#!/bin/sh
#
# Copyright (c) 1999-2005 SWsoft Inc.
# All rights reserved
#

#
# Plesk script
#


set_apache_params()
{
	apache_user="apache"
	apache_UID=80
	apache_group="apache"
	apache_GID=80
	apache_service_name="httpd"
	apache_new="2.0"

	apache_modules_d="/usr/local/psa/apache/libexec/"
	user_apxs="/usr/local/psa/apache/bin/apxs"

	apache_httpd_conf="$HTTPD_CONF_D/httpd.conf"
	apache_httpd_conf2="$HTTPD_CONF_D/httpd2.conf"
	apache_httpd_conf_in="$PRODUCT_ROOT_D/etc/httpd.conf.in"

	apache_httpd_include="$HTTPD_INCLUDE_D/zz010_psa_httpd.conf"

	APACHE_CERT="$HTTPD_CONF_D/httpd.pem"

	apache_pid_file="$APACHE_ROOT/logs/httpd.pid"
	apache_lock_file="$APACHE_ROOT/logs/httpd.lock"
	product_lock_file="$HTTPD_CONF_D/cnf.lock"

	min_suexec_UID=10000
	max_suexec_UID=16000
	min_suexec_GID=$min_suexec_UID
	max_suexec_GID=$max_suexec_UID

	suexec_storage=/usr/local/psa/apache/bin
	suexec=/usr/local/psa/apache/bin/suexec
	suexec_dir=/usr/local/psa/apache/bin
	suexec_file=suexec

	rpm_httpd_bin=/usr/sbin/httpd
}

remove_tmp_state()
{
	if [ -d "/tmp/.state" ]; then
		rm -Rf "/tmp/.state" >> $product_log 2>&1
	fi
}

#admin

set_admin_params()
{

	ADMIN_ROOT=$PRODUCT_ROOT_D/admin

	UTILS_DIR=$ADMIN_ROOT/bin

	admin_user="${product}adm"
	admin_UID=8444
	admin_group="${product}adm"
	admin_GID=8444

	admin_httpsd_conf="$ADMIN_ROOT/conf/httpsd.conf"
	ADMIN_CERT="$ADMIN_ROOT/conf/httpsd.pem"

	admin_pid_file=$ADMIN_ROOT/logs/httpsd.pid
	admin_lock_file=$ADMIN_ROOT/logs/httpsd.lock
}

lock_keyupdate()
{
	export PLESK_KEYUPDATE_DISABLED=installation
}


#fp

set_fp_params()
{
	fp_i_dir="/usr/local/frontpage"
	fp_v="version5.0"
	fpsrvadm="$fp_i_dir/$fp_v/bin/owsadm.exe"
	fp_root_def_port=80
	fp_admin="fpadmin"
	fp_admin_passwd="setup"
	fp_distrib="$PRODUCT_ROOT_D/fp.tar"
	fp_apache_stub_conf="$PRODUCT_ROOT_D/apache_tmp.conf"
#	fp_stub_head="$PRODUCT_ROOT_D/apache/conf/httpd.stub.head"
#	fp_stub_tail="$PRODUCT_ROOT_D/apache/conf/httpd.stub.tail"
}

# Print an error message and exit the program.
error()
{
    die "Exiting due to an error!  Please fix the error and try again." 
}


set_drweb_qmail_params()
{

	drweb_user="drweb"
	drweb_UID=89
	drweb_group="drweb"
	drweb_GID=89

	drweb_distrib="$PRODUCT_ROOT_D/drweb.tar"
	drweb_qmail_distrib="$PRODUCT_ROOT_D/drweb-qmail.tar"

	drweb_var_dir="/var/drweb"
}

get_admin_passwd()
{
	if [ -f "$mysql_passwd_file" ]; then
		admin_passwd=`cat "$mysql_passwd_file"`
	fi

	if [ -z "$admin_passwd" ]; then
		admin_passwd="$default_mysql_passwd"
	fi

}

#courier-imap

set_courier_imap_params()
{
	COURIER_IMAP_ROOT_D="$PRODUCT_ROOT_D/courier-imap"
	courier_imap_start="$PRODUCT_RC_D/courier-imap start"
	courier_imap_stop="$PRODUCT_RC_D/courier-imap stop"

	IMAPD_CERT="$COURIER_IMAP_ROOT_D/share/imapd.pem"
	POP3D_CERT="$COURIER_IMAP_ROOT_D/share/pop3d.pem"

	IMAPD_CONF="$COURIER_IMAP_ROOT_D/etc/imapd"
	POP3D_CONF="$COURIER_IMAP_ROOT_D/etc/pop3d"

	MAILPASSWD="$QMAIL_ROOT_D/users/poppasswd"
}

# db_test test_query awk_script
# Runs test_query and processes it with awk_script. If the output is
# not empty, return 0, otherwise return 1. Hint: supply '1' for
# awk_script to test just for the presence of any output.
db_test()
{
	local any_db=
	eval `sh_get_args '--any-db) any_db=yes;;'`

	local test_query="$1"
	local awk_script="$2"

	if [ -n "$any_db" ]; then
		local output="`mysql_raw_anydb -e \"$test_query\" 2>>\"$product_log\"`"
	else
		local output="`mysql_raw -e \"$test_query\" 2>>\"$product_log\"`"
	fi
	local status=$?
	if [ "$status" -ne 0 ]; then
		p_echo "$output"
		die "run the following SQL query: $1"
	fi

	echo -n "$output" | awk -F '\t' -- "$awk_script" | test `wc -l` -ne 0
}

#proftpd

set_ftpd_params()
{

	anonftp_user="${product}ftp"
	anonftp_group="${product}ftp"

	PROFTPD_ROOT="$PRODUCT_ROOT_D/ftpd"
}

set_jdk_params()
{
	jdk_distrib="$PRODUCT_ROOT_D/j2sdk.bin"
}

set_tomcat_params()
{
    set_common_params
 
    tomcat_distrib="$PRODUCT_ROOT_D/jakarta-tomcat.tar"
    prod_conf_t="/etc/psa/psa.conf"
    tomcat_version="4"
    CATALINA_HOME="/usr/local/psa/tomcat4"
    tomcat_user="tomcat4"
    tomcat_group="tomcat4"

    #basename directory. May be different. 
    dist_name="tomcat4"
 
    tomcat_conf="$CATALINA_HOME/conf/$dist_name.conf"
}


init_log()
{
echo >> $product_log	# initializing new output to log
echo "START LOGGING: `date`" >> $product_log
echo "SCRIPT: $0" >> $product_log
chmod 600 "$product_log"

echo >> $product_problems_log	# initializing new output to problems log
echo "START LOGGING: `date`" >> $product_problems_log
echo "SCRIPT: $0" >> $product_problems_log
chmod 600 "$product_problems_log"

problems_occured=0
}

p_echo()
{
echo "$*" >> "$product_log" 2>&1
echo "$*"
}

pnnl_echo()
{
if [ -z $necho_defined ]; then
	# set up echo
	case "`echo 'x\c'`" in
    	'x\c')
			echo="echo"
			echo_keys=" -n"
			nnl=
		;;
		x)
			echo="echo"
			echo_keys=
			nnl="\c"
		;;
		*)
			echo "ERROR: unable to set up echo."
		;;
	esac
	necho_defined=true
fi

${echo} ${echo_keys} "$*${nnl}" >> "$product_log" 2>&1
${echo} ${echo_keys} "$*${nnl}"
}

keyupdate_failure_report()
{
	if test -z "$KEYUPDATE_FAILURE_INFO"; then
		return
	fi

	p_echo
	p_echo " *****************************************************************************"
	p_echo " *                                                                           *"
	p_echo " *  ERROR:      The $PRODUCT_NAME license failed to upgrade. The failure     *"
	p_echo " *              follows:                                                     *"
	p_echo
	p_echo "$KEYUPDATE_FAILURE_INFO"
	p_echo
	p_echo " *              If you did not request the automatic key upgrade,            *"
	p_echo " *              please contact SWsoft, Inc sales department for assistance:  *"
	p_echo " *              ${sales_email}. If you want to proceed with upgrade without *"
	p_echo " *              the license upgrade, please create an empty file             *"
	p_echo " *				$prodkey                                             *"
	p_echo " *                                                                           *"
	p_echo " *****************************************************************************"
	p_echo
}

die()
{
	if [ "X$trigger_uninstall" != "X1" ]; then
		printf "\a\a"
		p_echo
		p_echo "ERROR while trying to $*"
		echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Aborting..."
			p_echo
		fi
	fi

	smart_undo_install

	keyupdate_failure_report

	selinux_close

	exit 1

}

err()
{

	if [ "X$trigger_uninstall" != "X1" ]; then
		p_echo
		p_echo "ERROR!"
		p_echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Exiting..."
			p_echo
		fi
	fi

	smart_undo_install

	exit 1
}

# This function needs for some print warning when some services cannot restart
# if called with arg, then we add arg to variable SR_WARNING and print warning
# message for arg, else print warning message for SR_WARNING
service_restart_warning()
{
	if [ "X$1" != "X" ]; then
		if [ "X${SR_WARNING}" = "X" ]; then
			SR_WARNING=$1
		else
			for i in ${SR_WARNING}; do
				if [ "$i" = "$1" ]; then
					break
				fi
			done
			if [ "$1" != "$i" ]; then
				SR_WARNING=$SR_WARNING" "$1
			fi
		fi
		p_echo "WARNING!"
		p_echo "Some problems occured when $1 restart, check it after installation/upgrade complete"
	        p_echo
	 	p_echo "Continue..."
		p_echo
	else
		if [ "X${SR_WARNING}" != "X" ]; then
			p_echo "WARNING!"
		        p_echo "Some problems occured when following services restart:"
			for i in ${SR_WARNING}; do
				p_echo $i
			done
			p_echo "Don't forget to check it after installation/upgrade complete"
        		p_echo
	       	        p_echo "More information can be found in log file: ${product_log}"
			p_echo
		fi
	fi
}

warn()
{
local inten
inten="$1"
p_echo
p_echo "WARNING!"
pnnl_echo "During the $inten found some problems"
echo "(see log file: ${product_log})"
p_echo
p_echo "Continue..."
p_echo

}

echo_try()
{
	msg="$*"
	pnnl_echo " Trying to $msg... "
}

suc()
{
	p_echo "done"
}

mk_backup()
{
	target="$1"
	dup="$2"
	opts="$3"

	if [ -L "$target" ]; then
		rm "$target"
	elif [ -$opts "$target" ]; then
		if [ ! -$opts "$target.$product_suffo" ]; then
			case "$dup" in
				mv)
					mv -f $target $target.$product_suffo || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suffo || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		else
			case "$dup" in
				mv)
					mv -f $target $target.$product_suff || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suff || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		fi
	else
		case "$opts" in
			f|d)
				;;
			*)
				p_echo " mk_backup: wrong option -- must be 'f' or 'd'"
				die "mk_backup"
				;;
		esac
	fi
}

# accumulates chown and chmod
set_ac()
{
	u_owner="$1"
	g_owner="$2"
	perms="$3"
	node="$4"

	chown $u_owner:$g_owner $node || die "chown $u_owner:$g_owner $node"
	chmod $perms $node || die "chmod $perms $node"
}

detect_vz()         
{                   
    local vzcheck_file
        
    PLESK_VZ=0
    vzcheck_file="/proc/self/status"
                    
    if [ ! -f ${vzcheck_file} ]; then
        return 1; 
    fi              
                    
    grep -q -E '^envID\:[[:space:]]*([[:digit:]]+)$' < ${vzcheck_file} >/dev/null 2>&1
                    
    if [ $? -eq 0 ]; then
        PLESK_VZ=1  
        return 0;
    fi      
    return 1;
}       

call_optional_function()
{
	local type_output="`type \"$1\" 2>/dev/null | head -n 1`"
	case "$type_output" in
		*function)
			"$@"
			;;
		*)
			return 0
			;;
	esac
}

sh_get_args()
{
	echo 'while true; do case "$1" in '"$1"'*) break;; esac; shift; done'
}

# Super server internet library

super_server_type()
{
	case "$super_server" in

		'xinetd' | 'inetd')
			;;
		*)
			# check what super-server installed
			inten="define super-server internet daemon type"
			echo_try "$inten"
			
			local xinetd_pid=`get_pids_byname "xinetd"`
			local inetd_pid=`get_pids_byname "inetd"`
			
			
			if [ -z "$xinetd_pid" ]; then
				if [ -z "$inetd_pid" ]; then
					if [ -f "$xinetd_conf" ]; then
						super_server="xinetd"
						xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
					elif [ -f "$inetd_conf" ]; then
						super_server="inetd"
					else
						die "$inten"
					fi
				else
					super_server="inetd"
				fi
			else 
				super_server="xinetd"
				xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
			fi				 
				
			p_echo "$super_server"
			;;
	esac
}

restart_super_server()
{
	if [ -n "$CHROOTISH" ]; then
			return 0
	fi

	# if PLESK_INSTALLER_DEBUG = daemons then print process table and network status.
	# Usefull for research bugs like 63469, 51592 and other with listen/restart services.
	if [ "X$PLESK_INSTALLER_DEBUG" = "Xdaemon" ] ; then
		ps axl
		netstal -pl
	fi

	super_server_type

	case "$super_server" in

		'xinetd')

		    inten="restart xinetd daemon"
		    echo_try "$inten"
		    case "$machine" in

 		        linux)
				$PRODUCT_RC_D/xinetd reload >> $product_log 2>&1
			    ;;
	 
		        *)
	            	    # not Linux
			    xinetd_pid=`$ps | grep xinetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
				if [ "X${xinetd_pid}" = "X" ]; then
					service_restart_warning "xinetd"
				else
				    $K_USR2 $xinetd_pid >> $product_log 2>&1 && suc || die "$inten"
				fi
	            	    ;;
								 
	            esac

		;;

		'inetd')

			inetd_pid=`$ps | grep inetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
			inten="restart inetd daemon"
			echo_try "$inten"

			if [ "X${inetd_pid}" = "X" ]; then
				 service_restart_warning "inetd"
			else
				$K_HUP $inetd_pid >> $product_log 2>&1 && suc || die "$inten"
			fi
		;;
	esac
}

comment_service_xinetd()
{
	#comment service records
	local dir file service grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	for dir in $xinetd_dir; do

		for file in $dir/*; do

			grep_res=`grep "$service" $file`
			case "$?" in
				0)
					awk "/^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
						{ print \"#\"\$0; next; }
						{print}
						" <$file >$file.tmp  &&
					mv -f $file.tmp $file || die "$inten" >> $product_log 2>&1
					restart_super_server
					;;
				*)
					;;
			esac

		done;

	done;

	suc

}

comment_service_inetd()
{
	local grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	grep_res=`grep "^$service[[:space:]]" $inetd_conf`

	case "$?" in
	
		0)
			sed -e "s|^$service|##commented_by_psa $service|g" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
			&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" \
			&& suc || die >> $product_log 2>&1
			restart_super_server
			;;
		*)
			p_echo " no record for service $service found in the $inetd_conf"
			;;
	esac
}

comment_service()
{
	local service
	service=$1
	
	super_server_type

	case "$super_server" in

		'xinetd')
			comment_service_xinetd "$service"
			;;

		'inetd')
			comment_service_inetd "$service"
			;;

		*)
			die "Super server type is undefined"
			;;
	esac

}


remove_xinetd()
{
	local service file
	service=$1;
	
	rm -f $xinetd_dir/${service}_${product}
	
	#uncomment old records
	inten="comment out ${product} record for service $service"

	for file in $xinetd_dir/*; do
		awk "/^[[:space:]]*#[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
			{ print substr(\$0,2); next; }
			{print}
			" <$file >$file.tmp &&
		mv -f $file.tmp $file >> $product_log 2>&1
	done;

	restart_super_server

}

remove_inetd()
{
	local service
	service=$1;

	case "$service" in

		ftp)
			inten="restore ftp service record in the $inetd_conf"

			sed -e "s|^ftp.*/${product}/ftpd/sbin/proftpd.*||g" \
				-e "s|ftp.*/${prev_product}/ftpd/sbin/proftpd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtp)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtp.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtp.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtp.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtps)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtps.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtps.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtps.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		pop3)
			inten="restore pop3 service record in the $inetd_conf"

			sed -e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				-e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			
		    ;;
		poppassd)
			# poppassd stream tcp nowait root /usr/sbin/tcpd /${PRODUCT_ROOT_D}/admin/bin/poppassd
			inten="restore poppassd service record in the $inetd_conf"

			sed -e "s|^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			;;
		
	esac

	# uncomment old records
	sed -e "s|^##commented_by_psa $service|$service|g" < $inetd_conf > $inetd_conf.${product}_tmp \
	&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1

	restart_super_server

}

remove_super_server()
{
	local service
	service=$1;

	super_server_type

	case "$super_server" in

		xinetd)
			remove_xinetd "$service"
			;;
		inetd)
			remove_inetd "$service"
			;;
	esac
}

setup_xinetd()
{
	local service file rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	#comment old records
	comment_service "$service"	
	
	#setup
	service=$1;
	inten="set up record for service $service"
	echo_try "$inten"

	case "$service" in

		ftp)
			echo "
service ftp
{
	socket_type		= stream
	protocol		= tcp
	wait			= no
	disable			= no
	user			= root
	instances		= UNLIMITED
	server			= $PRODUCT_ROOT_D/ftpd/sbin/proftpd
	server_args		= -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf
}" > "$xinetd_dir/ftp_${product}" || die "$inten"
			;;

		smtp)

			case "$rbl_on" in

				on)				
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;

				*)
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;
			esac	
			;;

		smtps)
			case "$rbl_on" in
				on)				
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
				*)
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
			esac	
			;;

		poppassd)
			echo "
service poppassd
{
	socket_type		= stream
	protocol		= tcp
	port			= 106
	wait			= no
	disable			= no
	user			= root
	instances		= 1000
	flags			= KEEPALIVE
	server			= $PRODUCT_ROOT_D/admin/bin/poppassd
}" > "$xinetd_dir/poppassd_${product}" || die "$inten"
			;;
	esac

    case "$machine" in
       Darwin)
echo '#!/bin/sh

name_service='org.xinetd.xinetd'
    
    case "$1" in
        start)
           echo "Plesk: Starting xinetd"
           launchctl start "$name_service"
        ;;
        stop)
           echo "Plesk: Stopping xinetd"
           launchctl stop "$name_service"
        ;;
        restart)
           start
           stop
        ;;
        *)
           echo "Usage: xinetd [start|stop|restart]"
        ;;
    esac 
' > "$PRODUCT_RC_D/xinetd"

     chmod 755 "$PRODUCT_RC_D/xinetd"
       ;;
       *)
       ;;
    esac

	suc
}

setup_inetd()
{
	local service rbl_on rbl_server

	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	local ftp_rec smtp_rec pop3_rec 

	ftp_rec="ftp stream tcp nowait root $PRODUCT_ROOT_D/ftpd/sbin/proftpd proftpd -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf"
	
	case "$linux_distr" in
		debian)
			maxconn='.1000'
		;;
		*)
		        maxconn=""
		;;
	esac

	case "$rbl_on" in
		on)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
		*)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
	esac

	case "$machine" in
		BSD*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/libexec/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
		*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/sbin/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
	esac

	case "$service" in

		ftp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "ftp"
				/usr/sbin/update-inetd --add "$ftp_rec"

			else
				grep_res=`egrep "^ftp.*/${product}/ftpd/sbin/proftpd*." $inetd_conf`
				inten="add ftp service (proftpd) record into the $inetd_conf file"
				echo_try $inten

				case "$grep_res" in
					ftp*)
						p_echo
						p_echo " ftp service (proftpd) is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$ftp_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;

		smtp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtp"
				/usr/sbin/update-inetd --add "$smtp_rec"

			else
				egrep "^smtp.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtp/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtp service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtp_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		smtps)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtps"
				/usr/sbin/update-inetd --add "$smtps_rec"

			else

				egrep "^smtps.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtps/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtps service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtps_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		poppassd)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "poppassd"
				/usr/sbin/update-inetd --add "$poppassd_rec"
			else
				#	^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*
				grep_res=`egrep "^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*" $inetd_conf`
				inten="add poppassd service record in the $inetd_conf"
				echo_try $inten
		
				case "$grep_res" in
					poppassd*)
						p_echo
						p_echo " poppassd service is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$poppassd_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;
	esac

}

setup_super_server()
{
	local service rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;

	super_server_type

	case "$super_server" in

		xinetd)
			setup_xinetd "$service" "$rbl_on" "$rbl_server"
			;;
		inetd)
			setup_inetd "$service" "$rbl_on" "$rbl_server"
			;;
	esac

	restart_super_server
}

get_pid()
{
	local i

	ex_f="$1"
	opt="$2"
	owner="$3"

	min_num=`expr 1`

	case "$opt" in
		false)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		true)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep "$owner" | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		*)
			p_echo "get_pid: wrong parameter"
			die "get_pid $ex_f $opt $owner"
			;;
	esac

	common_var=$min_num
	return $min_num
}

kill_pids()
{
	ex_f="$1"
	owner="$2"

	for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep $owner | awk '{print $2}' -`; do
		if [ $i -gt 1 ]; then
			$K_TERM $i >> $product_log 2>&1
		fi
	done
}

get_pids_byname()
{
	proc_name="$1"
	PIDS=`ps axww | awk '$5 ~ "'$proc_name'$" {print $1}'`
	echo $PIDS
}

#lib_test

test_for_root()
{
	my_id="`id`"
	case "$my_id" in
		uid=0\(root\)*)
			;;
		*)	echo "$0: This script must be run as root"
			echo "Log in as root then run this script again."
			echo
			exit 1
			;;
	esac
}
get_userID()
{
# try to get UID
	common_var=`id -u "$1" 2>/dev/null` 

# if id returns 0 the all is ok
	if [ "$?" -eq "0" -a ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

get_groupID()
{
# try to get GID, id -g doesn't show groups without users
    case "$machine" in
       Darwin)
         common_var=`nireport / /groups name gid| grep "$1"| awk '{print $2}'`
       ;;
	   *)
         common_var=`cat /etc/group | awk -F':' '$1 == "'$1'" {print $3}'` 
       ;;
    esac

# We have non-empty value if success
	if [ ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

delete_user()
{
	local rm_user

	rm_user="$1"

	# if it is mailman user, remove its crontab from system
	if [ "X${rm_user}" = "X${mailman_user}" ]; then

		inten="remove crontab of ${rm_user}"
		echo "y" | $crontab -u "${mailman_user}" -r >> $product_log 2>&1 || die "$inten"

	fi

	inten="remove user $rm_user"
	echo_try "$inten"

	case "$machine" in
		BSD)
			echo "y" | pw userdel $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmuser $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1

		;;
		linux|solaris)
			userdel  $rm_user>> $product_log 2>&1 && suc || die "$inten"
		;;
		Darwin)
			niutil -destroy / /users/"$rm_user" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
}

delete_group()
{
	local rm_group

	rm_group="$1"

	inten="remove group $rm_group"
	echo_try "$inten"

	case "$machine" in
		BSD)
			pw groupdel $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmgroup $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		linux|solaris)
			mk_backup "/etc/group" cp f
			if [ -f "/etc/group" ]; then
				sed -e "/$rm_group/d" < /etc/group > /etc/group.tmp || die $inten
				mv -f /etc/group.tmp /etc/group  >> $product_log 2>&1
				if [ "$?" -ne 0 ]; then
					rsr_backup "/etc/group" cp f
					die $inten
				fi
			fi
#		groupdel  $rm_group>> $product_log 2>&1
		;;
		Darwin)
			niutil -destroy / /groups/"$rm_group" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
	suc
}
initial_conf()
{
	DEMO_VERSION="no"
	PRODNAME="psa"
	PRODUCT_NAME="Plesk"
	product_full="Plesk"
	PRODUCT_FULL_NAME="Plesk"

	product_etc="/etc/${PRODNAME}"
	prod_conf_t="/etc/psa/psa.conf"
	prodkey="$product_etc/$PRODNAME.key"

	minimal_changes=""

	MYSQL_VERS="4.1.18"
	POSTGRESQL_VERS="7.4.11"
	EXTERNAL_PACKAGES="expat libiconv"
	EXTERNAL_PACKAGES_DIR=""tmp/packages""

	BUILDER_UID="10007"

	PERL5LIB="/usr/local/psa/lib/perl5/site_perl/5.8.8:/usr/local/psa/lib/perl5/site_perl/5.8.8/mach"
	export PERL5LIB

	product_bs=Plesk
        support_contact="http://www.swsoft.com/support"
	sales_email="sales@swsoft.com"

	product_version="8.0.1"
	product_db_version="0801"
	product_build="80061018.20"
	conceived_os_vendor=FreeBSD
	conceived_os_version="4.11"
	osrels="fr4.11"

	# This variable contains all versions, which is supported by
	# cumulative upgrade
	known_product_versions="71 75 80"

	prev_product="plesk"
	prev_clients_group="${prev_product}cln"

	# GID for mailman
	mm_mailgroup=110

	# plesk default password
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		PRODUCT_DEFAULT_PASSWORD="plesk"
	else
		PRODUCT_DEFAULT_PASSWORD="setup"
	fi

	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
		echo "Unable to determine current working directory."
		echo "Please fix the problem and run installation again."
		exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
		0)
			my_name="$my_name_2"
		;;
		1)
			my_name="$my_name_0"/"$my_name_2"
		;;
	    *)
			echo "Unable to determine the name of installer."
			echo "Please fix the problem and run installation again."
			exit 1
		;;
	esac
}

read_conf()
{
	initial_conf

	if [ -s $prod_conf_t ]; then
		tmp_var=`perl -e 'undef $/; $_=<>; s/#.*$//gm;
				s/^\s*(\S+)\s*/$1=/mg;
				print' $prod_conf_t`
		eval $tmp_var
	else
		[ 0$ignore_miss_conf -ne 1 ] && p_echo "Unable to find product configuration file: $prod_conf_t"
		return 1
#		die "find product configuration file: $prod_conf_t"
	fi
	return 0

}

selinux_close()
{
	if [ -z "$SELINUX_ENFORCE" -o "$SELINUX_ENFORCE" = "Disabled" ]; then
		return
	fi

	setenforce "$SELINUX_ENFORCE"
}


#set_params

set_common_params()
{

	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	LANG=C
	export PATH LANG
	umask 022
	ulimit -n 65535 2>/dev/null

	K_HUP="/bin/kill -HUP"
	K_KILL="/bin/kill -KILL"
	K_TERM="/bin/kill -TERM"
	K_USR2="/bin/kill -USR2"

	users_created=""
	groups_created=""

	certificate_file="$PRODUCT_ROOT_D/etc/httpsd.pem"
	product=${PRODNAME}
	START_SH="$PRODUCT_RC_D/${product}"

	clients_group="${product}cln"
	clients_GID=10001

	services_group="${product}serv"
	services_GID=10003

	product_suff="saved_by_${product}".`date "+%m.%d;%H:%M"`
	product_suffo="saved_by_${product}"

	common_var=0

	services="/etc/services"
	mtab="/etc/mtab"
	xinetd_conf="/etc/xinetd.conf"
	xinetd_dir="/etc/xinetd.d"
	inetd_conf="/etc/inetd.conf"
	syslog_conf="/etc/syslog.conf"
	syslog_conf_ng="/etc/syslog-ng/syslog-ng.conf"
	get_hostname="hostname"
	get_domainname="domainname"

	#VZP used to determine that we're inside SVE
	vza_file="/var/vzagent"

	PREV_PRODUCT_ROOT_D="/usr/local/${prev_product}"

	#default parameters
	tar="tar"
	crontab="/usr/bin/crontab"

	#machine depended parameters
	TARGET_OS="`uname -a`"
	case "$TARGET_OS" in

		BSD/OS*BSDI*i386)
			machine="BSDI"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			compress="compress"
			uncompress="uncompress -c"
			uudecode="uudecode -o /dev/stdout"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		FreeBSD*i386)
			fstab="/etc/fstab"
			machine="BSD"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axfwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/usr/local/bin/bash"
			rbash_shell="/usr/local/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			os_version=`uname -v | sed -e 's/^.*FreeBSD[ \t][ \t]*\([0-9\.][0-9\.]*\)-.*$/\1/'`

			if tar --version | grep bsdtar > /dev/null ; then
				if which gtar > /dev/null; then
				    tar="gtar"
				else
				    echo "Unable to locate gtar on your system."
				    echo "Please, install the archiving software and retry installation."
				    exit 1
				fi
			fi

			named_osrelease=040100 # "must be >= 020218 for  named -u <named> "
			;;
		Darwin*powerpc)
			machine="Darwin"
			sendmail="/usr/sbin/sendmail"
			mail_local=""
			ps="ps axw"
			ps_long="ps axSwu"
			dummy_shell="/usr/bin/false"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/bin/bash"
			rbash_shell="/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab.hd"
			;;

		SunOS*5.*sun4*)
			machine="solaris"
			inetd_conf="/etc/inet/inetd.conf"
			services="/etc/inet/services"
			crontab="/bin/crontab"
			useradd_options=""
			sendmail="/usr/lib/sendmail"
			sndml_ini="/etc/init.d/sendmail"
			mail_local="/usr/lib/mail.local"
			ps="ps -e"
			ps_long="ps -aef"
			dummy_shell="/bin/false"
			dummy_home="/"
			false_shell="/bin/false"
			compress="compress"
			uncompress="uncompress"
			uudecode="uudecode -p"
			uudecode_full="/bin/uudecode"
			tar="gtar"
			ifconfig="/usr/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		Linux*2.?.*i?86*| \
		Linux*2.?.*x86_64*)
			get_hostname="hostname -f"
			fstab="/etc/fstab"
			if [ -f /etc/slackware-version ]; then
			    machine="linux"
			    linux_distr="slackware"
			    useradd_options=""
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/rc.d/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell=""
			    dummy_home="/"
			    false_shell="/bin/false"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=0
			else
			    machine="linux"
				useradd_options="-M"
				if [ -f /etc/mandrake-release ]; then
			    	linux_distr="mandrake"
				elif [ -f /etc/fedora-release ]; then
			    	linux_distr="fedora"
				elif [ -f /etc/SuSE-release ]; then
			    	linux_distr="suse"
				elif [ -f /etc/debian_version ]; then
			    	linux_distr="debian"
					get_domainname="dnsdomainname"
					useradd_options=""
				else
			    	linux_distr="redhat"
				fi
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell="/bin/false"
			    dummy_home="/"
			    false_shell="/bin/false"
				bash_shell="/bin/bash"
				rbash_shell="/bin/rbash"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    uudecode_full="/usr/bin/uudecode"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=`cat /proc/sys/kernel/osrelease | perl -F"/[.-]/" -n -a  -e 'printf "%02u%02u%02u\n", $F[0],$F[1],$F[2]'`
			fi
			;;
		*)
			echo
			echo "Sorry, but your configuration isn't supported yet"
			echo "uname is $TARGET_OS"
			echo
			echo "For more information, please contact $support_email"
			echo
			;;
	esac

	# setup process
	if [ "X$process" = "X" ]; then
		if   [ "X$do_reconfigure" = "X1" ]; then
	    	process="reconfiguration"
		elif  [ "X$do_upgrade" = "X1" ]; then
	    	process="upgrade"
		else
		    process="installing"
		fi
	fi

#	common_var="real"
#	if [ -f $PRODUCT_ROOT_D/version -a "X$do_patch" = "X" ]; then
#	    common_var=`cat $PRODUCT_ROOT_D/version | tr '[:blank:]' '_'`
	product_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_${process}.log"
	product_problems_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_problems.log"
	init_log
#	elif [ "X$my_name_1" != "X" ]; then
#	    product_log="/tmp/${my_name_1}.log"
#	else
#	    product_log="/tmp/${product}_default_${process}.log"
#	fi

	detect_vz
}


set_local_params()
{
	set_common_params

	for i in set_apache_params set_admin_params lock_keyupdate set_fp_params set_drweb_qmail_params set_courier_imap_params set_ftpd_params set_jdk_params set_tomcat_params set_logrotate_params set_mailman_params set_mysqld_params set_named_params set_openssl_params set_pgsql_params set_qmail_params set_spamassassin_params set_vhosts_params set_webalizer_params set_horde_params ; do
		$i
		local res="$?"
		if [ "0$res" -gt 0 ]; then
			return "$res"
		fi
	done
}
set_logrotate_params()
{
	# primary Plesk logrotate config file
	logrotate_conf="${product_etc}/logrotate.conf"

	# directory for logrotate configs of virtual hosts
	logrotate_include_d="${PRODUCT_ROOT_D}/etc/logrotate.d"
}

#all functions in this file are valid for Standard builds only
set_mailman_params()
{
	mailman_user="mailman"
	mailman_group="mailman"
	mailman_UID=91
	mailman_GID=91
	MAILMAN_ROOT_D="${PRODUCT_ROOT_D}"/mailman
	MAILMAN_VHOST_D="${HTTPD_VHOSTS_D}"/mailman
}

remove_modules()
{
	p_echo
	p_echo "===> Removing modules"

	local moduledir
	for moduledir in $PRODUCT_ROOT_D/var/modules/*; do
		if [ -d "$moduledir" -a -x "$moduledir/uninstall" ]; then
			local module=`basename $moduledist`
			echo_try "uninstall $module module"
			"$moduledir/uninstall" && suc || warn "uninstallation of $module module"
		fi
	done
}

#mysql

set_mysqld_params()
{
	mysql_user="mysql"
	mysql_UID=3306
	mysql_group="mysql"
	mysql_GID=3306

	product_db_sql="$PRODUCT_ROOT_D/etc/${PRODNAME}_db.sql"

	mysql_passwd_file="$product_etc/.${PRODNAME}.shadow"
	default_mysql_passwd="$PRODUCT_DEFAULT_PASSWORD"
	prev_mysql_passwd_file="$PREV_PRODUCT_ROOT_D/admin/conf/admin.conf"

#	admin_passwd=${default_mysql_passwd}
	get_admin_passwd

	set_mysql_client_params
	set_mysql_server_params
}

## @@constructor set_mysqld_params

set_mysql_server_params()
{
	MYSQL_ROOT="$PRODUCT_ROOT_D/mysql"
	mysql_bindir="$MYSQL_BIN_D"
	mysql_service="mysqld"
}

set_mysql_client_params()
{
	mysql_client="$MYSQL_BIN_D/mysql"

	# Override these variables as needed
	mysql_db_name="$PRODNAME"
	mysql_auth="-uadmin -p$admin_passwd"
	mysql_args="-N"
	mysql_args_raw="-B -r"

	# For backward compatibility only, should use mysql() and mysql_raw() instead
	mysql=mysql
	mysql_raw=mysql_raw
}

# Invoke mysql
mysql()
{
	mysql_anydb -D$mysql_db_name "$@"
}

mysql_anydb()
{
	if test -z "$DB_IS_MYSQL41_COMPATIBLE"; then
		mysql41_init
	fi

	if test "$DB_IS_MYSQL41_COMPATIBLE" != "compatible"; then
		mysql41_exec_wrapper $mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	else
		$mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	fi

	local status=$?
	if [ $status -gt 0 ]; then
		$mysql_client $mysql_auth $mysql_args -D$mysql_db_name $mysql_args_raw -e "show innodb status" >>"$product_log" 2>&1
	fi
	return $status
}

# the function removes the "character set xxx" and "collate xxx" construction
# from -e * arguments, if there are any.
# otherwise, it removes the same things from standard input
mysql41_exec_wrapper()
{
	perl -e '$has_command = 0;
		$program = $ARGV[0];
		splice (@ARGV, 0, 1);
		sub remove_chasets($)
		{
			$refStr = shift;
			$$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+binary(\s+collate\s+[\w]+)?\b/ $1blob /ig;
            $$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b/ $1blob /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+binary(\s+collate\s+[\w]+)?\b)/ binary /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b)/ binary /ig;
			$$refStr =~ s/(\b(character\s+set|collate)\s+[\w]+\b)//ig;
		}
		foreach $n (0 .. $#ARGV) {
			if ($ARGV[$n] eq "-e") {
				$has_command = 1;
				remove_chasets \($ARGV[$n + 1]);
			}
		}
		if ($has_command) {
			exec $program, @ARGV or die "Cannot exeecute mysql";
		} else {
			open out_command, "|-", $program, @ARGV or die "Cannot start mysql";
			while (<STDIN>) {
				remove_chasets \($_);
				print out_command $_;
			}
			close out_command or die($! ? "Mysql returned an error: $!" : "Mysq exited with non-zero status $?");
		}' -- "$@"
}

# Invoke mysql in raw mode
mysql_raw()
{
	mysql $mysql_args_raw "$@"
}

mysql_raw_anydb()
{
	mysql_anydb $mysql_args_raw "$@"
}

mysql41_init()
{
	# not_installed is the default state
	# we must init it to avoid endless cycle
	DB_IS_MYSQL41_COMPATIBLE=not_installed
	if ! mysql_anydb </dev/null >>"$product_log" 2>&1; then
		return
	fi

	if db_test --any-db "SHOW VARIABLES LIKE 'version'" '$2 !~ /^(3|4\.0)\./'; then
		# if database is not yet initiailized, assume it compatible
		# otherwise, check the flag
		if
			db_test --any-db "SHOW DATABASES" '/^psa$/' \
			&& db_test "SHOW TABLES" '/^misc$/' \
			&& ! db_test "SELECT val FROM misc WHERE param = 'mysql41_compatible'" '/true/'
		then
			DB_IS_MYSQL41_COMPATIBLE='not_compatible'
		else
			DB_IS_MYSQL41_COMPATIBLE='compatible'
		fi
	fi
}

#named

set_named_params()
{
	# set up default values
	bind_UID=53
	bind_GID=53
	bind_user="named";
	bind_group="named";

	# get UID of named user, if exists
	get_userID $bind_user
	if [ $? -ne 0 ]; then
	    bind_UID=$common_var;
        fi

	# get GID of named group, if exists
	get_groupID $bind_group
	if [ $? -ne 0 ]; then
	    bind_GID=$common_var;
	fi

	# old named is not able to run in non-root environment
	if [ 0$named_osrelease -lt 020218 ]; then
	    bind_user="root";
	    bind_UID=0;
	fi

	# path to directory of internal named
	NAMED_ROOT_D="${PRODUCT_ROOT_D:?'PRODUCT_ROOT_D is undefined'}/named"

	# path to directory of named pid file
	bind_run="${NAMED_RUN_ROOT_D:?'NAMED_RUN_ROOT_D is undefined'}/var/run/named"
	# Named start/stop script
	NAMED_RC_SCRIPT="/usr/local/psa/rc.d/named"
	
	# path to named config file
	named_conf="/etc/named.conf"
	rndc_conf="/etc/rndc.conf"
	rndc_namedb_conf="/etc/namedb/rndc.conf"
	rndc_bind_conf="/etc/bind/rndc.conf"
}
set_openssl_params()
{
    openssl_psa_sbin=${PRODUCT_ROOT_D}/admin/sbin/openssl;
    openssl_psa_bin=${PRODUCT_ROOT_D}/admin/bin/openssl;
    openssl_std_bin=/usr/bin/openssl;
}
set_pgsql_params()
{
	pgsql_user="postgres"
	pgsql_group="postgres"
	pgsql_UID=5432
	pgsql_GID=5432

	# path to postgresql for Standard builds
	PGSQL_ROOT_D="$PRODUCT_ROOT_D/postgresql"
}

#qmail

set_qmail_params()
{
QMAIL_DIR="/usr/local/psa/qmail"
QMAIL_USERS="alias:2021:nofiles:false:alias  qmaild:2020:nofiles:false:  qmaill:2022:nofiles:false:  qmailp:2023:nofiles:false:  qmailq:2520:qmail:  qmailr:2521:qmail:  qmails:2522:qmail:"
QMAIL_GROUPS="qmail:2520  nofiles:2020"
}
#values of variables in set_spamassassin_params are valid for Standard builds only

set_spamassassin_params()
{
	SPAMASSASSIN_ROOT_D=${PRODUCT_ROOT_D}/spamassassin
}

rsr_backup()
{
	target="$1"
	dup="$2"
	opts="$3"
	common_var=0

#	if [ -$opts "$target" ]; then
		if [ -$opts "$target.$product_suff" ]; then
			case "$dup" in
				mv)
					mv -f  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			esac
		else
			if [ -$opts "$target.$product_suffo" ]; then
			    case "$dup" in
				mv)
					mv -f  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			    esac
			fi
		fi
#	else
#		case "$opts" in
#			f|d)
#				;;
#			*)
#				p_echo " rsr_backup: wrong option -- must be 'f' or 'd'"
#				;;
#		esac
#	fi
}

restore_named()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1
	[ -f /etc/sysconfig/named ] && mv -f "/etc/sysconfig/named" "/etc/sysconfig/named.bak"
	rsr_backup "/etc/sysconfig/named" mv f

	[ -L $named_conf ] && rm -f "$named_conf"
	rsr_backup "$named_conf" mv f

	[ -L $rndc_conf ] && rm -f "$rndc_conf"
	rsr_backup "$rndc_conf" mv f

	case "$machine" in
		BSD*)
			rsr_backup /etc/named.boot mv f
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --add named >> $product_log 2>&1
#			    std_named_sh="/etc/rc.d/init.d/named"
#			    rsr_backup $std_named_sh mv f
#				if [ -f "$std_named_sh" ]; then
#					mv -f "$std_named_sh.${product}" "$std_named_sh"
#				fi
				;;
			slackware)
			    rsr_backup /etc/rc.d/rc.inet2 cp f
				;;
		    esac
			rsr_backup /etc/named.boot mv f
			;;
		solaris)
			rsr_backup /etc/named.boot mv f
			;;
	esac
}


restore_sendmail()
{
	[ -L $sendmail ] && rm -f "$sendmail"
	[ -L /usr/lib/sendmail ] && rm -f "/usr/lib/sendmail"

	rsr_backup "$sendmail" mv f

	case "$machine" in
		BSDI)
			rsr_backup /etc/sendmail.cf mv f
			;;
		*)
			;;
	esac

	if [ -f "$mail_local" ]; then
#		case "$machine" in
#			BSD)
#				chflags schg "$mail_local" >> $product_log 2>&1
#				;;
#			*)
#				;;
#		esac

		rsr_backup "$mail_local" mv f

		chmod 4555 "$mail_local" >> $product_log 2>&1
	fi
	case "$machine" in
		linux )
		    case "$linux_distr" in
			redhat)
			    chkconfig --add sendmail >> $product_log 2>&1
#			    rsr_backup "$sndml_ini" mv f
				;;
			slackware)
			     rsr_backup /etc/rc.d/rc.M mv f
				;;
		    esac
			;;
		solaris)
			rsr_backup "$sndml_ini" mv f
			;;
		*)
			;;
	esac

}

delete_startup_scripts()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1

	case "$machine" in
		BSD)
			rm -f /usr/local/etc/rc.d/${product}.sh >> $product_log 2>&1
	#		rsr_backup /etc/rc.conf cp f

#			inten="enable standard sendmail & named (within /etc/rc.conf)"
#			echo_try $inten
			sed -e 's/^sendmail_enable="NONE".*//g' \
				-e "s/^#named_enable/named_enable/g" \
				< /etc/rc.conf > /etc/rc.conf.${product}_tmp
			mv -f /etc/rc.conf.${product}_tmp /etc/rc.conf
#			suc
			;;
		BSDI)
			if [ -f /etc/rc.local.${product} ]; then
				cp -p  /etc/rc.local.${product} /etc/rc.local >> $product_log 2>&1
			fi
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --del ${product}
			    rm -f /etc/rc.d/init.d/${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc0.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc1.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc2.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc3.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc4.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc5.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc6.d/K15${product} >> $product_log 2>&1
				;;
			slackware)
			    if [ -f /etc/rc.d/rc.local.${product} ]; then
				cp -p  /etc/rc.d/rc.local.${product} /etc/rc.d/rc.local >> $product_log 2>&1
			    fi
				;;
		    esac
		    ;;
		solaris)
			rm -f  /etc/init.d/${product} >> $product_log 2>&1
			if [ -f /etc/rc0.d/K01${product} ]; then
				rm -f /etc/rc0.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc1.d/K01${product} ]; then
				rm -f /etc/rc1.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc2.d/S77${product} ]; then
				rm -f /etc/rc2.d/S77${product} >> $product_log 2>&1
			fi
			;;
	esac
}

delete_crontab()
{

	$crontab -l 2>/dev/null > /tmp/crontab.${product}

	sed -e "s/^.*\/${product}\/admin\/sbin\/statistics.*//g" \
		-e "s/^.*\/${product}\/bin\/mysqldump.*//g" \
		-e "s/^.*\/usr\/sbin\/ntpdate.*//g" \
		< /tmp/crontab.${product} > /tmp/crontab.${product}_tmp

	mv -f /tmp/crontab.${product}_tmp /tmp/crontab.${product} >> $product_log 2>&1

	$crontab /tmp/crontab.${product}  >> $product_log 2>&1

	rm -f /tmp/crontab.${product} >> $product_log 2>&1

}

remove_ftpuser()
{
	user=$1
	ftpusers_file="/etc/ftpusers"

	egrep "^$user" $ftpusers_file >> /dev/null 2>&1

	case "$?" in
			0)
				sed -e "/$user/d" < $ftpusers_file > $ftpusers_file.tmp
				mv -f $ftpusers_file.tmp $ftpusers_file
				;;
			1)
				;;
			*)
				;;
	esac

}

remove_product_users_groups()
{

#	delete users of this(unsuccessful) installation
	for i in $users_created; do
		delete_user "$i"
	done
#	delete users with group=psacln (ftpusers and webusers)
	for i in `perl -e '$gid=getgrnam("'$clients_group'"); exit if (($gid eq "") || ($gid == 0)); while(($n,$u,$g) = (getpwent)[0,2,3]) {print "$n\n" if (($gid == $g) && ($u >= 500))}'`
	do
		delete_user "$i"
		remove_ftpuser "$i"
	done
#	delete users psaadm, psaftp
#	delete_user "$admin_user"  >> "$product_log" 2>&1
#	delete_user "$anonftp_user"  >> "$product_log" 2>&1

#	delete groups of this(unsuccessful) installation
	for i in $groups_created; do
		delete_group "$i"
	done
#	delete groups psaadm, psaftp, psacln
	delete_group "$admin_group"  >> "$product_log" 2>&1
	delete_group "$anonftp_group"  >> "$product_log" 2>&1
	delete_group "$clients_group"  >> "$product_log" 2>&1

}


undo_install()
{
	p_echo
	p_echo

	get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
	req_pid=$common_var
	if [ $req_pid -gt 1 ]; then
		p_echo "===>Removing installed ${product_bs} components ... "
		remove_modules

		# kill mysql
		$K_KILL $req_pid >> $product_log 2>&1
		sleep 2
		mysql_pid_file=$mysql_bddir/*.pid
		kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
		sleep 2
		if [ -f "$mysql_pid_file" ]; then
			rm -f "$mysql_pid_file"
		fi
	fi

	$START_SH stop >> "$product_log" 2>&1
	sleep 2

	remove_super_server "ftp"
	remove_super_server "pop3"
	remove_super_server "pop-3"
	remove_super_server "imap4"
	remove_super_server "imap2"
	remove_super_server "imap"
	remove_super_server "smtp"
	remove_super_server "smtps"
	remove_super_server "poppassd"

	remove_product_users_groups

	if [ -f "/etc/ftpchroot" ]; then
	    sed -e "s/^@$clients_group//g" < /etc/ftpchroot > /etc/ftpchroot.tmp
	    mv -f /etc/ftpchroot.tmp /etc/ftpchroot  >> $product_log 2>&1
	fi

	if [ -f /etc/shells ]; then
	    case "$machine" in
		BSD|BSDI)
		    sed -e "s/[/]*sbin[/]*nologin//" < /etc/shells > /etc/shells.tmp
		;;
		linux|solaris)
		    sed -e "s/[/]*bin[/]*false//" < /etc/shells > /etc/shells.tmp
		;;
	    esac
	    mv -f /etc/shells.tmp /etc/shells  >> $product_log 2>&1
	fi

#	remove /tmp/.state for ASP
	remove_tmp_state

	restore_named
	restore_sendmail
#	rsr_backup $inetd_conf mv f
#	rsr_backup /etc/my.cnf mv f
#	rsr_backup /etc/named.boot mv f
	delete_startup_scripts
	delete_crontab

	rm -rf $fp_i_dir  >> $product_log 2>&1
	rsr_backup $fp_i_dir mv d
	cd /usr/local  >> $product_log 2>&1
	rm -Rf $PRODUCT_ROOT_D >> $product_log 2>&1
#	rm -Rf $product_etc
	p_echo "done"

}

smart_undo_install()
{
	[ "X$trigger_uninstall" = "X1" -o "X$do_patch" = "X1" -o "X$do_reconfigure" = "X1" ] && return
	[ "X$PLESK_INSTALLER_NOUNDO" != "X" ] && return
	# trigger_uninstall - trigger what smart_undo_install is already working now(recurrence)
	trigger_uninstall=1

	if [ "X$can_uninstall" = "X1" ]; then
		if [ "X$do_upgrade" = "X1" ]; then
			undo_upgrade
		else
			undo_install
		fi
	fi

	# put suggestions for user what to do
	call_optional_function failure_note
}
undo_upgrade()
{
	p_echo   "    The attempt to upgrade $prev_product_full"
	p_echo   "    from version $prev_version to $product_full $product_version has failed."

	if [ -f "$product_sav_tar" ]; then
	
		p_echo 

		p_echo "    Now restore contents of $product_bs from $product_sav_tar"
		p_echo 
		get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
		req_pid=$common_var
		if [ $req_pid -gt 1 ]; then
			$K_KILL $req_pid >> $product_log 2>&1 
			sleep 2
			mysql_pid_file=$mysql_bddir/*.pid
			kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
			sleep 2
			if [ -f "$mysql_pid_file" ]; then
				rm -f $mysql_pid_file
			fi
		fi

		$START_SH stop >> $product_log 2>&1
		sleep 2

		rm -Rf $PRODUCT_ROOT_D
		setup_super_server "smtp"
		setup_super_server "smtps"
		setup_super_server "ftp"
		setup_super_server "poppassd"
		

		cd /
        	tar xvf $product_sav_tar > /dev/null 2>&1
		case "$?" in
			0)
#				rm -f $product_sav_tar 		
			;;
			*)
				p_echo 
				p_echo 
				p_echo "ERROR: restoration of files from $product_sav_tar has failed."
				p_echo "       Please restore them manually."
				p_echo 
				p_echo "Exiting..."
				p_echo 
				exit 0
			;;
		esac
	fi
	
}

#vhosts

set_vhosts_params()
{
	SKEL_DIR="$HTTPD_VHOSTS_D/.skel"
#	SKEL_CERT_DIR="$SKEL_DIR/0/cert"
#	SKEL_CERT="$SKEL_CERT_DIR/httpd.pem"
	return 0
}

#webalizer

set_webalizer_params()
{
	WEBALIZER_ROOT_D="$PRODUCT_ROOT_D/webalizer"
}
set_horde_params()
{
	horde_datadir="/usr/local/psa/psa-horde"
	horde_confdir="/usr/local/psa/etc/psa-horde"
	horde_sysconfd="$horde_confdir/horde"
	horde_logdir="/usr/local/psa/var/log"
	horde_passwd_file="$product_etc/.webmail.shadow"
	horde_title="Horde Web Based mail client "

	imp_datadir="$horde_datadir/imp"
	imp_sysconfd="$horde_sysconfd/imp"

	turba_datadir="$horde_datadir/turba"
	turba_sysconfd="$horde_sysconfd/turba"

	kronolith_datadir="$horde_datadir/kronolith"
	kronolith_sysconfd="$horde_sysconfd/kronolith"

	ingo_datadir="$horde_datadir/ingo"
	ingo_sysconfd="$horde_sysconfd/ingo"

	mnemo_datadir="$horde_datadir/mnemo"
	mnemo_sysconfd="$horde_sysconfd/mnemo"
	
	passwd_datadir="$horde_datadir/passwd"
	passwd_sysconfd="$horde_sysconfd/passwd"
}

check_opsys()
{
        case "$machine" in
	    BSD)
		dist_os_major_ver=`echo "$conceived_os_version" | \
							sed -e 's/^\(.\).*/\1/'`
		real_os_major_ver=`echo "$os_version" | sed -e 's/^\(.\).*/\1/'`
		dist_os_minor_ver=`echo "$conceived_os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		real_os_minor_ver=`echo "$os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		st=${real_os_major_ver}_${real_os_minor_ver}_${dist_os_major_ver}_${dist_os_minor_ver}
		case $st in
			4_9_4_9|4_10_4_9|4_11_4_9)
				perl_req_ver="5.00503"
			;;
			4_11_4_11)
				perl_req_ver="5.008008"
			;;
			5_3_5_3|5_4_5_4|6_0_6_0|6_1_6_0|6_1_6_1)
				perl_req_ver="5.008008"
			;;
			*)
				p_echo "This installer does not support FreeBSD-$os_version."
				exit 1;
			;;
		esac

		if [ -x /usr/bin/perl ]; then
			perl_ver=`perl -e 'print $]'`
		else
			p_echo "Installation of this Plesk distribution\
			requires that Perl $perl_req_ver version be\
			installed on the server!"
			exit 1;
		fi
		if [ "$perl_req_ver" != "$perl_ver" ]; then
			p_echo "To continue installing, you should install\
			Perl $perl_req_ver (you have Perl $perl_ver\
			installed)"
			exit 1;
		fi
		return
	    ;;
	    BSDI)
	    ;;
	    linux)
	    ;;
	    solaris)
	    ;;
	esac
    p_echo "This installer does not support $machine platform."
    p_echo "Please obtain the appropriate installer for $machine system."
    exit 1
}

hf_files_processing()
{
local inten="set proper permission on hotfixed files"
echo_try $inten

while read line; do
	file=`echo $line |  awk 'NF < 5 || $5 !~ /^nocopy$/ {printf("%s ",$1)}'`
	perms=`echo $line | awk 'NF > 1 {printf("%s %s %s %s",$2,$3,$4,$1)}'`
	[ -z "$perms" ] || eval "set_ac $perms"
done
}

### Some initial parameters
	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	export PATH

	PRODNAME="psa"
	PRODVERSION="8.0.1"

	build_number="80061018.20"

	read_conf
	product_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	product_problems_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	set_local_params
	check_opsys

	test_for_root

### My name define
	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
                echo "Unable to determine current working directory."
                echo "Please fix the problem and run installation again."
                exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
                0)
                        my_name="$my_name_2"
                ;;
                1)
                        my_name="$my_name_0"/"$my_name_2"
                ;;
            *)
                        err
                ;;
	esac

	if [ -d "$PRODUCT_ROOT_D" ]; then
	    plesk_ver=`awk '{print $1}' $PRODUCT_ROOT_D/version`
	    plesk_rel=`awk '{print $4;}' $PRODUCT_ROOT_D/version`
	    plesk_release=`echo "$plesk_rel" | sed -e 's/\./0/'`
	    PRODRELEASE=`echo "$build_number" | sed -e 's/\./0/'`
	    case "$plesk_ver" in
		$PRODVERSION)
			perl -e "{exit ((\"0$plesk_release\" > \"0$PRODRELEASE\") ? 0 : 1);}"
			if [ 0$? -eq 0 ]; then
				p_echo
				p_echo "The Plesk version ($plesk_ver $plesk_rel) you have does not require this hotfix ($PRODVERSION $build_number)."
				p_echo "Thank you for choosing our products!"
				p_echo
				exit 0
			fi

			START_SH=$PRODUCT_RC_D/${PRODNAME}
			
			### unpack hotfix
			p_echo "Extracting hotfix files"
			cat "$my_name" | $uudecode | tar -x -m -C / -f -

			hf_files_processing < "${PRODUCT_ROOT_D}/tmp/hotfix-80061018.20/filelist"

            sed -e 's/^\(.*\)[ \t][0-9][0-9]*\.[0-9][0-9]*$/\1 '$build_number'/' < "$PRODUCT_ROOT_D/version" > "$PRODUCT_ROOT_D/version.tmp" \
			&& mv -f "$PRODUCT_ROOT_D/version.tmp" "$PRODUCT_ROOT_D/version"

			;;
		*)
			p_echo
			p_echo "You have Plesk version $plesk_ver. In order for this script to work properly,"
			p_echo "please ensure that the version of the Plesk that you're attempting to hotfix"
			p_echo "is $PRODVERSION"
			p_echo "Thank you for choosing our products!"
			p_echo
			exit 0
			;;
	    esac
	else
		p_echo "ERROR: PSA directory '${PRODUCT_ROOT_D}' not found! Install PSA first."
		exit 1
	fi    

	p_echo "Done."
	p_echo
exit 0

begin 644 plesk_patch.tar
M+B\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#4V`#`Q,#`T-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$P-C4U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+P``````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U
M-@`P,3$W-#<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#<P`#`Q,C4R-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$S-C(R`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O````````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`U-@`P,34Q,#8`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R\`````````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`Q-C(S-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M861M:6XO:'1D;V-S+W-K:6YS+V%Q=6$N8V]M<&%C="\`````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(P
M-C$Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O87%U82YC;VUP
M86-T+V-S<R\`````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`U-@`P,C$T,#$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]A<75A+F-O;7!A8W0O8W-S+VEE+F-S<P``````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,38S`#$P-3$U-#,Q,#4V`#`R,C4P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*B`M+2TM+2TM
M+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E
M82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O
M<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS
M07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M
M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@
M,#L-"GT-"@T*+RH@+2TM+2TM+2TM+2!S;6%L;"!I8V]N(&)U='1O;G,@("TM
M+2TM+2TM+2`J+PT*+FQI<W1!<F5A("YB=71T;VYS("YC;VUM;VY"=71T;VX@
M8G5T=&]N+"![#0H@('1E>'0M:6YD96YT.B`R-7!X.PT*?0T*(V1A<VAB;V%R
M9"`N9$)O>"`N8G5T=&]N<R`N8V]M;6]N0G5T=&]N+`T*+F-O;G1R;VQ6:7-I
M8FEL:71Y5&]O;&)A<B`N;6ES8R`N8V]M;6]N0G5T=&]N+`T*+FQI<W1!<F5A
M("YB=71T;VYS("YC;VUM;VY"=71T;VXL#0HN<F5P;W)T5&]O;',@+F-O;6UO
M;D)U='1O;BP-"BYU<&QE=F5L("YC;VUM;VY"=71T;VX@>PT*("!B86-K9W)O
M=6YD+7!O<VET:6]N.B`P(#9P>#L-"GT-"BYU<&QE=F5L("YC;VUM;VY"=71T
M;VX@>PT*("!M87)G:6XM;&5F=#H@-7!X.PT*?0T*#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN
M+VAT9&]C<R]S:VEN<R]P;&5S:RYS96$O````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,#$R,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+G-E82]C<W,O
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-38`,#(P-S$R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI
M;G,O<&QE<VLN<V5A+V-S<R]I92YC<W,`````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#8P,P`Q,#4Q-30S,3`U-@`P,C(P,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RH@+2TM+2TM+2TM+2!B
M:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E
M82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@
M+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K
M.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]
M#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A<VAB;V%R9"`C<V-R965N5&%B
M<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"B-D87-H
M8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB;W1T;VTZ
M(#%P>#L-"GT-"@T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+V%Q=6$O````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-38`,#$W,38T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O
M8W,O<VMI;G,O87%U82]C<W,O````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,3<W-30`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A+V-S<R]I92YC<W,`````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,38U`#$P-3$U-#,Q
M,#4V`#`R,3`V,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM
M+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA
M>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U
M='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*
M("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![
M#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@+2TM+2TM+2TM+2!S;6%L
M;"!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+FQI<W1!<F5A("YB=71T
M;VYS("YC;VUM;VY"=71T;VX@8G5T=&]N+"![#0H@('1E>'0M:6YD96YT.B`R
M-7!X.PT*?0T*(V1A<VAB;V%R9"`N9$)O>"`N8G5T=&]N<R`N8V]M;6]N0G5T
M=&]N+`T*+F-O;G1R;VQ6:7-I8FEL:71Y5&]O;&)A<B`N;6ES8R`N8V]M;6]N
M0G5T=&]N+`T*+FQI<W1!<F5A("YB=71T;VYS("YC;VUM;VY"=71T;VXL#0HN
M<F5P;W)T5&]O;',@+F-O;6UO;D)U='1O;BP-"BYU<&QE=F5L("YC;VUM;VY"
M=71T;VX@>PT*("!B86-K9W)O=6YD+7!O<VET:6]N.B`P(#9P>#L-"GT-"BYU
M<&QE=F5L("YC;VUM;VY"=71T;VX@>PT*("!M87)G:6XM;&5F=#H@-7!X.PT*
M?0T*#0H-"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYS:6QV97(O
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#4V`#`R,#8U-@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K
M:6YS+W!L97-K+G-I;'9E<B]C<W,O````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(Q-#0V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN<VEL=F5R+V-S<R]I92YC<W,`
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4P-P`Q,#4Q-30S,3`U-@`P
M,C(U-30`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@
M*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN
M;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@
M<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES
M<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W
M;W)D+7-P86-I;F<Z(#`[#0I]#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A
M<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN
M92UB;&]C:SL-"GT-"@T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D
M;V-S+W-K:6YS+VQO;F=H;W)N+F%E<F\O````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(Q,#$P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN865R;R]C<W,O
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`U-@`P,C$V,#``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L
M;VYG:&]R;BYA97)O+V-S<R]I92YC<W,`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,S8T`#$P-3$U-#,Q,#4V`#`R,C<P-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````O*B`M+2TM+2TM+2TM(&)I9R!I
M8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N
M0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT
M;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M
M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]
M#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN=FEO;&5T
M+P``````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,3`U-@`P,C`V-30`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S
M:VEN<R]P;&5S:RYV:6]L970O8W-S+P``````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,30T-``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+G9I;VQE="]C<W,O:64N8W-S
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,#<`,3`U,34T,S$P-38`
M,#(R-34R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM
M("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I
M;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N
M('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I
M<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@
M=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D
M87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI
M;F4M8FQO8VL[#0I]#0H-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT
M9&]C<R]S:VEN<R]L;VYG:&]R;BYB;&%C:R\`````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,3$S-@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+VQO;F=H;W)N+F)L86-K+V-S
M<R\`````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-38`,#(Q-S(V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O
M;&]N9VAO<FXN8FQA8VLO8W-S+VEE+F-S<P``````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#,V-``Q,#4Q-30S,3`U-@`P,C,P,S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RH@+2TM+2TM+2TM+2!B:6<@
M:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO
M;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*
M?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+F)L=64O
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-38`,#(P,S,P`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O
M<VMI;G,O=VEN>'`N8FQU92]C<W,O````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,C$Q,C``(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YB;'5E+V-S<R]I92YC<W,`
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S$S`#$P-3$U-#,Q,#4V
M`#`R,C(R-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM
M+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@
M:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U='1O
M;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*("!D
M:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![#0H@
M('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@9&5S:W1O<"!T86)S("HO#0HC
M9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&$@>PT*9&ES<&QA>3H@:6YL
M:6YE+6)L;V-K.PT*?0T*(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!L
M:2![#0IF;&]A=#H@;&5F=#L-"G9E<G1I8V%L+6%L:6=N.B!T;W`[#0I]#0HC
M9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S('5L('L-"G!A9&1I;F<M8F]T
M=&]M.B`Q<'@[#0I]#0H`````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H
M=&1O8W,O<VMI;G,O;&]N9VAO<FXN>65L;&]W+P``````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,C$S-S4`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG:&]R;BYY96QL;W<O
M8W-S+P``````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#4V`#`R,C$V-0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS
M+VQO;F=H;W)N+GEE;&QO=R]C<W,O:64N8W-S````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`S-C0`,3`U,34T,S$P-38`,#(S,C<T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J("TM+2TM+2TM+2T@8FEG
M(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM
M;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@
M+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-
M"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*
M#0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YN97<N
M8V]M<&%C="\`````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#4V`#`R,38Q-P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S
M+W-K:6YS+W=I;GAP+FYE=RYC;VUP86-T+V-S<R\`````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(R-#`W`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;F5W+F-O;7!A8W0O8W-S
M+VEE+F-S<P`````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<Q,P`Q,#4Q-30S,3`U
M-@`P,C,U,30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM
M+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ
M(&EN;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T
M;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@
M9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*
M("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*
M(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN
M;&EN92UB;&]C:SL-"GT-"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@
M;&D@>PT*9FQO870Z(&QE9G0[#0IV97)T:6-A;"UA;&EG;CH@=&]P.PT*?0T*
M(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!U;"![#0IP861D:6YG+6)O
M='1O;3H@,7!X.PT*?0T*````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO
M:'1D;V-S+W-K:6YS+W!L97-K."YN97<O````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(P,C,S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLX+FYE=R]C<W,O
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`U-@`P,C$P,C,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:S@N;F5W+V-S<R]I92YC<W,`````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-3`W`#$P-3$U-#,Q,#4V`#`R,C$S,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*B`M+2TM+2TM+2TM(&)I
M9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M
M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A
M("YT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS07)E82`N
M8V]M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[
M#0I]#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-
M"@T*+RH@9&5S:W1O<"!T86)S("HO#0HC9&%S:&)O87)D("-S8W)E96Y486)S
M("-T86)S(&$@>PT*9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*#0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;F5W
M+P``````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`U-@`P,C`Q-S(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]W:6YX<"YN97<O8W-S+P``````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,#<V,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+FYE=R]C<W,O:64N8W-S
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W,3,`,3`U,34T,S$P
M-38`,#(R,#8W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM
M+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y
M.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T
M=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@
M(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-
M"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I
M;FQI;F4M8FQO8VL[#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S
M(&QI('L-"F9L;V%T.B!L969T.PT*=F5R=&EC86PM86QI9VXZ('1O<#L-"GT-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB
M;W1T;VTZ(#%P>#L-"GT-"@``````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN
M+VAT9&]C<R]S:VEN<R]P;&5S:RYB;'5E+P``````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,#,P,0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+F)L=64O8W-S
M+P``````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-38`,#(Q,#<Q`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI
M;G,O<&QE<VLN8FQU92]C<W,O:64N8W-S````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#8P,P`Q,#4Q-30S,3`U-@`P,C(Q-S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RH@+2TM+2TM+2TM+2!B
M:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E
M82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@
M+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K
M.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]
M#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A<VAB;V%R9"`C<V-R965N5&%B
M<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"B-D87-H
M8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB;W1T;VTZ
M(#%P>#L-"GT-"@T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+F]L
M:79E9W)E96XO````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-38`,#(Q-30P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O
M8W,O<VMI;G,O=VEN>'`N;VQI=F5G<F5E;B]C<W,O````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,C(S,S``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YO;&EV96=R965N+V-S
M<R]I92YC<W,`````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C`U`#$P-3$U-#,Q
M,#4V`#`R,S0S-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM
M+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA
M>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U
M='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*
M("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![
M#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@9&5S:W1O<"!T86)S("HO
M#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&$@>PT*9FQO870Z(&QE
M9G0[#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&QI('L-"F9L
M;V%T.B!L969T.PT*=F5R=&EC86PM86QI9VXZ('1O<#L-"GT-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI
M;B]H=&1O8W,O<VMI;G,O<&QE<VLN8VQA<W-I8RYS:6QV97(O````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,C(R-S8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYC;&%S<VEC
M+G-I;'9E<B]C<W,O````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#4V`#`R,S`V-@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K
M:6YS+W!L97-K+F-L87-S:6,N<VEL=F5R+V-S<R]I92YC<W,`````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(T,38P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N<VEL=F5R+P``````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P
M,C`W,#4`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YS
M:6QV97(O8W-S+P``````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#4V`#`R,30W-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D
M;V-S+W-K:6YS+W=I;GAP+G-I;'9E<B]C<W,O:64N8W-S````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`V,#4`,3`U,34T,S$P-38`,#(R-C`R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J("TM+2TM
M+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!
M<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN
M9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O
M;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN
M92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG
M.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C
M<F5E;E1A8G,@(W1A8G,@82![#0IF;&]A=#H@;&5F=#L-"GT-"B-D87-H8F]A
M<F0@(W-C<F5E;E1A8G,@(W1A8G,@;&D@>PT*9FQO870Z(&QE9G0[#0IV97)T
M:6-A;"UA;&EG;CH@=&]P.PT*?0T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P
M;&5S:RYN871U<F4O````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,#8U,``@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M
M:6XO:'1D;V-S+W-K:6YS+W!L97-K+FYA='5R92]C<W,O````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(Q-#0P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN;F%T=7)E
M+V-S<R]I92YC<W,`````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V-``Q
M,#4Q-30S,3`U-@`P,C(U-#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS
M("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@
M(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S
M<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U
M='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O861M:6XO:'1D;V-S+V9I;&5M86YA9V5R+P``````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`
M,#$W,S8P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O9FEL96UA;F%G97(O
M9FEL96UA;F%G97(N<&AP````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T
M-S8T-P`Q,#4Q-30S,3`U-@`P,C(S-C(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*("`@(&1I92@B5&AE(&9I;&4@
M9FEL96UA;F%G97(N<&AP(&ES('!A<G0@;V8@4&QE<VL@9&ES=')I8G5T:6]N
M+B!)="!C86YN;W0@8F4@<G5N(&]U='-I9&4@;V8@4&QE<VL@96YV:7)O;FUE
M;G0N7&XB*3L*("`@(%]?<&QE<VM?;&]A9&5R7W!R86=M85]?*"=")RD["C\^
M"GM0O9X^"?S]H2S"_+_(`)&_O>![^:<M2"MDT4:DN&[-'%[U<97O:2RE^;V;
MH7>>C>@*M57`F!\L7?/8\;\J23<WR!DZQ"OH%M=/*-N[$Z<A7S-+U3!$:)>N
MY>+4V4?`^'MISBHHZT)W@GX/,?Z2ACNWE+Y;*&SG<X^4GO7,V1OT39%SPOP8
MHW4AM-JA`'EV\(JZAZ<0J6(CX4\<3N9%7U>54R6P=TC28W!L*BAJ<SA!Q^ZX
M3R-(,F2'K/!$+\<I]A6H^GZLU7,U]:8B+K&M`001&5=9K#A^#&;,<&\UEF,`
MM@;I9IDT7_B0A.1*W^WX8+D.O*BF88S#^TIX.1T::%&S./6^116@?N.9TGEX
MB1F73JJG"WSW_X<`3@-CP2T1:"1U;)4:]74);P>[/_=T169#KUD<DI*WATVN
M`)KK3!R-)%&&]GFG,]?#=?V<H58-J74T05:V(L,20"I+3[MN5F75HNJX#0OI
M[\9Z35-G^)VUA=\)UB&4B&NF,MIB1([(98\PJB--XTE;I-(][HTMB#"HIQ3`
M(6UC"X_;U0"ZP98YM8X$Z-H8]<LY0,BD/:@_/,+&?)U3Z'*V4R1$QTX1*2M*
M',-C10F$($F:L-HCY,=%6E?N;"?91.(HX9G)G$/-5A'ZJ^M;[%F*2<1X0$L#
M9QG1H=CE9)LA7E<.S<JEUIME=P$;'XZ)Y"I*)55`>DV0'P[^_%,T;+TGS&)J
MPK:RNJH5[Y$S;+LV8B"KF[I2>$N"SZ0*O*<^`-O]FZX++N*HHA,JVZHG)G_P
MF^!4EQSQEI*-7]J.3)9,CC]'*D![T7@;EYU?=@Q=BZ*?(N+GTU\FHO&L&*/,
M[$\&K3,Q`A+E1I?,W-P!/1F5EXFF5,45D<@-`5#5W?8?HG#RPX9P2^YO^^]P
M7,4:'Y\8GP2L'PM[I2I.P&K+L$@`7%MU$3J[GBEYZWAXA'\%VC;B9_$3R)7!
MK`?A,*2<3G3M]+6V[U()Z6_/NF-4C-R%Y>@&%[E.Y1Z-FM>AMF<JE#^TH/.Q
M=?IQGT+!$ZH;3MDHE<[E/.F43=]2!LGIE=?>1G^JZM:\PU`\&@FW+="#,<<E
M$PSTEHGS!L(4JP()UX2$4.]:R'\#X`;D.M!:%N^'UWHMMA@&R96BL(<`^2E?
M\/#1@';?_)>%61OOFFDJR,2>%XV;Y%MH$((H%C0^DY#4CK5&C\/#<T&V,[J-
M6;7BH8GLT<P>6X=MI9;VIB&=\Y@ER(,43:4T^WAI=D$&;$3MB+)+V2Y!),I>
M?;S2P`5@=)N!50PSK&%#`;YFK%H._XW"]8O<UY&/B=RPCZ'L+4\*"Z&3M\(>
M[:SH_TK&&+;%NU36B1:Q%V)R-6D(),CG]#B;6((\[!]@"-5[QY*=$+I?J,?W
M4FT(-R<54[V;4I-0M8>!!;VZO8K,[QO?M/KM,B`,A3,8B1^P&?7DN5U*!%F@
M^J(6ZT'B,M?B.HW]GU-2Q9(0?F\C&.&>K7M*08UCVS-7IF(3$;R[()NR\FP4
M:!3$E0`MZI^Z94:'7"','M')F0%Y\UPRKL)9M?5,9L3;[/!D_A8.4B,8G1,;
MI/")Q!88[9FT1KP1O0KQ5U*;-ZW.B;\U5III150.O)Z6/4(":00%?-F:*<1E
M!TTBPAIE&[M7K]89^%+V]Y"\R)1"%5PM:.0`AYS`S[!YNO)+2%=`OX`MB=_A
MYY00X%MT0YTBR5H[5NI@%K?/R3&2"B+]2"-V_$C5Q">RY]F8JUP53,$J-]0*
M4Z19H]V5.PMLMXMZIR)LJ2:IWB+TRPM#UJR3HG4@K1FA$VLS77Z9R.,@M>4U
M7^`J%\E^T?_M976B/*;K:">Y%\C<4=O!\[KIE[VVOO;EW(-2_R-Z)SF.$C7`
M0DIAL8#<_=4ROBAF(:V&6E1E%"5*?L!=W:[2?X:_=AB\&`)[DO!O*-?'Y5DX
M=(ORJM9GM,JKV83`KC:N+RO9JD),3.4?$&G\1C"HOG]:&_.VHZW*DWLD&4FA
MH&!BPW7>\^4/9Z4X7O-C>\48CNA!IJ2+*\U065,@76GV^L?9KGFR_(<!;*?"
M)Z*[F/OB&KKL+_-_\,DWRK/NO!(2DJZG_Q=TQ?31F2?VP<4#S&O./$Z2.[-X
M7=;;]52W#Y-Z,T;=%,7+-Q!ZPD=">T54C$#F0T)D(#@*ULX.&-]XAGYHB)->
MS]E(VJ%4_<)8C):/H=<J/::V<>@'J4^YF$J9!(14)D5;0?RFJ?CN"\Q4Q6U#
M,868E4I1M)6?MVI03"+6YZ$+/;W3W^LA]+-J`>PPS@;PQ?6RAEM%/TC[)B;*
M[U2BBJ^[*:988UI,57_MUKZ!&]/VXD:9-V26<I_)Q87[H3#!PJK!2V8:_)I(
MM]9G9H73$/<@9ZR5;,9+:K#SY5TP9H6JP(J]VW++;XWE8W8L(D1BHS+_7@#W
M</BTIP7&'FKXZV7B4$T\QD>224$,%6;]%$GM['MS_=6-<2@5S0,IRMSDA-%5
M\9:RSJ=1Z[P<70LN9M<G,3>K/SF<)E/X;#MMJZ]'%V="'-^B=T<UH)5SW%HN
M$7%0"N[Q,`/83TS:$U9M&+K8#3R`O5V(J!5F>C5<XM@;?Z5'VRU]L@RY0S[^
M]'$>3)=7<5J>A[H1@Z\_[(AOW25%0#XX9>BHE?1=2B9385P]!:]!S.NP%7-C
MF?HQ2]Q<*^F`5H12^EX?+@$&=N;,!15[-"S*F!J+5&:EA0%CD;7#5ZH90WM[
M@U$GR?.$=N75`APA@51?!%VB]+5P_S6("9:/\_63%#<)^@471Q;'>T`H7?+,
M;MKSC*:=4`X(T@J$%W3)1L%7OJW,RFM3KR8TW#J&_-P8*V`!32)#4.Z&5,(D
MC`GG6.I$:+1B=Y@3:P0WIIE:PFC;O*9#A_9:K(,(</WX^0I_S-32;WE,R+C`
M9K#E`/KU\%Q2')'4[RIDF6.?H2S45\]5[:S>3EEGP,6YD=\??!\7A*JV&*80
M^ZV)J7U.-O:O/ZKR\5D-4[6\=5OVM&[\,_GA6"CM7]6C8_H1[UO9S_SQ*RH=
M+/1JGM*NOD`=!?U@7?84J`#5W9X?\7FFP\E<%%65<IH*-5SDO;@Q#Z9NBPC.
M<2U:#`S(.2X2(%7PO/IJ1?8&U4YZ_W+!&6+5GW*%=#Z2,G('<[(4MW9X*]SL
M'0D9'X>=2^FQ7U9#%-MJ5N5%QS3IQ3`O5BMP<9IA'<P[M/=-15I6.=,A(D37
M^-J2E1!M#38,6$AN%3'@XE"X#%EF/&>X2',I<C$!,=\9(O3H>K5,@T!K7I)8
M4U!'8`%'Y!3@%OX&]>])A0BRDWU^&A6-8NG).%@`/A9+07Z`$$-]K![*:RK&
M:QYI^9`HEZ$<H5YX)%%T_B+HB$WT)N,20>7K[5ECO!TRJ&2UP_YAJ`I`Y4S(
M:[C]9&HC7'`LHI>$U_8]^K_M$+PAG*HW9KVQF:XV9W4WO>!4V;LB$KWIR6-J
M02'$ZJ'C9#-+GZ':$+V*5Z>\ZO,#$G.-=OCJ:)8$`$I%J20;FE[_AQ%5,Y.R
M0\VA-LH?^:-_,2D'Z16&;KS!"_%[[>6(`CV#7*+]^7GX&E-G(AS,`>AW=1LH
M,U920(S16"=K<C2D!T'ZF?F-@L@@][SP3$Z<:N1@6F#-FE[/2*;/J:)Q_^W:
MH=81')K]-J&+GO_!"^WL&&)9O/K]LMU]9C6OK8MARTA&"U:5SP8.)SO`'2C_
M^4AVB7,9F4*TS,G+\YJV4*VD\JA4.A0'!A$!40`O#RE;99[\'WYN$9%3L\X:
MR'^R39J;]V4:I6BS];%9PZ`")\6;3V.U-6Y)MJ^]<69AMR^=B<GY"CI<J+Q_
M##/TYT?JXXKGN!AFD<'E_MK,XI6X(=^S7P*WP;3NE`=<2)7Z@$'K,^UKQUPE
M@@&KI<,S]K,:]-MY8/9=?X=F4"37FB(M\F+`I86=6AQR1``"?&0*3Y[AS1A0
M]5]FX$6N0\:D%5N1WLN`;VGB`0%WFBM^;;8#$U\KKMFJ[-:=G9G9W%J.!`"]
M1TXD.&,KT-@"?.GN%#/K6E#Y=9H30R5N/;*;Q+=NWL]<V\3L7'\:APKVUP&7
M@A9\KP_@XGOJ!VC<GU#`-C%DEVXAW&T_7PA/1>747A;E(+SLT&A(;E,/K!%(
MZ8,:*][X)4)DP/C&9I>AG<6@^+@4#*LHG-W9C`0UK'7R6E`HL3X1=716\UB(
M?".=^X1@N?Z83CE',[W^<3LV/_^QO^2"G+O0:E='\@8*'+/Q$=Q[&)C>K'UV
M5;>$=PA1'H9*"RL&@F;4\1]XC^V5+O='F2LRV^?/GXODT&@8?&E/8YI@53\/
M6/.G[OT0F5O@!:;1FK%C4DED</<[O*C:.WJ=T=TC5DN@VW;&:N/T6)`B#6]?
M54U(7"-X+YUJ^,!7'-0@9A-F[+(S$-&ZKRK1J4^K=@2OE`G;1R04J*L_4&O+
M(\X@"^"*5L417UNSE_1,DQBCW$!=[QUMK:;]*.`M5PSBTMFJ[L[=VK2F9:3.
MO$87J"2AJ9%A/I04T^DK8+[BV\;SR.C$NT>63Y:,4$?VP%M`Q:2;2F4;S3P%
M<,1?A^LDS+76XS!0YUHS+KPLILR%'O7GEKG0K=EH3Z+U0P,<I][LR#]8:4OJ
MJU8T<U=M?\@:)@1?2(`OZ)(8T#3F$]2:PC^]XNNX+G[+:JX6]NR`A.89,3"4
ML8H%T[9<<L,8&">3GC/"[0HAE"X6Q?DXSK5#TYQF$'*OEGP61[]@$K\8$60@
M427-I((ZN]YCCU"PA(X0=.#2JX^"/'NLA_''=9LUC)80)X6;5*GN<U>UO!'9
M$-O*>F"0KMO0-]\A_R'K@##W".FF/E@?30!=P27$4%I%G\7&Y]#R(4%=JKC3
M1EN+B$<]/[-['(R^PFM@J@=>BJ"4C>+:H[I2;.?KVI7/,!`MY7:1`EV[4/LZ
MQ2E$T/T;K`'#%)EX#^>=-7W=9/UJ-L=0MR76['P8--E:4S;<%`YC!E4@[G!`
M6QM$\K.9!#GQCE59E4Q%QE'3#S_EWU&MM$S_EIZ8%KJC[[[[ZO<3&&_G]AF"
M736U*WI9]VY")VFW,>Q%GNJ%Z*FH.4Q68TYO2&,-G%+"JTOY9WRM")I*+A-?
M&+PE2DF"M\2^Q%@>"W'4"9KN!>SORID=`89XF47<HU!.?H@`-XV,;&LPQ'JT
MI!<9GD#'LO#L<,PFR.5DBO,[V\39\LFIYDJ^RC78_I1^JBRDDTY/F>Q`AB.N
MM`HAM_#/JDN99`P>'CQ1T4(7A?9"H:ESKF!C2-\2J[7;8;OI($25,R;(2\T.
M4'230XHEETJK,]B#$R2BE+\K2I2ML%U;:SN!#35Q!O\\<1M-^C^_`93'I7A*
M&[(MG31E`9%_N)`973>5F"E`-A=-329#[ZZ9^=F0:\:##%LMA8K@6"#XGN]1
M-^Z)6A!.J/@J)Q]MH;07(89PIE5]OFZ:1J4P?I(P!,,[_L=2[$\-I3I_HO.R
MX943SQ9]D!^<7WIK;BAJUH')$=A%,#97]6BHHM@B$]!B?A,BSJ3&"/=SC.HE
MILP!S.%K8P441$(3HU74-\875A\NQ22=?]'2*`389:!":RYL/;])EW;0OTP*
M1K.,9;K2$&3K@:C+TC=K;X*B/.58GH[!K:2&"5$\^T9,RN)2AYO4HQ!LR>8*
M*YTX@K6@4()D##Q,TZ!^RO0WU-'`DY&*5*^AG6+`WN?J[-9_ZZMR1H?`WHTD
MI\&PCZGQ_F8D("=*SR+:^:1>L03:>H\R%)8A7%+0=2T0_S0.GA"I$T=4WZ%H
MGJO)YL#8!-:2'MV,CQ,*+%$W3"2WNSQY!5IX^=UXX?&(5JE2X[A"1715>#.D
M[RIYQ"J0;4G5"C;;K&R$[Y9/ZI!D-BU]^<%WM.04%W(B<C$88,L<L&86-1"Z
MX@B5G\FB"?8RWR>.F6"7Y*4JG/!]]7VV/W:":)+Q1G;G)"F7B]_((U`+_,=.
M9$DO5\\.$S:*(+"`%4=`)#PMN@9CTYUX4U#"*D3-&,$AQCH-4\9&-+8MB&E4
M1<WV!?#'D^@%^.:N*[6:E!1I](?F=A1S[0"*HE[;W(XSBRPW,KH.%^8;%Z?9
M^D(!-31)'>44/>Y0X[AXT6ST+IF:P46E!0!3]IWSZ^]C;PV4(9]&F[T9-Q#>
M20,;QHMT01J.L@-(HL`:]L@5?^'%]%2_E[8H^V%UY++(@GPZ`/"/*[/0[C.Z
MY:5Y_7M)8!<2[=&OL\)F^)D3Z7\XR_`_5"_PI/`,U7-+>A6`/$IXG&S0[4];
MPWG"5UT%D_P[TIBYESV.(K6%RG&YB?:N\S^6>_Y4;Z^BZ0E,"4>4<@\9?BDG
M/GJDNL*)WUS7@UF-(-2,OG!G+2*9\+464S%G;73\.FU\N>)P!AXBF6G>M6'T
M+"^W_%5"$(E/?Q&]`I>U4KP*C$WA:ZAEHDHM-@^:C9TBW38Y9JB8)4T<%"4Z
MH)YWV1^/K65]7H00\<XPI,WX(OD=MSX]5DAU05QWU-.N.RG!MY&%KXRI2'9\
M7?K<`8*2FYRO:,:BNC3/[=<F\/ZFAZ1)ZAV)Z&AZXT=(&?\MWF;XC8@LY)E4
M^6;&IR!-R^"&_&?S0^*%C]<[#N95@3W73@CEJ\I6->=O>_GHMTM@AB6H58)$
MC,93_Y61?V,JIIH*-JX&I"X/`J51KYTF<[&-S*0D4?X;A3A%48YE]Q8?23!M
M2+%H9-8KDGW"6Y,!#`LB7)-W:KO7=-H_-"8T0Z]VA@'AL<&ZE\MQ(BMM*,:_
M-$>L)M>(A>B4IP0A)N?1](J/P8?'1H'X;2DUO9K4_(V7]8(2.&"_<6ZB`&D$
MV+ID@T:IA83/E9V^B428?I,M>XVIU9M/B9:82]^$+@(%S0%)-P%Y#$]3PN)'
M,Y#,2%!H.)"RG2$S(0)M-W:U'FH^&3#H<H$/(PK!.MX:CZKT*B15ZLTYY&T3
M(#/WE=/PU7#LV8T+B_+^I(#__KPA&8%!1JTB,,@@YI=`[>UK#."ESL^6I`WL
MZK!P;"-7L6G3H04ZM`JAIYUUUTQ-\9T?KWR?S/K9K*[+\,LE+4['Q(L9X$4D
MUZT>7$%@HXDZ#05N[EU57`'FXHX,^+U8./=A:V"^YY$$YGT[Y"H7\T^:\N[_
M/Z=W`X,\G<B.D!#NJE#!+(`-A$V%;$FGCEWUJE*0X1<_^*':'.V&@3"M-T92
M,]%\Y9HU)*4'Q&<6H[>DI'U_T\MQ@,KZS]DJ!M>IJL_-:6](.%]BC'S2PLZ8
MBDAO/J!WBAC0HC,#1;K*>KQ5V[^N0OTW]A#*3\@<G\[(`5-_3]73_%*)(^Q8
M&(%KQS7`'D864O;B9$.'?*Z'C"_`Y+'HU99=J@IG1IR(`A/17)\<V9O<[YV.
MPK@*KT81S*LN7BJBR,$)SV`[ROK@Y5[-T/AO2J1GGA&WG%7.N$(>R/;F;*U^
M8"K?I'Y2+AS$SQ,[K0M`@S,ZUJ7_TR\OXZF1L<V%R<*IG8KTR/88*1M':AFM
M0296BH58[_<=T!D^X]50M#D`BZ`Y9T-R3>C+3765O-8WW$4[04\G#+S]3+WK
M+WGT5+XDV1!'RV+WS9/";TJ="%FMO][.F5K(@*_^)S9MWP?JX$3*;_ND*6AN
M1TQ144AMW/]O?@56\?4^CO'W:*C50]=P<A"5%O-!;I#08>-R+?^)X^X:],NM
M`L`;Q[51U@_J?_Z@.Q#7RO/G_"1UH0WO-/:?_%ID4#_\5]P#Y_?SP7W2T1@3
MDWE:I7V_C0BE$G4>D#@0@YD0TJ!JS:W=R177EUQHW$^AG-.6PPAQ=`B1"T+C
M>#!CPBQ3,@VW&3J@:0C4#GTAJ1CR;HX%_[>&8110BFE49?C:%2];-A5N9:R%
MI@3*@HE%AX'BW6.CEC?VFSA1GE;*-]930(^7C3.L@1XFAQ%D>;F4+A9*K#"P
MF(E1B+I`5]G:%H%:)3%#V=;?393>06-,7)*NB`-A<_^OQ6B.CX29_P&ERQ-?
M:)3GPA/-J2]Q05O,QF?*Y%/6SY#X`G2)P"$PWP;+RW;.UVUA)!E=U$>^2EG%
M6SYQ;7V?6_`X@BQ(7%:T]4<%W.^<<-'J+,T4>#!7(5_B0=*0M+=V#?O1J79B
MY)>.RJZ6!V6`WC8Q>28TW^D#LECN':=S1*!/,%']RU#6;)\&YX8R&Y,RE")W
M2?:O>O,'6W_I6W=Y,VT7[>2]<-E@KFT.`JQE3M.O2/QS$A8U)/19>.;.LU'!
M+DV1R9;OE+(.%E[%"7R!V)R"%3T%8[,11.NC!^=0NFIY-YU[?@5?)NS/YM_I
MM'*B<%$',%'A9JF$GJN]-[A8*,T!FL-&^UM>Y.Y#>D`IY&V=`35O7F'?/+2=
MZ;%DWMGXYN%35\R4T2)2[;GS;7#,`&4%<T8#AJG#6G;`LVY96R(?M_2[2&F!
M]XRF)3GS:;37A^O+QR.*230,?!X[!UYB`'DL.W'2N*T7AIA@EM;VI7V<OPK?
M?&#N]<W.(IE?CM19*&/RF8B?`"6!.A;O_Z?5"P`46M.I@0F%YR))$70(E?;)
M#V9;*A;J6RAX:[]Q/XAK9S$W2J.-\-P9'J/9E[Y?H#EGW57]%&KBV1T;TK9?
MPA;T:M<B@<Q;*V)T*8OKL$R=8S8W:!X:".VB[E;`E.I`(F41'=/K6;*-0Q0,
M%JRO!3&35=*4(&W7:Q62S!!]-\&Y#DG/P1BT;(7UP"4A)M/!\Y>$YX)%P<?B
M&G?-EL-UELA_#OT8\<3][Z9UDN>[_I`DTY)4'R4?!!]/T00!27A,IO#),H?_
MG#)5K*?!!E1->JLE5-(S]8.QG_;(2KG07V&25'<K,(3TO<IRN&'@5H7CI4HE
M3T\61&'Q;+\L$(6H.OGGGU+QO*0F=%H719="=Z%*]S<Q646<.ON3K-6,>%JW
M_2%Q7,<;!\%,;(FQ#&9/+,4`:GQ9:94S02!9()RO.9.4[G2I(1X=#D:1@4SJ
MQ/J/4-L@L8(WXMT6\PH9?_P-#;W;=JF6$U1AH?2V\@&*8FD:1C%YD;#I'!SB
MIR9KL>T?'[D<^PVS=L5M+W0JJA)X;0;,+AE?\[C6/(;16K;HWVW4HV#.CD/6
MGA1DTVH*Y"_=)';)_-DDG@JW;*T08`!9?)W_NC%<:!3>X5J1\Q>17F#\'T>+
M%H*E"!@Y;X'>8=01P=C<+"\\IKL/_*[8J,DAWBT"[S\+B$DHRDR/0'Y>TWO.
MNW7H+M7$A/XP62*MD5_>G]"U1)'@QI!^DC)FL!&'.Q!G^\]5'#7@,R`.I3V6
M$FV_EK<(@B7:H%NJ#5P[THD<2)FT?4606[:*?^!_K%P'_7$='U]BY_^07VWA
M2,,6V)<G_X#Q0&M1Z8>KX:<S!/!1&=_#,.>E<'7MALC3B1EN16NJ#2@25,=)
M7PN_VN_J`4J!SFA4,C"U"\4R=C^:YV(*/+A8-O<O<=("QG!\G;H195VZCAHX
M3E.<<@O>7[PD(Q;A]5Z^Z$:TCF)D\(F,4C'U$%=#7$9,MFKHF`8J-U?!)2GY
M)?!:\#")KU:4:^OL^&\^AJ##F1;$J3M'<#YL,<^!^RS97^@4!80W=MHF+T0I
MOB#_?B9JC3QR\).SY8%>UR,^H->U4W1<-O+AA!#K$G8@#9PW!2^I,JMB+H\V
MS"0Q_<$:J38_7]@&&X3,2IZ).\U'*8Z#CWN\7CANR`>-_K2>@%:;8$G2^PB&
M?JE>(J+"#"E5M%\4B:-!ZDHZX\ZO&OWDT`=K04U_#V9C3`8D8LC+`:@'[:;E
MD'GE@HUE*-=4TER?MNW7-_O/XR8B%J%IDU]+M;F)%DU21E\WX11Q`P(=Q.Q;
M%(Z4("]2Y*W6`O;K=F_+7+BL)R.I/RGSM\]8^I^H';).,LZK-^K#,FIQ[K.=
M7&$_1J)J/]>CP^[7G8?AUS!_EFL%U-)\*@&V/>\\T!D1G(_D`J)`CZR=KJH8
M_ZW;A&>$,'P5I.Z4`TD2SZX.M9::E+)%HP`!YETVB1X&",GV;P*G!0!XN*OZ
M?G#":L&/[C0TD<MLTN2^7-B5C1Y0!F\"-2_<5._Z"^`*<IQS5-?9U=1U(I=J
MY3F6R]&-2DBJ#H<U87Z&__[OR[WP---,^"G7_C!B9[>(TLM.8>[G$?-/<D[Y
M-M-E3<]:+\V*WD^].RK6V:>Q/SP&$-.AVO!JV[\-3B@L7<S@SRV_E_%5W<4P
M+XO-$Y`1-DM6Z]9V*^S%4^]63F?P4_V4[3XZ)C^(>8PA[*J/'V0M$3G>ES@%
MN?/[FPK9>ZBC:"45%._TM9MN2`ZB)4-N[T;W`[#(FXV@KL^'9:7G5ZB$5N)6
MQ%G:9603F;_?M!ULJI,L,H?%4Y\NO1:)KXB9:]/3+WVT7A-+N<(L(T@![\RI
M`7BU::%)"@U2`@#X5?4MM%":[O76^?%1I0A;<YGWTSQU5^]T]+)6[PV(?'3<
M72?B,>!]-ESI#DT24N:A_Y=$?FCK'9JP!643#`&QQ,S:2+=!*(4DP[[LX:W>
M=JWMNPRF,RMX0K^$;C2<A;O-ESHKU8*S%YN%W*TVZV<)0FHSN"?^VGRT>N5I
M\CII5HY2,S:2D\ZIK7YK!6E$&<5?N:-')+5-A:/GL,!99#*1!I7>1<]@)A6(
M>"!ZPS;3(+`"&#^QPT[%Z."._LQJ[\J;<R_YQQ@1\+Y@^ULE>.FM,Z3N^**R
M_M<S&\19VHP)6:94)H<%_>'G/OPVL3<J0B&O72M-#-^^B9P<,)Y4%9"FH*\0
M)_A?&V2S>'7#KP04.#7-@]428TZJ5<'@;=5#O+CK+.BLY0%LIJF2@I<HW#:X
M,>GN-:-GFCJFGSD#BV-VA<!(PH"9KA4_V764P<F>DH$-8*O6C*YM:2>+#%9>
M;2[E9>-N=/*_:R=Z0J9][A[+^VAB/,CZMH^Q;,,#H;)PC02V<*H/P>PTA!+/
M87$^BH@@O9EM0=G#V>FF4V^"'F8CEK]+@K8L.+Q#-6;(_2@1]$1+.T#<B=1\
M"@0PJ=JFT&42[L@'P75%-<%4+)LGV[FCO+Z36$:[_DQC.@`6I1A(Z`<JEB7E
M=T.H055P=&UOT!2:4SRO;Z)S)'2H*JZ?]N3L]*4LZ&V0P?W_;MD6]V_87&B)
M_0X5,V?)4O\&>9F21)^2X(#Z!F'!W84(ILZWQTMY<L\'9Z)%P5*2-IJWBV]+
MG:LS]#!]%8NU!O%Y7\G#1:-R-NG0M4!$EN'<="#P#WH7\0]K$-UMY"'\KVV;
M=*A$(6Q`?H3T<V_3^+D5(\^"4.*XS.E(S8-TV:TJ99;9D59Q`_9('Y<?K>V[
ME]02;WK@%U7,6(7W09:O@J0!'NI1Y&4K=H)<5G.+6)'_LB\S\+2%_J(V2PKE
M5_OTD840FJG@1(WZ!#5K`?V;V(0X!*KQ>R8.(,7-0_60!?R47S&M'0S#"7-W
M(EDY4VJJ[IX4?U?PP6T^DF!+55L4/F:_5D.*SMEHQJ/P7G)1OSNN0NV1$\,[
MMM]%^BK9>.%MZD_;1I@8S4%+2M%LIVTK5L"AL,AS/<_K?!1(^&)<=PB9@9J=
MAFXW?UNLI1W^VOM%U2'6[>N9IFTX2/NA*X7;>).BI<7U6YJ9*WZ6$P-BIU+"
M/$)OR^Z@!Z#NX!>N3]ZO#AJZ!H'BXNX<G*(QQHJ5.2`AV[:;(O.MM0P@(%S5
MXF0W$[^EH:P[*[EI)2[-4!2J0V:9.LB>"YA%="$JJA+LM/`]C^`-)BG\)N71
MAQPP+B@KK$V-=Q:2%]9M8CI.TF;QQU:A%6S7@`H9\X&C4^<RI$`J2\LU]\];
M(_/&I31X(K8_QURA#KODU@Q;I:I^6_FMY7D9KL$9==MOBJR2H+@K]V%;#=65
MZN>V=_CNJ/;X6[HT3FJ8<\8`1<9QCL"-K?0SX?7K4&P>E![L-[K^IL\\\]^!
M]P6<[:8%A?G;27,Y!K5@HZ&#?@TH=;\+@]!<.>/>!2/]>(;PG]G4,/<#8R>S
M_C8YVB0-_DZ"Y3AK:+D.BJ07(UM1KB*%,8_Z2Q&]>,F:;&`N7#'9[.U-SP@8
M7;/RTE^%F;5(@H"C8.(L39POD%XL,VCCJ9.[I!R;O^6O`%NJ,/X<#[O!`)QP
MP$B<>@F-@W),VD\<TO@+U`)3'UG<$,\M,J\,`7]V1*QNA.\**$*]FQ>R@S#)
M=!VW+;'^9#8/Y;^J"4D=E@U7PLRB*7=G^H7MXS/F]"K\`L=/X[YM[6ZLXW+^
M5-74.V=)/*4MJ_(DV$8:1-$2I"Z&F4!.B"%H/0G)=M@;-A0?9]D%6S'-:7J>
M5/1=\5H7R5G`1>7Z/&G/JN-URJN8)A$'N+XMQR2Q:(;>WB)_I1.!^)%<,+9<
M-,@U5=AF4QT_.=VC:[\)9%,$`65+Y<B"Y^]^M<["PTH`0"'Q,5ABVB[0M+?`
M%#Q]\E?Z_[^EUJ=7Z1V!MMI")EX[VY&_[4+O<'Z%<JK$-^N9Q988=YSE)`J[
M28-"ZU+.X_568_]K%3<\]KU3;ER$IZE_"$PIT1SVXZQ[O27LY$E`O34_$9X2
MX'T?XD0A%%AL,\N+57?W?HBC(68-5<*RIF9W:\1*Z/C:8M5MUILM79P"*YH3
M*[TXTV$/73P\3;'O8,V@QA;W'GG&IR*\EXO..(.B;9"PVN_Y,WO`>S)$_":$
MV@M*X#[#%.>9EQN0\PP\2?XT]G$^<LV^;&2Q0LQY0IW>ZGV/UJG&B8.UE-;%
MKO$(]*F?,:LML"*'8-'T90>__QP1\*(3K7YLR^]IIV/=.WM11M=[^0]TV]R)
M]6\&/!5["`""OC1^5GF)8NN32T7XKH91&`"M$0<U^06D5%DW@Q%`CW728#\2
M40:+(@JN5D#-@2#&/)+.XZ808;A/%&X?VYE@E&[TL9L!S3'\D%?<CI@@'=V?
M>ROD@?4-KI-K-&T[2AVQ+FN)101)D`3=]NVU4=[[_?U-C^8=XV-M.(_0(X%F
MKTF$CZ\3LU/`.#;T]YW3/9]01M0Z9#`V2E+HCPS-4AK_'!MY7"_Y;P7KZWQ.
M(%W!*P&ARR%@079R7[@>@#%&HJ+*M>#8^M1NWJC(R^HIPP3IIY,*.:1`ZV5>
M#:6_MPI%$=^PZLYY**B`H<1%[@%[YB,]5F+@3XQ!2^Z]MXORF_E>O&B[^DY=
M.!C3M8?CNDS<Y.<TR%V,G)CHNEP4\W#IR>@0Y,IP$1R8\!/`*9<&NV4\'GEV
M&?712NV?'.F)[3W<MIAUW@?GFWI>6JK!9#7ZKK^J"<S>\F7Q/D/=TDU@^M]$
MJ3H368E/LOTK%VB]*AZF(Y/9O".H`GW59!F7&'-5,JT@&29J&P7;\*PK6RP7
MV_?1'Q8)J4BUYHXY;FNY;:.IOP02`[%C(/0MP4W1;^D/&?O7U'-4Q.W0"H(?
MAQGBCB8Q=Y^RT?76/MI))HJ&7/WXJ4#X8LU_)'LN1$[B@(0JX3S6><#`0T&H
M4*ROA13TIH"M:BM1@W>09@I!N,_R]SDIP,\NOGA:YC6W[.#&/NP"_\Z;U5D2
MCHU\=@:H$8P-OL125+1>.%E"?L)H_#_8?Q0@VA/BS"JMO62TOQ7#(]P7@H<:
M!NM<#>9^XS.Y5P&FNA7>#T;I#CE`T)U.YGFQ;23:=R[/Q7]SZ7R`N3)(]OH.
M*R#^5)#Y897)'P[E"QU%S62!(N1V=B(L9Y,M"^<*;0\\FW,DW-3L/W-<CUE,
M!SK8M;]9:Z0/P:$AC,ELM>.W:KV9W>W+!H0U`85-,.5.^G?78XOV-PLG%XS`
M*LEVI<HL_DUR`$G'[#^6`WZL)_V]M-;R!B#E[.27`-?<OX`&T8QC;)]UV6WB
M^OT4[CSLKMY8T%?)*`UV&$BMB?&N?HP?TVM0");K_KO^)#9M)?=V5$QZ5"U;
M4\^]B9LC_P@45RU0A&4KH=UI$\E-,Y<^AA;U_TP8_9$"&M5ZU;21%\E85B3^
M(PB8[!<[V!2\*/RQ5\/A%:NK+L\0#Z:'36]E[1],O:?]]:`T7<8]]4&X0.%S
M+\9`<UMRV>9+(#4=E@P^I@'^6('7+N8`(':`$PBV*'3,2)#,D6*D!S4W+!'D
M.ES%&7/;8^RB9Y)C0KD^[?/PSEQNZUND&XT,?Z0X=EA[C*?(6^CK;5?M*;\9
ME.VSUY\Z9&\F1G=_&8$785.QN*JP&G,\)'>7W26-IJY'$'L5=:!T48V=BT?T
MI=::(IMZAR/-&=_HX%W6/#]P:'`@96-H;R<\/R<[/SX<`(0,_!=&(VT7<[(-
M[W3(P[<XPYU5%URZLRW3)J%+20$43FU)3!_._NL(1BSC7H+37=MRBP<[*;^)
M/681>`4W6<%M]Q$,UE/M<FW"\0YI8\[1Y98X<A4<E@4PLU%M;/Z"R1B='PY%
M'RF$>+(1=<=Y)UN28:SU=-I;-0@^8@L*'D))HJ5UO*!EMN(PQL%J3_;9?MZ;
M)GDX>+<-OS*[M[RL7^F+$1HO,SLHK`>./Z:/0=9=UZY.'I.%<T?<BC8WBL;@
M,D85OOJ(R]MG'*!1]*7&F20'PUWJF34F:C:XJ=K1_1;[2,L</(E^G12+XZHR
M:QV=<W:,71)CZY-%P],3+TW@MA+:]F_WFBJ9?>FW>%-E`"Q_\Y'Z0WDEOL0X
M=7==(;_[PI>.BXAP\+B!AMQJMP]QB$A%4JB]=1&^>(_E=D+GCMH`VZ45X`&V
M`:*IAQW@P7>V0PO7C9H^VMS*>JPB*."3<`E7-0+3`0M3*<0I!5&`=BHRGR+E
M.Y5*&^.TVN9&W+,X;Y2)?/!";[LT(,2S[?5%AF9IE_?KQ:Q`,=`XU09WU,IH
MTJ[D`90`?$"W?7OI-G+)G`^8"T`7DZLO37QS=?[?\PW6YL"B\],]8`/5Y&[Z
MP$\>VRHR"@P;.UXLG'9LQCSVPME?D2(NI>O/^:@(%P!R/AMP>L6OP^BBL5(^
MZ3VBB;,[:%.>W?`:U<8F!@5LE^YSBEY^L_*O'`L,VC5.?Q5*"\GGO]]>"-W!
M1>ZLF,IO?J$-=-`\*?<<^/Z'"`EMI+.(QZ0>8&<4/(ZZ-_SJ57)/R$R*H:G7
MD]I5<+8)AZP-`9O?NT$%VMJP@OUT0(M=)5E\Z0(2^$$8<@>!K,14B=Q^O:Z=
M\T]JUPQMY<0BI.)B;@P'2D15EA0KN*J<.*G-J*H-XIWL"LF!!I&3[D$#*S#O
M$*`LC63A>G=A_`;VGSI`(+(S6]N]2^/#\#EA8RLP^B`F'TUM7.C""T1QG9Y4
M1BI@3T(@KRA%^(VP@-*%(0L-0B`FCF+PQ(C$)+U,=7<%^FB3J5V'GIJ280OG
MRC4$M'WP$])`AHO29_E7N<\K-ME=6O*$&#*&9=W&HPEA*18TCO_P==*RU136
M(AIY&&T(E>#:&9T7+]D*)J<1*_RF=/S$M71@"-4D56O/P!T821![-9D/Y*@^
MYV*4[J6`(TO#K_:HJ8UJ3QN3D*WR]2UR!2&OVSP;:2"E1EFV%)0TZAC;_-^+
M4ICDAC4?U5$411-=E`FC/[.R5ZBR`J!EK?U+O]1^%+->S+CMB6`.V'DO]9+!
M7*ROGF`!;WK4/XK%;:^*QOM-(/2BBA:`4+"^V<).233F?\_D&3/4#/AS%)6/
M=%=X:+U6R`OUE:-H03_A#_K<PO!X48L_-1]5[I(-VQ/I'=/1L_BD0`?%0%\\
MDJF.R5-%0=/_ETP$4;9X#F?(^\X-=3CVV&;R\20964O!)[5:"HQ#[DY\A;_3
M==;0%0\ML['2+KB>Y$C;>T]+$>`EN,X-R*TX2FLMY_*J_,#[HX'29HMUEQ@`
M7FA7I<@R5!,3/W=:./I9;]0UZIB00-*#YR/._D/KBMR8R'<H31C9O^^Z;$V)
MP"RZ`CAW1*8ZS%.Z<$%0?R],DEXO^]8",?Y)(*,#H!VS4QF[@MVG&M:)<?.I
MNH:#4P0;#QK82+8W)G4[=X]*=]'B&Q5C\.IE934C@PR3,@%R>GZ3/L&C<K6#
M36VQMDLM.0X_KJPE);JUJ'-S=G\_YO/.)N.[%*3[T)6_COV,:SN&R@;=_!8Y
M?XZTK6LW<MI0$&-+]U+2<A-&[PE>/MU,#6TS,>G^)+"P%_!IB57J(1<T"W9;
M=JD'O^R>OK&<\FZ8F^`!!NP_V?QUV/;W/,`KR+C;QZF8JF_]1]X1O]?A8&`[
M,4IAHO_A&\%+:D+U#>JSJ?<(^7F=NJDIGYJAOO!N/L`N.4=6LT5M=Q9?EB=Y
MT?38&1_:*`O0HPH-AB*#3<DQ?&'9`(\COA@"RJY<*:LK?P1S=RN-`VW&XEU[
M#3/M(9JTO$,0M)1B)ND6\3`^8B,78IAB])9%GRH,_FX+V(4*)^GR;1+*^SM?
M7?$Z6\:[/W`,E?/EBGY^>Q%CR='EXSGN=95]4=RH+E7V]J[Y_;U3.$"P3>`G
M;`,.#K],+D=^V8@EZ$`!2'V=4^2$&&U=2@QX#'=S8ZS_K4PRP!Z^&Z0X50-;
M+0D1]^=IE7BP)G,7C&49HEMT:[.,T..^[X9'(:YL]6Y\:QNY0J..(1;Y`JUF
M+X4Z#ZH+O5N+B@J"B@17F]8:3$[QMX5XP+Z3^\Y95KV)H&SH^@C)/I0II)"0
MM*2ERJ#1TFYR,-[1SAGF#*O^N[A(!$!.`[ANCQ8-G3I0!1.BUD2ZR9>\O?;F
M)`[@^8G<&O.$3%^RL(,APXC'M*)84@9PCC&=7#7U$E`B1_'DAFX$TW)6+D/'
MQ@<S\[)])1>!%5R2%!P\OTPZ`T=<D^E)&5L!CSC4ZT=/7[G()]"-8VKPC^C_
M%61_AWL=X8Y1ZD'P@I*,_,9=?)_?\NZ##8,%P;F6Z0=OLK'BB$8&09U>J]#Q
M_4HCKTI,E-B^/VTS'J>%HE)V8GV5C-@40Y\<TT=315MLTJ?FQ\.&K&J>B,DB
M'-Y^6YJ1W0-3JM%@/B[M%#OKT+".\MR[$-(KC^M_^9[QZP]_G3%1]MGX2^;Q
MUBF!(\JA!75PO)JX\TQ!AR4<72!'JJR73CQBS]011Y-WJ5.WCQ3"W,)+W]DT
M-21@#>@#_2;I=;3G3,5F!=S7!Z$#,Q`]AO(T8M&,6L>QKX*)8/"=J8/L/R7-
M+Y?6+*?-ZR3L+4+)GYE^A,?,:$YE-/J^Q,+CD*=(7?$;N:@"X7("?+PA]FV+
M<+=,)X4!4?&88AL\68@X5/:0(+60(^]6])!O2`?7R%.3%O)(/21^:/OH-Q6K
M25:3UV]]C/H-J#$)N$7,-^D;<$@OP5`(<QVV+)N1$VIH6!0/&7LX4J0#A["M
M@^<MB9\GOC4Y]X?S#%T'4,^]NE9TKE&4^+5+G2D*K,9C+0[&W.BR>_BCW055
M*V*<B4G[RH``1S:S?(!0"+(,?+^V,8+"'3#LZ_[P;F2D7U\W5,R$4#:8ZWX@
M?A"E)/U2RE6+*)(Z*7>O35F0.LD71"Z4"ZSD,WAJIL349A]3R&,U/ZXPAU-'
MD.,V<E2W5:E#MX4.]GFSY3=[,W,G@YSZXKU"[LM.>Z+F>!T:2^PUEY/F(MDV
M*II2J^(1J9/@A!F2S-M_.=,<##&-DE'JC!I*;]*^E;=775AAD:]'K\IKO@.N
M&@J,<.^W_EJ]4:0#,S]VAW7TQF.#.E69J!95YN0TU`":-(EJG9B*7YM[]S!F
MI];%_;Z(D,Y\95&J@#8K`]#"A;JH<`(M^!3[V7?32/N(=A61$736K#W3S"4X
M`,ZM\B?I^8#1W"L0LU]51GY73-KJ4M[!W0EPV&-8(]T!FFSSP,!\#7\URZ"5
M%+>$B(+``!+%!]ND]F`LQI>+SP&?2FP^A=RJ[X44&G3#<4I9?*HVB$G8^XLD
M<F&Z=MGB-X(YU4!P7$CG`417AMF`S;5FF<\L"S4Q?'^3D*E\Q]5UDW)*T8=B
M&9"+-;%7ZEGWUOEUX.5IEAQC=EUXI:&P/F?-^J-=#<-8,AALA]$R:7!5C_-/
MT6_/`@2#H`Y?_<`8]$V#Y;H1KE;-^G28W<""%'\'.02W64;$G':[OI1_B&4O
M45P9;W[YF<P)_8N2<@HAT;YL:W>]/BQNTR.[>].U`O_-&*4*TW>3Y^#'M9P&
M7S_LE/(AC`WD&(\@72C&B`+VZCHPB*NG:CM;4.$A2GNLU$W1(#L.>!7`XUC6
M/92[V2%8[_^;-^1IL!]=K&JM-28F)OXJ=O^L9^UNB`K\#JEDMY0)+6.0!2+'
M6SI+L[I(Y>A2.+LML"<`68)CSP+'EDB[IU9?2>_:P7@G"5GR=\6%U(G70H@3
M%HP%DAHSE,?T+/2[\3)3YSESU56CH.M_OI-M?<O-(4$$E1%11%7.=LA-SI"0
M3`*<5=";GA[1%F5VD;.6.79`9OS\!%DPP4PSN6D2!&Z-3!$ZP:!A?+N6O,^B
MY\T^,!][#MKCO32D[3+]?11<+1_0?Q7Q@7MW1"N<A[/\LZ?NXF]SI[B4I/E1
MF[=PM\C.:BFP41W*&!1*WA!`"=R+XY5#+B=R*TOV*7:9`\:^25EOB8:=$JD8
M%[L/3SC*?3:_/;)K]_LXI3/-(3F=>ADTM1B@W^5,9=IFFKK-05[7,_&JZ11S
MWM^\\(KEZIVCEYTX.OH406D>.#I><)B;L)900ZFFJQ9ZTT/G*]IR`Z;U%?@[
MAY8:R#M*_%^>RDJN=-6WU]&7&.(LL\<ND[0U",0]HW-DY>:3]*'L5WY@<RV"
MCV<^N"IFI*+=?L92@'-O=Q.";8EP>3K)37(.EXYHL81021K8K97XB)V4:/>N
M;\SQO<-:DUV](PGMR9,5Q=$Z/.IV,U!'B%N?-O"RW*9B67W61%9PL,,]>="O
MG#7!50,H6.;5262J)@I4#/K%<<$U.1UF3AFS13@(^BW=6EBT%ED3^59C:6."
M8]Q;$(:70LJ[ZGKSSP?PR.CYN'5OT]OS[^?H_SO:XA_*P7XT4.=Y,(58#M8X
MH2/=9/W_GL]:/5GL3GP-J$_T^S!G5].^2)N'("=1_A2E.!DZFSUF$NDFU0^)
MWB&@F)33JN#?#VP2SO\3_2H&,"P=.S/;O*ZT6@Q^T5^T1&SY/7T$IJ>5:\@W
M.$0=]X\VGG#.777L]-HV0TX8`P$H730X0#R</D7I.%3OQO!:(-S<:?%;V?!I
MW.0DC4W:&4O3/:=6M!I>Z4D^U\4VFC$0QE.V&NIWT6X]Q&?NX?E3I?OZ2%\O
MUL&E@2(C,E\`Z$H#^D"$=[T)80C7_$6BYTGG^Q6=]6,*TM(1QB^>2%FK=O['
MQJ7_5[=]/=,Y;KO12Y06'Y=3R_C0FOBX7<TG-F!EH.%;5:0R-IC6=^+PV3?W
MV2)4CTD,$OC0VAQE\;!1Z=Y%C2SC+!YE20YYF@=-MFQ;!(>72SCGP-'AYG52
M)QJ8Z])0[[C-Z[FJ3YU^:RC9=1%VJ2B9OL@7UC,19\BH!6BY+!%@?A:96'7*
MU4A0\QG3)9TG_Q]AYM)"OK=I_LSB[=;_8#[Q`?Z+HQO\W08)"VBLY\EEFU:*
M/8SL"^R9//RJPGE3)Z>Z<HH%7?9:1=F50QKJP,GOM=8"_IXT%+A:+.UTNZ_0
MPG_CI6SSVD<.2ZWU.\^8Y&_8A2YAZ8.V>&)ZZV`*$2@+^XT&!UXPFN?\UG2S
M@0V*HR#_OP=E'!]77J26]ZOC"KAPV<39=%S]+,]ZV29VQ5FMZN;H1Y+K5F.2
M.YONJRH9<BCZC[>C'@<X1`<;%7;?;;F5\68'L[Y<1?5(8&^T*+DAOXNV&9YY
MG&BAF]K;:`!^C6[=OA.1;<O#,V]"1-%\,HA\QEKFI#=>DB>[JS4H!":_)8\R
M:U(KD,U/5?BI*E$2FW$14WIK<-4?-B,`]!`.QUTC:[C'5ZB3(N+T8"QIM-B4
MM*L1\$7;B$J+`EPOX"X<#P=PZ<-#[TOR"<!G0TEJ]X]F*RU)=$ZK[YC!/R:[
M#/3]R1#J;&?<.]_*.]D;P,"9W747$Y.T>/<$U-I*CR$T1W61$K1!U][)[YK5
M,\;#HNN/2ST.*?XBAS:V31TJ%TWM@XT@ZBA:X(,%?-5^Z)(^-^3%GK5UTE[0
M&=1RE@JU%[4^]MN-V7V-%YWQWY'4&5P./+C7@!,1?[*14>Z,:4XNCC+M`US2
M/WQDAJRI#E9.<4AHPB%;+4-D9NM\Y07AKXL($?[4>/4+BL6^]#6^X+./`46S
M#N#>WO*921`=5S43&3^*Z=XH_%E_O:\`31;ME\C6L*:K0Y>NBVWL@;&$G`UN
M\UWRQARN2!V[JKA]C'KS\SX46HBO\FPJI!Q):=P)`&%C0$VK-IQT?*^'J'Q`
MC'(=%?LD(!Y-?XL>MUNNS18T>-*B_M%(>_0)1CBKD]:70D/^;%S`\%]'PFRT
MO*S4+!0_K.?4MB4WFV@M/SXW*8:E;M#M]B44GS??B(KM/?SJJ`18KK2R8(CR
M](5P@:=:+?>S&^KK2TVF^ON<V9GM\!)HJF>J#!R$@SB'`VR]4WI\H%44>LDQ
M?=J<:YWSE=,"SK`C*?=X2APD&9QLCU/-<OS%SE87_02C**?_4'R&_^5"(H%X
M6T)`+N2TLL>`ITBDV6R!5%<?940D:TND;[+%OGJACX?://FXJM=@6#TOX&]:
MS'ZJ0D1_H%_\`M9`=O7>]`VZN/I"`I03[R>E98R./E#Q):&P%>T3ML\_:_7Z
M^54L6R8'[Q1_?!ISZ6HMOO6H+PIQ[^Y([P6[J8L>]:.E-BSIYZ/@=_E`MKN8
MZGG">T:_+O!E(7+'4L2?GJ)WU$U5F?(#.;@F+!*P=A9&HY8`M^<>5H!E.STC
M2*C?<=,L<]'Q6G:T1?58[8N.Q;?UCFHW?(:C%$U6/:W$FIW;&'"[XEG\:XIV
MQ-;]R9E;T7Y87]VND3]X27^G*8#SUY1]02,D`W70QZA@\I!L`5#3$7Z[Y4K?
MP+"V`>!@BHEPYBK;H"L2T)$[PVX-QR=B<$=E]!,(&'TI6A:?F;=1-,9*Z5Y1
MZ^H:CBL:[UWDH$W#-WO67E?>DRS$JP`*=3'3'ZJ5^]V?HM_.5QF@C6'_1W6*
M3+]Z8:S-@K%H4]R2HV+,2]?HB7YOH!,.!'ENSW+I59\[]I5;C3],)"[A`Q"P
M*(V_6:,?G;^^K_4E]>.OS6<>;E$UOLZ$MYJ$G8Y&<>DL`FZNIR9(FG7Y)S\R
ME^N@@1XTOH8(MS!:=T&B0N/`CI2&,ZC"XMOR>YTXB-TF^AZ;-[K6_1U)R%0T
M\WMT-ZS74BP"+C=P?B5^=O.<=I.MCLBX^@<R694ZXIK'<-W)A38T"]XI,2^'
MBT``O:7=.*BQ!/[<$KNO_\)^X_*+\''UWI87_?$Y>=&'8^N>A6HE.#*MI!@0
M^%F+FD6(@QX*FK[<?J]@A9V=9T*D'KG[IAZR7\[O(B<7@'J';Y\Q#)Z/1+Y*
M0%EG($OKNDSNQ?J;23W'\&C03RT8'9E,B#R]2:V-LPI&3=Y%-C<)LS$XM[17
M$AQ&$)AW5#@F5U_RK]O#<0]PL<5%>['/>"Y4B$T.L]D'E90$L6]W^(\Q[UCC
M%I8[882_;6ZPV98[7S.E+'`>'\6Q+_?QL:_FOHS@TN/2*=5\WF0?KU',TM@)
M<4='6S&I,1RC7:7&Y%-=BR^+ZC+K5P783$D"8"JCW;805[<R_&K<>:B]6=?V
M8G6D``ZK;.Q?_(X"L`[DE"/+^69&S>,LD&D0'-12XZX;)-#4)D2@<:KJ]H76
M8A.QQPGUV.FRQTI8TQ_AHU,;7TR9EX#W\,Y7%UVK3L/>GO3`[P49Q\KL4)MP
MN3"C%C@>IK)83R+74`K+O*1B^"&/=BLIL1?]74M7)+68^T9M#CJS+O(Z""PG
MXXFN&+%%\I87&#\T<5A^T(ROP-51HTKB3KR;^#77WL8EG/V9YHX<S#(S7-)`
M\9'DPNW,/(-;&FZ&A+N5AT&S=TGOM>W/J"YGB9A`1B(?#<8];49:7<EC^8XL
M,/`?DT.@]Y:SR$%G4Q^9$K(^67L'.*AZ$NI!<7(\Z,=N7NCK8\.T2=:C52-Z
M0&\MN?88.LI]^2[X.*4UU/"UT0:C7YP[>'O9X5)`Q5C")`M@W@,-[!<WB'G$
M::'$&DY(IX1O#B0;`%GA-)Y0I?G[>Q8J;\I,B0%/?;;T'RPE"*<ABF`ODK?E
M;70KW46^?\;-J'%P%S%-9X4P9TT\^P!^F+*+DL5]AZ@I)D)JW<AQ`.`@U#<.
M7WK7$13YB.>"R`'OH-ZE&]^)50K#W&P04X3V6>S?_Q,W#-1XYB%H=_Z_Y7_)
M-\T).XVP;V$.E[NF?`Z"VFP;NZ?`P%_\G5D1@RX[A&0SK;N:\64_%O(GG:/L
MP(%':DE<!;H"81BX98S(G"#2,)-=AHQP<XK06C1A&WM*1A+L=1>`T)*`&TLA
MS<R>BE(G53Z030C]*YM&2=@%%*QU$W00"#(0`JNGUC7TTZ31J_F6W9QF`A-%
M-XV\ZWXC?8-X4<4$'A;;&#*@5>$%VQK1E75.PT4`XXW(N*ATD%W]QD"R*=G+
M]!5(ZIA=?83#)]]"R^>/[^3J#WYM5;87KGI&EX*DN"A\YQ4TZ^8UWZJU$<UA
MW]1XB5B?I5Q(,P7IKWQH:B/S&$ZA>##`!Y4=H6G)#=,BG\_^VQ$\Q"!PO@;$
MR*"[9_GYTI5A?O%&/:RV3RWSDJB5\'*QANDN?%JR&N0U.I(WLQ\,2`1>%(QJ
MVN2*\5S(AQLODRXD5=SF/!J$H[5O\L`H84GR[736*V*<(GDF0DE,WLQNBQ)U
M^#$N(YH3C'2.ZJ/(*V_S.+3$535N\Z]E`CRRC;)@7-`Z?QZS[Y[!$AD4H5S2
M5&0@VZH<)<&2J[G*;MW\)B?,3S20[ST^QW.KOU-+24W]G$-W!LN8@:C*$#_[
MZZ5]E[5K^JM^V[*F:Q"Z-[\G[?(&^<@;$G/8-?.38=$1QKGQL4>Q]18W80"@
MZ295UMQ?6;VPJC&E_@*Z)!U(YQ:E0<M%@JWX"=#6+,M'/<<+C3&<LLDC]J:O
M2(/K[L#5=I8YPW`.-.?((907_APN7TO+(P[+-N-=@`*W10\N51/4Q0360*$N
M=>CFN2-#T$`M4!T@'HN`$B&D7H4PS6!&'5%Y;B="[99W\\,'ABV:GWYS<4.;
MK6(B0[OW3GFJL4%1#;;D'_?OAQ:F5>LO,@N!@].,;Q17M[-)XX55$.44Z`QE
M_2]%H-;S*'-$'H<@Q`FRX48=F-TR=RO3V;XC^&+LJQUNK\(T?7:)";L14B_L
M_&:5=6[(%LW'AW[?:#5=52?979X'SQDHOF"]$*S<!N.#;CRC-7552T&$6E9U
MCCO0U1T)B=V0PE9FO94-0&G8/!RZA+/_ROC/-Z0,KT;:R6!L+90U!D.R:0IZ
MZY2=A\?N"YE7K["O>C1,Y2ZE%@O0#,/;^O$WAE'JA1:+;@4"&I;P@+_IVE@`
MJ!/$@3<RFNDMS21/CB0_L%(%DL_1@[IH4HJVC5+:K?A9^PWY#`^+:[E89$ZD
M@([%PC$YDX.,Q3*0]EYUL63973+.HM28`,(<+BUVF":-_31L-=\=X\OKH08%
M"'NE%7=:.Q#`:(;47\'EG/@UJT7:U3[^96HC.WM31M7%TU0745HV=`<_:/2@
MYA3M\BQC`G%^.[50]/1F+@YKNH,94@#[_WT]1?7FC__:U[NV')H0`J-J`3>=
M&03>E];JV'B^)+KK_."\=OUSIB<$\U-X+H:JH#-)&.`4![[L@_5EH&4\PBPB
MX%FIY#VFOW/:`3MM81T(XL<R(W!Z6P#Z%/5M.Z2G0:H']N7D2+SX-E1(_MX>
MD<E1MA10V(IP`.@WDK)=OT$[>FT.V=^#7_'D_,N/L0=3WV$;$X">@AU+"!X,
MPL5]A3#QZ56U&J^K&J4/L@,>P(C!]=^DX;%D)+42&YPA&E#JID_X!)OL:4`&
M8@6LSC7%]:"//P(8BNH-C.GX"6<QH#K\.BLF0;`A88]QZ8K_"^!`21`MD7\D
MZNG&D$`%3D>*=,R?,!<&JEJ#E1?.R#&AY3+57ILC`C0;`(F`D@LXB@0STQCB
M]P4'WQ3_H1`VB(0%G!./T%7)IT`>8Z\UA&TY;EG(5+<F0.MKI9E+B#`V^,:<
M7358^%3V7OK-:<==AZ4P*(.&+OQ#_D]1.Y<4P13Q1-3$]'=?:0K5#..-<^^6
MD7+=8'UW,^>6(`U'$,%;Z;>VXH&10H"+#M:[Z^UN$<3#LI<=K'W!=+!PK96#
MJHUUT'3Y!KD5U'*,+ZFYS#87Y"D$+6-`@[_[+O'2@>P*DJT9U_GNDBWT@>9E
MPZM2ZV\!B'4=[D;RDIREI,^Y5<1P?$GUJ5*KD+[6.MEL/X-8@?I[_NSX[9.[
M77[>S*!B)2.0=<+)9VP<ZN5HAP$P0__>I(06Q]YG7([1*72QR=]+B-]TC2X,
M>@9+58FVPQ7)9"2FRIRR^4\J^!FLJ%)*[%L+6K"&]QL&@'I`FFR0>"T(06)L
MXNU,.1*)E+.'NO$_L'U;K2\;Q@$4<\RL^/D/N#5@>/7\T0L=[?=/GAN]!7,9
M?A^E)\9>>O/4O5YKK_//#ZH%NCM[4>;["687;?1&:(P[SZ&JG>&G1P,JV[O=
MXH'XH*Z@@_RXH2P%381X]2HG!FA7\QI1'H"V]_U%.T,O@KG2P0YYC=)=I"K(
M-<6F<OAU^5NR]&8/6>",T#0_R0X'P9_#+RJL?Q^#ZSVX!TVQ;+;&^SG#,+Q_
MR:!3!-!J>#X#Q,01VN9M6"_F>S7\?2C,(==K`#PJ_.PD0YB15ODH=J!453Y8
MW[$[K19G&AM76"BU"FSO.V6T[Y!$&ISP*OX'3.`X:?"0I39=."=LT74=?.NL
M@JR80YY@+2V0&%SZL<K6W]6S_/C%A@1)`%0!F\72XU,3P-)H^;=(>T^LP0S&
M?4Y$WBHJMT'],232]_W+PCZMQ.-M:N=*MC8>M/TBIWN>$DL/CVK%M;8]7MO4
M[&&AF:NXEP?5G]FNNHJKQT0@*=I,>,Q,"`<7\KBPM(N_HRV<_T0=#D#[G/0+
M%7N'9@Y9+^1LBXO0G:AA\08W#EN<.I(>V0D,JCO#!M"4#^&'&)&A8EFVQ-5F
ML?L782!"_[2^7EP!N#+(>YRKOI$B7HE3]`%7-5\?8`N0_^:P5)"*;TH<N'SD
M(Q093!52RT@A7?P(XFU^[4II,K]3[TSPY#2ZD8>5#&)4I\-`;C*_@2I76!=L
M99;!-^C$$9Y</_6DK@T[I4+U[2:ZI?0S.EH"2)ISC_[&.6-2UH,":W#M).@L
MC"HG-02I'?6^]PN35[3R<IK=@T"`<IL:@V)UG\K-.HNU=Q/75F&2A(CPB;,*
M+!E%2ZJ(1203MJ"R1,13*J9Q);I"\.\6YW9CZ!X=@%$,%G]'!DSO$@9N'(5O
M2'/0^#E%U^0>T9NX7K^=8[$R7%]D\LN9&3W#B38,P`;IQ`YQ4UO5[,6=;>1X
M:'"2`V@67NZ\>M?4.KT?I6P)_NXY^YG-+C.,+YSXA\SU"VZ6(]EM&)X'<Y-[
M5IS[TR*!6KXW/+CU:HE\?C8B>'HZ149LS3,'NWJ<Y3UT%E2ZL]^V*]:M8<G/
M4/7#TM^$@T)OCQ]4V>FQ;I%T*VZ;=KMP\-@FABA=DA`"(>+KQ@]]RE,KO0*_
MI8G6E7#N5CURVP4V0"?@@@'(WTH)B?BPD3_(K;)M!M6VMC.BW0ZL"%:5Z?/:
M,./5GUSQ$@:>)\.R^K)D,R%KZ*/-7JL:H_>M+(<S0!R$W"_9C%`"_7CB&1A=
M1CV@>")Y`&VJRI9*!XZ\0NJ!DN?_OAFA:']"]M4Z%1>Z&>Q^D9T_+Y2XUP44
MEDE9;2HEG,AYGY%83XJ+13H)_J+&ERF2ASLI\!2<K#(#V2##_]+7[,2([8_V
M<8I1'^)_N2?2'>?/S%*9Q%\/R\@F1VHA2`^+O-"=\:K-6-"F_UP!UF*C'?V$
M`Q[R0-61!#)AQD"_G40""$QJ>!S(NF*[QDT7?><^0YOIRAZL>5\QD"<F5+WU
M3P8KP79YXM40S\69Y?<DCIJ?3I^)@A.*4.(4&*W#/Z,!B*(@M]H8FV2Y#)E>
M08DMLM7O<*5MNDQ>0[:TDF[E,<)=K54K2@DD/4J.G8;L6HD?G3B0:*U&0SOQ
MP0UB4=`2\LVQ_NLX=C-%?*(,D93N99YQ*6@L`CM!4194^CV]&II#9O8I3-CQ
M1MX;]H(C@2-3VG-%H6.W81U<DC33Z^D\:AH$BJ6F$TE89S-"CI?QZ$KJ+F^%
MJBN-M'%8DR;PT(2I(SL*7M;095'KWPQLX3Z^C^MVY$=E?LC@SZV<[7[!-;\,
M`9=&XGSW]5?][^O-I/L'@ILC[1?Q92^3PG!]1H7D="#JK)V0/P`>\7.T(+]<
M,4.^0B;=YTOD+&)Z%0IM0!"49SDJDL^@J=&/5;'*JZ%9;X*<'%(G3@,R&\+Y
M=+3!BV>4WI`_2XD=73#=VUA)X'_%G#F]!!K\MQ_&+`,WL!_WI52:JC9\JSUU
M74K^M6IVCQ^IC.T=(5KY1*IN'_B56487D=:5_L`L<Q)0XVQ>6_U)PHGOP\6Z
M."NF/BF*^[I8@X,6/Y/1$!D+<2]CK_N,DY?XE;0+SNMM/RM-U8C\-P9<L(%^
MENH3A&(UM;GG_AID1BOU+M.H4D0U`'R)'63L)4;L,7#MCYKRU.065!^#U.<]
M-;O$8%LT&9SZR2<$$@[SFJ'^/1WH-`G%"F)_-S2TE5&KY\WLZSY:2PFKE@D>
MQV<40U>>K-!AC0%P?O^>\A_K:@@:ZW6.WSS/(L#V[W6B-_(V@)L>*:-]PI$R
M#&K<;',-9K=(Z';-`R?"WD\X3OYXLE0,5V`MXW_W6_(UZ(5"G>=N_`+$CF[;
MJJ%*@5,O\=(?']>;:%^-25TB8"_H1ZH/:[]`$(,__DG8]([:H],,)O0F;$.=
MO?0;@,[U@O12'&(A#I.OVV3^.OFE4-,GX$L(</N0(R7'?OD9^WQC*9B<WA?Y
M:GLC#0A`*0!%FQYPY/.'\@I%U3@99L\JJH@6[S1-D-_L/G9MBDCE0`_7^+)P
M#NJH.E[.RLE'FB%^68]1[&=6>QEADR@'^CDT)60)SO][-5=/P7C,0Q*H?H\0
M:,*CTO[<N_%;51\6CQCI5.,#$PL^F[LC?2:-^@T'0^@*+LK(7=O:<]V',+X9
M0)O,,D4C:GZ+_&.EC!PK+UYD."/^MAFI)\.:X%R,A*K!3O6R3R^)X-.YSDZO
MO[V32RWEPR[^-E!#]2,8F6RG%@(4IL!-ERQR8XF+^2J'%&`!H>M0UG+R1(_"
M!A_!RK=9L#N.1M4/60#ON+*@4RICSQVQ"YW@SCHQ$]E.G#!"0RQEC\C31$@%
M/>19GY>XD8>C5I[5^KYIU9_5M^[@U_J_Y2Y+)I1V'&703&>5B<IGDXI:[C$U
MWCM9%WT3*"Y"AV:)5^0Z@7QDR_ONSO<[3"?ZA^WYD=0\HY='P-P(\LDT9+@\
M-K`ZD<'0JX"*:\+,.G'8_:G!T!987)#0HLPL8+#NWQ10.7MKE(:@%]!0WI,Q
M?]HJ)+Y?PCLH.-"08Y2T&T-3M!9"5$*]9H$!````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M
M:6XO<&QI8B\`````````````````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$T-34P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]A9&UI;B]P;&EB+V-O;6UO;E]F=6YC+G!H<#,`````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,R-38Q-@`Q
M,#4Q-30S,3`U-@`P,3<V-C$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*("`@(&1I92@B5&AE(&9I;&4@8V]M;6]N
M7V9U;F,N<&AP,R!I<R!P87)T(&]F(%!L97-K(&1I<W1R:6)U=&EO;BX@270@
M8V%N;F]T(&)E(')U;B!O=71S:61E(&]F(%!L97-K(&5N=FER;VYM96YT+EQN
M(BD["B`@("!?7W!L97-K7VQO861E<E]P<F%G;6%?7R@G0B<I.PH_/@I2[O-R
M\-/80T1FZ%)WI+U01@C0Y'>_/GS):5H@DMA'8"-9UH.I<4D,`N:MWODBCYVP
MU#?BB6(M1W/H-EAJ)&_1+`_=2E(D-[8[/S\W1R5#64>2-+<A)!EQ9$T/*/&!
MPB`X#R?JN*UU@H6<CEI>)R7;?$U95`56X:I?),AO%MU[OPA5F6N'">L)\,S:
MDHCE`"")C01@?=O<3?IUT@Q0/U-PVG;-\YO6QN=]`5[?IEC$<2F@U-K5K:$2
M9/\24A6>Z-7__46[[NU\+0F&$%E4T%0I*0\3M61-DF"BMLY25[&:8]A"4*>K
M8S7+^N((L6-O$\K)I8\MJI-6!#I-9L?2P.+7=7G)3)+N?UFI:M_B2GC/E4U%
MK'^HA8&<II1-_Q4JI?'+3A.VC7I_'PJG>\&77^OO89H<*Z&[,@#(^O8(37AN
M#/!<GK.OSNA"KC6#<;B_V$D)<QSI=I"4I+K3%H4-A?0.&(I;H8F?/5=RS5FQ
M5:2BST>8_-Y=<9^._&WWVX$VNOZLQU&7%6$VY@W93?M)S4P+XD!"[!MF/&ZH
M21.,\U#I(;Z?;:GVJ^6F:(/XIN_W80%/?KH^*'^]AN/1+LA5JGY:X'"(<OM*
MZ1,A[#F3LLSK[ER\^N]P\W3)*XX,6&&+P&OV2*F*=0!WURQW.4>YBC_N(TYV
M)J,0?#D#_"ZJ@VTEQA'Q\#"WU#M@P/.)J#7P\(]U.)]6^G#'"QA*TI6'["P9
M=W/3=9MW_E30-US$L\A'KF2HC-W!*W4KFAK7E^!P/K\S=(B:_%&\Z^0#FLBQ
M?GX?N3&8D?@:9GF#P)FI)X3.JSUF#MEJTNJ%/2`S^4!'K+)-/8T#TC,%Z*^@
M#^4"\!B=>K8A"_DU'<"Q)K7(5G4P!@<=Q?>2/7RS@^[LGJ%[4S'+][J7+7"-
MWHU]#YJ;_UN'BR4A^%KFLL'JX!AB&*B$JD-(Z?X2.T0DMNV.26,U>3HWX+'Q
MBDA&#3*NK8IR6#YDD=];'SUYCGS&;X-]'5&?;-D`=B@1,D,7]@Q6AN%.RDP]
MJAW@^WKH=$1R`S26%V416]S^D6"SS5G5=K6EXIUL,).4-RIW#&J+G`43M-)'
MQ-!2FFRCZ<36=\&"&P",#X#=C+B+=9A?W[72Y=>W7.*B'7!>6MR[>1D'97A/
MKW(Y-O\.Y\HJ$9VT[K$4^RT@];/Y$]D^JN-U'K"D/G/GT4)$^_6-#=26UQ3\
M>(DH9YH7J*+2$YR(V3O,2;+PNU/^_\S#?:1YD;S?ID1PM@"I0!L\!:8OUE+6
M38)(3A1I`HV4_K5_*P-L""V$FX.@7E!?%B'95F6X+J.F_18)M5R^\1$\FUM#
M*(-KJM&F(S+-LJ=G*X+D117<$E=#V'\PI/5;]9V4\ZD(F*9(ZO@'_H3EP/AK
M/KW%C![EE)#;TG2##Z@C+%W;6XADD,DYP55C:<@52$J)F%OX=!XV+ZZA."W#
MI4$<W&AF."T'VH?+RJ\:P@8ZB-Z^4?,I_H8!UC1AIU(B_DZWIVQJ>?(_%S4+
MNF+0CZR)2%,MV,U+.CA*1$&&S?"DDH!$!=`W9>*=Y4#^EW4_0S=5!R/V++::
M@M->=4.SF7+-!.AFOV=#;5(G:>#TW(K<(7#IC@V<M>5436^>(E&=X!&,OUW6
M^]2W41KN\Y)!.T]"VKKP[U<VG(CR6\*X`4(;@7V3Q#LZ3\;96.+U(7"1H88!
M)%]*_Q?,.AOU=#KL8EG)6(4H+H[DV-@/_7JKR8=N^NUX3*+R<+]5\#$<=8Z4
M%I"P>*-O@I`J>!1(9K$"UU_)=XT/S/-%;REP1)<^0!]'UHG%+Q0443GT@VL'
MVM-M203Z8Q.ZH0K*A]+U(0?D!X.103=2T'M%W43>^*:XY4B==\VKTV^F,"0"
M=87FVM#Q/(YP7L)=&AJA\`#@&#1"C_,%CV"*+/JLR,03NJ:5FI.<@K;FI![F
M-#K52^7X(34@`C)G_>T=B-4R*:LAXA,;@2915A69J>'*PU!';F&]M757L^N?
M@)&+`=:55@K)N@).#O+FYSHZ+T8ERU2=V/NF\?JM(KXWXN>Y,]_,J3A2G^,)
M4#1^"B':78^C`O4AS/K25FZ4EL/O,%5AICMVS<4DFY]F;7PU<>"WV14`9B_:
M,@(!;58IK-.-,VE;0!(S5#OR5ZJ#"OL]*?_WVL(&#--#DX?R;BO"Y7GG]A<]
M$CYN7+S,TA[OQXZ/IOSC3S5F,D-O!,]?X,J>"WHCFZ@Y4SPGQ[8')?*TZ:3,
MO)TGAN`D2@LRBNVL64)(SEL%D?7`DVK+X./+@ED(-&%;ETD(@C2F$&]ODO5[
M(-4C:N'`LLLS]PBAGNY[6=]-XW,2+Y@53\=GJ<64,"#8",GQU*=#SV0-IW"C
ML">-TP[E"2<J(PA&_%A5OI/ZV"4?`[S^V\G,*E_K/YC*-&[4@FFNZL:$,*Z2
M/9RBMD0KC&1@TFSW!PS]32IQ.L+R<%9'R/NFP]S5B@OQU*J+_9X]LE14)*EY
M8QO.&1L[3RX-@V)'44>79WYAAN&,V!C/*ZUK5*Y[PC=PG'KLKZ9-`<@"LK66
M:<BRPCN4BF3V^.>/=(4C]ARF/>1/X]7-K[%1%F1F`-PQ4,[G1X:NW_!$?U`!
MG9BGTZ&4<4$ZF5T'NQ-M1T#6"^)I!UV]M`FR82^0$"\@.%;9;2;)\O!N=AHR
M7N]SYV8O=_!#OQZ!!)W$/?>`_'6AW._HXXMS9`^C!`N1SJGBWZ$MAZ&GU6I7
M/NV_DREMAE"R5,6<\1TTR%&^RV8-E;"]18U?1Z<Y>5OBI></6K)2/T)>SN!E
MP]6\7H[`OY68M@U0;SLQT[`=?/*):N4!4_2R4#)\7%2^AP+M''C/]GAD.HXG
M+CT07009M.FZ#8HK?XF64VXP2J7OJ9`>6VC$E>P`BXG_)C7`RG/!0T8V.7[&
M*`4%DP%H6*1\L9'O]4@I(<C!P;=J@>Q3%XN,.@S?S0@D4\=G$N?WS@RDKHE@
MH@08@!8VE!?Z/Q9E!;"US/&74#RDL`U-.S;QP&:+^ANX-P'?EZZS(B.<L=@X
M#`9O<CJ!+3=JEG+GFO8$^1]A"[;;OX&IT"%<*$%$\S/\V#%+"2_;RN_9=3,A
M%%;QX*`!R&PM!HA)[4K75N7W*XTGN;?^$&H`J0N/YHZ/P]N$>G'1XDV70DX)
ML]"..TE:ZV(-.]Z2)C[<ZW%>:S6W9,UXG1`RM,T)E$;H;<?2%;JV&?M(PL/E
M,@5Y0*A08'%Q1??C,$K+J!6(K@))&6=7H9O\<XE#W\;J8:@X_[D\VX85;1$$
M.X'*(%@.)<VEVH=6:]NI1U><0T=$A)^*#!+:B_YC&G789C0#9-(P=*EG7ITK
MTL')OHAX]N@:<BX)'YG8G\BBV/^.]'MYGME^2@#&$(*)U8JB1@3SXW8]C%D4
M)V!="V8":>D$O6:"8F]AJV24W3J1\^>)%!B>>+'Q"S^WQ"270.,/XRS5(+C,
M_=`N7.`(ZU.[OU]O'"M4AX^%_X<;%EA7<88!06RU*$+)YXE,5E0>Z66DEJU<
MBY.-D34KKVAJS:4O)P<M"4*L8=J&#\<P`I$T[XJ+I[D?^X;D8&``FA1#+0R0
M2;=9^3-:-/VEFOAZ9MJ-<_>?2*XS]36=LR+>A%@P-6/G+CMDZT309F9EC-FB
M<S+H9@W<R>K/](/7MFQ$HA2-TRAHT2U;JZEJ-K5A'1+40]=_5!BX=E)P*$.+
M;#1O_OBMG/9/L1,Q_[8R00X9U2REGJ,H2?C:);-+S"PQT!1T\_1:X9,F-DUW
MVYW9`Q*7*MQR^&TCE_?]8&1T[E2!3*N:D2&')Y;@'U-"L#X%T@%QQL=Z^FDT
M&FT74283DS!?>HH>>VTQZ#C5!9WJ^\9TO)F`PW:W*)4Y#NEU[1,=CSG[8V$M
M,#="AD=MT_M!0TCY;B<ZCGPGU*93#\(%A/.]F2_3B@1OE6N/QR68N'V#^BK$
M!UAK25Q3=<C5J*H@'7F&*W8G?:NJL!91K?OL`G3\K7GX7#3F>NE-""XVHRR'
M[9+*^,=NU@CB8L!MW<W]*B:)\@/3(7`=,T`CR&CT*&MWI?8B&>P4,)API5+1
M=<`0^>LZ?$F)9XF&1/E_?VWG(&S<`F*<VXMR2)UYIP1"T0)K,7^+``/@68C?
M'/6XGI<Q9?O%E21W>CMUR@66-2&-=]=E8(C=/5;$6':/!-#7'$EY&3[?_K!N
MM+,_JB4VBQNGT7:#]XF/3_S58PB24QFCC4=B_J>7^+6?C*:I^2NJ:[OM_K',
M-I#*%PU#0S5`EU_WUU,A$0Z7!F%W<Z.-K`EDO3T[S9M[7/X/#EG5U&NU0WID
M,`WH9DE%UN@S:1)AF5>QB;O2U-N=W^TLQ%(,.41TW7(K\VX!:GF/IZ'>CWN8
M-V6%%TD>8Q,_'JH<2YI'.:/(9N"U#X@Y;D<696F):-)\3YMW`PF6;E8P7!J&
M0.=:^K-Z9A3N;83Y;\4+IZ_)P:M90_,F\_[(BXU80[\\9&4`'/9$B=2*N*7>
M<@,>SZV>'31=_^WA;W_7J(C@LF!B!1RE3^Z?![G_QMU[@Y_K0A<`K*I[I23.
M`B!=>W#^V:Y(AT'P7Z4'BK!B3%K92+G<0CTLZ"$*GU/1WS,-@$0F?Q+.Y*T(
M8B<9`VROR[V](V'7?.A#<*OD]_=&:/\(^>UW2.E?J]6OIP>6G^N[UF-6L.X6
M*X@`_$\A*)D^?*H,J49,0-5LMM;]8TWB.L'Z&B,<HCR>=X)E-335BS4KUZ^S
M;\RF1)<X@]B2L9B(R-/=4S/18HR!W]M?Q4Z["P6<M>X$ZIM@W=@CI`L(]/+C
MHZ=1A0\96R=O(^F6@54RO%2G"R+'"OK214<?NSN9OX7GO"X7JLKV93>$7P[/
M[9N8HSOY2ALVY+]N*N3GU4+6@*/JFJ9A0R,53M%_9P=LCZ]TU=$UO1]MWP=M
M9W;MP95YN.8+*74=W#^$PU\L@WH'=;$!`=$\MOKAR!50CC1MI.I@";^=51A+
M96M#H[1%\T]H(0(C&Q6_O!0TGZ/!9^_6,5T>G4"(BQF1SM:)[AX4]`RFSM$E
M1F&%NG"H_";*EDTL%(3VU(M[.[9<TU;-L9JB'")=#;C8SGR&6U,DFP?4E-I-
M9U;QO2*49<EM@P%=)4!H]A!;F'[.6\]%UK3XHZ7QM\(XJ_MZG";*_K1+-G2%
MSL5X\I=`&3!G3%$'".LIY/FX@,(4BH;3$8R<.;!PKH/^MTJ_<&'Z]LXE3O+,
M0.>M)(HDB=R(8'HU!#\^S]67;JB2,J&D4%8$VGWC+DX)`&JW^Z)!0_-QJ<W_
M<`E3VA`T#XEVLV3>6DA?%"U[6(V*G(V'[P,AMR_#F[U>FI+**A^2]#%R.<%*
MO$3_G?RUUOPCWM6V/XY:NX%Y=EV$GI9$=_U5/HO26I(H(K`GM\=)WR8+$96?
M"08K'?MFQI4TO7+)(OQ@J.ZILT&F\%;U\D*C..?]Q_UPP"=[Y]_]<%GBK?2P
M!J&G)G#WQ*]Q[)M,-:\TG*"#X0597$?+FI%O9E4DV).XQHU+OJGY'AAPC*-F
M;PM8=00%[C1;4[M^FG[`5\(-R!1$;#!L8Z_7ZB/8"+*>:>_OU.M"2#8].HLE
MJ+#U=S)3.\%^HMW:F>#SD.CQ:^,4EGP457LWO]&<^.MX$T>9[M>`B?B9'MEX
MFRR'BAF6SE(WG?D.%*L>86OY/<IY6_!58S.@MLU4L425.C4!./R&DT1@%EXF
MJ-_)E&(T;3@"OK$9JF4X0[I5YBFKKI$&8'$N+/:Q)7?^?GA@I2;J"X:^&F!S
M-K7*EYB$?+WXKRY-<NT^65(Z,*<A0C0\%FXG;+L-O[N&!J$:UR(P00@^%(02
MA>S9\;HDXU+1<`?3**W'UX%&,[V*8I405&O?"J8"/7JL@O)>6K!,E?;!1Y-#
MOEI!XI$*L@-\V=Z;>-B)I)M06]25_B`"MG3E?I4UTGP8H0RQ!F`"QH>JLV)#
M:*P0/T/=P&0J%NK-DN/EL8_*408M'K&Z>`5;3G2H;$P^DV#$SJ/T<2J)Q"^K
M)Q16U`8NY%"MN_S6^BN&4<VZLB@_;KRD&Z'O;^Y2[&S1.2-V4!K(O`6N<9C]
M78)TU@6OSHNF6]#:*1CKJV^X"?6P<%H>O2O9G&!;B7@E(-P+9><URK=91>CK
M`AL[*F;J']*1-J+JIS`:,]@K,#F?:E#5.\Z\45\K#7'9C]40X$ON=5E1/1G;
MZ+N%T8?FG`A2)<_()O*%6A5HA?_\-@I"!0T-=#J'GAQTXU2DCOW4XHM8!`6\
M<=[QI#@=XPL)-1DWM*,M-#C74)!U)E>COYI3EGG+<P#GKQ_\MU<I[(8)2=I2
MRY(IZC-S8#-[_2X+T-6*=%GSFR`H>2#</RQ'":V%W?BK1UN49O@+*)!Y`Y<1
MWJ3\P86_^&-*%L0VQO:ITC/=@&<J0FXR1/'<`L4LECU2V'0Y17'FWH6A];S%
M$87QD"4+A4<R\B]TNHM[6\4@UP[\&N(8E)E&1>)6<&6E%T#C;+MY&\(_0=@(
MG[\@_(,9:!L4+HGEW.*'PW1JSN-I:-<3!(J;P2XUP82O]S\Q1!5"4V]W!$\>
M[!3+@<V/>^U5**0\>_,!"J)Q(1?#VTW]:'<SX*X:6:,=)G?]#^K,G=BXXTK]
M$UK!9#S"_F-U`UC2`IKUZR9.:@/YHUD3>>5]_X]CC4!?G.*#,\F6S:^$.:LE
M;^DG0W;F"M-\?\/(CHFM)W'*4VW5_,4[RO#`\,/^K#5P$I`'B8?X7Q.%&4PK
M?-V%II4-EY7%BQ^)5_#MX-R%>Z"N"EU`LQD&O#7$CW/0]BU(G8M"5J^6O`M%
MM)&/XB05U8^6M(:I[TRT<[@`%;8O;C]!*W;Y5OZB'%Q%<1;,B2!OHS3_ZO/)
MBCRF`)%#[U!O<)#*#-U3=BK5&95WEFXJK,L+0-\K7`3[/J0EO5R4;WVIGP.G
M$_8"(W]'*;C?EPO?U?6T"+#A((*/@E\6Z;D8V)<\J!;QT>60CDP*8X.!?DG>
M-YJ_5%I2'(P8DRZ:4:\QM8-PTT%W]F`AK<R*!-Y^Q2*;/L:/%4\ZGC=B!,Z[
M9$EO8C9>3B'\;OVXVGA5"KF5C[00OBU$#!X&B&H7P6*YQE%88%L\J:)PJ@KN
M+C:65@%9O/[S7*OM+3Z],*[KJEHP_>N4Q1R"!2PQY[.P0Q?[H(\MYW]$M@D2
M_>T[I5S=<7^`F>`I!5KOF-;M#CH3"3-YM3KH"N+H[J$9!;=KAVU$!XCMNSF.
M\0%.HA3*1,1OM"G:%^\MC-9'>C_2`B<GQA?<M^"&WFL%.WF#?+LYMJ%HUK7A
M23-3$;(QW,8&ER'YNF;@YY2/S$"1D8\K7I/AT\UGJWR540!;_\3#0^;G$([>
MQFVK66@.3TJ[??[;[E,F."*:3J?G5#F"9S&F?&;J.Q6]Q6-[/X=QQQE@U2/Q
MA;=(@Y(&]OBMKC[G@5S\>3%=V[;!^:6:>J=RE^6:&8RK/:&CDC*\0HD``#$N
M]XY=]RK>\"$6^BG[MB(2I0:DIX]GWOU\3Z1<C&<(_;_+G`Z%&?4JD03/4E9-
M<2H(`$]F)C74[2Q^911;YBCJ&1D57*[..4!8=F!_Y%"WSX32&ZNEGF!;_1.O
M^RE';&F=H#:=_I9\\X`BK^H%#$PN?<7')\*ONR^66\K',3_?KA490V.T.%8C
MQ]YP"LJUUD.6]_F`UFQMG[0Q6]+9W3<D-S.WIJ;)9*3&0$CV(MD8PU&H\("`
M=Z&IH$5CTK]:V^Y,!818S[=H_I],@X?!L3##>:79+1^L"6?[K_EJC6-X(]HJ
MC8K""?/^QVHZ[NP9HBD-OW_Q%5Z^7P!$33O<3UE&Z9`%S%X/`>8G7\=VR.N@
MQ[,L!C"7>;64((0O\:YJT=P$[N,KP1?\X?T@L+]#$<YT:?F-3?#V7Z)G!A^`
MYS<+D#$QF["C:$6@W,=A&A:[VN4+FTYG_LM>]GH-PJ*6E@D;8=O\+?Y\=Q$P
MK!9IT2`R$]K6]&;8?9[^<-9,?"_DO6DJ"N%D%\FF$4\%^P&3IJ("G^H:^MA?
MP00`AQJU.00=&RPNZY4>72][W-*&Z]=F'8>]2UED([3Z<NVQSN[7+MQ*@JWH
MS?$+:S2H:[F2,A/#'W#Q4.:['_Q/8"QAKMU@0*J_C^(42+T63S+%O__!/<;R
M'JFY_#%5?@#2C=T$%^XU%!"FL^3%\N3_<&@YL2Z@R;Y"]"V+G>!X1$C#TBO\
M3YDHO)C7//3YBY@?6E\0,'"B)NV`N8W8)%X]&9RQCP5CS!I#CV<S#=#"2PV.
MW(,#%Y2/R6D'P-1O5#).IUG5ZJZ)JJYX&\X4CSU``6FNP-RTD"=^F31W@S9[
M[6BV&GR_<CJ\GHXF/VY66(3*)[S6CSL_D,WVSQQD<6924*)RX,EB$FK1OW>(
M&W4=,05]"7:XUW'=?KOYFEP(Y>5"DW,]Z:(7<OG;FH/"#"8O<UY&H72P0TAU
MQ+W)K=R4<H7)+Y"H`Z)#EO3LJL8A^E:\!B2.9^]F`>>4X0<DP*SE;:YX5AJ.
M7&0TZ_$H??>A%9"C*@N1AUK?R8"!.Q)6'9%XSJ?TFPK*A"D%8\^`Q.!@*\U_
M`DO/QAWV]?O10]P=_Y4NU$@'TD<))KA4SZIJ3<#:4XXR5"LZ>UB#AG/X+UX:
MA^6+JPU"Q_1A>JURNS^@8G::8`<'/U/`*5ACZO.0(#_UH8C"6<FSQY#HNO&K
M7=0NTZW2E@:&5QA3\-.A\WKVBX4T;T6DD3_2Q>>=8G0QD@BTY4.?BUA;%D7?
M^V[S."`]R]>@DS^K4.&(EO]`RQ%\+O8DXQ4F89JW(6@R%BH'%-\)<ZW!]O&[
M9KG?9GK<_3#AB/]BL0SR+!BHP;\:D_U^QR=M6X$WP[@B>OB@YR`L[VO42JTH
M'N/GH%+)PQP@I!K#*F>L[G(9%Q;4E-F[.A&@\R;=-[]XMV:\Y%C@Q+Q*Z7,Q
MSOV6Y&R38[GD7X0G8I*&3@/H;IW($SGS#4C^=FZ=5<A;K!7L9VF<X>FMFNCA
M5V+J^5PUX5B7/`R!&5XG(G5M"ZDH038&H`S4DC?M<(L1[X0=>!P9V5XT@VB`
MF%3]`ECJ&S`!2H<^`D5@H.[`;KI6=')V00:^J/'IZJ/0!P;V^8J#7M=\PUQC
M^.X$=$5SN$(1A54VF844^UL0U#R/$QV<I4E*3':HJ80ST&`SE<.%C_/OB`PG
MB7"I5>EP6(*YUK'(.!%+C`N6UD%1K.H#PB+ZWSFE!K18P5@3[+2UA<0"86[P
M'V0138Z(-4(TZI]K5UU"4\>.V?F&6/G@<7V5I`XB-+X%4*4$*3J2P!C4/'>)
M5!/N//08L\UNO$M"[NB?\=UP;KX?%"KDX,3%68DGG`"W?"^).R,$OMIY18T0
MZ?TVK92DE_Q@.`'M/ZOCGBD\Y?6`?CSCZ3@F#]Q3-9,IZ*O7+7+.#<$)+?,%
MJ##77MW?!RS=)EU%GS8'HYK'%U5'[]K8%#3"(C09W,\!AYV`^XYQS7[W'S;^
M<X(E`:FG;4""R6R34XC1\WS"'@L#Y2RSDTC[:;/`$C<'+`S;C*A3$.N:#BXT
MLL1WG]2#HNB2O"\%IQ__`\1!?!\Q=^2IM![%>@<WUG0C_ITKP8(\2S/@P4T,
M_/XVX1@>55"Z=^\7$I(`-E[F@NXU6:5E$HRX-*6==2QDG4P#HG.&O=`D(HA'
M_$=C5/]2=RE/_9+?^$D8BL[X6[OU9%_%M6WN6Z@0=C$IDO0\.)``N4BWKF"5
M3DCD:U<0A8ERN4*:)$^*-VC_-84YENPP&32T2N:E)`/?:=Z!.0!BZ]'-?)4]
MGK7;OA1E&C15:0P<OG4W:O4M_\'KA9KK;.6HJH/AU5=\/9B,QU:0>^W*#V7U
M%K)N([[=1LG03C7MIZ:?BS1?JK"<TJV`*C376MN$%ENA]#*&?G)%O=\OT8/Z
M,$GZK2[OPBF4<U0"[1['+Y=.4R.VF@J[)>'R20([0J<(('-30=05,`PO7,AW
M"H9`95H<SX*471%;)&!4^IJH;',48\KL%LH6%@N@S5)!F]D<)"#1KE!L:<IT
MO[_NF:30S&4MQX.-+3RHWFX-,D^;`2$79HU*`B0JXM2C0,I&/D^V0D8!W/*K
MC?ERK`[`IAUU!*(JX[-8NFL=:>L'17]'Z_#"\7K.1J1O>?=!O,!_6I)S\?H5
M13`BD??<@6%&Y@W=6IK'1M&#N%T,7?=9__7$L-]@[%"Z4A\WV?R!B1.6-3WN
M].7Z[W9VWL0U@W)3J->2]KUV.+=W&R$9Q$_PGI^?6>/,Z]I.JZ^92LEB!A)V
M8L!OK>WNZ>I9(7*5M$W6<)HH\<HKK8?*!$_&,93C^-+BY"C%?D"LC+H7TKA9
M`;L4\5#!4TO!7A@B&+MU(1T]F8"2CEK`E&W+8SZ[G'LF"89]4Y9-O9HUD4`V
M'U_O!PBC4,G,I_J[9#/[$\.2:^22=U3>S;NS9UL<J0H`I#<SZ02K&9&M8*V9
MB<"K_+W*D%QYM4M^^-I^1)#0D8R8/Z6%CEYR;R&W13172D%#6S8E,5R"@.-T
MG?UE2]W9<9Y3MU[@.61NQBN([:'.V`+HBH.#[B4''+09ANXA`=!&$_`3857<
M82,`Y,@0W=W1[9<"*PSN3?OZFN!NHH*Q+FF)PH%8*PO)!9AE(.WO63`+*GG@
M.2HI*F1J9(`CA;@VX5\ZN-'H2?.I/;(I(^*`60RT&>+;"'ST7W@:@,.\[BJH
M!#M+IXTD_`2YTL2%ML:]O`"QR<(L-/V]?V=#H9UXH_IJ),[L1%30<$-+4=#V
MT&!1XT7",-]&=+;H921UR=W%U26945_L#*/Q5Q\!-L[Y-\#Q__=0VU2;P&X4
MC#Z%8U%TI3>Z0X!!4',O="LLN*FX7&?=UE8(=GL>>3VLT.E;(3B+T6J3>]DL
MYR8L9JX;Q61A.<4W.G`$52DAL,VLIZD(H\J9^5?'9MT;&39+**$@>U?4]&R^
M]51'E3A#7<!5KI$&,E=)7%!H!K?ZM1^TL7P4OL@!;T"+3#]<^7)(.XQZLNCY
M4]??M'!S'G5P"PN*S)UFXV+KFUEBZ9UE@I;0G-H8DJ+?-96;(9-LJ:CI_='B
MS/-NSE^3@[XX<!0Z&K?IB@Z[GSNO,SAQM55'LM10X/`GPK]#L<\DI'M,EW\\
MQ@I39N]4&3:5,12RVB.ZS^J)#:#2//WF0V9G@CPX7RY)Q(**[VS7]E\*)R4`
M-L$I8-GD$%I>;+1S^N-I#"J<8`1\YW2%72*<"CHL%!]5@>\_`XBB%0M/$TF3
MGR":=<:W6YX<&WNUCE5B3*\#IRI.7<5>\MK>LE>\FWGO0XH"?^V!QO%/LWF)
M,$;-AEU8\\R,P!DIX4X]B9,R+?8V/RN.NC8YR3%\H\BV0ZS^._H)_*2/%Q8(
M;0O!H"<C`=GZV)N%)]%C'[TWP9VIC/8;S&(-W-)DKN?`-<LGT]>`_#(1X+#Z
MR!Y5:)):C$A^V`FRN&NL(R><]*G::EPH<TZ+0G&Y)+#>P\`)2.TIP%K#9W*#
M\3&1<]I'=VJ03OI/_**7]>PB8.'K(_@.?,#NM\OE1WS\*CCX1WG0T)LM-.J\
M0TP)I[B9!,W<:ISFKMOTO/<AZI+SGOQ[L!.R78Y2R<LRTQC\X#^`I9-=:(/<
MENNH)RH9;I]WIX@N2R"=UKT]]#%,YG8^",TA!$9=OH8`OA9,&/,ISI;]U(GA
MSQAC#=34/DH5"<.;MIT#7*),ACZL'RJG0JV,85*'BQ$RCFUCG<A($BL@?K5M
MT2^2F*HQ5@*%7#\2&G<`&AON_'%@\XD7DAZ(@@A=C!Y;"(XVY,Q'G&5#U-AB
M(()12!4"0\#P;KR='G(<!(E)^1/EI)W3SINFF;%$!9X;#L$\O@]&I+X-_1=J
M5I=)#W,3Y199J+@C:$\Q7WZX4+ATG4#;CVSX'VX5T60NHT>-[)66*>K(>^W/
M30)_E@8=;@?"M>B_QNC[)-7`Y9(,G@J6UG`&F[KAG-3\SG%LZ)F=Y9(&R=>\
M`NJ,;:+:E&02Z0:WGZDI!="IF""_91.V"G0Q!)EIEPX?=4`45#EPJO"?Z<@+
M[;M$_:TG_$WU$B%R>=C5='SNKIQ![6K"B*"P,&L_K\F"174LV!4*P'W`-5RA
MOI4/PK`!Y#&P]FONN[+-M\:]^CD;8L0P/\3N8L(4!L8S]LN:WX!"#BIL_P>>
M>4SC*"D=>WSY'C<NQ<K4`)@_[:09`<ZBO2KQ"!HAC[3%R%WFT+T^BN.JV$MQ
M_CI;<MMDOL!-ST]"2/;1_:+8^A$+O0%8M0:_N'3`5&QEU>5"I=D0&!KZ;F)>
M"1A$<>&TN]J"K_G.S;_C@-J[38V*S5H-.;**CG!N*U=1SB"%$-BRVK2BB*2_
M"".#G-]_AHZG2/QTEL.RM-4:*VA545A5BD1%(O?.+])FP\OG<M?D7TB4#V=H
M2@BM'WLU$!#8&.-3CV.]Y9#`*ME`$^%PE-X?TZ%SD86A/ZO)OP"\F'^2%0D!
M_5?$W*.SI'*OK3>^"^<-36-G`5(=4SOP;1>0L!!=^*=!_DS8^<OSK(SAFS.`
M&?!6FB#)XP_VNRFJ*3I2MIQ1GSPJ45&#T'&\HU9*KS1K6]5DCC&[C9I$H?E-
M&]*OUF(G$I\F8^/A,E9@A(MD.>2XL!A`]WO&H7])7^TUU-)P-.0"UQ2X>B*O
MV[T(XTJ2ZM[]QC5.O0N(WTO4`PB0ND>J;87D2+6>M[M-H<S8K2<7FYA^QGI(
M8Q?2]()M_>8E3=LZ9K7K\/4+8(./$;7>5HI%Z:!?>>"%'H%!U\QUQ%*O*4?,
M03!4<0Y_--Y6P`*!=ACZLO9LU]ZI%D$J7T]U6D+X9S`5;:N$;\J7$EBH@5@V
MVBK'NW]JL$$E-V4@`V^YT_C1."'3ZG'D4'.Q>P2D+&ZO_Z[K<O@0ZFGG8A5G
M'?D_WZQX<*XC(]\IE'!<OAK<0LRLVJY$RX1"*[H]2.*+T4QM=61_1A.`X"5#
M67;!`U)ZP1YHL2]JN+)IWIGE<_]ID87Z7SSL8Q1U;^RGWPK`37YSX$5>9UI9
M;><+K7<^QOC9%X;[O!$:/OZ_<0HH=,;__Z>M&*QCR<C\:'LTZIN&<BF#[:MJ
M^>KD(D'9;K7(VLO!X>B=2^)CA$"JP_TD>Z3%CXGWL@IB7#!SM>E58')#8:A\
M?L)1?RO"=NN4IH^/?H-IP'MO#^W@H;L`X?!^UH\A:=.&:1$2<3NZY1Y-A(3>
M)WL>V`IH],3O:Y/8=<TXC%+_+OG*&<)%4VJ\#&1BMTL"@E+$E*SV\@'J('GQ
MOCD?`_?O._$^'():(QW2<TG@#/_P<PII-;0,>*BDBFNBM;BO^]+):P^W7F"E
MO%/#U5.+(N`NKPK_Q3AQ/&@5L4"AD7LN`42\Z43#$Q@BR/H$?I*8DX"HHPM5
MCBSA8H?8K-6DCTC$'GB7+_B.F43QGR<;G@E#U.K#MF^&Q9_R:%#@;CW+'>Q'
M@1R"RTCM_C[8NH>[32<"]C;+SFCW"`+V8R(4JSAU<.[#\JR930."$>N%*\$M
MSP)@=9+]_;__UG<&_Y<M<S_Q%5\K#J5IGRJJ.4:5(7QFX(3+AFLR&S5)0T`S
M7_F>HU/'0]AS/,[+>JJ24.0/(;O\5A4WY+I4O9.K']0SF58,:\#Z%]I*XM4;
M1J:3QWZ-H>%<N;W`A*)R'>YH2M=.:[!8JPY3:XYS(K&<7,6&&!$VI:"L'$)+
MT01179&(7LN;Y-#5=1Y7:?`]0400XZBHS>9O7^&@N7P]5+K6L01B?K^R*J(]
M.@^%3CL'A?!WP("\/J^<*B=T_L]ZC*#IJS7S/<Y!M*W97\X0>FA6=6C[^YGD
MAM66X$1S!9*O3`I+V6A23X&),BC^FI],$E(S`RH80,#"3Z6V'4W31GK$8;$(
ML0\HY(V-IY5M#=[`YI5.`43HD2Z5(NHUT16KEA4LS]%&=Z+@-@13:)-6@U+^
MJ8J'?9/G+G)H>_AM^:`S+]-\#JW;M^JJ\4I$3XZ$CUE?9R=CN^B3];Y0/G:#
MMVL8Q3N(:B\,C)2!2XW.L;WF0<UQM6'-LFRI0Z/:WB,GLSG=!)L:"K@#=)65
MK.4N/]&XF']"S<0[E>--^>?[@`&^:TE@3=255NWS=_EJVTWWY(D)KH"UAP8#
M8Z?J"<@M';&6<*"Q1$LDO8<5G;74<`YS1)ME)CI-1`\YE".[D?9#T^IK<3O1
M"6)N>55RK)8N"1ZKP?(I8&_"C*$I%5[_2BL%I,Y=LDI]TYZXY5'BB(L`.NR/
MQJHANE(IL)Y!JZM6P=C3M/G@JB<V%,*5=B2DS^O`7)V"&0$P.R"?C#^,W&<H
M2?*W.U"TH/=]8M:@^[1GE&.#\[HR36N2Q:F2X#@I<A9?C;$Y$5"(B$U/?^.S
M5B78MD!W5,B!V3,I4HJU`)J?&G54AO`#Z<OST](LX]4$<!;W.+F>#P!=E_*!
MO<835W_'5)]_84@JJDZ';:\(_<GP64&_@Y$\^UDY17">@BG`O=HOVHX?^=V6
M1)>+<4]OITP&K[>:%MY*ZRDJ5'XV[P%8)<!IL,6M#MSTWD@.[[EO,[#KN94M
M9TV`19O;Q)(WQ+.@^#8D(>.<!#81[\4PB&+''@#R^R.M9(]V1*;AE<8];V]S
M+R)[^U1+C3/ZR6!0@?6A.IFM,?2$X*_1]8I-BJ>$ZYA1<;2M2@G(NYV/3K^C
M^?=,3GS_T0LKA`_F0-16,E7J_@[)Q/N73J;1P"N:6)/!^E_/K#YR>&14'X#V
M^30UFSUG4!KO\ACP7'(PB.Y+1A8FA\%SN!Y"XA*\%@G!@(,=XXN)(J*79,44
MGV'W`+>[RI)J>-NU@D'O%0*L69M-O4.([\<3V2C``X.G.U;W""'3EQ]TQL."
MJ%'OZ2!:YWZO3!^K$P"GX#)K^FLLNQ0.J8,E[)QXM3/Y!RMW2'+96XZX9LW%
M#S+&Y[@ECX^]4CZ&MJ6N^?ZCZJ%F:25:D\U7L'N6FGU-J>)Y'(UAV7N2,6G^
M_Y78UC1W;G\S7&[TCOVH"??T8ZWF,&999G&`VU3SP?++HR`8>!9(D?\Q0F/M
MBB%+^R`7F+$!3DV**'1/9CS.`IC=HA/`Z<N*-/^BR=(_<#_RF9KT7&(1$6QU
MT*/S/)1)NV=M[CYB-K#NONHV(PP(0RE`A1&#E8P3F:`2@\7Z)YYQ"T"C<_;6
M3T8.S83$FHM@ZH[IV*2V6>KU[+AQ^OC')OOP:74=\O>^T:-(#.?R`WBL59I.
MF.3^E!'PJMR&#VO$DVUU/3'[>F80[VE=LH;6]#@*^Q*?F0"`$$`KVF1F>`/(
M+^J#P("D)TY-9MA@*HX]5M2'U)]-O__&O_\HZPR"3KH#=&I4A'XO<7W\/7K^
M2]4[2S8?@`=V^&W\OZ[.O38E80E5TEW'=L\IPL2M'>A^7)R2<032#WJBPW.A
M;9D"!)J&U3QZV?5!G+(\H#O+%7#4?K"$R6DC*!EA[J,A>9@@K=:9\W^5>:0F
M-UV.[\,'9<%4U-R+DIT/.0(-,T7B3%/I["L^:,OB=,9\3%67A]F\<9A4I59L
M[W,?7-Y>)-J">_6_5G3_#>8*"NF1@$Z$]"#R!*3\T.U=[]D6=@1D,T@%9]P;
M3:RHB[P!\N8:!G.FL-J;[%N%\RZJ=Z/A*J'.9$L\@LX5^MQ9Z'%3C.'/>N<2
MY/9H(U[#=+RC1)?/`(J]0?!"M`TYB#OP`C+!OK/=_$NR;"1)ZY?O^@SBIJ6N
MP1[3DHN_:6?`6DK"'2'8@"4;H4.VGKAOM(S6Q=B43'=3'OI6K9<!K7&*IGT-
M-;B`>9ZQ:O':798,W+11I7)&*`N2>S.6#RWS!,2!&F]Y]KKT*W_G9F(F]#S_
M)0GN:ER88-T%((O(#\EGY<:'//HLJA.P5];,H7HFO:7X-Z=REHM-L0NMKZ--
MIAZ]@7W35MFM=K4J08E>&?@.]SP0H^#(2TD=AYX]_HAZ)#UIX<,=N.$'\]Z-
MM';,91]-IC)$$O^L;W52AS#R'A[O\>(*?A!DCR.<[(])*IQ+`4'H?``GJU$/
MHP?/=:#<S_487%[X@1,:,:^GBSJN06PEJ+7/N5]7MQ<*"5''Y"^]W^5^QA:%
M37W7+#LUY=!FR_*4`?YZG[4*LYP4(?=./EI9"8VX^:_]/H>R]N8X%5B0V>0>
M>D>Y1G\BH56PL>C:QD.NZL$<AV8[I<R.8*GKH>C<EQ=#?9%FK2B=4)D[!$6=
M/YK<3\L!`F>^#B'1SSRM%6I'*H4=K*(5,,+:"+:,(Q@%$)4>+R*LQO_"P)<M
M<RMK5G<`;;-*2H,O#YQT(J.&P8AF5XFP='9A[$#2D%?-8G&K0$R<T'H"C/R*
M#'P<4#B9W1;J?]?XZ6$IF'-K,9A.?=Z_3H0[\7PL8L#I=I.R5WLI+Z*25R8;
M`LU;]@D,;>K-+,+Q>3M_GZT3\9$;_I8W@RH%1QVN<+^OU@J0W]6<CK)V"9_$
M;G__J&CY;F<'+I*81B+EB+<T5':U3`K#%XV>`::`\XU$,H?!"B-+B(CH8O*!
MW:\FJ@PN1_L;:H+PK@C-3])Z?\E`X4>9_9QGO7B#LZMD]^TMV:BOH_*YD\D=
M!RVPBV^BOG_7!7_(S^6(0U)ET&,55FT<KN]HTXF!P<OK,&,-TO)'\_H-)>;L
M"%F4ZAN&<NMR6PRQ3&A-/F[P.[K5SV\TP1F%-<MCM'\'8@V/XHYSC[0\%(WL
MMO\/K,3?OCB>^2U]RH$8*U5/ANSJM!Y+M7EKP-=O"'PB<-CQT6UV,8:5-7O#
M-Q3CTJSL:7H-<8X-5L'*-O0=AD=7$/A?_7$,A%0_Y]*WI`R7A<VJ_VJOL!H3
MZ=NQC^I74=(.D$6].90.YCH\-1D@D]>*FB)O]?$,)96"NHM+O`T(<M_(K:OA
MAT-X1[Q:I;+IH`3V68(B2*);XB=8S]L#!E8XI4VOUP+]\[UCZS^F40=#3)18
MBPPC1#1"]WA^V=$\(2M0V9O>7D:>C)9;]9VP!IRI&!U^!K5!`L\&L#\]WMVN
M)N=)BXA`!)22WA2@,!@Z/*&L`5L>B/%A@*;S0:<=I<NG;L7^P>TS%\3<I54[
MMK-G<:QN-5+;>=5>L3]BCNFKZ!F?QJP[30,$T../GF@LD&;M.DATWX$<(RL1
MYJ=3)O]$)KYWI`7G0:_#>4W%CQ'I9^:A`8;A7O$=V:6)#ZG?$=]&8VY%M(GN
M&3I/M<$@.P])\*IL]L<>4^7]6]UG)\,1A0I5*?7'',2V4$(.U%O6A:HQ4D)]
MX,?8'589YFR!48V;_TX+8B@<FV)+!?OK32YN:@S@_1_7&[`6Y58>U\YDTUR%
MYX=+,Q!=MPD2=?4*1F@)+[06(EB"?<G!P(\KE)#.6U2I"/@)W`W0RL^:/C5K
MX(Z/(?^,`&;_3N0`+FV^_#4RM=0XI[P*3K>](8V8L<GWL2*J$?09-RX0&B`1
MUI(9>:4M9NF%#PO(M*WI;6HID^U?=RI=G2&<F'-A<9&-.Q5A?LEO5O2!=&0)
M(U^]DU')SWL;U1HF&"AXY&8&2MOJ^(6?*JC^;'."0R2,C_1G@+&7JOHL\B12
MY:M0]*YL+\W5H]OMJ_Z?!BXK>'=J#`ZF"JS#OC\7DR72*JSL0VB:5K'N-JQQ
M:$3H@>U\7W6*RW5V;LKZZ6*\D=9[XT0O(0Z=6,!,-0?:`)-SJ+U2O:V0NT[L
M%^3F.-B/LKSEHJ3V[+#\J?P_1G0,!JTRC5I*TGR4'C)RJ5\MS;I^A-TLVJ7,
MFOI[\YI[0NI.Q6A(^,Q5TMZW4?5NM`S+#ZW^=^)ORU@/]W?.PR\!]69P4X\:
M#_BNHWZDYV61HHPTFRH"ZN2-H?3#VZ[Y7.7C3?J@'/GQCW!#5=B)FARI;G8<
MF\)W)2*EN=<3;YSVOV3"S)*C<TL:#4W/`(./2:)0H\ER:WM=R`KD9+;&X5Y,
M_;N4[R;UG;OFA"F_9,67(#(W$0OKCCA>E6$'A`D$R[/)`A_A.IV$]V@@/7E^
MD[-!^G#XV']Y!K:N/4HJS9NC?#&34_`K8YU6B6*&M3XY"$J<CKA?&93QC4/M
MAOSB=\<W<Z8@*%^`78R(67T_-1%Z@/<BC;*R:HSL%;!@(\;01<T+J[D4?"/R
M@!?;G4BO&H9<VW&MU'>=UZE*HPI,9R6R%4Z5:8"61R!V*[2'7Z(!S,KV?&"8
M9LZS@O2S>I!M,!LF?'*Q$@\+TT&EP[BPEU(\-SDPSC_ZT_=WN=_\HI9M$1JQ
M6GF(&0')>\E-'^Z/(O*^!GUWWN-'#FOR^B?QVIK5S]?\M$*>+W50:^)C)NKS
M$UEHR5-0M&0(K'A=Q`-^^&DS"2\,V%H*]-@'@Y!Q:UL+4XD&&E^(SW8JJCJC
M+*N&;CNP6_K0>#88-B,G(BZRGCP/PMD[H@UP2%%$D,TDE^9)Z2!2?FB>(GHG
M<-BPI5%YWNG'+]*VZT0K$-'U.S:]_4!;Y3C^23N;Y1]^E#+O#+1I6DHYS@1;
M19&FO`FFO,(_)>Y7Z`@9,]4!X$"@<!I()^W+.C/Y-Z#@!U6@6A6E6U7>3C`D
MD[V7)21C8G\K2=_+D#F&P4IEE0_%GOQ$^7U[`GG9P#"2H:ORTM%`W8GE6*,%
MP')=RA"#'AL0;\T7I%G\.VS>0ES<4-YP/T5:>='K]@X0/#@E]F,=W=7CY:9>
MV=7SRHFF0KJ:Q(R;NYBSR9/2?3S.S'=4GSN7BG"O*A5A?:+[7IG7<A"`MDAW
ME*>NPC3*Y[8%Z=71`6^GMNUP+4"0!(;^O,95:ETT+V?]LR.\SG=*&3'.)2:N
MV2,D\]!<&'O6AZ[RK&O,WU9[_XW/Q][(6^TW3RX6D3,<UH58.".6NKJ,-S#4
M<:<SHT>CPQC'VV3[LOKOJ#X0:D!<BZG&4"S*;%TW=$0^/AQ8P&0DRU\"KH^P
MY%Q:4TGJ!.)2*73,,[K/9RUNY*G-T^L)33P.R@LZ`K9L*^J'L-;N.*QUQ$C]
MI(DY.W&\6=`)(-DO?2PO#='/-%OF1CC+OB<;K-K'K-)/P;"1<RW!1HDU5?Y/
MY)3KS_&?LC_F8IPQ6!5F80:>NII^<N>M%F$FW=$<6"$E)-2[DV=O%41%&_^7
M&SW]5;4SLAL(&508?7%6V;).7[1F*E$8P*&O$'8')!FY?.^_\^2JM<L#N=>L
M(S&SJ+(G[)T]N/F]W":7I0RF'8EY+ZO[-8`TR&WTJK)*KIQX%,0T;;6K`GW<
MS7>V.P;[JR2LW(DVZ/\7ULIEN"=,_EQRLG3,QX%$U`NM4^:QRA!EMP$7M+%;
MBAUHX':JGTA4^T<1FNJG\5#X]J5]F/PJ&]^IFTJ:-!%7,B!PA%7K%.K_72A_
MVM[?:6T1>02![QH$0%0GC96)XB"`Z"#)**!.W]]-:)Z:[6I4](LF+C*ZM#=I
MW"!8*Z#K+=!LT<U.,],#+51XG`/[6;85(,_7&%<^A#N)+W,QRI/96[XACTI+
M'SJO2N2L[$><6/[X-.SV(G)L^&+:CCK4)U^.4;XM[.!7]&_<Q%>O'.%R2#6_
M29:&^'#IR].S-[L<>,^+<J4$4ZD\_>:;QU/6*&WCUQPT:8/,!^>2/QU0'NP/
M.$1!6ZU;]AH9]=&]J?$O_10)BO=EPD^<$):0#SU!J9^44]G:DO)%"UY$8JQ,
M:,@TM9BQ/XM7*L<T2&B9!_U]=EM[S_7$V4AN+@<^D.[B\%P4:/8'/M/F/[7)
M@RP+19Z#N=K&G\\`U`+!YO8[_7'/Z4:2&;;BI^$#G+)]`IVKIO'YI!5@B,1F
MH`^EM%^/B*P@XVC/$//>6FA<05+Y*W[!8#`LZ%'D#:^U.V'8WZFM=.&PV.8C
M_JVDJI=\V@:D<<\VB;BL@?B\TJ%6DK`/4<@GOW"P[5I1U=".H2`'N-=!"[+#
M#'FA8*%N&L#;*(7E0<KQH]AP[%,V994L14R\Y8L9/<!'2K5==A_LGT!F6)%>
M`)<DI3BS;*%8MR$J)IK.);F]Q,\^"U$GK0_:]A#BE'_;\TWF$'"-S=QTDD1V
MZ2&J.;24TIDF'59R1!J2I;MBK(`9X!@,IRRD%S;<-]KW)A]V,HL(`F6N:GX7
MB!5E!G,FZ'F`UCJW4TW=W;%V19_<Z;07-PBK9J!OAC-7Z.^L1;:6L884J^K-
MTZ6MC1SRPP/$/'Z?2[4*[&T0`IBNX;H)OGZS.,<7B$0#8<JM)\5<\QCCXW]5
MQD#O3$50*0PO-^'J+DU\;Q>\PW)99J\O'A(Z-$QAWZ5I3OTELX&;A`L7IKTH
M"JF)C&`@?006`]GT.$>L4_;6.+VZ*P@H'0LB%8"S+_N4[5Q+4\=7)V5.>=WX
M`K@%B,RN9YM&=;2C45$8JN(-KU3Y^__>Z,,'O8RX23:962'Z,VE5?:N(1\D4
M=NX:!'6XOO.O';>OQJ$QCTU[0=:*FVU"UJ(8D$I#U(XE^W&#VB#(!+*!)M@P
M\S&4DZ#%/PV_`TU$>B:<8DSF&5TYD[59QD:_&+MZ=I-=U4?L"Q4P-EEXX_$#
M]0/7CV#:0/-$_U>4D"NX"L\,-!>B\<M)#,&A@HU7%B&(V3N=T,>1Z0LE+_BJ
M`<(H+9;`UF8G]I`*K]2FE\?UK2JAD>VF^ON-2$!_N%];PA?[CC3I3I^/05F4
M@(PJI;;N;6Q!BKV!.+MVUNE2W?:_ZCB$`2Z=,V268C/>"AS&_`O[_-]41,D1
M&<-=&#L-A$JY59[<T%!XRTKAAD"\G-+NKS4R1?4AXNRDN"&T&VV>TF>7H[7Z
M`4P^YYFA-5'<8LE:-W31=:DF^AIPA.UNF"A,YX31U>0-#B>ESZX5X>TA9FVH
M&K>;.>*X_<_>4%$3-B,:;1//>V5^%G*+V4@WTYB5.$)(8I8<TKW1>L$8Z%.6
MNZI?I)K`+$(W,U=K@!R[">I:TR*1\E+Y:HA6LX7?L)>TPU.USCY.LC_<R>RN
M"R?,E2H*Q:04FW(\=+YZ>")6-0?UI%11UM=JA%=0UO[BCDO)L48-SWJ]J,TT
M3+@M)#"SIP#S;K`WQ+C!3Q,YKKO.^PJ+Y29>8#A'>(`N?6J0!A54&'ON:PYI
M#<)!NE9\XAU(8\=<R%87VP3D'`5Q@(M^39^[Q`94]9/=8MQ_THQ]\:2@WX&A
MN8$E)1<@Y2$;2"1-&%%;95$6.O9R<#`HX;@3Z#WVASKR:'#]:59)II[(LBHH
MPOR^>:K9..B>FW)>%1\>!_/7O%63'#?6$U]76AM22<@=^I+'KW`>%>Z7#6M\
M*,5:GD=8"/B%K&2]1MZX_75QEXTD"K!0+C<Z=QE9_JZ+"KG*;+QRS\&']EQ+
M<Y-2_DLCS2C7W+(("KS0P/'7JHZA8]R\-`U(A.0J7]Y@QK_-KR9'(+4HD-UX
MWO:-QO3D[`JK&&'G9P$4/E0#>/MF<:4/+P:AUM^32%]$)DBU%@ZG@O`F24G>
M8<*0O"CK$A@5QK:*]6V;X9]8]1E\-\Z[CZ.7,M@EYRPN)%OGV4?MHU7PO_J$
M/ST.^.HF;.AU6@//,H;36`N9DLK4UQC$K84K'//D&Z^W;N&QN=SWQF+FA18E
MN;1@8/=/^L_S9RLH%7RRF/#9`+XXOO3"ZB:ST9V?2>I89+F,C8MQM-SJEYZ?
M[I0WX<+(OS/$>VJ[&^B66@-;F)0BDF[;8\F$;E0KJX,Q:FL55,5%;5-U\42W
M#?^*VK.26XW3_Q1&V'I*/'%.0?U7VKIF">EB+4L_CI3(N(Y[TT5QM-Q3U</7
MXK)_];$($-)O3:+T<5;6]+_`6^],:WA`@AF6CN8'2AY.#=F6J)=0NH^BQJ\;
MG\%44H3_B2J)'$H6VN[T*4':8`2ORW$ZSU6`'=$/K1MPMTUK8LI*=YN$0TUM
M!8)U+UR;R&'=RE&*#/V"C^]F#F0+C;UH&W!:YTIB1%C:3(Y1VB&H7OKHI>IZ
M,P%J<?*HMUPH9&V7@P9>LD3$;W_SW0=Y^D7!]+UK;\R'M/KDZ4H4@'&,IZ7C
MP(QB:(?PO-.RDB;6]Y%81S>O36[^UJ]*8SQ/@LE;H^0>KHAP+09&[7&#(JL]
M4JN5J(O_7'D;O9LDTV=B>VRF=!<$=Y1)XI?DY#[-<I!PE,'E@H!428;IO:PT
MZ4!0.WQ4\A<)HD<(\2D18U#&Y^Z$$;/]#SWZPQ(UROT@V@7J+H16`#$.**;T
M+J4A,ET\?#[+!T'%,<W6B'#]$0`;,'4;]"W;D&O%"%@4!&POLOEQ7085FB-=
MO./_IT/UBUG?Z4RK"SE#,E!Q"25U>/C:I-UU4Q5]_WF[0%'>%M1G,.Y\N.TU
M3O%-ACFA@>=L<G9`"@%69*ML_R424@9GA<E18S!UHR.,`E6@LR[[^2;T^26P
M;S=.TG;"M"KF?!LIO89U\Y*\NNW=W%;'Q5VJGUL$3WS]#FSP0W,D^%5@)^<E
M[H;>?$71-MK+;>5>PK.T'A<X,ABO#**\^WJ\3;#0R;8ZY$`HJ]4$)5H+\(#/
MB^UF`9QNNPJ./0N]T(=N^@3T+4O-I.C56\K`#P//*JH=>00Q+F-!ASKG!_!!
M?&9*\P5(RG4$`J9D+>%;+>B?C`WM*1UL4/]$OXBR./X[I5H0FBDQO5@/5,-O
MWO=@EAXB?"\64U;%U:^IYOZ;1FM]^CTM"M#]D]=88'HRW-)K@Q7B)'9?E!Q/
M>LEQ*F?=DZB,+P2:5+Q$9ZIGB#<C"_,5341CFS9L,,$BSHP[VM_%X26@(,.#
MX>*Y/44F.M_W(>6XO#SZR#PC\X<-^KG9DLU1L!(]/$(CFG@+#D//G29TK0S\
M!UR(3)N*23&2_/F0\(J[)-";,/%=R*E"M'\OLA5IF%\%-C9@&UERL5B!PU#U
M;E_=6YQM1FDJE3'`N8<X[F^B-)8/\4)E<QQMXBUT'N\#<NLP>IQ2"7381KL#
M*O-0/FR1W./5C1M:#!DF$XRN6<<=00&8V:41`YYD#>ZH+I2YMG;_D<P+1;Q3
MZP2YCWXD+'V9QZP-R:`#2U0G[L3HJ/26_OZBHF]">L]U@8@W/18S_[C[5_#@
M0(-\8$BDOSS5@_#RB!X2;+_IMEWO-:!"%_E93P?A'L4CD7,N46OLN;RO$=)5
MMH$2+'17F,74)P_W99XJ<YY;9!&TP_U.5?^J$?"`%Y)_4%NM38613VF[\A"+
M;T&2F/]3TJ-9KRN.LGPIU8EP$M:Q[2X`UW1/",;98[+G!J9;SBG1NS=<RM/%
MY`KWC!\-;66D^(TKDDZ`>VDR(8%L$'Z0]9EAY[8`3,(SN"=[0V']*0SSH2S*
M+K81_2_!G@>IPI''J6D'[@MSXV](:6D<WTB_L@"]^&&-BRM!E+0YOK_)KW0.
M/`O/*5S8QJ<KRE/#O$QUW`K'<2.YX;R&>_A_EA66<+%PA\R1`2!`"4E]$J<8
MC[];HB#LA9RS&S8+MIJ6%%VXX/AU43>L"0QJ:`?<_P`PFNWK5K4'&A98G&+F
M]_3NSPSY?&DJXP2"?QF8>4.$;:DO1C"S@W#H.)H%3Z7EJ@H*>Z'9]W^TH+>*
MC5-;JESXA,ZBEV$K88K8=VDRRO^W"JI/4:21[(%DMYLYDA=7T-.I42&8@+D3
M%"I)?647^.#VR2&!WDZVBP$$J;V75B\'I!PD].CLNX*Z*<C!WD\J9-D4SAZC
M;(#)_;KX%[#KL1?7G>D8Y?#8.@-WX7&&WY`YV?WR$$?ID8&35W\%K!W.9A:S
MEZ2[HJT[8!9*,)GOIV`V!36[A$PQ*ID6IJV8(-P$Q5-""K8TT9J,\E&X_5U3
M;<^F:'_2/^.%MY1V]<?$`,*'S<YMO%AQC7O)?."/%?;+J&9`KE7^/9GZW6^#
MOWIM9T^9#+"]7<_-K\6EM\BW#?/_#6YV]]GLCQP1\VBKW7'4(<QZHMR_&*N(
M9*IB8Z-JFXTM6<G>]'$CX5=X;]O.GY,@-T3DEMK)R,$!3#^F#E:7[O5?H^[4
M>);&B@[!\)?>`V]=_\N3EM\_X[.H6M'^U.>R\?399YK&?-">`:#7E'%[Z,?&
M1#@F<+GU;_A&DL\-);$";."7U_:E+Z7^WC6QSR3(@"F:0&(1-A-JA!WV4/,J
M>H44KN?KS+V:D@NZ]*D,R4^2_8]D"'4N180=DTY0F"VM024W]\,0_A@QI9#,
MAC!)BEWP3JOP+Y;0:L.$DT;[YWGT-XR(/FZ/?0E5_(UX`'R%*!E"$JOL,L:+
MENP6\R+M><_6L%RJP5IC7=IB2`QN385625[]E<X)[3;R$$_M&!/#:;YN:LD]
M_1_K[0ONQ*Y+87(35QY+SI*6^C``=>I(NA!5N=?`QGLH+G8SJ:0+=RZ!:&EU
M^2S\A)N15'P(&>!:,>'.143H*L;.89RKMDZ$KI3)([3Z:X^%?;=&2$+P=U)W
M,>W?2N@3&T3HQF1:_J?VS2`@P?LZZ)'Q!5!+'>51=RN'%D=4$4E:3WYC^^,4
MGK1@(4B`(;A16+TN7`:!VY#<R,F+T-E$Z&*0Q#/KEP<JQMIAS5UAS=\7?WTL
M5<A0&>0MD>XF0X&6;L9)G(U8181_"%])H9/?,24A@$95QI\E7(FX]9I[24S-
M/3YX>*Q_CC/XU6=-,Z*@!!0Z4GD(,ZQCA2EE#U,L:*2?F&C]<VW@&PK=I6R7
MUU;7I$LN[?K&MRC"]3(@X3?(Q;A<L6B()/VVG;/?`RA6,SC`DD00%R_@V"46
M/_%U1O\]8Q%8V-M=!D<."9OF>&AH1VD]>3G2P@?6&,(Q8FW9,'KW;!R(91PW
MW41P1R:@(B4B1SRW3>9@78Q.":OO%5X2`5D&R)3K:O`YNC.OSFL92&:&&)BI
MZ9!ZS4O!;5$!^(KA/D(S&&FCHV1R]<>T<&HY-(BGJY^W-AJ^.9QXX^S;[W`C
M,@A*51W-V/%0TA0LZ\HF-;$PXKTD,U_C0>]A[/^$/1/HJ_8T-[?#8BBW#S7B
M#'+?+M03W<:J.W;$@]KO$`LG&XW#E+5*RB>CI8ZU3HJ]1*DJN?ZK\1.?MKW'
M@#?A$^X&"P;__ZLOC,"1>(CY&Y[9O#]3JS=""N\<F0$K>^2;S@PAGNF*/%NU
M=2*5;D'<8K#"*QG,>66C7ED`#'ZU/$*!*M[_T^`IP-3:%`!YIN/&75-&K:4/
M_N.QP-DEYX7\RY"'1ZA0@I$+HIZ3\N6'@L^T-7VXM8X0E)N<\`5EBTL:[&%:
M>RBQ=)2<5>O3XUD>%[P3LPI!@HYY((LN&_!2K83'RR[RN!"9*'J03PE/0+`T
MMUH5CV&%*I2BE0S?WXJ"``O",2>B96IU\J&V))SP7B.#A%T5B)>`QECG@2F,
MSBQ7*=>O6'4(7,LS^`\!-)A7VH-WZVC/:XH7#/X@%UP)XA'PCXTJ@@WBUFA6
MH8I;X^GI61]5=AA1/*3[5^SGRKSWE_.SLXHRZV4!<_;MR,;.H[">Y+WAO%\&
MFZ*@5G.<\X)SII:V'GI27/`[',OSP'*P:``4-_]/8]`V)D;ROLZ&(&YAR[2N
M]G/Y+S%Y2/^;Y$BZ*=/!]T&LF>Z.'M`85<.EO@/?S!#1Z",8ZPN`JJFJNAA-
M_ZW@X'1.S_J\!4-Y'LB+GEN]0VA?F=LV8A80BU0:*?R0#\GS'9XX>$HXAJ>\
M0XMI=U>PMX^,GE)Y,`H+NJ/<&9I+Z0^=0I(5!0UA30T;^Z_E":F6"D1G5W*S
M4W$TZZJ61O<4&(S$XY?@"ZF@(*^80RL1X";(L(931K8^S>C^^E&C!7CP$/U?
M&C?9?OP$XE*LX;32W,],_GRGB8%KL5=&%`K13+`L^K8/VM:@]A0K]>%>%BQ"
M_N8:G+(]Y!>QTK`_<9D!/U'Z\!7(CG)@UM>K%//3PN15&)4T.'$*U\Y$TEUK
M)+WX+=YG&<T?#@TCG7J/6$40T87_Z[<AR/W`5],VOL:+%]I>3]'V\\S(U3^$
M_2VX#]8G_-F[*S08T_SF8E(X)SY$ZK]O"X)F=[VD+!$S$*%?>`*DP0$&#[>I
MT9*6B)9&T8[G32%W-'QB$R!DY0S)^)7.SB,._])^^U:U,.W7E\:Y.$Z3RR#9
M4I[95-)P=B6QK?QN"5(+R\8F>V2U;Z+O\2:7E86<!?*)%5A/1KG]A*P0[S)B
MG.4OFE<0W<=%_(^;>SV\]2($DJ';<!QO#6K$E)0BLC?P"/^-3B^.CX3^D5T4
M$]HYL]J<.EQH?N)*?0^N/Q!RS>GEY9/P%-:NE8$0=5A_?V6(N]K/0+'?/IY/
M'82U15382MD-)B5'/OR/F%=L^1Q5\F#VN,YK??_DP.?DV+Y@;$(4#]>S)V+&
MW;9#%O$`<A&0D]XDU?5QB,B&[0+VUO]`(YJ&2Z%UWJ$\8RGJT\V62FJ^H'WR
MMG3Y`I"W0.=G$J(CW\5'W*?N)4QZUR6'8Z24]X==XQ6W&&U!@$2@'Z\M([&%
MZ(VD%N*YIDS1N?#C0[HZ`RP9[MXON1`FKTIVBF7E/@8Y0@4R).L<!XMP1[L[
M[X-9W'F,16=2E.ICA[-;]O^U*YIW)RJI\'EIY.C8KW)]KSH*NQQ[7B[`AY.+
MI-/O7?.C;"";T/YXW,H0]CG/9:Z;1:>W>W\M0?G$29L,9?^27O87L>P7K*H>
M]D,UR#QN27IHB]JPD/2,@2=4M*3HG$\L^E]X)F70Q!)Y/95T]=8TY?7W+?Z?
M(S/;19YFJD]5>SD!EF\YP^[O\Q\I$-@4=5^M#50=SW$S*GJBZ+"VD:C0=+$_
MG6O!-'66BYS#L14R"8@,<'7NY'5OJO9VR9K97T'EG*#K].MNQZE?Z_""^*W\
MG**3SM-#G_@U+[Y]-EGIP^O"+KGBYK`[G`AE%,%IIKPVC)U&Z1"_[Y0:*SO<
M4ES:'Q>9&+;"6Y2=H-$S.$KPY%Z]:F7X\+K>D^%MPO2]=5=$R6?MY#C9`DYL
M$GL\-DN%=RP:1QWM&WW]YVA^Y/`V$$3+%H)%EU.:)>SW]F^@;Y^YYJ+@^B8N
MF.`).W`#K5'[9M^A:\9AM]C?FL`1H"D'+"6Q-D*0UP0DN"C+8XT3EQ>$A?3Q
MG:SH2EU"]+S8Z1T,S9,U/51]P5"%U:JQK2B<VE%S-H16QN3H9V#,42PMX.9R
MI[BB$:DS2H`F$QX]:CHRNWY;H=*KF?4J)`?Z?[RNA*'Z4%.\.L!0@K#27#5C
M2`*F6:=ZN.:/6@#]#<1.]7!-G563UA'`'A'M+0.&_'3I\BX7@/>SN?)=544]
M,4"%Q5["C]3,`/Z#N?\:]@>.SVJ[*Z=[9A+$^!Y;`C3H6[]4,$L7,@4A`SBF
M:K"WH=J#8%VA_7IKCB1Q^/3DW=$TTKZIHH48:0@30#\^PS["+/U?^#5,_LMF
MUJVR39&OX>K'WR-.BTWX"6_[V`K)S'L#5'1.F1\>NLSR#0@70V>)FUQ0%SR5
M`\Q-K(-ZWF>[DQQ&UYN1,.-`(:&I%<EH*;3OJM[A,UD.QT,-(TU;%,V%\#[#
M,4$]%GKE>`\YHI`+B0H5T6M62JC_WXNS^$;I^O^7$;^&7^"&KICNFG7W*F=C
MI`?3'$36,<7-O2FDGAAJV(O[%)<+KTP-GCG5I0%)\2'%&*'8*;+F-F_:3N6L
M`E]#"8K.X>G.[L&-/]]=(RB$],#L\H2$\3F.$!EDYOX4TQL!:%]\D:7^K+BF
MY"<NL0X]NN<XD52UN#=NV2S?I+?]GEDS9(EN\;@1KRR^#**V:<I:%#CF?L0?
M8)$[KBAZQ/8./6..C/79^H$C=2=)RK0XX1!9DJ4*99=:VAAJ`$/VA7,$4O3S
M.2DH:F"]E@J`^%:$P2'JNA.I]L`N?H-C:5-S3&+&R.(--+2`Y-)-:[_7`T,L
MD=I/+"85QV)/[!MD80ISI!L"^"V8T`?VE,%INI2(%H#F9F&!=_KX#L>UT[ZS
MG4HB7>%/3-9B=\EW;.;[#K>$HRW."7'4^8:S8KUM.%_3-889:S(S-2?9?;`.
M\)@=`2X$B%N[@$:)[:EQM'5_#2(]XNJ\H&3%"L%$YT+6<8X54:GX],LC7^*0
M!8WF8?B0F=AT;2B`I`F2H)[C1-L`+N>6EOKY4-OXS/^CGO[^$@Q>PT=[.70-
ML3J^%,8MA<V0VD7F6LO/5XOGPUUD0L]SX,_<LS6!TXO:./.,)CH[9TE347"%
M]*_Y;G1H@0Y_7T0V)P_F1Q4$VS!$?AV0])=-$RQ=UE?BE3D`)[6Y5,S!6@*E
M.H/#^C7]W.ABIQODQB*8EZ,(@%F$]L`'Q!T..NBJ)CU8G1VQD3S_5$M0FQ)J
M2LAW6-#^9R2TD&S+M[8BRMS+Z\;+T/9A@NV=4]FX%EZ%ZV.3$*W.:-V%;OJ#
M,%D-)HAL[>U5T*?;]5.*_#<_DS@>O:"MKX1-FZ,PF*)Z7#59V]9_L>Q1"XZT
M.^ONI/`K:%^*T8NH%LCO:,*^S1%<9,=$,W78P3@+:*PG.\4N,P)JA2@7Y5_7
M0QVJ%ZTKG_3;1$"+%-"D/;T2/W4;)PZ\Y?;JX*A97+-:@F*D?@NX>)8FOPF"
M85.!RY[(Z&REV`^U>G7<GHA*4P:J5RVS0HETWK&JJ[^I1/EA8<;#"[<:;*^#
MQ3\1A]N_2++,`(I$BO!J&ST.9\<(><D$#&*NSQ`KX3\.<V$C/?BWS<UKV=1X
MFAGZ/^9U%`8F8ZD6LB71M&$AU&MR5\0/FD`^M>2%UIFW^@]-DWCRF)H?3%2'
MN:<76$X%.!%'30>DB2I^I^X%3ZW@*C!G"5>YU<T2#BC>_K8VW`DWUIGJ9!6L
MK:F,;&D,9+0GI?5,"?KI'F!&[[:_=[<_7S`#>.EUU,/).RJD$J)K+0%=6]+5
M@7)L:UD?D!AL>^83$?Y2(.FQ%E:703+?3LT!(-I2L:^:OS&*0,-^'_+63_FD
MK2G/*)7/W7,^=\!%OW-=B6'!IER(F;5RW=X$.@#@O3&^+42IQ)C%8YO4DT$,
MP9G_FH-*BPCD9C2@)6W(H:,GTCM^"L8,?(?;#J_=^QR5!VNH*5WQ)C@*IU4?
M*^PHCE$J=@1,'PEZRM%KAD0'%*!M<E/"J.\A_5`V'7IPI4U1.CV1.QTA.%@J
M?SR1"5GZE(/>O),D9ROI5'>-HH^VTV?H8$M.`U%F:1KN=N/&UKYG+E"CVGQY
M]_7G,?YV??^.<D[3;QO%DBTNGT.@(93U"9H75#4O;?6<),;Y47.@=Z4A_J6T
M0Q*O[308ZCU<:X0GL"4RFHQHM@4D,!2[2?Y"=8Z<2)\X#U&%NJ%`8S)"2FH5
M_=A_980T/XM:@0P9K:8773!.R!T0&-779[+-`KXYH.?3,A$X&%4.T[@O$"TP
MMC5A%T;/!9;H8;-D9)A7@$@1LZ\JBU<S):"RE+*J^H(/XK8XTLLVS0?E7CG/
MI3W!4;8VXB1]>:<>G^.]_3%ZSOGK'!;V2[H&42!00*FR7(V,3T0@B^F<-X?B
MAF?3Y0@G81/SHS:(I]7^G-E<07;8&AEE>&9ILR-WX*14JU)&#3MY6TX[@XCV
MU5GO%Y@*%M'S=$L#;]E>W\-I9G:K&!<?-`,2I>8"1Q(V\PJG3]+$\@OJB>;A
MF$J+UT8MD)C1%WA#OW%BR[#WV04'(PUJ&3[DZQO4V$4,;L%S'P6G(33W;]WJ
MN8[5`T*/=-WV(IQ*H4E38;ZL5.HR*?U,*Z#.Q[;-$:KE#[Q3G")$#(DF&![S
M/24`!,G?VEUQWDP97-G`FI(]\):+_(R</4IA/R3W%^FP3H%D'<$>3FC4[MF:
M@_$U=H;/PSP8*+\T#'?"=AZG$)D>VKP&'30U5.+0&/>V5U&1G1/D'KWLGC;C
M?MA6C;8Z8'O?7%&2`17QQKJ:CZ$&?$!$AF177\O7`<HSQ+O&*QAT3FN\L;W8
MGV`F#QU-<=L=99?0Q3`DCJV+0:R6DR$[UE)=.UXN`&==-3U[$Z7,39V%]]B$
MN.P_KI'5QY.8(\8&P_%2IB\&Z<Z[H3OUFQ^KZG/N4D=)1]#G(?,&=VK.GU>\
M@/,]%P\!A8(Z&R)E12Q993Q6=[HI1T2-,?NEWAFGRTL6DM(&A0)9^!<\*+"0
MXV2Z,JM=B8##!PU-B%&M0Q`83&"T#\\+*VI.5NT9GQ$*R($Q-I8G"1>E@M)6
M".G+$:#X3RG]5:7YD@W9A=M,!5A5=01P<N?IVU>WSY[IH2HB`"PKS7\?X^GB
M?/?&(26O"S?#FP=X_(CX/66][9-7;&2]O&8VF84[I=#]BU!!C?$[YF.?//-D
M8<[)1L\D6R6?5MY?=M868?3ZD1L`OY>H-U!A#D;1<,&L&G;09VW)@`,.Q,W%
MGA7'6.2V5:N-X`[N!&M?!F_P$<'([A1B"',+TK*H!!`5\9*-+A3_2"HT_,KE
MC>\%HRMPC4:RBV72Z1!U/Z+#UJ1SUKE-B_)$;1U<N>1+2+Z,UTI*4.9RCV<V
M?"'1X_LA9N#,^2F2Z9:UG-FST/E:`[_Y]G;%@#9`YUT!@'YV+#1)MI<L^0IM
MJH(M-%IF2[0G]1]X)-/U-3USE-L5]QAINOS5W*:Z__LH3;4]KYY5`5C@4KO2
MI'ZWG,R3^-L?X#821H3/O)1`?"_M`%!)LZ*-#JU;$CR:*SQ/SKC1G<#E.4R$
M)6CE"[]:#>Q([#_#,2].TSBG[SY1<N`T"4)KCU#/ML5'3=!44RD#%^`^.^_-
M)\C,R]1#\T!;,KK$EF+S50:+JX5OW'W"G6:\[4%N8"+^0O(VIJ!R'EU6^V/%
M69LJ>&PW2[P9Y8B]`?F1&AGOU9;L@\%93>N<*Y-M>;3'EN$2`,%%MAH#RG&"
M3M8<8Y2@O/4,K4\\T,@@DM]+2:1FC%=0LX/+3.N1+(22I:[4O[9*PTC(*VM$
M_&4)S1%HT]502,,0]EX>A9;R$34-IU&Q,6[2/_#T,;QNA@9LNE,2MA`!U#HM
MB^S@@.W[WA24^*H*O"?T4NEBV\#&<":Y3!CQ5G<`)C1=FXS<-J>N'+>FIEV[
MKC:>)F6<ZM4]9N_L&U"/HGP/57NCS\/7>&H_+]EF3QH'#2U'^LP0V&D[WSTA
M;@UF"SD8L'<&27ID_>#[&>H6%=DIKBCU4,'\0+3X%>1JTM]HIX]+$0UW5UKX
MTQM-7OY6+QX^?]\(DZ<0,ANWW1J:N[S0A/FZ!_L&TQWULOS,M8_3H$U44Y&`
M;WM;^Z.K^9&&Y+8OKJWM8[>S%+XX<(?17YG<MG`5AS#.21NC8VF8>L]J0$V@
M5`7<*.\,_T(#)(MC.K:[;8/YKM0U)<R:FS)=OG:X5AC9?S`/4X*_VN)=5N:[
M7`U.+79[&_+&UUK*P?+7'L1QM'-D`D"D]&*H"<UA+X<P@+]0J3X(XG):0?"D
M8)Q\ZV5:4+=R+R$*+_3_J-2P=0+-X2S0\P4Q0LKE2#9(;^RIC3]$6%RX1GZI
MHXXL4(=%N3RQD[&Z.$1N%X70J;5HE'_6"J816+Q^RS$Q#[4=<)L=[,2XJFA/
M5?QC&H>>CX2]FJ1)A)5N_5XK-;E+)ZVSQ^FFZQ_&4^(/2[S^\<RB%DC2VKO.
M7WCW[^$G37Q5R)+7%G1?GGT=[1WQS/B@1"OG..&_BT42/QMX7@Q(*DY@-/AS
M(J6!PG1];>P^0=CAW2_3!-CU**DG4@6\*#D,%S<MU,F'TRP/=_QZE0PX*`(S
MRU?50@3:BF=O:M.5ERW3V0L;4Q`=O]0(6F)3JKR0"*OV6+7"LY<3IV8-;;3'
MJI\[O7&,1"Y97**6@DF%WS%*SFV*G$;!Y4ZI05Q]%@OO==XM[=]G]OIQN$+1
M'N0*%75U_E7YE^WT_)W1?_5$B@'TE)\)2Q^82'P$PX[66B:*IY>9<12B14'F
M%)&$)'1QT%N\="V4,S$D6/84?^^)#$7Z<A\^2ISXB0SP*P+OP,D:Y0603WHH
M).G[4X(W$:X25Z.9I>G.(&/2`;J$EDT2BC191IUAAYN<@M+`4"4R"B`N(\T/
MM"_J25ZA*P7K4-:E1GIY_&H-JVSQ<W0UCV==PP`5F)G0$20:\;W=$TZ+96#Q
MPT0GXI&[^W(C)'<*(IN%;(,ZF9-!AVJ+$$)'\$&7DOT9[*T3_O#TW7GB%%U'
M=6EWH.67MWC7<NT`R'_>AV=1?N18B$N9B:VH"`6/Y)_L)Q#6WBK!VL9#<@]Z
MB-OK+BK@Q^@EAE8""`AZEC]A4])/HFFA@0#]=KS,P8:*B1/.TC4-6C,?N<P:
M=!P\*_R^6LHH(%Y%I'8,+,3(Q#E?X-07X6I[QR<,;LE)LR`L[C<<M[F\HA#3
M\8.?`OYM`-_PB&SX6MBZB>US3.UR;&ZZ6'4YG(@6G)%OZKA2+V!G6@T3+_H(
M<&^XG!\^G-G+Y$=;6'8E(2T<YIC*@+T1^XRHT;]K(4,=W*)C>PU(*QX"%H(L
MKXO3YED40\K,V"H@J!K;_:2^89;/_>L&:UTHN!-15[\]G*.R^37JZ];/?-FT
MV@2^6,V2YRL)"$/K<3C6QS^4PG^)U9&:."JR,P8?8T:.5RL*$+Z8:O:0@D`?
M%ZH0-$FNI236RWNG^].TLPSUY;+=37D641J]I80OAVG&8]A[0IH2]K,^Z$[(
M300&`.,'0;I@D!HR@SMLOAUCJDB^<ZE$'*QMW=T5:FOGH6UK*S=$I%\L"L=E
M8:Q#L&S<*4T[L;9(+*<1(.4K%FG2*EH7RT-$WYF'QYOT!__0CU!3MBW,FF*W
MN<FA&:"*'RTQI/7G0V%<R][*[E;C$8V>Y5JDK7MST!H)7&?7[5].C"=5,QNP
MW\36>`6DX5<]A`_:[B:383B8$F8*TGK5YVOJ8GG8ZZ@2X,)H#Q]"2(0%^,R2
M^;@&%#ERZ7BH?NI]&X#3JYQ?ET%"AO7/`OBE:.SCM+YANAVT0X?\'[+G44Q/
MZ-=N_I!+)C7EYA>/<CJTS+LIXVDS?Z94A=BR$,K,U$6MEZ%X]O:$Y7Z]HI*`
MQ*H<>-P%-T\29):(`Y#&"7OB`5&DIV<2%=D+[7P,GTU(D(H/?H")H[KTMG@J
M^*#R"AM&0G^D5WM5<)C56L5B0!3#(VBJLX\6I9A<G,13!*E`J16(+XI-XV%2
M.0"TTL?%-R`[L21"L8Y`J4.(%_K/OPLZ0_X@;2:IRX1@_9]^YWHHEHH6=V,3
M*2I&&1;.L9",JX?NID&S\_IOPC?%1G!/\\*-9-EX+40&5+@J<@3"^NA3BPY%
M__$*/VOA2$<GP9JCHF]C::I++W3\)4<*WER3XC,(K)@B4U7(,7`;1%2P.$?`
MN`V`Y_4\7PQ`!-N2^4"%;11O'JF@E)_YVDS4P9ZS>$XNU"L4@^!`.U<?L[[U
MBEI/+@8__ZLT25]YA`C9]O*4;84EZ@\ET.:9,2`SZ`E]!-CW8QT6L)NPFE?A
M<HT-JN/1RQ*8<H(9&XG';WPP,%6NW#O_09+NE1++<ED,0A;+]XI37(M`$B9R
M('-:>)7:;S6X.4C!$.FL&"#$15K$-YY_F/P>BD_!`L&>1;Y:HJB+;Y)8'%OX
M2^:W9WT,8M;[7ZG#!)I-Z291ISYJK>L4'X@&T(*ZFOPJ"0K6>B*KEC%>S#RG
MD[K%:`K+U=%%J>BSN[>5^&&<<]R?DU8++(Y:/]TAO?0T"="7((>XW#%,-<`+
M[EQ[)P?V&U=9Y-75-OB`TI8M']`F)9]^YVWGA<YKY\$\>LSJV9]EF-O+R`C^
M@S$SA/WC*%T7U6N8WDZ!MHN1E_.>@'Y#(N5)"$8$*VPB&%M5&^2!\>GZNA$K
M.N\)$(3E.<D1]QGB\^R&V-9>7E\GMNUJ-REH:]D`IN[]<`M)!M8&";9JP6H?
M'#J&Q`UI:W_`23L:`*5M(7T2V<;T%%!BF_X18`8D-(=R`2M$7,1W,3">^KR$
M[(PUP1J<1]DIGTH.^@W?C.V47!SA6&_BIT"IY)F]%/Z.J^H(/;@,&5^<4"&7
M;Y'R3D=B2?+/%L_<F47$@)`^IC0.\E=[""VZ8'_:Y*];L7D-F!ASKCLV;1.6
M4ZDSU]1@K//(4O@L[%*N`7X@K'BL2Z]F7?9^?_+NLZ*TBAL^HK!M-YE5S$^6
MIO(1![:%,X)&3/)C$'>X+>&#4FY<37DBM"?8>+)2##7,.HKSE>5T(;;0_?PQ
MK]-PLURB+"]*8N\G@:?^*V;Q:SFM)Z_+TC_V;#JE`N7MOLL?BJ.:83=:#_%&
M]DE4:1#__EOZ]N1318Y><)>"<W6?BIY'&)E#IA5O%&-#V;QXD&&$7++#<K^=
MIGWV'^]X$#5844=5HCS4#2#B+6,#MFNX)UY1JE;;[#X-RD)`1T!!%\/OOD-?
MBQO3H'D51LV*,;U+H$C1R.ET.R%G=$RKU4>65(60[JY94LL88=BQO<`-P42X
MO@X=W6QSL;^32]SH?6A==%81^5N2JQ:9,XUT76I-WN%5>+Y@+FAYEVK(PL!=
M=E'%=)]N\U1D2+6LP$0`91JK^>V7$^\20\N"`T/H*=>8KO/Y`/SYO$>'E+$X
MCM7VL<"FD)\.+3T0,I3N-6QF+V"_6C+!#7D*_ST\%"Z.57]F?,(_[/D;ZB8?
MJ0<2<(=E*%J.5@W(#%`$>NTKEU'KCSXEJ>+[@">8/H<JK$G)&L2O<X5%90[J
MND@.?^EH^#ZZN!F+U,`^B/@(>/;B^R1$B6:I$H=JC2O=F:K5=12`L<[)K2HT
MNC0B/UP;PIX=$M%!WYZ0-B^XZ+PMAJ<-MQ6/M?,MM#$L0.174=VPDNI7N+.6
MK"EZ,_.IP,@:?N4-P9/0>E$A+8(RT&>;FB.,W:B.X*1V$3O7+ZF:_]KY(:L"
M3'R#\_`!A.)D4.88H*3@A=+0GL&>-IRR4@-6.>&L9O2%#=/,=IWKDY:`Y#*E
M0@@V:-4;$OP^,[Q(GJ@D/&'_L!)3UM<<DX11&"B"O^85L58=*PB"P)3;21=,
M<IN[\D<BP58?U,_Y#F%R"96_.,>K)L+E?>":/L3#JTFJSFS5G&"V6<_0N(Y2
MR.$CI_3,ZC9C5HQ[`8P3#1F:ST/O0Z'+B2-"7CFE&=91?2'7UYSEJWO.M\#?
M7G^2*YX$2#J9VOT?;P(1]1M?B"Y\B+X`6!RG8A)-GHED:B<;K.RQ`13CW;0G
M"T8X.MF:B`70B*XT\U*42>V;HPA'&R6QU79=<AI";V&4%2JQ0.$&AG02F;IT
M6F%.H#05X)E];U,\CX0`$G=<'S0-NESX]C)K;H58&\3E;#KN^,%-:-=ZI\SW
M(>7M';[>JVM1X/-TH]+T$IR,`@IS,H0P3I@$O5D</PK:#*XU,FF=:`<S8%GQ
M0"-@1:\Z`LL!]GKK95)SL(3'N;H@__&)OQV0P9&"(LKFB@7<1LOSA%+Q/LEM
M*9(@&B7P'/`DT/MZI`ZAA1\,F5/<T*OIT4_W+`>>^!OL\N_(]+O:3WG%@CDA
M&6S)9@4^8`UMVNWJ=_!7>)(9":UX^./6"I#*[Z2MPZ*G@.^!QA&;07AV3QV&
M0@@FHY84GNL(#$EPR:WWG!=+M#BI6^-%J2R711#C;:]2-D#K,GY#QO6NS@,_
M437LC"OEF7A6ZHC#0#)"0C<<>>W9S-`L-;+>G8QO4E,5K2,KDJG8,D/-(2B6
MK1E9LQ<>6OC-;>X,&TOYM90'B2V#=_%YRZ!&1%_&YUN7EH&[K\(Y%@AN"K2M
MV<,=,90&P_;HOB,=\#I-PR10O2UZ876KLL3ZK$M/)$NXG1ZC<@O>_WF&W5SE
MVA"7.;:>Z1=CME$.+8_RO+%,Y&9G"Z%U@5Z'IG4":Q7)_/V-RM<;^@Y:XFX"
M&\_I(!B78GIJ'!N_A[\>@B=T.%$I$DXUJ*PC+:HC<!H-0SF^KY2$U3&X'!'@
ML`"/9?VAWF9+,)7'<M=N!V?^'L/>(&B>54K=Z:;9P`*7>1=NZH;UK>NL/L1Y
MSU=4C6M%/JNHX#,R!BV%#]2U72R?S<Q?5ZUV)8BE?I8L7=%RW024[!HU)2-O
M!&'MCC!KTJN[-\`B=:,MC&D\(KA_(XI9Z;WN%$4H+!#P2S\PQ\X@#BYEQ(B`
M7,46/I(N[R6;RB>[&@_"ID3*3^-QX.)+<I!E41KK0FC<2G'TKW736HI_[4E?
M)%$R[02Y+C=.\[2YQBK0*"C#OWOM=#^IS2):BXX!YIT@R.._.OG;R`-2@)P8
MF@+[0E@8J392GMFLO1,`'UJ"]#KG"NAJ]2+F[@,3.<GF8O^&Y4O7&<U;M7ZM
M=%]7EZ(^A7>#DIBKBYW00$CFX2:PD1RA[\A`0+M5[L.FJ\ZCA(446VGNJZW0
M-+EUN1<;U6A-1S2F6]<$#*8YS<P/[+('NQ3"4'(,1LD+,8=:$#XLW,2JZZGB
M&F]%!C18337):XDV;IG*E,-5?0SG?\%:1GF5O9N6MG%5O'+$V(KU*0+0)QDB
M6T$-+C(0]XM$)[C6ERN&]NR"O\\0J.82HRQ8Z/ONK&T/%+Y;<JS2&!Q^5E=*
MAVRP/6IHH9RT]Q(?@9:2./AXL!QW_7[:.QQPCX'=S7>FB16R_YRI:?#T?C_-
MC(#/$;R7-0)3:Z`<B%%X/9A>[=%']E`'GT]&ZWF7O5',R@X*C@KQ6E?NM1T#
M,&I^/=<F#]2Y`L((R]8"N<;Y-A"IZ?K!"H!K5N@?3MK_5-R(^'GHGAX1J,I@
MP$M*6_/7ABB7#Z?$ZR<&+[ASBT^C1EH[^GC"`M*9]4]I(>3?FP"U(%!(^E=>
M>TY8%^>BYW.$*G+"YR1-FJC!RKY4X%=F;K=\[)[>R@1I*58D93[\44%$6BI4
M(!1:W1&+9.K\F:@L!&P#S@!5-I7WYH-_+C-73@">>AG\R!(:)#8B&+/)^H]5
MC^.EXT9D4\G8W$@?5@TL")<5!?4#UJ/:,%9VZGM^63^1*8^VN,52D2K:"+6'
M!*.Y\H6%CSMZMC,0Y!(.V!CJ[H?;\[1T6F:A;?[[CEJ-2TB,_V<]C:9%1MF+
M4KK+*A]B--[(QM*IES'9>@H$/!$+.6#.W'D?XKII6G3=1"TW5ZI77`O9A7@V
M9-^M!WK!7&6U9=^+.#ZI:;5_U\Y:.<9D1A/>7?K+5PHE7<RL@ANBG;NHOM":
MN*&(38YR/SRCN+0F1LN77PJ^+\P<<O!7L"^<MSAF&'9M,48T?IZT+P=L7K)-
M#JG!/B(G!0WNIG7UNH@*](BML/V&E1HGID9JM,"Z3+C6#+LI8&:'31;95;25
M[9Z307WWUJ>9''`E0SE.Z]#'P'!L=ZFZ7J<*8/84_X5A%=MHEFF-FG+'`6MR
MH=ZB8:<<]_$1/.K)]WU+B9<5B.!C7A+S"8.'Z<#$$*'E1_-`[]]&;"R0A<72
MJ5=`$.)O[<`*D=E(B^/2-Y#X@_&;RS*8/ZD4==]K:=Q:IUO/\_M:\_>+O>&I
M4A;-11@7^F.N87(G<S*N6S)[GQ0L;S#(Q7_07W/_$Z7KK3C[\AI^]["J"\6O
M'@4#1(BG%"><M<[&_ZG?.BQV&WTC=-<K\SE44OKG42`PQ15W#)[1UI&[A;&R
MXM*+0#;Q&[&;L`H311AVH#X>$DV>X[.NT\=T$]S+)C6TI']7!`=1):]]3E5Z
M"(MLE65ID[&;>!=G304)SL^_CW4[A5!7=^^W[TF!KOPU?ZWRR<:C<X*E:E-7
M5''5,O7(IO[\^PDGEUHTFQX[6"F#0),#9K[W'6S=XZGW+"#M(_Q;%3ADAY7/
M/-W<&;\K*I;<5-4).`<J.'OGT?6\&).IO:K6KL<JZ>5)]04=*GD!ROG[8]NV
M:<:DK&Z2*.Y&OYDTA9LLSCS,6P3-,;**1F(0N9(ELO6]AD:J]JP1EM)_GVDS
MP&D9H<$,`#.ZIQ]]?G>)+P'V"W<Y):"26(LGO>(3IOY\<?AO'X`1?<WI_);#
M1B1%,HX7/5=%Y?9A,',UB=0OT2'&J)!D!:77_7>A(.-)[XX'>S`31KZ[FJ+'
MH%=VY:&5K?G_T"#GA6PJ>T\2P[RWI-8:@IES&62^>L3X$CB?1AANFV.>8J6%
MG6L7@F=:0?8%(,\N5Q'`)&VSWCV5N7\6-:PWY'\,@[>GGF&,='V+YPB\6(##
M5E-1'>M#Q33GRK=G<]]04H3A5M:`YK^-MQM^#@Y'HTVVA;^@>S1%OK?&OZFO
MM,(!@2JY$,3:I4`OJY"]ZIXV.#EJF)F5_W:5?LRH9Y>#B40#2[S_1G;#R1J(
M*N'GEI^R*_,B:_JS%]J(1:I\>Z:G?%?OJK.ZG?DTAZ/W$YCH)",39^E\X&P,
MCJX6'/JV,FSVR`;$!*6]3F'NF+`0``4CH;?3`KT$5CU6<M"!+B!_#,-%(0"T
M:KN:/-@D^5P?QGJ?>!6-DE2"Q!+%\:=!J'HG8%Y9RBI_HK13%UE/!<$L6U-*
MT!0-3@D0''VDQR(2-=ISKSR)Q$'[1(64%$#[KW>;Z,E6%I8!VC>%N;(2AV=#
MZFB=)'IDS;&&T"P'F'>R0%3`[_:,::O5BU,CSDK[`P-T0;-MC#-.HW).`WB\
MKK6QJJ-M::58V!ZE6%U^`)O.(/6SHVT.O(NGB*IW9>;:8<X,4Z`@MRCUI#(Z
M4D"(WPQ-ZJ(19$'":G.5'7"7:(M?62F@*#]X+&B81-PARP=0U4CILS"#ZXPC
MOUC%G"NXP-B%<OPUEBR]1Z4$[^[WR1J\OPW<'?H$P$#1)[YK>A^?6C(!W5@8
M9H&@_%QUB)WEBYD:.OZ#;F<KC(=BLD`,2(;M)<&K?*EA,CF8EQ$Z*Y.:]QGN
M&$`!O-0>5DH,.&]96JBT>-'#PX_"*T1T32**1HUUDXR?)A%A!2JL.=W^9YPR
M4>]6#=F>8U!:9M5:X.Q,JBE@:7@QSI^3"?IZL2N#50S@TTKAHRPX:`TJ2^Q<
M[/G/T)?4OOMPBNI*BM7U/>\A1F]-I5@4C7:3H@HT+W3Y0*7!"P$$&]EA9O8\
M/W!H<"!E8VAO)SP_)SL_/L2AT)ED=CHZUKOBB<)J<XQ#7Z;-E'64]\+2=OM$
M%G/O-BB>!2U;PIU65QMOSQOM/[A;TUCEWV#9]Z<?[\+%TUMZKW]&';SO43_S
MXR%V21RE%`JN>/9ON+:'"@NZ,8("M51ND8D/+[F25'P-X`P?.[)G&I]UJ"CJ
MCM5EZ-`@%](W'A@<U:?.FJ'.O<,N'E=QV38XFDIR<L5#KRBSWQ@[$E]=P+>R
M(_ASG@IVM6Q'OY3>UU[-8[N+'_=#RYL"Z!:>1F$)DP;!EBY<`[H&3B7)90+9
MW5%RG?7C(%P.;A<W='A5HCI^[C%[;0>S!F01.$DQK`$;7)#:1#%0(U]5W>+E
M]$C12;KBMDMOFU$V^WT^Y;M,(?8B[&'/\8"L5QFZD6$0G3<4^+_5$,GD2YH=
M4']V0&T;?X\A=9>ZUC-F1OU:KIM/G>0#(`5S<`4;-F"T>]>>B\DZJ2`)/.(Y
M]M7HG%_XZJQ^R3_7W";5\R[)VFLS=7RR'1Q"3>J9@OQT(7Q/3^#?=*QV[V`&
MLDUZ3HCTXA$U'0M0&ZFUM`OU!<WWA43Z:*LG@FEG]R"5!.[8:PVF(I''HH<"
M09VDJT0@1_)9!C?@7"J0ZY/2ZH4<C(MV[\%QW;EII^R]S>--7B:-_.1$33_S
M2*\]BTB7&KM/0>O3[G8S`L*%Z[N#H*JB1;4H!:=_718@?C+/P0&BUO6?HT19
MA7<W1H/X['K+L4@R*4Q0?I08?4&""X+"/ZG2G3=2:@]>!F)=YX<?MHQYRK*&
M&X,C@OM&E!\6O@^SZ''4'=V27NB\8A;]C!?[K%ED:W\<68RF%Z#(]APFYL.+
M/8O:C<YY2[ENB<=G$Y(@J3T\[2%C-6O/!;'/#]0YH54SJAGDB5P)(`0LKY9L
M5/ZX9<_]/&@26H>6&LN+K!-)#E8N+@2E>]]:.7)1DC<EN34:U<',F'=36*;G
M+.)R\8//YY72^*FO?^]?1AK<8A6OHM8ICHI+_GOV[(<SH@I7"RJ0^#KO^WLQ
MB#@\>AQ*VQW9O$6]YUE-"N^EK/V(9,YMF!LYMT")RR3IT^>UTWT%$UP!Q)&M
MI+HIQ6]GB\-43UC!ZTL$KP4/T!VH/-Z^0_T1$,;T6*9\L!L&H=*ENLJ)ZOLC
M"^3H78BN<TLT$IQLJ"`83+?XNF5HH7^P"+_2I2KG6%L(#RES57@/_N>*!/VV
M=HV/`_][T/@=`)#Z`L62))J&'60E.8-YM6U9^?A-K$A\9];,#VO<F$&^`AW;
MT<UL\ST6F7XYD@D0/XC8E`;T#`NV/(`-Y(8)(H5M`"D6$"*^@":U!7&\$OG]
M8DYY_MZM<ZE?^?AN$G=?.*OO,LD8CR!6XOGY-\=!SWU<\\#!PF$YI2>^H\BH
MP0I)XGXT0+(P7?6NNQ)/DV7FOX!Z/BD`T8T_CP"AQ_T4-LABZ?;PL+T]!E_R
M762H/S59C-<._8#O,=Y#A->X;UDSWNQD^>\"FJ+ORGLS@TLU=0.&2@\O.:BK
MH=&H^/.'^*/^X<,UBK$."8GL\_VO$]2E%G5C,X#X8E0?[+I62@N8=FW<RAZ_
M.`'S+2<.Y6&6CM>!]!CD=7N/.EZ%`"6&G5F[>S7AR23/%[$XC!D89/HG0`(]
M4([1#V'#CA(WT7%"?W-JF@BQJ:66\`E-HNA&'XD][HO4!+(/&W^\JB$!%AYX
MV#6]S$:-*`D4.:,4#FS9W(!4B7/S?9=*-YK4KB^YV_'_3PR`=8]+R^.=+^96
M#4!?Z,/Q:DM;D/Y#<..(3+8S&S2P:(LZH\(#66?RH`]OMA)&BKRFKY?48.!=
M08O8=T9-.AJ!Y3UNKH44/2G&M;?K77BFP!,U:BS'\(:]V]>7M<$*4LE1@K+$
ME?G>270:-X0'%&`F3)JK(2+53#D7IB2;$MJ(FF@]B3A7Y6X6/T6PL(QMEI44
MN77LY;0`?9UF&JQ=2BF]1X#\PIU=5XE(V0'D$1)O1(E0=&2N$6Y:G66C8TM&
M^)K/)G$TL]7TOTE:R."<C]D:.C0,`KX"BL8VFZG%5[X^(X>U":17S%M\KQO$
M'8>V/RV4I`?X8,3:X=W2H43RF"PFM@$9%8^+#A^N.\OM_I=[QZR__ZI@"H;A
M/3S9L(`691&,(':(LZO2:7+]>%NFE%(YF>WDTQ,65SF*BQQA.\K[-A$7O[[P
M2MGKW)MS=:2;8J2&M45BP'^J!2*;J&1,O"K?AV$%^X.\5[7=I]O.RWA+/9C?
MBM)U%/_8Y:R/)'MA0`2?0CE)&G$"KD.H29`5TD._-X6?KC/\S6BP?84*U\X6
M65]^NC]NBO>T$=?("^EI.-Q0U/"2!!2FCNKI?7*XC="KCR\1J)F9'<(_\N#V
M.7DMG&.S'!KIM6H)X:1F$XS)7L8+9L="D3I-JVZF"&>7(,&UI'V`X=WDY"C[
MBW9[TMC$DJJ\X?7#PZY0B/I0SV&=00,=A-:R1:^9MA](XUO3S*,>?4HPI$R<
M(D[8F/'APZ]\7KCF&E57#$0,8;MQ&@$9H+JRT9[)/*@^#&J#3N,B;72L+`M/
MA.J^'JAYG&X$1W%`I-81,J#BP:$R/D3X+^@H+R$<,O?5%C236I3;;*=9!?0S
MG[<QK:`06$;#<NL,,:[#R6%EL]\M%HVABV_C,;A<A5#C2N\K:0FV@-+XY`17
M4%78IUS71$NAV3?NU%-&X+$=+1!]C[PL\T(DD,&$@N2^UX4`_,7"0JH53\8O
MRQ,>`L53`VHA\']<'19?CM<?W&2<#%=F1KI-<5!=\K!C[P^BQ5,2D?<LI96G
M1`BD2DB3*HNW)/>5@"3JFH:,-,5Y=VNJ$V$DNSJ?RPGD3AI,)8S,1@711[N2
M6<*YR_K6Z,4Q"F0DHP!V^F4J`M`<D9C98-*^?U,VL1\ZILHQR#?I])K*65V%
MI*G0]>I@0H5&UXPT;M2?\F/;Q9!KJG[.X[VG10L=FI=@K_CRY1!`F/F795?1
M'*1,*B5^[&7;0,J:Y&.5VX[A$LDT]_@0:[9_,"!7&WWT^AO).(;-A,1&%%_+
MQ&DWA>37?@!N2B-GN%;,@Y56_L['?;+8Z!==!:)5+1]]<37/`:BUG`?IB&_Q
MV[0Z"'^<L`X[)#8QM]CNHL_M]Z)^@>56:\,WOCX4/&HKL"*8-Q]MD)&P5D%8
M*?,D8ACY_[((14_83A8RP2KZ\F9M.9KLN=R^*D=,9QC1E8LZ#]*R@BF%2?Z%
M^I8GUU4G==A*6H3<C-LG9NWVBV]JWL(!E-#5YR&_9@-$+Q_P95HHOW@0?>$!
MQ'8E\F0Q_B'@6%K&RB%?:O9(X9,+<QQ'2%`(-<N4Q4U/&_R2H(S>32%D!T14
M?A.;2W?G)]-0)??D8@KY2ON7@L"[Q+#_K%+"'75946K%Z0N%?DH`;5U*R<+S
M)DID>Y'FYUJD'*U!>#:P42`);ZD!43)2Z\2JMVD^;[="`*B5]UI=KULH<T[!
MI#O;I!?B"!\R*(6;YTIA:X]3(1+6[DT'AO[?>^!O36W>,YF/^$.^PG75SV%R
M",)/\SN@SL.KHH%"Y38`L^<%`8%D&.#$3F:AIU;]6GW@44\?QI[_7<<+94_@
ME$UR>,".<WD0[1UIKZQK=B.09UKQX^M?,[TR$],@E^W:LU?1X)L40E2=^_@B
M&Q\Q;]Z!(`3+G["LS[=V\7;/5$Y5,*/$G/"(#W+I.8">P5IRF[VWJ0_KD0!`
M.>2I,TMWC#R$61(^,$<I4NX.8_:7B3CO8AJA\_YR@'M^H4[7_L017#@S%"E`
M+.?[,UL2(8%F5=<,L#ZW+?5-MF"G])P5T<RWF,^LX]*/P<E5#%CF7KP@A9</
M?01#^&).>5++'F/HI6(#;?FB7%5*4RLLW$+Q3UI,?GV!<I3@V?H$3U0&$W18
M63I0R8<M?-[+7%=\))NS,I]C0)`14-<K<X[XZ-4N#()G6;(P4])_C(E.9>JG
M_?+VM4'9>!T]%YTE!//<TF]?.*NGG;S5<A,P\7H]2D]A^>VBM06S7=)</9=3
MGP:MN>D&H#VT>?([10+C8_-H('-7Z#.0^\L&\5WF)@,%/)+"Y>A;NPH6S]N$
MO^ICD1MC=Z).#*K4;"LYS=^^<^%+JGT2J#<9@>@IU'Y\UP'P&,$ZWS?-A?+X
M&Y?ATVO@:'JY#]I]5SI?'.26V'%*?U5DU#1`]S4ACQ!1L]@JZ]^07Q2?*R`U
MDC%E:?M-WCCC/\0L!$%'>EU=@PQO-/JN=?TMD/.L?4F)N-=+P*Q89S"><[I.
M'-FCATW;N>$DQH7BMNJTE^!S"8>V&#?X`OQ3NO"8JNK&=?>\11FS4B7FKJQ>
MNG];4&G8\/ZJUT2[780*F6@Y%Y>^O_O0HEPCJ_\479X0+SE<?6>I`U@M]\5G
MYV+WK/U,+9D:B$PI1[@EF!\,@+(0B9O<S\86=9^^WPAH?A*!=S[M!<5AZ>>>
M]G$)5H1R^>O))LAZS:D6YAM&Y2^V[`;(5OG_RHJ+%>WW7Z-Y+P=5,/!'SLF9
M+BD)4%7;>H.4$O6M]0=1S4@O_442\C-=%BWQ4&/19X2=H!)-M*&92!J">Z2D
ML,/=I@S=4,O\C!\LM`AC1[W<`!%DXV2@/D6\/`6P'F.],B+S7HR$;3=T[/NF
M%N]]I>M[)$D73QP2BU*UNE9:6:&=2UP@JT]MQ!]`XT'@\IP!$4#<QJT#I;R5
MCJ[)8;N[YM5"SL:$O\@6&71KO_5IIDS$]\^MI2P"8"C3H>"T&R*V"2Y2)0`\
M*BS_Z(P]$`YW.^:L#)\D&!"1`MT-J78&45>TM=Q/@3#8WI_S7#;+,QFP<$!>
M2RM857'CU23?DI,*;Z4],G4`UM9EA8\,HYS;*]^0LYU?%CWME6<0LS?*<ZS1
M\J[L.RGKRHQ`\HWF!;+.\<^JI&25D<DA[77W27DG[3^>H;A#F<.B+(N\4X=,
MFF=C(W'468SLJ(I_#4MN-/'&:^T_]L=(@@D#D_59)"(S"^M"FR2LU\<FZ>M_
M4/LD"&:YBU?I@)5D+`.!YC&@6'G.!K"-*K+`H7<I=O<L>RP<L+GT:G'180.7
M>;@G3S<.YR."UZE'%42DAQPA;VVRL-?,/X*Q*/1F<%K^K*Z+V[U)%K%"1PC)
M.KS"J)?&V3D=@^ID;%AJY1[1H64I@/1B+<#)V<D\L%,^;@0VS;+OF8UM@WT/
M@Y4.*JVM:,'#8`80H))>+:6@?<BA@-K81+J.E'0E]$S31Y6Z[V!B2B9KK75D
M]M.JJ,MM@,DR1>/UDI;0`I&QQ.-ZHA0V2BV9X6G%OP:SQI##?C7+,(Z+IP.8
MI+.#3(M#4P-VB@EGGYVE5(2_EH<]M3C&FFY)]#BI%^?+6"3<E-%3,/6.E0CZ
M97JH?A)[^N&M!;"A]@IMD&S<"T4%QH/IJ['+&#9PJ$6*(4]R**A$(^%5V#T?
ME!TK5H$'7&3B%M_\&'"YHK#A@9UY#@I"2!F1VI#J\*G^]6VH`^VJDON8Q[:Q
M>EZ/*(8N8I*R"6-("UL?MU1/F,SB.C+6'7]:W-G])`M_7;Y>7NQ\8,JPT,Q>
M.ECT>50<!>XT''\9=Y;^01DL>RIF;+J02X(02K(I2,NVK.?E^>8.P0#V>6Q]
M1:U4]\$$<F:+W,#=HP^&];YEU9K?%JFC/!.5WX-7C5IHH`_GUKT`C=Z-??'C
MUI9.[%D/AH)$SI5IOK;`V16TMJ8;6/V_L<4UZ39+]^UWI@]U]=KEIT0*TB-T
M!]_LU+*'T0`'M25'KL\U3.D@3['O6[E2ULYMOT.K#X(@).OH=(RF&E4I9LE2
MF32/="UH:+"`F.4&^W_[99>'5KLWPW)O)UPBUJ#_06C_=L2*U[3@-0:U*%+5
M[\S/NK;L[L@I.J+,8>0Y_^=(LN;<,,B+)]J2L:R+5$A1*?U`1RMOR,V`HFTC
M$2NJYT9M`+%D8O##W0"]Z^/-TP'$+='M6"2RF<!#L+SIE@Z7(3[+*;TM[8R@
MZ5A[-(7_;;Y20E@@1BID)?>88_D^_@H1^1,>.HJ;>[1.5Q\R&TBZJF02LGPR
M_"5(-8!ZR&"?KLQ-.(C>M.3ISZL$S$8?&\LR*2\&7YC-^^5.I:%\QGY.0;U,
MM<O5EIY/21F%L]/6"HLI9J:H[!>F=33F"WIN+NI0/>X<;#X,NYC'J[!O*)^S
M,>]$C(WUV)Y#-3;X]RF0ER.P">XVZ^#YO<#G(4QVHB]1`F;#7FEK5MB*141T
ML6PJXG!X0.MTZ[V<B!WARV=M4L\\S'DG186I**,I!K+"&_(C#G]8/XA09M=B
MPJ9-+_?Q0QDF,),64K;5)?VY;K)TUTH'`B+:ZUXO3KXBK%+*2NM6:OPZ.T'(
MLDB+TOQGS0K_B0_'$5QH91?3AR1T6WI4/(27$[)INZ@2110WXFX<[\(_/1!Z
MK@I3.#'[[Z^+208&JP7SHEJ[.)O=D8XC(I1L9%3G21%K?6?-,.)?0]*_DFQH
MQ9(@G:G(HP-]09K@T&Z&+CQJ!]?,S;SLA?,A:H++G!7:^M(71FGL-4!2C%I<
MQ-A.GUED24E0@,L'?\W^*R3\53GAXL/2@9DLPO+,9X<(ZO-!0<QO#P)WHL>T
MDXTY,A[W3EMV.&#H8:R3'-TP,M[L12E-'(;]G"[<D$+QF?DE:.P4RGPGB';L
MIG(X,^/M#PRFI.@+S):7"EMPMQ[91F]&DPX5!!Q"&16\]8(90QEU6HVJBX#M
M9<6.K!N*,?%I>\!]$Q8MND!,OI(%\W3W2DM1%\.KT<C@@_;*9>5&X+S/YHLB
M.:E16C+G?^1?.,_(.6F0Z\T9!?15[U[,O:4K#(I.SG\8'3;0L?*!H7!?1`<"
ME*J=C&<W6*BCE,.*IDX2QA>,92G1#A_,Z!F[L,F#]/3(D%*2;.AFM0=@-KI(
M[\':$&PQ&VJ=O&UZ_991R).,?EMWU^OGR/=`96!/53$&?@:5V@V!K8F(*[+9
M5:MC<X'`MWI@F6+12FW)]2R&93:Z/-</40KT_>W8>QO95?1+>'?TQ+65C=7$
M*TH98X`6N`=76E#.`'MD%/(`O&5A\.+9<YT>[4R!QY?/5PB/>69C^O>0M`7G
M*U;:"F'2,=!+E@0,O#RSQ:,'L6QJ8E/@[O?%Y-H4^%*QJ%]DA^")^59Q,+?$
M]BA.AWCGO-[]$RWU?U7?'8YWS!;IB']R<AR#<`,+Y"B]L%`;0\813K!5V\;_
M:!Y3,+D!.X!1@AF`LLGA3YR'9//]8K4G5R]OA`Y&=R!/O^R6;K'H]T0-%$E^
M,=*'VU<#E2.A+P\ZX)$:J;D&*&3!5O,J<2\\^J,#T;5\W'()TGOG7>6N#=M#
M/?H0]8O]H=:IQND9O`VN7`OE@+OVTT#[K.-;`Z"]M)&O\)U:F>L8$?F)QJ6Y
M#GT!&#K0L9B*O?.DW!F]-O@O3JWXS_9M=)$V4X0!2*W.&KS%;:U(5Y&T4**C
M0:Q88E%#^X8O^;3.1M01"S0NS<1(4_^(8TE^46[ZORDSGHLM;>;NTARL9^4[
M4D+84:*8<E,15>`QT>NS?%;%4V;WFVMPX#"GEH^_%%0"/F@5Y)&Z6JK[ZB<(
MJ!H%D46BUGS.@^*X\<@+,&C#1/D,D*6^:8:I0/W88.)5$Z*2__/UD23_V<KF
M%C4M@,)F56#8`^NO]_2<+@0,0LP+UVI,P0;IF<Y5WZ`X:H3]EA''$:/'_W_#
MK*10X"]-TNKT25@9H6\3"C:Y$=$1EW=9VNEX<<Y04J?3I4WG5L\%,A>+3(NC
MDF4?4]]=8U-6[V@1U]/L9F:'G$57)*!6WNZ^$N#H[;+;IL8^NRS"?PZK..%U
M_2!I'FFUL/"NHP\5HWIQ>WJ%E\$X>YGX_,J9C^SI9./IG$H`1%-60,Y!R"&6
M(PUY-+XAU[]KF]FA:#SLB*C.;.1,$/'J3:]MG?V[U5Z!Q+J<^;`["R\?"[+Q
MQ%::H#[6R>\*AY'N(9\^NAVNE#I*'1D\'0327XJ/>&V-N>%.E.O!+H]1%YM(
MK:VY1J7J,J2C84H'KXY?\#"O_=@X/T1FAL0U<KW25M`&9KL-#B1S'II_C3YQ
M:>BS9_A`MS/`AO/3X4JCYCI%9DLS=PBM\K9%IJY`ES%,(4C.:G<O(AYXNM14
MTL5:T8XH$Z&/!F&G3(IKJ9HU?C90^KFB?VB-:U[NJ*26G\.CB)V2X'+#<O0P
M6R<UIJ03.>LI<\*YRX<Z.?J%4+7;B5,'<A_L,:8#NFCXDZ2?37>E+,OUSP8+
M8G2'[RV`=Q;G-+[RN$XB(!Y1-=Q<U![7ANBKYY[>UM8!_Z>O=N#A>2RQ#R4J
M_,$F>Q)IJ@>*$NQ[WY`L5T(CJ7HBE9G-DEJY#6&](^`Y4S+RZ:FX<\8`UX8J
M/Z5<).&LF=VVHP-+(9MP"P7`>+.3%\*'">I1=#*W8`H0KR@LP(Y.2FF4GO(`
M_L]U*4?]C1NN=RB\:GYY`U%<WLXA)2HI[K`;:%+7J`2A2Y,\6B5FGO<NCS-8
M-9"N%!G5RL@.8614Q\BFA=2)VBHJ;?AAEN+!J6?`OX("9F^-#74'W0@.",/=
M+_HM4XW(:7ML'(@R=-?RJLUY;SPI"'M_,$EZBP_7DGBE1T>_*:QO$/+.V06G
M<">0\)I5?@GZI%7H(8\#9`*A-\>E'6U0<G4[[@VB^$5<P\31<RHUZZ7BZRA^
M8[`EH>K(S6UWTC0R_(OS_;`,<:K]]80'!K>N>(*N/1W2M\;[$TT3_V8#WTT5
M?)JGY[Z)@TSTO#'1JI.6D7<N[!@8;F$:Q`;1YR;MQ="=4*HM`#MT493R2!_O
M3X42<%S:_*[G(.YN+P@8KF0'^BA[C?@&<]"B,"$@EC4!#*YK9"TYQY84JACA
M@V+C!>CM>R=F_>'Z6%$5AH:9?NI\#LO-,)SUSH3QJ\?G2>3J.-G+6[]]1O<R
M+E05+=SNM?#G!@9VEY@=3%(,OE_20J0#87W&1=+SG__MP4IP57R=]TJ*`.&:
M;HD-`U(\P(Z?QS?^/<@B1*E.R\4(>L\7!9Y=A)P&?!CX+`-VT;RS3.1:#R<\
M7I9:&J7(10$HUJFJ[+'6FV6:Z(G0JBO0J0_S:"7;>X@D"O";6.OVOFYJEIP:
MCCX\<_1AY[7&T?ITXV'1A:J!<V1;KW@B?DH+L]4:Z2PRT#O:MI,,)6EMU%/)
MG&SR\8Z&\?D2+)44/LR10C@GL>6#I;VB0N!9=3P4ASJHC\(1NT89!"HT)&ZA
M'K/*L'DALEZ#*>1I3_6CKA3+:UTPRR7+*\!2:KT0IF#F;;^)8H/T0Y69XY#"
M9R(^%V=@>ZPC_"H(8CD8-^*7%KWW6E%@E?4[!:J@:+YVLQQ#/"X]][Z2DX^^
MJ3^YQ,:,\EKM`AL.:2`)1!V.=NN4V&68YS"V;/*&03J(=A6GPK[?>;PO`#\(
MN*GJ$O.#$W*]%_N_@EY590<`N@K5/VLO_K(0:F;)K?0!PE#7YH6-<=OI9^[U
MBRA*:[1ADM-V3U<.YP3^C.<&X>Q0O/19RMVC-=_MI\E2]C`TJ,_'<6RE$Q-1
MYP>Y:8$\T2A#M/".MQ90&NEC2ZRH+-4DFRL-;.%UG;Z^JE;J&8'IZ4K_7%Z:
MVJ>0HCD'TL/&M'@55_;Y2.Z<CQA3XH%#!(#N-`DTQD\ZA^$2$9ZH@Q/.WRDH
M90SGL0(D0F@35,N)CCGU!D;&^@M]=RN4-7F0-_N<BPH95]RWC.9VAM]3AV@Y
M-P7B[+,-#]BZ&;K&F)K"J'QJ10V&IE*)(@T;A4V)"X`D<BB][H8PH$#L=TI8
MKS%T_!23/;KUQL?;IU$$']L``>:+=NBUA6QPI'F&M^4@9:.Y#0K!S(RJ;YOR
M.)L&X>?S(%RP!F6J]AWDIX`XW<>T?>S:B<01-W9)@FO0(,VN!3K2KM\*QA>?
M@KQ3\FS@M,X3@8O?ZE[Q$LP9&MU9'K!-KUZ7I%DI$A-N\K`N$@I=`O01-)[F
M[=RQ+6O=.IEZ.W9FPCS.FZMV2Y*E.TMM7MVS.FA^DT_@??4T_E308R$\V3^#
MPFB,C1S'IP_*&)6:Z`[XG3Z=]%/==V4@9AJTLNA*YZ&3+_(3.5OE/YBQ,X@V
M:,,-]+XBKTK0U@S]>EGZ7,_I^>H!%OX"J6Q[Z*)W9CTBG;W>ZNH`"*ORA+JR
M566ZG.^FI_A.<)%TLY_7WG(.^<D=C(6@(*+W2]=:"%[UJ0DT<XY4YSTN"0`)
M7GRFG`F/_,W'Y@=1.9S![:LN>>!!+&)=[Y.NT(MK%ZUMVO0+=>(Z$]H1*ZT-
M"27MHHU4Z54XGKEJUPFENU>NBH".)C5+[U!HU7X8'_PW5Q]Z2;#?4,!-=/?Y
MX4V\-4'\)OZ^FH(G5WN_MQB;EL2(1[Z3C[]DO-,A,\L(_D-(N^GLR)?(!()L
M*>00J>V:HA4,0SBV8H@:5':BEVI,?NK_J5$-\>.N]5'!??TMSAB\Y!BI9KX5
M)[GP')0$H'TR#/$FXO6<@-7'>^5')B'O8$_AW_"EUF:?T8!`86@=:./+,Q+>
MYG;S6O)!2N-2**=C1I''WY0ITE13%>UJ4'LC62NH&8<K]"TJ:M9`&"W_+2<=
M<=)1O\%L7)B98H,)5N1)'SNZWM>Q'57$S^0A&E8T&19I>8U]"V(8RRC]]\01
MU%WZ+E02PZV])<7.^WES,/FG?Z$`4,"N:JGW*(+@A=D,+"/_S<Y?A>W;_=!3
MTW>)^N4]F=9B_O2N0]FTYJ46&CHXVRRQ_11+NZCFPZB,)&V+>>MKR)#/`5)L
M1P\WJ:#KEG)-*EE*"#$SK61"SA9NF7PV&<^9C_WG!N;CY/X6"T];AT7,]-W+
M`$H9UL:JV=9`O)F!AU3$I>A?Y/!B*L*,)\RB*^5L!XB]S'F1(^7WH16U"'R4
MB(+`;T17B6.7)=A:RB^9%7]IY>C&:&NI%Y.J+AQ%X5FLS=-.FJ4<SE*)(NX"
M4?6F_`5"9TNJPD8VE$Q<.PL88?L:G>K)0[JS5+%%FX'ZWQ-QT+/->J'X9LK@
M(48IOEV)`0BY(/YTN04BYYL3)*%-S?"1?QI"81V1_`B<-)6%=L2J&0L83D8W
M.N>NT^N%7PO^KCVY=T%H^?9K#6]OQBU1;G<JCHE`6KMM_1PXYJ[:S-4DL#,,
ML-';E,O_L':CJFZ+AX770"UR?VS)_'MW#YK+9&$W6R=TVW6+A^1\%X266L!<
M-L1"F)PGS]@:(JDNNE19M>-.;(%T"0O#-LP4D^0N7H=&N22BNP`2Q:9KC]9X
MXHF;<=%Z?M;-IXC/B'>3G`$F=`B/^+O!>^.+K12`V)`Y/'6T>[#-S<;0]A#J
MTA0Y)"Y)1IWCN5(M*]=0(A#>M[Q$A"/P#T;IN'1B:B5/3':-Q&WO%[1+,G?@
MT2XHCQ`@0#9<!XKO^\Q-+*>07?15Z4.V\\UY7*&`;CZ#!7<4FH'UL5VI36WZ
M:XK=MC&'*6^)50<M=HD*O8_%OO$U3Y]1X:@S/Q-7"7><*9Q+<H=F('6C=P%9
MV900=>,%?6_RB-Z%SE4U!A-&LA:R+VI\8'@HQH&&"ZF]#J/4U0&BC'I'TPMR
MD?&U$DUC,G(\Y'[G<%LQJIJ4<N56>WJL"&!ERJ,I3HO(,;%_JUJ1#%!8ZW9]
M;\Y703#-&T%(=;WY6Q\EZ:+*97W(C,K\7^=>_,!=Y=%=:YU;7^,/"$IF\7_J
M&KBK,IY9+D3Q`6/;90N;<+]O9=$!C5(3.UDU_3QFEWOOAM]Q,4^F.^>9LL*$
MXF<NS7Y=S]@/MX@-)K;$**$<(7Y)(ZN[`(CR.WD9F8(-9&?)4_4>`6OD)$>&
M@[_W'O3NERK>+T,/S6^B%.2[3.M%>Y)BXKHB:@36XS\KPG_ZU&N@7'5\"2T@
M'X@L&\3&2['_OCY&]-0_-.6%`*9C&&JU\4UOCR>$RYQ7B)`SP),U=2D]!39L
MB$>3G#>R:;N"C1`,(P&\WA9@`"]P3_0<]<X"'Y1GCMR3EBL>TYZ(K!J$\9O]
M_N4;J#)Q!>K,48!E&MP3KT=S@Q-:U2@Z7EAU.P";=3[@UFC#^U)CJ\PQ8'11
MTSHV<(TH'IS;0%\J-;"]TR[@Z-'TYC#*YIKQM@ZS/,?_-R7`,&'='DG#.9%P
MIB95Q166S,DE/A1+IT$%\W'Y/W<A,#TRO4BVG:./HFX,.,V($Y[UM@I@V$48
MES61]?'-?BD'7)<6#H5$UUE;Y"3!U/\1B(J"J<TTM%+P`XR2"9-+)S&64TG!
M#'O+H51WQ05XJ##IV?T(6\,^\ML$<;3)+Q6QO.$^7Q\R9U6MW&U+E0.$MFFW
MYAN'<O"HV5M6CM-.*$9A0FYY*49VH>X@#E"A:47NK[SC9Z<&Q'8_$9+0`&_`
M`Q>(RQV;&"5NQT.1+SRC/%#J?[CESBUR1"O&'E_:\2&;&_EXHN$&V.+FG5DY
M@^P>5LUR?C/*\BYPZSWPUKNE=I(]5(BA`)'P2?=(.MIVPQ("0B:W'64@!8?`
M?BG$(,#\(*O\\(+9CG:Q@Y1&/YO$9KJ,1.H5-%DXKE4X&5I?GM7EQ/(9B*:C
MPP^R#*1[4(K%>W0Y)8$1'P)Y$HTVTV7WB;N8R5(@\ZL:3QQVB<1#W5EUWKN0
MS5WD9O"^(_I_NU$,'@*9^+Z/7Z"+]G'=4!>\QSPQ*+4S@D^#!X5]5,,@9N'1
MXP4,SX.0QSWP>D);X=/4Z==(0.F+EBWU?03BG,E8J%[K+5*D1Z^!V<1],>CK
MA;PL$.D*X[,T*JBWK?1)6\!!Z(F54SA[.KOE)R<9345)V4!I1L>98^@5<S8#
M:@4^/#N2]W@H&UF5;T[J9@>]&5OTBH`7HX!I:<(&^$?_@((7"]_Q*.'$@4L.
M2:T4B-[KM>/NF6\0\==L]2"_IEO_@']W,"QI"I3\F&K`A^+MT'*HB$5]:?3!
M66BB)N!9PJ&^49R!IK'JQ,)D*54U?-;Z\XM#GDZIN,0NH<HZV[2"#,L;G5^"
M(,$*UKQ6XE9CADX7L`OO_AV;_3`_]*-1P>G<PEO,Y$GSDXX06T:5ZT>Y/$_-
M3IQ`Z4%BP310%IH%!1/\!(]K4L@0;(POOG%14O1:WG<@67#45M%/H-O50D34
M__$"BN@0HDG,^85:MDV\6YEK[-^\W@)(V;>I:7,]\XV[63P9L$N#33`_`5CO
M009V?.E^-[L2-+60B.H,H\1([8N54.#PHYF)M57F9IF]G<1)5J7<37H'.<%7
M:"GCX;0M%UJ>J*-U$=;IP\"P(:EZT!ELI+J<HGR@MA.$X&M<*V^2Q2@)R^H1
M%JX;6)OZDSHS6)VF+9;3><H!V3+_EVE<"J]RVI^%<&_4GN3V.JZ+-<R06?*!
MVBAVC*VQ0E'VNW7`J.(946I,IQ67B^2!9,^A"B?J@M4A4GUH_Q83A59_0/OH
M9`EPKZJ4S\"=Z::E7DRC,5U[0LS:TQ_JH77^_*O<EIS`LCW,7<^](\B0;_M*
M-/$D*?C*?^R7C]CDLO/WHG@4#W[F3/A@J_.E'K-.H^N,C_/*71`VKVU'65OH
M^85C0>B%MC*0DMA(D$+$B(F/`4UP4?KB?8Z_%=@-"=[Q00`#-?\"A:3TP%[?
M`$=S?3?8.5B4&\.F'?:`)`+NP9`*DTF64Q+I)K+R9XP]S+^=+SN&Y!AON#W/
MG;_1_B9:V0;\#6,&[F`MCG_2-#]J-R\S*Q&=BH@6N1=S)J16@_;L?RN<6_Y"
M<Z4H<FC!>U\XH/K(P.4LU"T%1#AB?MWWYL1I'*%NA3.3`Y/SER">_:S(:)51
M`$]7\1@;B`!,GHM#[(GOF%H[7Z;*HB+5XF"$P>M!,/[/6(OH51)];)2D^#.7
MO;"1K554LT(A#BYWTX#ILYN7/L2$'9$(]"$N_4+W`OWZUDJ`*`$U#,BN\8,1
M.)8+-L.R(L]T@'`<C;^;S^%)C7_!0EMV@=_RHEZ?DU"9]5K"K?1+]E/:YQ3T
ML%X8.E,S25B;KH$UC1,J!FK=+@0HEI>T=)$'$DRP>=YR1C$Y48^/LO(SGUDV
MR634U?%Y]NA-RP<0SIB_$O9-_?^```?W)5"02Q1F3Q"&U\*BU*=W=$:-3J4B
MDD]K&]$,.(N)WKY;(\R_UP&Y.03KFQ!M%4>9GBF_W!=@^5F;JVG/%^Y7WZQ&
M[ZE=Y9'==)>3<FQ6Q2&(&O,>0PCZ&XZ3YZNFP$(\EG3&^_')""B?6L<0HS9R
M4O>"B/PLJ)0WP(IYO_&O&CN'^(MERN,"/B#:HM)2F-RV7`>RY:C.ZM/$$I!U
M4J7^;13KXZC=28P_[.R?K>+W=&*HA"B=._F3;<8=45L<MO12.$@JQ0YR)\,$
MTBL@V<V8/N0Q4-TZ<3P>\(=C%[*@]"(?)-,-DE![0O0-DE`\_4`F6<G0L!]E
M=]:$?7`P'5A?L)L$*AGD"JEU$!SZ\%%,GL.&+)H[[^#"=3LWU<`A^G20B%V*
M_`Z&M[57-K2`M#N]S:]3<I@N&31EX??5P)E]0$C+[GE$#`3\WF.AV<J(QX^&
MZHCZ@)=>6"<&AUC1N^TQ/V(.*6RSU/]=C#*T!%'$*("QLBB:N);)AM="=X&,
MFWD\:`PG)!;WD%R0P9G[B1+X?>[W_V-#A:WBO)EEK@"QS9TWJ!!\B3$.I7"'
M%Q^/'.9N1--.PC3J9:,+3'O*HAH1E,,3`)'HJ8:42\S85Z3^ZR<9GR6R>>_.
M52$:XX_4_N[S$/\&U9D#!]"W=TL6/Y>:C#B3_$%H[IZNC$5.A]B_U^IABT?M
M8`C`B(.M2<TXT\*^TJBXQ%7@B=,%JIPT8J.Q&F5,(K]GS>"QQJKL;J:9Z@#^
MT.6R0;&^KG2>@T0.GX,/9E^1M2^@;4;C;V+DRD8PW'OO31DGHH&'ZJQQ92/;
M-TND=),J^EH1[*W5KV3/F9JH'5IB?S&4R5OH(@-D/N@6=8^Q"A[ESY$QBT#=
MY=NL,F8BL<2/'9;(I`11##P^2.^5BBUSX!Q'_XNEF:\;_V0"_R[A$EJ@(B1S
MU:L`Y&4V"RON+I$UG[B%;\O'E'?G04=3I.#'[.?A5<!!1#`>9GLS4`?V3<HV
M&V]H,XP&FVZUJM(>!RD"@FIS+K4Q]M3%?HVL;#,D2Q!/K\*+`"!3%09C;@I.
MQ+PK@D?XZ'O__?#W&8*/+6@(CH*D?PCGMSOR4KFD95!=2&,<$<J!9M?M6K=6
M$6`<9<$B;JNQ!+JE&"_!,7,?"-.K,5\.RM)`P%00*]MN2X0##K"A"?37.I\5
M$7T,TF?=:F(@#2O!JC!YQD*/:[D`]+XX'R/[-,`A04#4WT$!O#&&X?T:;1;H
MR6(^[;R"_:7H?>@:2ICN_>"D])$X6G@/&_UG36I7\;X'/M#CQ'&-EH<1VSPP
M+''5PJ_B:N`#HECNL$V)EYK4.5%E8*AW^QX\*GT((K4L"W,=.3#\,@-\$K_O
M-)MUH[P-6@L47]%43@>@+RS5%]SUC4[5[1:P0#$_44K9M-74W?Y)->F"YV>`
M_/%^@X9OF%<!Q:PE.^J-WWCK32J>^!JB58!THAGT2Z?G?>M53/>J8!CDE#+7
M[-;Z=[()HO<]^GD%$[-QZ;/XHDGP<9Y:R*XH"[?E7+AEJAB.8:M7#LO,6]U"
MB]\RM1/+41/;_O%1RP5@8`#-3<!51186WV@:ARDW&:W(6^ZH<!@!AO5>8L_-
M*_WB7M>$J5[W,I!%82RJ4*!,*Z$/TN3[\<N]#)>*42!$WFRP^WW2^^V5@@]>
MHQXH3C<#&?X+5[0O34C?0<H6T2O"T\`$`%<38>:!ZQ,GWW,4(&%':RX-^^B1
M^-H1[7=:Q:J6[=P!I\`)OOZIWC,A]-&H1H:?H.X\0C(TT8GD*E@KW0-O16C;
M!?\'"?K54[I^@,OW829"=I:W78]*I+0=9478E&!<"CMTGJ**!TB#;=B`>#(7
MQH*D+IL90LR2B&`"$UA!,YCJ>=V5KVPKUPE<6NFE><B7)XF^^^(#ZNN_-U,C
M(D9GR%O"%10;OX8LZ\]V2*1546!PT[G[\H&<GPIWLG>&,=WF%VDA-82E/S&>
M2J-!KKWR!#9F,^+KK;(&@])EWX!`(=>?MF*Z71$I)=A2+Y3AC>=ZPLK;I>LU
ME:'[&NOCP3QBX4WWM26O2@DS)`!WK(]N0\==D.HEBX9KQ8__E;FA[RD\=*!`
M3RYK[@NG3;OC</0/64VNRMJ!).EW"#CGEGPT!V[R6;ERGN6?HH0/!3G(4BC6
M17EQ25(:I7KH6<9Q2K?B?SF#AF:,AME"")T6<FW/'3=XA?;XORF%0S@L>5AB
M3/TX?Z1EW]&W+E>T2O`;+_Z<$7T$$\A%!,:FM_8$CAW+R\+;2+ZU&KN6;K2N
MC!D@.TKK(>'\+S!H2V*.-#BIM[/D$0SRR&EGXL;F";_5^C0PVT.X@%2VGPQ?
MM.D6#1JSJ;F5EB(V7_66V>12NU8@@\<DW!RR"K2#$PLB9:*[Q]+XI%V,VS2N
M@*Q1R5(?`0F;?2K'/GTG,VBYTZ>U+$0N40K*5M532P-;Y;^$*9&:OGT'OA%:
M5V1OHB`:9)**&BW>TS7%)MWX;!@+S#J6IXM*H1@+P!)I%^&FLINOUDYYXM9L
MV)&!8CFP?"PLDU6W)N2Q<CO2U#1:DHUOP-E\-D\?X@,*;9I*JD#P!"FV"8/^
M"PFD5WXK30RQ2!S.$Z#^23P>W.VA90HY7K+4G@^$J]K?MOH'`5\:-8QR/1\8
M-4&9_AYL$^][3U34P##1HY[V<^J!+*]'SI0]YM@RE03`C8G_-7N'>K6*=VVG
M5:MX9'FK-*%"4$3M]XK"(NV3#(^>&`(5G(/`N.P162I@@=PO<_V&LR>;>2<@
MV4>5?L&[61Q%&:$TV,T;AK8,ZQ3H^!J]==="5.0SA%IR3P][Y`77&)S=_";,
M^5Z=^)S0CA[22.&Z]"-:EF8&&]7WY42VZ;.B,B0>4ERED.CUJ_&S*4U],0@!
M"<Z<4(=6Q5]6H&^#*039W"`XU>VH9QYFXZ3E@!K<!A/7S!:WWI^:I8;'(\*4
M"]PI5^:!0T=-W1]-'J@_ZE-*FY8#*S_;77?^-=+'OPDY(2N0*J)W(#OME=J-
MJ*TU^4=$@6?LA?XXJ\QMK.GR>M3-C5#UK0B"%.9!`Z=CEX[%GG5EEE9TAU*(
M56T!78+CT]YB,6&/IXP&-)\\B%V>K]X-?"R9ZJ[#0PE4I*"4]).:4A9<(CBK
MVD:4PU=DSRWST]%_HL$>0HHGL7J#O!Z&TE`N6X)XWH"(\AOOWBD^!;<?3J'T
M5B\./<Y<E5Q]DJ.U\U[20\OT[JJ:6!(3R;&7^@HAL&9R>6H$%C-]RR>.TUM.
MLXA0B$8Z,AQP/O[Y"\]%@":)>$0N%&!7@!@)4.++_E1O`8,!=4SNADI]15D9
MU'^E)",5=]4E"O*-\9)F>#AU@;WS34IDI++@&NX3&(1\;3(9&?DM(X#O[*V\
M#RSB`7^S>+(BJSO;K\Q.^-O(E"KCF>396\NXZ>T$,=1R"6[*/@[VJZ@XX),'
MR0LESB"GZKZ2[7D:U','R)QB^-P&/54(JIC]9-QC+R;D]QI$(@IG$3>5_*=U
M;PCMD&PDXV8+K$2>`KKDA%<Y=;G%%ZH2AOXLZHQ60=8\OLSEC@!U3G!!V_%&
MA2/6'HO:^75OS),DONXJ<TLF=8UV90%^GQ/H0:7P%P*&)E2(1Q!IM8?QXFW;
MQTB-/3A<4HUE+.*5R]PQ.,LD<`3>J(H,TQD1Y&:3V(7N/3PU8$3_6Q=9CBSZ
M@!8O"'X/]Y:11?:V:31IH)_^K^JA1T[7>).1IC6Q^TP.FT8Z&&@NS=H+#0_/
M#*_$G<V-=Q\T`"#:C.F2`Q.]T5'7(KN3$FG1H\LS)\SU_0_MXQQ!PWAD58Y:
MO%S,FE_65:TL!RWN)EK#.A`NT*![B@RR%2/`_RUJ>;:0Z"F12_N?#6D9;24.
M-!.$#*4>I.N-F>\_0QKV/#;U*@.(.\LF4313R;996FW>E$/P`;'W(<+(W;]T
M-4HEXICT#&E"-0@P3ZKQ/\9N),K49>E4,0V-OBF2B0RCKLE=HZBT.'X*K[+Y
M:GB.V/S_4`JWM8,RNG*\VU!=[5,VFB,TKX3S,QK-61P84++B,Z:*,1Z:,QJ"
M(Y;6_F,Q;\G)U-%7B'YEX*E8S8WOGR8Z(A=\BZ0V97R=X7_CH1LUHVZ@@>\&
M?G:B^9SOF=YCU+)'T.NO.8S3AF52(7LBAS._-"B/"3S>X?N0^LZ3#S50#L2*
MDUDZ-FQ3ZMG=5A28+1QI_754./+<9D!\[4R:B7IO6:GABAW0*?22U\-HZ)@Y
M.!?B+NF`,WV30>8*+ID%UXOOR%MWZ=P\_%5--COP!XEPWJNF5D@U"$42+"VH
MW2(PO-K,BDP\QR-FYDJ@4`BWK#\[N8/A<.QK@1W0Q1F.,1:=4X9-B>4!22'\
MUJB%LA@O5)Y`26`3KI90;X1BK&8`B%#R5X&A[6HJ"?!0/Z=Z#[EK2O7Q`?WU
MJ[R[<A+&S-3I$"^S:*X0'^NKI)=AXS@FF/2FA)9AG!W7@=JI$ZI*Y%0^G6*2
M3&X(N'VS;N>-CAY+8971?8&%&"TH[K3R21KQEL9WA#,S&U?.JYJ9F"@H$VW9
M0'@RJT5<%0FB7;>SPF8SG>!]C0H3=W0^Q4:#2BH[6JUW//L=:[Z\=1Z='E'1
MBN$!))IA\E611_VCBAEH!]T->R*O$F',-22"HEU.ZMB+,8`:P?/,BW$*5%ZE
MZ-KJ0/J=<%PW`^?E8OB1LCF?Z0(DG),`1/CNON]U=0>9H1*:$*[JK\S&=#5#
M:?]/!*H@99@6(0F8MP%9LK/(#?J%"$<IH!<5$.M*0M?QLQ8RZ[H^D7;_HRG(
M1\,A03'F_[,'@5)U?*S(=+K#/SIMYNG).FJ84;!>#A]D.'VXB]#HL;.)ZZ&3
M\?OJ#!_`N@BN<D$//K(C6V-R3C3/)!-W7=G23VH1[LW848BZ#!8\R"?)2;D#
MU)O+R;00:#\"80A`@=<*KBTS]&@]DQSYC=D$\2HM1`,YPZS56<Q^C;IBC`-R
M*Z6M6_8>,.*9)?@LB.VW6=<T*#*_1_;<KVT<9Z'Y#X>@W.(_Q6R<KE6A90JA
M_/J"B75\U3_\YGH5IE\A@ZYQ$KU5,KG&%P"T2`898>'[9'[%R.'_P[C/7OYL
M8@9MRC95%;!!`C%`=A(L`K4>M\'B(V2;-ST7#Z*@B%.\+P0WQ)8L#:ZB]*G4
M/P27$"#="X;KHR$>+5"<<MIE>!XH,<L2V-0"":YC]A.@C2$*AC__'-/`I%';
M=2BU?+Q;?1LLUP%2TPBR$CX`1GR0NGO,D%*QLND140GG7[K%XA@RG#FMTQE6
M@3TD36"G\ZF%&`8">Z#I!@LU6/VB`2[[YR_!3]#SG_4#=%_.U:YY0X\X-8T'
M0CQ@`Q/HL9L>;]Q>>(JDIUY^E^G(K?ETUFC.)KXAE-Z%"=F(Y:.T\/CT;$IN
M(J;)Q4D0\!G0F39TWK8_+CO@JLE!94Z/J1I7J$`N1;K71R^$??EY3"`@?E2+
MT-S8W8?G%AYLS(6E_^EFU%?7X-16^D?$@S.;Z@4LB.I;3=_PD&Q86(@W19)=
MZ+.EY3#LKD-J@-HWZ!`I<=U0R[)@W4;LUN:`B`8M+W!0J^Q&")A"".^AK[7L
MHL/3H3MG6,8+Q:7-S*ZV4.P$MP^'JG]!P=M2HR\4#O*`#8UO64L#D?.9&3>*
MK=:=+G@ETT4J_)=JI7D3U$<1E_$)+G$?<Y&5\SH0Z(U1"'JASUXII=`8J<)S
M,XS_#BPH01$(9JNWB\_M"BL"1*""+#$"5KG,>4<&5\NP4KAOYPZHJ;9%Z'*<
M)PM1/F`[4PTL!:R,0Z*1J/153[*E*Z2XDE_P1*:$!*+9P<%4FBL2SC3C\3CI
MLDT_@0-V'@2'&WBD+%"QIT=^-K$++XZ,J,;TW2NG2<>N&:LQ16+>/8`D(?@I
M//2=MOZU$WNJ\]F/,G92LZE_G>=@N\@PD^)4'Z'`S#4?=RT`GO.#\M4I0BA9
MWUC.Q5LA\E:P49Z=R$2S'^#.E,/<T)#3WJFF8&&/:0.G1L!@\"R-1$9R$ZCM
MRHY!JNG2$`V+?@9\G-'JF5PI0+:6*Z%R?>044VU2?O2UR7N-SNMZWB5++?!K
M&4P\4O[X1V22[=(QZ;50JQ!>)XB*#=]#ZCA1MA-FS\J]YTZU7S@%50=K+JR5
M`G(`B)@B_-F\[*,-;>XI]\5_!(\\\:IR+X>K27/*M)>^:WQONGN.OXXNX&E8
MW:7T[JB\W!Z3TMQ3A*Y2)UJT;``K3<"(APWAO=^JV,CMCIIM4XBYI*T^I'?,
M(8#7++#VOSH59)7Z#/XS(JKPS?-U?/=[(4!%/<C7-%A$#P?,)59UB)@]&O5%
M@R?UTC_N?+D('#)\,9QQ-KA1ZK)T(JOI`OZIE`N=>,R-G>MA+`S^DI:0[>E6
M)L![R^/"3LO38-U#]#/"AQ=XKU"GJJ]N:XOM8W[?0VS>"LS&JE,94EE^)*1V
M]%(D6,6N`Z_4M\=AL$&;[&_!J_V3^E@3GM=WNG.:KS8KAS])H&1T&VDOE)$,
MN?0?3J7*@-]OC#0"RYV-4F4%;33S5GUC2-_(8F_=@*:D:"O3B?A9B("?#X"P
MCYSP=RZ<A[YF?6L6&A)0'2@=,I)8U1H_2%V)BR&=9KD,,KWV]S@RRX2$F8`]
M9`$$&RS.7%!7=Q(*8)6F2`J(;_*`FYT`->C3]FJJK)5DKS=`L<<T\D1>"EEY
M7;*&AQZKX+_>Y0[DUY2F2@$+D6F][UC]@SZ.F8O`&5#$DE+?C<EY?]4S@GWR
M5\[Z=3YH`2L1+(`["Z5+])^8X1_*+'/H3QA.H#+G'W-D.=-*<:")YORPM89X
M&.V^XQJL;]"RL_7N^^P>EQG?V0\7H(SX+&`H,I4&RC]*+&8<WVQ^YT&P`&7N
M:E0*3PQ%T+CLTC51YS+:K.X]O/(!L.?>B*FLOC?-BW-K4;C%D-O[+Y#.WF@"
MCLSTZ8QIXX7OMN"Z?;51`!PO>(B?E=,)5V`$"DL[3BD:)QI/QSZBA?BGP]Q2
M3"+":`I+;]!%]5)?(L3%-$'AJA[J-PG9L^-BAU>=I>/-T9Q)/:_6J<U.GV[7
M97Q3(<W-N0W;(G`?S:@P]P1\X-N28)",J^.O(@5E6+'+7\MEG.^>4<T[6-:L
MO>C$B@-)'1=$C:ZKV1&AX<X]/0`7W8U.C##G+=#N>YIWC%QN#)+M-"^J4LJ)
M[(/2:S=,]P+H/1E`V\MC;%SF[Q$:75_UKQ^^ER179QYT+%#N41E([R("M_EV
M:<FL78>[.]+^SRBWJ$3X)R'F)S8N<_H34KV#16L;0T?V4>1+@6](H#&GQT&A
M*7R4F63>8YTPV7*^G.BX;1E@9&A9P!O[?H^!1K!,=A0)VT+`B@#RCR=@H:.-
M[C$D8LU_$M$!N35N=>S>#A7.@@IYS63%!$;^[@[E8M'Y\,!F]J)1XVOR1$/B
MLOA,;]-"B)XY"/I;-K0J*S[BH7*27_K$[YO.3,!+:;.Z?!ZKO0#>!)U?,@N!
M`(-;^_-[JE6$'.:"_HK2&\L<P_#!HM5-3E9)N&ACWF+94MN8/Y<5*W34A!,_
M;4B01.!G<EOL)@G,0?6S*YX,`J4Q&TV_/&Z]IYX]])8H/$XBD3/AQ\5$`91Y
MLUY`?7AY6X_[*3^WIU4^2J;:^RNVY)J;]H8AW9D8JM6_3#[KLD?*!D_"FJ/+
M4%YI"4ZTAX%:,JTLW!.28M>[?A/W*@'XF>"U]Z?7='WG07;2Y>IS'NA5-5<I
MQC?(=Q6^A*E(GR&;\3>>DIH8FG=!_<GX19G1J6+M[/LP&I4V?ZYO)=32@4F*
M-^D-)P>/>V*G3SJP@J1^7XF7O%Q`0@0]>`+1SI)X&II.'I#H)9.8.&Z60X#*
M[K7WV\HPR>[@:7%)),1N^^03ZR=`T?RQ/C$W4<L4^/$+N_@0<\8(",(MO63Y
M%("4[:>O\C[Y8`76OA)!Z6C*?=``W61S'B@1QQT=LU@!`O^=XH4")S'Z-H.T
MHJA_<P=<D79X&JTBXZU-`O0"U*:0R],$[-NVP+\8DPHSBA<3\/25HAZ-JTA(
M_=\OK+#)4C6]3V1+Q-C\SA\L;CIM<EP4/23%C^D?[?(FS8?ZGASS8?"[I!DI
M1KH*]46$^3&?4$X,(3`5^%#+I9A:M\1R&'TZXKD]+7ETKRE%0D8C0GD%`E]6
MM\AYT*)E(?>HKJY1_TEH^43(WY)M$0X*(1P`EM\WYJ"GCV&F'$W3%SDQ%5&J
MX3;)677`ERX)39(I?=4Z[B@<9]RS+HX#^R(;U+"@7/TMFMK8V`!1X'7/Z/$:
MRPL4JV*LXB41T$'G8WW"LEP5*++8*@*:`<TF@K1N.AL;J5Y'-K*/=;JU1@6]
M(.0%'&>?.F=&X0;ZJ91;#M)8GDOOP?J45U#>A9]APQ,@Y56E:,AM@6T_"XT3
MCV^,]_L8_P9>;X[QJ94L`0[GQK?<N&\#1&C'BL7AO/59L:3XT?N*DI/0KLCE
MYBC=^76=3&/<TQ.M]Z['W!E>-VHB,_CY8Y#HJ7M'_-T9/$-_^YV1_9@D+%#W
M*KT#1@7!_JG\Q?*7/C+E32DAP2>-YOKF@UG++E-CA,U(FQWR+I_YSADT2,TF
MW2IL`&PQA1DW1"/HI,('D2`Z=K?:RQ$JWA3+OI>KC8^N9BC:V-%;NF(K2G,-
M`'S#Z+VF\@/LDHR!`8PQ4U2P'+ZL@7U("K9JZ-C<E*>NC.4QO,7L$(<=YFA2
M#8YJ_;>F!IO0O:[+;^B4`Z>GNXP2_P'3&J=\6\@*%<]^[VLX(+U^$:@YGXE3
M:P-B^8I?IQCP<WEY<#,%&TF956DBJ5@[:2FF=.VOM06<4%&0JXFF<6;4[!*P
MK0[FN"\\V#D/Q)1TVUV.'.%]&:ZH?YB1*KAB%"V,Z0)^_FE07707,5URO7)M
MS?C:]UFK/)9*P])F!3HK\_4PE9_1$;U#:J-7+IN$IM(RQ?A@Y-9\K`QKG5,[
M(U#>7LFRIV5O0CZL9/<$(@$0?RLJO9_9,IA%PN:-,F)(I#$PT=6!8(]9A,C]
MXLM$+5[LF9)F_8I,8YLZ$P6HQW+,^62<8*C'.W?[O)]MT1\JI$/.C]/E>BAR
MN1[@)G^O]D"(\N:0N;4W6DQ>CL[`N)%O\U`O;SDG=AK-.0;H%;J$,-BTTT^/
M,FU_12LHT`8[0#OS/5[T1'%6@:+#>G7EN#NS>V@CY?QUGR-88&PH20C6J53R
M_-M:YDG"."9\_KU@Y6LF@T!5!#\/(1PH=?"2=+SP_/J/;IOO#O3U7V,AVVN!
M5'B*S1[_U"F*/G\-P6[0X:$<NZM"_@98/8D_P-\E/&XTY5D<A2:I:8-W;7(X
M()YT=]W/J=Q&V<9D6D@U[R"&ZL*T8VC:G.%#K;@X]N%F?"-&5=[/D[\X'O)(
MM?IO&J4J"_:4BX=\J>>,8[_,TV>ZB8ELN#=2[<$.V\&>^:"^OAL2R@T2D9?7
M%16*MB7JE,1R;-#V\7F\#9OF6]Q-TE]@9S>=!UV-<D@S?*J*34AB[]C/X+YK
M*8H-_`KQKC%/^.[FS-NI=C2$"M*'SM0@;CR^UU_(4,2K2Z(=TA#$(CM(1X1%
M1;7:!H*XT.X</;U&G@NAP\,AK(*.5A^&%K+%5@E!Z^8BENBV?E81U@)@21W'
MY)A+RN55_`%D;W3L*P4%F!G:$G?'D.^6Q*BTIW>A9$$O8N=D1F@EC0B79^Z'
MPO;.A2QVK[*=/JYD5Z3<L.8L5G^WE@^%R+6&F`VK?V`X;#[K74:W+;%)=WP"
M*^`#PN?AERY[5'./LG,)3K+PYI/[^*D#2$.7@R-WIQI3VFM5@O2[A]J<SOR[
M3P<U>E_7U6_65B_*#A)+X2$@B!8RSGE`L:7$U[4T.`,Z&N+TG.1Q.1LX`YC=
MU8/73OXT!D#\"!/GRZ.5(W)!37T1W7B8./&V#4N*9!N,+LD_O%OVRUIKEOO?
MC8^<L(5V!IN@KZB_L#XX%_Y9^>E0]/Q1F9[F=6Q/L.1-"+7/3HN92/3@-[IE
M87ZQLEWXS*@`_^Z5XT3OU,]'DS8TVT[3$7NHVD_>IKC1728P_0OQ%RKA%82>
M`B$SL7TG`Y"26OH:U)/=A16ABV+F]9$%CE<)+?@!&=,4S'<$2QB?LZJ]R+"7
MY=QVM!(S0)96JG+^?SN)P'&/XS;<+OGG281P<U5/7)F0*?"C0&-U?.M?7(^J
M9-F^;6>;;<,T,U8QV-0XQR:!X(`!\MCG9-1HOXO\M22KS&P,U`5'M0!@F(Y]
MI#*8'Y0"U8`W-;WM;Z#`1UAQU0,*AAIF"BRLD/-A'D3B>QS5\$6AY5%7EJVO
M-@7PB+0&.A[\<A2C"VI5C9)R;QO;:'8H+"DC8TY-&!(/AL>D%"`7$Z=+&YC_
ME[0.9VU708T^V.="2O.>W4I6R^:.[B]&+H7`P#0`!1PO,\B,GW9CTC?+]CVU
MB1S;L(Y`2NENB9/^"AT>V4>;17!]0[/S,HNP&8H@^VGV2@DAW,^IYKN9E%+K
M?(/.U%:0UMFS6,FQ\V[`E,@,9[$USM"YCT']V120/H*,&5J.1H#F%_`&**W$
MKLBY<P<&PZ4>W?)+V<9/$N&'1/T7[Z"?]F)`D]UY'S@!@!4^UIR2$+.]1N2S
M[,13W`):PC<`5+\,)+FDJVY>J*>Y6SOIOK/!UCQFE)T:*,R7['^`\&S9D]0=
MT+DJ*?$?:JC]&4O$SGWNO*\$:0^Z"%F]SPO1'.)KN(&HH@ZL[E].%^T6#Z`]
MUW^&T:PP!!CUJ&3HFW8\>^.^_GUP&:2A^O28\-*5N\^I:AWV&U?8"9^2E%R^
M1]Q02;]:(4HUO&,%ZKU28/RX0`!7M>04'Z0<!?0DRQ?5!3)]UR/?;/#0K/Z9
MQ/T1KU3`+U5Q>I]"#8J'4#E0#QQ)LKJH3X.EGGL6Y>3KM%:?AH_]69+*,N,(
M5(\$ZJ?7;O-^M"/A[PR^Y^=B82_%(D^V,6!Q\G_M&+G<>KIPN'@,L)U;>`!0
MUSA]8]Y20AK*K-B[3L,@PSQ\BL\=Y#D#PGBS+<#-[O&5":%C@/QJP]HN(<%E
MGV4Z$<;/HL`0[EC-#@:[I-/X$[8W7)0S.W&3>4,[;<B&NT=5KB?FA!<1)H]/
M99GXD5)[KU/D#]7ME4E'<3IX0F1HL_J1ZFKD\X[,>KZ*ML&=9K(N#R'HH0-T
MI"$;*EB0(;/?J_YN#MP>K-`RC6-`5>A]$JIFHY1&HYKE>X=7,4(=9.]QP(RB
MN.\F<IH<(L:6*X0(3],67&4AL08;S&/>4@0@6"$*,O8#RBLO`NS;KW6`)8#=
M62''>T/FP\;R-B`KNE,8Z!I,&R&*H<MO'`+<=_2V'`2S_.V7OQ05Y0Y4+M#(
M_\>8Q9[SCYA%*1U-L';*"AS/B@9Z0(1P,E*F(V4%5=),Y2K'`!\_X/-`:[VS
M7+^YI"38MB,3$$\*-JP4467_9;K+#0MC+1@+H1#H+'DSQ[#+ZPN>((5-0[XX
M>>8#_MX_@HIR06IJ&FS,UAFY+6DKD\&E.`G8*\MN_+;J_J@E(AHX&]]$;01W
M[3J.GDVU=MUUAD4(7ZIB2Q%_NP`P]]HLAW#(;!CF`D$!2=07(;#FW4%=X"=)
M=[D+N6A"1UYP4+SPZUK,UERT6+R3`5YZ(VV0^QT8_6J,$5JZZ0$==]TTE2/"
MX@<SY3/]L+)Q.`!5A;:X+6C!_X0Z8()8:G'TFQ8LX(0:7AK\7`!;#;Y9QK'O
MD?OH[#8^2!]Y>T`V,\+1R,H91T^D42#^*8E+53<,]ISUX?FK$7,\-*=YT4&#
M^3I]W`J``UYS((5R()9&;Y^K%H4C$@]"EZY\^THEZ'>4(MWJ2W+L84TL6&H8
MQ%+#M>_B$IBC1(T9`DCGM\+OK_JIA'#'6W5'_BWPJD;G[.J\ONX!,6C\8QL0
MU-<[+3IUF7Y."DOE%&\,U5ID$`>8G`Z,YUUE>'SFVLW%FI2>E&(4E1MG*LGR
M0/T:'QY$C!N;60V[+!_94,?Z`:(!RFS*2#S,?EI]+4?EI,E>90'JN+O^WO84
M&OM%(#/*\24F\J+!O10*PT,+T9^6VU"!8&SP7]\)\_6`'B0W(BTN?BO(]R`F
M&8HQ2)I!`CI%HVCD^-3<,;^,YH9,[SI0Q[AG!:31;W@$1C7V=!F(0/KY8\_W
M"J7T48#,U6Y10.!/7/:&AW\,TG\R+\7%F'JLJGIA\DH+D>83^N6L[=AP=7>1
MV4=TEX($93FM+I\[#^6?#SBK3\\\QQ$Y3^3/;:79"8+SBG;G]_?-?M;[;AD%
M=>5-XP+^J)=SZ)S$;;*#$2)WX3FA"-Z3XS0NN`-;HMI>#3O-RK9FS!S1>GGB
M>U0C3%_MD897YW[Z='CB$`OW(C$D=W9))1H,M2XM!85`:`@-<IWH<9+X_'4]
M:56=1P[]06X;W0;,JT:251]A&W$Q%L0`U)Z4K/LRDB:-%R/97;6^',0$2L<3
M*&5T;$0W.@QP5.T3G*X?R?E;+J['=9^V,!?2]ZX4<+^+(R+L%6EA/I6R^FZ>
M@=]H82\SF<$(Y#KQ?/P,N.L)(:@S*CO#]WD/5;-EW08$P\V#S12>3\KOF)7]
MY.DE.!8IL=XMIWEY4TE64]ZY:-YYM`.,'"A8#8O\YOG'%.*>.-PW#Z.Y90/;
M>E[LC&\H:R'=NFWZCLKP&!S#!6&#MO]W>/7H:(D`%#F?*W1Z*5Q!,L6W9M_;
M$I;B.N[,M)II3M.UP<@"\<4P?2EL28KNT+?)N(YNR8*J;]3JIP[S7D.0)?H1
MF2J@2*APQ:<"N/7\E@BO;Z`D*Q!]YX5YR%>@EFHL$D_@3D'J&57VI4=8N*I.
M2@\74"_9R7:2%=EH>69,2>LC(:\+4*P3O./9B3,YT48L/4.[\#^=4:X,/TUL
M"TAYEPKOY8MXQ\R*[9;:EU9BK:7ZTDB'.U/X4XL1A*!Y<@K<1<GHL*3JQ#HZ
M.68IBZ"W-#$\O:<8@#2S+P0>Y&Y(H>8$1%8&JN219S>:R?=4$WP;%7O,1YR1
M7R(W+SW_BD)CA?^=^_@30"P"]-:B*;&*%=R_KM`.6*D7D;*2+*TC\5>/NFD&
M2]*M!QAW`:FR"/C@2)2?RQF+CV2,YP9J<Z3FUU':!<Z7>JZ3(A]#E8F&QA(Z
M:-BG*'K2A%/P!N>"L/DJ[=!KS>N$K'K""'93#O%SJS+\)Q4%IAP9)=N9PQHA
M[H?R]'6$R=$%L*>BD]/]%7'&CW7T`%'<IO#GJ9*#"X7+M4Z:IVW%H=>&=&BA
MU9V[";;U!,*&!I,-\,=A(MKV[G;&N#P%/!%660(N`JVOM!43%5-U?\]ABM2A
M:SYR&ICF;/]3M4]3B_Q6F)F?!P?;0X,#O^[N+9J;Z7>F$Y!9-(<,UOS;&.3^
M"#,1`5[54Q:`$C4(&3QME/%4']38^<(,4Z3#E_].(4;UOKJ&2>I`&R;1G";1
M82SR+[071F])L#H,Y+9(2-R%T,3L]D#+]AULJFMF=V0W(SD(6%C,!F3JEQWV
M,1Y=\3>OT%:63`DU\VGA0R!US^&H&AQW,,R6-=,;$/:/:A<\]?IQYN`[B/95
MN:NN+W6OW^2U(HWFM;,KA$8`A6W0P(5__<8XW:=9BN2C(4Y>43@<,8W!3TF+
M3(FH$(0,);F[8;%'W*JKES8K=7PLG.=;7&J(Y+_*B:[SDVNU#=S")]E^>X<8
M8,B!'9DS).-\='SY^QYWM5KFR0,DNPW=6\WT%O/`69,J_!W>$"VEQ6,:AT,?
MJ\52UY.N2IJO@!$K+8I:HA&>8"^<SQP@8!/2=L.8%E7F141"0MW75#BZ\!;R
M+RY4V\Y1WXT5UNPD52GJ36&JO**1LM0<(2G(:KD=J8T$W6NS\3TT9HH!K[Q?
MFAXO9YLZVSS)0FTRZ1OICQP%,TQ&T$&LFXV,P-"=B&J6DVB-UOD%/!0Q)N_%
MI7,;G>G>J?4T]PS<"W"NU/7TI0JL"@L%I7]KTG:!EB2'>7I?G?>9\(]W4`7_
M+4"`,;$_$0NMG^728+QZC-<_;83^L33D*@T.(M1'QYN?EX&5)8L(KCI[USBO
MBAS'F."G(X2/D3J1#A!DWLV6;;4MX;^+5TH-T>E#:17F8*Z*1&ZQA]SZ,%`Z
MAO'1L>J99LD6/.`Y>;[CT5$4"P<T8ZCHR>6HN<:7##>MN5/FUG@SJ*,(_;VT
MOFM2$LLH(DJ/^Y?BDIY"Z#[H.OA_`]%47L*]U>;T"UA216/$"XPTC`WX\AZ0
M$!$J#.RFK`?TA3>35%GN8#3"(XI/G4;SJ+-_^&#LYKLX0'(+8F6]7\B%]>/,
M+PS=6B]JOH7UMSI)/L6&\D6ANF^`0:#FM8R<'F0NQI)O2V7E9^2B_<ZLG:/K
MBAD`PE'V/(]$51^>D)?\:!S@+RC[\*VWIV7!X6LRL@"VH0CDNHM@\$GY?D@.
MN=A85HP7%^E$CF.K=WAC0EO60+`CYZ6"+KIQA"@^H'%BS/C4X=<V(I\R`IA)
ML6K4)<OVR5"FMVRA@NU`6EI,KDYO7#81\2BY%PZWHT+TQH:<$D.WE"J;F37\
MQE/9_YAF9.05+(=GTE[R-18%D'E)/$(8UN0=&%M+V-14*4UW;92?:4:RD?T@
MLA?GSI9M6Q_S=+BO0F5NN!5=#VO!.<LK"S9ZO*Z*&X.[$(8Z;18>UV_:@HEF
M)R":(<9V_NUBS$`JVTMB)E;2*WSNK2#,+:B8-JO'EVL4SY]WUN$R.R@02*P<
M'O<J$?&3+TKDU23CX^=3F"5CMW.N2W/-,/#15,?AG!3BKVG+I=R>M+5^/]*[
MQM+57/9B7=YR'44PH6'[P&U_[S8"4$G%$+7]WA\#*K$T]P#DH<&0P%FXOR'@
M_J;9L.-*R3K?<'LI56C1:"KT05UV7_NP/R@3*)-^F@%//AI,,<*.RR\&/CP`
M8#NJ*>5,V#A)V%+'>0?U;UO<4YLLZM\Z.4#Y21BXZE7`DQ5-P.""?HG*V6_H
MFA*S3:ZADH``_A_PLD:8=/;J.37>AN&BX,#,11%&ZQ(7\!-R]'#+3TZ7@*,$
M;(BFABEOSY9.RRP52.L/0#N%[2$$XD:13&\EF"5%1@V9!B$'-YV^\X[L01.,
MSP"E]ZDC-\K?G:WSAO"''5;)M%BBIHV54?_[!$O6-V7<;?8?$6U(R%D$=CDC
MVEZ_`@OWX%P.#Z6C\:F?#T5_S&)%KL11S('B\6A2,S\4/Y8BZ\$%QL$F,A#2
MS3CAI&UR)1C3RNN"=EOF=FLKF8Z#;9GV)OD?G23GGX$ZC1B%P6#4L4N&^<0Z
MDS5.0HX!2$XU-"*+?[:E9`WL,GQB0^0)<12,=GTI)U.H/J06K>&)5Y_%*)XG
M4('O?"O_%]RMQR47UKX@CRV,]2WFC9AXR+_?K>X`QEW3&'IN@67[\7[4*4A_
M_[9@S0%SQ.<H"?BTUL67UDK+33?34)E_1^1(QWFUX(F'+HTJ^D0.(G/=_F``
M)[HS^!'U6G9DNMLO<-W%P_//TG.1S'L`)`QDE1,DIO^DUOSH]O)?8[\:^DDM
MZ]!>6+:2=VC;1'^"XTOQ;'%K7],[!,Y7RK/$RI3P1T!;VXLQL7,)NP!RP$?<
MJ[HU,JD=[>5<*COUGEBX_]G^C^\9R4K@8<N]!#9LM[%X##-E],Y_BZJLR"N'
M1]3^*1OCHC1>*I(Z-\K2@:$ADGX.56)+9B<N37D2?R#,LPVT%REXR9VYF;DH
M"GS'1DXDR:FO3-VO<UE38FC5+!#])`/"SQQZ$\AY"3.1H8\6$O_G0FC:8;MX
M##J<97IO=\2/U7EZ.1\]9WO'&++S).L8IUN&OM/>>5C?^*Z`[`RVUG?J`X`R
MJ%"U*U=W$XR+/L7QW-ZU[ID<#/:#YD4W2M=.]CJG9"D9-R*2MMVSK>XS&/Z=
M][J0I)[.['5[FT9*_-,GH@9\D2:;:W"$`?'96R-KI<I/E5))E=_$=>+D:M7E
M,UW\_$IRKMBMG2+!12]8=;B<%O\]VB=.;C]L@T,];2(UY[3"APD9/R3=A-'&
MO-CZN[AWJ]UY?4A7I1]:'>@BS5;B$C,F&(=#>9U)=Z,L3B,_'I/^_F)4IO:.
MR2OHCU\B(-S>`^:-M(^Z.L")NX]%7>8X:IM^Z/6?W<.5C[$S_%W(A]!WVZ\?
M*?E_]U9EEZU1)/HM8]I`]3DQ=]A/G'IBC=1"]U.&QZU@Q=)E@PG.`P,\TGYS
M/K&S>HC_TWA3WV])/SH@_XP0FL\&F/1U5)C2<2KR18IF6\T5K91P/U.KT2Q7
M_C:!+$OI5"MRG..D`EM-/F]0(D>2\<+;1!*GHI%W^@J#=:]'/JA4<*ELH9>I
MJ#C<L2E/^&UX<)O:>'JK@^LW"_(GHR.#P$VUI+&AP`97?\.S--^-W6P5)Z/<
M-KR2260W8%4&ZPZ*AJJH9>UQXZ]HK;4PQ]V(A6.W/Z;/9>KV2./=F;P=$K?&
M+P5E3_>Q['R<Z/25>I('!X-TCCD3JTL=1X[?<-3U@7P_1AA\.L,Z<`+SJ\YY
M<P<%@YC#P$AZH#^>7/+=>_K8:K@-JO]PQPP:OT5\5Q->F:S'-N?#-9'1=4>B
M'9Q1S/4B>-0@*`Y9T0?(#VOK3$@R;KT>DRX9>18GQ<8,"F7ZRAX(I"8TBZXR
MF;/,<3+:8-"8#UW5[XGH[7.S(@9K$J.2^%"^>$]TT]TK(J`8LD.T(H"]?'45
M">7]HM*+<_3;ALF*9(W059DKRJX\/9K2]!P4\<*E4:S[=,2U+D03/;?_GGYF
M".":HAS#5*G3PV+DL?["E[9]W-.K3R:/N+IX?.%1[KU=GRTY,_[&]=\6*A^?
M>4<G/>;F8+1]>IJ7CI&5XOK<C3(_G7BWM[!?/8_H;#*VE,#TJ:/3^#<`4?--
MY&P6V=Z2>?AO`"`VYN@XM_^'%'#I#_QO(5JJ0HK,XRU!JH2I$`IJY6>%[M*_
MHQ?J['N**Z#E3%@M;TOERCY$#)?1\R_;A07_VY-6]P?0VRH,G0X5H9L`K6`,
M5-Z*3RZ^9)DN@_TB"(UCCV/9A>.F<,1L_>F"T)PDR%_H(?$]&?R.*4UP0A"6
MHN9+__%#B'G-8+;1[2`27O>NRPD+3?,4]T*`JX-0)X8_7WA>;-$?ZQ=D;@`&
M9XI^(VD$2:W4R_F1WJ,1+\#&S(?-L:?4T,/K&BAA&B#W>U^^S7\O/KER/QX^
M+GK2_\SMW4L9&J8_3]-5!!1B;GI`(?WZ3;7+X.<IZ,S/PED4'6HB>3Z*8;+H
MM>\2R=6$M#?-N1'.&/5)!#4WOX&"<@]C#?MY;]Z&W=86]"D_Y(TBW>_J3PU%
M,5*T"*5+I$R"-^]VI;#&Q7JV<(2F0!G-.-6[`Z'5/99;(^N5_QJ.,0;\#="&
M]\!#\N!A)-+?>NGA=:F5L?QL?V=SR:+)4,[G5J+HM$#O5WLO-_7#;4(TSPC'
M0E1#N_`*87(ZU1#W>66AA,?F8L_\]A1=.[P!!JL>ZIK5&^AXH@^FQ@64WHY(
M^K.FG$6]`*NO$N88Q5\>X&WHLN<LAEXGE*X$08EY@S@.LS!X=,.(2"KMRQ[%
MR8]0C4HPO^+P2O*+/MJ!\K#9W,?QESSG[34E/(Q*<H7_C'F6>45V>_*3>*V=
MIZK6ED>TM/`Y7W,I$2N]VB4YZW,+<<4>]*,XNQ6!1#0XNJB03GI9/].L1%&4
M"6,(XC0>J1V%?#J9_7,O>`J>^CZ6^.!OR@]4WYB5FC]`7:Z2=J^,DD;5^9V!
MLJL`C39"JO2]8#T+^(%>DC=M-Q%$OIV<`"G'7]6:!EH,@DTC(VXVT<ODQ(DA
MZD&N^AS4KO-.-*;XT;A>;B%S-OXT]Z&K+T+=NF(12',]69,+,+THQIU=);Z&
MK2$5)G5KOF/F3J>Z(L)VX^EQFB=#IU=%`>YSE`&LGN>3D!+I5\I9!OE:R@K;
M.!I=87V<H&L\X\5S;Q:&&/C>U@BD=/G'=E6I!T,7L13^DP"B?#L*,NQP1IV[
M'\N<`1A[*QJ/)S6H@0NHPWTU&&K[#>%*E6'/:(+<X:BCGY>)/+&03D42W3+7
MNE!J^,]WS,B:#-#+,#/KB;E+01+P:-^&,TD]6L(6)4N"Y4L3_T8T?J20/<Y?
M)I(YDL'#+_07BRS9C:Y=D`=0ZD``R3Z-8#PC>',2K[R@WDZ3$!V">#MX7D!4
M#1_;<?\C5'^3Q>QC1I+@[EGX+X7RAWV*B*I&%%23\JM->QI?4"=)9:&(77(#
M+"HR4*)/\C,'`KC+FW9XN%ZGB+:1#`X--?G2(,!V:=72[94?>KXVBTS#N"1%
MHZF<;Q$4WMX<NJW<?X=@#D0[Z$,"?^;O@YIU`]PK1;.RA)ZC2Y/VA%7O=T2F
M]F<CH14?60XUDCQ_+UB:59$&@3>WW&W4'@;Z.F*K'785(D,Y$/4$(.L-*&V^
MH;"ZL=L1D2)I,LN*ND$KS!/-,5?>LF9/Y+%_4JL_'11S.M5.B(]:[0GP_&9I
MPY+E-Y!)C=A04B/GHF-YD[K+X1+DBZPW%!=]*",Z#OGO2ULR^(23K6FI#"70
MF(\%!H9ZDOMDIK#S,"BQ[!7YN=,%VI7(.TE(R'1PYM?QV$"/_U&+W^I4-#ZI
M)975Q7X7!'@'%YSOX6DH8?FC@/[^13;R84B6O5X87$-GN4-(`9Q@-%Z.GW(V
M(`HJXT4[-;:MH3F[K3U10C`%D_GJ7#3KR;:UQ],/*?[+Q/*XAQPU<C&]0``K
MN\>^MVF"Z9IE/%0-=?R0Z%O!;D!S8/(-N`\!CR<2C$;IO<'&!C/.(=1BY.U&
MNJF";-?!W#<PM+S9&LCOO))[IM$=--CR+VM_\S5_*?A"%'`T@H5)N0)@4H*V
MG=RU[P`W#Q:T+ZF-#1U';X/J$E?7OI<KN"<GY"-ID+8_0!?&@0]TL4MK)<O-
M]6JSF+S_87*BB,19Y(0).CD#$>`G_UZG,61##&1THZQF0_CI/J/B)=GET!<T
MYG+I#94$[U(?IIT?YD>>;7@+^'JC(%5L_]Q+GYZ-%PA:0AO(ZNS#AG'%Y7:!
M1R2!NW.L9TL3PK&J*5I$K9-S/S)B0/8>30)BQ$8NUT%P57N9ZTHF4RUFOFP$
M-4RP<G'X5MWSOI`HI!%,IHJ_?.2%V>$W;])I(^3LVR9V9!?TA=)I%.`4&]7=
MJNN9/09+C674)HSM8']604P*(T2GDGO]8(5I:0'BFP6='FQR\US[9F(?D>0G
M3(R:IJ+;BN)CO'B1=4KIZ8J,"$VW!A+`4U%G^7C,LD1&['S[I8O@#T&+!"9>
M-196UC+&G%N'(RX@44?`'_=RDML[4I76(*(,13HM[)0IY\6W+"$WQSQYH/0F
M'!<4T\T+A8#%0*OEG4N-?.)55WT@W\)V'#[K,5^W6QWYAS>/J4M^%D"#2%H=
MO?OU:+DC:=+<5'T#U>=UFK`0R=A05@T&QFKCDN9$CD^;O-;ZV$!?QD0M&6K6
M%BU-^\>OQ0\'%:S2-H6^*)FA.%F6-KEA:12']'_>/-NI5#M8<$B9M,S>5G3O
M*'XG9/.7[^(,W<HAGV)6D[@RCEQ<61.NZTM[Q1U"Z.[:^"ILWFMIL0.]$T@5
M8K*AI=YG/*;5)FGM"P>E_;CS>:L">:X[]Z*3OG6/L@AXC'+G&MA^V*:&XYNW
M+)XW8+/+(MBLIIPGWC7_`&(4;?"06?F"(9#K))>VITJ^`*U</7AT607MD%<L
M1%'6HX($?XN;[9*IPR9#/>5%7+)83H:W@<]L&8+H"&G1M:$[)+.#4?W:E-))
M]0"S9G?\H*J*!^ZKH,5N;ZZ^;1K<9U$*[SOVN^,3`+:/[9I(^I9ANIBS$19Q
M&4M+134F;PD>'<,"0A^^L(+I^(NE>0\P)\-MQNY;5GX(4I!4Z%TQVT-IX5NN
M.)>6*V*M?6G"%`N-F>"WECM(?FD)9=6\8GYEOO==DFN%'5N"`XZC024D@]_0
M848ITO:*V!I9]CEP#^WT$(5,2=\+BZ`=:>SU/DP"R-33+?>_)<E#]B;F[>(;
M,R((=#Z5H?Y*X@R9>/^8V,F"I_4F%:FBH-CJ;BC%H!K[Q<4I7MPJP$:G3<=E
M&-#__F3=RIFZ9?XA)1.O`@;ZR:78FF6F%1Z%N&!@Z^P8G/#,`BYXT(C69S2U
MLO!;L0FHN+I6C>2#X;;]X+_3$2</'I^1%F&4<5A`EG==P]B(0^GQ$]QK_$U0
M,$%7ZA4OT`K,1,V[O/U$!4O2%0][#CKR-WX97+[0D/][^31-W\M,4/T`T2RB
MS5PW-SXZW-KCQ2DLZM6J1#F1]`R-;2H:,&-9]IR9JA,4[L;@O1Y7BP>T9$`N
M*/@<]CY;G+`][S.;G*+_)YKX\!%J=VYL;G4"?4>7A-\XU<0"->F'9QVZGD">
M]Y-%_@?9I\<RAT+6O[82!4S*S;T7)E3/AK*I$%L[4]UJ+Z@EG8]$7Q^IR@/N
ME?3<^_S#<;12T'ZX,^OCB?+N#S!&V4*XT5CV+;Z/2O.Q?QJ9!^'N:^!4'-,*
MY[Q'F8:+*M8!37+\>,ZL_G>O(%BOET(L8S,^L6FN,P]:N;Q9S4(+%=@$[%B!
MLA9ZQ8Q/`FG@TV"=#8Y]/(3B,<"E/"#=N0!Z!JBW!J^(=G+'?J`M&1]Y7GGQ
M/]JJ76K7P?NGUXAD%1+/<YV_1<.Y4X]>Q8H:_L44'#KB=X9+_J)Q9)RQ=)5M
M-=RMW;==<Y$<64:4]7_5T`N.M.+!-';KEJ.XKK1X?5O)VQ&R-@F&BDWYV'6V
MXH8^[MFE>&/\G"1@?(Y23-'/?$Z),6\568\H=U^35&[VU`7_2GOZ6`>CK:;D
M=6NI>(\Q9A69L.PU9\C`W1#"_/0ND8KO>(A)0(-V<)8'6X3]Z`P.%:K@GP:[
M``M@V^969P>:9>5I^W!16:`'O9GMIX4]$MC"(U.D)#*6<4G@FKD,WKA.Y<D<
M?JZ+B>T.=3Q,NUCS3F85)5_Z-J%.RUN3+04HL/V[5>9PTFJX%)P\(QQ;7W/'
M8B97@G:GZ?RF&EM,*Y(<.4,=R"\)L[8.R)B\5!@R)WY=@^CN&]8=KIWBEGFD
M%TGT4>F8TD1],+#?E_YP&G\8A/(DN%*FL/`,X%29^(IFL2JD8(S%)N_WJDAB
MW^=8-/B9^/[L4EX/;/T'D><_TA>(;*'<LE?;1ITL_1B:]EMG)UU?2HF6@V;J
M)&:`:3CP"PPB'AX$I6Y=.)E'_.7Y?\W:(A?VX1I)@XTX46]6D%H6N6-RH?1+
MT()X5H-"HU($*AHGE2@GMJ][7$,[2@3BZ1#VYOZ?&GTP3QJAP[9][D\R<X!3
M5.23'=F%QCEN?JM7*4%R"\7:W=C(U-+GI_LYQY4KC[;F$'R)-6&G%M10:3F'
MZ-8'6I6I4B]/)`Z2&+0VL<XST^>P0H(DXUZC:-L)?=2L'\!=:WL+<[2,DN/Z
M2?@7_`"8V5IS;M-=MA2Y`K=]8WB@7_T%LX_EKG%@'^KNR/;>%:A&_-P%*=E6
M1L]-L[1GR!!I>GLB)[DRC%#5]S0RE8_1VUG3D_LJ<40Q7#0QYX)`BN.F@+^T
MLJP=',648&8!C*]B3V]Z6SDILB+791%N4_A=5NU$*!.$[5K!(4`/1!$*2Z[6
M39ICB0"F.XI1=R!8<:,$O&9T%G`#Q)MTVN?2WCH%$I:%>)%H[1D7=:@OD8>,
M*L`.`54^R`G;YN['[I%@_OJ((*PE=&&;\".<#1?^U*XT`#8BX)[MB3/!,L)_
MD)F=%^K<::$@K`JUDZAT-8>=(TWMHY[667'7?I6`+W+5=ZR6(>857#]NOYCZ
MM]NP7>!E([,T`2>NUUA]@X>;,ZY0-A*@5DYWAYV^IU("MQJAF`XJQ&:'*@>[
MC>&HRU7']A4IT\C.YQLJ6/T4BN1K*'G-D$;0XS)IVPD8+T^JL=''SKJ0W<G+
MQ5V!4%GAA6'U19&9E\E!1DZ_?<L%AKL3\7M>+:W_\=.[X+%-''YV5`A*^;F)
M!5)@C8MG&C=47:\?V^$J1M*P<PD:6H"&EJX04%B$'%1K'U57[%QU7/%1EK(+
M,UTI!#;Z%&_H)N4;YJ&_KF,(.$&^.:%E!B=%/%.YRZ<R`T"[L:JNB";)`OT]
M$D\2`GJ4X=J5W"(/;1)_5>DZ2VU[GW=W8E%[[,X`\Z87SIHE<EKV4?>_</E:
M_*L9&(:Q#C;'H+T?<>G-<CTB_DZK!@4ZKSXK'A+YCS%13Z;BDT\R$.R@;T>#
M.]MPWS,'ALK]8AEI2=F2'`IE<AJV>H(_6>JZ,M6\,??C("!]XA`IP2L$*[>H
MV;B*=5U@AX@I>>G9N7O$Y\.R?E2NU4E?B&?6(6##BO#B>Y?=*0R30N8SKXAZ
M-?P;PGAU7@/\C)\RE/!YT/5?0>7I6*%TS]&HM,\YX3;[R)ZY)LY#2EW%<-UR
MGM)`?CS8D@RFQ=D)3SQ*U)Y<&Z)A&ZX?A!1V42U:>M7W2Y,PX4X5/Y[HE9^8
M25)B5'<O^R^U26.=2?G)W:P%\\8NCR19O0$^5QS)OD/88H="!LR>SV+Q)I^;
MB^WU'/V?O&H_'9Y#T-6>I#2AS8G17S2[=OTL5#DM.)_N07-NQ/@<?P:_.V8Q
MZ13:&"^C5H?.YY"`\@71Y517*Y"C%O,)AWNAQ(!_R?$A.%\ZFKP+T;?.`_;P
MEK)R5/3-M%PY@)EV*K*8S[LRUW*OZ8NR5RKSL'$GFY*?'P;'IUV#`X39U!IT
MP8,Z7=*[N`00FPN,O8FXN]F\8MVTV9RXO3_#=G^H'LH@3O?%G)0QJU_BS+)J
M4VY0%/*EC6I=!%)84$N_^5&6T`QDN[1XDWM8N"29U=M]__=MIZBS<#\:"R`>
MY/[*&APC:\;4*Q`O<3$Y1"3V2;;#Z%5NW0\<`+M;@Y?RJ?"#94J.TMQY7-E4
MY")@#)C%XV>3%@Z+N&H>>#\$K=>_@_C*:"<T%NIG3GH"I32L=;Y;(QF=/]D@
M07A@(!,[M90`III@+(YW8N3&,Q-?Q(,Z!7RS-_)$1B8B>2<3CFGN6S2JU@`9
MTPS03)H&P#70C3%4CCK"*/N<8RAFF0C90V"9:EOL*%N6T'JFCGP^M$NN5AOI
M=U^1'9,5X.(_;QF'J>`DH6+$$79^8%:_+N/%(Q7+!S#F&0W=EWJIGBLA/6?`
M/1$R0O#?V"WZ0XY:,1"G+/B8$GST\+1R6!>.[CAN?DG6M#3:J14FRQ--X$FJ
M,OI$8V^]N=0M?HQ&=$4>3DH'UG+I(SO>`=Z1B;9A:D0[JBVIVBO\=GN[8F[]
M'R?;E.TD8*`,XFS48R9E3HG22G9K78L-!T,Z14QPJCO5'.N99)[#.Y(ZO6<U
MJ^LZR!Y+5O];$5!W-TW$`M!/*]<_7YQG_$`*>@88O#&Y6>8BW=Z?^=I-K0@G
MY2M:C<I92R:4"7/W?5&=7)U8'?'`/B59SA7&H,BYGT'Z[Y-2LVZ3[XFIK:7_
M9PP=HFZ/WL^(,:7'>C?Z#U:M#<M(;.@R-+^3&&4OB_)F[R%)'JM_A<BJAYU0
M]?KL^`.2Y!HD*Y/TN^RG_-T[F3K]]DS,W[4NQ"YR)$HJ*N?:J[N@&`0\U"OX
MBC5J-QX-AI_2!43)F8*Z"+$G^,$/KB[@/A<F[-^_,:>Q%F^'#I;)Y_\[RQ_B
M-S6*<W?%4^IJYM\=$(XQ:<1F3MC];I/)O46'^M>W4FL;]MBRI<XO9"%>5F_+
M/PY_5Y-1K5HAF(;AZ14.J#:\I!K3H`]UR=))Y7^&7Z9Q`C9?4M@9J/+_3-9G
MX&!*P6YH*2(9?%,B`F``CU\&J=P#OQ/C2`CO\%9T>L&H6ZFL7FUUL^@U_;S1
M(;;K^".-&4=&L7B.2"=<1^4,M\9]!Z@4/A)JZBGK1'9>E%XQ;>1KB:MD_1!2
M51T;!G_V1,;"XNH[-NL.A33C>E^4M[$[^!`^-0X&]<L.U.?T=_FV[YTU6C\=
M@-&I4D]2#=.FK<=NT7HC.Y7\1M'-/?M/Q>T&;K[3+PV)`5NPB/L.2IOQ6;K`
M+MQM`49$."F$W)SN($,[-XZGAMRDC;5&9U(NJ@=O#$;-W).-F<%I+D-F:'3=
M,&[R\QG-$$Q;9'!&MR*]5C6U&%MVEP&[-[%%:!SUMHV6.BI_`XO=.@C!V$WM
M\K@^LK:[3;MN0_/-=1]-O4EB)FD.$ZCP1$(]XE)"&QAC=UYBE]NC#\)]&3"7
M^0,K>)>&N?-7&7ABUP*X=M^I?`"4]OIQK(II6Y2@%_BY%!CE<XSF]XYVMU/`
M]X'&5PWS+@8TMT8>^4>5_AK-!<#9KNJB\56IT#]*SGO/1<PDGPPCZ]Z%XQ^H
MD=BH?!'CU.&5F^GQ>X""B<ZC(A6O;R63MZMB,EI5.4F<FTO&)>%",1'8KW_3
MV"5I^J3$TV14:9XI;"]H3'B0MJ1.3EMYU#W_#KSR2)5@R8L741?-8B^'[&XL
MJW`(L3A(\/S"0B@HB:!6!%P<K$&4KH*_H2]>3_$UDBR>';34IL$X[/&FT([^
M;&5WJH1;R/.OR7'9`SU*\T3*V0C12;6G(VE#8T$>_7,SU>MRDNF!`<Z%LO8I
M`,Y(3D.E%-0;M8!S;$,7-*%)SLH%E@@7_Y0WL[D.MBT%6_+TUP95PN1`A3F"
M;SK_O,N;(F5+],9F+[6K4!6F=P83?P#]!1V+Q\U&FEY8:W\NW8#3UUDN2N8S
M<366'%.*:[:_>6S7A+$R@S-$![0J(_%=R(\ZR5TTQE/(J=<(RZ4/KF79RIZG
M8UO`4AL$R+!`8.EW=]YCM^-<?RHCNV/J$PCKA*N\*4\RG!M_Z7>)-`89-CM1
M8>/A\,KSZQ@0F[CCVF34?@V@XMX=N.X?S]1$8)#3?XPJHT6"4YY1O]E,OMIA
M_4B$Y,ZI%55A5XIH9JIFT0X.:<DOD4935)FJ<=L0A:R7UZLG##HMJ^5UFLH:
M3K[O-58MT#.>/^[K!W!%_('V*`-A."G=T@K.@3$[IC]H2)YA<@,I>.U"TO>&
MW:::#PL]0QIVFK@"(!PV2;UT']G*I>5'\*E5GZRY?5K"RP^P:.WAC+U(9KS?
ME;K^O*38"C@?V83/U/,;;,&U(AEH]O&.@FCJ%,W"N[YL_J]$D\\MSP7DDTHR
M_ONB+/78JGF8LM'H(H-ALBT07>*W_;6^C1?Q8R*,^<`[NDS$T=C)N/^;K0?.
MRK3RV+YST/.*G6>=]<%'WXQW#\I(C<MLF52]V`%A_7@B8FUP`EH:3XV^W(U\
M$=6S,Q_X-XT])52=S>C(R9CS5%8L0KC";)'*(((3GG<&]D"[8Y99=I)%/DDB
M1&QD#0%02ZR"E6''@9W#V>IBE+`+Q"*56#=`%%DG$/9G>E'ZYE/3KL*C7(F=
M[LQ*ZMX_C\.`E(.%IM]^O,OR,E4:>SFY/_>_QQ-?$ZK47IJM?;_'89*;UU8V
MCYR?.QBS%FHT[RKDT%@&IS^/-VV4Y3C(&]G,D_,S$Q2`-Y!PF;4*QVRFR9Z<
MU8Q&E!YRFE%NM(I1R!-Z,(&,``*0K6T:Z_0$;.9-*M7F0MZD&F76!R>43Y):
MY7S\3%2W,::;5FN.!>Y0"AX+R6/1MW>,M%F\V&>TBJ$3DHF9Q]".+E0T:4QW
M3!:]/YIZ\(<+J#6QO+ZPH*C\1]MQ$W(@=6:A081N7,+D,Y4^F8),NP1XFIN.
M.;4Q);524ZXD8VF7>+>2V;D,H`ARE++RP+C!UG4AIEAH#4N\Y!53VOH<F\0J
MS&#F2U]<L.(:PN'W+:N&AI4BA3K-.XFFVD26/M6>E33ZZ^8^Q^Y1N3%W4Z2)
M291`'D+I5(E=5&AL:00F"5^5;8#WIO.XWCI9/E4'GYV5W-C!4-O*A0W[4(1K
MPK<\P29/'H-Z*2M%>EE@4T@R)9HE*SF>F+POZZ*FU.8D]L+(Y$7!>,!3>Q:$
MX/,GMS-P<&/(/$"ZA#EQ;&$<'JN_=T%7792HM08:;6^$?2B6XJN/;0=%R*_'
M7$&BA>`R7?@X\9`MJ],SSL_&KV53+,*^.;_!XY\-ZLKR?IYCAI,/QFK]BPBF
M;/50N,D-"MWFZT$?*YHHXP.A43A;5!AL!1M9>UR<B]V;W:"(IYO+0;=_6X)#
MG@%Z,U78`7J5H=JX,@V4HJF%*^-`D6&*N,:;/65J6E1&1('\W6&JES@(C8-X
MCI31^I0B\.[R<6`JPK>\)-PHGM7V#?3S)3_^5UC4#=>\+%+8M0`JKNSLU8PJ
MX=D-0WC_.ZQWLEUDO0AV`H09?N3Z"M5)D^[#.*&5!$>B[]%*VS(;DF;A;!#J
M=CS?Q%M0W+Y/:UC3VL>,:&878&P(O[Z/RZ0[<07]`VZ1')"Q\E-^@:]IPSSN
MC]\*BOJFPLL"5]\J*7M]-L5)"\>X6XG5@C#$)(%'6)M.8(0'>-76Z'X]Z2A,
MZ]DXIIU@XFSPD7$<994@C.@SBO*RH14K#RFFY_9R6%+(G4S+WPZ_36JY:NT<
MKR?^Y5DP\7E&#+RIZM\L%Y]%01P/$WRLW;-OR?GN2:@S+5WU2(Z?ZRO'$R'.
M`*AF0BH.LZUN#^*3=]@W=\ICJD%0HBSB]]W&%_`:SK2NV(^7C=JBNBRK7C1V
M=7#EU%"6?579FT9W:U;3&6FHK)/=P2+0>3*+0!\(-%*959HJZ[GAN2E+,4?W
MR'KB,-@V1S*B.F05H1B=D7CO?)KG!JZI1V5SH+.LJ#]EA1H3-"#>=CN47RB"
M!=]>X\_7%K5723RKTM?JS5)[>^NCKD/BZF7^YI`A&DO>84I[@%@O5X3)ARPW
MT3JB-1P@3!6%XFCP%(1O+9-]DD[=YL;YWGJO`O\>P+"-DE@\=()4H$:I^*H'
M_A,3I"M7VZ;)SYX@K8CE;S<M&WQ!B[Q^'T&EPOP-4Y"$IA6]7($;:Q!VC./Z
M6N0-MWQ^UD7-PE^H2><BA?KE9`K1QG!A.B+S%^ZC%'RO,Y$!3<8.Q!(FOF"+
MS[,[3L`G5R+]@V61`B5?33ZDOD((CK]^MUXJ-!J)Y`IO4EQFP9@A>Q06DHE\
M"09-'8SO3^]&K:_%B+.V[$%&TV#$:CI'^;]'H7Z=\OG^[I@#9#XP\CX&8W09
M%3WHI\M'JG5P]C_V!]&U0(G339<O-.T>9;R^U>*Z73\>8@;5*(.N$$$V%DOL
M7IY/[=[%D75>1O6PWD_Q;)3XW(G]CM)M82#@V<0]?E;*<TL6[8\\>WB92%E2
MP:O%9GUAP>.&[J4#D,13Y>-ZQ)],*:W"/:&-*`+Q[#G.S+#KC%T,(;<FIR1L
M&YR\VPX4-Y)2)(QN>`JJ%RN%*VD3\O>AQ)U/U$\-!_AHWD?9S^E4%![:Z_BT
M_!5@,C$;?A2),DSE%A"4$_[IOHS\D;R@.D>W8(.F?";YY336;[WAT`F/^P=\
MN=JL[TA25,"[T*!G(VVU5MJ'E.CLVC.#'A\C&$=%JF>%D5<PB/,;]5,%?["D
M+ADEEW"X`\#(^`2%IF*>TAT5%^UYI^.'EENGV'A2)39L[$[<DQPG*D+\:D(M
M#XS-+3I:1\R?BE?0'G1.\R?&^=<^)BW(+[9(6,[D$;K[+SM<+&.TT$&Z?'@K
M]#2\/NB%DCH8_TNF07IKSB5(`1*Z!J6AD[<'-$QG+AAVPN%,W86/M0+^GRKT
M?XMMJ[4$5./%61A_F['-[8-`YE`+5`%-_:3N5H.4^Y&[K(M8TU87Z*$B*KTC
M^Q\/.%HJ=G-;$(4GT&U!&X+'^EAIS!R.EYPS7DU<M<4-_97"GC0>W23/-<<P
MB1ZV_I7,Q-89"WA\$4VFO5XC_0UOZ/H4M[2&:EB/&^_<N:3M+JX-KKV<L?SC
M_68E1#F.>`!XI0Q*7<6I95%.8?+0%)3IDR5DNZ--$(N?M1Z1EA%DT+2J&Y7N
MB/HAU":C.KFW>LQUMTFU:?_`=Z(^:!A-V*D0H--H=<ZSTDCA$+]*"^P%S/]^
M&?$C:U1%$O9_IZ232BM3[C6$!G%>@@A/4D58X6`VOHE^R:CJOVG59:E5&)1)
ML?"UJFU5)%(4;1'VLDB\9SB]%Z^27T!*(9/]4ME&5IO$4!>[!_//_N1;M];O
M;#<=I3QILG7F9];;93NAN<@;*"%8=XJP,?Q=ZP^E:\D%7.?W`UL[3,ZS/-V>
M&JFMAKG5176Y3<.4:OJ,:G.&7_<U<@$K.@RVLFODN$NPG!/Y3".6".\=24K^
M=9V"?.^53,#$MD5C53`&4`"*KL6#)KR#XMDG6Q![:Q4M48='\9AI$UG;O@ID
M3WFG>VZ`QF[P23*3`;#'W"QY^7GC<1.$LYQ<EZ-9`G'\<>+2ZO<_RTZOYA=H
M!1^?#,9?D!OO:+#/2_#,T7@.$;[QMA$4#;K04$7H"SF`14GDO^/@BY1_Z97<
M.9SK!GL%-/E-KI>C#$3!\+7K87U94]CZGI2[=7Y1^(.FG.&6DUA2.(4A**U!
M0(7([W:=`=W,+Z+_Q>KGQVW9-`>$MJR0@&*;4FW(\(Q@F-+(5;<KIS^N;@+.
MG;');S7Q'I49C-:<^/5XVIC]_(JM>)!^>I#)O9O">9PE`!>I\E1B4BEHL3,.
M%//[C%X-:WLB=P5O:"=S/;5,B)&SRE444"(BZ,F40LIB91_$M^%Y7Q7E>Q"0
M\N^Z66[+">MGCK5VM>"JS3Z9]E%NN)7>X%>^:9=>46-8%<>K>O<:U'3'X'NS
MU[6<BU]7\@@%5RBG/E<X!&$6TC#$UCBMU6:1#^$\]\WH$B4H?_!A:2Z.VC(B
M'^G81US&PF5[9EW1F+#];ZK:\.IWW'`Q^$_JHEB.@*L482)_EAW,"9]ILC6H
M);EEU2.A\L"/))S\R!RV67WS\9+/]#A:\1&W/7M,N1F*"XI..C8"&JE]'0@%
M#1L85:BQ0EM'7SC[#>UX4=*`A,DM&X%BGA.\-U+LB[E-C=L2I\OR$XR7^XN6
M0U-XK@X\B69BN92I67#:R5KH8E2_9CSD$\BRZW+'AUCRMP&EF$D[965`V%!L
M!\JF&+?LS^H3R!42=K3H<A$#H3-DG4QF4N*A6ND^R<*3Y.06/;^TGD'>70EO
M1DMIM#\ORW-GC)<22]3E2<3Z(`@,"4;3P<E2".;*[7I@R53^FL%RC`KK]YX_
MA9JDG*B?[,I<DB6-D&A4=:RIITFMV!<N@*13:5=W\*,,6&0,;%IW5;.GZ4:.
M?,^_,0'>`1[H"Z/>$HAK_TBB:^*40I3ZHXF"-"(F6>U/G$S"FG.QQ^OX.GE)
M(+^,F&<HVG"5J=UYL;48LJL?[CD['P=1/D6V/%2E!-?$2T=I)]D*WP5'IQT2
MV\'\5FC``;24/ETLB*=$+8G%"$@B[I^QR$@;R6M'W;FPP:MMXO`RV$KY3[$\
MD':80CAQ1TB-GO1S9F);;3N=7&CDQKL!&`N?5-=VTXO5P;=VK7WBF^%"E>@:
M?<'SC!?^07@YNM2.C^F0=P4B:T]E9C2GQ/0C=QIO6E4M,-!!//YSW`9PX'0*
MIMG-Z1CPO[N;P#"22:4PPD@_<=,X^[F>+`7;Z`52>WM>$9X<G%HUH`>Z(\4>
M+@;!M252XZKIA7'\D=P=^'K=:N&IX8)U1@YQFN\2XGK%W%7"*?)'+^E9S:TB
M4/W1R:%-K5]WPQ6![VV+^&AKP&9=](T^RUKPC6Z8A/[W3/[VO$9QL>:TJB((
M&\B@9WGYKCNI^_RD:3._1CN$MMTJ%TNDO(A@U8E":[:"10(!QJ/WD)HB__[(
M6UHXJC!VG0C0):&O%TF4;5@6&4,&K"-MU0D?,Y$DZ*\)Q$>FJ!!Y)Q6D\:2*
M:6``PBW!%MI:C69K71+O=GK0F\Z;YFE4X./-L`4O[QZDQ`\[V1'KR(6-Z]CT
MQS*5]S&%%,10T:@9UTE@Y9Z35+?B\6]6@Z[/WZ2+.FALUA>1I"Z4KN)L,W@F
M^R!0FT!<.!5*QS[2F/=`ABJ&GQ8M4C:+[4"K'"GTY(A^`3)7F>1Z<#>L.;0?
M/RC^X]$_%YBG<:+:6K>UX?H)D16I4:WDLA^;?W6LT+Q0?M>-+BNK*DN\Q5UE
M34/IZ6WF)G7UYS?8'9^[F)9X0Z^E$!IF]6&=9%/)/<W36Q5^";RRV'Q26=P?
M-Q.OZ+NYQ1HI&BN7@Y"M_6L_#-1P^2L[F;XY14!Y)/U`BY>N6\'CE]QACC//
M&'YW[FKW06$%4;3W1$CV$$NP.OW"(.5VU1(AV^3,OXXWQ_E5*<*.#XO.W62/
MS&/+`D@8T76'SKP&2Q@\^I*.-7Q%:P+L@]QN.6LPGH45&AB2]Y/-6G[WX>66
M-T8<8_B&2JLZK/1;W<8(W3T%$/ES$<9UG)@AQVI8)%6G`&*7)'\P_9AB6-5Q
M_0?+BV7,K$]RX?+X,[!:;<W00#A4]1%'><:[*]\!2JE=.J-X`<>7Z#!;_*NX
M#=Z*U%("^6);<8I,N>7A@4%1R>)VL\&(>6^>=5]UM%,>_P]:^;-TVPBB:NNI
M`W,3C>XH/+AYSYL,"T?E.^#:GI6G42A"64'R=TTI+`/P4HHSE3[!Q6VQS_>,
MGC2065&#!Q'A:OBK+Q))1M$!O'2$84KP(O),DO%TV=8,&=:+%BE9#RFQ6PZK
MHHV<-;WERTG1P(S9_'I;?4BW-"$/)+(DW2`G5VUG&M^`P+'C)K>%$YY,!Q$/
MIT?.=<2C-A\Z*WD$CBVAMF"O4LRJE^XRB*UZNJSLS78YX7A:`^L2692\:G;D
M#OM_N$R^[EVO*HH:$/7>F(839M4%R/</:;EFMNYS/6W,&C`QQ'<?,>W>-0W?
MI>+T8KOD`,)I/WFR23LV^,?0@9$6,!2CRH_3_#Y?:[.]M:U^7^50PZUDZICK
MK1+W#S*)3*J3&('(*PX,7JK5'9A1]H&AH"YXA'EOW2G)_@?N@O2CD.I?[7IK
M4,:NG0#L](RV%57I^I?+@)`J/(.<LF-^8:QU=<0LPQD[1!AB'Y+J7;Y;QTI#
M8E,JNTR8R1V0&+G,?NF'">XO]5DV+<4KCC\%H0C`Z&-,RA[.@*NF81A6$!`C
M;,KJ^(4=1K:*%=W#_()<::7KRHC(<(,BVX_K33/NA:T9AO>-391GY5P%>SS7
MH.Z7PU[/A;ATI+%/UBL1FD=1S.WVC_B?E0VR&Z<\U.YL,'0,OI`12JK[/&4&
M5+N70`<-?IMD'EG2-Q3$L;`F"5F1*,";8SA3#(V+IV;O[J:X]>#],!\UOAA7
MA]GJBOB;X!ZDS3<NKVC`T^EDH6',S3QD;R"8)234G'O"0XG^Y+'."$A8\UIB
M;#)SC=:[;DCH%H&?7$8Z.LAI/0LB,$13WG,!MM<FB;]3'-TLHK,.&DU>Z\5I
MY7:N)XU#Q;/G*KK_+ZYK)]7,#3*B.$]&I.->XB.6=V]%\G=7P)M?O=U8<)9G
MI][;(-R5:A"E\%W7%@$NF%&5E/@NI=]8:SU&RLAV&]&\`&C]R'#25U-6Y*6%
M*&)/6/P.R@4)K)3)ZY$5L&PGZIBBDY9W3!M%;2]V\].+O^AR!'89)5DQ[W6O
MHKN@?P_ZN#$8C``;HJ6*\%;;2=ED1%Z0"%<M9@4-+\TYF9P%;;SE2<;1K%,R
M?"^Q!(&05CO94!P/S="[AB#B7B?BE9.XHXL5Z:0ZE@/Y75:1^6UT1<=\KUWQ
M1.3_I9AQ-AKI*QU3W7G6?Z?4<UGEYA6RBP+[6'XOW443LW6A[%]9V<\R:/,I
MI0]QIID;0C3[*[G+@YH+]BWP_K]=XV"F\]J;]K^X(=!AF4N1`<COFS'<UR;7
M`7<+?BJ<D5SIO9NV\\U&V9W&"[JG,5!,KFGWO9(24<^50'4`<C:F=XO?'"-!
MY*GG")GFF3P):*A&EAY,7L.S4V9!V(@A#V/0%4/(-^R1BM:79UO+W%+2H:G!
M9_>,J<OO=^),B2;0'XL90&#%PJ(W0$`5+!%5@T7F2;8XK3G<5B03Y4IX2$C@
M8W[920.&,NMWI_`'(43)_.,OK*-OB.X%N4LWW^)79/J$=HZZ)&_QO3H)_I1.
MI2D.F0Z$Z$SI@$!(0JG<K)3(]8$`^\/FOQ>GCG]#1.'E#V`C>B#ON]G-%M]3
M7+$J&F>ES2BHE_LYFW9/!@@Y[RTS'125PWMB<J[.S'<G:[S*QVGW'99>OMU$
MB4.3E6S6(86$YF_'M7)^U*0JU%<3]G":Y*Q[,EBK&^FQPS=Q7X0'+L."[LNV
M&_J(Y1,;R"M.M<15%%_$T6I>CLP`>]IPKAHQO9J+6'9Z."%!1?!7A_&NA]6-
M216=QV4G%C>VL1%`Z\>(REE`)?;L'K)E^&RT!VY.*LXCVK"ZJR,GI/K]EW^1
M->Z_&G_QA0-.MQ)P\K0F$@:OZH+I/E`9F$F,J4YH1A$K/K,877?PJP4`EWJ`
M4#XI^O/+DT)HF;S`F"')'+IISY>Y.E"2[>?;G9*DWW556'G)-N,7DX^E.7FB
M-E$G+;7=LN<RD.9R?C:1-:&KP$'V`]M;TP%='\I^\C(,L'BTWM2H&JSYK!C9
M+#]!03P^OD0DT%?0E.H-Z9OG0^W-G9O9W619MYYP-[I65U)_A@UP5/?P$AD^
M(R10O"`^:#R[%BI@%Z"'IF,)IE$HJMK.@DN';43!*TE!TP>%?42+8"=5A'\6
M]P$A>ER2/ECA@F8A,)QE3Z:*P5(Q`45_D"3LSIS[$$K00-T=U>:=\'QA`FLD
M41/937,$'-Z:MZ]]9@J8OLH#[,?_32JPW1'AC"SM"U:B8L2">E0W`W95:=GZ
MWZT:H]^WLT]>Y7]6WIH,<WP'VY2S_]XI8RI-@]\7W/R0HQ`?YB[G/BXW^O?"
MFM7H!41<2;I+Y-^H.5?(+%O9,0X8.PGQC6A%YDM,HJ(?-P.WN&8<I&54L5M<
MID+?E<F8T/^/:^=PR)7QPL@2.C=4H$";B-*-?B#-OO+[H'P`W9]-][U[!DU>
MLG^%SOV])_BGW=!3?M@I&:ZN$UV/#C0'RCUY0.PE#(L>AI]/*M8H\W,LW@C!
M^)4&-"/1CCX>$$J_@H90N&\^B5/IR`)]9ATX`12F1?K\@HC-%6-)=8/>'*8^
MXX7(^8@:-W,*MJ)1\LZB,"SROV;";R[5TL$BJ')]8VZWKL\GBR"1IBQ3UR9:
MMM)1FNT1N<<,-KJ6^5(&H8I!U2E8`S#>=APS^*E:3NWAT2;X._V7;65K:0P0
M\DH#?;5=2<-8+M+$J,A"C-C<@,&;+<6Q/:^(DF+2@7W%@^>\DE#ZOO_->>47
M@[=DH0"4[%J(6;>KB<+/G(I;`+M.FZWDB#QF=%EG*[.HW7C"+0C3U"F[2+?5
MOE4L=TEX0)"H9+<T22Y<QU=/^>T[I*V?N4;I5)&5;U0L*6%A()W=,C\A=$L3
M7UU#H(LQXO0=68&-HK\.;O#VX5F^#6))Z>R7(UP7BPKY#247I6#F:.K&\L/A
M`%%T`QPF4%@=CBF&8AX]'PU2YU]"F>55M1'!"D+ARMYQ;A6ZN/'Y@?Y??B^1
MNO.L-2ATZ3A!MU5@#VAP$,;!/.JJ=G!H/S#D]*N6/U.MS+P=F&J+`@I5=#T]
MIXQGR&S2M!=4M_+43E5I*.GL]:Q]'LBV$_W$/!)+8+AJV][SJ6Z3<PU`<E+<
M$?B1SVT#\4)F+2%'ZYLM"VCKL5Q#V1!:2#7O_'R"*FZ6Z`?^_3]?\N!8Z5[4
M2XY*9\)XHE;=G:]JIQ<B_^ZC=0P5%238C=#IP/8!8,"AS)%U12#]DWL.'IN*
MD5VR=PU#D:@V8**/@I.*]_NU%U[)61?64ZA7UD%3`7>F8<%-VFHU&#3&5J?8
MCI6F@,-W:ENG8+A+5PE83BWJ1U'^RC/*T-(G^$634/_>!R>3W$\[5/44[?JX
M4DB;W.V_+""S96U1:NRGW&@U;=.R/?)Y[+5$U)-NK%KA.=2F00^"SH5%KO#I
M;`RQP5/IF9A\B&9(?YHF<HZD2LLH1A-\#Q3!\:B"98!VS0Q\#^83[6]@4R'>
M'=BP$.#G;\[NJ<YF9^+7FU00>UE-@Z<9O@-A@I>AGL%N53Q<XP<+&!Q_I-^`
MP[%OH$RLY[YAR@P$Q/0JUB(%K=6-34[&7T;[>T`=J>A+$+:*P)`8G"P+R5.E
MK?V(CU8-9!%LE)_\+3):A[O)%(Q^I-4-_.$*9J.)A)1.18CQ)E/-^Z,<=;W;
M*J8`K+@`I<?,'KH-]8$-.U?][-L@_L.PR%Z1HEI$\$1]&9<D*TDA*D._PGBW
M":3N'"TH>N6^DHA,G]X?D@9/-+E/,\I$5R.3-X@C!4Q1'G$:.ZNE"I>(BE&U
MT:A1TV8DIY8\?T\Y`XH@J,;+CI76R-K[,Z"H8@3TLQJZ^&8$*)R3S%^H`)#[
M+)G]V"U+AKI09ZU,:[?#F/]8*/81`][37_;Z)Z)^?_55@.W4D$HEY_1\'?!3
M5.F<90N]7^W.E\=R5F!J@T*Q"C:\>T$Y>RZC#9<Q&`65ST%=K4(`O\0K^G=H
MI&GEP1>*+Q#=RBLOA%NVS+;*O&P,W33[),:S7$N*CV(*O`.7NO/JK,VYG3<T
MK1"JN['I/+3[73OF;1S43CILIB`;@.+S)F8TV1/\'*;-F'O-<(U7_RW+Q7P]
MX"Z2^+M0]IA<6]LT6R>B?+U`UWFB6G[=#9]W;2!;N]4@'5^J5UO2VQ>>QK1^
MS_SN1J3"PQ]@+X]W\+:PL*J&P0ZD>@S/J;4#)@#FC%J0JWWFT@7:*'GPB4J-
M42WO!"ET.?T)$)8U<6I%ZXOY5KJ&9:4MM06M>G3$*&1K',0#]TQ1$*Q^Y0K3
MFO*61QWB"%=YQ)_TXL.8,F\V^/#P<Y)TJ$'\1>8-"F2NJ8K.5`&/XW45]N0?
MDTB`;[9PPREW1\-[KJ^CA'>!6Q=U;+O$Q4ES!2R&CPD+^^4@``5\7F):1E-H
MA"E?`-UG0E.'IC\4=VWN43.FL0C&I)VPV8_HF.XJB0[I&H2DG#>:Y8):0,OM
M*>893'$FTY1Q)$/N#3>-]-!C_[^ET4!S%<&])RQWJ]]S[GR5\8/KQ+H9^C";
MV.6<)5?L/J2N[#=)<'9B?6Z7$C_)IJ&`5V"&O>]=.TR,'4PIT5CJ9_"V$;47
MV1ZIC6S&Q19T:EN##EWQ=&O'_>;/P#Q1IXY2&3GR&.(S:KY;N\XV+W\X44EQ
MJUX32`DCNH4)8S@N7WAY2EV/#)=1/_S\3AI[99!_8D3L1QRA<>_IA5=A$#A4
MW.!\?@\!)!H"*=?Y5$9J7G)@[#_8)/TU`N1%!D@.#AMM#J?FH-?[W%FN'?/D
M)-:!G4O-L9@FO?;)-:'!2D@DSFJX=.$IB>'1D)F?Y!/(BED)+>/I)/NV*WA%
MI?JA;J^QDZ<!7'^VO;GV3$`8#D/<YMG@_MT2^^8%U9R].-.<QO]Z2+`"#T;+
MOI*,L`[J$B^2*LRU'.AT(K=M+[\_7SOUHS/CZ=*+H#BA/,GTPQYVX9Y!Z'\&
MVI/<9$B4'-3:5*W8MO/UC8HEO&-FNZ21](XSL*2<E:?`K+GY"^62[./ET$!7
MW0;.5RM!?/3YWE&'!MS_L]4:/]\`F%UM8F_G8P<._<+WV1C`[R6)`;T*QS3F
MLW)UG")/*>)O/$\3/"S-HT<SWD0EOV6(@U%TG'@X][AIS(2-C?)ZM]N?O3DL
MG;\;P(MD1WJ6/F*MW5N^$B1'5O`M2Q]R[4X2SLKFG40OHG1@`SJ*CN-SG*Y(
MI84`BFW/)%U\Z>U@LGS)MLJ&.WQRZO4C5H]-_VMUR4,U[TU]A/(6,IT:R$/!
M:_R/P:V/0OQ[Z&_BHVYKV85UP"@))DQBG,!+U)9616C[1,P#'BL_$X2JW6<*
M,!,DO)_<EFI@;KA),-A&H(2Q8O@[6>,W=U)2),T(.$S7"'\S*]8#!?4[DS2:
M@?'#=)T*UWNNY\0]GDQ5^`V".`.501*@S.H_",F3F*V@R6X3$AYX!/[_GKB!
MY8,X0$D`QX+`.4@SB)$X)=Y?1[B"FSF0?$5RPF.ESP]$$;`4Z"WUH1%SQ[]4
M]RUIXR^\3S.@,*6#^7T-3WFBTJ&\U9<[_?/C7O<OTE2*7(HN.ITS@1@<%1'[
M-6S+6;"`O"QN6@;?G7N42N4;P9QI[_G"2Q=BB'6'_?K]O@E@W(O4,G59PVXV
M>-"?+`TEZ2Y\@S.G8`)_IRU8&JD96)#`K\:;SR)!Z;7V(/,X01.6,Z;=&H2>
MV/"T;P:4,S!<XAP3G[!S2.N-'_V*:V]U;>%9]!-YKTHU%"9$.&0,IB;XP8DT
M+UM'V8NB.=IE]PL?%_MD18ZL'4V=GF-^&G>G*AP)\:CSV._6I*[]:PA>A]K$
MJ:&[EK*]QI[G7H?//0*(70V="7S5SA;2]-]BY$/_[^!AT]:H)06Y(D`=LM*O
MWB^R,YZ%+7R\H%K6)+^`-PBY3V[;X96#0+=.@R\EWA$S,7/MY@>2JK<MY5DV
M[%_EU1+,N")FL&_*H`P$4;WL_-XE@<<T3X\/3%!N^(G9YM5G=+K^VRMVR5#)
MJ+HK@H\?XEE#="RR"/V?#FI53[?GUU<!2`*7>3<<!\X"W^YMY\W85P4=D>SW
MO`F65Z(C5Z$06A=HH?RP&'\_[D.V$$(`FZJ;9;`SU*F)U6[QR/-/]R7/:')(
M$$'ZN#>+U[3(K-[_+/^^BK>)87"O@DY?8H!>YK@&\<=K,65JEG8R&H_-E5_]
M9C5(^'1YC7L>B^C+_L<RX@$M-SV!-K2@!'KA79>RC$.W30&<0"_['"*I$4XS
M7FAM!1BI%,G@']"JD<'L@NVI<UO%CV^A^7N?I_MJAE[EG4DDIED2;Y%DK`B:
M#V+T785&HQLRK9S28(=@*9&G";5GY*(DE(9[O0A&ANW0[ZA/RN.'3W=_FJ>O
M[NV`_":\EGS-O3YL4$B#V0RHOM4,H(_U*5Q,QU$L\3IE9E"*=53A*KT>QOQL
M:;^"U,U&[5K0-0Y'OI+5G`,I<'EL^!-K.6SXUN6,QE"R&PFH>TW("#PKS=),
M81S\Y@(@&HSAD!I#F,XNK;+KU&G,-2T<60<U__%"%\)9'R8=/NF*->;TYL<,
M1@>Y*)5O)RHFL4*=AXTL9G`I@GM?9928._+KW#5(>A=[?@+,II)22#`NAU2E
MO]QOFEWZ'W06KZJ%(F2N''^>#Z2V32;D],01FKQ9^6"TY77@DV2Z-KI6P!_$
M:^:,R%K,[)BSWUPY*O)GZ5#V5A^X1&-(/_>%$K]N14R\>&<+QT>61K$Z+.;@
M2RVQ''T0;UT9M(BM%T884>)K>0C"2`@X48*^KG?/=,/,"M<:[GJE7V%R!TG`
M,P;_$4,UZO#-J4LRQ%\*TL;H8XA$8V")^LE=&;95U6'$E<"0/&]-S";4(_`Z
M9CH_=-*M#JD1#E0PX3)/8467-DBJQW.#Z%YE2/4GH8UE:]/O2Z-;#NR0</A!
M%E#'2P6TFPZ%AR^:LJU\[GFJJ;FK>LT>)@RA)@5K&KB/K7M^BZBFBJ*T':<)
MS[UO%6LPHD3>123&O4&FF9!O"+PM-21H0!)!J0F87F:3#!7?7R20/UBTYH_K
M=]EY(9+,0P7SZ!:8]&4^7E^$T*><`&UPT")RVW_.=B6Q/LB<-U^S)IIF$1!-
MSN-@'>HW'(ET&0M/,-?=?;PA,%5@>1-0>;XI?LG`>REA3SW_F)UJPNF3;VO'
M*_\9B=[OETS'RUH),YA\>UT;DXO9=T2&M<$VN*E>7FJ')X"[(H2TMF3Y7D?=
M`)J%SQ#:[2T%B9O-A6_9],*?YUA;3%8S-F#N.,$J3R(2\AK'#!P?%!=Y&%E=
MN3C4H,>!V=>"/XB_`QYRMGU[*XS09YJ%]3ZD7LP[TN176X4%,0,5*G<#A^I5
MH&L^<[_)ARS-$6M9AF'#XP;GUMNI#?&D*29%_]LN[0B`Y!UN4M>E9/ZJ1106
MMF)T,>?(]2`RZ9LH\<AI.B8!W.<OPF8"04.+*6+.F-Y=`U?W%)GG<N9E62V@
MM+V7QR>+.#*./>/3N,WB7'^E5+@<Y!:1CR6U6(9YL<2=G$L<6_]C9=P,BV*@
M,6@QCAM`:)7.?2S#_U0HIA@,RD'`)KG)HVY/KC8E#FOLJ/0X&BC*B#9EZW:1
M%W;:.W>WW)ZT,]8L^%JBY"M._/UC"CSA=N77M-L0D_P'1[5QG-WC\N,DP!;3
M-R090R<NYRL+ZR4U0O^[K`&<J`(Y%4M[3O:J+L^9%IFQBM-'T^#:O8^72)1Z
M%U=2.LYRU4WQ_7;4"_^(!C-I/]0[^1-A'="]<7XESU[F.M]['RSG\9D<UQRB
M",F]MK%-"*5PU#-3\>FY?VZ0H#\T+!XM^;%GCSGI#@?5&/U&38``@BICKY4.
M<BW_^2M8_^VF:K+&J4E1;*S]!.0]H;V)%7<)0^&'<CU@Y7IJ5LPY9(M%A^Z/
MHEF:=Q*Q%?"L3]OQ>=:R_S4N#%RQ0<"NQ7#<W$8.I^ZH`)U"-RFJE8R2-`O>
M4(('>ABQ-RL`U2[51SN\9CJF\>H^9D8QH@'92AHMX,\2,]<B`CE8K;OD=9;S
M3S5.7&X9.6!%%='3B?U7-]D-U]A+V`-GRG9<W<:43&SOIJ%S,Q1.^(*"62H`
M7MHZ98VY@ESR@2>^OGDRC<`VI0!,PC<&&RQ;9&_,:DRD*!4E#[TI=JT8J?M]
MS$W9^R_BT0?(=4O1NH;'$OD^+<W-N0\7R*N)QZV6P3Z9A[H7QW?BW'?R&C/Y
MQ'PZJ!)/L23DW=E!':ZC0ZO/%P03$]-PHNJ7,_/?H%#(C,P+I;^"_]Y>\^;D
M3[=.WT2<@A;!FWC-54MHL0!:U#&@E^&P?L#G&*A8O-FF$Y:WDNH[(5`T1I+"
MN_GC4C,3B1B?&#Z)5+PS6/\@MR1KSP]4RX125MS]<7;TILHK\O&WCHA7/5XP
M9OOY%&-$6H8>.U%L=R]6N;&27V/OO].#9#\3D/[TLIR&H76Y.GU_26HRY,(V
M^U%,XG>J04#TO!5EED.)O)O>,#:QECF7N(,]+ODQ-:@4&PG5[F9WHG;$>$OJ
M+,`C\[L$Q`?CWPZ)C'>L"3OB#7Y>RG2JI>1XS7.FU<(F_3\>YD7TE7,57>EA
M1857AP1/4*BJA(_T:-H"I-.AP6AYSQ"7Q,HOW$[?XUH36EF_]HX1-KAF,;O5
MQ5+1_9N1JK;-"@Q3H*38?<<:<"2ALY4<8C+VDLFER>A/5=I!AJ/T$\2[-I-N
M%1DOBX^(3/P$MW/%S4\)G*/QRB7,MNA-F2U\)*/:/]8^V!GJ8%7V"N^7,HT;
MRAULIJ;[:>`&Y*6=XK4M5ILFG,4L5S-`)7;/G$G%\,4,*3LH-!H`.?H(NLZM
M%T[:G.*D?_*?-E'1HS\-M8?5QV);P`/)M8U0;B_7R\R=Q,ULC^7_9`K-^D+Q
M&`7`_Z)<E[4L1<N;:SE@Y.F30\B_8"Y4!S76G(*1)VAJI&*-S1'[]/7QRRGR
MT8Y$_J&J1'_/H"X/3Z$)/H(IHG'_3B,#%KU^R`FC=+T`]'I%Y%>'G=08BC70
MEM>":R\0E19/1A]Y":*E36VS*"\<^K^C=5*E%`4,4`,<(@XZ"BL7!YFIOK*B
MM$NELM'Z6OYPGAD-Z4N&O0J+)G4']34UG"<B$=@1-%M#@IWH$U@>.%B"@GB$
MR`R1WA-%U1<FB%P@%?8'51C`6&S*_>`%:`L0$B([XPE'UUKG](?_4KJ48R>W
MX;.D\;EX4P,25/8EPP)^O#[J(B,J=S>@)LOY2J9]*72Y*OLW`RYOG?&?UT("
MW@/Q!]0RUH@-7LD+BMQB94)1[$S'&J\)/$-OI4I?6"1K19)4R[$E9]]%CBY)
M2DBQ$]DSGT<[$RLNY;SB8$0-5H)T)C2H=$^?5C=8,NIE5[\'?K#LW(+.A!$U
M;P2UO.5TC^W<EIUDO.PO>5T2[0K&GENUQ!)Y3,`ZQ8-)X^.69+[^/8?X<>P#
MV_L,\%7+=P76M>A**`V31@P.3<,X*]A[B!*2M%!>X$TK0S`2\'D#QCK(_SFN
MS!IC?U"+$"3+&6I1!UL:JOD\+P^;F;*6012<6H7U5$#\P42[>CH_SQ:47HW0
M(M$[_FP*]K!*';QB3"X#^\6[RRJAO1A=C6NSV<U4K$B3/=6>WJ<GV5RJA,A"
M%HW+/IQ>@=@^!1KNSVPLI/[#M,`9SER0<V0M9#<X#9@_UN,8TQ[P(659"=T,
M1;T-V&T<P2]VI[2/GIE-9$[U\JE)3-;YK#5%8_JXF(*1H""3W&*=T526T2)7
MW#'OL#-"H!D>QRWH''!P)P-+<V;Y."H^IY*\0`SW?F5."B0S=_-MK)`75@VA
M6*B430I#H:Y?J:<3=EZ=+?VH&EF<JAA5O7V$V%9W*RLPZZS0WN=@'11["G,]
M+;NZ?PY:L!QJU\CP*(2,@85)^[)G=@&.#_1'LE)E%`;V68MP<`!SYG?[W%:6
M8U$95LOO6K11)*AN1))?P'#VG#'*#;#K`0>*1FFFB>PQM_$;5]=5PQ,/]9^P
M<:^"4U:9*IOJZ/7#B%\,-*"J7Y'L'H&/2`63Y/?;XE7Y,&K<2W7"DQD$?M$,
MLB+_7U26C621MI-FO^FBU^ZY*L&\[.;'#]E[!GLZ;LK:CG1Z<QAI!=(+_^+P
M6U5L<T0M,4R<L]]U10>S+D2\QB2#R>^32OXKUG.03G74,!SK!O/P\OKZD\D4
M:L".HAQ#CR*S!"K3;?L(J-UU&QE"98-<NZO096WWKIB9.&17H^=(LK5XH^J[
M52353S@Y^C:29+5,M(B:&LF)L*`KAKVN[S6EX)JGX/(@=9Q?'#ZMZC&H8"2(
MQAHM=]@7]+-K<TD]+CJ[_8S8P\=#^-U](',-3=MVXF;P>(-0J_M0/5[)W.2Q
MN]J#OPS#7VAQ/H)1J^*V\E__4/S_4FH>?H/N(?E+:_N[S_HU9J6F>LV%G=`+
M3N8,RQWOO0"%KE0$;ID?LF1$@2&*I*QFCSG]I6L2&I72VOJWM%EQ8Y;'!-A)
MC_)@]Q"DD\V`I:,39%@,5;$Q941:*>>?XB-WD;A)7*&L?J4KUX:LJ\-W'"%S
MGTST'.3:F@A6YB!<WPU'2:=)S=.-XE)!:MC9.(3T$:[ZUUIS&+#0S[/LVB[4
MD:35*`)]T<GAG?.'?M8F&^_@";E#_6=^B1RQ,+K2_T%:.,J"`ZL(D\6N'3^L
MFSV%^U4PU^6C7+/LJK^X[8MZ/CY[XGA@T79U'LV6MZ<VCT9ZJ#,K/E++UTO9
M%_'+AT3`<V-UPK0C+QM/_XZ;#)/*F/N9G2UVP4ZJT2;.=C%5_RX/E&6!`R)J
M-:[E',$/%0P?L?:'_]`%CO,$A;W<]<#A(>WG>ARFI:TYV(C:&HVCOX:+>`1M
M"(IJ6-1;*<NO<VSKAC[1)FEA%^!4!\DPL\6H20@U1Y$!#4,_G*X%V]P(!G.S
MKLSLPYT"ZR'>-+(.R(:'L7D6##YR!.FW])L+LW(;6HKQ'>L8O/_6E(UK_?"\
MZI)Z75"F($>L1VR1ZY+ENTN++G*`1N%(1(@-<C/!R$QR9$9-'$<B#2A:==DQ
M4EVVE*-(H-MZ"HQ/95@BZ]=)G,+?9K9RO6[#\Q0QS`#AE`L(UDR-)_21S-IF
M7YO#\"6EUZ\Q:\`D+A-AF3M%-B4X/V)_7?1A)':354BW]FHUTP_Q_QKO]R;E
M5$F*O/^,JV_OG5$]5Q(Y9A]!3W2>:M&FG0Y'DL2WMUBS#'97.$C@>3B<WKX!
MS%E@.8Q56LY9O#R&UZ'1L<W30_3TT@!4-``9;4AT-,P%[245'GNLMPLR5>."
M0P\0CEX78W[;&I_3S_2D#UYN`Q`\NRJU;77>KS6^LW[]8*]X*,1]4]V.>F5A
M9X1!6"39#T=L??,DIBLF^&C:"A]\>CB(VRR$7EE5&>:;QWMBNQE#B&\1?`E.
M,C.8^+'-IU)DL2&KSDX+L];G]C04RR)<27;KK`Z8U`C:G@DN.:[@`*R`:XL)
M>Z7,&LXO[L[6#.P_6N?C4B.3TCGMK-4\M"`%@F\5&Z&.>O&[[9>ZQ*:!5L1G
MS&4[T8;UT7NG=!S[XE?(;T\AR^:[9\;0%-@QJJ,\=D1]3*GT*<>PMF[*2``+
MY2]D1CW*8`NT.O?C+<"S3KT)&W?^-3*]D=&_;U"\Y><UZ<9I6WFX!HBI<%/6
MM!"D&1]NEX?Y_4-__HU1M#7$`K3SY8V(+E[DS1[S:=F$Q[5K>[!Z*VY@:I,9
M_4YAU.$[NI_8\FC\SZ+9&[O'Z]]OL-+-]>B7XWB@$$YO92WVGU'6ROZ;?6HB
MQ9,/,:=5SOTR8;A_L8M7S;^2`^6QIOI*<%B`8<="OZ*J@N)!LIE[%D3#_DL^
M%KXB!G*9CIBV'!1-?2=1518,V`<9,)@F@7-/C]_NL&!>&H;S5G\8ML$.(B$=
MT,M^YI=;K-TR4[?&E%RQ[^E9YY=,D5(UD-G;EU"RKUQ[W5PR:;(("<\2NCQ?
MJ+Z86L?'H.I-+Z";OL!HON<A6[P;K/^RJRQ5VYB+NU)@^IW1C6:X@.*XH!HT
M0'G4`8&WQ&.0+.,VC!'Q(\[U>)N\KB04?@YO$=X!$.I1E@$!FFRS?7UO"LRJ
MG.A9B+,-$O=8%4?MHBO#T,0HY?#HF#HHP=;<Q*)X_8$P!&XY<I7<+:.V+^5!
MIEC$F?4H2YCU:H((]/"K,D>"FH0UZE12]%/Z5Z<9V<P:MYOT@6$_LF3Y2"\)
M-YB@,)30Q?S0N8!Z?(_:09*664793AYHG@P53E>U=M,-SAGZZQ>#ZW>C;?!Y
MOT"Q?KYZ.:K*R6ENB533*L2B@[J=3;<RGN6!IKZCK)J=YKIHE4V&OVRCO4L9
M`"2!:98NZWDMIS*-SE()5*9G4[UN!D**]6/[(@9(7T&N`J3#:?JED5<\?[_"
M"]H)"G]3V.XC<;^["_,'C'K982LVV_%M"#V:G3EW4V(#R72@3:^;?QH8&(S(
M1WM9^#^:U'"TWYGOU&#.9A<TCP*5(PVO^[:P(,3D(S$EYT7;^FI?$6-;UJYL
MFSU+!W[V:VLJV@AIQ-"E[0%:5GAU<^RN0]:E^/F;[/Z'6)9WD,C]>@3KGIYF
M6<!Q:Q[3H;/0W)/:.9O5J$VQ7XSA</2ZZ^=\]BPU5V"<XX?<GL.[$K7;&F@F
M^(,`]9%;:P47C=GPDH;8MI"2N,?\;J+L5A]-PEM1,AUAQ:`U;_&&%2''+T'[
M'$!LX[.$]=>O`?]$7HOHD[W$%)\F,22Z9=?,36IY,)SH\\EV=%8U"AA"T9$A
M;B335#/-^?6_,LMP5B&06":>A[1GK,_":"5:9/YTWNH[\L$P-5:;_@_DR@?F
MK]\&KETV1Q*L.&69N.,P';9[,.C`/A2&X#-^88<5<)5;7[F'7Q=\O6>4`((X
M0YF$;XO#CSJN*$A(9^^C`K<-0+TB^,/'A1BSW]HQ]1E%0+7`F^Q#(_SR80K&
M`!Z1H+NU(5Z3>=1#IP;[<Z17E69KA2HR,_UHV!;V0]BOM.M&BP^:ZES%+B@8
M]HGL?!?T+-9KOR?[7DE[ZA=0RX5SQX)S8^:>9M*J;NH-=,E(^A#?FLD*N9T0
M*B5K-CA.MD-#RX0LE(!=>VNTX.,6JW&9O,K+N6$R1:R0?B]D\GOU!%2,]-\Z
M0Q$KHOTSIV&J@W)?0^SZ-@N',;*!@$.3\7)%?AF5<$VM&]D:<KG"X8-`%PXD
M25_BCL-C;X%^=K#`7IFG<&@`[EK_'2$E)M49,HG8=?1@*O`SN=8<H4NKUJ(3
M:]6ME\C'8%MJ@HZ"EX3+^KV*G4V5O-$:(N-T*R+]R6F>8[%BX044#=^Y570#
M%#5\_=;I<H,?\KB_8Q_=.;<\R+V@S],YPT4A^OS&YAY>QH8YI'>I0:VV.<!N
M"T2+5NRF"1R354CZ3H_L+=R^P"T5`M;OVM=]!H-T7.S($Q,GT`KBVP3=`PMO
M,/86:&AT&.F!O80\D)<Q,5U_O9E';Q7K%WJT2/-/P.#D[G.<N[`*80YK$CRK
MU=^.G=MU66%++T&H@3>U]H\=G#C)G^2*L^X.]"'NHB>)\BID`DI%/VV)00),
M8I@LHK&=$T3>!YG%_>:&R).%Z^&N\XMQ/U!<20.$Z41]=0%H)I_ZY$IF%%P[
MI(L1*A?I*`#,H^\%6<GA>ZCUREJ8[^(8ZPZJE$1G$_^WK3Y%H7O^?BHUPQ=#
M8K*$Z'^V#5022/.=<DQ?L4FVB3E@.%%V'P/0!T?-3HM^?">S%X/G7CI$&6%"
MIR<^[TW6`4Y]C1L:D&2HB+=E6,MAFE2#Y5-=OG)0D?GS<0.782<V0U85R<:%
M.8\2DIHO"?'J,>ZV&N`HM8`I*E3N$#RA?HH,&5_N)A4RVME<N&.RU]@'FKX3
M[X'R]J!`MSJP_>DT&FE>'0*'I##'G'18CMX>0^N9[`"J<,>RA&^>C)R26.U8
MHP/_\A2FI?]!1#TPQ<YH<(W""2#="_31CK\'G#WZ!:LEZ[KF0,(',FU]O;:[
M6&$0#06RKSL;@6=P3Z:8XP]D24-QMR'*PZ%Z.J;U:?1IR$3_"$_2`R62I/_V
M^G-8OQDDX\FM3%#`F7J?;H.QA+";;M4Q4@R=-R-JM"VGH0&2Q(H>NBOK''=L
MKL;@OW._$`BU=?+28P0=+%=#&.'CYZ]<,BS#&6I8;*,CGPEOG=8_,I20$9T!
M#T3[S2![&H.Q<.*2:X^$8LG-)<KQ&I)P:2%M2LGN=`]<]%)L5]8;,MX>S[P?
M)?`+I6)>3W-#+E!8)F/G<[]9<`L6S*_/N@H1I4%Y+AE8R\+X!4(`.Y0>'0IE
MU%5(`);W[?O.%@G)]`^GQ:\!\SCU$R'["GP8!DB8/Z&F`>@>>9^?!]O5@1Y"
M77NWXE3\(?/@DJ3>?`ZK&+AQ\N!]/J":.-:AD!Y-@F-4=#^'4K00^8_(MY60
M=FPF`J3C:M.7Z?A.C,=9!IGOIWJN]_D"UJ\F0DA8%309Y41F.I5/P.?Z;X^*
MS/F;.[-\6QR>'6SU]>S8KB9SDMN*KH_=&U#!7<*79:+'FR-D1A^4(W*$8LU>
MHVX"><6_9%\,CJH59&FB>+W:?`$RZ^!7*8SYSOE4=+HS/#]P:'`@96-H;R<\
M/PHG.S\^\!0MFI\#0YYC)OR;XRP&`S0WM;-4D<'85=7HO&7.@Y;K0&30L%]X
M.F27.,V>>I#SQR3['`-G`A;2\!(@P&L;@NCPO()#YQY0/T"P&O<]S.-)OHCG
MO<('8(N&U%9HI[UDF<5]TEW-.T98<&]2>6,/KO/+:YP9/"9BGD]T@</?J:"6
M$;98SU3]@D'H$%&<BS4DNW3KM)K;<2DW+$%&IUEXZX$3PM>14=,9MVR1]_9B
M!'A5AS:*+\A?[JO[9M:NH?QJC+$KATVG#`S#A2(M[T2('8`/0\1\?)R+7YZZ
M8#E#;>1D^S&!M:N[*$W7;;>8\>O*]CLU@GEY0X"&0H`9*M%'NL*F%VX^R$:-
MD8/N'0C5U%96?4)P-UMHK?HD[(>%'T4`%'R1:*85YZ9GX).H1,=)93EA3Z&W
M(H?N.QG(#;\\@S+QVDE$,YOPYN!T#Y0J4%2K@,B..%$MWM5*@/.TXZ4RUL8*
MZLYE.'@[Y],@!R-)$:F?><'*#YZZ?"345V)\FQ-#O83K_#M!U*]QW[&<C>[0
MOTW4,ZD,K;/5`YD)=L/8[N?^PD\I`0(*@O\T$>+PWY1RE`+:AX=KIJS#$9GL
M`.R@&`(T!?;G)`CH,$8-HDLS4PZ:ZG=-O%NT!N?5O1*H"@K\+OD+(*"3(<N;
M/%"1$5]2UWM8$Y.2K%6"1-*<J!-ST<'7]+R._Z]&[6"QN4`_]$.PI!1L6'QL
MF_9<KJ@$U@"!;IDD.6_G%U1H9'UW:9GL[O*5$M:0ZP1C2F:0]&0E-V1+S>IZ
MI@7%VZ'#\8P'[]ZD`*-2^'@M]055DZX,=*WAIK?>&N]T>IJ]CVVSE>;[DV(M
M+F6@;0+M`_.:#M#D$1,/=7ON_5T351UP$3^FBC"K&RPM_<);@1ZWE#6KG&BZ
M#A%1&#Z\"4IY,UHN6]Q%"E\_*ML$L8X](+F/@L%'D>MECRM@E^1XS@_*V\X,
ML$0HLIHK8.2P+:6FJA&>:,["2[_!SOS:F+/]\O@VI;J2Q9N<F[KVXB"'CIX`
MW+<H9E;W`UC:L4C#SB'+3E,!@"MTHQ8@B>E"3\<L4,E-A[ZVB?\;A9>W`01W
M6DC_%A9?J=V1D]=^P^DQF;F`)E_3N2(=D@_GN@!2BG8JU,P$,*"]Q(-^@M-?
M6K0XSUD'AN1FG;J)NX3V,#YQ&KR!_`S=,F>!,XNC;F#2ME=][,\N'>QX5$M^
MHD,#P7TWM^#""Z^$^"*<ERY''`6,.2[KS?.;4_YL>N(=BP-A`ZKAO9W+^;+D
M*T'V#X\S)-NYK+)V_5<.KB?^./33VMB`UHRTM#FL5<W'*M6;&[98:-6C;>6R
MZ(KL(%TOFEA;]4L6_%JTYT0#3@F^9)3U\*0W>F%*\_R($GL#GOG>=<*]/LQ;
MS&-SUXT96EL7UYQ,KIC!SQ#;$"@@(Q]::;(!'AF@W[:\K])-L439"J?\SBE8
MN0JW^LG.$(?;O7"8UE`]5412ZO'2:X^/8Q7GB'3XY'O>R2#%7\704O85HV\]
M!;64J:"X=,'L,X;;SJ%UY&I^2-JV$*A!4IAQVBE&^0#/SUJU:=:N.86-O.CD
M<&G?GFK;!$B%'TG:[0"5^1LLLE<`]0FO3*RYLG&`PY]'6+SOL&^4(%WZ0P$]
MQ$MI@/@QID+P8/#?QA"JR\LIRB>UG.D/*EL!YP@IX6#97?D.KKA+T!FPZ_5Q
MNK0%>YI/)Q^#^=7;$2-S&I[Y.9TJ.-'EW.T21R%I1$#G;B;_:>Q,EO%^+]LK
MGD/"VEN$A4*A[0\*&S]:&-]6"MFG@=79C?KET@)^,:*';G(H,<.R:LOT.MRW
M$A2J/]$0?P>0TA_5**F%H=T>JU(MN.R;L+B4_-O`Q5YS$4`&#5_DR[#["G1B
M8AH29@0"FHMA1VY8`?X?J+7Y#.J4SL1&X`U^$JA/J]S6@-XJ57[Y3[9,2QA=
MM4S;RT2ELM>Z$A4'BI%[7UPH<:RE$"VZ8WMJ2S'T#`N4`</^-846.7('KF[Y
M6OA]N?,FO=]615?T/,DO_88GY1Q_G^K*\@EDE(78Z59Z=U*GGRI3T?J:7?'H
M-O6R%93T'`=(`_*@H0SNSP_O6S+D%DQG^WK#-MC3!U)R2[V2`KM[9=CF2&U%
M$F<;XV=R1K3O$;MXF$)04?U_*=*HN-Q)FI)>H<#&>)+4XD(\"FYQ;^%2=)#4
M6UYT"XXRR1W$1(>YR[>DS%$9[\*CL7ZN^95B9/680",VT5.1Q:A/$,$\E@,K
M32!H%<5[2R^\<:RN\N\JZ!S<Z'6&E.E<NW:J6(*V3T$Z6,\P@RS[J,AH-EUK
M/>P5+-RKPV2%R;1&8,.6'90K@-3BU&5J1LSSL\*$O>9ZN<5FKV]%.AT3G^PS
M)N?(/8VJ@G4%\SA]`R`_WNUS!L\=<!4?>"M<VH4$4YDO+XV(.<,[L>C8F@CD
M%=Q*(@!FS49?07'P&^?`NLC4+E7'-1WK2B'H2/TL_SU<,?(M+Z7V$FID7+50
MJX;^P<8?(E_C5A;AOG!6RZ*Y9:+^R?*Q*U5T3TN^_!,C=E^PXSF/:.F?3=U4
M$UKS=J[:I9.NT&]PA(B?=DXIXF@,:Z@[M@=CYLA*W)<IG`>I_GN'+VEGEJ<N
MGOMWL>MLNWZVJ98;L[V35/`(_,:YR))C63=:!N<FSG)B42M19<YSNR$A)K9'
M\*VLC."4:<NV1).-FZ9SBK#M>ZK*]D)0O'^>FKL=FS^$_XATOZ,D[V+5_'4;
MB!NHD;W?VIH0YI,9T`25:ND@L=6;7L`]A'L,I4U4CAJ(0MH<^CRWW_2!S/"C
M;H#DQCRGJI(`--,HO*^<QQAUX^Z$]B&T^G&D5R*F?R]%E%Q<A5&XD7^Z[*4S
M9;-.T[@+]OD=%BMVKI+XYAZ\;!/0&0,_9.(N]5O1@HO`8MOOZ%'7E&RKN.CO
MWV)0^\:V$I7$6?-BN,'J*7F0!*_C0K2:[$I5"SOI0+;EVZ+@IRMVCI+Z67WC
M@V)R,97SFHGH?^C9+GNN/12AMOA.=[!/'TP3?@\@BW5><?RZMX?$Q7W3;`UA
M#"./6=DQKB0^_$G;"C\#L-&=WUM(CU"V%?KOETMW7Z#5UNQZ%*:]?*>4;,2Z
M)9LN,B<V[-7,M*"0V6.9W,)TLLR]`Y""SR'G]81QZ-%B/`T-N7YU]U"ZUUMO
MSQ-E3:7OT>22'WX@XD0CXVYWKYWMV?P:=R`MLSXE6:)#<[89$/5Z9Y>(#./[
MT@A?,@;P"TEZ)"K[U)I/H7T1+Y1GDZ.5^B5'\]V`F;0SP&8#0M2T)\-2%6KW
MEW]*6?ABV0Z#76I&]K<395(?RR7$*IO2ITL,>1E)NCD@!9=Y_O13E>$F8I-%
M?>'#4G[^[=[$TQ8%6T]K1S,2U$[M11ZUSLE^3LL*+8.PI9V2H?_!B7D0@%R#
MS@'@7;<#';T0:"";G:VZ0'>)_","]G.6U<I(M."9=2ZPMY7*$Z6&5DMY<BQ@
M"B(02X^777S9A8R!"-WGG!QC;80,:]&\NN4YK=)=8XA?^56L/B![U"H+F[QH
M^12QSG3AZN5VPALP(IOWGGQ2;F7H]:4@T]ZAP]-38XO_@DQ:A%7![>68H!&7
M:.4.8*`3O`9`DE.]^N.BBX.GAGS$72YR&&6MS9^,#F_TX!OS5LN.7^%HF:.S
M!>5*-.<8E'/TUY;!$V.C%S&RG*<@I6!GC?FQ^7SK3J;*]1X>@9'CJ.G/>@CE
M2:$>E]$D^^M4)4(G!ACPSG76$^'I*!/'P*]QV5'4W<)'`%IVI4J>;^(9XCFD
M(4@R/;\3.AMT]M`L',,F]&4XN<4&Z":RN+X(@9N179ZO=L)Q\*[5X=;)N?J(
M$L=9J?3.P.9GU3;>).GP'TH*KI3<VPJT:N1G#`825,>D']8_MTF7G.-H3.BS
MV"2)KCKL4#V%P_[*7LEKY2(??8AJR>-IBU*?%D5ZM@S<#Z"Q:Q[7J9XHC2\K
MWNIKP3"RH17[SZPQ7@!'5+AFW]0BP^/WE\7S=9I[SZX?<)EU4X_I=!8]`#.*
M\-^G%',`-_>>`B5SZM+>#?_.CN95JXMWTL+'T3M)>5<)P'T+8\0MD?]$-`)0
M]7GG-*UC6ZH*O0/C@#1KI1Y+2L8]+W]*.GVB0>ODEB`6+P[N$1K*9HQMQY4*
MG[%B%Y+NJ`333M'^@I^K'EU5*DEVQ,_"E]!PN)WU9NNPLB:5WJ7RJ+2]2V#9
M0CYLYL\S0CEH(L'NA<X`G/)X.F34=/)\N01@JHG0Y8QFP>,P&=JA?LIPK+*@
MQ`$UG^P@.O]<8:S_CFT_*_-[4I&=!X-WV^(Z#G^R4PT%E;?Q[T!&;#.;SNWW
MX@Z^O3=CE!31WYZ9QI0DCB#D$O=-QE;38],XARA:!^#)C,*P*6?1.*\.T>R%
M$X\NZ8&G&ZIXKG?F8!1[I%N<\71N>&M(MP*>"_LWOIUJ5$]9J];/KXM(E_MF
M*_V)3+9(@T8(HCR3#)56R2")>B`(L;N:9P#W]&L3K/:7V;N)MT()*<P5^@.*
MS53CV1:.ZK+!^YU3)*_/^OA.5>/N!::'\`+@#T@B3><9.EZ_.DFJAR8N_<U%
MY4\WW[IJ):GIC_R.N8$.H7D*J^@C()8#XY'@+"2B5T>E"')U?.,*CF7`WTJ$
M,".XR*F]/#"19/'`,$>YQ34+\FR_?P&5,B<T<*_?>)21%P0OK]OB6&?Q-_[X
MCH8TE2GAOVC4=DK)*?-5%^I2H%CO!#=)?LKYHM"X^^)PG'Q:V<X"*^'."NDJ
M'LWH&K;C`15CZZ;^^*5BM<L@/DR9+/"%JFFKX-EC>U@-)^@R#=&N`-__3A><
M$B)VN6I+YK]R/E^[J\E``<,*#4^D2I*G:$2;Q5;+NY7A5%C<8K586%'6`H9P
MVE8Q&I2*`%`^F*J"LC,W-YN"^QTE!4^/<QR,_*1MM9*=[!K@9%BJ0Y)W,2XD
MV]=Q9Q)['IND*"=X]EI6VB0LFAM5='6J^A;RIM9"UZ,Y%JHS+D#-T%OS%C+S
M&8LZ)-2U=8PI??L,,^D_.G7UN`F4>20.#82K)H&E=BEI)"B%$1?H4E^/#^?,
MXZL[F#?8%"I:9-DQS0R,(2E1\D0-9W[^<G4%GBEG"MI#S^J`Q6V^)!<A2@@3
MOW/(QPM%K&KH<D[T>DLC.L;L"SX0X]-4L.9+[Y`9S#+__H?G1*!KA@03LZV>
M#&#G,92$-$;VV/KT\L92'\J57LPZOWQ?7/IP+*4\A>Q#N`ASC#[F_$5<#*@L
M>LCOI5#2'X[><NP=J,GA"T^%931MP1\6^S(KSDY2F\1Q835C[4>J,"E->%U,
MZ?MA5QVD+J'SJ\71X5A9/HXAR\412-^0M!<1^38S?4>^[2OK63SJ]/,`1B'+
M1[X\?!Z1D9".%+5RL`'&7:SR./;E/6Z%)"QFJ>>"LJ?[0&-B'GK1:I[>]5"4
M6D3H8=&N[;N5XF+1,B\;Q&6TTD;JG'86.];S_*<U(D-!_%'/N3A76_TMZ:+;
MLZ@^TW=X:NN'MN'.\(<]UOUW\*+>HG\3]_K<`>/C7F7#6%85M.`:^B6!'+]%
M'V;O@-6GSLE&+&V-\&F8<&K/:S8U,M[&5R&T)D_F:YPOC\!6O,-LLHN4;,G/
M'KYH\^-?&3-+M6J;@^KK7?Q3:3^K'19>.A,.9;,OF%6A1EPKVLU#WHH?U?!P
MK)I":(L5C26H2/L3[2#1D]29"%CL$/<%\W-DA-KF>9]_1&P<S>5OQ5.8@W5D
M<"!3&"[&JNON/'-([:)<+NT!^$5WL,)R/=;23'2+>)"Y$9RDF`)/\02>]<<(
M)5!B$.ULH5Y?8BDW`DO'XVV'G?D$-V2!)U)WAYJT-E$($**.OC(=C!9TECLQ
M6RAH79+FU5@#1L&].6U;Z9\A@6L])3H`=Y>778(\25[J+SRI9L@$^S3'#L6'
M6>%6B0:%C4+X&T[/KD_8D+#!6%7"YCVP??,A_LNP-1E]VHE!`K#I[E<%&DHO
M^+5DO@=;B3>%^J<2)_?(-H@HB$D'N2-).2@G[Y&$UG<+S&SEYH.%J]A;8K3+
M6G&'9K&%Z1DU.J.KK_SG@TN7V&8@UM,'5I]HL1B*#5A#Q?PVU6R`]"`)K`':
M"5NM9YE<Y;_*8U><2@U,"(5\KMRJ_'D(,9'BM6@61,9$<)<J`0EH?A._A,9G
M2N]AO@ZH*:,!Y\CY!O)22]51Z\$F@:)=^0[E_6W.F6V=P4,A8ZLKT_%,'#I=
M&U&AOP!,1`6?8%NFJ^X-TVILP@[6F@W125O16MX^7P?&R''S;GKEHG0M*!X.
M`;2B<>Q(U;#@UEX(>X=FU(.703./A`7.J;=LS0.4OUM;7T#[P+QM_'%X\Y/8
M!Q;D95OPN04^(S&GX!%^%Y-(`-?)RX=<7+XA4=]O]XM;+"VN$65P=8CGWJC7
M*92V2ZK-O=.YIE9Y:;Y6?QJ;\.I%D]X%RYCS)X?0O;M?/]E26]6%$+05A2+1
M>&<UKQ,I#2-8L8K"588D3PKB'70C^3EYSPU,F._+ZQ1P"DHQE]$GNPA2F512
MLUQ[<=BV"+>QI+3""8^K=D24G^[ZP%Z30V"7V5D*RJ2))[.=)E(P7TO;?62G
MMCQH^6>506]QHKKFH123/?T$3W-'C)44G.(R@`LGL%O`<#H*6!DYCGUCDVF9
M6FMT1SJ.6Q)P&VP[A-%%>G)EBS%KY4#=<Y^MI#T?Z9\41':^"`#+W\E9!/UF
MTBP][TD8?5ON_K9[A:=[/5K-:!;QO$A?ZGVI>C]"$['>9(1B)>%'R,HE'3%$
MRLZ/LU(9:!$\!BLF-DP\X=WR6$RP8:D\]#["-)>$JN\5Z9T+*-$(*L8E1E_*
M;O=JJY?X;B^M8W+&(P]<]7>M3D<G#)$'LOQLO^ZA]D7@R8WO4X^^+D("(0.W
MK"SLYHP'E5/X.XMQ!,2=(U3J%4#OIDE>%P2\P8UPT0[&P\_[@QO8H8<G;;_*
MT:.$+GP(Z@7$&&P3=K+4;)*7A:^%9`RQ__>64ZS_Z50PH,?Q?[W,+,`"`%(_
MIF('@_X_LWLC;9T4\DZPPM`%F.P2AC*Z`M"5=^I=LJ7H"!IOZA`+*P:ZT655
M7KS_6%4XDW0H<3B&RXJ@P@O;OPN9<JS*)^/>!QX"2[7G?1?EQ6_"1=_49#*D
MX!Y(JTJV^*WJAD,7]$AUY<:81*,3,T]]RGLP'%E@\%L5QS==>\$FTD<3@/FI
MXTC&($;#L04V1-&NNGV54MI:+(0@,1)8Q0)()>`#6*XK9)XQ1BE@E,%'';G8
M7V/0H^DXYHGNUP\E"S5$HWLO3GQ'BGI^#2VNZ1=M6L,.F,8B4>JU0]$JI/Y%
MJW?_"SG&O0C@"Y&[!5MB[C%RSF5.>>/+$"P&TI+M%]*-NPTK>17$/-GV-?6I
M4<C8T55E+>D5XC7"^G4?,PL66K#54CAS!<Y!.TW<(<%AEHX?(&>-ZP<$D5Y!
M&G-@=7EU\T+YI"<G"[@K81#26J46]TS+>YZ/!R#TG/3%_=P8_I6<D2GKDC+&
M+YSI`=YI-!AFH\V9C?3K`N:-L#F]:4@F=D96TLZ(HT7%099#LA<+6FXU&[OU
MO](!R3#Z)Q70WEL0,O(.(!AA^^#BK-RTU:RY"3'<\3?\4?3P-[WB9;!<-/0Q
MD^Y7OB&Y=Q:&70CMC9Y=2$#&1!PIH>"?BM5OH=V57H\68<5KHB@'%8)74K).
M7;+-]9*M(APKQ3S>EDO739Z8.B/<A+I7,]6@/]2Y+OS7M[XG!4,;$7V,>6H=
MRB28N9?$PF;P7G7\6M`=8=):QWW"`SW2<WM<.9;Y'V&)4GUOE"3X*6M3Y?'N
MT6N[8_X)^\&JH1D&S$C88WX-I0RZ/-1,(L1+U&GP=5R?T*'B1#@::O8ZUTJU
M#LHE-4'DA^S?2D*%)7[B6J"@7+M'4B?M>5G#D,B[+>D+<S"ART975;.E+9*3
M;Z_")6H]CXNMMD]'UM?@K:>3<(\M$)GK)#%3RY-YRK!*8%5?*Y&A+@>DE/9;
M!)O"[Q+M]#MF26+[Q![&[/.8(<!RV?.[E.>3'W5HOJ'N7CR)'WJ#Y],XR$5'
MLRA3PE^'LX9T8679U9M,'?;6&%!EP$WF6@HE.F*U5**5``TLA82YGP380$4[
M$N/T<J>X$3G>81%N%LM);"WIK&H!&<.8KQ-$FL,V(HG\-_2Y16"20FP2&WT!
M@0MA^A'_009;D6CNNSCI3+STJF`H+X4XJ@)RL":1<1![;<Q@S_\S#E.A;64$
M1ML&6;4W,]61B+;OIN#^P<55N8@Q`XN<9CA/L9\7+>E!/*6'^,L5T(/"I4:!
M!NZ_\A]IQ53$7QC:5$!KJ^^:0HN0L*8,;CNRZ,W(IPY8Y/T2`5JK)[BVS]H3
M4O"O7Q+DA=ET?S_3R[5#>*W`MZ![?+0%9=P33]9G?8^0->%&&?Z34?8E"NY_
M#!K)\)Q<'#^*98&.RT-X6\;DCH/">8T==7-493)`>W4,!GO&M)AY31K<X6@%
ML"G'Y3=.KM3693&$@<1K'&;?Y&=$<<^"&:#IM`E\$*0U#>)\M8:J<0]`;@$<
M4ZG#WP_.!W?:'CR)=,4$J)ZA$FV96HZX-S%7@B//9O`YEYB`NKTH5ZG7602`
M]ZSJ"3>,#$T'4TD(SFOR(E`LPX]E>`3B!%U5.F0<"'74AN)5SKE',Z>_*;88
M9-6J?LL[G5N^>,#E2SK[WFI@Q>O`?N$Y<8/$X&O4PG80WT8X3)\+11:/K_V0
M3'T#\_R[%\"=]2Z5S[S5[G9F(0S1X>0+#!I+D9X=6G[P:934CEN;I74%IX!\
M%M@O`X-M(Y@N=S66:/?#4TE2,XH'DBA9(!"Q5;+DF@'[(43TN-X2/P`*"TC[
M+5`GSZ>@@\Y_)@WF+IL=$KG\GSZJH:S'$BRB11M=XUKJI,OB/>\.$57CD-,1
M!J>=CPDEB=-CK.&!5%(RA#1!*<QT\\"(1M19RN5!P;F/?R-+X'@:X9+*RY_X
MA.`XA$1Q^1ICG^Y,;AQ@91)_DUMS)#V%J=`WA1@6D'=R@TC+.R<^_-WO`A7M
MDU?C0O_^MXWF8H28Z[BNW(>F_7.FB'Y,B<FZ4Z->D@(47,2W"+<*0)""5DVX
MZ&_Z<+@6_._;R9@3?%^R^,I90/1\/OM^6:RKXW^6$H=Q6K.QYXSLX8TL$`U_
M+T)GYMU6Z]?@"0\4>:&I.T+\&PJBQ=6[W190<%;.(,Y+Q7K1[.N_SCM3E.IM
M$6^RYPF'Q'9`CTV@/YBN1$9]NTQNF(CQJQ!I5L%CZMB`G5XXP#-MFD8K&_1=
MZ;)Y8F[(.V"6US03H]:'&[>=N6_-3*YPM9VQU;-;R<7E-YX*3$3D%YNG0_D%
M\^DJ;OTZ3)V<*NT.]C)(5O8?@`]-T=8='7-$%6KOOE$NC[!Y=][@_2+P]\31
M4O_NT\Q,WB?RI#APPSL(%66RPBU'*WCA+5K=:VD)G#NT"A]W?J'M?FWO@)(^
M4\/"'K0KJ.:^PK%CHP03C`[(ZEE/6+(*M4%ZB2(R`3_^7GO3+4G9#>CC'U/*
M-F[8TSC-JH.3*S/"G-2Q.F)OIVG\F>R<B[4?1/TKK=::W0;*1Z1T/:O::2X.
M@96>5C=11LZJEVMXPL!)$W=;D4Q94DX1[-CSOO3K^2A;%UD%%T%?)',_#_C9
M\9)-6%P(9:8N6*<.W3GW4E]//8P$ZIW*:]$,\X`X:H'<B&5C']/^?0^4Z41@
MI4>SW4)=J,$5)WI&:0CUS_<*`3,?ZG`.X@A5K%_6>\:\&W;A?!*ABOBLT98<
M#[7^W),H[`I84_MP252XM$R<OZ/J><#X%M#/0L0DR6$!^=F*QALJR]FI!6HM
M?K@?#G72R:G8/H)7-QH>Z_DZ4>ZE2,<V-TLZ@@J-?CTQ0&'Q/'DQT7Y@4X!V
MB"303)N,V8;=?L=2@1W?$_H^*Y46'2V'JUE?D\U0":LFW$)P6R$9$.UA?"[0
M%]WN>WF$.U;KX.74DR!A?F;^!YP,I_AK\:PW&*Q#"ZYI$197]HFV/PXE2:46
M[(:!,?A%E$(Z4*$.CIK8V[=YT>YGB(FKZ>5QX-W+Y;`;(*`#M@=J-W@T<<1]
MC4^VO?0G((GQAMS9(2G['39E*D_\\Z8M+S*XG^#H1*D9GHU=T3&Q+TU.DO$.
M=^B:O543M'/&P_1ZDY\BIA*TF;%IM00%7X(`FN"HMNH[#P*<P('G>+!.-<D(
M#B_,=JR9KTD)[`8B]1N6.F:*6&@_ZD6(Y8?>51N$?7V7FG5$GKH:#G4&6]4=
M5[D1N@!<K&<D<<^Z(2=L9T?\C74R6("?`&5>Y`>^B\:%>,\,ACH^<AUDFD%8
M]6WW1+X,]K2*H8FP,TF55)4VW0MI=8C%L0,+O)V9F\*]ECHJ`&L^]'VAK2B>
MK/,Y2D,L,`1E%74'N`DQGBHTG0E]EXQGQ3.["NTAB08KN-04#6*'>9BH2-?3
MXU^**WTBUA^=A;Z8<$%1J=!6/)3J;8>WZ'7Y][4$Q<<<464QTF*C*/E@)N>8
M2<U5)*PE<U&XO9DR1..4?SHX($OX+V?7%C295O)S.7WC:(\[Q5GA,JV@)AQL
M'KE[O*4S:&9&H<'PZYV"F8,=D#]2XD9#85A.[N($-A@8F7,!^JCIB@/ZT[C;
M5/,9[J">B749*3F-9ZQ@R^4U9[BL3MFH5'L4(F9K=\6Q#?CC$C);35RB!&[2
MROK_"K%VCF8_Y\P9HX2G#L02U)7:/GD?JY%?"=&#[W)%;Q[$)S)#PZ-XC>@P
M1@G14)&T(J0\/:ZK]V[MN]J`-N4=LAYQYV%^6>O+.@O=%]:<M=U/E,_86)N1
ME`4KEX;)`_ZF5'#'&-D$(^`>LL@76,VS&D]NBIB2+-'$`;IQUTL79C?T4?K<
MA!(;U/>9:-R2OVWMV3S>F/JA+4_I]@LA)$C$:4Z*?=9AN(HOLE!1]AVROH<:
M^_X'P$:BO78T\X_&I^N=\?AK^%X%:I_\'Z`?XP&;(BL??Z54[^[D\NRF/+_B
MV%;!GE*OP8&HTUI+U./O,H#L`M4,S"9PYP[7?;\J)GDK#TK("$+B,;.`_\P_
M_;-P<R%MT[5;/>3>+.'(.V,;PZD6;H&*;<I>`"N05METHG_9K(2PMC_?U<B4
MYKX*:O,]*+G_$(';-A4U-XA!8TAUL]]_T]8J)%@^OG7*$5E='B],G=PO)<7X
M"99G/S5XO<431HY7KR"?ZU`7#7+4M%VUYB4A,U-Z]4N=!\98^UV8[@TH;1?"
M1P_\5:<<B1(M8Y2Q#+78'15UKT59H/(IF`A!P*OOT7=1SFENR5FH^*5/R_HG
MZWIL]$J*DK07D\Q_?+[$T*SV%<_B&UJ4$93XX3<2.J@RO)C>A!>,<RX?,]?`
M?%#6("4XV::I7'024Z/XOC1P3/);L<50#V@9ELPT\8Q7_<V.`.KW:M441.9(
MT]R2-'OW%'=KM,QVQ691[Q9:+IJ:C`FL0+`Y/WZ%Z*P)EZ&7>JF\(XG%Z&TT
M@2E$N=:9D0+*`8P+IB\>YU21$L%Y3S5TL%VSD/OZW(-]]9(&)]%[U$Z;/*KR
MZB4'55CU:HL+Y6\LT55?UA-PCEW%$RLWFE321>/?3Z<ON'"1>N]SOS.@6QR-
MLBQ./?)]>[/5(!`IJ/BBADKV("%'WR!QC9ZQX!QSUAL4Z[JWUKDQ/:4^F?D?
MK6RKIP4<"O,R_+4*DJ9.[$>(K_`<@OL5IM8A5OYT\:IBTE"S'6,'2F892'HN
MYQ!Q(0=1A_\K#7('',WASMY;LMO,(HB)+9%XDX/R]">V(K+U=A>)HO%6'C0#
MJWK/$:^3+`VM\+E$#^-SDP)WP$I3U+Y73E%P%%6.%WV+;LQW.K+I,]&!"J&B
M[KT$2&5Q:*<"KZ%WOZM&ZU(E>G]V%F&7F5F7IK?DU$H&1_^D*\"H$6^5B0?5
MR\+2PL$LE5]8@3?RGG'T2EB?Z8D<RJR^PQ=;DU&8:[W9_38F5M97(4)BAL!N
MWX6Z`U6Y$E%^S@PED8I5RS)LE8-!+OR1`SXP\6[!P-2Z_\L*YS)5:<-6K]I$
M&_9KK"!Z5W(X22Q!<W(@:?36$%YG"ULKE,=M7++3'NVNBKC1*-(]YAFXS7]C
MA/!LE_?Q@CH:&X\*@'$WBD()D1(L*='FPD<!#L@Z*D3(A)`6XT!!$.R`3+CP
M:>PY-E\ML#ZR'1[J%9HB]*!!$GE'5>=!(_O=+!2)2&/+=7L*,631W%<NIW8R
M+T7+7P#*,;-96J*9DO`T12NXLLP21\A1DAQ5$HMWG$XKJ,O$PD9^Q784"Z(H
M7VI*;S+JH56IA^K`G"3N%SZP&,_8B'+MZ;XQU;?!.8-O!J.0_=%/*,)-.@*N
MU^T=<AD;GLB7$GM3]5J?L=ICVS^[)XL>+$'8S;`<&KJ74)G<6T=&R3:!3A^S
M),/R?Z-%L6L4F]TD4^(`\ZS#_-F<*SMX%E^A9OEZQ<FH]5\BD]J)7YI?3+["
M&@6'`C"H=,!EB+[IKUEU&I8$D%%F0O+[SK3X=-1@$_(R+RQBZ^^;-":D'ZG,
M88:,]'GC+*[I(6,M8@*NYZTE&0>P&*`M,ZPOHF]2XN4C-BA8Q)E0E;FM[1(#
M@/G*GM\.&^@#`4`^NX;]_?4)FN0+7&;8U3V8.%&'4NF*I'/O"WFX8_25J^IT
M1AV5%]P+[,4\[$/U=O5,N`S,E[8`R3LDU^YD]XZGP#!W;G*B?`?H"0<SA#=$
M+X@RW+W8NSXL/(5DLW9(IMY;0)=(M<]]YFD:=!"B_RN%)[-#K<&Z$G@<Q!9^
M#[:DZ\-L*JZ"?M7'RK9OY'CVU.<_REML[7ZCF['\A<5=ZN+>2IT6A'`PVHL$
M&5EE]@/^)\<)3LO2FQ'^P*JTL\L-N-H2RO0Z!"2<:'&0KWX.^A<!YAL&\M7O
M&C^_^@8_0/;?2=U&HT[/;G6]''2"&/3N[O3IQPW]/K<<>5&G\OL@7$;('#M1
M="D4"HGMI`C<0-C_@:3S'M%&^A#U(]CY%T=*WK81#GBQUS>;<O:YF<U+D#8<
M`,FP>PUT'OXROU(;`BG_3.1Q1_5C5VXKYAOED7(<84IUC,8':,&7Q7+N$H+B
M5:DCBT-QCF>V;D;:O1V)B$*04'4?0\S\[GL!&0.?3?!'V/Z%`\K,H0RC=N^)
MGT0=&T/!3W?NRHMQ`6?2X0#N[A*7499H(R'NX,9\[Y"YH:F4H$^@VG>/UPP0
ME$'8=ZV$%12,!?D$Y*TB<IMWJ4E#B6^94L?`V5GR9_FK)_P)#$M:_4"=DRL<
M>H?$$$G_$AJFOTT>NQ0Z:1P8BJVR3'$`7B`(B;M9_-4VQ%J_KAP7.,"9;]01
M`DDFRMJ_3)"1!RTL]HU8[J`Z,")[7^`A\,X;M]V`9$8*U<Z$YN//YI[P<=&4
ML,J]4HE2E'%"/9GSC8@*]:87<U-:67]X"$,1=]X_#$B*(Y*><"=)&M)0^Y>:
M_,UC@U2.YC-X.*9SE=;_'78_"E&5U5E.^#=]X\VR@^(_P22QC.*#'=D1)<^]
M4`Q>?<6E\F.2QUYQ+#T&XO49DX:;0Y$P$"U!N>\[&V,2$TX>WZ=6D*>F"@];
M0[XD7N</[W/.G7<&*_9(G%<W3*9@(\PW1$-Y`7T%Z><E,0<FRPLD=PB+.#L%
MKM-6HY0C1#_%*Y%K)@NRW;H5'3;L8_17L@,74?L<5$!*\MU#TKIVN3+='//^
M:\\C"KT57`@^D0_M[+EIXK9`52<84BRMM5F5<HCS#T92D\/Y*50MLR_=L%KW
M;%^R(FQYCWCMZ!FVEI%1TUT[Z&!MX`&QB,9[W.U$(46I?$6T/<:(C7HY#[%J
M21S4KZ!Z[R!*>][OH":JM&P=8IS2=I[4'YG%%38RG(7R<"9B,@*26>B<+J,9
M*0/D",^:+*0(VDPFSO)URA_/.&&/K=^NG:(9+PVGX1HJ\C@I&@+TA/LX<PLA
M:H?YJ3$6F0"<55))`#/UMV/(&8Q"/$V&O83.H=&`0Z2^+"A.`LD\,/$DB7]U
M@";?#^A]*QJJXX7X"5+]JLM!D$>J&0TZ9,)C*BSM'H-*!DA/PX)T$^6D)C.G
MT*)Q;NKM3O?R1/GDL2RR!ANF._+*03`_3<M45WGM>O.GX:M*MB8GT"`IH1VC
M/Z.#9!5W.^L2=DMI)JD`2WWV_+,%LK,=[1+CI#HU+@K\D%U)TE]MW,NI)GF;
MR04>Z5S1@,I+1S/0@X?Y_,\4H>X%)HT`^PY]'C8XS_/$*JU3^50S2[\RXG0M
MX#$Z,79_O$`TSM!]$XKS<JCY#G&@JV1E4O^I[WHPJ)"\(.CPCPE>Q4*/I#2L
M"O(A&*M"?*J2H6FAO*6RUW2"[C>V^2_[^:$\&?70?XN8*O]EC%2QX)W@D4<"
M5-R87H,N:B_\HR/)_VZU@_=<-^SI"_3V7C7&9Z)QX;Z"P4[OL-\1*@"]P&H[
MTGNJ7IAN*I/]`<K/BD7(M@;0(0JC77>KJY_2CL)8/+A5[[K_EL1KM05F.G)X
MYY03+SSEX#\S^E%JU]:)2GE6L2,_">2VC(<NDRRSP%)UA,#>V;YW*VW7K9\E
M32T@7EM[7\\<!5_A>=Z+B/6X[06[ZU0:2,9%7YXIFKG:IY6M-%<R:F"2'@;!
M"2?]SJHND1VAD,[KNB$U2?Y927K;$6^`_+!P56V'BT9*F7#0M+>+-2=C\SI'
M$CI/JQM2WHC?M>MR9KLMW<"D#]IDKE*[Z\U$)T6Z7YL,8`^B!J6H*+T6VH`P
MGNN%I71$H?[6I6!Q\(8GNLKRM4'R<NB3K6UCP'MS"?!YX)X*WG>N&&7:&W>#
ML&I_\\?;-[R9LR+:&DL&[O0LNJ>V>X'-M1(F"1"X]KWI<B1K=*<E%D7I9MG"
M58NA/MY(+`Z\G\:Q]HMJ"+DD0Q6DI+%,F"[>E9A\+$W>L'4YQC6Y3<2RM)6<
M%5'_H1M\V?'5;I'W'`WS9=Z^]$4;,&*G?)`24*F*-7?AUZ(@@:^!)[22'?7;
M>;01H-HZ0;NO[6MXVX).TK8+9/A3='!J4&3KFM#]V5ZHUSWZ[2;[O]EI54/.
M_9S?'Q>A,D\2H*5-4WWHR2AW5K,?AZ>FFN"GPD\]"),UGT1\`+R+WUP)O1,;
M0ZB8G7:#QJ=[H"?'+7E$QU;L16Z/Y_JQE;%O2*&4N1^`,?F3@YV"9[?"!CDN
M,[%XR4L^B:@FUZ39H[/Q/R70#+(?9IJ[2Y022BT=V2QKU3X6ISF$8-%Q;_<V
M\GE=S(5;+O8&ODRNI<<#SWOH'F0QZ!B6U(=0^SRRD^-F)!Q0=,0JZ#X-WUGN
MJO/61(`0Z$^HZ-ORF'@8M2]=E/^0'15B@GG[>XOK0*%>+1SM85P^JL,7LC64
M,P+9[!9B)_H?_2B5K_-@"1#ZUXU5\K4E""!CA*N^5LN2U!8Z-#1#O]#V3ZZ,
M5304UQ%F+7Z\2;1E7TM@-EHS>:D2OJ2:2+VA;Z5X#R4>Q,1,2]_R$J-R5\%V
MS'],Q(]L2VYLK8-2`$/4!]&N2V3N(V]]&:UA:I>*!2/A(7\"+RVM[GMMY">3
ML-HE$[-F[*+)G!KP[9I=YT/87Q?"F,2ALPS(T\/Y_IO16E*@7UD%/#HN4R&M
MYA"!<ABE(E7."XJ(@SE!X$PK35'ZY?.&K%R2:S*G@\CXA?ZK!43,LQ.F@E_.
M8)S>\9M!RI*V3I2?W8DMS5VE[`5W%R'1H,%Q$A_0OYQW<%4UY>?QB!II/.X'
MMZWQI-:66XF%!F@D-Z3X=T@?&BUY79D-TE9^1VM9$:FEURU%]41C-KIOS<41
ME*))E\)`<'!E56[G\[39`(_+05?V4&%*L4&P?P5^OA^ZP=OVIQ#JPYJA%BCV
M&J&\''M)0BXK]#.(*=,RF\2L#-Y1:[ME0D2@[Q![TA<VZ`GF4N/&@W6Y_[JC
MM+@B<IN=D-:\@J!X5F=RDY@HE;/%BC^&K'GO@+Y>SL5H?L6BWZX4+2LH>:NK
MIRI^A*>`](E164;U9H#7B(0O/P8/Q0RU!!3R]]^-'895#Q?*D1RPX(70O^"]
MB[8U;:TC$\34P=YCJC"E.E=>7751<V/N?O<]_<`S:%BGT@5)81%^I/;Y.@<C
MZR8[!\%$"J>[U)?L;W9,L(J+@UHU'$$KC56TIAFKH?OO^`=YQ'E-"2=)I?6)
MC2M8_A_Z:4IN#)X27V7]7+I+7R'C5*PW5]S98)+;.J5GJ\^R#M&D3%PN0\0&
MU=*&MS-AU%<V5>$)Y'9TGC'`D<5&QV$A$EKDP9U97,+K`F+V.#RJLR-2!M_P
M.+CF$*(9]W?;#]*2"]\B%A7G$@FFV4<$Q-_<I>NZO)T%#CI2?1,7HD_\?V-G
M`G.+OOT[&)\,T]`8E/I-Y.8.WD7,XIB%)O'<G?Z7.EA%4_0U7MK4._N`K2;@
MKL_B01?SV>M\L:I_<^`!<U`#')9DULJ`R7..R#4'Y_Q;RM-8D0<E=4OK6_#!
M.BXOMNJFC:.D_`3-2TR%+UN[G#NXZ05\RTSSB5+X:I/'33K!I<!CU%F#E30^
M"C_'V=HV%X/+?^2IX["YX`V!XIFOGVE>Y0_VE["Q!W]"@<IM\DS=5^:)EP!H
MO9X`SO'55^^`(K^RP.A2J<;TM&O`*:RMBY8U9*60T2:(^KLJ<;O<=.5MUL`V
MR[')7$<173W9CQ).CP/%'K9[E--&&(D_%;8S6RVM0QW+8R$>6-,1:3\')=:M
M?-TTZT<.%BV.B&'5W\CN+.5X6@X7^"CGN?A#_M$ZH7N_3NCZ^30`Q7M.[(N)
M6/\A3K7^_Z;A0U%$ST1?L`9?$KN07WO2!VLZ8[5G<.#IJU:VSUL(!A/;GK[Q
M1"IY-Z`+8HR4(+-]I\"MHL`]W#M8)1?CTB&\7!0"PJ/;A39B48R*H9.JI2_`
MJ%_A\O3+5?C'<Y>B="A/G)Q]1=9.?IR&<:7.UFQRGWGR`NI8IH8:^J!OD?3W
MNRIH&&*/VI-4J[(.A4-MU7&9/X:=?^E>Y),E2%$:O;H/PJ<`43CN!)8OLE4R
MI>Y5K1RDM#XA%_!=4(H`D%WK5F3O9M,*TOLN4=YYVA+6(<%!V(3>0/H>.LE>
MDN:\R'U7#X[K5T4`C1.P!<MCX&;'EJ>C]];J0<$1N*/8\&_\%9$;H+<AO%HC
M[Z)6_WS_X!S6MI(>0^Y?:>\6D!^WJM#L!0LON=)W,ND?H9G^0=NRVB7E@F6R
M?+T(EQ]K?$!2*%L4<"0TV(V9?)6D4$A?'.UVP('Z7H6;>T`OL.A4[5=NU@[)
M7%HHBE)19?M6:^JU56B-7Y,'U<;M".R^9\#8=M00RR^TYE5];9M-`9BH.Z?I
M)\7>DXHF)!["B.D8`XZ=6TIG]<F1S]3NILW0>>#0#-!5#S5""#;^9[N'H876
M"FW?NR&GI(VWRSQ"&C_4Z0Z?U"T"4M/DPL'52V[L@6\_^=]LR>%+2X<(:S@Z
MJPK:-,'),RN;OV/4^\K>+06E:RLG,<[+6B<]26RM&V2[`;!BO5Q8H.Q?MF6J
MO<>/(GD+89L;3T?[,FPB%_B0IHTQMWU>/9L?&&S\,)(B8]08)H[FC+7><X6B
MX[M[:?JKDG^%F45LOL`^J@/-S^'UC6LS,6M(:G:1\G-]^W:A8&DE1A4TX0^J
M))T^U;S(HL-4W.DVJU-RM*BXK329G,^CIW5'56*5ITFUJ<R]*HECZ5IA+D)L
M0[.'EAMX+KYY$(SEP<8=Q(0=Q3F_]8W.PY8:&?>SK(&D>Q>K7^/@!I]ZJ1'[
M$U0"C#)V@$AW(F<.^>+RP^C&X]@WD13$)A@I7:AH$.5YZX?'N=>\;==X$-0F
M#EA72<L>YB*XSK$"VG*B+\R,V0-D.?C$(8C1:&#-ER>BK9XG&]TLCE<=?U'M
M:0Z\8`C*:A8>&QV&YH_BJ+FL`J)T5Z^2?/HEC1$.E0GYK@O<,(.4#<OEO845
M<&1$'$%;*9;_&3QIG[OM2F#UMLMRGDH5TB)*@+81NKY"[CU^A^%IKIWIXWO*
MKAGK=Z0&FU]B/MDD=9:')`<V!`W<7!J+DIOO)Z"6,+RBMAMSE9;TI<P<'DGJ
M:$4P!9^B%_JKH'U@#>\F'`B(9B%&7^OT,9N4WE)N_=03C?Z?YWOP_ZC=KO:P
M=:^)MD49!06HE-HU750].@3^"G\5UUY$(?^L+X%VQ\+7QE+61XZVKC$7#@1N
M/D[1?+?U`<VYGI[1&];0@8[@5+G<X1Y+N)40/(;[P-3O1!>_+%W?O*Z!WM9Q
MKF9B.##(0N(O^&T@A&-_%1HV8`:5;V'A,*]Z:\]G#%O15D.O*0,+:=R7-6'/
MT@601.4.;[>7:E5,S_EY%1]4@%BLG936.(\P[7\D"3+SCF!+$Z_P:"N'.V[-
M'M2`%IOR[BKTQOES9:'7BK8T5$@6/29)^9I$ZB(O(>O7R/")A0C,S!VE#WD*
M(EXLTD2-X:YK^/0T(`>KRZ*Q2(=@FQ4#@3MC!Y34G)@`M<._+C/W(=C5E;03
MXDI%C9#V7E"R7_=STBYYPL<WBTE("PX.EFJ:+N2Q3F-A\[B[ZO8\LD24,,T(
M_^X"-5LHR5M)DX#VK"NK#WL\A<KF8'^&J<D/(89F^6CT&R=RU_ZE+0Z;)!WF
M$.;P&'?(`!N],V"Y0+:8&OI[RS#SJ8V[@$;!)VZ3H&*TQ52+@G0CW"-WY`&G
M>59/>K&,Z65^UD'?R(GUQ,&K'2B8BY.=X?S0V_;4+H6S:M159!X`CO_V<L4K
MF./\07\*45*K"[(G!%Z2)/7G<GYW!]\VOY7+,^XXC!0*TZGZ)0@+:GZ6QK_;
M@E@'K-KEUKSH(/MV9#\<0CWF,SE2C/SA5:N_'#]*A^OCT!=->IX6NTT3+=9W
MU'<$[3`^BC#YXYG\A.A2M_JA@YW_^<#ZQWS4ET9!3)JE:;CU;JEHMU`+7IMT
M_FD+F=T;G\)@.M*_1UT$0"(2@ABF:=WY5=-\GV,QG2U@&EE'Q?")8'B%(`:>
M05'[V(OS.FU-49=V`)(78*DI/NXKD7[4.1:FIUK>DP&^6$U+R*`-#O9'Z8I3
M2\/V\@!<<6%:;\>B.-QYL+",)F1!E5W6:4PG0^X&.D'M5(:`@2YW=3-DR!VG
M+;(9>:ZDO(F?@RH^O4[1*+6)Z^&[1FQUDBOCR`(#TCJ-]&',:).(7?WB;4O%
MI3-CPA#DPB?YRZ,U]NZT=_9%Q;P_\"F(H'VOEH=)GS@AI9<$+L*[2@10>:'N
M@Y6KW:V3H:@W[Q@J:@O,LU9[KPP:RP_80!.2VTWC9]XSPJH\GT&A;H/KDCX.
MDL:I,ON/_LZ[PG":Y&3.UB/AKUFE1D8CA2U(I`X!,`./7]:EKB.^8QS>H%<(
M-O3($"^3\'.U)OWY."/2M?@]2Q829__X!9'3-G@<EV/TFQ%1*SYJNU/HCGBN
M\^]-62TA2DST5(!_)*F>)K`(;<G*?$@U%3Q+?IJ-2,#U:B^MN.[M#X+`"#OO
M#9X;0%\7WDWR)FEW3[0I#K_4F2O3!!">;B'0<R=4VE-$CI900D#O\I(3?%U8
MA>+#,$ZH>Y;5UH]7TVT2@@"/B7A%[:7_IPLXLH5<0S"4,)I*!@4H7CHVZV%&
MXG(N&3QL]_2CMWJ$^`35K=<#U-D?NX+ZD?B.VIV<,$DM%ZQZIPC`D,N\1J,T
MN0921>5"N?Y\Y]V!U(9C_[WIBF_$AR'TH[DTK[:`PH?.66=3H"Z9+/'PD[6I
M>W37,O!AQ6J+#"O8AHPM5>/>_QNYVKV7P+3==DXBT6FDD?A/7,C<QD":G2<+
M#./P#'NK,C'.L*![GQT%RKI=8&T>M&W*,`[,?QX"<L.U#/C6P\>2W=-+YX'N
M>.)=D]N'T,JN1J%TP&(]HR,LP<E+HBX,HNF6Z\\W3G0_I/L^Z/Y\*7AP+#BU
M(-2N6OW%][C/X^:.)SVB!5]UGX0@$C*!5.^'M:R4904RE!7=Q(*"AG[BPA>A
MYD6O=O%'T9KK%WAPC$*Z(L#H^Z="\VLJW9#)/'>#F"T*`K_OAA*YS*<FIM2R
MC'E\\X^3XM?P:$^7V?@L$WD6H@7N,`_\S.P>?Y6SQ*@DMM*N$5=[-S9W4!\7
M$[U>4'W4P^FO!P5!^]2I`^6'A#(JH*VH2;0>27S/EMA#%$J\X2U$AX:Y<1A?
MLMU#^O&+")<X5Y\SP3=W\*D`;+;Y0#+FZ;OQ9G7H.AUAI6YKW5.NYTZ?_G$F
M:RKCWM%'2]EK?`KGQ+7'SH##7'4N5+S$O*%*@GH'1EA''`T-Z63:W0CX*KH/
MY5<>:2W^-'@"OCF;\&;.@*=HSLW>=9(0.+V9;*+&(N+'.;'W?T(MJ3V4R+0G
ML"'N2G(Z-5R<JM`>3HF_ZLHAR2#L,31A[J0+AJ7409GG_\C9!W7D#M>&&RS8
M<,+,OEQ^S'97Y(&"VL=Z$LB3&6`_.4M2MR?-@7BA-1;(%&%FRZPY+AF];C.#
MI>I(VQ-S*#H-\Z"C4ET4V<8*YB.+1_@M#332HAJ(,?=Y3Y?TN`1#<]=:0Y_>
M#MWJ4=W_K6(.B6VJ<`O6$)^A8VKY^*!X6C;$[7D,<Z%D[.[WQ5E.0/40YW2/
MPI51,K@X<GV#@,O<'N9WG@_!J6$J/O.C'3\\&+NQK2:+SWJUDDH-D)@+]/M`
M&G\+>[JG$^0C.]JK"A7'I>K#N&5/-Y=EUHTZ(7(\2[BVC,THVFA7]N6<+".R
MD.3_IW$,F2:(#./RHCORD;Z"5`.@5T#L"YCX>OU:=:B=TD-U'&+Y^L6<C4^B
MMP-(EM$LN_P"3\Y]Y(.1D5VE8^G;?)1D%<"([)";5PQ2IM<CP>L,]ZZ9+[&.
M`[<VAB!D`66798,7VO`I5D!7_N]0/K%C@?*>+$35'-@;4R5FW.@-U=HV$V2E
M`I\$K9L,QS)2B#1PL6?6"=,BE)BPN;L8;)G)QK,A`\C=:MH(SY$)V':[AWD3
M'"6A!HY4(F@KQ#'E>ML57;?<@XJD-.1VAP4=V+CVQQ*[JSU:U[\KL-!+1BI>
MANC)A+N09T*@[4:-F9#@5\U[.M4J<0.X;V&^`$.CT72E-)*JE'>T+6SHN8B*
M_<GOR"D!!3;7\V!T$85/IJ.;<`Y(ABT!*S.T5PMD>5))S0`JVK3"O?E59J`]
MZ2QI89.Y\WY;J$0Q&+XAXF6G0,7^\YUS*;@'+7\%Z\HW)`Y[0HC\P#D[5*@E
M^;\T;YI7R3M7U\4X(,9XI70R0>,VL2$LHJ`"DU_&1F,4)O+M796X^*%B6#@#
M/#(I`\,KJ8HK2QHO#=\`W2B+9:#$IS07B$3S:<#)B7>DAJCQ092@Y$QKH/A3
MW^[CD7.B,5_9"DRB]']/B.AB`,3]-H+2]`9$1C,Z.C*AK[F^P?KAD\?PHRUP
MD&RZBC:XD>?+*JA:KL2<8_L162J">JV3J)NJS!1KFG.SKI>RT&6X.=*.,=K/
M72O%B54'UL"(NKQ3A1:W`E.-[#O4]U:SJ=E*B5L,QX776%]^UD#P=C;75/R,
M+6W0/2NSDI.<=T3EXP0E1BJ3\/I?GK5`J;RMBY?A3#GSUC76ZW/(1.MXLS5H
M9N]M;9"-FR++05,KDR"N)T'3!7_=AC(VDE?28Q%Y;KC)T!FB)Y[\3:/;?<!*
M--VP;:D-$">I!1MA1-&_Z$:>,:%P;B>/JL]T,[`=#*_D3K[9J*$T%"]V"TUC
M[O#_*P#OW?$5$,^@E#O*J.`IG)W_S,6=1<[MTFHP`91"+XRG_MT&HFL?K%GG
MI3IS,*CJPZZ,5*A2\:MW++(:1^)HN-OVCK!=<RD+Z)_6"RW!1`PSL0*JJG;,
M$29I5:3Y=/VC`KT+2=9PC852VC!I.*#!=HF90,B?R[/GC9X"#5RH&+6U']QR
MA'>_?.^`-W(?$%W)*)VQ;&#QO$O0=W=Y*;&4G0M4/HIT%\DYY1N7*PE!4U<Q
M_OT=7B^05BI?7MA9/Y$!Z2.%+SVY!T^G,E_=FU7@+]N'-SOQ6+^MF%7FB("Z
MO1EDQX,EX)73>0V:'F9@G?99N$_+V9?!L@KD+"T-$FY@&]EK[4QG29C]LH%H
M*0A?Z5'P:PUEI\E.IK>_"]^!I#O/-G[*E-.:2E#2X,7S_"S(F:(UCK/:YTJV
M^I&JL/,1A"(#IO)-1QS\ST;`A^^[DEUXY#SURJTBX/W"6BZQ#!_[Y(W1KLIR
M+Z%Q]QQ7[&#\*RR=@:E:%_\D).%<>R5#HPYRAS+:RH\&,;4PEROD&G*_\C>2
M#X,GMK1BRT"=!A$1W\[=$K[RID:1H@$/.I1RC$RWY/,8<>\36BE+7;C=Q)V9
MLX<X#W-+!Z*HAT&OX&%[$;P.*GQP&_.Y10^C(-*3E<!-7A]8N7O,T@[F8<.A
M&]1B*ZQ_,Y+'$X&8C$LXF[X*8_'\(Y-#Y=!6L.06I'P]0X\^!718$@Y@=G$]
MVC$2GD)P[XPRC"[Z6D]O]'D_9]'G?^/I'S0H6`U%=B[:.$Z.XGY<GUX\V3S+
M$T7$KF1C3*%M$]UA>Z&!'LO/&7`O<#%S_V['\I"Y,+!^_AJDWK<VXJ'B+41\
M#<X'UA4F1+=M8"3D`U3V:<8WR$1!U#38A*]W$J73:28J%GAC?G_QBT2$'*IZ
M.;C4DX:3*/#<X)VSMA-<7SN*TOO!/_9@G(^I)_#JTA.C`IE#ZX`E!`5$K45!
M@<(H<P1.E1/5=#K:D"[@4IZ@@PF@5`X'P@G&:'025.CZH%'MEV]Q_<C+6^`%
M+@]Z+#Q5\]MUCZDJ'A;"VZE4P$<6EM!*`5X4`PL(/BG*%XR]-OGF4=`6X%<F
M7B9Y)CF1?)_`^6@ZI!\N>(QVS*4,?^XPT90A-@<KM(0IS@CI2'<HT7!D0O(\
M]W-*(`X'-<(,?XG)U,30^;U9R_RK]S_]PJ\R+3A^+A)6MP+D%`)&!,J!U^%U
MI9&G;SH"&AW3WGE]QNJD_S%$2?R-V)\D8UW:1,,`+PMVK+S&W4N3HPUYFKN<
M<?`&8]+4ZX@-FF:P<AIY<\B]&I\J;M`G-C8IEXT]'%E;:*CE,ZTT`1K4)D.&
M2IL0&!+H;J_L-QVJT_7Q*</]8]<DP_<!C@6VTR$:6JE?LS[?(]"F8N_8S9)T
M:7,'JTMIO*QO%66ENGD#SY.%SZ7WG#IQ[?X&HMHR!C7&Q+(65GO8>Y3W4(GL
M#8'^3@Y=Z+/H#ZQ*$AYGE8>\X^:K4).QV\E>1AJFX#IB?5SI#)1I?*GJ?Q$.
MH&"'A&.U(&Y[UX,83#K&&7X`3E-G`YH?HQ*>D[^20>N`EAM6@EW=(/3:L4ET
MS5!$L\*Q:$8+\V[/0;A04V43;?'[P]5:HLDV_'72.O)'0(=)&#9*,2>$VF!.
M*SJZ!HF'A"HT%5IN1*!SU(/0-X)>EI7\P,\'#%(('UX_(A";S/4CUPPQ%@4/
MQQ1$&#`S"^[+N.PL"@9&GYZR9]7J1,40G;G#J=US]K7WFRNB-<57))IGLN<&
MO4GMA#\(<]\]K"[1?4A?3/&BQ(<#:$M)S:C94S>18.ORXW0=[#BS'#-AC^X-
MD6\4`253O+2[.VXMY:!>4Y=8UUY#$==IG8D[%2A"^Y;0!5#J'^$?4`A$%%$S
M888!^5ZP`Z@':@YU[GGG*P:PGL8B**O\2`9V*NSI'KTD\YN+U8\TDTL=R=9X
MC?1%T3TS]($,]I-O&CN"6G@=QQNPQ#A6"#,<4IH\B.*&K6C(K8CGUBK$KX7P
M$)F03AOL9V'0DL+QMO57PL<U\OYX1@L!Q9AX[G/R+K.T>AC.M&C]VDHA0?J%
M*:H`EFVH!OO>W*01Y,+V\<CM5E$G:SA=1*!$Y[=_`C+38BO;2QCBIFJP`D)2
MTL9?T/_3%K,'D0C!I'H8HXE!6I28(N::%28,Q*^Y+]LG5?&1#36U5$+>DS%%
M?U$-;7:8QYUKE\>4W1**O6YC/TV5`G[.3FET0DZ)BE491G(3_J5]NFJ'*+G@
M5-A=XIVR_?R+Y2NQ9TG0SNRSL(XIZ8$<TXH?)"H:JM9CU(O).6N"M]JOLR7_
MM*J%YJ<!<3_$A]G%F65P[222M7\A:$;C.CI&0Z8Z)2PLW+%*)D^BXK/W<<WB
M-@3VER"\L-H)-7.H1=:P[^L"[9"5X;G/@9D=Z\,L#%ZEC!`A?ZJ/TV:$>V7G
M&G;X`NI$ZMX,[951YH[NLM(+).@CQ42_3E'U$,MJ9CMV\>=J%`IL:I#9)/GW
MN5/H'E_5RSL?DH!=>>==->L58TD/N%-];\BHU[W04[;'Z$.1<(N#X$FU@@:[
MZ52R\ALCNN8LY+_Q5>&/K"M*!.%7OXJ@3NO'*';USL5]M;)Z&;W1$="\U1L[
M\):#SZ?+2!D@7'F6I\K8`>D-3+7$!W^X9_0X><L"M@9).R\($]':IQM6^.3\
MZ;RZGA-0NV=!+/<?\U%?E*9OE=PBR*<+K(YZ#'HBNWG9PEYI[32$MA.:P9<@
M(,ZM,TPR-,71<&Y*A1`-#!1XX?25J[5[HT,`=NML$L+!6%"/`=+;A,U&#E_3
MG;SY#D(@^>\-""%4;@KG3FW/2@?H:Z=X&VE!*6V]%P\(Z?58_IP7.KF<,?O^
MK",EWU+%I,1XMC5G(3*D_)^-_R:`BI=@W37%2]_R"50*\%#ZF]3H",C7CKD8
MM2UC>E'^-MWA/VJ@*[BSR=%\K8$Z4O!E;'/KCS7PAH%*J$9''_0,0B;D)BH+
MYY881Y\*>A"FU-6;^G_+>66V(,6[M8S<Z,11AP]#%//?L-@OBZ0$;^W^LM!.
MC!LS(27R;$E0H+V+0(XJ6@R2MMQ(4'HQ&TG@$9##IZNO0^ET!["DC5'0AS3`
MK6*BOR7BCHF$DPPYS-"MG^\14_B,Q/UE7Q@O0RZ+SVWK,_?D]S(QJDS('/\.
M9H>7WH!%8Q)0F1MM;VCQF;!>PD4`:D3X00/E?KRZOY5(O,[_N;I(7U_%_Y@:
M%_A*"-:?[1-3:-`_RJ!T@2?;<1TX/A$`DYOA;4>LGKR#01IIWF_"^*2#PDV^
M6/V?8DQC[-IIBJ-^`XS$CIY?]`?@S7Q1/7YHY6?/)7H)H*_!G@CX4_MG7S?$
ML3<N^\[H8&"6W")-ZD_<)_V'TZV.26QRJ]24=(BR575)@1;6>K!=*G\R1!%Y
MT).7,!^4I)7A013TQN;.=E1[.W->283ML4%9$L9R"E&\.@94S)LJG>%+/1F#
M2W<?:CDT0>BZOXQNNK';7)7%+?%X;BZ6LI)0?%L/Z+1J=S[R4-#58((@ZI3V
MA?KO$VU"S8%6#+025978B9X1AW@]@<&G\M$#@9=#]HD;T+-TD%F8B<`"2CW+
MMXS-CO'EYB0$P6*&:G,V[H!+"!_C:IS+#MV,5KD?YV'CO7>(81/?1!^40+VN
M-`!A-O&-%T,`P@$<50ZH:U^9%%X,(>*RL[RLHF@^;`LBG!5"$?,ZLE+@0Y;6
MUJ77E;?"T'">JE(G^[<^^YED!S[MT"HEM"4@L*[#(3Q!4!B>)!!"S=!]"(BP
M4D$[MV#9A4@7'_[Z4/N%`U2Z(U0P8E8=D*K\"!@N;(A,C=%YS/!N-6J=*T42
MJ>O$IHHX=DXNV@+Y=7^`_,A69V]I0(7O54C$/%1(,^32B/M$FA'I*0-GV:(<
MV#9HP%1ER_51Z&^L6Q*RN!$?W&=Y_TQ/WB\M,QN?L#5Y':KW=@0\1DT$R9F`
MITO1@3E349EATDU^BV6@%M-Z=0'^>B%.6A[.O'T"?O#\P>:,UA.3KS$'S]O-
MO#!^(=P1N84XW@C/\X>`76^X73W;.,]TSKC!5AF-E3566]5@IE:9-GA(+<1=
M42CD$0X=@S0^9T&(6!KI&GG$`LK&&QV>HO@&S_+.1+UR@]8E!W$E=^>8DI*Y
M_.IUISFU7R:H[&O8O!'`$IU$..TS6.O"@#*R#.`/ZAD`PG,F:\;O-K6Q'Y>W
MOK\&OT$50\][$'-9UG__;U,N.G79=HCL?%8ZT>T.EC&?O>#*T)H]RK7?Q9*9
MM1+D@VVOKWL0]6H-:=T=*GP]'H0MIYL30$MF$6WP42)==_<GUM:LG.CT'6%!
M.D".?E&$-5(_;!>DQ$?H<Q^\)%0VR`(4D"8),(CF/9:3N5\AD=(WY;Y54859
M"K/,JOR*,A2]IT2,LB4P-)V*HDANE63.S9E!EA"2DDB\!ZL?VQD<<0[_F>C"
MSE@?]8]*@Q&+(P'N;S2FS952W*YR<'\\M=Z&'!"H$:XZ:FLZ/AAA-V8B;=-9
M#@$QDI)YOQIR;K#^,,M9AG3"1?R-5829E?*`:!&'JJ:7^7VEUI"5%VV1XP-<
MG%'0_\HJE/.>>;X^FRF!2CE!!8SP+17%@#C,+EJ*$''-]H)14C1MY^DC;S2.
M28GCX4PKJ..OE?@+M!]J;Y0RQJ0S#2E+.P#L7M4NL&?TJ;70.?`#JZ&AF%NF
MA9-1XQ%$-56FC+,O5YW&H)DP7GP]MBK+GOXC!P./YM[T8--(BAER':H2<$!3
ME[2!27!N;SAX:$Q(?B00E81P+R4#_ZR/<<0R8,E.:A\TR4YS9G1)"%`,H!$E
MG`O*TP>)TI]V7F?4)4$69/P;8&6WM$7A?,8<;2]>?]$85P%[7!3[Z_LZU+OC
M3]-DM)W"2V_Q.3EV%DZJ8-QDT^!XV<-#ZO-I!:>KTF&@V:UKQ9>'I5QG`L[:
MZN2+ND;Z0B%:F#1-"(X\\G&$L\^PUK]/](?/WDCD!U`U>"&_<<D]769*4X=`
M&N!>.OFC0M0->Q(>NOWPZ;37+`M3J-T?+`JC1"]!DIEL_M;<>N:%LA6?%<`V
M[*(@M>VRFVA_DU@B<];-]_([.`R!%:Y[L<!8J%E27?G$Y1[D3WJF_%[$6G=%
MH[3F6ODD(B-)7Q-NWM8-PT-+NA=`)&]!20_:&80()@<[!)Y&_\FLV\_3W2E&
MX6O?K-Z:$>#V8/;2'^R*+8'J=0\O14RL+<(`Q%AP,^.(:%T>XG*I!EK_U>/<
M"K-C@>K+^1QK`<+J)C[I[)-ZI8HUZ]V5-8)FIOS"#515JW5U7+8P031;F]#*
M6]I6'.N8I6&WI+3F87ZWC/7/A2"Z@_H^H1?B-A6C[A)1C#@T]Z=W7QM1;5*/
MVJWLHU'#<P)8;Q[.T\A>"%P`R;**UG/J%'@^EQ^98I]+#\0SE4`ZW0(+226)
M58+(3&Q[T`;X\7.\KA1>O^$F((2J!J,8=+*U9<$QK9_:R$AV(GSDCE]RE)LV
MEQU3]B9KDFLLOZ5&70(TA#'>A.IW97/D[#7\D!DZ.(6*O[ON!HYV(:SLUS?N
M0Z6,5--!Z&%.5*P-PL;X+QN-91R;V]QJJ7FI2<@+VR2DF8-G9-LJ?9IR%S62
M'\@DTFU6HU6I.Q;1"E'<!KD5FW-+[3!"#[?PF&-[<Z]4C?Q[+N?"1MS^SB)9
MKEZ2M+,H*[R6%F6>2)#=8ZRH*,(Z1]65;JZ@J1M[/_S)8BS\ELD<*>=71*&#
MZ*U%L-[[9)R:<:;D\9*%5(S7JV.J_#S$2<8JL/.S<#>:8C(YQR"^262VV994
M^KD-*88X$%U-."*:XSJ3K>'@J[K_7`L51Y4!_.0Z.FDHC,+*25<ST4V$=>H,
M\C>,"+1V?0P8IVO6-N[HUI/?EO:DZ7R>(\+1UIWJETM-OP<8%_0L_M"`,)C?
M/9D$SAF%OD]K)?MXX8[Y;]+T-YI.W$*_'5P4*_A&'Z@MYF*]PJM6SK=2F)@H
M^KC-DW<`,`OL?W(GA>*\[7>:GD6H^,80:OO"/A+.0@3;]GCYNK&]RC@XSJ#;
M+(H2>BAR4&7NMP'OQXU<@SV7^4@;)6HDR!7X\[4X0K:U"%$N;MM<)OU?2.J.
M(DR;<<"C"1P3].(12!0+/8'?9.-R.'^K^0!3\PV!WZK#^^B5_1\.Q=+6;FB1
M_0%;=0,<37K96(7`Q1/'L+L1'7$YY$AZ27NT#U+&)[G,.16?M&[PWS(C2.?(
M07'HPVRZR;-<TH>9.@N!>?YL[T,'@"F#6K>;3IC,BN86GND`Z,TZ:38I$#FE
MDQGB(2EWRCBG?3?$+MQ$+;C,-J))>Q[[S+FUA2OA/!PE:9*^.DG>]&G4+97*
M@!HL"GEB]B]K[KI.=W)'CKTOF>RE"3=LT%<)VPKQ1*L66:)N]Z\)9YL$+&ML
M,VEZ6ZY9F\@`=A\V\@C6M;KJJ!I>-ET+?+K4!NB:XE"[']6GW;HY/<XV'OV<
M^V-D?=&?(6U8KN'T>53&IZNZ*D/J^5[>3YAOE.,^KEUPAD?MZ-.?5XRE_#ZN
MT`($AV[+9L&52/B,_^$^``8?_CIJGG#K*1/QQ'<R0>)X!JW\B';S%M3ZN4[3
M!P8BU1L2)*3<U_'A()\:>;:E?<K#:>FMIJTH<J9;BQH;CMU?KIU)Z8FU\@8_
M):WFD(#&\Y?H%@*0GH)9Q13(K5I%I&O.'7*TD73&"Y:]H<R[3T_#S;F>%%X7
MN%DH*G/_UVQB3/R/BPX4DXQ:0BG?8<&VW`[/\K;WJE:;.I];``?]PV)$[AQH
M`G747[QW5[N03R">3L<#WAG\UH8&[H9K<@?U_K,[MB"J=JFC@];NZKCRG2WJ
MR[QY++G)3`*%'4J#"99C[\6Z:4=43@JG4K`E!)+'Z,?U5]JV9E"3FN>K8PG9
MFM;N4P/W?4959S01U2O3D2(F[L&6$4`0S$KLG5W#!YED:TV>!\A-E[K(F7PO
M5!;`B$&G@L,%]*<0C,O"$ZY330TJ1D-:$TT-Y`[D3[\!3S#EVY&N9H7[9RXK
MC%*P&6*]AA7V!Y5$$(XDD8VMXCBRB^]4HX['RVX^"KP0@S*XSD2\2R<VI>9+
M8_6&7>_70T#H$9528*U\FQ!R@.2[KYV/)Z0P3ZF_YS@DBA_0/X1S@T'1*@XT
M-Z14;XP],4G@/9FOB=,G%?<3UNW++V0TJ9<"1MOG3^;_N&+<L0EOJY1-*$^5
M3W#B)'"7#'\4LV]'QYJ-Q-\JH6Q'Y36;5T+P]P60A_P#ZT`>9H\"&)IAHI_+
M2OIC6!($NJQY@Z`=:+J-_4.*$V8R*7TDXSE"$!_PDXW+Q;,0?0MIC+]LH!OF
M$9?5?EF[27@:TC<1*$9I0(=TVN>8(JLEY%G#WF[9QHFO(DV].T8KKQO&4BHA
M'(W+'UC,-PV$K`P%M\(2F7RNIX.7$RP]91SX2O7!:+!R6KV',*";IRN#)E7W
M-^DK0U'+8%HUSM%12CY-NSNC!AOM(9=C74`71A'_-<(!>F4S++O`G44EN;1'
M*PH<'^W\K5NM8"(X%(4TSZ%NCO<7#ABNG*6\7DI$%?]\8LKES\]V(7E[4C!0
M;I)B87I[S!NTN6K=R6`7-8B=,A-QP&1%X0ZH%YW_F'[%BL1&F.CTTC`F6DGM
MP71_Y9`\)Z$7.>HE]_MM:KN\UHLAMF#34S4U">D\TAO64KJ)R9@0T-L[/ZE^
MI&>4L)=<?PR]4R;PGDPD=`@+X7:!>2HU)P6#=M\0@$!R<L60%;GXS[GRB&2E
MW0W/7:E\FA!N'P;%206%"02,;.5[J^N.M)V`*:[EW'D@_5U]-<<]VES.TW_R
MO-J6ZA.B+NETW!2Z5DE9QB#55%`;YE;.%EX@#^[-1;RJ7/W8K5@;\BSQ5>QR
M5$!4WFZ&+9CE$![E6,X%LGORC73+NX9?8O;F2*_C+D,D.>&>34O*V;J:O09_
M_:3:1JV80P[5,:E-7&95GG/T:P67`.U*7*B*O&63\Q1`I&/ZW(Q=5#IIR<H"
M+S?]>%Y3SS9-NI;KH%A/DT[5?2/&]SSCUN95')^_^^K+\#TF2Q<C.;7K7ME[
MF+5(H<S**SPY.`XB\S99:))84CL]3#&YQ_E&L%%@EH<9>[@ITNB]Z,+R+-7>
M;L6W8%VFI%$"/B\>S#,7?V\3<V?,"XED#U!9PU:V>L(UIT*[<PL$$5%R/J(/
M4:`LK1EW;)\J^"%9P4S.#LE@BL6'C?`Y-5:<W0+:CZ4JI<+H"^Y(T);#L_(G
M)"W`^LJY)S@U'>]=?SB-`&-2LB;;>W5;=OP/,+?6\+P4)W^06QL!NHW"^7/]
M`16,J93]?@W:SUGQ0&7]'RH$$1#9V8;WM$</(GQYYCHJ7"!/4C$W8OGJ*=ML
M!,=@[?3UF:!L/YVX!8/M'D$I(:!I"@(A)/;CV7"FHQOGT$9L7_>*!K:DEM8Z
MDM["2'S/5W>XN1A_$OIL\-YY#C?%1_=D)L*=P!$3N^8(-?*<NAQ9VK]=Z]M%
MUOJT<2#G:^L!H+3WWN@9JGLV_]W;+0.1S]OVL;/XPSAPH`S"&DH^HR,9:T6Y
M:O"L+\F]>RF,`/[46037ZZF_M(ZR#K!A$#,6A#/0E3.'-9JR\5M:@Q6DJKE`
M[:EX%;>^)>OTEFV$N[SS!#*XF/E1L0#O0<;Z%^5UHM+D(\\VM4"KMU^L2QUK
MT/O?.IC/?\JUI]&V3)9\D<TS:='=:M^>KPQ4`.]?H&J:E?^ZA";_*`["0P78
MS>4":@]D.@7STY9QZM(Y#0A7-U=$*XM7<_#*_&"`(_=L8C56*Z[Z#S9DE.")
M/^A2RDFO9MO($F]\[#/L4SIA,:[IXP]4,SGT=]R\W-#!-4K22JVSJ,!KW@54
MB3^8N:#:'-KB@Y@4>,\=S*V0Z`[#]C+]\`9*O"6>K+RO@%9L&]ST==>UNPKT
M%_9B(ZQ]XHG@[$*I]S!R2+/QC2.B,;?9/P/P62U])+26YNJ=23LM?`]1)F-B
M]V3&\N_`B,_8#J6K2?/W&::F"XD5$&J[@N(R>Z8WBX;5S<8HOPR6%=Q<2K!<
M_YN"TB\ROX7=PGHV?+M-H&&!`:T>`PQH^8C'\.F587<GZ4BBM.DPO,M6`9C.
MJEY\FW^63.6>-(0$%+3+SBGATWCO'9^D/7I8-%\5#L*MCI<ABT6S>BP,C[CI
M.D\M3H7`^I"B,-`._B-81)]W%<'('9!"@"3GK'XS]TUN%<UF7?ED+`&L-1UX
M9`]`T1!VVP0(YXS'F?.D6F.4*#+Y:O_"2(![G6\\.^G(B$(I:2IXTA4"63)'
M;NTQ?1@?PNTY'%C+CV](>P]#`*,C4X*AS8H3M<FW]Z[?T7E8V;J!:;06.ND/
M(IZEKN=._R:C\>*?3I<4+>G;8!R0B!41U)D=4V]XAV9D_T5XYE<HZE*9&_5Y
M%D_P?\$YX=<H7`%Z7<7N87+V*3S9:K$Y*1IS`2#JQH9<;5`=WH-W+W]DA7N$
M1(<Q67J8`_J`<O<"BD1]7]7M+U;O'/-$9]IZ-J[[R#FKS@X%&YJH-K1^R$W#
MSM`C^[TJ;]J23U83+,,)?+)4`Y32;25D].E9AG3^NS*CU5WA<Y`!GI+ITG9R
M'ALI_:&9"QMF_?:E92QY5Y)4W?,'O@,`%S<Z.CGBXSVZ@<YMC"#@\ER]Y$M4
ME)F\L):$$/=PW=#4+:[\"HKQR!%Z(168Z0-6;ST-M1P>.OA9MMLY11>/=*.'
MNCYZ^/YI_^YHX2*,1QBE)68W`H["71=0KI/49HP1$COD$^D?!8FJ:-B54@ZA
M-^_I">.Z/;V+73MM;R[.FU>S3P$)^MG\S:*>2=1\]9:<Q14Y9Z5=AV0D7!S7
M^CCC6V6,=[LU_&_]0S2`W#8N.E8DQ;-FO^>O*!CU?7(:9]DI6*)ZX!K8XC[Z
M"FV"^Y?FSM@+YU&H@A=I4+\D!*E8+%C%U'E5&0<,,[0_#)A&XS#3E\VNVY4B
MX6]?`Q?P#R$$D26SC5'(_D@C$NG"]E,HDK#Y(*K[A.:4]KZ;>^VS@_//;F5D
M!=A]YRKX^!H=@O3F^,9B7A/;M+FXI>MR]',,HW?>9]#9A$:8@*._5F1LHE'8
MF5&*3Q1KXQL@HARW%),Q18`4"QP15"?4-RG.=-!&=.R(W5"".-0C^(O?&KAZ
M1#B([+B'=:U2KKL_?-<B8;K;8<(CQRF,D8$GZ#CW))<5M0)Y+?NG1X_NY,)&
ME&5<&+!1@BAG."[L"9,;JD8^SM^I&<N/D7L2BU(:V/P'V]T)F,A._&(MD#J;
M`/%8,:VW1)'3AMI*6^=+Y^9,@I'18@Q>L9<,K8S+UI5S[I'#J%@E?^@_T.(;
M#<UDTX_YJ,Y+SR@>_Q137JB#%&:1=#UF*:$S1E#OLT_@+1]`$+BKC7J-C^73
M0>]T<5L!6ER?T]A[FT23T4)!_!'%N@PMR*LK]#_OK$ES?B4=_&=[\7"U`2AS
M0<DKM`@V8)XFF6=Z=HEV0FXK+2S#"RNA_>Y]#V(?@949B[)I*KVG&M=PLJ2-
MG$_O^]9T$S7LK%*3DVW`OQ4XK?,R.?J^:.%ISYQD]&>NIBYVFV#F8?;'O3!T
MH:"*567+%L,H0-2^ZTL';;N-'W.O9L4OM(QA60<T@T_>^`!?BU&&M2'S'^#K
MUV/_%M`VFH2^<MN.W9K`UN?0/7F*H6!!EB#)R]KQ&C:(8P]8&=&`D9U6_UY:
M+`U!1.`IXQ)[JFE[;-W-+Y<%]Q5S<Q2)7/+,6!H>6&H29<'GS]!?__3/%`+J
M\NA!9'G%^5(:.;+<(Z"6T5NCYT,8B<$?%^%G]1FO)J.THC)2*(BXQ:-5NS7^
MR5_IAK_,/=,:0N-Z73P"*6H;)]3SO()^0K_I->XCW"K@[7AHELR[T=N;3V8*
MV4<'[JD!ZI4T.H6QL?QAR55Y<IR%)N;A@-8R4+SI626#7^#^96G4\D'U'.K?
M/,XRKG!4;A$Z[HC"]2_R#5&UIZC./P38K[G1./8;W8,2K:7QE#FOB2HWL9V:
M,5\`W,0M[]^2(RX_8)[O#:8#!\<I*%;\%-;@Q&J`TM-MO2"!1",Q9)USR.AR
MZ..:[G[L,5R==[Y\S./%B9PW5[4D^]>=YG@Q/)-\?8TZ/XWJM(,9*!6Q=]LT
MK$TK1?CS&K=%KWIQ<%E!2[L*OX7RT#T2.Y$Z$?1:)T',0?;,&>P;G0N.0AW,
M%;[\*"5F2[+V(FA01U<OW9S`WT($KZ*(W.KJ5K=%*0+@]UNDD![^\]>@?8MT
M?3@_'%T04G.(5$X(P:^,]['P?]'^J4);(6@8%`RJA+_8UY:[XD;7-33R_BGU
M45IP/94XS!'!4!9E.R;R<!@G]<WPO#\GWQ1''HP1^&1>`Y9@)RVJQ"Z%Z/BM
M!3"9@,[!?\R$Q\Y9^WA4B0]BJO035-F9\)/95Q2Q)`#O_+0!50^AS%RL9C5H
M]#D6,M.>S]YU7N=N4W$54#P<)V,#95D#9*N2H?@1H?N46^5DP'*]U)!#T+]!
M3$?M'0A=,CHC"FF%DW@B9<2EE,[*V)U;HD*Q,;\N`T3"1G;E9(#'+':@^VY_
MF#6]E+D=/!JR=<2>]<?%V&H"9/%^?1/ZT,^1EHO6F.JA5X0I3XQ/A^QY/)@`
ME8K!-QF/*QBE>K25J@TM4?[=P^T&4SX'(%EL"F-)'CLJ?3]#'JV3EGX)MKY*
MD<?_&\>M/QAPF1@B0^2?1%%^3WJ`[43M#/9(QO<L#9/3RY`E<_SBB__KX=]Y
M9D(1V2`<9PUS`!:?R4&2=S@2*Q+YUA'!'>S*"/J+`ER:]WC1<4$>Q]3MQTKH
M:'RR,#"J6@\[[WK;0E3?G7H^-\Q^FU?:9]4.AQW)TJ#1()/BW.O?WV:8'@QO
MQX'U!4JI\W#47NI(LH67E<KCS1X1?Y+5X?FKI;"/WP[&O0W"8BR?0R7N)21W
MD$X5H/N;<DW"&LTT<7YE*#=\/T_,=JL"H-<UN?4`NVG8S*6FRCY7C'`B\#Y/
M!KHJ%/.H)[:/-*)Y]?SOI2+=CKW,UZ\KOP!OB!R99-(.L:/_\QR?)R,P4]ET
ML5&[W::JW[E<EH%^L<M55YDQSB#+6FWAO4X)3EAJH>@@U3RV$\B<HLJ6Y\DL
MH-[Z1$;^<\=`="?*'+%S7<_\KX;D[4/SD#FPS,.1(`1Y3V/`T.=371H+_48X
M^R<L:51^\KO(4^OF>J7Z</"-_#/ZP'GF^,^O;-NX2T-H&4<B$E^,AM2%[++I
MGNE_3WP!WE/XSC>H52S40IPR6OPP119?>33<:TOTBL0PT`JDHFD5H>43^F.A
MJJ8H3O,YDT:K%=;OJ"5)C6N:W['JFN?.?YE=`%V/D%]*ZLAF(A%P3V,&;+6Q
M([:C$FT6/;R[^=BP('>1&H/='(#*E?I5DI1,?I#%ZBXQMLO6.D/>/'H35N`X
M!$C90:A")0S)DV\(1LCT0<+H7LN_4R\5SG&^G8:OG1%DYKD&M`(W"MO<Y?`-
M=XT-JUT)-D88=GKM*W1-$R`P$D8],3VRT\T?P(&^<__^XV/6[Q>.JO?+G3@*
MT4EKY4[B2[._M<6>W>]2(OEG(-*9K]<?-J)&R_8CHDA84R2O<6H,\Y6_<V::
M]TGBHMD'M+AS#JUE*S.-O*ZPX\1*CY#9%,K0S'K[O<W/>)#R9N.>G33K?,VW
M16GA!K)'4/#@CIJ6.5LUSS-PH;3V5//`"D"^6MP-/\@Q%=!8W*T@,L?BOETP
MN?P"W>.<F<BR@6;+N@ZSX>G5UO=H$WO"-ZP=7<=*8_>;1.;/L-%,BK5[J1D_
M0[3;H^UVKOEJ`KK7CL(+7\[$$")E9(HS97\Q=!T<F3Y?$6+G@J#[]_5+#>X9
M4P?JMX_Z#4_5YOB#Y\]R#Y9M.`LHQ'L;\ZW$.CZZ'WC'$*GJ(:*.M'WA(\5+
MDF9?>T:\YDH66*7,9HV=POYR&/VZCDN'X#XK_Y/#O.:>\[^,^8VDS]$[[(_L
M5>_^_HT)O?Z8KJ:[0;35WAVCCS#R</HMSG+N,U;YW_W2^QF(H9S9'9NB:@R=
M!7VW@K'!1)=,.BK!PI=!2-4/<RY*N'BP\U).+!XS1@9`K6S-["%RF+4[_9MZ
MD-;FQM9H\7!>)49RFW\Q.5<`*P':4.*HQ1D<?$"SMFBU$52&04*7L_IX3]JJ
MPNWQ=T4MZ+N7'DP]IAU'\IYF:@AA:P5TCK#`X"!X+""<)>380,=^ZR1I_&:]
M#:+R=A-B:MOFD#L90I];U7[%\Q\CVW`*3-\$M_T.2`R@JN^LT`J#3F$9PZE#
MR<'_DLF8K;$(7*':NV##`UMH2JKPAL%L-4VYZ>VU5C3#T7@-@Y3)!OZHHY!X
M3:/]A78YMD:F`=E)=6IWABX:D)*WY>5(]&[>)9T2D(N`S=T9*"'3,LN5T`HX
MYVA8LW)F"W&>17.:0U&@OIA#T_&7K!]A,0UCZ=T4(G2N@]YH'!EX%WGMVUQ?
MXE(7%V[JX07Z?P3&@6338:]AX#?,YQ""0#I#U*5B5B=67+3)?):)QGXB+!1B
MAKO]^E:]S@]9EWD1/",=%^^ZNQ"L?C%`AI8YI7_6"-^QBS`;?E;BLU!R<-17
M)T/;_[V:QHTAL;B!0")$'%MSA5$)RKJ\O*.;A\G3LB_*(AT"S?WK&7U*T65#
M+&/NU^S]J@K"MH)I-$KKHE(R,/U0=AS@:8,KG`FU,W-!HKM7&Z*KF3^@969O
M^"T9+AUTQ%8BDS$Y!X6_>IMFS2V)9>)*1PV>VKKCU=A]5VA:1'2L<U^JZ[D3
M),R+L"&<3HTLSCB!)OQ,:8GA"A301;9M*B0`18SDAWUU*L;[%;I2^ZLT)*9N
M(TAO&L)Z3WQ@Q/73MD6Z0::K+92M36E`79NQ[-&FC4KAI-PNK]YQKS]3M%\W
M?RK59-#:(_2Q.;A2U<*UQP^__/Y71LS6SN^AA5>@8AE0Q2_]7(@DAX&H`SX(
MF3#+S\R(W5R_;SV]5K%+R:UH<`]*@$P?>F0#H1IARH&O8^!I#^33/I.0+A=U
M+-U*0:0UX>#;?\<4M5H'BA<7&&$;&@4(ML3\1B_YZE8#;C;4;$`PFE`&LRY4
MHWWSQ%#,F*KX7S6!B2>H2C/GR--3B-^0N0L#S$YU2TE_\\3])"46WX6-(.$4
M>B<;URXRU=JJJN1FOHIL2&&-H@5DI%'D+!KQD8Y.M4N^O<.<)5BRPTR'U$JE
M*$E?U-^&S/W^B0,(*!OW,15?]V7P8Z1U^BW;%XLE>F"6=5B'Y1+7'*U/D%)]
MG/1#+TDR(]_"WAO<.9VR?(8-K#<E9W0]7IAGMG$H-^(P`+4L-_JL92A[;!Z/
M1?7U&4V4L*06712$UIG3@[DX<3"K>R`N#A-\MK4:&-ZD<51'X'[@\HC2Z42O
M=01;K`/J,U&VR+]F&N8B\J<N":QXUV@B,Z=2T,?%%R*56%(\#>Q.A+R@=':Q
MDN!NM=@=0B%1Y#:;;BXSN@'3TT90ZDZSNV6=)*-XRH0\DL#F^`N:,&JC:4TF
M:=/UXQY-=!<]SI1Y^Q!P\6'#CBI`H,@(?%A&R!YS]2@_/6EFT!',*H(BHM(_
MTJH#:R`GEV1`3."9('6FA;TRMWMFC@Y@)L^23(?T=*LU/'K!TNTEG++KF*1-
MM`5LKNR_7*6FX$6@0N=4>Z#FQUXSH!19U(*A3S'$(N+[6:#Y6WX<UD6CJR/&
M'>A\1P.]JW"N6%&&K%\FQ1]YR<J'.>)\]O'NCC,N5Z?[],C[*W.L(QZ$]-5>
M&$^?6<*J#4_GX?LZ77^<`$U&F6@S0G-&&KSOU0`)=V0%&2I]%2IXGJ.Q`]?(
MFC,7#`1M1H1?2J(B?Y-%C:/EYOK@FW@HS.R@AX*JAW1BQ)LBE;6=\/E-L$*>
M#N$M7QP73R/PYXY71;-JJ&<(SKGBZ;CI,$&O]N=IV,_*W6ZLH)3Y`"68DO87
M0=E'JXD"$<825&/C6*2P3C;G)/B1RQ6RO;G;M27H/,Z+JVL]%D8XP4O=T%YL
M\%M>B]N-DVQLL?D9DT3=D[XS0=+92)LSFN5'$"X3?.;VCXJ]/@@#58MH+"#'
MXR`)4V2H,J>6V)KU>HV5&/<_'ND]@HA:''*YZWZ<V!9);`LM>^JG*XJWOP@$
MQM>B;R/KPMWO@3-6MLJ12?C([.HRX9-V,@">,KA7MM&0[&W76-7)5%7'.3/P
MFWSZSFY`AE)DC9@-=)G$2A(2!&Q+V=NH21NNF*P0\5V.BB$I1E%P63[*[V&^
M?SE"?W?[&:\B/W^/N]'4M1&.K?PP>PP>Y*%F[LZN#NZ9TNW>&@SAVI@T0OUY
M7U'=B[V^7;R"V?AE/?-$M.5`^=![][/(308W//+]0OE>#BGHEQFA[R$*'R_,
M^Y$`[/2Z8CE6S@P!Y:HG3PUDJTD2SS0O+52W\%.3FNF)EBZHU63>9:4_!KCA
MVD_A(;[J7(U!D!OH%QTV4XPSET?4X#'<>AAY'V&F_=$1:ZP$Z#)L^KL[;2/+
M4@?"\K%!4BPS+G*+GB?SRSX:<^2+<Y-ZZA[#VN&K?KI<&&!T@GX&0]F99<G.
M87?^W_E.X($K]XYI0<Q_Z)MJLUB+P\8"[S$/M+/J!%-G<13\\;`')VN^VY7&
M.S8+,SKK"3/RUI7'NDQH@0KGYJI0BL>Z\"?VSJJ<I)G1*\RJC2KL(DP9AS'1
MNA[_Z,8A+G`)ZC=U_@JN]JNAU@?7UGZ<@+H7"$9@H:[EB:Z!U>]QD^@9LD/&
M<-V>O#0JAGL2'=T!;D?_P`A=:8W^@>(<Z^D;1X#8X\AO1+"&#V\QQ!-'3W2=
MJX7Q[D2+&(71U(^J;Z3%?T"TZ4#(+TRS>IK;$NPZ[2KP-"D/GB5LIDC@\"BP
ML2O,*@:PYO*%'BUE[IJS8?7CE,LCEQ=;P+X.%':C[";>TT=_O^[,SA.G5;4-
MD/B+K40[^<G/KS<X"+WR#%0>6T[XEOKQ@WGF$T-0.A/!L;2O6',$U%-FL6#W
M3Z-#UTT-K-^+5X9?OU:?A1AIB8Z![+GQ`>IWT.1MI)38J=0$=:U+_-'!V1K4
M=GFK&38^\F+E,*H@C^`[O%6/N5C7ETR!QJV&&`T*P[_9%]E2VQM8IRY!<Y`G
M181K-`G8EGXA<UF593!!+<U&?N7)"+(E@DW<,%P3GAUIP\S-.9V/RXQTN-]!
M6Q;CNZZE%I<6BT98U9BR3N@2!RUWW$F=,&EU9RZ`_KT)NUI=L>Z*`0]F^K7*
MF4L5WN<P/JE!4-T12O<?YK`8PK+L1DSY1=<8N[BP[KA$H6WCUC_`N*X*?L%T
M=XGA51[^-(9/.HIF2"B**_)0;.QZ.*]3K#)6*O9N8,6&;6!7&3.LV,WEBY-:
MAM:^9-HRD]F>@*XBO2]]Q3\5W/M??(T2]+DU[M&.$!@LB;RQGP0ZW^/L<6S8
M7##_1SCBY:*<DT1M2(E.<2@PS7WF":KOS./TW+)H7?:R<5VFX1RBX46_%85R
MW-06IT]=Z(\\5@4Z4KH81''8O!77,MY$(B>%K\DEVY/'[R2E\0EN^1M]L';P
M0J2HVZS*Y3%$I/H)7O<:6+,7UAP1^8E.*RJ(44<^+TM&:8[`(X!\?`+'8$=;
M-R;,?(=<IE[/J(7!YA9T0!H0K"`A0T7602]&S/!P=Z&;D)ZSSRM5`/LV,-63
M</S//`$[1IR#!!;<ZB)O<T%5:"W(:V\]^-KG]@:#M83T86I%)^QK36A3Y\>O
M`(X59ESW3!"9%V_T;9.^FH5D;"E[FJEF_B>^\$0/ODK?'#N13`<<!<*KH]+S
M:.E^^.78X=MQR%PT\>K[BMUO116.WFC%*<9X/L"&5AD,G]JVY@[9GK04OD[^
M+M'JJF!!<T)<+]8?YNNQ-=%"B54C,IB,(//%JK'SZ!>3X0P;L1YU7X3)[J&2
M6?YXPVMG!4,0/7%SUE@(7_4>'&,$<2)+8P!9WVG-20FEH(_-;IVD\FRNCA=<
MC_![6JW(6HKN9=3@L%4%T'!9*F$4:FY8FS^P6X1PV1C9EB`8^GZ9^4&O@I4G
M3PTL[2$?M_2$:A>BY^(*I,.6YE4*Y=]WTFQ4!,'`7BC"*^#(D,#63Q"3/1%U
M8I9H#!\P:N].$D`%)%[S;:8:6E4@U<RBF%?SD(4+I'(7QJCQN`_.K$(:CT'/
M>!729AFO</E31_96X-37KK5(>TN8:*VI#S.R'!R^C9G6Y[Z,>0_3<+]RX<A'
MZ",H&!ULO1?_GBZG!J&IZ?[OA^^(PCMQ5:5MXU$YL:4$Z)F5_0R[F#0;H8`6
MX!C3,]1[C>C>4I6M:/7#-CJ5ZOG9JI<"ZZWF&#I1'GWS.K3/Z*2+!WG0L,@6
MCE`1)Q&.XD$$_R%G,H)9;.SCRQ75MJ?@BS54:R=1R=KOH_I3V,^AY4577W,S
M^ONC>!G0?^/CO1S/:KPB'<H,*:`[I"DS'M]29]->T%3&?31#Q'U^FW?7=#IB
M*PP`"V=(:K^)_I,+]FIL^(K)TN7E,=SPN0HX>E7;^+1WG47E<M$NA;8VTC.L
M%"6<7H6_Y93>0&;/&+L"M!RY$(`[?)?F@8")^/D-#'H,K9[ASY@9EZY>;DW7
M5(>G2W-,>_O8^B!AQDYCY(?\SS?0F#V/Y:5B`U2R.2ECIFI5(;>+\HYE(L91
MXHG.LG0^G6K-_XUSP%'J%_T-8:PYG-54-N(1M1T8L<7^>Z*@WJ#.$$I+%Y^R
M+HI]`0J>5?.&/T0%'_3V)HD&9X'6-=]EG`5@&&+<W0[;8VXG`*G47L1ZJ/-@
M!53ZH7D1"*R1>%2C0MZ7<XIQSX;7<'W"(_;X7EL6GTC'G5,XWWXBJKNE<JY)
M(KY*T1:9+))NV?O0?5O@0HP_9IW0=_#O**O\[((\DT]U%8MOD-8M-2/I3,5"
MF,W&2\AN1SR!<=M+?S3RZ0?043U[XP6JNTZZ[;#Z,[GWHE#3)5REAT8:07,M
MJQ)%DFV>2W1NW,QAWV5NB)NW3F'Q=;J.?S;8Z6<&N.0=>;T^(NU;G.EYXZ+<
M8N-#RWTL"#WKO`=>=YLZQ&UD;\9XSW^(,V208BY5J=2>-:"^*`_!M457CE\3
M/1[<41V\QH9C)7QD_WQ+SV0ER8_E70_JW;4L44NS4)BU9E!*-:'V]#3Y@4)3
MWCNNNTR21Z>QG4`_0G.DB\(RN?.;M3N2OE(MT@,3_/[5H-UW"4/'7/SQG5)\
MCLC\8QHELO7@QD>VAGC>U3YK0K=),>G?5>MLN92L.I%",:R82*J#OJ1PU"4E
M%H%FX=:]2<)P0F^E[0K'M,(^0"@K<1"UG<6#$1<HVC:3>&&/:-#[91?E\LVP
MTEHS>8LJK_>-./$HCW5O#_G)8*/RN/T#70CY"G+2->:EZ2Z+!GYD:)8_\''!
MDD?[@)S<G1I),)#F7_7TS:=^KJ5WC?PM$\<)6;-^:\F?*/-G+(.Y)M3$$83S
M*E_Q&MR)E(U%1>48X@K8E%<\Q8>;(FLLT%L$7&L:X*!>RL.XI]^FL^W?6F>N
M(Y#VC%<MCQ`:,2828[\Q1$$/+GX=]8]/<&K4CJX67IO"HT1TM7RP1F&*I0K>
M;(@J^9[K"6'1VQNYA@*TRFUD1GS^3A>2G/^+A%:]$NC,.*-K@2W](1FQ//&V
M5R/X4/R7(S*I9_-WS,/N?#&PM*DA&`/F(LUK(#OE$#OO1=4(A`=BF>)]&B$\
M!9*MBGIET+@\`9W&6IIL,4#],9JT]#!`9IB=[(),5/1%MAPPT6@(PAD;("7-
M0F?,LZO.?P@LLXX-9@1DXK'MJ>QZ/,:/$\Z/46=,O#'/BT:4#T6VQLA3%>^9
M&-J^Y+T+`G!-/KNO%$05S,94?1D&&/@)I9VG]-G2)EP6?$)Q),@Y?HRH;J4`
MB%%#K%2=EN\,F`&!$"2+LU&+W+'LUJIP+3N7MTA$H<7NJE3Y>.(#6X=J+M7M
M(0OK'O4<@_':!`B1;77"EP^,'4ZQT7G^6Q":BYI8SI-Z=[\TB02NBVM&"0.R
MW^.P+06]:D"7F/D:RW1&;C[`'34KSJWK:RVCK%P+80^`@)JG6=.AY)J6Z)B4
MRC[/WI)_DZ";JID_T2&_S)7.7O*U;';IEB+IWNX"8')'_\N/E-Y[L":N[KE+
MEH1)-DHFV&ZZFGR$44]EF3Y2?\4"IUD`(KN#8KB0^,\+`USP?M,3)JV"D+0U
M,HVTQCH9E2]S#>6<CLZH[/>#*]P>CP*^'"@F:U()E!ZTA(PI`,`5'\N>`:`=
ML*J'A;WW_V6UJ;@GR&.W/L-B8D)>58-AF@HP0N8^J.Y__U'N:>EA57;&X(2'
M`41^4T)LM81%=ELKM&%\7KY$=YO,)MT5I20S'TUCM7*]<P39^VL,^4Z>1F&V
M;\B@M;/:^[-6UIS$`F;!+_!OWX_R2=9D$T!QY[\O[4VX`+9E4@/95#AD?'W%
M(%7E>)J-Z@SC1)2[R>E5ARA*Z*1#V5#;,7ZO9R?]:VOI3-5,`NE.^((G9JZ@
MZJV.86<IYM*NA0ZZQH-P#9V7'BY-M3.!]!?B=(Z8O:A;-S07IC@'^DA'?AK"
MB8M<:-<$F@G%G,>8U*EB6$P/_*WB/))-*4@FU-7?N8X*XX"Y-E83+1'\6!X9
M&#&]3-RKA77:1NE9TE5GTT$$7:0Z/MH'-MW$[2M#":9TT$ZG7B*FEBBI2UE;
MV<A9R/#H^;M(=/)KY1S%\42_.S!A-)P?<2,:OS3^60`LH-2'T].Q)\%5:^[E
MK^%#3RR8L%7MC>+&?+]K00OBN0@KAF^TSA>@@08(NI,^XO0#:A7\C97(E-]A
M+V^232HC\L$&O,#RTPU&*9=/F&Q0S,&IR:+FS)E/4=^"DY#R;P%[UZ<L)8&;
MO:GZ6(QC(.S_@IS<6!-:"4FHRF$*3/_%#"W5KY/@*T*=.V.M3J,<<YI#,J,W
MJ]$76\[`RP7G9W_C4]>((A!WR?";,J+$"9JK+.WTOA<'D\X5+6$^E_[AU)J"
MFP$+Y(^F4")G=#:+5"?!RW+!A.[-R)8!A(K[*EPJ9!:8-`S=P\^*0')-=?!]
MK?W,2,]_6F\/\B@K1K6ZD*]NUAQ"Q1#R&9X8G4/-*+91FNQE2EP#BKD;0\][
MI![X?Q`_N'YZ(,,"HR\4X&$)&,QVA>>-'FQ3(1@=I6O[GPI#.&@$T-D!1DJ^
MM9^E*RYW^:]F:H]F0:=A')L#DJ7>W_0STT\`G%Z+A.':H4RY&_"U2^I1S>NU
M.@^D#Z=<WG)[FLQ)&Y77856KVY87I-H#NPC#T%:XV4_E'>LYU6Q,VG\#8H(Q
MKJ&.5@(&ONMQ=I-8!T+;G?GJ`*7\*XQP9DI'O'.\DM",Z_OSTCKV_9[J"0DL
M(6U]^=4CY96LD$GCSY%5P%3_23-?XL6%*24*FS%E3\=^``P'3&FK3:],(J-0
M;*4Q,QP'H(O772WV(<I+)`@"]B(^\S90E4@=KXXUV48:5B%@"@YQ4!J$Z^IW
M1OIH?+5NL5@MB#LKO`/V5?F(=G-,Y`^H32JV,I:J52?(>OH['@:6DI!VE3__
MI9X2R!^1S?-VO5@IIV:N,^^=5)Z*&F_:K)_`1[\<833!22[UH7FI)]J2.4&"
M#ZFA?'[%1TX]RILP3`@NE;+;T#\>.=0T7\WN0PC3!>;NK;CBLTYT,(8[ZJZZ
MRMMYP!P^O/;+^-TA^3-4CG?]JS(1LGNG>5L#$6DMTPOSPS\FS+_VJ)A579;L
M'9M-+<)":4KDW'S>@5V4\\2_O^OL2<%YB>]YXIJ?(#[;.Y698+7+]B'1:!XN
MQ=[?]?AYKZI@JAC._X*ZQ.7#F4-S?_/'=UQ9^-X:!V0@8,K%7&<M_!&<U6S1
M!8S>/=>7(JM04=$>=!A1?'?@*0=-SAW@G-WLT`IUB02N2Y^-)F9&U.C9Z6VK
MV)P'9_>1VYS?"B+&@MMZ1KR[;Y-X(2%7MA@[VR`?L,27:!(`(.G$$E0)0TKW
MC>X,_NP7:RR#+SE&0:_N/E86&;K+_?#%/IQED&$??1%[&^4OH'?Q-VW2L!%*
M>D33QK`RG^38`_W-S(8"O(6]F'_3`'S&6B%?KA)>??T<K@"*7>=Y&"_XU8S2
M_E_][(=%-_B"4(AWC]926,]B_;=1J!%E642;!F*33/76G445Z7DUB&2#R'FI
MA)YD^>/E+ZWR>*V1;MN9IO`HE^I,XTEL_S->(OL)I`Q]6CP;YE_PU39H.O4U
MJU$N]U;5$HX$I?;R+8:S7([NIQVFV1+0?;@=#`!%UY=5;AF"$L1S287#CN3P
M:!CH4@_U&N]OP:;,^0I&[Y^PT_CS8J7$L2*&'8/!<R%/MG$C#B%SLVO,PGK^
M]'.DH6,YNY4-!G_%6FL<V4/.C*6\?5;0N?J+PU%M<T1;!I+#S`TW<5=F8*:?
MD(\X!$Y2/C"<3J,&FWV;^Q@@)"QU4JQ:0=R80$51$BX8?`T4EM%H+V%DE!I@
M%O</DWQZ)6(DN^WYM/<>51(\O;1^<#44-2'IFC8W`JZ,YVA[5\:8=C;Q,2XF
M8J'$)N]K6L1F+$+W4:3"8:7,N/31)GVRAX7N5_3T(3%GO`#A;3W\`4W5"%T+
M-PCS!)*256P*&2X_$B`<Y>,OR>]Q&)&\[Z\Q\DA<]=GDGCZ$++7M*8R-Q"*]
M/W^B\N2[ZPH2(>-;@<,33IH&5VL>HV1J7J?H0;56UH?`!:7DI%_H#=65Z5I*
M+HVXL=M3"%`[R\RIV::T$LM-Y?7,YZ4&V68VK@L`&1;M+X2]Y5@Z3Y!]4HM1
M<"M.?8`7@FU8\LY]RQVIZ-884_]M2<-'.*N3FPM$R#[`U?WD*X],U*>8AC)+
MV:/0DO"A<HT3^[\3]L6M]R$7=#9*\^UOCSWI'I^4]BH?[#@]E^:0\'=L7\0(
M831VH69&%/>;W2N']?<`9D#^FG#0D`M_\,^='/=^S-V!G'L9:`X&E2C9RM-.
MR3C\[.0D=X92'V)5/X'%E%MKSF(R_A@U32[6NT#8@`4AE%1OHBPQB7T%C%_2
ME>UJ_JF%[@=E]@S.?NM.4Q6OC_7$'0*7G0`G.4)PJ<W2T<YA:ULAA))!H&KB
M-/:T;O!@^HSVQ4ZKCF\)3AJ[D;RM$RP0L7.%!T!NL@=42A%7U5FY@USS;EBL
MIO%^2LO'J5[4=3X<O3ZTJ3&V\X=-8_OAYBMF_%/"THL1\V[/.X!1=B<7U<&O
M2BDBE;::,)BP3H',U-/AS]ML,C586#ML-@56O/IWR1VIG5GD!`AZ^S!B,-D*
M/>I_LT*TSOLA9`C9LE&11'</F3EG,D7<,>/:Z@`@,4M`5>&P37"WG,T<D+!.
M,9)8.YU5R#@U7^R8DXG7L^-/EH40+CB[W3;U`%7<\'*I\+M^8/1H]@]&<0D]
MTL8F>A:2V>.L((VEW3C^\$EBY#43Q!:<';"-%<$WP'WH[9R;O+_,](?IY*M\
MT.DSQ8^IKA#[H/G/!"<I\)BW&,GV(+C$<YUD4-2$$E._Z\@MZ]"E/^-UW:?6
M[@$G#PB?/L8&]X1CGBZ[_!XCF6%V:;3&D\V9WNST\@=0A(OG,W2F\\T(4SV5
MJM=78F8.,/%+MK`M[B)EY&B@)5;T9SA1'E?0+0$E7D"BH)0"!5,WI/7YJIE*
M4P:<RR:*PK3#)0%^5G9(T#1DB/?&J&@DS@>]I9SJ)(\U>P?^]<S*TTC,,]HJ
M;_L"?CCHIV^(:G*N*3TIP[B[FB]AH@`@7+R&[:?P.1+^[-R`S)NHK?KY#\9@
M=KX&/3F?%B<.PX]&4*'+?NR\P@9CQHMG(3+.H>W=?8=@ZA]Z\^:,817^\&@4
M>CA+.=H@"7^N$F_N8."G=@+-W+*LL"#)*VNDTD#W_JMN<9_=5@P).FM5FU:Z
MR0^9J(SH*(S2`TIBHI<Q[563Z+GWA+3YDI[&O']&.&=^[$G!.W^"A!>;)&G5
MT/PIC4Y5G0OQSM69F2$8?\-=4$7(&1?YR>G[ECRZ4F(^M+59`7*(2;<+O1[X
MD%_^\7OX/K_P?82R0W0SO^7_5EW\.!8/*#$8!H%7)X8STNXQ*AMZ*5,4Y=PA
M^]X0)K]I<**A4=BY$6%!BVQ1GVB;.0I$13JNNPTZTDN>6I!D[!VV*7!9P>JW
M[7=)DJ&QZT/+';XB4AC?XFQ4:SL,U*)9:(5VWG2]GWY9$7-O4=K82BK.V6]5
M>_HI[,C$V0H?E,Y2#?"VJN3/9.=9,TAR8?_9(%A,7.?AVXT(\B(8W>=/,*><
MJPB5Q^5EF1=S]I1G(;YU>'_Z&>RK%U`EN-C3"3CXQ5_MHMY1U8RKDJB]YH8K
M,EO%U"1<\9PZXYOCI&F49^X)_G?5[$0?@$:,<J&5T;.<+.KSA+?BQ'ABFI@@
MZAO'%`KQ)\J%NHRXY^>T78?:P_X>'YRCPP@$(6,$'/&^L>)=!1IT6/JG2?F%
M#/[`^T3?Y7QNB0@FYKUV;ZDNA8.^'"?-,T1:A;@N-&;MQ_6W;!5[C\^$@3#B
M./QPY_(_!]R>NI2W*JLRIS3W/6M:[*NRE,4W++(R)BIIG9R2+[9GDH?&LS7U
MG"PF#SZVFE5&R,.(;D)7WLH_&YRIYN('&]X.*MA>8NXC*=;X>++!\CTR1CL_
M*DP\EHU$!8&3+Y#>#(4S+,.:A)4%V;@'"MSF)!4K=P3DZ?XUX+9+*T?M#BW$
MHYN9')7=);I`H:1?(.HRHIS*LZQ=&3\(@I5Z.OYR\*5IHGI4=#=I$W4I7:'4
M6V7(_8*(7GHB@.KG"#^@;;3`T.@2Y$1$RF+@H#SALYZ%.@149>D*U%X)A8%(
M=88(OK&X5WCSC$9#^"?^T^4'1T8I\ZA-4HW_EE2.L7\Y?%AGP)'T.2MS^?+<
M7:&TU4H=)MK!+>WCT;<OF0>1@^X(,T[WS/E'F\4I&/KX[$M)=#'GL&CV_*,%
MH=[[&R'\/Q8Z;3\##1WX;>D87H\,H8,M=2(:1R_5.=>S1^:=V.>X(HF73BF)
M6LZH[",,_VW1[HOW10@AEH;TK/;9/ZI>92T&AN(H<2CHQ(UNIE=G,LD##CI,
MTG6>3,EMXA:/!0%ZF#%TQ@JEB1UBUM)>L3>BC!"Q_IL+^&TLO/I?X^QDQI*G
MAH7$H91_3!:Q'$/F%8;\54`:4.ZRIR]."T>YF<)%<Y.FKD&KSX%*I,QK2"V;
MSY/9>015MY'M!^FC3':]9K(SK_]%H;7,B'!>W]/N-6F:44#Y*MM23:F@M-K\
M<I)?OK%#)*F,PQH/#,DUIG_3,AW4JSD;3-[`"$@M,;+E"JDA/JW.)K/&;6..
M6IA\#*PYQOF$Q[+Y&]+W%.;"\%$I;,407!)T:6EC`K[%LFD"I^P*[],*&SD)
MT&T77,Y#XA#)X[#4\+:O&?YUL]LM<INT9$H>:](_+Z[0=SX*6,.H>]G@E:5B
MZ&/Q_9D79HJG(WM)2<=U]4]M)SV*7'G248[GWG%AWQ$FX"(^B9.J0X#27S(@
M_9(T$4_-KHX!SVD$5K0WP%:L$C>_Z-MW\PH+2>QJ*'HWG'#SI"6R3.I4;H]P
M_"#^%6.6\.X[?\S:T493`&P!^HLA=.?=[<>U:8M/-CC8X/AR;_L.B"&L'^J`
MO2-,+4R21VXES)$'$V:H>R5K0'QNQUTZ_.LIN2ZS!/4OQH\C]_-<(X5;76CP
MT==_43'&HVH]T!):,1S=[@7;DW)\2>1_JN+)/]5]/*G@^P70P8ZD65"SJ@?O
M!+TUHD@1JN]SBIQ-7(WVB'0_F##3!E/*0)AD"1440-T\H?^G.TC(!84Q2*IS
ME+_</11,;YAMCI>`LTYGFK067'9T2[PI40R;D[$`G/R^J<8`(7`?'W.'&-6&
M$I'F#A4V7QY-BB)RZ?/KN)_(A@NXNR[-$!S%R'W\@,:,2S$%E7W&1Z@;'[<.
MXY"_`4,/#IN>UK=.G^/\(H5V-#X6?B0M71T+9CE,RP+4UTM%'M$\/W!H<"!E
M8VAO)SP_)SL_/BYIS6II<10%>,O,QWOL$3/M*82FJJ)TZVAA^P@D5"T7I$UW
M`OLR.A$-[':NJ'XX:;-LH*WO&XX"^+B%AEI\E4"33WG,>FKI66EK&(S%B]\X
M>G%7;=O?TF.4H)EIZG/WSTC]G:]T!=)6BAV0FTP?AP%PF;&+U%5]+6?'V:%P
MK1Z@=`YR$^H9S2.TE^R%AO@/OM&(XI5S5KC(U9RJ_A,N5,7N%'52S--?>/.%
M[(<8O-F_LA:T2V,4##-74X6)HJVA\!8@TTDFS"17*K5WC1+^R2?$.55&_J@H
M#QB]\1T>>7@@3#F6*7I$*1XGZ+K6(]@TIP;:BIRY9K70TM03-P\A0`S<H6TJ
M.I@&II.FF$06:6IL`]2[<$JZ>E-QO<;Y^F>)XRP6GE`-*?CUA1@R5<9*?(;:
M#X:W-D!"TK_)1;PR<_3AN/EB3B9&LW>;$"6AA`=/X\='XRZLM;>4S@J;:97C
M%]\QNL8<#O9`YH=BSU3(VW#3)44%M5T_K?]"S*Y;JCLQG9MP[$20\8Z\^L91
M,^I,[$L!5]++!,\&FK&2P.>XOQK]>3SXU3R3;NO!@8/3O)@'U+HI@]5L@_"1
M[S*/(Z'VL0(F1?U_-&>-V6@HATQB$.DE9Y&2^+PZ"[F!H#R;G,K@CM,H8P"H
MI/9NHD\$[]'NXXU6\A\R_U:T]DXB"",.5:#<^54_@QZ<<JG(^I<E)`<ZCB`V
MNBGDQ4WM`M[9P'K?\W<Q:RT$_N>]4?#M<\,$00*`[L[PD!J4N#`'424S=X?1
M*V67&"C](*>3<X;J=;>0+9-X?OO09,0:I2HM2B"!(X]YPCDZFKH[V<SSV-C9
MFG2\3>=3"0<`@)*PE.QXO6Q))WAH.AVS\Q?NG;1KV#D]-@23,@F?-!)X/N`W
MI:,Z%Q7+*1N7/<!1-"QF>B=$Y>&=!)+34WP`M;8[KUJ5YJ9GX$;9?5D]]PG-
MLP*"_ZMC35HE^(,G+US[FO;U-U0`SU.25W5[GN#*\CLB`?$U_P;(":;;=#!1
M9S]AN(__#TAP`_!J+844<S#I46<5@*BZI6?Q$HIC*-'*8R]^SPT4(CD`7-.F
MK-KKYSH=M<$\W+WX0'V&8@=91F[<*4\W62WC1<)UURP(T(FZBY@D2D"]V(4O
M.;^Y-;^"793Z4%2N?P?*GY&4#O;E>2SB\Z'VY+XQ@NPILCRMAWWBVS6(.Z9V
M>N[>>%#OO/5Q2R&\"T:?9KHTJ%'O>D@*N&J0>M,8EI*=;-;>"MA0(D\ZX5YF
M-7M@<-(F#,EZRDC3I"+2YM-DTPS8B90(9F>8<PT=*#GIOM;75.`[-B#-O;$G
M^YPE;XZV"M=X-N3BUG8GW<]V9%WZEL1>(SV]^S][&0\:5S<2I"A2D>"&T)&#
M3R$CN@,;#-T/F+1.SN=A[E9^WK`/I@3-!%ECH1OA_7&)[;X.@G2D?@#-I%F5
MIYL.XP>=`O0K$OW6I=V)JP_9V\8O:?-(+B3:-!EVAUR+@Z[LRS_PH%%/1AA<
MDQZ@>^,N,<EXDTF2+2>PQWJ,3M_P<;0N/0=CO'D"?BQ-$ZYO\:&%(%SP*CJ'
M6P@"/P)@/EXJ5TMIIDF\/-$$WB$53&<.D#GGB=QHCN6G?WN#SDNW/R\\HH1F
M`$PD#J?!N+&/2QSH]G*',"9"$)DZBE&'KP]OD1/2:TXZ%FZJ`T9-EC$G>W6,
MNN#YL'6L1.4QWIP3J`MBM/_%8A!1.2"<'$L;?BE5^#V2^<^U`I/`GD.\OH30
MFQPO[\!.QTC[S>7*".NH%?>XS$&EVM7?7/B.S][WFLOG0SI_=/8'(T^)DX7G
M7U5#O*LY3VWPY$;"YDI:L[.-V>X']"]%DG\BD\?N#2HVREPD1":"[]U0A194
MVU>_498=S/MAQ44?97PK%%FCM:+B\W=0[T+EWVE_V#56A^X`.<R[>$)Q>WJQ
M>$*:#@PB#'?,XB`^=Q0B'%NTHZXBUGQIOX%NY91ES8NQ:,;:W5B'A11#H6.5
M1JFRKBE3P[F]O1MCG]DX-`>LGXRX`<&(>3_1\1P_%,+RQ<C_4"L1O0A8546`
M/X1+2LMGMQ3NQ1<19X4FAVC9!LTRCI(\T^HZ'7*N!H\2D(#);"M"L"F*]#^3
MY,^A!)-2;>9BGOEZ&KV"<:@M#`R#IA'7=](A,*!VB_"5Q;W:/VN^^9M.@?##
M7<S$)E8K!H9$6JD\!LH$K8&&4+1),18#;8]A,K:_D8X%@:_>S`C(X98)00QC
M2+%P3+`N_Q/Z8&-P"N/7%=;74=(XJD(R@`Z^)@HEUQ]\DJ?_;19&DK\?C3Z9
MQKIN;.95L'V70)IB=B3-.)>.1Y<T,BI=Z`@`U!M<7RQQM@1)D''G)5^/X2QJ
ME2\\TX4\&>P8AXLFI>6LU<%Q:1NRAWLD>XF+9*NMB0J#:OH@-M'&5K4^[A3@
M;\AP]^++W4?5(KBRA#92J/J&HQB#N/F0%".)R5KHM3L]\/@+I)*4NYRHMY*.
M#&W.V!!Y9>F='PFY@]1D>N"PY%+Q.R#$:-OXU&##=%`E^;E/8(QH;PQ6*1S$
MFMD((`(T2>R!#?_7_PGMMTA:PXQ<H;IIJ&8&8\^(+&EN9=5C-E?Q(K91!Y$*
MA+KRZHIS=+77I/-N,$'J4X<&GW3FBFZU(->]A#HF1OECK4M/`>H*0>O0@#N*
MRL]3]2@;L1CTY$#+)[2_LO]!D=)X,LH\_.EVI^BE8G?F^0?'75QAP%?$F<'8
M78XTHPXK!)K2-K\H*M+#.RI0D1BG64-3**@TE10^UXZC'W^Y%3"Z/MR;UMV=
MGTD3ZWO%1HPD[B-L6##@(0LL'!02_7LG^D+Q@?*H)$-Q^BN?OO:NL!1*!/N;
MJZX)^+8C]`WF@*(`8RBLD.O*V,N\[=,9?RO])]K"+#U4*]$=E[4@PUD)6\@&
MI-<U,(R@6.PIJ',`N0HO4WSFB?2!VY,YEWKAYM,_G]0I:+H_Q!AZ?A.G`[<Z
M!-2^0T6%)20.LQ?'(GLDPCK2\H.<1E+O>!5F'F3H]3>U7)P3VQEK%7U!`C0<
M1)9+Z87I3]O`B;J&674M7#ZGSL.`%C?E9TW>?B9_1+<+-RB1[SW0R(D#2#-J
M(!Z.SX4TTLIVW$#S>*9=[HUB\#`0T3)R#]M5+"B*&5C(8=SS@8=[)T+YP0QR
M`"IY"+!EUW#+:?G.D*1N.>=#>.=2,I!K*Z=84DCK/*%TKDP)[6).>EDUFC$G
M)(/?\BL)QQ#/!HOO=DI9\,QA$3K)IX!_#OV/F-7*]DC^D[L*>9_[B/79W;!!
M$:<Y,YY1D",QCK,`>-OSJ>JU0>\%!+]KJ.4%CLQ=!VE:]9J,4:B46@58A/\[
MGG+?62%]FW)OJ3VM2:??YC8Q36=&/9:"`<(\R31FM`5`JZ:OII1%JL9S@4DK
M%P^.LED8<?^F*@LS;YJBZS'B$HX5CBXPWMITEZ+F3K8V\$CMNZ\V-Y^6=6T1
M_S5H22J@)<M%E(HT5`2J&]K9$RNGV:0`G9QU[+1N#9)DF,\^5M^7F"A>^/];
M8,=JS&6])UQEC(A&3`W$&S/HTPM4+Y%U=.CH_X'&Q(R>#Q0M53-1_^A@F-&(
M9X$Q9H3)QKUJ,Z*M:&%<DD@CDH*S&:R1"S3"-6=FAQ0@J-A'+A9X[D'[BO[,
MPO+5QVG:R;LY8RCI(>^EK%<2=IDGWIC'-A#MVA@_)8V+/(-LRO2EXD]8G"%5
MXRUB=*DBXI7PE,'4TX'?$!L8/?@T%^%STIII+>%)$S2RWISF(#E37`X31CIH
MP9X4JH7O9;M.0M0U3+B!%D(X!I'H3S[^'A+NY,_=I&@XEQ^>,<,A%H7)*^UI
MNP&_#0#XN"?6`BM)R4!*++HPXMH.KKTRYQ/_L(%VYHEEK!/OZ?Q"R7/$I%&G
M]-JOP7$\P$196YN=O7AX]X:L[(>5I2)LM/B&!K?GZT3QURGPM2]XM0CR'3X#
M**<A?B&B('V/<2<9+)&\JI%O<*B*)CMT'1^7H2XG>8C(WCP:O"V5=C)LAL"`
M(EQ6&2I:;:^5;L<31@+:3R055<XX)[++[0#@C/=2RQ5Z:8H8.C\E\.4'YK8$
MZE\(@O2,OB0&J7-&NVQT$W4H^%`WY7Q]+S:3TT!`_-D1#`ZD]NA$[`*6:!*-
M\_F'1-E/#.)EPM)/*IC=&A2='!23<,0WY'HW^G@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O861M:6XO<&QI8B]C;&%S<RY#:&5C
M:V5R+G!H<```````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-38R-C(`,3`U,34T,S$P-38`,#$W-S0Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B`@("!D:64H(E1H92!F
M:6QE(&-L87-S+D-H96-K97(N<&AP(&ES('!A<G0@;V8@4&QE<VL@9&ES=')I
M8G5T:6]N+B!)="!C86YN;W0@8F4@<G5N(&]U='-I9&4@;V8@4&QE<VL@96YV
M:7)O;FUE;G0N7&XB*3L*("`@(%]?<&QE<VM?;&]A9&5R7W!R86=M85]?*"="
M)RD["C\^"HS-#D`7_PQ`*UR=MTBUK4Z"67\OPY?1,;1V6=`(G82Q8"T;YY!0
M+SSZJ/7@K0!T=+LR;\/ZYS*`<'U?%6(N4O@(P(AJ=`B+Z29^U/J!H=)][#*%
M2IA!8?;W@#/$'+R-Z0%L_!RA+RTY/Z6-=OFOA3O`5_8;6FHG;M9^'I;K<@SU
M>`*K=R4IF,@(5Y-LAQGU47,JE&0R%T:58TK,AOH\@^QLJEF_.>MOL7]%?)#%
M-FL9Y23N%*Z82HW=BC9:Q0K]AK*OH;X'J!\#R;-`[-'W&Y(9GMY)O0N#WWVZ
M.A?/P4?VK"R'[#`)U%:-.6Q^Q#]<&>AP@2L$\=64IVZD91!LRW(P74T"14-4
M:W\M#1N]#2&&6S/`:#SQOD<JI6WY)=9.-4JM9(]$4OF<M!%,-N43TD">U.A3
MU\LZW?K=3:Y-A.E'%@7&X3?[;<%FR)CF?F*`BTCW$GQ3+D`E2YAO<.7*5??X
M\@8E9(=^>VPH)YIXY(7+9A/_P8?&[^%LY0K,]NIL7@2C6VB3)IY")!U.@MQ)
MO/?(V#@D*&C<WX4GXZM^Z41'J6,2Z3LPK-RQYB`(&7"6D9Q:EHU"P)(V(3?A
M,WO82)OB7AS=N>Q:Y.0CBJ[1GUY8]@J0Q!V<2="(S.@F7!ZG/O*5%+8HB9YT
M8IGB\=!1UL'I[$/0C).6.='V)#:^WUP6V\C'E@9.'<C3O/R@<&-<<K`GU8)Y
M5,*'LL^*C5<I?0F_\8:B)K&L3@1835%*O;,IIW)@DC@\UC(FC.S(X:8BP^(Z
M#JP^_=F(9BT[G3/@:K?".AN@$S#D32.X!`8,\?AMB#!XT`!TO3G`A^:AHE2Y
M0/8^?Q.P'X<:.:&#KY/@AK)Q.>V2@#^CT%:'G->O#$]2^T,"D1!-%`]*O`Q_
MR9FL!-KV'$<*Q]V?3M[V_NA@H$N4&A,0%I\M1&0>>5HQ]_>:H;%+/PM;C[7O
ML+5B$WCT]&,?6MS25=E06=<9[K2W=E+EXVZ*3H^RXX!<->#J,-JF>.C^:S17
M&TH>.?QHP)'.5(L&#G':ZH<3JO9Z)R>E5AM8@KA8,]1^,,V3P26/ETX%SK:K
M*&3)OD*VQD^)VT&IHL[CHW[Y<#"=/"S@;*T_2FH43(.6<2+Z)8#!Y4N:^*$>
MK+]WEI9,W@IDYSH/!P,#%.H"(,\T&3PV0*FJ#4;\)4=S,%VU>`L2,&];IZ[Z
MV->-17V;^S2XBUA-*XH++17,M#:5`)+.'/K2MI;$MJ!SE?;)267G1F76O'KT
M#+SSB!P(G$;W^V`*L585"O;(0\?R/VUD%;L$UR[;]GB^MD^,95CD&]]5_1X3
ME&+6"Z*\HBJJ!W$%*(;J_<0>3H1;1O57OW9@E$4C^EGX"\OP`=O'P-[WW#B@
M`GSI4H4H"?-3>=ECR?5EDD=5A)1R,`C*+.YHMOQPU;)BK2S7\OL$S9_3U;<V
MDW8#;CW\$K8T!P-DOO0W627.`#V/(#";=B.O0%9B+4IM*5X4)0E_NR!TU/^%
M+0-Z."[0+'6(T('[P]5EE\M9%PNLS,%/%ZCBQ&L?X6`0D#:5MK@3^MP,XEJ8
M(<Q0S:YS`=HYI;OX>#,$T^\@[O%<_V3ZWOX)^]67O"&"^899HH#5@"V,2F!3
M\X$1W==W^ET)4,O#LXOX$RXA8SOYOAYYGFYL79*XRO=3SO[4!1BQA>7K)+E!
M1FG,NPZZC\BK^4>*Q7#_B4+7Z-_*(3@I\]4:;7C0H^4PW*P\?"MRD5]R6^J)
M!W'@OG'=#$SLV3X!9`\&YEQ*6W[R>^SNR/O=9B#)NXOF*15W@&/Y19&\<Z$S
M88!_QWQ:7Q][IYMMNQ\BZJ$(&E^E7M4X3=$QZ$F-#@EV%!D.@5#OW$3NDUCJ
MXJ0;S%E/%P$L.\WIWB8U%%SGJ0RFG!UQB#Z3D.H"=)HNL'^?HDA7*S$X_'%S
MXD-`EJ]3&]?!@!WX\%2!_9(!(=@I5`N3;D(63J3]I:9AI%[VLAV\<]HW+5:S
MSN=']N?D,."XX$@14K1_-_/,:<\#"I*O5M%^&XV7]B?0U(-)DN+)8+1@+GO5
M[$UX1R1<`0C80%9%(J-B1#%U?[?YF5C7Z7'ZAR_$4=1VUGC8*/!$D/4Q362\
M6,WU"-8^&"H*!MI=;8/I_^:!:-B!5;5)I`(/0,NQHF2EN4$!S2F3K#RYO!Q9
M@W(V2%`2Q-'-W1^2'!CY/N>,86^?9`MP.X>X?'R9AP7#ATNJS?4Q)GIA^=)X
M,X#`CTW^9***#\E=\:O%9KI>YS3J$WGEM)T?K6-@J(>3L'SPO^"+4D`Z,RB9
MN@E"VL,UFZ<<'N;50X4L[7T_1.<R;B?JMY96;-WG0.-U7\O[^FI1RMD66_M+
M@*!27S!AZBP>?D4=)W(-W:]XT`NTJJ8G4O?F@:^B_R8+\%HO6Z0J.P6U-M6'
MY7CPB6I/O#7D7T2<^1PX[L\['E>9,NI3M8[PA+_G*L`UO6^?-33V8C`3Z:P/
MI'B]&.U[QF65E2S:?*NE7BX%22(]62#>.^N'.W7Q8FJ-0H*9,,*@<%P!LF_L
M/I2RV:!^/R@NMMG?'30R'.@(10A(WEV?("O93HJS]$&8")>YYDR@C>-*T&-X
M,J$,'Q_3)7S\65[<.V_67/C!^E@Y%&S\?WAN9RCGI?1;*BT10XLFIM!/\5K7
M6MEK)^@A8-]W?*406,'7M^1D<DZSJ;ASZ-19G&]&:5G(/$N;GN2:_$XYO5)"
MKO$5DXM$S33Y^6^CF`*.4"8&#L9A*5)H?Z'BB(CE22)4-?K@DJ0+%5<STI$)
M4F6EB)NL`Y]UJJ&=M@8;%7@>/56+*NC\VR.>*$B8?8=#&GE55=O7([9$^4^%
M89M3-C>37/JG@OXMMB<HQ;PLCK_:\74T1*PT@`7L9=J+,+8AP+*P@99'E=5I
M)X!1?Y@$M6UVD(^=<5^747QPLA].74&I"HM>6M\,N`2(=_/^/M(5;HEK$[BV
MND!S\@YB(Z#I!83W^TT>@:E4GL=K@)\7'*W<AB4@G@@?^96K#PG@S!OZG(-K
M2')VK($M)!!NN"A:>@T7F5%-H+AC)0A?XS<_?(1X<D=<S@"*3[P&<QQKL@8\
MP#W3P9/Y"H+V0L$95:[89H%N5O0+A&\M=#$(X^RI?XS?:CW/<PYHB9,"2AX=
ME="(F[#P5SK5L;Y?]M"8J'[GO:6HE3P1NSYE3V!X.$@F#?(L6=OEN.)):69$
MMWBGKU=G5<.Q3V"J$!&O6R?OHWS(WMI<=YQA76$9'8C0ZF7#[GC#_O+0UJ!7
MSY[MPH4MP>Y"3#"(&S`8MN2:X73=A!>:H4)D%3:JT.559AN1ZM0(U7W7X8*)
MZNK$OGX)21Q7<3`W+'ET6)3_0RFJKQMWE#4A..BD8#?4NU9]W4']Y2H(Q$!4
MSY.9T`XV=%YLIX5\-+"L9PUGUV'"P:4X]CRW#!Q*O,Q0`#%]W]PH)`JR0#V'
M\!D"H,W.$Q,.Y'$J+6,SP6MD#%V0$U&%LZ+HY.SHDT5P:+1KK4!:D'>LH(ZL
MZ7D0=WF8WH+HSO0G_^9I6LTJ54RK7W16/G`65\#5)7/X_`B`BRH*'7+;?[-9
M1(S%6S_CI]4CDX@'1'S[PUY!O@)CHGE'BM-O9+EH@'JM3LC9`>&LSOXDZ=XG
MI*Y'O,`HTHA'4<H^W^I-V/S0"#/Y'[.G]]C#3C)(\;4T->0M.WZA70_-CPL)
MY@0MDTTQQ\.6!C1FFX\486L)7D5-K02/R1?M;_RX:UY.71UUKKN^CCRD8B;#
M%?;6%I&EL?>7Q[L-)J1D"-'/V[3HNWOY^P$%O&9%2\-S^Y[WOA*YI29I]@F8
MC@8EW!RY/[L5P^EA6;-?)5=!Y3?OS4^,"E1M]VD<I%.+CKA;$17ZOIH/@'X"
M3F55MJJLND5^X(KJ$(:/'6!$MKWCC0>AC=WVV0R2^K-8$X?PWC&:%-)HDL[7
MNN_HX:?$NOFT:K#+"`SWWP'P>V#BZ@HB(DL&#V6_X-ZN2>>V0^SG-/.9AD1_
M5DJ+?NK>!>'1B#]W13&P1$%2?^^`,J'\V'-^0'@-63HHOE1[W?/T?OWB]M5T
ME((GQ4S/[?3O7EWT'5QVH9\;W(J-H"LIQN]M#1K0986?IXQC,C)54<RPZS2L
MX$I"LRG8;;Q/$/%@P2EXFR+:-@JW_1?-9<O7G;P@)/EO`XQY`@G#,#9887QJ
MVX@-QB()_`-H<BHC;9R1+K?Q"EWMK?M<`?W47&[T93A6C-5V9L7$_$%&N.^<
ML-Y,LN(?G3PCY,W$8<.OD%4-,VQ7T]A.F9NG$)A_M:593B0;&-%FHY;=$^AL
MI$2;U8',-Z4)506I4\0ED!/=(]B\/?PWG^^**I>^'+AI1-8R,?O-1_>F0HF"
MU?3O]4.4=2(I+Q.F4$,&]<OK&JAQG28[<89S>X+)R\2/H(=KKJ=]+A`:`L[9
M[[[F[X:,RN2K9)K*WPY00QK[1#YU2XO='=BE;!U3`#S?%\:.@9!XRA("'@_(
M"$>'_EL`N_+3;AHHVI&`Q[1XBCGJ$'Y[>FMO-9<IS]K+DP`0V9ON=ZT*X-.@
M$C=AM)_SL-"<EC,!EV8.["8>T45>&:U,UZ..%7Q$O2!LNLD,-5QKI79^O2MV
M?NV%,3>V-K78^ZJTEI30<M*W6Z)]Q42:4H>MYBUMN7NEF'"0WV':XVEUUKOP
MIT0]90LI,A:A?$]#)B+=&@\//ST:2G0Y<HOQ>DG>K=>D"BJ6PI]DFS\DS*&,
MHO-/L`0)]5:$$4@D;VVUI&1?XR8E>G4V*#UMM,B)<(-1GK.I]7MW7(9>#VG!
MS7(@6E`&I@/M`7$&*(N#[T6)A_Y(TOV)M?,B!:07S1)RHG';UP`!.7D`QVZ%
M$)7>-ST+D(Z6(8@%-6*K#R[,.,ECJ.1Z0!:35!M<&@%>XRX6W!\^;R+)*X[/
MAE$`,+$[UJD%0Q!>+WAO%,(S9UKVK3Y0%Z?OG,:LU5H1%8-.Z]>%\X?7$=64
MLT9A2;,O,/8R/QUKA\:IBO&3A8"?9'/HTPT/+GSIB1ZHY'TUZHJF^_6[3<*Q
M@R-(-%^TQG-N7T**I[O`7[%YQRQ62(TR4+M=[([5:(8YZ"U37\LG-/%SJNN#
MU',@^3)OX4Y-KPKC<?31<_PK!#[Y2)UX[L"F!_>/^".($R0>3-:^3H#>@1ZP
M68EPK<BW^VQ>9,CH9>3^FDFE,QOHU_A`X"].)`L74)WB&;0<\)WQ.V4,-.9J
M'7FOV*BJ,H00="$M!_$YM@)B]Q+2Q9)P%!RMF#)K)U0N*:0VO*6H-NR5T-R2
M"U49@:0E]NPI]A[&\"HUEHHY!-T/QA.?C6M<C["V"!W*C/V45<0W`PR9A<O)
MSGY4K'PGVCK,ZA`LQI9G[JE-T1\7!^:)L=:,\9@$&"RQH'&8*M+V^*$9?9']
M<].,ANG\M-Z5`(6_6S;'9,B?4\5Y(XW$SNOW'U8H@79TJ7#*\1&[02+3@:%?
MWRHU__E">']^M?K$*E?H,2R'<+N=%&79T^4`V*]/)0OUV*UOX8H8QW,=>;(#
MX16L"<K_6,5[(3?/9R_##HBL[%WX-DX\8[CZ1'.(1@:<)Q`>BG,#VW_E<F*E
MNS<QD::+;`%&8*VV38)QN+]6C#2,.9LJ*54XCAC:/;8`'(XN_DKE:'8Z[:!@
MP.]:]A9?PFWP+U\XPY']8.G^8,3,KC;;L^JOP)DDO`QH2ZN"$&BP6>T%T@"A
MQNH$<;I0=^VRR$`B,,X^X2*03$"E.%WS50@9N>HQG8[X<G?%R>IM?]'NV1=F
M+``[S@^$34XHKRI'^#U]@J4A^W`>GKA4`/V&(U/4^HZ+OXVK]%98S"XY1[$0
M2K]XT7!&+PA\C>/148F!XC6:X$Z[T_^N:/22!R`83K,T(XYH;OM>,.RIA.*N
MN^Z_;U\5*0S!].8-=[.FR=S0`%GF_\8Z>0H9KE)FD@*?V0LLA6@F\3+S9,[V
M4@C`^'92PW".^.*#XN1:G(2@!K)Q*C5DIK$F6`U($)8-?(#_0?-3K6,"R$`I
M%I4BD3IHLVWEVZ.9KR0O"(6#]=?BL;[;`@=$/@WSF#S`!,VA^\-JH4(Q"IFE
M!+:KU$B*DSJ?:L$?K\5@R3/*=V<'Z,H$H0>"TGL/\M\;XD_NQ6^>Q+W300\Z
M0_I>D?9TRGL!!INTUYU`C<['VN'?/Y>8J6,S+:P/($6]1?WKP*#IPO,"7.;S
MJUN>M*AMZ0!"TO<QI6AN7._:[(BI#>+]@ZGE?YB5*3_=F'V?HM,"MY:Z`J#U
M=,7Q_M#,NVA2^/#ICPR(7R1L.U*&`/A+PP^8=$\T-J40_]?:'?(1Q?XK/%;P
MF`=DYJ=IEGH4GD"F8'254.Y84U8S,;DZ^S>6"'N'/5VDGG/R1/#@_1,OVT:\
M9*6>V6SU\9,M[E$^Y-FZV`&S#BAF-#O?TU=RUD=K/G+%J!*O$)-RV8Z'-TVP
M>!+R<\W.F20FR8PG*0>/@&EP70:#,F<-DQS6NJN]WL6*0P$1?$]<%\V*E-FW
M4[U"`!V(75?]*ZD-`E9161K7-YKY3],I(IHQ,05E&=7`SC5M^&C`'9=2EVK4
M*G4*^5$[+?2=UU(^D)JX#$KNJJKA`>)F5\K"'4HL[@!*"T]AO(6?<M?9CV.'
M7T![`6IZC=0U#7V,5W359G&[IBX>.'I^.^LQ<IE7_@G]:<ETGA5QM<`;9PJB
M$9V?45W3C.C:#WJ0,K7X<L&%Q\(W\KT-.[;=LW0X@$[0*H'&@CYW<LN#-;-+
M0M5(<9E=>RMOWP[D</B(8M_%Y2KVL`=<]XU*19@XD!M-2FG.\T4QN!L!Z$L4
MP9!?N9TUFO/]3]&"HB+2;^`']'X:@Y<*K*(73WYR8&^_+`#V'B>`'JN%#RU[
MA1`:-_ZJP66:7H`N^):3M2,UUK@Z/6'<&7@E"WN<LVM/C;(=AJ[W:Y'HG9Y(
MW/V,3>:Y..XOY4:P0)$HQ'8F\'M_HUOIDX.I9R(]EE9GD=P9]A1/_#Q],[&[
M+?UW/%+1R*["%U%#]SS(J$0B14_5&:BMB<$692Y.#N-VJH7;3X_50QN`!8(%
M+#>1D0+*&O(SK[R`60XN+^>(VA#*!@6"]5\F&,WP=PQY1W/^Z*6<&&B8YER_
M$?WO\6`-7DJ1QF!#)D=GAHTJJZ.NCN1S0ZWM6!],=D]]6A!='Y@_\#PDA7ZI
M8)YV61"S)19K$H<ES,J_C=2Z9]:"52ZIB*1:`N^/_QAY#__BA:"%<.=Q^=5W
M1-/A4]$N^.\7,URTSQAPQ>=DSMV+*`P_!/D#H[,@"J9C<.L6^_P8^QOE)`>/
MM!5`/_6KC7Z,9_I-#2/=09_HK?;`K"URA#JM=$3P8ZB!FJ8WM,S0J4Y>Q*=F
MK!3,LUS52:RW!LB2EM9/D(</<NX4J>B^]-XR5"N8^<`S`]SKH+;X&=G"CE;N
M:H89_#QF<!X-Q`&?9L0=ICK56K&<^"]0);/ZX_Y[$38H!XZE&;04DWZU8MR^
M_INGP1]QV>)'ZE?9*A'LX18*`.!-]I&WOA7\7NF]TE[?1;KP>[%^OOD-L[]%
M+TJ*<+[PLBRJ?0PJ-PVO:$,=@0H/PXPE2.Z3UC6%A+2*\@+^*[+=S=C[9[8V
M#?KK*-^ANP,S.6I_>2UP%?,T[%EVTER(9V$,'<SB-[OO-0;#-FB5FE(OWJU4
MTX7B&VG8X[6C$"$",I"$CY]-_-(>,#CA;%-!J!7;&(;>2A)YG&!2K\^#;/;`
MI[K\Y3*&/[^`!0W,E#"J.*MUM-Z[RG`>'9.@^H3I`OGW#']EISC3MQ5-@;D>
M\3`[2+F_B%ABHU5B:I,6:7<.'Q+,1RE<AJCAO&4#I]C5+-W"`HN8EOE)[YQ:
ME^WQK,QOEH),_)_*$=YNJEQKNY;G%L"<%UAB<?<;*DQX)?QVSK(IV,!OZIUF
M!#:Y;W*O6U3K'`*RYY7CKCORM2:RRW4+73"R!B'#49Y7.@]5@/J&OO_:>^*H
M"&<DG*7)R5LOW@)YI/U^DF."?>V'TDO?1,N*.S0*<\C>PSL9*-M4R`#-4:`!
MGFHM5@]\].N8:(Y0D/!FF.J(:L&T.;X(HAY;[_-)"1G[<GPOH[8YYC%4W+]T
MWAW$-S)=D;BG.MT8W4<FL].GY`X,C7FG6K?LNC:J..7YK\?@#Q56-L^)$G'/
M7;C];!<899TR2@*@B][O;0!&'[X*=$9"<@0&V!TE\S1"1:2MWPUI-0'?:#F]
MH%VB!>AY`K#W%B#M#4@'7@QQ>33/3V\3K%E&T'$CNQIU*OGKC+V#VL%LR;U_
MLB^T2'!OAN5M1'?(2BY9)"+//5NRCW6)E.#T6;JBUM7Q[.)N.5%MMV1\_YH-
M#3V=2@B*R9-W%_XL.6Y-%0"$B5*JK3$)WRD?5FWP"(IL83'CRK@B=>VC)*)L
M&WN?,HW"Z#HQX`<U`.NVAXL/;FH!<L0CEOED<3;P&)4&0+4!"[RI4KH3H0D.
ML,*N(D#,<26>RYZIKL]5P=]V^EB0P!<WXYYWF7SOEBQOZ$&J19"6'$F[;>)X
M2IQ+!K*?B\[5>Z9JSK!_HYK72^"4MW!,+5`7B7FL)+"+("(#U_O95\-U&CDY
MZ%!9`E3W#()&RX#U7RXQ4O-\%BD6YBO:J&L+S0B3%U"[=%.$1(["3FP,UO6I
M[_\&[9#2Q=4AW]GKB,?#4OS?"8<U*X^L=:27G1&/B&LLU.VFC+*<JLLH%^(N
MI,)^*+1^:NO<#XHT_+'"#77-;&@G4F?+P=9DX08J;$D8HJO1S)_I-MN/Q:NW
MFP-%8P&0BWLVS@7X7OAR>;`U(6*N$.%`7P*KT!Q,6A"B?0M-L^UAH`5',KX8
M#<U>"D2_XU'^^5+-Y<[EVX)8$P1)T=+1SQ3JM3K@)`[XN%JCWLFR5HCJD,;F
ME>X&EWKWX6?:I6+4FD;[8.]904Z2!2$K-(X341T^56^@MS.WD7S>Z(KB562+
MG^[%:EJACRHS]]"2.=\H/QJ=XA@&N]9-H`N5T0`!V@W&TK63\48\B:!>:'E!
M-P:_)';XZ=#=\&#:=B%Y["?6EW%^&F_'2PHAS%K)SD#&6+YWXWT-8]2)3-H0
M5'S^,^7:GD3WB?R;Z:]L%>4J(V2E7(_'_:77[#9.\8+XGB!)#5NH"Z&Z_.H<
M1A^I<YHXJCDKA8E$0(,>$[O3LL-I_GJSWI[]!C*$VS]R/"IZ^WH7`T_%TZW$
MV2LLG.N@54XM4K`Y<.(`RGRZ[K&/=NXM=XV,6LS!0*(,\!%<AZ>ZFM\++4U?
M5VXR>`O^3]5@A`\<;4)"A?!;4,A0XM)1:)&'6')P5"/DLDJ8Z-&\">RE5*.(
M<(Q/WB+O#JB`!3:_K>4X?.HAU4>5>@\2:U1C"R2(O6:"=J*LO9O/!-J4*AW$
M:KB^>8R"G]>5,AWX"W/^7!O1'%_D.YQ;!-(2M3"%T(:F<55)IEMY9M#LP+*6
MF7/JD6'<6;"E`K<,E,CU_.#.)"L/,V#UF>N>L(LQOE)8BPNPRH+Q];<RML`]
M>#X+`=O>"$^4"J<NBDL,[R8^\`4AI]0[X0<+,U$.FUVY%GQ'3:=^<ZT#,)WB
M9Y\]\HIF]A_+?)G+'S*#3U@732+Z@;#$:*J`>R+>KGX)**\B1MZ&W_EOGIA0
MA=Z`V$[9ML1[E3N#%QG!&>`5N)ZN+Q^Y"-'W(?8R-P.S$K,X?+KDAX/6F"=)
MQ=LK\:F-90*9]SI@7`.(QH:F1<`ST%\.7*A4+1DB+T`CL=F&*,R[+FD0#V!1
M(XUV_UO.XQ-RRX]R.3EZR_L8Q@Q]&;=(G"AKMJA#B0*A_L'N,VS6CM_847W/
M5Q_5]K76M=(ZC4C")9WHW`WR,@*C_*N7Z^20PZ-I%T5-Z!T$371`?-3V>/ZS
M&WA&8M\C3ZU*:Z]E.*-+_Z%(GO#O6"$X)*+D_EVBW-W#-F*V'<D4MNLL1*#9
M%QM\ZK\D#B->VK1IBGIRE,*!,^H6GZCK(!4NQ*_#FH(V.NF.I'P%##FMA4P-
M;\H,$97H!OGB4%8)+Q`VU=Y(1T'\NA=><5CR4*8`054+R[<M75N',%J\[G@<
M`20SDP&*(!>K5-PWKG]X99Z.ZC;%GK_45'Y.0S9_6M,H]C'L&E+O%C0YU!'0
M6JM3+*EYFO8KY!!#0.EEQNPB,F9)K"B<ZS]3OVB:;.([H1[4^\+T`,Z'\!'3
MZ39.`<`;7?D!3S(#L(J1'_!<2OF*/^8IO_<P@`C3IABWW*_,N\:4GV<;CPVO
MKCRU="2";&V!RO3G,4O(BFVI#;U9-=P4"3(]SXMY+7MB+@#VR=APD-SY:W)!
MM]/)=2-7E&-?TU+H4+,W[LD9:P%FZ<5NM$,[&/H$N"!+!&IM"[-RF2K"$[SV
M'_T1K!`FV4:D\#9_A[,=S;Y5&V<X'Z2$1S#"`3B8N5M!0$YDT`\$95YI%XXQ
MD()$G]FI/^[4(DPP#.-B6<!KLF2S"B<4Q,=V,\HR@@N5U,$2@_Y%VHN@MU'$
M(19ZBA\8Q>+M.?&&E>F*B3N<QS43)WW'FR)/9B)1[KX4-$O%-3`$V:<3#0!'
M!BN:@JZ*NS[%);-)!\8/EHNHBEAKDPDC/6/JP]Q!A1M+X>9'D!?.%/2D+FYC
M1*'HX%7!T3>/.^<PKJE&?;(U2)GXVB4N`=SX,7SP\[A8J%H(X>>SY9'M.WL3
MOH-A,[Y\7]"Z_&'WY"^5`E2=/^V&Z5+G`BB]MVJ7*'Y6S6SH-=":X?T@W5#U
M?LQ==?0L6E#$XTC!%44-K9H@I8S`6SC]C/D3]1&%Q]"9Y70?O!\HL1C\*&#6
MRAAM!JBOI54<<R`W4&!]@1V-+,1T%MP>ZK<8#IP<L.G8;LIFX'U+"M9*(A/X
MZ#NY_IQT<H@_CT3:R%?P935($-A9(6)!'X7KR*`<\X".<'I[-K-$,)6]%$EW
M6*+Q]B)3L%5BF?\=9[#X1/_S-/'"O)X%R0UCN!!'O+(O/5"9040@/N4O23K:
MQ1PI*,E<HG$*L=LC9JLTL?+K`?=+%51NRC)Z^LB0H%.\^[K:5%(?GD;7Q?S+
M;)@EMV_6DFVNH'VHQ+3XD[6%F@9T<UL98]B1:#[LU[5F/_IDI6\57B$70'GL
M^FOA_-'D#5ODN8PM4U8%@)>XGT(S,,TC;#O/:?"`:PW@D9_SN*@#64WXHWHF
M]AS6P>J!@#Q7*B"8$+>;NDT`=-70(9>?7.H7L]2C)\2ZB-!H@%5Q8@+?G]^B
MCBUU]=MV%!E8&27S\8CK!KO))FQ]Y"1SS3[K/IR1_2-EJUB;SO;C_Y%$8L6U
MFE&N0.*^M,1&YA-_J%5C>75P,<22`)_OHVE_9H.]NHUG<-1W`"T+COV+RL>J
MKC.3NSX44C0G&&!=Q:YP\_QS#?M3NT"+6A1B\]+O"N4SE%T4:=0PLRQW<)%<
M:>AJY2,4H9X4'L=M$41N3=2#JNM4?06TLE3%KQT,(R[J6/+GRBMWBRE#'W8>
M4CN;,`T0F@:S/*<(HNNL9ERZU]#%NW'11@Y!L2)WBG^?XN;[=X=`PUJXDV"Q
ML!DR1#+%]J?PP$EJK$@X+3&,4!O6Y!6MJY+NH"&C-">;T,3EDKN<TN?NCJ#(
MX;MC2E0*'6>8A%GRJN,NOC-4"Y+/=KE*]9NK4G%MQ'JH>S%W>AU=I#GVU\H.
M!\H">WD&`TB4;*+<6NX,#/V,ES'49BQ/5MD%H-FVDQN,&E5*)TL#@WSZS[V6
M1'KT;43?'SLX9ZXJ/W,N/3CX6C_MIHN)1'H\'^F6#&?R;=MZOHAD6!HZ//7=
MW;A&WC![*AG)J$>L^T!)FKDY3BW&I>%6)L9QH=!.X5-%YF`60GI>#Z9"#X>=
M8B?NE)#Q^0Q@CL+B(N.(CLJ_W-SU,UVES"%NRR`L$W+,R/#MF6?TF)8FSN*'
MSL#H7AU8PI@6`I?67@,D\"#GXN/FK6,&-)E'-HX=:CDGGQ$1)_#7Q.<9-:J,
MV[O+L=I%V'LM;AXUX!3CS1-BSIG/<9!$<2N.-C8!$^&9=)/<QG3=0;;%\VVQ
M20\<P@PC0<+^%<#J/T$"AFK/$\Z6C=R)S3Y4THEN/\+$./AR9!&6]UHN</,*
MTV7P@LA7:77\^BQJJ9^VS'.*X.>&!P?-VH?$&6E!TPT="6[4Y^=>#N%U0IUT
M41=0M[$7UXIH63&*-FV)KZF]F]AG9YIKZQ^`&DN[/="@%N,_8Z!<\"!:I\O7
M?'#MUR.OFCDLYOH+CD%)0Q!IG^#8/1)YJ@WU4B%&SF850-DU.3#KF<W#RDJR
M(7NQ'A%&&>)NO/@R])A^?E@"@Z$:7-%-4,4?V$QXR=&/-FAOZ/6J;\HH:S6M
ML,1E/`2=8S5QBR96LQ/L\,T=6MR@0>5P))4Z*R2*>FU$,+HUW'>S]U?$0@=P
M"B5%FE;1XUA/./ZA7%4/7(W]5IG+G!F^X3S9"]EU#[.Z\_`2T1RYY66"QV^,
MWGVMCM]<XUR[O<)4,@;2?$LRL/@Z]1,A`SXR2-Q3K<")U.@7NV+2]V(<]Q_'
MCV%N2^AI092#V,D3RZ=C/`FJZM(358F!Y^TK4A09N*SMYP//(V?"27]0?P'5
M\&TAO6\?-L!#-$6VQ`7,?HM&&?0>C''8J_3;8WI;B`(:->HJ,K+!20DZ(47_
MYLWD(8WIF2-A8TV!E";B(^HA<5.WF;,2@?TCMEE7W*P4CQNZ243Y^O-FB6S"
MFCG*=&X6$O(OFS)I!SF2J?@1A;*"+''P.)S<=L]A9\F/MPADV<;ZU$PDG4J[
M?O\"ARIZ@U2K`]T>LK]3>9=/"R*_KZJ]QKF:!@GKV-Q(=?]64(Z]F.V+"#2Z
MXU*.7;)%('JC3;62[K.6H5E#(YGT*EB\\>?0<`$_\=0XT=2M\`C(./9F`)""
M<NX67XI0R(^FFX<`_-S;?\(VQ"\Y5BMP<)%/UO9J$^PF":J-6NAOC:R@/I_<
MAJN%(C5-R=IS=G$92T;K.BO-2Z=Q8S;))MD4Y5EGI7^H,1;),X*4)!K(.=?5
M61+-.:%7%,%(3D?TK^6;F"%67V'N3W(WZ:<EG>[C;<'0D&D/6!J.#L^Q3E-S
M^/<\=)]VU9^`K[QW3:@QOS-1_3)PG/CE_`Q86LNI@6K:G/;BCI=Q.Y]=#N03
M&_Z+B=RJO&QR7&6OKE?A(-(1X"_1OYN'G3761U=B0B?3*O&>VT_D:E4<A[]E
M2M%IC*H(D&1^!V-L'&R*`=>4?H?,(DT%4:$-7O!VD%FCA9^'E<[@;J/MH@F*
MLT0&NN8U>";WDF'0Y$$8U6*=M<$LN00#;S;D1*,[C%WK5]\C/1/G@2!NB1ER
M8[:%23Q+''OE4><463:;0BP,K^IMJKEM%;N+]YZBE>\@B74=VHJYSA"Y":3(
M\`RF_*QRS9X`3FANT/>KQ4S10$#D#PN9R[^68M3`MV(=&ASWOHW30EN18PID
M#&XQ?3]T0#2/`C2;;+769N>-T"*$A$;,+^YRD1DJ#JTH\[I"A;:=W%_I;-H*
M.^<>I95/>2+T83)LEE^P15W"RR%2X!P\9,$]YG5[K*R1TN2$\XZFHMRJ\X]N
M8THR:GA!*+&(`:],>L>IPUC]3CS%";L,"<>8,';,?=]:R.)F"7_SQ-K$K0YB
M0>`Q&.EB58.44^Z(67W\A'/2/;&'W!G-(V@O>>%I#3&6BELBSC0UOVM=?0$J
MVK^)%_V=F^,?`9L4B1*B\T!GM&.S((/>79)L'[DJV]=)LYH#4<P+(7)G%&.Z
M!.,:'O+YTV;Z^`#EHO&;W7G0>3'O-(*U12VQ+;R]C>2N@].N6W1L:;-=),EG
M\$Z(VDSYGKZ@7(/C\N(.V&G-'56'4@PM;#!<=+%J/J"7%U=VFCE?L4$'<A,7
MCW[A>W./%,[>,Z$)"O@+2H6JVY2%D$_U)*M+6^,?)G3O!+X\E-=1^A46`NRP
M15PQ,`D%N(\/:VL4E1-!R@&[:1)Q2/W9S@[.L$WC$9AX>HJCHTC9\>HU61KH
MTOB>AYZ%E/Y,(3O05;@IET(N8M/0^,2>'X+!KM1U-SK#RC)VS1%;5H`["=-&
MEJ37]V[/_!95>QBO`G>E_C&T$X+(C%I,2GQ,F/")=,,).K@9V7:)OD,R2,@=
MZW\/M?NB*U#C,9$QG`/<[G09'6V74;^-B-3:4@Y\"(*@VY7%R[\AX@XUAYX+
M]TABJOUH]F.5)[=Q/RF[I^>U:946,I\;J]RK24?34>YW_X;?S.E*;>Z><!OF
M@'*Y`8IH-$GP@HVCW/F8%O+=+U+Y!7^X[,CU!!-?RO$,V^HY#3LD8YKXHQEW
M@0%JRX]FQ^X$^9J;VSX.'RA0-?(-\S2N1`OFUM,_^4PIT_R[OLS?S?#Q&\Z+
MAY9H!(O4@L96>.!A^]=B2/AC>C%2M%&JF5>BH'2PJU6_[6P=W!"&:**./Z?,
M[35W\3U6\4*M>?1(J;?5K9A1$/[OX3#7CY'W/P'**XMLF2;6&D(+EF@?&Z3:
M'8%/,:F4E#I.K5<'LL`0C8X2!?J3Q^-QMIX-:<F`XZ*CC30S$B\MIC?V0!9"
M033U6(]W%ON<M6G:BIF1O]!0:IMVO*?W!YJRO9G_F&D8?Z-NK:H0BX$?QZ34
M6=$H%A;.>)U4J+P'.Q76?8>"B9(_FX[S]>,6M.SR74#T$,]]D]XF^9K#9[D\
MTJOA"3QCR4E2F/)[-7%\S==,9M8J$[<=DS/<X44V!,.JZY#^?99I>L#]M6B9
MCTZ?Y=>]B1N8)56M=="W*DXMU.4;+(KT0'H`!4S0879W4%Q(R74,C=7K37F&
M6VC%T\ZUF:I:I6"0,V?^4573\FT!"30U(:YO2L#V$HY".#5``!C2JX<$A[7X
M@_>=X_9O=_]U6-"-`+M?^./I)Z:9PK*U"MJY<=N'I7R7\<KBE#>X-JT*%`_@
M':IR[]RUW5)A(B4ZB\$T5J!.ATO^XA9?_RBTMR.<%,1O2O97>AGO*=5'TT</
M[[,>`_A5XP?GV_-2-`@Z]6*^6SZN@X\9*+L)X3B[HA%A(5.L/D?ZUI_Z$;7$
M5[L*/A@92#FTC@MWO.>/*IRU.0D%J^_'H;09F7]G+T2:]>J,R",%YU,&+<X=
M#;8.FA@\E8OMLMM>K+9S5*9)_?BU)RV>AR`I_A5^^!7N"G]0`J80)C^,^ID#
M`;36V*;$L&>+GM0+R13ZR<R7"M2IWSV"]'\O$P$8NP?;H(.,;M:^MG'A,FM"
M'M$]U:(3`F@%BT=_JZT<BW"/I@*TB0ZSLKUFL=-_<SL4](>0[4UL=O6COR5[
M_';NXT1*,%!/6?#M"`%Y"A9M2PAO%@RMVKPG4^1[QL*R.DN`P#8V!5"P\=U&
M,/=U,F7[?BY#-`'N?X3>-C4;DXK3.@BB*#?B&1TF*$;O\+-^.?DKL`'F;[NX
MHF:?K1M+WY?!=J/*#]V'+\<AL!4>;2EC1_E/OWZ^!+69PVWK!2_&LVL'-9WP
M/G>X#F:Y.8CB_))B#3//0/>OKPYDQ!BBOKE1NNFI$5B8\J_AOL_^67$&/#$Y
M8?L^S9OTP]3DBNR$A>[MLQ7(2N1>.04S;FX*T;;Z9LZ5V1)6^)"%028!8%:+
ML#7=DE%`HE[SWH&;N1N^/.Y,I)MRP]>@K68<VK3\J4A15S,^PPQQS[]FEK*&
MH0YS-7[?H0P2TDUFW$"D_B3F*15?;;<A9"DR"NH?_=77C0"?][T'"L]T@CND
MF>8F[CH)&;9LN\)NB^[?L)!THK7`.#=#X*XUWQ()5B&4+$2+'^7EP6ED)JNV
MLROBYK96/CZJ1US91(OY7!FR`'"/$M28U#F)F6\'^G\UF`'P)]8:*,:>3C'H
M'X9;*U@2YB9FC`XWUPGJ3-]<RK.:1[6MD]L=6#06@[7[(]NY94\/FR?4T08C
M2WU+P,Q5(P/E#;Z7+SI%@5F]B>0P`Z@+#IN"+U56@#AZ&3QW*O6,.J"W/_/`
MFB`Q35VF11N_4+&J82:[T1_Z;_B]KL#--;X#T1B)5VR.CB`;Y.9"+&C-$\/W
M\=!3(,S[$74&/5Z_WZQR.2KDB04O$0XC]Y2`P;13'WU8PC>T>0!;4*#`.&[-
MMO/"6"'EP_I1&(P]?`'N5)(M\2"8"/8$Z$G2AM(R$5<I;#7-B]=^(K/6#&0"
MEK:!SYS:36)W`91?Y$BH46UVTOE]H<)Z8IFZ"D.1YN5M)R764OY(OHBUEL*T
MFPIJL5_Z9%BI4Z4O!FQ7#)5!@_QS@.WW=FA(^-H1^6XK++A<*5,%JB6`><BE
M^]_S4+Z7M!&NB,<*XJ;2\LA+58X)9TJW".KB\4EG1=X.3_O6EKT&D<JUL+TG
M5U+?E[4Z'WV0I)53%)V^#$&="4_T)HQ`Q<,#(G9Y).)I3Y.LXU42<X""-']1
M:=T/1P,4A?W?II2%_ETMJ<(+0L^E'#;=QY;J[63@8.!D$?2B-07TF*ECD4=K
M3SQ]Y'9?(_IAW*_?M7,2G:Z8,JFK^\.Y6-&%^WD^M'2ZUQ52F!@(0;<+G;%+
M3.7>A$KA!YQ-1*-:G&<<S*^DC9T?#AT?LB]A7/B[S4]*#N+905?,Z\8RDPON
MARK)37!K6CDP5;]*X-N,__19,](-MLU1S8VVCPGW70:N)-GH;W0<$)MU:8V_
M.>NK7,.4`PH6^3XV4>QHC';\W[F%8W?]S%1#0.5J=F`(9`52I8V6I:HO<;1$
M``BA4.=VXAH,"D!T;FO*^M`JFRI$D8I3(#3;^?V=S4FUC?;3_K*>-C)%0:S3
M)W(*VC4J?T3GOC8$?$-,^#+]1/QQ(;:[^VG=D4:28@0+_^$"YBV:C=4Q'H!B
M..-A!\N%?5O`B1-\,`$],&P.H*:LJ>;*-P\^@:[V]&CZC(ML%`_RZ&K$\0M0
M\F>!ER%`DOZ6G:]=0W#_ZQXTG2CE`*:P`%'P'4$>2G.:4=`;-:C8.R[NF65`
MXD!LHO#=E'$&H&DTC+;&=GMG!W1=WIR9^`M6_Q]%LF5LMGPE3?7#8TIMGF"(
MZ!"B=;'WE`K\,Z+4,[2<;`-_O<(.:6)W*>>GB.)IH5.SFEKFIL@Z2)'X^O6L
M!IZFG9`F[5$^9TQ?/>7#CS2%9A=<!E\R4XH.W'0K,NJIKF3DV>ZDMW#'I]G+
M+Z)J]F9=XUY#125P\KJ!3_+,5TW*A#?L7>1',GT_._"?3+Z^2(XBH5M6&(VN
M-%N%@3%M0GYR/04\<'?FO(=@2NFXDDQ2D?1A$GDX']IV4MCR;.V%!!O.2K0Z
MZP)-BN@IS\O"GFW2/?V':ZD)3*IV_I^"8.E3[462IGQ/K=W<Z,X<N[ZW1O_G
M:OUZR90,',V/!*0-9WZXW1=_1-UWQ&]FV,C38R'B4_\6Q\Y=;,%KZWG7L['C
M&$L0B"(#C,FQME?I)YILX?AW16AY08&Y8"_-Z8HSI>6EZTOT339VU@Z,7,Z/
M'VY7!`ODB&FJ4#0"EUE_A&Z;%`ND@\"E[TZW"->F).Z#D27\3E3^#$QJ`+U9
MK:Y87BKP1;8))26S:Y>X3!.!=&)"Y;<LERGKO(S=1P<B1E+8Z1N4"61$/M-K
MTOD7"KK=M0*%BA!0SHUH_*K'Z(M!+V,B,6T?5^2Z5&/;!R[CC%5'_)-=6:_"
MW(\4V@UOVS9'9#S5QSUA'64CN>):NP$VL5%N$8>SZ6K^=T0\I.JLIC.T<%WQ
M4CID61>]0L&RKLUT"O<7`'[EM)`*%DMRGJXT(TV&;T_S]OH!ZGL]V)=4UVP8
MO-8)=);F*_.4X;;AL`:(9`(1FQ=%<&[=*;<;)NVS=WI@L`N._P[2VR)\4EWD
MEJ:<'M_H7_+;L?F4$X'FD4H"1WFZPJ;50UZ&J[!S0"#V%(@YW_GMXTYH`K6T
MI&;#@-I,$M)@"+6_QE2A`8A_8($_]%[M4`TS+[VOVG^7><^('(A9=^M"HO%1
MN+Z5]7,Z3*X;GP4L!BG(HKD<P_E3*"GD"\>/9+%>P)NB^?9("A4J7X!_7J$H
M3K^]?)(*O8K:69PGE@_CO-G.1;7B7AT['QV,PP8>)GF^ZG+>4E9[;IHW>(+&
M-$__)GGHG%4<':0=42S\UHN>,TM<&1!?EV=0(KPYDQ78%V^ASFY$`0UZBS>5
M];+)6LI52:9DER8AE7'QT+W5,X79/&^^3.AK0@&:I0O70-["6YA2HUJ*]PA%
MAE(<1I7ZP\@'(\=@SB#Z;!(^GA/55\E5%,I1?LC")/V?8J^]N1ZO=8;Q<="D
M$4Z3JQ.J_NFI&:<WWDS\:4,25>C;EI'<6"W'I*3^2@`]S8ND(4W6"9A"S03E
MS_FNB%.5:)?].G=69@<KO990%1R)Z01`W!N1`8=HY1PEA,3R97J+6_AVR)I4
M@Z+<WFOY`J+N5K?_SV9K9@#4#(T;`$1?BN3*?GEN4A#J75U0[;/4-I<\%YZ=
M`%X+SN"S*:OP:\(1E<%6DLHFFPJ><*+Y]&.[QROWL'I('$R""`ELH?-XHI2%
MYV_)?<PA"1.ZY/DPWL'^S*?:Q"C4\GXS$E9Y*)'A1VF5@":IH2;<E2^(0%VO
MR_HN'("Q7RNW@Q=W<$M3OZ3988W$-3&Q/3D?'-@`E6%W,(,/@MTO+:@G:ID?
M0E%D,\*PY+L'V%[Z#E#!SZS33YIX:HRPFFJU(8%PP+/\65QEG@1A!_>Z;CC_
M+E:GABO-^GD-C>7HWE_V05D4\$04_&@II*$'U5*4C2XR4LMU+>C(AK,05*'B
MH(5,'@03M9H6Y8+_M$RAMLEHN,^^VB^FV>&"Z_LD4N&$3;/!^EH-49?B]7J:
MM=:#*B""&^@\Z22;!*VA:'Y.=]0"6'QD+U6TA@U*>&;U$E^["0.YELH)W!L5
M#QZ8S`+$(W+([?P.LM'=#I]M2Q_3Z/<&IMN5T/1*PLT<!O;?+0U_W]=V?+HH
M(D"Q)>[:@CQ>:!M>=PV8SF64:%C\B>="G#L:%!@=T,T`<S`O[A%:/`<U_TWO
M<J!X1F!JL:F%F+@?40`5SZU\CNO_TFHPG7\<PQ^3FFUO^PAAS"6_9ABJJUW7
M0_CETH%I&>'O)C(HRX#!Y;3O89,[<J@,I01%=]JC<V1OX_K$VJLG$-!LAMN8
M"5:D?2HP:4TO";+5%A_-:JQYOA.0>4]K]>:R9$BNM^<Q:LC3+^V97457M(MU
M,#EB=Y!<8:_'2MZD=I1;NLM4:>)]#G^!C=M]O0FSPB9,7`8DX]3-RJ[WTUPF
M8VQ$[H<)Q<N%`Y&Q&\)Q[KEX'&UI(&QS$THTA!OP&]]Y4\3AMX'?\D1BN9&+
MW?_S>!J*,QY1/87NDY7'U5R2L^9`/E"%U)P0;#0@)0K_RQ]HK)3S*Q&+<6T]
MAC/4\@:EO\*2^SPY","=?ZA@G5]5/1=V*GB'^DG#/2YE`6V*WC+S`,/O>,CA
MW+>YDC#/#)UBRV&9T&#<&V<HRUBKXC#5;DS1HF?@0F*C8TRU0M8H1A3)FP^.
MR/7JM"(,SN[=%F@.X%O0FXJIRH?X.YI['YH`C^]XK6)7PC]LS]NT]#'\1&?D
MA6>3Z,(4LEFD?=?Y6[/5:71R2AY6SAQ:X0#+!Z;G`DM[M>A$[<Q,"P&_9U(H
M)HK,_$:F)E`?\_EX!U02###7(R%A0[:>*_,0Q'@BGFB>#VQU6:,.[I!WEG1M
M'@=8@`M[@4WHNE8N?+<.%IVVAG75@Q>&X,G&K`[C+[2-9N</NGN34E[P*_X<
MQVF/P>7-.9H"Z4I.W)G_%R-N,`JW?O<_&/ZG;4(Z"%H`FJ&MZX5</C!1)7$J
M':(!%!%TD'W#\=X<057$`6DPH122I+F_XJQQ)=$/FRY)()#>>'([UYIC(=(J
MA^8?>-#SJ5??C3OF6+"35V5'<6M3GF-U([4ANVEK>CR^8</"KX?*>*JFVB>X
MTD&'K**/+S8,UM"AX"/M?B*7X%B)(R,OT,RAHU7T?_[!XZ89MTUCV<2*4E/N
M)1<0/PQ775JS@GA\>)_"^Z(B`N&`9`;(=A48\C^,9_BS"N-YRJ!5@MODOPKB
MOI@,+,QPE]7?\2ZT*-)$/#C]5K%7.8T$QGE:/>_)*WF\X-&+6?`#7>;NLRN]
M<346DP?4>56UB*//.6,II)8J;/Q1>#:EN&E;$@SVEU%#N/,)GRV2'["^%E>;
MA>9#.SVJ`NT-8'?082XK4`);#AP`44\U#?*2<WE!1U)V]UR<7W'#IDBB.L;>
MG[%,YC&LCGA=T/BB-;?L_%3_HO/]D>_T'(9P8@436W_'ZW)$4"#&=3^(LZ5?
M</9D#_[/^ROPSHQ0Q3W"@BAS.`PJH!0T[%-U^$#&-9%T4Z__P@J7RFX_MSA3
M4X8#.),L40A]].AP-<5@MX8UD^L!D-'80RB0?K?(51%<L%`5:SDT%4"52CM*
MUK)_H/6X1"EN\^V:&]"7)8T:LU^UUU=.AX4=VT&I?&4W&#_HJM^:N`@`%$O_
M9'>/(H/::92;'9FMO552["Q'J(U3[42=R-10W'ZA'%Z"S/$BI>Z7Q\^P+86A
MV=X]HDC>W7[5#OW?UE2P&7"2N^0K;$`7O"OI-$,/S=-DC^U9CZ)BQ94!H5";
MF++0JD?!E+J;4[4(X^IK:XCIA6Y-V<4$&RKLJGC#//K73)GT_"UW635,*)@J
M2-5X'%*^J_)4X]0U=++I5?&OZ7+Z;JE#0C5Z]HE;J0O@Y._Z+0@+=]^5B`(2
MR>;<,2FYZ+MZRB$4E,$/-!&;U#+X?C:WYF$]I0*8C%=HKG``\>)%Y2G#3CO=
ME^75"`+5*G_ZB2Z+!#3&R"NUP+FS)NMYEQ?YO%!-2?JX#KT[*+)Q">K;%EFH
M-7AI;'4`'CQ'<-<:)F$:3FNS*8W3<=[J:WF'L6'RN-A\0$@M<M%N&/*J6U+U
MSDD#N%Y2SKR(TC\=U+@,0TUM2.#9++R_./&W4/K#7%[`51^H2F]:&QMF3F)%
M(5HCX1*;(612H3WGLY_P3M%I#SJE19$>`6'T[>>`RLGK\7.47B!L.6DA'F7W
M-N$^PAUHA[&C]4Y-[/JCW+O&\TZIBY<S=/S#P%?E0S(8,8!@9&\GOOVONOA8
M3T^@0G7@J3\GW5+5&C\=??0O3S9\JWM@]4UA#Z.SOG`.DV$51"/LQ!&>\SXH
M]NBR'F!,"(!>PB!TCL^>ZG'^;^"BR-@.DK@:%IVXX)WZ1%GQH%3:^U_)0J9L
MV@I)7V:NUM[YGV%?OT]HR&\YGTEZ*63WCMBD:/.9K"77WH@VI]F&@0/I:J00
M(Y8RI,\\SDM<-"%Y)UZ<RQ7IR:-TH>!!/0LM^+401\I:92ZV#RYT.$8KIY4:
M:1:J\83D.3OA'35?8FE,"NQOX>:[CIF/9<"K![+=JP]\=Y_X82P(<T:,WY4_
M3DTY>,28K32SF22X0F2_LU:BP-?"2-H%^B+RA5\?FH,VAZ[&'2X$\,]/WM&C
M;ZE#Q82:)0-F7/;Q'G'N&U@*S'2-?>I6^:K^QTZE`*ZG*A.Q>T-,"&)WTF<:
M]ZXM'2%!=5OH&X&/X],51#L`WS;'>Q+M)\I+T.IK;^/U,7V$9@N#0T*#XN,3
MNSU@,4F];5TP*KC\./0`O7`P7T";E5M,1(I+<E419`D)=M'[0=L3.F&\2OYU
M-VY'4XE9M4/ZC/;GI$SK4^"E?2)7Q(EHAA;].ZT7)]\Q$K*@#"G>G*6_N"+P
M_^[ECHM"M<[P,F`L50QXJ4BB+^*U<Y;J;>QJ&<Z0T(0SSSBB=5DT[1#4U#$&
MSP[!]CLM/M9D'COX$VB/+R,LP3MRD+N%6<(B%J/PC?@6R-\B_>>)H_8]V</8
MLO4GO9V.OU5C%(8RIJ/+JR*(YIFDQB_DHK*OM/"W'8=+6=D>V4".W9PO%8WJ
MOMR.1+4$!2^9BM3FRD/;>#(I(]4>=.-;?.]V21TOV-IV[IRFDH$!-%8?>E4N
MLN<(A(2>,OW!6^LWU=@YHLT1/(YN&O2Z<4<2LBGN"9AP=)0@Z3GC9U`[Y99-
M/="S3<V^:WF,<U*2I@'AO`9]M^M#.CVWAAR'*^460P8(FJ,`J?[PY/II!8S8
M<4:Z[Z4-C17/!MPU/#7/*"C`=/3W<`O.HEY?1"HNO7$B,W"F5#I!:H8JKKB"
MF#1HX4XWC[RJ@![0J;'B&KO]"<^%E]_ZHQ8]U<!'0W8&6=](_IKQ%S5MK-E0
MB%)P$GOTDTQ"C;#)"9`)HZ?>.$+:QJ*-W%/]2M&%$6P<-5HXQEGM+[X"GXE>
MO8[-UNA8F?_,X_N5#125-P=6PZIW"16T%G__-X574YEKE''WV(FMTC^6#.,_
MPK$50:-\7TUO723:BBQ&K'DB/+9GHC!JKEOZ)0GZ,SV8>2*=#"5>+4S*:UGJ
M,8]_A"U1DOW%!'4--2:3<\<0AK8[:M*X-+311E$&/$S(_NCX-*>M9R%">$U#
M6#3Y`/Q;FQQ8*&S3.TVBOY2G6,>'N\W6"56I//TFGQ.4-]J.ZB/EH+N9D7NE
M1:Q(_?K#->FSG*[%6@U1X-8:,L**3]C)NJJM-#^J^CU66(Z?F<L3UIQBV5Q5
M'YQ7#7FTSX1V[LH@4;M3OBK%#I^1W5'FED,@9X?F>6-=7L[IG0BD9Q`$O&9J
M4;[NRQ\766&YTAO(_NBV+-RS)JV-!8)^%3Y),!G([1;W^T3W'8L%ML`_C7K5
M`LC,IGWV=96&I##MU![[Z[/CQWW2SNK\A&,PKMI<X'C834(W4;O@(]UE0^:*
MQ`&2)UH'&2(S6/^5/^T)&Z4W&WVZA*+^>"]5]Y;L952>\E97SANC&I*FEK5:
MO%@#G)K;14MQXY=!S>9F>P$8+08D/W,HRV#^.*:)+U)-$N_P)`4)LX890%!S
M*`^NJN1WKL44B(DLI\`_4/FZ;6TP4U]*:77]]WF#*"5^E$YZ&66QZ<:+(&$K
M4GMJ#!ZA&L=3I0!$0"UEPC"V:\RN'D>[WM(/6H+[NMG=[&^8HV5]3[+L34K\
M1[(A'3E,U'5%2@QA#:JE%;W6`&[[]=\OMG.&&F=",@U[`76;5K`4OWLE-5Z[
M)LY3P5M5E""5.*W\:MXGA71E][3F;HR#H!5J\L!4^TT^H="FHC,&N'TZO,)=
MIFD]06;U?8HM4B;R,M84?R..5(K6::@";3))[M(MN%0F28U4,G@33IO+A@M,
MW^P=7/QG%"F<-0H<P-W[\Y:[@MY!<4]AIV,)$AT%[JZB2\:^-`.#$N'!W,BD
MY:U?M).`CELL]9LKGW:L:4>B(V+RP@S^MLOT*QV$?[7ZY!T'@ZHJ>C^XY?<[
MBMS#,#B<48),F/_7@.$?$LPM3J$@//4/C,TX3/]F6Y,P#M9VO9X`(MG;']B7
M(DGAQGC8@!BM6-#%)."NK4*R6Y%;Y3T+B_'G/*QKS"EDU(@NB%>^\SJ"#RE$
MF,AR0\M)>I=J5,!F=WN;O-N0P5S$I5%\3E59[B[#Y]7L/H5S4NOS^TM+/\_=
MQ;6GV%SP94NSITG`*5M9P)[@Z4DC.75^E%82.YMW58JJ-`X,Y93O0FA4D!D\
MP1;#/'@PV!%GH36A9"I(%OD"H615&2(H2XU[Z)GO:W0E5Y;RNBI4IX\TFWVE
M(Z&AMPA"5.<9J"-%TY/^F)U.*@D806#HWMH)&4G1[/=ZEV7IL;97AJ8Q6H=Y
MM;8$-.I10[DCVST$'^HJ4D9.5SK@$D""L^AQ5F%I;#7T<G!IUY/R!70JVC6Y
M`A`F!!Z$(0Y0.H;'V]@$.ZS"YN<-;>'\NE+UHRWQE'VYG$,#5?AW*FBHVZLH
MJ!O*55'?MJWJ_J.,P?OVFR_@+]CA,V*7Q'BIQB`_O:/#UG.WIB@'HF/!6]&"
M+(QYF.(^0&<R#KIG6E&#`R-G;H<G?_N5O^AMMZDQ1OX=$*(1*?8-Q:NJ#1=9
MITV*4T0B&&&>?05VI\I.E4W,A7YHB1\/G^K?N-#<]%'46^$,E,AZ:?7]40[<
MB966QEF$_.QMT3BSAP`E8/DBH`;3^3&VQ_(-KKAL+GEX1]!$.A]1#>.,!8B!
M[?`N:46$DQ1U&#Q`L%5M`>A#@]+*%0DMZSQXNLFOK%->C8]=**63BD4+K@=D
MOQSN98[T*`?EIICTY9]XY5M?]Z9B#U]#LH1L6+^"V4A)]GSE1LDZ)J?B\$;R
M]>QVR;A6UH-?FR\')"CO.(1C+5V7YN")EFC=O'!@;Y$S"(,!O_^2G([C"L3Q
M-_5$VM(0_?2_EFGJ"P+9"1>\X*/KJD,U6/X!6NQ)Z[Y$(CHIPHS&,"JLQSU9
MMZ:,,^FM"ID=/*_7'R%G26%O00259`R2QDL_?/%,Q]I8F:*CUH\=0$NK$PL-
M-F?KGCE`#^CJ2M.PH9<$;MHBR$S9G-%`G@>^Y8A"H(AS\@'E$^M%S/"W'^:3
M.^Q(P`E.\+R*ZC_S\Y`4+;]SI>WC?]]V0E3\<9(>HB"9-#W*SF$)#4.B!RF3
MH]]`)5<HUEL_[#D5DKD+8EVJ9=T(>4WA'3PK,7UI<L[T'J`K$_$8B;B`C5=L
M)KC-XWQE`8LXG+"84+4/OM:"J*:\C<`5-;'<<FE5:^@;7FJY61`Z8GNYKV&,
M7_Q_75$364.9HV](@SR>8IQ+&&'79SN"_W9NV:VT;76OX!0L,R=K@U:8,_=Q
M$<^,,O""UH[-F:+TB=MPZ,0@%$=]TXF<4/$.PV:]J*2N>G>KA11Y#O78N"6L
M/KZT*AM>_F9R`1-),Z",VB[I8!88._'4ABTT29J,AHL;#$,_G'3/V.J=.T!-
M-[%:'<=?0JQV!R?Z9\\Y6V[<(SD2Y3+;&*5Z'D2R`ZQ.0M]K^8I`'L0#]*V)
MQBP*DC5E9);1C!HT6>HXEA`^;BW2,J2(;0KARL'*1"#&#4:K[K;CYJ.\8BH^
M3Z7%59SB'&8;F0VYD->7*:2R*4D7<BIZ>8Y32LL0'"8Y5<'*8"1BXRNE`T5:
M_C3&H[;TG<"QPQ2,)<-%V&SCQ2B+T.]O2.MDT!B(G#1F@J`R!+,DTS-DKZ`U
M\N+>_3D^9X+6^M%:#@1OB$O/#!GHY[CTH]C,(DWN6D+=>S;)"B;SS>\.WZG$
MNL+2]G3HZ9K:O;=DV=1V,IUH&4+=Q=FQ;*P)[:PIH,,X2%47)S64[?05OKLD
M/H=WH.\]7Z%&F6HQ?K'X*\-JU&<[-%'5LSY69*RPZC@NY9$6D"8JDHH6\;>I
M.X!M+IP2,PQ]8Y./<E%O9)$ONW0'QT$2*I4\DQVP+%YO=#F^#QT%A6R<<TEU
MN\=FXF'T=-Y5C$#O!1V35W#%U3J29O'KA"1TN_?G6D=1C3AK#"MC9!57)ZJ%
MA6,&_1<*E-</[85Z%J.1)ZZT`<,ET:$'-2LW2%N2)B[N-`8@^_B6DN77)OT_
M?UL@\=:\+<*I^;ETV0ZU_WVI753B5'^<CK.?X'S^LX]+,;[(;Z/<QI(M0.R7
M$@6VN!4'O]G5?TY2(%6T1LJALL*1FX$'M8\LY#!?[F)?S3RJ$VW5%GM[UX%2
MQ.[A;U[OTSOD8$E>OU)PE5B:/&=11:FR5M$4QY=*978)?:[?<R2#D^#U%3CW
M<M>'K'.?#P*7G>(VO`J=J/N+A#O@W?9KDU0GY`]/V](?D!824P"SAH.W$S65
M*S?'/@Y`CA4!SKCG->2]/_PM.3=JXH[3+LD;(LL7=+H#,0])O,M;4VGE&9IT
M+;'!V(84,?!:%*^4QJ@3B="PZT=,Q&XOR4M8-^ISO75X)S#_]-([V'JP!\5&
MRX^4H5D+U[X6=K+_?4B@;F;K7%NJK.);H"AS\'RT!":$@P@>K1EF"#:6])`X
MCT+,%)I983J+:HT^E['Y>=R#2'R+GIY@=X>)$%$E$WR3PVH@@MR,UPN#D$F#
MWX%V3FI'%.U:GSP\SMA=RIVWT_FT<8>&46Z!.0O<XW-D+)Y/:T[Y1D[FK-AC
MM3".SYU(6Z4GP[]+TNS$:K/O9(=48Q0M)?*$L*0URB*V(:OD*RT+YK5F#J9Q
M9RIK.@;UH>3=Z7OQ`O=G(I%2O3<'M>F*BR\\A4''*58P=8];1;1X.$'Z:<61
MN8A=K0A?PQAN)4=T?&$+&5#O:TF,5.&$PFDI"JZ5HJRP(9.CDRX(0.^]*RS$
MIYC41.U[.I?4&VWKQ09TXCH[TTQCAZ^"31;+ZU1IABRC8AV62S8DV@!?Z"&C
MRN7Y)()[Y!^<BP'?[P`O=-(C$D@9W]884]'MDGGQJ?N7I!QH_HNLA:#ST'A/
M!Y?PI0-F4_(_]L:)ASP`()CEKPXK)2&5"(ZW"3F^:[[RG[[SS;9-=+/R9>AD
MFVVOUGS;K.8)QL"2A42\H&ID^30)(*_((LV[R>]C>^U&_ZWBY)[O$S)4T^I[
M8N)*??^4F=^T95@/R=XF(?E:YU>-!S.&E,NTUK!=5I7PSNK)>=QAS]@N"3I?
M=;LI.Q2*G`<$=/+P8='@V(?0@NE*(#[D)57*@-#)XH(M;:&TT;+,@A,$T=9H
MF]_@V"\?4$!?ZC$-@,AVE/W6DXD.R]O82<N6O5W6\RY2DM.ZMV0?@6CO($8#
M(AGSW)+"+(-9WA&<8QH(^%09P`C$C(2LY?<G/)'?0!EZSL)T8RN`T6PS%&H$
M7-[LA3=7D\Z!(B!([BN4X>\/M[%H@I]FF#FZ*IMFK^+D)+HOF(]MDL9,(_JH
M8T>6H-]D9_BC8;E%/0;^R=LB<QK'.WP5VHV82?@JRF[VX9[B8HJS;TXVQ"HA
MK/Y6&I+=?]%-(Q/^+0%8++:_O.YHAM$3*9$1!A5PP[/>S(D@4GV1F6WIE$4_
M@*Q-8Y>8\PVEO<=1\!`6KY(`@)FK\"'N`)[('7V)`4Z"GUUE=C(IIOBCV8B#
M2!U3M;)K;`)<'X[HLU:@MYE<@\%80.^^,[YHX<M]S)/D).8A_=7H6<#$#RM8
MB6[D-,QTE$()?NY<K+D_`/%:K!@C&6BDPG8^WWEP`WQ1G]TJ&?5?F(F2L89\
M`)D!;T6!*(O6D*?#PR]<`]O:5$BJ6HK=+)AR6%]YM(!^0@2+$"0"%1&N]5KI
MC>Q=Z0T%.^.BRE8+$,\$30CL4T[0QP,7H[7^"<#502UA;\;TX).IO/F#5E\'
MP`>)`]^\_=8<I)&P_JDQ)YG0^\.4P;0<CJ.Y4I\L;8V[73RG;<SH-IP5!U?E
M%6/?%YZ`:[%IX:^N,CF8?Q(LIKA[$Z>Z$!2"VDXWJHT"FV*<\KU'0GIT$-%"
MA39.V#)5EV%V^BNK47K4C6WCN_#0?^(/+^9C%J1B&EFK^P":1>O+0"R],*)G
M0IPC1$XD^:B+RI]>'CTK#!4;>2)_CC!-^9M<4L9)(QN%"C@!]D6Q]?#8[LTV
MY;_TUNT5C_\[#:*9V5&XD/Z,.F[S3-C8@,;)?(O@C6$(!0>MFZRON=IR53]W
MOOX!#./*D`U_HT`O@BR;5$DSCC%=AOM1F'L?T9]&)_C.Z_!+;1#<_S?;AE.-
M#KKY`(>&$,<GQUYX-[MS\^7(#SD?C"GEU2+K;)*H.A]T<<H_XX;(0U,)AE#;
M)W>!;+9)&(F-7]S)&&9KRLPF07':&:#P(C0@I%+W?9I`89\]G\D1T]VX<,!/
MG(<20J!@P$ME6W-`H.%@Z,4F0+2:0=!PMJZ?7?%I]NS4P[F<9JD$CU4YA!_H
MM$DT#I9`O5:XQVD:P_<H7(7"_&]I$]9.*L&75OU4<8<J2NB,#5_=0HUZX#\6
M!XGCF%6C(_%C(]8`R<.Y2..K0.V(SVD1G"^G/=PE((8<"T:*[5Y&`4M/\B7P
M.[6R?_@!90$HLT@F_OIEY173.<B>JE@=R,W!+_&_3&G=DE!_IIDV09,<M26M
M):Q-._7V.%&--)[+#<+$;-^'BUTR_WVY?MPXH>8'[?!G$&-"KG:IYFV;+$HG
M9M47&AP,B*W\2]PN+G-N4^.;!.V1YDR3QH.+^[%$3#TT;VC:!'8@C%7]0#&/
M-U>,IA]BY\,?CF2[H34+>=)M&S."&KNV]#`KX#WRVF81Q\+)(T::N-%IMMM#
MO?U"\R[*,&Z*6$:$S$7@FD=&XMK=ZW4+JC;XK-3`[PQ>ZF^7OW[`A0K8[L:`
M59['F@G>S-FU\/2?*V$'I\=ZXK\[GC7[='T^_%!93'*-U@NMWI["40NHS"$;
M;DOAB_!TM_TEE^_?%E#("0U@\J1GB$-;Q_C'W5!F'99T7/%?3QI>1X#(.A^B
MJB2=2H;?-=/)?L0YTLK:C477;6AVDB4N-0ZO/!KM=YJ467>W3%.+2_6>!X++
M+@K@!]M_=6AMR5[XF)X!?/-J'8&`F?:TRN,#J9LP@>RIU)-EV>6WE@B.\8U)
M65KD"AEJEY,MDJH2%1$M^[ME[+M73]LTH1P21\[9/=28&\[4.LW5^[[BH'XH
MT(BTQ7X4^U;/X%VILD,0!/]_4H?\4T5G%2\/5E@&ICJ8!6M#:M,P`M/90Q.7
MC*I/5AFE3KU)E"#=0T!F'8+:C.(5&MMJKEF4]2U70JN(_]7]WNC3:&4Q+%SW
MZ(R.76$JFZ?.QY+*)(\B7@9R)-'2Y"QJW-G1=^%^_XQC19U=&^+0F.UI-@P:
M9+IR_5*)\$M;266_3+GHIWB8OE1H'SH%:X*N-$]!!A6Q\T(REC-6&W_HUVAS
MIS0&,AIO%L;/31WT.9:;9<58$=2BS?%IMZJGU:L0:1:O4R_1FT4E.*QQ'NT7
M?>1G0.R[=A4J-Q)=7K:M;8VZ["WRZG3%`S!70(3_B1FM;QNG(C$_''O32>`L
ML5''`I%1$SNR+T8E&8Y;L:B<);K7D9M@B^B3`@8B0OK!T?NJC?1<_M=&\DZ]
M^<FW!#6L]0J;NGHNGO3X.#8^F#Y0V3R95#=3<_Y?`%#9IUVP0:R*V(^#C"]-
MRRFN>@ZH%PH,#JO;F\'"-5*7],9.K/+IL(*-]>MW3/C:08(32O?R-AE"J`[!
M,?[5S4F\+Q0LNV<1X3=^`7S#V_-,-YMP)\;]3RR$B:%\W"P0V131:S]E4-3$
M)C)K"=LLFZ=ON\1#;I\;+QWKU"KQKE^A'Z$V_S/#?B+#,?\H6D&H&C&\`::E
M=B^L$O*&SM'R@&&*[T.+QZK"]/-$9O9!D-L/Y8=`/(`\$/(_Y,*.'=L+#F<1
MQ":*^-W5R:Q<Z]=S0"J)@T*8>X;BO+V52C':9&KZ8EF6M9=A5F.Q*R'PY:"\
MG)#MZIE"!%QK4))G@^H>'7>M9*]W^$GXJ)P,$L&'5G_-3ZD[`'2=<T.TGC8[
M71XRU]P;%Z;0L#6=2-('8-976A4G7RF=>A&ZNV&('4>ARDJ1IIPO;E'G=YA]
M9:W:3SN6I59?,DGT'J0S_8ZKI6>>@_2\7"QO&(Z20*L[WVHFV7;"#A^AQ[VS
MTC$4^WC^SIPDYES<O>.2E;U_WG=;O8I)4HIM"+*5-I2D1D"ACM4U4O52E30V
MCG3F'7H3!4FX)"`&C[.>S^]Q,A+9D@*I"JTW">JR+3%4_O9T5P2#_P(E5^_I
MG$6VF:/<TZPT88+G;-"(Y!6)4VTPT9ZP#.N.&>"[-MU*GUBTL#:,UNFS'YB7
M./D%F.O0H'P[["ZWZS#5EZB+?&C&4G:WGHAY;`\G[2OJ3KW1QBFSBM>')I7B
MH!@.DZ>;7EM;^6U[/7S"*VVP+\\,K:T00G,L5"PYURUF^,$L'6%I[-#P70)W
MOV9%:!,(@O/@VX8I2)$:AYD'!L%<BB%-0Q^QJ?Q#8RN\95LY)])]G7"/*&JS
M(9W$'#\G2FKRY`18&!,;)B9ZF(]#]I&7F(R[('38.FI,6CTRVX<N"E]U\.SO
M!8X3)2GXH*C-`U0A\43`D8T!^2:#,](*^<DQVFQ+T/_/X#GKT@Q$A/]W8=7Q
M;O0LS^SO_LZAVZSOI,!96O)>;232?A?=VY;E4&$\$EQ[U45_X+_V%O?W%O5)
MMA>#75(8!U'PKYF)1@#X2H#!!44:`]NWY6+,_1H$`6K>:W].QSE]/N`Z"3VR
M;S`OTFE_?IOLJZ'&WX;ROT8/H>7U#Z.#"6`*^L\2$PYJO;.2K+2WJSM81!04
MZ<;W2K';LZ(/I0IG0QK($4_[09D_^\ZL8+V5V`77MA_3F\IWX\J@;*WO32E]
MY8-O<!C!9VVC*O?;^S/%=X]V#^QA9`8['#17B?,*:2\OXM\^SPCQS2[<U\_M
MXLN:;[RT-&7O&!:Y)``XR=M1QDJZZZ*FL_!".I1K1E"`7B%6F5I[H%+A.ZMH
M)V?/+24VPSZE22SP]Y$/"O:#Z)",#USS2,R:;_@<S3F%$;"'%"ZY`T@B*F@C
MPDCGC#X<%EV[5D*[&EKWTZ3^^AL,.CX!4`F36:X9\#0*#A'G+F9>I7KRA/QV
M34'DSUS9RDU]#D*6W6I*'L;-6$@<S?4=GHXR^,OP<?,%[RJ]?1UC=)OW;[9<
M_;,6\S'RZWQ3\S';'[EY]4BX!LOD%P^M(C`HL]8OE87Q[Z04U"A.1NG6YGD@
MV7Z9->Q!LWUIWUK/>V1U9XL`#A8X?/@(Q/=BE;K<:)FHBO=AHH1IR9XX5ND7
MZQG=J---VTSTOLL#;\=FU:!\J/97J9X($J@1JBAQ\>E7@/P7K3'>Z2&18*JH
MRQBX.Z5K'5QQ_WBW2=2T].>Y$<&^@'1B!J4$;W\LG-*4R1*>BA,IYZ<-8A8E
M/!%,;*C;BQUC#[[?DKM"HNEDB$_L#'D64+'G,G<)Y]4D$FY,<*%=:\]>>2(+
M@;@+Z^CB=L.O]A0*PP)G2I[1>+-'WQNG&'WJOV4E+Q7A3$JKD1,;J'MRJ3GV
M*^"9SX^X=1@Z2A8"HAM7G%%09@D4.4L@+78X,CO%?)YSM.[\CN*='H0*-#LU
ML4HU]3?I7WK0;Q63%*@F-?;H=AQ"=.=RE:!B00N6T025.$JG,97;JBVDJSD>
MA7TEIA8V_2R$J<HTR:_<_C'[[1%L"_!=[`?%S/]@EII3,RI0!M'V#8^1=V#G
M9V3@&"(`4`&Y58D=U`0PU]#5ZIRAJK`+W,G("Z42A1BW5BN9.Z!&U1C(F?UE
MY._ZPM-`/Y8<AMZ8(V8QD@3;70;689?C3$K?NG1F_)3N5OG&W_/`*$TNL/;I
MM%9*>9>)8^AV6<PC$6966Q`3KC/W7-Q]?/ZPLOBD08`U7Q5GNX+A._IH+U.>
M>&9D_C76OG$2=?<=74+%;&4LVFS,T<\A2!DI"@2I78F*?U_9OKCOU/:.HUW^
M\5@1_K*?@TT%_,@ASJ+4UMI]>2'UQ6:B,X(SZ##EYLE/*([9$%MU<A5.:AY[
M(NH@897MBD2!?3W\-BU+.'S<KK5)U+:!T)+9*&[[4X\:7.&!&7MCXY,0C2Z+
M<%_@F8J,ZSY`*HEII;'85</10I"HV!E&3:Y?-"G5%*/`:<$(]X&,_NBX:::Y
M%K@28@S]0A?K<W"AJ&6>4UM\\3>_/)!=;%A+NJ7F&C&6VLK/#/R[?A!\)3C_
MO?F$4/#D`VXH3KB9?FPKWPM1#Z[";/^MVG1:KR0\RQ<ZV(_)VL1GBER<!MXZ
M,=JU<)FG,7WN/NBNZ@03?J/*L^@=`6Q^?Y++UMV?0(=UU761KI0RHM@!AO9!
M_ITQ?O\-QS50]\[DJS=D=VL.1XLQ\<B0?GV^#8VZRFR#G\F+HBU*K24@P\`.
M_EA0XFRJ:+Q:ZHJ@,6U&LH7+@)X"GY3P7]:,A,VI>//I,J[X7;YGVB\2HP#X
M/F8S/3#C%(8WPR_QE>T*FJ[^6@"L_='"`SAE'J"BDF[@M$-8A?JC_,)U(_6#
MAFPZ6[Q]\GI%'6NH2'=VH9E7D:@EU'#<8B42D!!:#`CS%G4'^S:!?%N+E]C(
M684B-?YL9>_/)*E*".N>,D&8?;4#2+O3U`F`^=>5J*F%FU2@9(EIGE?TVU)X
M\M9=."L5A=18<I0@!A591^/Y!=%6K"8I!)(_A.N'I$,G5TNA(2>J_,GNV"1Y
M`*T/1Y&2?%*NRC2,`L[\K&'!'^0"B'PB7VNJ5@JL/#CPF>RZ'8IG-F)<ZU-J
M'PF#NU:#VZ5$4!]<!)K'36=8N6U,1&TV<S;`UA,8A]MV-:O>Z9C#OKE!_*.<
MQFMO#,,\;T,3H<</#11^X'L2.TP@)MQUYI\^?R1$IF8O!7ZY.:/Z]0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO<&QI8B]C;&%S
M<RY&:6QE36%N86=E<BYP:'``````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`Q-C,R,30`,3`U,34T,S$P-38`,#(P-30S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B`@("!D:64H
M(E1H92!F:6QE(&-L87-S+D9I;&5-86YA9V5R+G!H<"!I<R!P87)T(&]F(%!L
M97-K(&1I<W1R:6)U=&EO;BX@270@8V%N;F]T(&)E(')U;B!O=71S:61E(&]F
M(%!L97-K(&5N=FER;VYM96YT+EQN(BD["B`@("!?7W!L97-K7VQO861E<E]P
M<F%G;6%?7R@G0B<I.PH_/@I!READI4$=8O0?"PO)3-;[1<OW%RR1#=WOH<Q;
MH-*+,U>-)DF_69<6AGHHY8^--_U2%Z\^->12]X(PAI`8WJ@<R;FS3LCMR95O
M,YP>U9*KX92FB)V(14AD!B>CJ!SH=,L+-EA@?2^Z?P*E1B@FZ,?TNH;T'X3.
M&<_]G)0$:WWA*!G4!MD$5Q`1)S'G/:',77'+L#\_GLW>.E9L14+7:YZ&8&FJ
M#L"'Z`K`6U\(_*+;'R<2ODC^Q*[A"$B>C][WASG>2[<@1\F5G<(J;FX$/Y@Q
MJ2V18%,TN,O\PG^K_Q,4M2^[S[36$>^.A:8,KQA7B./<;(58*X8AG)O%F6MH
M'C'+F>NJL$(09Z_>):Z^>:4"UFM7)#5B?G=WM6NK`G(5671`+^T29;ET]U,?
M6U&!<"6#"((TAJ0WT^+)9140O(F\:1&.94H5LPZ#3?Y$P>MH*79RJ+!#A2Q"
MUSC.TI>$30#'D4?6L\-.-UN5BU*OZ!JX*.>G6W'>LI7=_+G[+-%L5Z8Q[,;1
MF^?#U`JMA=P=B;HW\&GZ%%.0M3AB63Y2#>S',>WL\6PX3-.&2N9X+1+N%C78
M`$#>^1ZMSU*ZB2^6Q'QE9D_"Z'90W97!@'5;6PTW7"=*+?F>1UGY=^4%(+/2
MP4].]FPA'593GU1JC)#8L+[E>"[SCY.H&P7V3DV$8IL17_H?EA!FLB%D^-1R
MJS^[:X*+N8QE[=#ZHHE7PZ.A'V<'L:4J!^JD`=`H)S&'E0+.,&57+;&;M)$W
MQ4`8\+=23S;AUDB8-1I`C4,B[2+)!SW1+`I!:AK%<OSYE%A=@,>J$?"O+1%.
M_71D1'/ZL1_4S";/+"<T=H*-WGCM6M*'PUP>H3M0/"N25P4`G:51G[1+<KQ>
MJ-Y6PPJG:!1DL">\=\14$3MIH!Y81KE$QNV3@VA@D.8L@;YDX)&Y_7YLUSD[
M+ND"T@'F48/B//=UE^M-=\,4T/9R,^1B`*9(N?.WGVL$E[5I)FB"4G;+&5AJ
M=(C0>M.J&)X*K]J[%##1F,ZPFVLF3$%0;T]YT5/*`(&$+N)KXWH5_7I`U]MS
MXN/>K6KR5+%RYSB^*#--7QW^$+$V84Z9.B".R1+G.E#O*1(9Z>BC92;B)&=&
M!J(;Q[C#Q17M&4RQ6LROK.EU@>%C`[UJ7-]XZ`X';OE52^L%GAJ@2W8;(D%U
M:`&8JX<:&O4!Z9':XUTUER,@]0RW*LJ[`#+?.!J[A>BJA53P#I]`R[-SVSR4
MV4UYIO;+[3M=H>(3"UT^EU%XLD/V-SV']:B%GLS.?^TUB4`H^GL$AM)X?Z)`
M-F^?6=1YOE>V98_C#=ER#(U*Z>FW#*(F+C4@-O0BE6R2?[KEO=9GO@SQ.S!Q
M:LBW%UX"AJ'/KD/`52$`@&XHZ^+<</ZBAZ`-WUOVQK!]J(F<2!3)B[NDM1]?
MDTA@+0=B`]9%Y>OVR1W)@SZ5T:8DM,*8D:2`@3"`Z-.)N5GUP$&D5!]OJ8LD
M;).O8&D&V9?5])I?N;!D^Q[+/MX!E9<,U*:^S=1SXP8/#R5H'>/,=6N+@/R#
M?XA&--1'I/+JPR-;TT(Q<*7IPW^?K;8M*[7ZZ=*L@/+"6_F2'<&#XC\;5OG7
M+?UHYO_740.V>'O2E?AF[M[@#)N>4ROT"!8E,Y#$;!T<C:S_%J)#L4%5OJ@<
MCME>`3:H0R]/4L4%(A^='MH$0JPY_9/TBYH17OFI?U@D\#[EU2%=4P1ES;;W
M\F8$D.PQ$3=MGXWR:EBG9O@J$61DHV1)\9PO^24'FYU2":;'PAQ$O>&"_*(/
M]N-RGL^J=5*B;X';8/#CHQ_<U6P7\O[((O:G>`WABB,%@929$:&<(+?,"<&E
MMZ.FEFY/&IA[,119]\#F,B*Q2/WD+9!ZB:S^WSR'"T/"V`TH2".W(),Z3GP+
MR$%>)LUPFHB%\W#@H@IUQBT8U8TX\MSIF;CL((^'VY:?C5"":"IQ28CZC&R#
M_?PJ*#7ZKPB5H7>S4"+`#,;C*2[]KC7A,+$6"^[Y6(2($7,S_9+(W9QT06@F
MGT"U2.+C&KG>5.=CS`:R[06VGK90NP#%RA[`@?/$`":T[,2-5[=*$&)GP.H@
M65'(UXBZ\HE,5UXD9)U`?9S9^*&\4C8/<'/ZC_1(]]@KT,?AQ&`U,9'3M.[O
ML":$2Z2OD>3AY/#'UK=8J]$X4T("Q^'O?"U=?=OP@>#H/G+3OPZYX410_5'P
M#.H"]S2UP1N'I/DB]\<5`UX+1CMNK[/+?"F1M$%CM.;1QCC#6(OY0%^'I&&#
M70L_?HO,:'!LSQ/-EK]I"N-RR*`+YLV%#H+L]5$7:>UK]2Y6ZA#YRJ2SD5;"
M;IZ1>5)QPH;RLZ7NN-$OP"R*L3;-'*4#BMK[U=/!.MML"K4<2`?*B*_[DU80
MF8#>^1I%S(FGCLHSFK*:1F%+D-FOH(X!!^&N9/N)P4=@A[G0H.X^;U%*<I>\
M]D4[KU6<%24$FJN4<?!G-YLA\?0W5?Y\KP*.>H!HQE#W/N8!IRI^G^8HR>,#
M.`"5ON(G[.S\[>/H`:^,^7:/Z=//[TW!8DA=NAF4U\/TZV+M`M2<\DSL=L^;
MWW;R]?3,1P?A4T267]4$XN(UL%*G)6XYCK7<!?L/.;DZK+E[TK7E>BHM[[%L
MZ+#A-,?&`$U`^>O-0ECO><AV'`#[YD&<9E(AD(<>EE+>/'2\DG34;H#+VHQY
MT=1+02?K#YLD"^RSG](9?-'+TJ.@<X7`BA,<=31T5*-K?*1STXR\7?"Z<A6,
M!L)T+0)H?R.*Z.7%-P*ULX=:4MT4OGQC`<)"@PW1,@R[?DU'0?\DBW8$Z)PW
M-NI*T2<5X)Z&Z)*635=T;\1"?,A:I9!0'\>JAG75%L!D`PN>M1V116&CBLF3
MN>D-.IJR[..H^*PTN^X5=0^BEISSAEA1EC]5RD^^.:CT!AR:7PLGTL$\CU\-
M:\[0?%G#2-,-RBGDXOX4#_)O%_#:01CIN@?X.E@MSLE+AH^['21-3SXFJ-K,
M['5+0>KU:F_811\-KO9^_JKF$L3H%5_+4H"+%#M%82S/VV-$%%1#U'.;S&%\
M\^JO1L@Y4;&D`H5WPFFUSG083)7=L7N?<E*IN:F_[--"?A[LN?2F<F)BY]2&
M.;8":-U3]$@-NF[>MG:_LQ2[9S0%K,LEE89XX4O&\X"K2%/Z?@$]1E419"1`
MS5`],(\WQK#[$K9.FKR.MK>"'Y"RJ!M^2,PZ$E"B=D`XT.W*UAO!29DSK-2`
MQ02W$"A)L2RQ(J_I>-]FA\>ZL-#_+Y@R^XW@L8VHPHX@68A6/&*\%.<&`F_F
M0<9AVGYA-73$<7Z%([W$_6:[*'=?U3)\4,Z!!`I_HP'-H!PAI77)LO>MEH)O
MB676];N#!W$0$>AGZ-^-&I0";#['7[Z1/FO6R5Q9-X>:6Z!T\63#A'(VP1)D
M#)]X`0<J?C;=DYRB-[_44KA\J4J.O]83NFW5QJ<>@5]DT@K"NC[<R:FK(@[)
MA,5F`7+>GM\H'N"`8(?UQA)'(EDS3E&$Z21]ZAD6]W@6:M^&<EI#UB.E_Z2/
M&7A,^<@<6DOXZFFB)LF'^SV,8RYN@E8?J#)\/<XGJ9];KU/1?Z6&X05DK]QJ
M/W]=G9%'<"5?JQYT?,.7OC'?3<O5U3U*C0@D5@9G,_S0!U]U4WFX%G).AL/$
M$#RV*V3*FBO@F2=LG<]"OC[1Q/M@EL2'7MC-\]MMHZQ1LB#CO<.58JX?@2,F
MLD#374X^8M/[J^7?_8OGQK3*)Y&A&N[P4$3P_6!AF.>.,<.E[!R@Z%@T2+O<
MTVR*DIAE%!:_E?08,I'@SAK>1EY#+*+PC<N^A<HZ-"R9C*IBD(9#BG[WV&ZH
MXL7RE`;[U+WC5@YOTHXHXQVW(RRL`7A[FW2R%]]O;R5Q1B.2VZ%.=S';(`^Q
MG&+C?^9T#J5?^"506/[-O1LVN6G@AU;?>]]+>TNH?O;"<6P5@PJ8%3I#YG%C
M0?0-'X+[%`Q2H_I-H99M]^H6@G![8>]3%;_;$)JHB=@26B@R?S-&&>O"67:Q
M]=2+!_/<(UV;.&\,#!77C(Z7SY[$-^R[Z`(_B737W+.H8[KFZ=*2\JW1%&D(
MG>!+>/[#@`WYK4D<Z,AN=(!CR`!UILSO^@G;[\;K,C%-04:SFD?C#5^?Y[,1
M-R3"J_@:>5Q$K'"=0%O8CU+.R6@`>&K\$(E3XP][XT-;GNI+R^Z*,T:HH':[
M5,$]O2U](9"ZO<;`!?X(</QA@78NKM?%B<&=G=E^]12?*RSF*9`^0IQF)!%.
MPE#&<(/_.NW??;0_#Q'+Y4B9W72'\FO^YJ9%WDLW#1;9&0O!>"(0V!W(YJ)I
MA1?$:X;P1E!HA/8L*+;0P1Q&FY/\3[?]E_P5<+PC=X)$2-`#OH'?2^!B$'T'
ME9268_EPEM%MAQY.Q6^;-X!PT`QW?'?V/]]S)[OO!(<EP:TF4(VMQL[T!)49
M./-`/S^;RH/3`%NR19E?@0(]R(98*I-XC!233.QNU`FRYIU-_W?H"#[)'YQE
M)L8NVT5<@?K2BYIF]^U7NK\G7Z6Z-A[*X$0)^_=!',&SM),K:LJ9]LV+?CCP
M7C'MM.;K]S1N4L279_..V.B'">RVV&$A&96.,#UU-\4?28Q`3<5#(DV-#0!@
MR+8Q3AYQ@68IU=+PZ;>>C&BT1=5<Q&XP[6T.#DAD?&,N8G;YF3*22L/K8A(?
MG-PRSS0/1IBAQQ2Z^O+]!=0\"*34;_Y0C"F:`/+@"UZ"#(D<U"KY4C@S%<!!
MQK[8'"XQC7WS_XSURDU&XT`X[6F4YA\('"^.HI8)LD`-RI:8V6!DO6>]/-0K
M]'9Y)$L)W[1AAT+$.DC$=M3&-+\M0NK%)1&+6SS)6GTP`(+^A>G$U.UR)]A*
M*QJP16-^]C@T[!$`H4[I>$I:UKHS8[S(DQON*B2V:QGUGD6H^DDVJ-AH(,(/
M@;$%,D[,9!O$=B]^@^^U#UPF/9V*Q`_+H;=5Y#X\`).,<0J1::ORVHFU%+I4
M[[%FQ;#Q&Q1V'_HC+<R&5U))]L$U,:QW:M,JN,V$BM([IWSFLOC#;2U/=]`V
MRE?J6O'K'"Q*6=GI(F89'?VZ8Z^<C/KWWL+/>\,6I`?_XH5,(!@F8QD4@E-_
M7_W<$C0[!Z1J?BK(O>2VII0]I%X\16?.&3X@Q/MZG.@6\MFM=H24#[@;Z^*M
M3&'$8:ON92_K+I;`0CVWR#G?2XHM^4@*2"_NN&P+G#D@%(:Z-9RFWO0SQ?H3
M7_K(*"A?QDYNJ,J;G;#6^%)+R$F4L!1$0-3@#7ABO$K>N2"M69&1UTH#R-K:
MC1M1]JH1NFB54*^PK!Y[XS>V`_%PY86[!/A722_SD`,-#PJ3U!S/S=E?<%!D
MON_WB=8!PZSH3;@2VV*]&-33AA;DO35WB7$W=C7<<\:8DZQ7L2Z&_LN6&>&*
MWK+?''J63:'&I)2SC109HH".U,YXTTNF'!>/4>WQ6Q.-Z9=M78;W9*);HO<I
MM9IG%*=##C<T_!I1>EGU$Z4X@?0:S'/EFH)"]P0?!GB0S?I(+<-O%O3Y2*,U
MM$&T*<-?/6<".\`0L.355K24*AIB(+JD::7OR;@C[%\/2;$5J]8(,ZE]9\5>
M=MRJJ34HUU^'EPK(T-@[LWI]`F.28#D\Z=DL&%9_3=C1+LH!B1`![<BCJ-18
MFX(J^%M8;@:S(@?UT`.UNH*A6#@OZQ5F1D&,.8`:!+XO?P`<I9#S=E*J\*(-
ME+W&`W2N$G'[K_XD3PX18XLP:H]FV+2*F2"HB8SV5%?1E#=G-H_GAC&-1RT8
M$Q)),N]$:&^UJK%S`U<KX'=9O7<Z-_+\7--Y%(E]/0=(88(M59:_=O#N&3^)
M%65C[(!P+B1Q'OEUWS+D0+P2K.+$MD5,?0^6L")*KW97H,4F\8N.4_YQX%@6
M:\#'>.\FOPRE!Z6]L486$MNH:P:O=]9?22`!?7\;V+:>9N2B&C@CI*W4G&M&
MXR3($FSB2/+$`6\_XE]8;OIR'?6%NU-9V_P/\>,@+W96=O9APN",6?\*!-$`
M_=EEMK)TEV[8;)$8RL2X?ZX<UL+#@],J*S<TRAN^>+[T\BQ8WIF2!-X,('A&
MJT5_[O;_.6%3KO&BHH^BN?VV>/UOCB@L6.V'EK,6YM0TS8-YAAQ7D']O9X;0
M(C>#9R06:D@OIV!@B6+3V`CTA@T`S#F,RLF6D;PHE$@H6IUW\?VU!??:`#5>
M6"6\FS'(<2HREWK<N_^<_D(`K?VUZ+']/VOI=K*88PQDMHGM+YGE-[3YT(4F
MJI84?.(CQ]<M&M.@SNF"`5K**!H!N#\V4=EN/,;O.#=)^]EYN0&\O<)+C<T'
ML^9\1[;+(F]@`WW9A\FK>E^96=T#%[,&;IMY$T]R-AF#ZC]$FP/UF3(PP2S-
MWWGL]-]#B\L%1RAP,(5Z%L,.V#/(8>''LYN[J\3_40YUOB)#?(ZOH13#73AL
M'"\C+1:%*UXG\%WW]Q=R&]-</#MD:*1I,%<:AB,;.7XW4QE/O&PK//=G7NJ<
M$%#O?X8+^<+!!9.%8Q3N?0=.H^!8VKI-H-WELG"ZG7,(##>.Y00)N=X5=[J=
M#U,27XD*\E.6(=01_S>M(>SZ@0GZK89LLX=X.8DB*5[%%)31'`Q-O=8P$D'&
M0@]5_^]DC7%:J/:N[\>_+@P_MOB%S(W'0DBP3J33=<C7_)!H0;*P("JNIK]S
MD[\;E&\"]DLI\NCUO^=0?X+!"Z2QALF0[["*E0A14H_'[[SO6(&=D^D6"OGC
MH?&]I]5HFEPW1XXQ,(A;.)-\139B^:,+K.^T.\`U<Q3?*K,&MW$9D8V,G1R.
M<N/*A/?%BL]%*$6!7TLJO/9,X`=]V+B;Y=!U[45O$P053!L.1*:38W\:UV"5
M280`MLR@\E1G^$'U70$PJD9<[]0E]2U/G_]XK!?N(O'E=']Z[Y\B+5@#553.
M`]*8N/P?'1=+\1>HSNP21&!%9_T;6@Y'4H.R_WYIUS_J*/E?D\N1J2-.BI0_
MLZPV%5:FK[#*V2^!EF,/2U;%(@;SKJZ;ILUOFM4Y?O*:MFT[^5^PS/&I/.,R
M>Y_V,:@J"4KAQ\\::54%WDHZ$2:C74>..@+?F;<?*-*&`I_4NE"!?'?&E&>I
M'&XSZ_E"S1IKH'59)#)\`3I+>W&+I#ZO_HRPB:DGOLCFU4VHR%[T8MG.57:B
MZH=#,!EQ8!?.<N,S`'^^[=`JLPJ]:5<Q?Z*1[\1+2@+%_^E+3EE9?@4CXPKJ
M=J_WR"M&AR"XFK%VPC:MG3JH.0.@,?WO=V-2N1<_%G:GMN><*[BNVH:$)R8L
MIAC2%30VV@1?+F,@>7(,"YDHBT-C&3"LD*>P%&[>B]SI4.*+=*)?YW\F9%@0
MM0&U>V3_/0M\97ZDP-HV3*'B+N\YX%5P,'&>D_=?SG>O9>^P;&2/CDF(SFLV
MYE=SU\)Q2,($<DZ$@,KO+"D$Z),,0PC#!5AE[[XT7S<*"OF?&#U*GQPS!F5J
M=.:9]-WLFK;%?V[K;;]QKCD]Y%UOD#&>YXO4];=?7L$$U&E1+CPC#=QB?J--
MJ.%#L5_#\7QF%M]-H,OEP3@6M+XKDK8Q\#%9/X(5'T*UK%6#WOXBA<'5RD#4
M:'&-6^1N;?>*91./."@3E1($1_:I^0?08^@;$7M[>@G1_STF\_O%O(<"$J,9
MASF9R/&_62+Q)#!!O`:X.]?T\"%&P]<HS\1H=^3/O9J,`G8*!@%%/P#@**U!
M+_6!3,BQUV%]?!N)7[A^EY5E%PFT"OA*:%A""W3%Z1@_U(UW^R=2%68W7CT9
M%)P-ZP%ERG()QG!:MPG9Y_1PJ8-V?;5CO#&M<JIE&!F^<_PC6.XW(Z]^8\J3
M?@:0!G\FY]D;$V9'WJ/IVL%D+:P=F(FN$(SNF-7*#)31Z3ZCFT@FV;&@R5:K
M)`?%X6R[;?5DOPK,CJ27^:SP?6[797_E1@OXF]L[J5`6F0@+`FXL3I-D`N%"
MV'7$[0`@LG'Z0S.QQ59,(L_4*9[KY8^?^K4/NX=T(T?QFB@@,N0X%04&[!4E
M^94[0S_+76S'#9%L'\SQS1S#SAF*'U1Z<OPP%,7P%)ELS`LG'G&@<89/8<X5
M/PUT[:2FBN&K`76;`]7Y+X25(ML]-=]Q0`CSG/]>-46PZO`O)B`:7M'K8<>)
M@NQ'.Q^>\3U4-_RY".`(PD%8/CDD'@HCU#2GJ1!LW"F)6``UI(:9?]0%HJK5
MPZU8N(H_6<VH4YIR$YPI97Y1-7[IA8AK):"`*J,J#[V]6*1/24:58%"3:#I<
M!AQ\8?@X$FI%L+'19Q6TFYJ#GYT\0JNA)\+2AEO[;G":@:&.)KJ*[C,(O%ZY
MS76T"GTE.>RJ[9H)$^QCX913:ABS:8$A1+9)Q=N";RU`EGXL+N=7TF.;<)#L
MACH;PA%'%9<R'3\X:S#K^<_)I[T@RE7=F+C,1U$`%!"9;.TD:,Y4[Q!5?C#S
M.G[Z%S[(4?CT7$2Q<WI@F-,EV%:/D\X59_EWA</F5LDSD5.DQ=G@6#T+6BAL
M/ZK6\;#5`YZI($+Q'SPG5WF3?)5M52"I"/F)7-D:X2'DI(X46W*?F%0W^NL6
MT8YE.E=D^WI/HFI?9I>_2N!<N"BS7Q'`6-),E\D#'7JW`8L*QD0^")[7TASP
M$>)T^[98+F?_K::YRKKOST9.M.F:J=)M4^Y,"1K_7ME[;<ZS"8$^/B%M=]W1
M+F4+?#Y-P+*2C;(XEDYRH?*#>N\+YN)]^<]WU(1J_"+6SK=5]YSJ_F.(_A^I
MC0VM7Z;$2:1T@*)*8R@_XY43351@W(,&!^[D3F-$D72J*XR8JW=V/E^;L:*-
M&'V-/%0BG-R/3R&C<B#5T>DG?+2`QC^'(7'"&%8LEJMG)<U`038,!;1Z2A<(
M<3D-``QH>^*FJ781XH&J=1I7U1)+KL>2`SQ(`'SW\!W/%N)PJLOH;NG)U$_"
MSL).6IY01:DF%KRAVDU!_)%)42W*4H.&6]HRQ-HS&FO,NQ*-1JZZA3R0V%EE
M[MU891'SUX5.AL/,!F:\=;'NQ]9B$DA>@6L(N.`="`TD]2-$PWWYL9"0>=^S
M<O!8+AP2*5KNJQ%;A$1](V/?Q'*R7BY#W51R:[+9I%3-%7I-H3,H&MHTB<3"
M-`8R"/*U6A[?72A.J?=.IM_G+RVMP6=\<6Y_HH*9,9Y)_?8R]"N=3?DAEEV_
MBBH0@@!NRMG,HUL/DD'2K,E<(>L3?(</E)--3(+!PJ;3E\CD!PST2#-)_T@?
MT_:L=:J)R=E/A8NG"-"@]7V-6^6F%@HLT<;KS^;5GG5@4)>6A_"%&%AH#*W:
MS6B4OM'I8=ETGYR1S>03J9ODPU6(<B7>M\3(@"IO2[4KWY75D53#KI[B((#=
MZX5I)1<S6XX;3IE"HHAS#0W,95:[H&JH.MW?2.CR$>BUWY07W%BYA/ITZ..R
M4E_S$7:Q7ZD_%GS'+B,=U3R)[@26\=V#K"Y6B5/,O&R5</3W4&8IUP.V`!5^
M#EJRJ4G_,%];@\A-@NZPV2-906C$7YTXY=V(D&E_8_=$J))&(`R0I:SM_,-H
MR0+Y_EB',`VBV/?IAW)RD#MWUK(IU$)D]?`K!-<_$8^-KKTO%D@$@\Q:%"--
M)/MNK]$,X$K1&GIM(3'%9__OTF'FIK5&@%<+G-,+^0!*,:4Z+%A$0+=LALJ%
MC_+-M_?:,:+D1=[+"\"ZDC'[0[5>X<J:=6CX5.JY\;K2?`Y\'\2^P&QU=;]9
MM'S%F'<^@N8F79`I%4JX14=%\@EWIF9NG]PCE70<OTGJN@[YDEE$BE5:+1:W
M%_#BFUQ9EO#8J/8L-"V6A0N-M)B:9QG:.2VKBU<@@+B`QFF@V"/HJ>^=/5NZ
MKO\BU2,7*8FZNT<:/@KR8A5"0?V']4`<-]G^&TQJF_W)[^M,R@,-ECOHO1)Y
MZ'M%7>ZYM6MR^D7]\2\N+>/N57/,`!V:M$#KYMJX)X]\#TE?"S6)!6]]Y=9H
M988O"RWO7B]Y`.+30BJ>N0095B"VG)ZP#,N4;TK$3P+-XWV=:;GJ*YE9TK2K
M!%-Z,N0Q*]3Q^U$WN,&<6R.5(#Y=-K%X6-V5C^ML]Z[26K@XT:TJ7(9=_=+S
M?%MCL3J(RNAYX'F@FPS?OJEI*&?"E\Q=F?74J,'7Z:]2I[-,092+A^X,QI30
MLO\=6TB?3'0[SD=>A*YJP%B@Q$SW1CHM2VV;`,XS6@8V/0VW7B&J.CCJO>%2
M.MWFTP_?JLE!GZ?VS)41R95+Y0#[0MJGMH)T&<Y&]B^?!]+'W8-<@6-K%K;!
MP^*U<Z:-WFZ`PWKGC<947:F=SVFKQFU4,Y(,Y]=+ZCO1C"_(S*ELA]88:N3:
M@R+L-O`XA2G>R265T$FR`.+!*DQQPM&72W4=09'TP1=V,OD=QQ<(>?S`S&`*
MJOUV=/A4%ZB0H7+AGWZUVM:1A@NLNPW<ND^C*JF>ILZ$V,FGK/IB4_Y`87<3
M"Q%14[(O*L8)R>BHP==A&]A!F=QK%O:Y8H/(P?-&NY);M#W\T]^5/_R:I\`X
M$8$O;8(P_UOR?;ZTP3FI[0E+K3)4E2;8Y9#Z;[':MR?PQ$V1[D&OX/,J-R+=
MV'+6^E5:^'S1R#_Q1'@;`*XRZ=V!Y->E?<#S5<]!\L%55Z\MR.:7GT13M3&C
M%(S4=##W!3;+Q:Q"TEPB46''3C=NFCP2@*X\,HV%H^UX4N?1JM/IH?;<SD58
M_=%,UZV!02=(C`[!Q4J'[X4:$TYG0>3H)GNQ5Z#0WO_+6:Q'IIZ_9=O]]VF5
ML5%U6/,#*[:X>C%.E"GSJZZQD%YX$S3=3$R7RK;)D`,`A[.9JBU,$>UI(+%*
MF5_6^1(8ZX2U=)"-=F=;=;"OOOZ''W"B_*S9YSMPZ0[5.3\WM\&3IV0HXY<!
M71M0Q7L@V=C.5;"1DONPL.#5(&$*QSA2#.863YIEUE`\A+A$3W\QE/@G+W$[
M5HBE:1$.:T!B.Q\!648,!=4;I<RPVZ<ZBH[_H%&>[T22;$+>N).\"\MY"9;C
M&RR>I2':M3D3:"6KK#A+&@/SGQ9TJ`_'&-E`XL3H.8/;_3=1A%#2*LZ54UI"
M(//?I^=\MP-![6@!KB_<YG9>18KOJ3A8MA`XTVN\NV&0!X_DXB8]]G-N_32W
M*YU-5_.LD@5:)8!]79UHN(-<(,M8\B_4I^-T_;<Z=NBJEVFM)`!JU%Y8INLT
M6^M?B"8<DQ[M&C3(!""61]^ZS/"+;3LI=GTS']_#4,U\Q<ZL<N2<S"R\Q09O
MFJ"D#Z._02V;JL+:=!GKFEKW??_+H>,]C*_`6Q!,CS0='QA$\-7F5C:IID`Q
M-KK0X'7PU^2`'(WFCG1V.*^A.S7A?,>X0Z%_9=P,KQ*D#H,`.6I\).3-$9U&
M`=`:[*II4#AVM)E@!:!P\X&R>)NB!0;(82-$$&,\,?1M,(QSKSYO7QKLE(*8
MDOM15;\5)5'8\KK?=O$FH-%,ZT@&04@]NPBQ/KV4P=8MG:8FX6AJK5EC!G$C
M]^&GM_\Z0C]H%RO>79Z&2'1AKS;?BISQ:7$69+HC%?6A6>P<6:#/\NU]]+N\
M[H/_)!NZ&Q4;^_'C^20$O_K%<[TRX\J'1PU>X%$!H_W\G\0I4;OY0=%YV^-^
M$-&Y42P,0PY4I.TW=YF7ZD_QA<'WC/_<91-_NGV]U\<SSJ+5-X4A:FH,EUA;
M[O$.:T]-<:_7,C9!&(X>`OGVO:3\ZT/;C`TJX$)E$B0K5J6;0;5(2[P*83AU
MVELDG#5^@V<%O.<;IA,;<#8F1LBN];E)8KRT2!'#]QJ4V:)1QX0JK)/DI_<X
M?NE'DP?[RJCXWI^7A-;D/)<&Y?`ZL3B&I1,&&RJN&$;N$*J6.JUEJ,CWU5&!
MC=)43?FVRV!<O_%"T9'MI\]D/<Z[S_C4Q1!:LZOX^"E"5_Z+I,$!*+3H#&0O
M;;Y3HN1^^/'4)8AA\$4"T_QG7),'))Y*1?W/]6THG>"%RG(3.Q2Q(=[SO>LG
M(FBYQ;SILA[USMT':#+-1/"M&\<"-H_V<R$8<DX:!5I84631D*%R/EX1HK'I
M.)S"VGRR%;>H$DJ:."\51]?;U?^)OMF,]E/0*609_'?&$+\.%CX4E_Q;-D&#
MR4QZ%X>9`+=&]2-*7LYE&>+<^?&],^3^&B+M\C`"?T+CUF!7E;=!VRUV6G+@
M$R4[]P@95>4GD$W7[9N&\K%L]WJ-FLJD&]+\:+D6[586N<O631'0M:6=T".$
M`8$;(/G)8AMULU.(@'543HE\%6_73]IZO9?-V`V$)IQU-)NK#THP=Q'[]3^*
M<L3_[>_/^52F/?]/8DR\:EUPXOR0$YD(L.VEN[Y'L%R'(7GWPLD@1(5W`EF.
M">],+Z;'-44;+\EPT[EL#_/]5,4;Q]H'ZOH+O_]9W+<WB;&>E-;%#OAETV%.
M\&!;U+7U]"45V"&,UE0"<DJ>>0I0/`A'ND3<(_SB&YT!I$J\4CB5LJL7'V89
M3/67XU+(#UQ[_HW+XEJ'S`)S-*SDCP?5A@%=;Z8GR4:<?@S'A8O0VG'+I`<C
MAS^,9LM3,8'TN0]'-C]W`FC[R!1SHVKAY1ISP\ZHZO4U>X^V0K/*V1?9\2_O
MTP\9,1!.C4%D709WU8Y$T7JJDGU^D6KA"[M\F9N<Q-X[CL).*OX519T]$Z4S
MR"0K#:,3)&5%.O#&+FB+RI"A]GK<^)(U.8CJ/S[+4Y%*G1N$BI6K%4@@NKVP
M8J_..@XW&EN3Y.E-#.]QT'K"@!V:$X22`%OB@@<ANH/-M,V@)@J$^ETU!USS
M3J"ZL'Z2$,W"R`CM30O::EY]GCWF.0-8;U*L[/]!;7*7]=OJL1?U@DOKME9S
M$;EH:I2Y=\.D8799/NNNL^B&%0'A`V^%#\%AWXM8QZ;>5=1-]6?SR?(/Y*XS
MMC)\A2WHED:F/,4"?T9@K+$(;%VD![8]['_*?D+:G:(43W5I%HR7;7TCG4$(
M3L&O*?02\*YO2Z"XEEP*T5@+*A+F9I!G2#QXEFO+9<P;1XOPIT/B8NWARQP@
MKA"Z_3)"VZBW7&*[?;#<#W"9<LA9J2P?+2LASG!B>M%MER"9U`93I;YTXFEV
M6.8)U`U(Q7*:L[%^/,KH^KVW;*ISP)RC/E6YQB4\H?6?(/EWBHJP3"0O^+^K
M@B2FPTTDP0L5.)8D@EZ4Z;FRH(/=F#-()UM':\K,34*0\=;W.RR'3^\+58*]
MP:/&O!G(+*Q-U8WJ?N1^ICJ]HT+9ZHDAE)';,D4<5T]X:V:(E\:`[(F*<0)(
MK,L>Y`@WK8W8'SM?NQ*D7&&<(/ZHT4%L0C*$T6Q-&E5PX52B:@0ZDVM/C%@<
M:0GE-,:3>M`SBSR7<.M:]@A^"^0AV#:?.XB2G"*$.H@1!LU<I`U)(Y"[$*3-
M4'O[)V>"#>@&G]]HCFZ.F(?!D':B5+>TC"U5'@V=2AWGD&G12U(..PL?LD#6
MG7Q-K=&&(FC+8Q>HLL$^B,DU)!GLRNN;TI326742&#YUL`Q$Q9MH@\A$Z84'
MMZ4`6.N$E%A?J]?3!2CE/G\FW/^SZ-+5_<0RO.E,2J+;2#O@@=KLR1J\^;3V
MRR2*(5-*^'F@7YD)Y$V]_=U`LY,:*:DL4DECTJV@TT$Y%JUXMO")S8[SIZRF
M%,$Z+)<PIO@^$6@5V6$$(/=UOZX;!&V]J$S98B9PJ?WV$ZU=$*@2DU68,;$Y
M\R+S@TMVH9QO%I'%@WARSJ=OK)E@B"KJFAZIKGFGFR4<A1+FD"S^</H#C?\)
M9``%X_Y.4?%5#(X&/O7\&9Q%8-)/9!()BU7(ENIQ)Q\W^2V=AT*#15S&U,`]
MZ2D!A]3B^\27Q.R=G,E[6]S22)TO$1$!1:4*_/B/*_P9FAQ^9PR?(^@<"BU<
MMLSTBS/@8ZT&F"L<<8)GF-K(E1O^5'\_*!C(^,"@<(Y]7C'0E#8Z-R*['R%-
MTH=9AZ\P%9QI:.P/&6("=PG>F)O#-]1=>G3]L75<+-S>*&8R&J2PW_&?]1LZ
M$'[T,BM?/(=498!QX^])*;BTHBSA%YMD7Q62*PHIL-7FCG\!%RE,6I*8&LJ:
M-.!/9,$?U8:6:(%XT>L3#:F;].U4=T^X%.(<$%?FO-9(=K'/#!3#[L5I@6TP
MY=..L<T9E1G\JD]D?6ET[93T]7N!6=0DG;J?6!_$DA7!G=LPB"82V>9T5907
M@/63K:5$O8$8=#$?(X\Y*ET2)&#883O=_)(H6^&H@/FVZFQG`77O^>CKYH->
MG/ASFLU'D1SO#G/\Q"E?XE>5"_C"+76YO9(,,'C$`$YXKR,HO:9GJ(X,Q^^5
MB+6/$T/TZWMB7!YN-D?GO])T&O[9#RGMP;%F;@1)5Z1(Z?[WE-D[M4W&X5B!
MSY\UU&A&5.@3"SO:I"B?+S[@X6%*5.^+WP*(`2[U+J)R9&%ZBM%/?CNSK(G)
M]#Z7.(J51TS1<X4=,K*^J=HNX[N-FC$$$27R6-3U!*&-L3L=@/^199KU#?&+
M1P<D1G:%,MP@M'0QKWDG#5L8N^N4XVTBWP\4(NC8;RGJB(4_*(F&31X#/=$6
M9J(>?JJJ<'E!#+HQ4_QWQ.`T1ET.(%'W2%8A6V-]H=P4;#*B>!I+\P7&FZ_K
M:^G5Z$`C^Y1MGQV("2`#7Z;-BCW(+G>6*L5=>356?87=J(31E_:O%-7$)T7C
MZ8]-Y%,*)0;NY%UKL:2&P3K&3-A#-(U=S.JO-.'0P'D0I[)SFE*;XKKZL]J*
M;#I:OGJ3R=>VPGV<S@^`HB/"Z8WJ:;1WZ_$6-T)UL&H+?</R6U<:@6&!R)<"
M7(2B%GA9N+3F*Z_&D6YJ@`(%&6<Y`4R;0FH-^]U)`K*3BQ&`.HAH7CCE@H#8
M(-F22(H2)`4[?YW&^.Y^0L87FO%M,V#'*`.<-'SM$<;C(`M_M[>7D)U@2+$7
M1H,"EU_Z\D>X8X>GQP9FFQ,Y/JZ2I'%\Q&AYNOYV/Q733]?[1M10!1W9)6:.
M2C1YJXSUPJ'M00;'.XOY<VT\NXG=IZM!54#C70MJJ/8MY=[JJ-LFY./EIJG:
M>K<>'(]_[V_9HD!CQV?.G&:H-;T.%+77M22^]M!46I^/61EQ80W"R%BQ(6_J
M"9&A0V-6S5>][1V;@*$(57'4JX-9XJ`5NJ.6]5#%?4V\73U\$*7^(UNQ(^!)
MKOC(?UI<;UYRGX(\Y*?>1Y78;Z!LMDMIMWZS'_?:(+H#;X8%F^AF8;<GN:K$
M]&B$2I;*09EE@O/,A*[+Y)"C\)V\54P=J:Q#68XS?*=2:-WKR1.=YJ8=8$Z*
M^*7Z*\JCC)D/O'M\EO4I?SDZA^13ZO(5UF]_5NA@GC30#,B:4[V)>C-&N?D$
M/!CHT._JWX+64SB3X=3<LU)GR'S&V85GPJKK8LC09?2TW/X79`(B9@+4J5O0
MR@+G1R,K'<X3O5L%#@(E'ZRLG.6^X<#QSLE/GAK6/(9FR_6_H<L^#`\BE/DI
M$<%'$S)>0\J7-F,*N!2.PPE_0<5QGS-;61[/6G+&<4R5QT*Q`GSK$Z,"!KDX
M+P/@:B]_&BPFSC440,GD*C_4Q1OH3W;?ONQ.CM&S($9*P3W1;P3XI6-)C3ES
M@C<B%6-H@A%#555_^"+SYQ\%&#4/8NI*$LB>9)EO!**A)2A&P_9Z?"`TW.LF
M"EXDX;(4:(N8>*5DXW3T\I@14#KE<G!:O;$A0@=VQ?-R12T`R3_3LGE'<9/Z
M3C..5\*-[Y80#PGPCLX3YE\Y`R;+G,Z:F4@UL.E>?&4`[SMX1?94J;U*AM<&
M`I^$KOKD:6/ST6I4P@;#]C['*=_>],'50#^-2KNQ^-&0*PXV[/!'9,_(5:MG
M\)RV3HXL4]F-MZQ]UW]2CX!G4;DWOO"\M8?DJAO4B$K`2`ZV`*2+)PCR.?+N
MMX<!W\F.XSQ$8QJ2X&R)ALFA.6V[..L;A;_>)6)\<9\"3%)\[%E77K$=NG58
M[=G3?"R&-2,`]SG:"?RFL<D%12VELJR+O`^LXB.#M"%583VGB8^9HB4<S,@1
M_!AK:;E`6H9O?Y0FG@@:7/'?\MF.O&&;ZH&F'E:,28#<F93H:>;9`&,\-&TG
MR%5=8%5P9S35B,79U=*$1[R9A/[7AZ?*_.),9>INH/QH<,QLZ(_^M`U]%5IK
MZWS6(R*Z`D@.FHU#2`ABG;<*L^#L0;M'6O72>S4,#J%-&_&/.XJ0XAV$\_K_
M0T\Y2!PB%4_!>+`=]"^6"J(+A^2VU),WB9?UA#(E=*L;G<I3CL)TC(:L)XO^
M:2,"55#M!R3N@[J^?7M7VW_9C)]F`BM$BI!HW>:XM/B"CL(#SX9W'U#W6J'"
MPC?`JRCA&PJKYH2VGRVR-.FHLL7VB'B52V3(:_XZ3'$^,&L62G9*)TUJ?Q$&
MN[$UUZAQ0C\QC69Z"1I$1V")G2;?*'SSV)Q&5F4F<S9M/;W",ZBZ"KPZP)Z!
MI]EXA4``D"55^'>J?/'R%N:I[+;HR7LEA8!#LYEU'TXI5YNP\8%"U3+4T.9$
MKU>7?:P\SLR@.CEL$THXO#W/ZNL6^LFY:=`N_UQ/)M",R;ST4M**J2%V0.5L
MS3VDIF0,YF->71VL[4PD^G;H1H2AC:U!O/^<K"!J1XW$CA=$@!LG8(SUZK)G
M'D.F,@JQ-+G[OAU>O(@)LY6&&'88A<N(#66^V.#(7L2CO675B%SLF4%8V1H#
M/()T$RV$2/'&%=@[JLA\#WK8HX5OD?-GT[0Y2$TJ!NQ!&U\H@4#/*YS+P'7L
M'DU9_T2.?`NK@4+$FT9N\%#=*Y=.SO7:FPY?.^-J;M:0]=GNWV'S\>[@X<T*
M+D.?@XBXC<)/&FB@$.E[Y,+.!B3R&6]?K''#_+-$_Q_+GJ!E9ECO!W=ND4JX
M8TGNFP\,,I(X,W1<6[.9_JX849LS1L]+G`9(>O:D(,4-TJ=R9Y8O<=-'Z;#7
MWO<]64[J/RU#,S!BC]^1=T:5$\.3*^UY?>ZQXKCWO1-YX"4@2T;J&\!RSG)J
M*'9<"K-'RI<IU`_L$\+XPUY]0^<1,V-#3T9B+@)1O15Z_,CB`?2BK0C=1375
M]?_/(#8P=W]9,=!O*XK7.1^1ID\KH"6B^\\7*AC%9S@%VI)A>1:SPK"<)Y=\
M8_F#`VI0.O#SJ+1<_>L*/MC(QWM]J.&"<'\I=?BW6KR`U6MSBG/'>!(M#,-S
M-EB&0G9PQ)XCSC21IMRJ&\Q*C?M_S?B+M&[=X5*:O9)<`O/8&(:,?DH=QXW]
M@XQG]$!&AYF;2)I<\N<,XH4%]6P!$BH[Q!AKUT0K<M#2P>W76*W7@"H5E=\%
MF->0EM=04KP"1O@G.Y4EH$M*S`)ONA@6*S^DEV"17J9O+SJXFF$(`!ENDW._
MS^8CZQ4T2Y6/6(UK@RS&S_SWV90Y-"WRD1!A$0V4U2#2+X_&/<$#6\SL$SM#
MRV%W"]Q``8A;O=V3+_LCY%VDCB)KL-<'#R('?\R]61?](("1W'EFVV`)@2BI
MP0(:]L'EFP:_4[GLRN:T@8E7K%-TX14(KE-(FK_J7GX/QT#='.%"\5O:2NRO
M)%GPVE;U]$K^FT34NLBT^@0NG,-%X]2X)>"V]<JU89##(I1C'6=UA00I*GZT
MMPB-):"=1MR7#Y!`,N%%Q7F)D4EM^UVIWEB=;FW('`(6A=(?N<`+#'J5T`3\
MK65/#NP*@+1NN=LRV)Q,\FJ//@6<,X$S`8+=U!#!*>M"#4O&VR>O]I2"[6OR
MS\^NMJW7;H-ET&PY+5IF1\;)-$9Y7!)QRD_35W8>58PO0</BK"`/+)1=.R@O
M52P<$2Z(3."&K**7F7\+"<H:&#\FP\73P]>5_:`QM%2X-4KEB6"GL.,9C[5H
M8A]YY[:6.*DZ[+O45A]OX6WD!H:S6HF"D]@TVSZ_"ZM$B0=2(6)3&'@BJV^J
M?LHX@W8&0`728@'H*4]G:">-%XX]D<!OCV>K*-\=X\B^+E,A1^P52K*A$$2E
M;O];I_[)+,7J=156$K/+P=6+S/%"8OHIS#*LMWDQ;:#I7K>F6*1PBT_$J#6X
M:6N=AD:3GU-@A2=B,O(\\,)-NZL9!$9R:^VI!V$,:>Q"-*TZLP=MM_3S*^2?
M);G\&?.;Y<,R`>C*A`'BIC3(ZKK7PHS'XA?J5%UFIWZ-,R&0-3H2%LY/>)AW
M&`_A<B)O"TFD?7[C>"&LB^#F?*AG6QIT&IRM">[Z$">@YC?*JFF@2_3A?(DN
M2_&=SN=I5B>AZ^XU3@$E))O3W(53W(^DR&H1_3.(=LG(5C7.E<E@R(BMA4CU
MO6A=WVG/&6D=B([Z`L/R,T7[WJ65^\X/J@80?;?I]Z"9QT[FL]76(UYPB3."
MFYR3["!,<JO3Z>%B='JOZ@S=!%34;"`Y8B1<VN]HW14_P"Z(2BW\8KEZL(+K
MJ*%$>EWL%GR#S0;Y)$;_1EXY5?.*H5;4E.;+HZ$`91ZB&'SR-#(KOWS$ZI),
M,Z]^;!I`P@8%8K\*;ZI$M/&E=:;>7&7`KRF!SYHF30B@3S1]+DWK`PZH\?0C
M=%Y[2'?T3N'\AC`ASN&THFD')+J1<N83)L4/)94H3:P\/#&)K>(RC4!6#![W
MN0@6Z_4YT\MV-I71.B#1V9#@(WDSA$2I#D9(J0F4G>%GJ*X"PCBO/J=RZ@M]
MXG5VF@*NWH#>8RA9KXF*H,+UN`J[@=)CR(!!K8W5`FC-+X#)UP6,>4S*?Q"Q
MM$1#ET8&&]*U\\7'?Y1,S07L-=)T[DE,(MKHC#8N`@]*51(67.$CAA#::3[B
ML?CQ1NN-8SP/E!\9_]MW6[FD*O1N%H<+6XN!$T(XD1FR+R0(.HN2(%B4M16V
M9_<1YE03_QSA)$Y64+T'NAD;H)`??09\SF8.`\MH$/@321PUVOUP>"C@6S`9
M#BFW"X5<]-$=[B('!ZWXY[EP[L-'/V]M"O=%7-644#BOD,V;UPY0^U0R-Q?G
MGS[B74`LA'/7:H(+A1C+R\.?VZVK4K28=[$/=.SKGT82#2-K"G@B0`82.U#V
MKR,3#@#YT8/'NA\RA3T(8;ZWOAAC3X27,D99-LK1F+%2Q4T\"'7^@P#SI7Y4
MY+S7GV1$>2YD>4V0LGQ>:H_CN0VZ_UFH1M=B=K16)7RLW)*-GJ24Y#QH!67W
M.#L+\K*&V:6U\ML;-4#P72;9_YT6'LG!S39PRW&>SW.<S_NP"DX?`^*;APC^
M5W%TA(M>CLQB'9<(IX@[*OMK`S'LM?ZNF;OYIJ>80AYQ(V92Z)V#O,B&A^1S
MT$[:?5#<U?P(*:%$KGL3P#,?M&MF=EIZ8ACD8=\J?.)8X4C6"?PXTX*YE$%]
MHC>U!GI@,-E*^18#>F:4;SB(1<3]BW!E,7OP;]+K>:$&R@[[":9>=)&T`%X\
M?&%SEBI*,$69WP03=(.$3:TDO)2,QUQAZCR7ST4%A$*N8+P:E9>Z47S*9N#%
M50'I_&?V8Z5L1BQ^#F)E%H_&\N&ZY&/.6TK#6:ZE!P7!@AZQ8'K&,'RJI79(
M946\)QH">W7R1W3Q_&PE(^+MA.&A7<-]R/[!<!9?XJX'I]G<+G@LI^G?G.PI
M><+!+R=:N&I8XRJ\XNNC/,`]%SLU+JQJS"43LX*?T7<#$9M-EWR8[8=#^7<$
M5E$K.T+1P=?3(1SDHYD!)I_LPW)#O2Y"FX1EK419:'T%BFO<[85%W$M4J'S7
M)C^K2\NI>3>KX,^4E02(C2@QE[>)R,#?\E>7W1[Q];YMU:AL-[:O)#:+8%R"
MN+8>[\HV@R>!HAW^0,NDS5O'7/UXY!=PZEX\\*$EU0T+WQ^)`O!;&]IDWT'Z
MV;F((]'!RJ?YI-4RB#8AMJGQU@>X2(H'U[_X"?>\QZSKTNJKHZB.2=\GT,XP
M]6=VQT9-'[9K>XM_"U&W_9YL\/L2N<#T4N)`K)C=+!'Y/FI/:](^84-3)209
M9",)^XGV_5\,!=G%1&$;2T2+><83,>I1">$[[S]RX8FLZ.1LIB&3N0=%/V%V
M/DKU*B1L4.3\:'6ZVBKD55!F=$Y(0/E%FZ.=@^W?_K5S`*FC2;<($')UH:_U
M`Q-8[*HBD"_7<$X7?K,&9+I2YXRH)Z%W.Z+4S@Z>*G<\>;M-KQ8DF-Q+^[!E
MX&2BL""@]*$`DUQ((#!Q`C?@PE\=6#-;'*5+.OD:$4U*0(J(.\OWG:N=FF4P
M%,#;),C>M4Y9.L9;-Q!)<,@S8?VV)DWHX](TICA.*3S>0R'Q0R.Y%?OI'SIA
ME5F"G(JL`-#^)E(UJ!E[]4Q5F""*9O$@Q<VD\Q]MW)Q6\QY=BOP2R@57P>;8
MY?JJCRZQ%SD67290/QIH$-\*1`ZQ:1FU##GJ3)VTX@'9AE._`(("=+V>3F7Y
M#0E)FMQ&7&0Z=R!C!Y$X+A=*X4DUV3V2!_HM.(!,@`?[%<Y)RP(UYW>#$X]6
M%/AM_I>EX#%:PG5Z`0Y9ZX-^Q.W5<=-1=IK!1;4`^1F*X+.*^3,@0+I1&N$#
MD&J$0[AAJ(@=H?.+<$6(.KG0"_%>(QW1F?&YDEML'ZF3P5Q^>TVO,D._$]6M
MC%"ETWQ(1ZAI7.R_UVPV3<K8,.#P0#$M">$<O1(L=Z#'4!A2D7<]Q%,^S8Y\
MQ7/JD,?;A5=+Z9'R?>D]CHP$$ZF;11SBN2$^Q/$*4]VWYW;+-DE?1:,MQ.U,
M/B^!0W)!RMO2%N$,P17&E+V5#D+)(B$C40]G0PPXYRD+L4)C8=D4BLG/@'\J
M.J,:O'KH!]">3G]D3O=@$3)ZXQ@?8.T/;Z(OK'C1@@Q/@[";'&J)J(7C7EB7
M"6`AB>I5)K>:G,*5_D^O5%I&=\=K>)1K3U`UW;T/&=6`8<SKML%%(FKOP];J
M)B#-Q,3';H+UO/[I'=I!"5*J+,+X(C:RE_E'9]?2\\I//&'?_]@^J81$//9V
M+)53PF`E0LG<D'F,N9Z#&C,KZ]WQ5+?'ER?T:'&LPPV@_)?X\A_Q_1[/U%`7
MK=6/N((W./^'3#KLK<XD%JH]>V9O$NR2:RRT7+M".!AD5?R#VU5/]UXG!G".
MM9R8I"@(=RR5A0]3H]&]Z2;^26&)$A9-N#-F\7NTN<^:M$@0H*(F_TX21^19
M'I-DW*:?#J6W(E)Y<`E>ECXBT5/$%#B*;:U?&G"QS=*:PUB2!H<HSX[N9W]6
MR2NJ/D(S'IP_%INB4,RD5%./1BU_4?]FTYZ6E!PU-)8(I#%4P!:AQQI3HB8!
M7R_H39]M/JE:J>_JA<%,2V_*\8"^.\1C5:2AN9,76.9`;6X0>Y[,2*@,+:W5
MO86XUKN0^M%32Q\G!^KK!Y&C#4J$[(A792^`_D6`BF@`_<E?9Q.)X/]#0?;'
M7`@4045Q`M#\;$&ZNS'+AZQF`#QA?*]-=VX,&NSKR[),.$GVW7I!D<W7_,+Z
MDE0+=V__&#1=3!!L=.=A)>PTSGL=)O9KTS>J#&O^S3@.LK'XUZ(2*MIV]8ME
MN=1#21\8?:P^R+WJ6M<4K&,*^/,K[F1!]]D5'\D`B$]\;=QIP(D4QIO`K_"W
M"KOCW8Z"O0LVI/HE_-(/$2/JJL`N1Z6O+3PBU!J@EC;,V`;*G#;V8R3S-TV[
MU5N.Z;-1%X<5L7RT*%O[C/P?:W1ITP3XWHM>4#RE%,?<8(7?JT8=VGW(2KIW
MP!6"1MCZ='.#8D(B/'I%CP.YO>!-DAF\(X*)\)X@E#6"GLZF.HVY+O5Y_\K,
M2,[#;RG2E`B*M2]V\[(63SIWE$23[2.B.7<X!3KBG9:EP08JYH5D7;DBG)U8
M+E`GEQ$41%'T#(DRP!.>%"2W:."'C0B>YPLHG>$04!!`AF?!GFC,`[%RF3==
MD[$P0PH)AN5)UGJ0B1ZO7`>"2K'\C&#-):[G9OEK[8.9IB"&"Q8S!11]_#D)
M$:*S`L-#`=;U_?(^0A01)2=<#XZ]^&_$VD**AU7LWABL%ZGG*@>]Y_QNY]&<
M>:K3UTWA(@-!(L'7EQ:/T+7KFZ^3SI+,0[[N>-N,!W-KS.5+AGJ%H)HOUFP&
M&'?KZ,K*D.3-+;;E;M-^I>@QH8/5,2B/^#5BI%UZC*K]?P"D&:=Q>[Q=\?3$
MVPJFY7M!DCL^$!--'H)ZQKQ8(>D>;@'TPP6JQIY,IG-7_0A*]:4J^CQB9L\9
M5$0<*!UAW;L#:N2RFJ+>TY/,.;01]AX`O(I5VFR%1(QH^V!X.0HP]-.T`Y[,
M=P-Q_:`W!R`77`=&Q+>D&T@1[WX7[&$!21Y4!P#HD*)?W*C;_K]+#+<4%\+L
M'KHO9+_?-5``IU,=&"_84J=5,>R#?).2MV@;,V;_Z.^Q8RVG&CRF?#Z89HT^
M.S"OF3IU#M#CGN5_^GE83LM[GM6K"W5,"87IYK)6_-J8LWKD(P_+H`OSX0)@
MS8&06^F_CTR1(TQ\G@N=Z%<5[;$U-499*.3>#N1QGH9#R1DCK[1@D8(D<UTH
MG]SEY8-D':[)V57D05LJ)_=&Q7YS:TG)(K&?OB"EWP!]DA55\<MX2*=]0.>S
M6K2Y=SV'ET]&S)X]<VSH]3^L'NNE4YDA2Q^H=>/XHL),A6'LU;_:Y^S@UW>2
M1!`^R^BPR[NWG$K4!K*3M<)H-+-`H8#+)R1"=V_CMV<#'CO!&=EC*F$.D*"\
M$=B(_,$]OD"!6D2RAJ4@SM/L5U+9Q!)%N0*2>KE)^+<[-DP0`B\V8-W]SC":
M\Y)/@05"3:OPZ5@VNF`M^2^)&F([L[K]^`0_DM:B>/Q9#V<.B4%8?SBCK5'`
MWIF-W`^S(E6QS:KIPH3`%7!@EV0*Y%R'G(8Y676`0(&D!IT%^,#//,<(_I:7
ME[/[AUG*(\3F^I>ZZG_B;0*['DNT#$O`E]H70NH\;I=7CX,>Q4M2!2I/"1LD
M9IZ^%=YYO2A::RA\_")G`)U1;+=6MM)?]8&BYKB8&-KP*L!^4NU;HJ'I2B-=
M)#[3TVH+S*PG#`U]V/$<J%G>E$AJ).KL,5<)2ABWQ722+6R\I\O*CVWO\`!#
M](7)?B+KD_Z(NPA)ODWB<35(G,/0&3IMA.M&8-8\/&%[X8J$D,/4`]6_+'.,
M[O`%QSADA-,0'95:'YWA;7]'\\QLGO$[^/$.$VS[Z8PR$T/"+$:MD#Z&G_'6
M+7/VU"IDO'Q.KI-]-ULX&53/7>@%6NO3BUF*.%#L^5@$]7'FM1X.B^<OV!-[
M>=/ZV39'SRVQAU%FVYFM#MP/S9\1=$CXR[3V)W)L$76)A3**E*9>V,=1L"E9
M44PJ`E.K`@";^"1]CB!+/O@V2+AG,C[I`4Q.C.Y.6'2F^Z?C[U?P3R^3=Q4X
M/B:Z'P,GQX^5=XZ_=\4+ND']1YBJI(++.BM"&A,6DEB,1YLK*[:<9(:F64*.
M1V2^?N"!_:LJ:])@'11D8Q;_SASR1SN)DG]`\D8`/<WU;>\`QP5P'^KE)J=E
M;8@U"78E(<C"V7SXX6>Z6:9B5T>-4C<DB4W'GO,-V"%\Z6;'?BP+GQ<?F_[\
M3#:&O`"M#X(W+X/$W,`18%MB`72JCN$9GE]+%_R#L[*+,-3T)QO*9_%,]V[6
M%O[+HOA\H.GM)H)2OS:H-YJ7)_"T*F1KK1L`F'P`^=EMLSCBTL#<D[D0ID'/
M45SF"&5[LD=U"36U=N5>UQ:O-EL;DM!\C7HJJN\+UHC=$0)=,PI03(IWB78,
M3A#%S+8V,1?6RHJ]:*FK'/6R734RW,G?B#IN*8PD$2GS]!SET?&T7*E'&\6H
MD0,)1I/_'X(*+:G@WF->M&C7R[KC;9A@$/Z_J]'5DKPR0>3],P\Q8Z[S*EUO
M3SIHQ[%+0]).,F'_=2(P&PP2`JY5:^,I*PEFD*QQZ^5%&#>MEP2@W2+);_I0
M:8,YIP6$NU7UK'5(\^1\2M>MZI<U<24C28&DV]F;8I.]?)966>:?MJ5=]:UD
M!E>.B$<95U*P+XYQ[S>]NF8T-'/QM@*LU<EBUZI,0L^W?#[G:3A/.D@J95M!
MFA/$-F!U^J-]3XE\UP_8C/(@FZV$4W0I+]Q?EP"1+?=H"<.(.!20DD!,0&BC
M#]31::8MI8AJ+T4N.L4YF`=+//7TPUX'-T+2KTKQVE)GU&O%-!H)@#F9A.2/
M('%0\:S&(.Y*N*4`.[RP]5XON:":V";\K.^VYE)P6&*I;T64RO,@SBDR%#&3
MW<VF>>IT3:\00$NSY5LQAZU&A:MSMSVQHW+T+G8GAF=L@:X?:WJ-5/KY?45M
MH@*N&@JVSVD2M`/Y1V(F$;[/86>:>8Q/8F,=3P^G<NP!08%G_VJWETA"0M$2
MMC[RO-\>,$Y2(76C<_OIN-7`ZD_K-&#S`<\\QP)JLFY[`;FDOVC!?U]^KH8Y
M%"7#).9HRLI8L76`YR7AX]DX0!G^(152_`$<X-CH$Z+>]-M1GGDPV@6E9T$2
MQW9KU/"OY>-1">(JHS0&6:W-?K.'\1$@*/-C#T[IV5Q@,CR7@Z%!<%2I]JW8
M)EA`LX2MJB0Y>T78G,;";HW\;)`Y&*&8\A+\E8]$@!/=0=!/E^KA?LW#L![T
M*OPU'!@(\?[>7\+0>7(20P^O>]ENST_SZMBWR6!B.DB^(*2W54WEC864^?(3
M;E"1\'A$5[O$D?FE%&L>"SX@5QK3ZA,<_N/=NYW-NC0Y'H(2IIF)%`7R6`'7
M!#_&B)R*YO(Q%-M3"Q.ZKXDV2UT[^=F:E.M1I`4'P8X%7R`<50H"`G!0P#2<
M)A87P:T:^B\NDO[@1S-=@EV>\3LHA`V\4`^!4P,=:.F7!<J$]2(@<H#">F3.
M(UJ=4617J,^18:`OW@H&,?EK8,*6;PS#89>M6ZMXX?NSNK((^!-"FY-XL:Z*
M<"FG/B&$#]WNCO-S,IKQ4YKQ":V,`2/&?3YK([H4C'C[,@HY7\KM3(C2`-!G
MZ]8`-N=6722&S3G^-10E'V+C=7T;THQS.AG*D]R2E@U:SJA*Z+5I1`D*A&RS
MIH5`'JKB4X4>B6)F<[I1&:<4GN0&Y42Y<#LOJ".F4R09Y`:S7,A"4X&GCF!@
MX#)1!]8)`]7/AC+:MP&1#?(4A^_WMTG8SWS:$M\Y56ELV(A#YC733_<;N=?8
M\*Z3'[Q6S@!.TNL*\VP6A;1UCK#W9&(Y8BNTM[->4]:BZ(I\S[3HC$;:[I'6
M;LU=<878,ZTHGY3I^?]>@;2N<ZP,7`K5,2):)V[+B>_=]LV"8A0-UO]W1DC1
M3ST1%[XH$!CMKI/3]LRG>R(=X@Y&20ZR!$!F23OMT3?Z\Z-OY0Q*@,-OX188
M^L45H2Y/T'!CFV[RDG?1:)WZ#L>N'QTQRX+79_\\C>3!)02;PJ(N@`TG?XJ*
M\-7`K5EH]"^[^\.R%21O@W+3,0)`[(?U]Z[=X-]X_24.5':CJYA$B-R":)$-
M/>!8/FJ+#;KPG>`Y.$;&-Q,.)\HM.LHY)J+;@NSR_VF^RC`RC)@$$LILAP4&
MKP=,.`X^]WV!W,EH?'K[&<&=WZ(&Q_9?:@ZXY41,T6\Z3+W=H'72&8,HPQSC
M*IQ*I1X4A"*%L=>WPJ*K!!37IPK;_LJF),9#M=C7_+61J-H8#%G;2"1(S:9M
M"5'<8Z\_"O*/K>A'G]D5\/[TJ.!Q",QNFI&9S,W?3C+-6GS_W1KY[1A*S"IP
MTP,%8WT92$<HM8>R4T"CBZN-6#:GIKN)/6IOU7CTUJIVBA_/<DGAEC2[Q2/Z
M.(X4`!T!I.",X<::U\$B&CZ`83L;I1OYQPCULN!Z-0QP94]3/Q`L8P0=[>^C
M3^+R8N>[!C%>H-!6*X'26`O35IY#+C]`Q57IN.DMD8[5_QR'V-IXDW+:_>[@
M<ZH*,*4>X?ON<#H=I;B:*/U[]G-^X6?D1TPD]UMNO'=1WWV:GM51,T?[D7PF
M:>:`*>GF)G2932\"POH$U=ZQ=`YZ(0?76K_!WZ--3WQG])X_*CO64B)TCS$(
MM*L9V%JO\80E&Q]H6G24>+&!HQI-75,U-[E'3+IW3BYUDNT/QV2?M695,Y%,
MO_JEY=T*`K."`Y\1],3(,?#^8;ZJF*L833=[[N@4S$83ZM:ENI#5N\G;206X
MBN/-DPN,<G!0E*('1E`,UOR=3"):IQM4CBMRSD.81][MX&.@U!LM:$MHB%Y/
MA\1.R-.6$M:0T#XWOCK02)WRKWG;\X*@+TU!W(CN5(BXT61:%[@Y`!X&_D.;
MK&*9IIMC7R?RH./`""#U9TWT.A%^(8%5"+>QE,U,UCM`NJ@[=0HW%\>%\5,'
M'!VNFSG`V4@0'7Z/:UB@=/(?(MRJ_9L;@?S0#+Q5O?8Z-)0$/7K?DMWQ&Y;-
M%5326F[C""`20H(DOY.]L+_[^Y;=5@=UQ<ZY>898K:,X1\$3PB@T*XDGY'1L
M99W&$G58];Y/JA")[Q)H>9VM)02V-+8KC&WFV)_`#FFC35S7UV7*M:G&S\,T
M+$R&=^"Z,@E+H)*^KF6-*.J;A%B5$P+.6?9:@FRS8+;5J6Q/W.G24R'N"%/=
MI;I!T(]Z6CZ=%<NY/F';)*V=OUOD8"8HZ]-#M4/"L/8=BR<;++@XDUB#"*L_
M@HOJ1Y;/^X051^!`XV<B7<3TG\OITUUDYM*(:@A<"3;W>`9\"@')-2#2X&%4
MBI?;RFHKH+L:_U<H:UNS$<*3WP2+9'V41W(CA#/GTS8R*,JX,LFE9,;NX_A]
M-CE=CG!),^[K9P/:FK_-&G\(K,S;2UT?U!PIJ3FTF(7;&3+]9Z_CA]7CI")=
M129XM`8KYCCC3ISAN9$#*<MW#4:O;TL_*4;?C)GH_!6?-9,U89*.^LI_>43/
M\;,QQLXK&CFS<C77O7#$SK_4M=H]IO.87UDLSSO99V;BB1]:]K1=N"7CU5'!
M;%A;HL$!1DG`8RAWA!8OX=Y(GRQ&:6]A#B_QK@8'AL&Y.FUA''F*+"NC6#ZY
M4>J^&_;!.D>4%3C4![Z#^;/`N0*[MXP.'4;2"`?CA!.G50PC,3^"1Q.!`,L#
M-#-1*IOWL842LE)UF"\RTZ?>]_0?/Z08F89+]<?'L_8L]U\IHL9>BP%X0Y#7
M"[.*EG/0E:I"?%CTHW>O;*O)"H9I5*::#F/$AO/^^$[C3[+V2,G5W,8VTX[*
M.K9:0],(CDC?4/G_4X;E/J`5EU<_SE>'_W+"Z\_MO_T!`MZHUFGWN<B'>4>;
M/V8.F=#3=6S4Y9RV<Y[U]5,J(T(DA7/6:NZ-I&)@RDPR%CVGMM'0K^8W6H=]
MO7FBX4PL1BIY+>M"2%R<,?]J2WW@)GFI@AINA@XEM4:DG^19B":N!ML.R827
MJI/,R"^(4113W*F#7N@W5>L`.UFZ,$FQ?3")"^,$GK#O)B.K%CAT.^E\9UU2
M-EVK0GDW-:0Q;R$#]65/',,8-P*G?TS9UBWD5KWBM*K*86XIN`<^$R;@UMF"
M*KW(R<X4&7^[`%X5N?PN'M!D9_TD".,($PG6#4;#.V2"#,DO?TAT(_R0V^_<
M9";JP^E0C,X\EN$PP5A0J];&.5V=A>%S4`*/;AU>MB!'5%S?HSP!$=54\8*?
M!?+`2<,&>L$BD-5WH'V;^E*I9A!=5G5RH%%Y@;W],^8=.?\I,?NS)^L9JJF:
MP%E>$B5XZSS,>LID$'KHQ!)TTT5#U#JSTL.+J%7>.['YI@WG"\[OQQGV1?RP
MM"7D$^8Q5MVB%P`UZC4'E%@RO=A[S>GTB)CN_T'&8,5!HG41A5<"F9L@7;?K
M+*5!Y2T0T5YCE4=N;U^<VK(RKYBFE2BZS*<BI:P["//FI9[09;!OZ<HUS=F%
MB="0J5X1)B9>@XM\$A-NB!4!O]\%QSQY9!:Y@`420<7ZRX59,["W>>*[QF>K
MEU4WBF2VNIC*/5GMQ1?&4#+<+H\^5_T%&LDN^UM/#S&8!XET*<*IL3P\5EKL
M>44A$N=F85RQNU#[8-5RG37>T<O@\1^6+J#J%3@2UHN]GC0[@FT2Q=D5L2]Y
M:S[SO>1)UC@%B2[T_]C9<9?`P(;*+&`-*$E#B(L\SG^N.1KQ<J'.9Z(8NZ._
M@"F.ZX]7W.7P1M(A]4B<OUZR6D;LQHB9C+!]"TB6$HM*1IX2]8^W>&!*0H0+
MBEP^A=R:_$2W([#+I6QC.UW$<D$")U()MX-XU6]P)H`KZN\4!?C)$I=BV_'^
M4C)[-J5C\N[Z2;!&H:P^:,!2S89GS'JBA/2Q(W<J)P'"P'FB5U670MO%BBP*
M5WJ5+A[/8WW(\YXWC9_Y(-WS^D:J*!<0>S]XMRV2O;PQ^F@J4?NT3MB.PHPS
M=7>$_<1^/S2YS:NUJ_U)CC/-T84&3+N]B?[)8(G'C1Q(_(QR6^%#"HR`>W,`
MEAT?S^6E.@:8=C$D=8AJ],WG=9[$+EU?N?4,SRAH4'KY5N\>^5(G9;4)F.GP
MO=*+)U7CEGH7"V1=1P_\KLWW8*2Z_)]T]3HHOC-P^U=(ABLZ%P/+]49HM6WH
MRQV$.D8;>3<%R^LM:I)/KO6FDHQG_#]-BP8N>T7[X*Q"(&']4H"&R=IY_#&I
MPUEVFF!YBBG]"95]>BN-GW8S?=4$:Q[1L:%^`G0!4%PYKJR]I-WLQZS8'Q0)
MO=Y+E="G3\A9L-BT',MIR0)A8!W4%BC>+=I#KO"G'8?Q]?*-UM$8;=5>8.2O
MM'_C)<CVH:K9FQPC/'Q>N/\+?O[MZ=J/QD?[*-&<3SPH"3L+)PW!LG_9_4\(
M@7.MRK"$1CK,=?XD&G%P&(/=`X#X*=7?1VY?>>-Z,)$X0FFTZB;-B]7GO(,]
MLHO,#Q6N37/DGJ3;Q6GE&KC:9AH:]E]Z;_XEBO]GT#V$4HG%<AN3L6W[Y;MJ
MC__[4!U;+=E^=:AM<:%QW5B$==6HZ72!_]MJ72JBO>6FX:'HQN"AM6K%OS@/
MLR,8V@KU'H0MG9E(EIFL7&X[>CP">(DOA2$AF+%F&16;06+]`'7;G`GS'XR!
MVK([@.N\UU;U&#8G">QSY]C3+UU6R&J*AEC<:I^&'O3@V:I[7QI]05OW:P!O
MHXX?3"7`3^(I+PHX4>:M"3E1,X\00DT_E:Y0Y8I*&IF2P#]F!3&;N!8Z.8FM
MTMX62#Q\ZI/^)7W7U)&`ZZ7/8[O8#WMA*N]UNO:]>03`@;?HNN%A.;J%QELH
M1)=1NWEPPHSWN=(A*3P@KGBLA?&>C0=P(F!Z*K:>U>;%P(PR:O8=7S2Q:B3Z
M2Y_1V"I9D'56$-_U4I"HGV/BH,R8KOH+TS"ZRF05J.YE,KT]X>'()#<*$R85
M[N_&J[S8`=X:QVG'IJAA-QV&BO#[.6:JN,FRR+SEHPGYK;P7!JI;;!:E05'1
MV@M2PA9$86WP(#APNO,8.2DX&-T+K84I5]G+$=4+X8AH/2#JW7PU>A'UE;\8
M0"-"P.#MTH#BW'E./P<@X8J1#363*LC)E/Z^VJ.3`]2.>:RG;$&I0(,/`YX$
MB/ZT$^[K)J7RJ^"5#E6PE$PESJU^HR87]_<\+VTI-*F/Y7CG9;LJZM5(PR/J
M#[--3!Q0)>KG6%]]-*4WYW&!0(@)NU:^=QPH,=/)TV!66S9^[RQGJ#[6:>$$
M0*0[-$82P[GGB7Q"0.3B230L8U$6GYWCF`W`V*K70DR&53RLUZ]V^&U8E*SY
M>"&U_B.#V"[\P`X>LUF=+^5537E_7?FTDU`D[+-&TH[\,LEVVQ[TO[N9J,G.
MHX215&P+)O7X7!,&Z35.\`:G_551>C/0R/NZOY2Q^J4M\IUM*RHN/N(\9.`Y
M>\THWE@'/^SM"A&/2V26OZSAE."?9;=U6"4A=CAD^NT'W;F"9";2N0AUWI'O
MC/17>J;\"C+6']?.V5O1O=VHNSY(%A;(4^K,#/L^\P8SC=C@X+**L5!100HQ
M.3WP)[%AXS_N`*A76FMQ8/?`\[AM%>I+GOIAV;/J](E2%&@TIY]+:JBWE/`P
M`&<ML+`8MC:^D:%0L7-ICT>-T9Y+,(9SY%2@H[G7!)5*D-3*2-%6+*\<:RD3
MO*U*AT^=XB5.DJV*'-U[;W.ROK3U-;QY,`1*T/:^G/)U`SYW!8&XZY^%S>Y_
M0.L.2@#U!Z.WTUFQ/UJ@-87M;"8-T0B>]*O3HQ*=""#W?*NC"/U5!U\1)%;N
M&`"HSE(.X@.79R5S_\V*P*$/_O5[H.AU\D7S`Z0I+2@E4[,7_9\C&[@D<L.J
M!<;%HHB,&SS^@"IDFJ&YIG^^N:Z?]4(!E$C8#)T&UVNI0%2VX7:Z,SBH+H1?
M-P)$[?WZ_^8N!ST1DHRM=@"7QQ_HF&-EN'QP.O5JX#[J"S?<!\BAP9&[1&9P
MTNI1,;^5A"(_`T(CYL5.&XO87,-0@#C9X568?R7N>+O&/AF:&);7L:#VA[-S
M%E5/*]@D]FXSDN3P+_(64VT0YD#\1A#92\?/(4@\S2SRBZ$U9&!@:B&F'VAU
MP`US-!MV<JUFGE,<M<`L5VIW-L<@T;>^KTW^$NKFD2%+7VQJ`/:AI//BK2GH
MW`T!5-VX&N7V(TXN)3#6JTI_APZG#X=TX0W#2JO"&\G*H+>Y*S1<H#N413AH
MB6W]W;OY<?E'%ZAVF6O8OK_Z=K^'N.Y%`UJU1I#'4[`1#.]HQFDU'2#^!T@J
MW[CQVV2`MS%%MVY7B2,49.>'E"HH,>,FRL&:3&ING4T==?,]0-02R<IU7M'P
M7,%-`XO_:,4)@NW;NT,A)*5]0OD@^(5__;FEC-*B`-(>H6'-5$K\SLF=B0*4
M8$WT:HMPQ_()DD"9#^8V?6755FO-EGFK1*19=V'/,9:F-V+-.MIV9VO<41YI
MP+[>WE/J8_E-1T8/P/6`5C1`63=XKQ'J/#'TK$;[UO:^$D&@!52G\H9!/995
M@O2^ACVI7ITI%@E)X=[E7]-Y/U8<\=&7#RW4;_P[[H%90QFJ"P](K@I*`_P#
MF]9%).VB88<XA<U,AJ)72+C*%P8C:UDTRU"OD.G%MGS5Q2H8_?&8%/R1#`9J
M'"RN`&K4LS2,`1W18\C9R(&IV[S+%K<VR=PKCIW];38J;,H*$K4D%$P"!PL0
M\46.:V]X[3`V`GE]JP^#GI4!TC<,-V;L3S1VC,POKG>'-WC#G1=$'\W>8K]U
M/QDV)N6/4*![9HH-:.1P5EI9+TE^"Y)J[LK.91#*-&I($LV3C-=%P3;SJ]T`
M\PCROTU7T8Z?$:NH'F7G*Z6]"A_$M\==8PS92?EZJ>?"EACG1)ZFAC%50=X1
M'D5G+O(.XQ0*JO4>*Q#BS#_S'.D(Z`J/PMV[4-X(>Q"1N;6(A+9&H:^)X>[7
MFWXGIJG&<YCSHL%M=EJ=6WBH%V4G*W:M<EZXKF$AFRB&O"OYAZB`!^EIDD*]
M',>U*R3",V-?]/.<B-Q4MYYO\B\HV)]W,QD<Z"]P]/?FQOQ;NV.PYK[.;Z7=
M>&^7JR!2'K\EKJA=<HQ6.,JYQ=O2VU$V2#<'C9ILSSYQN(Y\6S4&049!+`IB
MUZQ,/*<\^,TO<TU/MT,SC5T%N<N\#M*8Y_<?1^RA=*?RY<M/$8[9E-N&"2Q:
MUS0J"WZ,F%,$%T,5/R\U*K,L%I*G(+ZB)5W@."_[='HGS6M$7RO]-!^B(PB'
MO_*Z1>;OSFW50:#('E^%@-W%R#UH@(_=!F*N/-R0;LW^U\4R@>[^."_G1DY&
M,89)'*B>%'"[=PG9)*;YT/8.AN\S8O72;)-18<MN4=D$I].LQH[IDK(_OA<W
M##1#P4G#)!IF^XD`BBY\ACK$,=",I8*QDH.B9L:K*@WRKXL\3`I"\Y>`"IEB
MQN8@.?DW"ML("6JXHRLU7/1B\1,"*H7KO<FV.CP:(]<JY(+4(WGK1:=,Z)[+
MO@$'=70P:'H8*1ATG:9+2G*&>=I-7OR92>R?L\#T0['KQ4!_+I::?,Y==%1Q
MN?O0G/E(XI^E%1)IN4H:RT1W$N(D?EM=H2C.,IH-&]!U=F@<0&UH8?N1!KB>
M[-N#`EJNTET9E_D=5`J8RY4OX_`L=8D"`@39K+S"J(;\8@4,K"N4R-3G`O^@
MFDJ^^4R&/\39*85LCK`N-U1.T6;$8D68M7Y5UNI93)@40H)37X.?8BJ/)K2T
MY3>O1/3Q!%#:,*J0VH&8O0H0MG8%)85!2U$&#O/QHEQ;Q[[I;*_NO6Z7*Q7X
M%Q#;4:?BCA6AP5,E]Y%(T,JZ\E#Y.Y/)1U\AN`/_GV5J:'6QP0TYZ"98\59*
MD42DI/S&2^M-'1;PR@BHH@/P5<,\^7;_T<[U3PX&Z`06Y=-MA=X:%ES8%O`(
M`?%;7=VL@X_83&GSYN>AQO#4Q(1^R5LN5=1)1E2S]]J"$AM\EV=?--(X@]=9
M<V-!V3#T$SP$P[HW0V<V2G'UF<)&O#?W<R!?@4L_H:\*S??.F2!.8*LHX;&>
M_BOU$AO?=X`?)7P8*^J4RN'>X?(;XX.U"BE22BHG>=IET18L1<J/1M[#QK\N
M7!(RQIF$+,49D_0ZYEY&YIJ^S6P.=.W=CGF`%#)^(LT5)PP+)I>`'&.`$9Q6
M8&3;K`%:YK0BQC>/0C5S/(*Y:([OF0CR,)0J=9YS?/U=#F:AA#ZLS(=&GNZJ
M19!&/C@GQVD<@\!#6PP)DG.ED"J`ZO('E"5`]]\<('C7(ZHC2I//AR"_)^KY
ML26%46=S>4*NEKXN3NY#UKXF^SPYV@O%\V9V)IN:N`2%^)ILX9VT1+V-GT=8
M%/D!6?"NQ*>4$%YC&6\$P_RJT3N%FZRWJOC%J_PRIRE#J#7:)D(I'=<N8\*+
M\T,=,*$G2&^S#F?#N5SA).947L(N]3O9LZZ!M@[YR?GQ&3]^;*L4+T>+`PP;
MM8HD2^T^YT,.(`<D#N35C[4-GF)*I(CAZ=ME\EHZT$XBG_)+".=:"$`\N$0X
MO#=*8D/.EJR1BYZJ(M=U;E>T56GC?LR"#R:;*^/1'MI'.9PCYL!5S\OAP-=Q
M"W6@>*=V`WQ9D#HT.0"!7U%3?LE6/CW`L+5K.\Y@!4H:X!3REEFBF\_H6`&M
MTHF*=R9(V4E1J9A5]ITL*Z8;6,H72G+-Z>]3!^'2CMCS00<EA+P`-OT(!8&S
MEM4PJ8CA%AD--=.MFII(H!H)N[2>"47*>G\(URP`4EEOW9P''?I],>:QQV!Z
MB*]#.FA(ZR+@2.%?%W4?K7!3A"&L2FD=Q,=/FHCOU@``^KDEYH5F43BR'U6.
MZ^TVY',6T;1^Z[A#=OW\R:R31)KYC-11#<J*);FQ<R/2YINH-'$[_-;'+-%.
M&&T8+,@O#.+Z^-601Q&WR=4O2Y[7"[!P76!T=LX$'+H[YIO:7LZ<9+C`0"+?
MXKK.@LG05':H2T_([7E35*LWL=/WFPF3J1Z6K?M_\#F0-4\1)RG=)FE$NZGA
M;CPP5@6<%H#Z]OZ=#QK-+]O*$_R&3[E"-@`J=@B+\M5O;50!&"6,JB\L+P"I
M_/H_0@])59C(U2CNM8C#H;(Q8W;@.I$1-0ZD[%[3&Z'N\)-H(*Q@]ESSIQ"9
MKZ[#Y^=T;<AKY'.C-D?<'1S$OGOTA^XW(@R6>?PK6UE"JB=%FQ7(YA:R,Y@G
M5<&@Z1&8X82ENB'S+U%H59454RO]*%0857"4+**KQ0;4.!&9,D.QNI`_SI9E
M6Y*'`<19T563D#;1+;#A_3UA=M.J.(M2,=BZTG;T;;P;*+@^BAP6P41NV&93
M&>Y,=T@GX*)5.!AAV0:O7L?=UG?GJ1LEA-<)!GV_>^*56^#\B#*R$T8\J2BB
MY,O\!74Z[<">1OQE"09MO=OXBBS)^(9[)QQ'+B*%<:*3L$24_;,U('(@Y7Q"
MQ1K>-:RBLB&=NM=E*Z'0!97BL)J$]N;66,+?[PU=@U4'9'?+E-?"39#_!7@0
M`_IHGPY'^8D89>::D/ELHHRE<:V(+YZFP/7]<%>@X?1\GQ4Y\W<L-+.E^[[.
M`\>X?,<:7ZBB6@\5OA(@&\^7[>O:-\>W`&=Q&*0%8:7G+*1%`>)4=3VOL=>^
M]+;$JC;SQ?ZOJ)%XGA<^$Z4W_,E)Y.7JX/MHI=$'ZX^KY$R35Z)'K:Q=^50Q
MV08/GR^,K2FIZBR]/GUN[@)AH33]08A%K.4]G;E1C#ZCKE8;]Z20_A9MVYVO
MAJ\/G6P+!OL@EU\WZD5RP2?TPH/)9D'(*!<?Z_<N14^*Q$MNCSF5KY:("#IC
M-)IR*JGCOY//\T8K#\Q%"@F'<JZJ0(QB:IY6SZ=?EF5B.T*U;MH*TP?,K9>H
M)U`6P'U?0_FU=O\K[D<_H,II7:=\YW9L3QI94M3Q]H0A5^4?9\#\;#RN&P^?
M2(?9+>\'`<U1FJE#,EZCE2@4_@B[$CPE)N<+RIRMHVV?:]WD\D?$LPO4_7(G
MB"2?U[TH(I@9Y;B/(1F]BQE;+6XS[L/^J9297FS9`>1$_QQW.\0::;/S*Y`3
M6]=?)#O>]-HK?Z\M52CB]&@6//)90+"ACVH%.G).P"Y":^P4[TZO)?#N%8L,
MGY,ZV"D%0I"=CMKO13%K^>^]<.AM6N])=3OJ#C1JI&$BYZ@<VW).>-(';2_Z
M3&V)#9B;#,Q8W,\0KL9.5_S90BL<<=XU]7YA(GG6W3Z9GB-JZI^16F23MZL?
MN%_\T15%,J+9RQ-7MRNP;T$8%$N<9G,+"\/UJ#ZY`PT,RB0K.%"X)-'D[J6G
M0HT,;^:?7]S_C`%)M.VDE]ZF1*FU^JX<-DVS1R6[@^]JM?N[N,1>-2J]`49G
MO`AB6"N<.@&;FO@&C52G5O`Q58CJ)JBXC*N?E(VPOW#V,]VRL$VC9+\A,.G#
M+![I2TMP)\BO^'0AEUA!A;1D4ZS8/P*JF&.GL07^*-9BC"+(22J9`]M1W#M'
MED%*A^#Y&+)RO)MVU^<NSM\MKZU3B,'*]#N8XV7WKK$GBI`T#<?^VH?O]M<]
M-EN0$MR:&E(;9465]\D:="^+*]!,CL,CZE,*7Q]=2JJW!Q<<1,-N>L4W3R&G
M,)Y5_14,T`-`*](.V'7<O([8[,F+5YC-P?Z38(-0:>*(>D&=#8C&G&@1`JD7
MQV792G[3N"T!UQ\I=D^,N\%S=WQ]U8[N<JH)Z0`HN=-?7!+N,%<$_"*Q\<6]
M4-']2[X2=!@FO9=XIY"V:KWA@J_4BF+=Y+[5*E<I8,])VS]Y!?"]`!*6WRAC
M3[K$CQ'G+@ZB6+(H@48]"Y`M-3F\<VAQ$L8%$B\CF%Y'RXK9'`UV0#/M`A$H
M>-:G-$(<>T4@FVEY[^YB0W3H99S"+@:$3(8N'$75`'GB-/3CNL*9TAC&9&6M
M[UW>:SDKXE\A25_[I2>^_M?%E1:=TG4>X7$)K,*T5G;0&(#E:'DG?0M4ZY:%
M?=<W>G4LVM"2&.I:QI'Y0I6@<]X`)U$/<.=,)11=L\0AA&\OO@&P7-_=8!Q!
MZ$>H1,F@ZR/OK0/J/8`1$FPKNY&H,&A[TO"Q0Q7Q"N,]&=ZIH*8=<ILB@&OU
M)"71-T=67_WMXR+^%C0RV^#'PA."92UR+PM9V`LJT%-%K+:+.?B,'U`W`-3Z
M`EM-(4MWG6/L:9[@Q_F&U)V<=:8'8_A9\2WZ2^WT`J?+Y4:IA8Y?')2R`2%N
M?E*QIN#FT85A9"[($W`(ZDL1R;U^5"43D4.#I^P_#%E_$/<RXUF`Q)N1;V(E
MJ>1B\CHTCEX:DB',77PJ"_;OHKIPK:^Y:!!;\<VU_%]T<W#G<=.?MTE="A2T
M&HFQ64E(4XS?MZK*]/U$+@F)E-+%NWFB\FV#.NNG?7^)-M6+*P`1@Q*+EA>1
M("B$)>!(G\+\KK_$(+%@YP(CK<4DP;!QG0T5A>YL//I/5FER=O#(0O;/6@`F
M%D31)`0+H3)Z/CY56:CL9T\*_F\@GM*ZV0?=JZ5R3FA9B@%]].]L)01,>S_^
MQ1%K$()1'9<`_#'#02['#LAHY,+92/X$"Z]??N&_O7+VY]F40QP5"+:+L'9)
M`8M-,-I;*9I>LRY`.9=@FB)H3_O5`8`+?#3<K^P=#M3'\X@21`(1QZ5"0Y,X
M]O<T."-(N+8;ODG-1*]N@M2`/G.8KG!@B$E-3?Z=GJW;ITL+`Q?!O05T34T;
MV.HKX2G4!N//%#KX[$(`D]/QB4N_N!2]`SY0$0Z/Q^.THLVGKOT&S%/UV_+J
M)=ZPI<"NKI<A]JM(+)TG@6L7R.#K6PJA[VM&.DS[6/)=X3P>3U'$>7G-9A&B
MCG6=R$-^4Z;U[L\ZP<8<KYBT:<@7J#F=[91;[C\1"%-.\]T8D,QZF:ZON@:Y
M^(D)!<#;DS&-9-/"CB65S?I0NRVRX@2CW.3V=[T&S#+?E^"QY94\O+^"L$83
M/A@1"HP0LS?6^R'X:B5BIH0(-EA)ER)DWB4VCQ6N_7D2V%;\4E66B+@-9C+R
M@C-8U8+XKO!@L&<&<&K:2JIF+^Z^K1D8_%9/4?_72XM?XLR093W=`T);6@*6
MQW&O%/6)(<<2%3IGAP9&N1LI70F&C@*3*@&4I$@T,@\UN[44<4:^6C4\33I:
M7\C[H\M"NXF-&ZO<%HTZRL3"":V`JOMIQ.8-#^K,IBER@:,I'O/DO<Y(^T!N
MYAARQ\[J-8%OB#WCL"-6#/+)"9^AG<M7TWS`_#5\%]YFTMKL9N2^CHDU@T88
M#RS9M/,-[`RAQ=[5OUUWV&_SJ],]V:('5%#OML2!F?D3)6#;MZ)(_6M5>6+E
M@^5RUCV1^`P7]CI02_.BEV1W54_&;H[";O].8,-`[X9@.0:,.9!Z"Z)1/:X/
MKKD?"HMRFPL=UHS[_Z/5$";C/^3K/J/.`-_K=INL&.!R`:&*)&*VM)25'5;V
M3GF\"0#59ZIMB;:DOEH,,Y1[-\=Z.*1V@&O=<X<RTHTC5B!:W)070VQ^[T;/
M@9>0MA)X;$\`23E#+F^%SW6-VB!W;)RKH5,3]?``K/&`P_UF0O.X!,E8>4R9
M2^G]OXF(YU?=`B\TW6KGW!18W?-1#T.SD3D,799E1`&]2,4MYSFF;6/@#'[G
M+E".%A%)LZE.E=BH)NS?;9?%+)2MW<CO23FV2U+T3+#1<T74)`NFL,II;3)^
M9VX_:6HF)88S6N(J8KHW1;"2X^N8`QQ15\1ZB65H,H'9C%D?'Q/A+2*089C"
M+TVZD:3Q9IE(6>W>7[/BLVB@[AWD8R\EGV>%HIQS0_,$=\&M^+EGCMU)_8,Q
MH@B'<8LF/:S;8^Q],=_@3,B&JJ3>XRK^JOSQU:0..;"@BX*\,G2LT4-=8=Y;
M#L,2`8YLTY`-,`+%4P`VMRQ7.0JFZH8:RG3-+FUILU@/R.J<RL,3ICU<[FP+
M6[CEU"8YZ>$[Q2ZU0XEQF+7DF..$K"72M]XV'>=,<I5?.X-:<Y9:L@ML:#(S
M,:W5D'^>LVI^=N!*9%*L\\@_*6VX&"O1+"#>$!2;SONWB0>"2Z-UU*B]$:I[
M&R]S2MKES-*VND_Z,JG5+U]6CQ*A0DB]6?0#"4FA<5]"%.9$_9[UKK4N"H>^
M;9@WZ>GZ&W9C72$EOCH^7)*RP/#]YD\N_Y>(]:I;"8`?B3SD3Y8[\DG$'A#`
M0^14Y5^`"7Z)+4MLQ;"+#"K#7_4JJCO]O)`C%/2\`768*J8HZ'`6RJ]G_9PN
M-@;,U@QH;#0(3`.Y(T.$](Y-[UTQO/'SM_Z=`=JH];S$P26C7M9/H0I%E(V.
MJUSAL?867L@$ZDH1?\',XF>MR4;W6[.;H5EU;N(P75$#\,8(E,\+[ZKWBL$`
M]NL%11N&:00#>Y_L_5SUS`;M=*ASUX]9M,`8BB'(CV(M%W?E*_W&_IE5,)AG
M;WQ&8X=3J8)&&(U*F#-&19&,B2@8X-!#H*[O)@"A`T?QZ!]"!N0N<RM`9:21
MYP8JSU1Q<L[[AU*SC>!T"")&7.W24#`P`TDK0!ZQ[!WVD"OW1#MP!>9A!..+
MK%G>AZ"),,);AIG4X1<;;Z'Z#POJEO0\O[GE1+]Y^U<P.1I741B@T2YS\,U!
M.YJ-[XH_AMET#Q542<X>O[I9OL*`Y`5WG`OUB,L2,BZKL?<*8JLWG8[Q)ZH9
M6>-4Q=*P$5(KRC;IW1]^`453+BCS,RZ,B?0J;944;/H5M:Q$;G?2Q42$="67
M?5N'_7S)/+^!P<F<(:2VR]:#S^;^R`@*4>@4H5YL(;V8;K<65.,-WJ'7:M,Q
M6.E.8.Z&'J3-C8``_D\CU[7<%4MY,:P:+'["W\B/+S5-1@_*H4YB+B*3&[UA
M#!GBY3EC,5[5OA[[-?<QC,5!(=`2<LG#2^K]J@=*ZSP_<&AP(&5C:&\G/#\G
M.S\^"5LI'5J.^/R1XTN1+$4R;U)YU<%SG/F9D`;E[2U=(C!E8F*R&.$&&#;[
MZ+\_C6XI#>I'V?H*>H-*R(ST]J=8^5O4P!3(E!M$?]O"+S^).-P;;5C]MO+!
MZ#A3']E9M"614*&3N84?SZV=;:[#ZK(L0;;"SB/#@$K@TF;%B7H.D"=D!+Y:
M#+&<O;K;\HCECO@Q`]LP/'F'F-5*&/FFT1\WP-@<_#C4-.7'V6SW.^9LIE2X
M&GRBQ?"@LTWG[S4<E??H.<Y7G#[,A_?8!.=;6QE,(]BU&!9#LL2R_UA,?A4:
MEK">$TC$AO?Z`",`TS%I;+'N"83[N^Z`('+F-@2I*((T\(Q2J%T?I@6:QWRA
M\+R@!A+<=N^)TH[?P281H"^1)W6_;,5(AFP`W]\J;S1$68%W)V1TB.BT_*5H
M[>IB#E,;@5B33'=,A#9Z?&U1X_12[%`=4*V%:D1QH-;3L7!P_N0/PO]23W@2
MV@,<&&U-=2O&MG_W2X$OWJIUZ=^#0QE6S0&*`G;6%3C*M&R0;K_'Y()8%GKM
M8IDTW.]L[#;'_-\J&/6?9->AD#>91@FSENI%8"9FS?#I8;(VZ--^2:-P#$FB
M^]!,.[N1*H&$!+@,4&PAG=)!LV9=W(2M..X4TV95\`@8IR[3]"F\Y$C<W8U-
ME5,!#X!+ET@@C+J6HE/9=W]7(R@$ZA(*6?;BP!V^.=PE),LK)+7N6G&>W3YX
MF;Z=E/;^4^N-A+XM79WF-Y6$G1:W8N(^S\N2V(!A+,[[WNKTX*EL0C>%P_C*
MY-'R0`RO;-B!^;H?1R$]B=!-GV^$#'@!;%12;RW5B=L=0EGLE8$$;4:YH1M%
M21ZWPZ7HJ9[UM<EZ61<-)2BE.R^BKIZ"];MO7K:)^ME!HD>1JL"7$M'K_,"6
MO#=/2`4$2\DGO_#TO&EZJ>=*%Q1O]P=,X+/8%3<"D04(*E6-C$O)@5$K6,FP
M%:`O%2X-H,"_2NNV\F\6V/@=[N1P-/)'_%=JX^S#W#A!1#W]0E]<1EEC9<&5
MYQWYPL`9^TW6_\P&,-C1Q;9.30#(*;7G>T]J31M@-!0`UE,@&>239,;B>O<0
MVTMZ&DG43*3M^'W$+[/YO@[8B""\!#NF?\'!YVHNHNNQD%3%***_\AZ\;B$]
M_0S(Z;7VJ,EC(`YDO0G9.6NXM0%U&C=!U@M]GC.BWM*S<2LG#4_.N6.B8@=%
MOIJ;]&=\U52`R_)/+PDU_['[;"5\TOE("3XTA5P8-M@"$91,C(.M9]E-$3A<
M+#J0SN5.CE@%8FEUWG41T#T5:,Z<\=K4TP9Y-('9H\R"?EBFTMQ#&_QB1O/K
M2[!(F91-HBG?G'I"5Y@VD\XFW?BRG`L2MH-,.@\DBAW$'XAD[#WEF:1DJ.B0
M`.$73?\2)FHIN#'JR,MR114ETVJ(IA6A*B,6*X1_W^XD#E2P_-YN"(DZ+G*X
M7*O%=\V61H_YE-,Y4T%GF:$X^5L37:QOWDR_SES$\Z^&_Z7(Q,>=HK;@LA>.
MO+G?$G++].=0TD-R9XBNGDIE2(D5*:(&E!WUG[!.39-4'U'91(SC`MBFC]@C
M)K64F/)2N;AO^&/J@^@>NXD=S6<7'TG<L`$AT/X\E#BG?2HJS5G+;RRC?(42
M!*V*^]/+!A4__5*1*ZY[@8UNKM#_KZHIVAG.7$@ENSQ/U=?9RF9ECQ"!27>Z
MJB)./@P)RFAQ;3H"%:PSPD0+4/'-5&4A%Q0`'WSI:3V6R??UB4!<)3N\->OS
M>D<)TE(&0&@=)ASJTQ++.M"PHJ$6<ZDYR=FLB."R:7.);\XSJ5.,!UWV0@2B
MFK@Q6JI>\/"$?*G!7C%T.8U,[#O)?=]N#.=>%34^^2(QXYP>-/,CL[QEH5]0
M@?;^:/L.)]@Z6C_<+=QA-R)F`5`\KB9*16]2]HR<57D3+@C$?3&%UY/)=.(:
M>53]81S:B)PC)_D:X/\W)Y8O&3$7B%.@!;)ZT_N[4@(=$).8IG5?NZ6!4*<'
M1FSG":+5]7AGASO.^XJ6M6AV>J#3SME5W_G'SA;H^TP@T?`@35WV:_4?-LIK
M3534MS)]*U[J0_JVQJ<!(V\EM-VOI(6E/"%]03"/39F5QD#,!\>G(EJVSX]+
MO%>1V<\PNA722F!2E!?FFGKK\?)2]+.6VW\R\8D;$FTW&U>+0QM0;GT)9H#(
M"G</9WWHF7:$L:/Y(VR.."DC4>)BM,YCX*YIZ$Q*8;SB?,A3<:"TJ*PRBQU_
M&"G=QE<%U)5STDBI4K`Z:`>DD70$*)8CT\`AZOZ0\[9LB(<;QKIIP1DX+W6T
M4YFC2BXJ)O?%TDPFCG?4'T``+A"XY"5C<(.A->'GB]=ATN<W8E_*\W?L/&Y=
M?=!-#M$;!U`IO#-INWN'Y;3>NWN6:8)53QY:?4UJ">LA7N;8W>5#O)"5`I^=
M[`UQ6WF;.,'%#:/MZ@4CS!@N,PQRV7M;S24[::T_K9ELK9[K<5N`DNJ_O5[0
M":,OPC[34']4N.^H>50(^&X'V"*[<TE'\_&+H++!1P'F5ITIR1]N>,1&KK]K
M-"BY[#="&0='":'J@L/>YUQBHX<QQ6?L@H=6>=\=\3OE)IA*EDLCAI0T4VJH
M3)W+Z.`>]CQ4N:*FX?\>_S-]L3[(F<@\A&I#51"%>!0:4(KF!)/'/3&K/0;@
MV)G;S4B;#D\NE(]=AF]YNAH:5OQ:Q@TBX2)&?[X/^%:'4[!266:I8C72?^LY
MP!P;7`\)%HF]@&WF:-%G%61SZZO-G7D5U.G_#C4:D?1F2W`SSHSB[U9P07*T
M\_FYZ601-3R967G.$:P;H@"2R,'JR:*TJ,\JSIB!,&%V$3M+8*.&F<NL)8]T
MP_6KJKBQ9D6WUHBY9YL<L'!KM>M%MZ;1RI7&\+Y,#CA?AI_E*JRK,B5X?3'"
M2<<9HD'FZ&YR`6EM@[C<'0:%HG,UG>C!RT(,J0DH`=MP=H!7D70.XO1:#[K)
MM[[//$HT%2F$NFI(7*=2;T^V0A7EVY<^,U'A@)0Y)6GH0WDQZ.^</W-$8*0)
M\Y^ME:H.JYC?IKA$]CG-?9"YTQQH@TE3K!,[C5875,12/NB?%R;>UUAK;04B
M+D3-](+A%O&5DG)JF3:K7:C+LM*BR::#N(;OF)V9(,-SQYSQWH^4^*!*KG'G
M0QVC7=<N(`=Z;&Z8EU,*MR/N7^Y!F[E0'6^U9.YO#3:A^7_,8%`&C#I)3)#4
MJ0-E<L@L>CE,FW$V8S(^"VV"CMS/A45HX>&4D*-U'PJ;GJ)!.W%XAZG*UI'-
M#W$JORT79M5\F.K9!F-.TF1+0:1!UPL)IOW6=`R=)B;^R:BW+P0L*.L<3KW#
MM)#,4&>Z-3WX1#RMRYC57/\H$J(K#XT(8I5B6:T56A,)LJR>&Z6^%XN'S^*6
M#92^HK+EJD?&45XCV[MZ$%OHB9%V(`5--_@KBTW(<+YO`D-7%?2#<.KYDWAS
MTD[-(,<X_!'1>$`TXJ9CN/L>4/)0O(H=R86G8?,D75GU2QB&U1[P9K:-T:,5
MD\1C8@"9GR$E5\/'@)>"5CU@HE7*[W:RBQR/HM5\A+FP_X`.>GU15`^53)V8
M!6>#NLE-'C9:Z6OZ\2[NG&T5/!MY:*E+O<4J-ZW(7EUA!,.=>"%_:(P'NNOL
M'AQ&('\*GV6"R5>@WN]]?\L,*<`V<],M#:+3T7U9&X4!T'TWX/OJCZ0DO'N?
M&&RU=15)D5?]CH<PEAX=V#:CPR,W4C'N;NJY<M0P`L7WTFB53O9U<$3N];Z$
MU"*=E*K8A^4:P_EX]I,+SU/>V&J3AO1D9VZXSH63`(C1'V.R4[9D`NA;,86#
MV7[(RIJ4U6U9B\ZS<=?*@D++!&X^^^FF$/0*D$-!#KC*&/MG8J;6$@#IU4BD
MG>;E(E7P4U(2ITR_1.Q)-6H3DY46\":C>N^(GF"K$TG.5`Q5\``ZJ_4EP;#:
M"#QA.2053C'?K,<"JS@?[<OOQ`SJWR^>GL3MFFZ"^]9;Q<5T&F1.Q*Z?KH5W
M)>WAMV56(Z-+_$"=!]EH-M42L)_ZJGFM^^15\^#:P=;OT1'Z@!83N\J(*<2$
M&F)80_Y0D)^F?_OCJ7V:1,$SXTE=^@24=&=OUN+E0_;G9A]I@6^^=XV)TMUJ
M]R=\,,)07;8KTP>&!Z^@OC7Q+3TV>%#Z69PV<CMPB_5O-1R]6BPDAV3\A:\1
MF6?_$%\_J6$P&\T__!$WIA!]I1.8FW4]N:`\8FV-^4^UD[>.:<S:_SU)GJ,B
MDS_[Y]R=ZJ6J;O*YF4E1['&Q^G]0%&MB8:Q)#W6?6ML=>W&\W*%+N$KKXDB.
M!D]_-6.8*NS+U]M[]8@S@K/A`?`?O5>%67:>RN/T9]G'.%O"&'0.^K`BQC>>
M(^4_7I>RN(U-I.K\\,6G*3$X%:B2GCEYB1/-QC'QH,LJSB,JP\85=O!R?(/Y
M(=.>#]J&A37P"B8J=_JUTH`'/E:W?"P=U!9'@"JG:3T,N0J-P>91XHLJ!<@I
M,#!<S/R.0]OR)SL!1LW!KD:C4+--M]LU_=DL+<GHXVI>A8WUKZ>+QV50;XL>
MOP*O&.5FV!0MO/??[(W;%"AJ&_*?(6P0^X3^XC]X$,+:#L0J7)6K)V?)?:0F
MI]>73I3)OE)6P<_YOMF^UDV7OP)T_T#1^<UBPW/3-J4QJDC2;N$0M(RS6@",
M<%YOK3$:#-^=&:0^^5BS#Q5`!!&JQG"0Q^:7&ZM/^0D`=;#IK\^0`?)X:H5H
M%K1FP>*!0SM.]=(X#,\EV\;+HN.2ZA2%Y$<-I+9#\V%#VDBE#T%3&O6J3@9]
M`$(I$OUJ2[W.L)'>\F'[LKU#7CFPME7[F3PE0F8W5)"F29FX@M&8='MWBTU]
M2$#7!*;6#82^./39)OM!%MDTWF&D`[XSDC/_"JH,M-26Q](+ZN7YC+'*U"%T
MIL\7/N6'!*"Y!4B.#<B3O2B;BD29%3K;'.Q6GK-+2(RDJ(_PF2O)&`[_C`LW
MGTGQT3=]U`RKH7$-:.4G3Q(%>0ENP/G8Y&)9M59M`9.)<*SD:H`EAPS=O/\+
M-4'2M\9SF(%F09IYLDCZS2I2<J0#47P1/=^8#^@S%33=<G+54!BY&\L+[5@@
MK)K_88,H4&Y]+V,F0D$;`G]5)6.F:<'1([7>`HO2EQ=J8UBP[BR\1V`,>-I#
MW/SC`IF,.J5HY+$HPSHDXI>.>IG.)`(R+#9+YZV\P`&!37M.A_&/X`_VZK`V
M9)T(ZHD$C.0_J3:!57MF:?/Z80%GO>UQ3?C8>%D5$J=^I"0001Z#DT%*4M&G
M<B+81^"WP<-'L?!/GW(&1`#4A[U]8'TBU*JGD=#%GI:#X++WPT5'41;_CJ.?
M9"\PLOP(OI//_NFG-<X?GZ_H9"1C4W5DSFN>>,+SFYMWJSV*:PLM-<SO_)`F
ML,ZE'JOV$G"V5R0F7/;G4021/O3]G!F!93C;QKA9R3*S#\''G>RK:>#LQP@M
MHGR0*W,IX4':P?]##W5`Y%;ZH9&O1^&6/Y6K?D:HVN/76U&0.Z5V\"C9Y^,>
M&+FQ8711?!M<A9EAMX*KBOZ'\8<<_']L.Y)95/+0"Q#XBW?0M7M(**GK/V+N
MT4?\,5X>>)*?72XK$4G)O!'Q60YE]7Q=<@!H+C,0[,,.`5)9,A^9\G(BG&<1
M6@BZRBHYR;%8MQC8ZCD_2M@/U:YFD!]Q>83B+HPZC:56H):M=VABX*&/X'E_
M@#P\ED2W&?S<@NU/9!\K%O)8-QX(RRXL'B*00ZNLQUM&T2T^XY[72%;"7M'.
MC/(YBHPL&WB$>;LFKH=CZ:08(Y(=;L!%BW;VX:QFI])'645?,J,Z29-D$"UO
MFF#XU;\WQ+_(=V8]9#I#+HT.7)!S]/S\`K2$*5P0^X'M<E'*%SV6<R78GM^8
MD?P"!XW)WO6E.285Q+IDGD?BBOM^J"H]A)7]P4^M0&-_PRP!DV>6S-7[:(.O
M0%Z0(_I5`<B%E0P4B*R?`>!,[V+@)X1X.=R<?SFC=X2!'Q02,O3LS1<>U:(&
MB7L)M4[&)#*9Y8I8GZWQ![RR&>1$V)D;G5:"4F1D&JF-0/=04&KYA#(*\4KW
MZ#<_EPHE+3@8.%<QF6M&'J3LV07<;;Y0#^V;7G*^(9^;2=;M(6@O3%Q\"AO'
M'2-BW6,OB@AF;`Z8=;)LP%?6%::JPX@N`R)B/N2U4NL2!]U/8TY@WUP0T!3-
MLHA/?2,1C^[Z_#L^X+F'5#)56`SMTF;8+.N)4-'ZBBL7""=!AN#ATDNY6PM4
M49GA4%=[+*O@)0GO/&!Q)U@Z;`O]QML.G-"0-LEYZ\3O]I4;+$%<ES11)1?4
MAO79/6S6]%A)K1!1//Y3"F>(;^LQ",-4=9[438TL[3B`Q*;O;D>$!5!G_J<Y
MP1VBU[_(N#*WUL(<:B+@Q(E/?`;E&8YW(<&@!$@OU/R[=<63A0N\FWKAM2P;
MZ>QRUUO")$WNX!59N#I?Z\.+PU';F0@6&=VFN;E"]L;$9,;QS0#J"O_T/WR)
MJM<<*T!*H-FKQQ(SW!U+(G%PO8HRXI5HID:U!R+^9=.E!G+)3'?2"%6.=B.:
M4K=W_AX4;I%%R^1UE'R?OM9K?7,*,PU_,7(T"L8-;(_G:P%>H7?\3S^)4-@"
M`T=-G<;<V3&YE+MQ]/X%L)OQF1=]>%@[--TQ_J6(=W>/KL<882!)S6F4]A=`
M&P\8Z$A1&O6:JTHZ0(`U6Y13'6#"X??ABFSNGQ(/P6F^F1UY9FF69.B`@32_
M)4$)C/Z?*LM@YP5+QMYB;AVG\G,@BFCZ@;2/'=UP]ZH<VDBXG6ZCG\U"(5HP
M:T;)@Z'FVBP.79U)+E1>_$J8?/O)PNCL%PR_%UQ.(W(6<?R_N31%/A7`:*9W
MY9LTL$,R;>@S=,5+A\IMI?PIYE?0D,O7:P(;<.Q34I$6G^4B^!=@:TY;9BW8
M!@F#S6=O_%,P]Q'468M=FHJ;L4&]REQ$ED<D6]C.?0[%\7U8T()<W0KS5R9/
M>LYZ-[$H;&ZRIJ_\#;H;#5'0EIF4+OYB!,(IJ+!7EE)0AJ%[6IX#8//)0YA(
MT48[9*`$&JO#V"P7SW$P3&?`I+7E1RZ\-2Q3>1UT$,:#%H9K`#C3B&I(4<YZ
M@B1M3-_L]B(8IP#"K,BO3-@'U:&TUX:L'LY?B.M-T)VK=;[:7J3]Q$M2[GE,
M[%[P7N`7K*)+@"+W6['F'\O&</[)WD)T#5?"87`P!*H3Z[FC5^=\>06^NL"%
M8KT1%1BGL*DL0PEF]5+S(DT35`06#5/V79'1VW=L$6+<Q3FO^GFM##31%38B
M5Y9ED!Q'G3`J?4HFZ5[IF05?!A(:0BCX,*MEX+#OI4GA4-+*0:MZ+^;Q3SHE
M`6OB8TB5-HG;VQB/27&XU$9]7E="9K./`M`9]Y4>(E#P@G^MB&O##]2[5/TZ
M>R#)3K-8Y?;ZTY+\OOVD"AC,)C)?L+&%@SDR;^`@8G,=LY*\T']XF.QA0A4C
MB#P6K\\ZT[]/Z\#]I:`$?JL/NH]BC,;C))79ZLY!.).UQ9X)V0<:\?@>@Q#^
MBWGQ!,X4>M+,&I"O;TL"1@_WTFH\0W,KAJ/J0!/XVL2PYI7G!-17>EBXN(.2
M`)/4B14=:&@^$<`=?1!&9@,7E^K-(O@%ITC\N[_2!<7&2?EJ0[Z1)CJUCHRF
M'>CLK'0`=[-/X5-94ZB[%>:GA6(O$NJ/KZ-'=JX]D'H`'I/??K:_["N(^L(C
M3H;X#?]F"\!0GWX*D#+MSB5+4.B:^R'G'CPO#?RZ0W2`[+O/'&!ET.V`@"0?
MY[9S[X)501U-1YH;JG&R^E]YZ3"77@R4SNHHQ0^2,)K2U<./1"8-.WW55RD/
MX\J()?T&KT_1MY.TGQ0\DL<H[B.;Z7W0QY;=?3&U`=(3)->YAN,T)\^H]AH*
M$6@7+X@`B9B0`L:5^O+'X8U93^$S2G="^DF-OR'\7X/OJ2L.MO;,W&QC*\WJ
M<3"V3!2D4^P"D3>P6G4#&2-<V12_ZFX",-[\Y.CNR,K^@JSP,.-`+1JYC(80
MI!(5Q4$_.Z_K$@$VP.NT5*9^_>+@\OA9R:;]C^P`?R/#E0E4#'+[S-F.W%].
MT?!$7F4*;B!=?/<GG>[8'\Y0B6'$P@SAR`&,8,#,?#BI>2?\?3$@2_C3B08F
M'SS8M_IC0!2ICI4&<!QB23S`"ROQMG`X2$-I0.Y'`V7S635O@CC2R.W2LVZB
MK)][I8GL.T@A^BB2X@1+:+I$9D2#*YE>[=9X7^1#-$\EB@@+-EPUC/MG',S'
MP\UTP1Y$_,"#*&5_;N$%(1^A5:6M$5=WLDEO*5#82A"?XU:S"Z6B^UF5NLL"
M++M'!8T%,>.#BZ2SBD%6`F:A]IF2JW>JUPXCC'[_/BRJF9108[-F">I)D@J7
M;F.=P(B4FU'SD]*;DLK3)SAUNR)E+!AW6*+]+Z6@7)M`M[ZZ_X3'.F'3AO/?
MW^2VN*`M.AG[3X.L.>=`=^2RUMF+PM?V@3AJQNT\GLATOAH*=[,ABH^DG0;'
M-R:#%_MZAY=QV@HUUVV2](H8\'$DGR`ZB2P?8++V3,WJFK=)>X>X^(V<;@U0
M.B$SD,I6OPLPN.&8#L:@#^:`AZ8\[OE(RTT#`?8=(!;T4\##'U].U19/8C*>
MY8B)$>=TW53-JY8N4[/MWE$;DL:\`02B.![RAKIV-C(W93_Q&"D:$9<(8H"=
M='U\D(7FR0G#42*8V.AV<S>P1]%6]"R<1_1W?2T>PP&OP-"PA]L:0R;.H:[$
M1!Q_8U1QS()U7P;#%AO5J!$<A+M5P+\%OK>IP7EC8O)%6Q_V)[NG@/=3:HA2
MF!+158;CP[13%X[W)VFIP2_&F-="U6[_U$S]"A[BDTH)+."7IST=D[5DH]^K
MN%<*X,"[YPV"]S;/]7-+Q/]O#C!89&ZIPIU[P5BA7R)JF\I9DXQ1#\M=Q'2"
M?7X1`"6V1*EF'RV)5[TPJ_3#7YR@"WVC2`-!=N!DPSQ#&(S2!A_\;J`@U;L-
M[Z;LL@S`D=<2*L-REI4^O.GVF,/J[XFB"'/X1,6>156\I)"_BW[+X?<CW3N2
M^\\WI9]E2HR3;-::#:PU^R<,/;R1FA*08.34-4LV4D4)X!O?@/%2KA9=;42R
MT$2E+0+,@R,&BQ&)QF3R.^,PVF@_"%#KU5XFC/M!BMIF(]UH5MVRY1NC!?)3
MS5(7<JQ:=PUH1&@F+3H-KVXL$T8Z3PD19_SR)W$.T[1J'6U9()W)_F'J,7DD
M9H-U3ARWZ/V/*")A/G1HB<$S/V2*2FLQ<V.9/\**>%WR[+0I>6GOC`T$4NB`
MT@PG#\*P+_1+"0IO]\829HB/?5D%7.DH(IH50JQNN9;@O[ZG!,8TUC5K!&=L
M>\H*4MYB0M[P5&#DH1?>._^$A&%O">^Z(F-WK`+3#Y)MUMB1;,(H36<@6[Q+
MG<0I6>*@;1,5PKT=[M9^:3<K+W!C:0Z-]<UTAD1F6OIR8NPL`B8E@U`]SHTR
MU.`,Y#!U24':<]$J5P]RD119J`0!,Y(5/>5[Q;/=D!@QS[$#A'1'`WF'=87"
M9K9B&RM!C21%.08-'>I6PTV#A!R$BUY9MB2])/DD9TL`HA4>P![PE\M*=;/=
M_Y,A@L$<W#Q5"<ICA1[E.#)+T3\<K\MZ_\O)AUSSL(7I^+"M`AD:#VU7,[*^
M@ALY'K%7W*UA>U!]T-ZK`OV:SM0YC+@5Q99=9A%S(W#ID0MH<I'FSF"#<^=Q
M$_?[]1Q!2-K3LVGZ1?_K%\/($)JW0W9`9A:-+,Z]X/SIJ5=E&%ZD3$NL2<([
M5"SKAA=6?%@Y+.=#G0F7Q0$ALVUA7]C!6),;R5I'H`&H^<?%VK>:HU$+S4NZ
M0Q#Q^CJBLCK%:SMV\;*+P2XKT=]!<E.JAP!."EKGB\M]=-IEII0D:34`A0/T
MLGYGH>DVO)-IK&\4RIYF%:5A*\YQ;__ECVYH!7*<<B'"M&.QN]C4-NJ=DALJ
M+-CGG7K!67\LX5+=[H]?"9U[&45&HLK5Q+JC.V\B$.JQH2&S0I2NAR?Z>2U:
M^SJ.A;!)^0R[35JWN6ZEQ$YUW-J6--7IIQ-^_6;&+R\4ZPSL"&:<*J)1_=B'
MQ9&<YP[,8N-&`^G4'RD.'#118'*6PG\!K/D,Y+F$<&X(KM=BWN-$-^*W]+RO
M5M.JM*>\+=PRG\P5R?H[&2$*`ITEW^DL:$"_OVHX&1"$Q?RB+9"NK>TWXH/:
M5L]],-%F<B`=3#28?GI^.5I$XMVJW%>AG:YP63;9N[N/F9@N#@D_-GOQC](T
MF&-_$).8^VX^>TIJ&3H(6;(%P&M1EDQT=G%R563G?G))]6&,Y;_)`+&&#[)`
M?!OJ;R2N%*-O@S3)4'$J;\YL3=1FA\/>T?V9.^=-O@G@IFM<%'/>\8G>M5!T
M,2U6K\/E[;O'OF9U]4UV20*.5?(FU?5],3S->E`49?X]C&7S"O[K3-0,ASA9
MQ^AUN>J-I%AT.>>[*?,43+8<I5!K\R-VQN#!C_;*PE8CM3?_K1)1?6`PL8`K
M`!</X`K9R_2.`,)<VL;F]\;Z>Z'#%U!KY/876[5,YC?F4GG0QU_ELA5;<L98
MY#`\`<K/56L"ZYZ.,$@KF&M2V7AH%"BO&P%4)0^CF)]"M]$=??5.??N.V(-!
M1*1<XW&C+6SH7%TAZD;$T)SDTDQM&5.V_ML+F.@YGD^C([;:+O`O4&2)?;_&
M6_76IKAD6:&<N"AR@ENQ%Y#2/IGY'+QJL^:5STHR[$&B>5$J9$A?F[)$>RO4
MD[Z7(T@U@BNH*\ROS4YU@6L-M/;R*5:JW:VN%UUSQ"Q;_!?>[`</NQLF<IS7
M0IC]49*:Q]*O'"+^SM#4T:R'^=$5!G<\E)06F#TQ,;LPS"9]E"6^A_A10LZ?
M_<ZCL/>9$Q4]F_="-06*M$UE#Z<M_$KUE)BH]TSZHQ3*.SV**J;K]Q[GHD>6
M!EG^(&%*3*)L:YEC=]HIX$5L?\(;>)25%D,?B^T5<,5,H56Y\U\S+_8MXIZ(
M$>.[6?6$'1C8>'4GK$:#'=H'!(%0QC4LJ*.*6CL$O/]DW.G&6;`0&E^/@,=I
ML'1CJ>4T!;I;=F>+85`W2?\FQLX`YX--U2)6@E&SI$'KS`Y!:`F3J5#]_NR[
MF'S0D)E-3\V*F]!R=ZKC13=_7,#3C)E&84UH@PC3=C*O9J(35,Y/G<#2L;9>
MJ0/)Z@44^.J022U712VSU$[!Y!E#],&IXQ9S:)_$9=T87QB[G;&8[QRYTSEC
MT[C%X+V0H1JZ<%`1,&W%VU&(2.C42-/8:2>/_N.7ZJ#WBE7JP$NBOZ<$P:??
M!S#K-SL62*?_7XI(K@FX_I?S?LI2;LUG!T,<:#D5?.%P"]@X-S?Y22_%C12E
MU(ZKR#X)\/;Q]4O2_-IRV*P+QY.68R&Y[(UR>?O!-U<]6T4D_)/G6^(G>430
MBT_`5]:ZNW8:*<'):RA@`[Q6"QCOR8?HY:BGKYB%0*Y[:-4)\@>/\DK7'AH/
MT5WSQ$1LDNAP&-47&TFOLFKG+<S4,;]5O&IU[>N=YR97"FYXIV)E4#^]GZ!:
M11XP.Q?M1"!LSP@68:&N\QG\O4<]Z>"1+V'?[2UG"G?NV&[IZ'.JC+TD,>2\
M6;;KA4HI?&,3%%X[M"X%RYZLAY+SJ7\^7L/>I+=K8A[;:$1*.8BA86[0[7#3
M;ZJQ[T/I1+JX!M"'"*JMV\`P*.F79BR_:V3L`*`Y!&.%CX'M\VI!ZNGB'8!I
MPZ1/L&)MOA$/;V_35=EIU?J!D+@@LYL92G5K!M3['HQV`[$!J@T4$[2#U5QF
MQ'<($;QQA;.G[:Q8S[!=`F:&U,$42^X*S+1`#^''/B\(<.N#\"'_M56/0DP`
M-1(=6#8JI2UG>IPCDSM0R.<A'NHA^=.M#=N%MO^T9DAEI37K_).^8PXC%ZY>
M9G6X`Q7SLD/!QU[?T=Y`%"Y@CU'`_9BH#AJC$*,_?8DN0;5RWP!`_^(_6>*B
M#+%PE01D,G^P2%S7M@K[Y\:,37-*AZ7Q1[*J=\7)>:T&/^M4=N[#7"*=ET'.
M,O!>!NYK0RPG6PW6Q3>7R::=9,I9&\!B%'=W,;'+-:%'VAM&YS1SXRO>,U^@
M3`I>SB)P2:_4TH@$_@POZ:%!J3O6NR\S56UGDWE68077B);?(_B*B"CA7H,<
M(S&RV\4%)#7$]Z/-615*95T('MFE;>MH`(2HZ$8&#I'@(I>T@)XIOHOC2X;%
M"=)[S'"IH[#I?"O&"[]5XFTFE0X_H'TD:8PS<Y"1XL>ALJR]K*+7JYQD+Y1)
M;*K%LZ+<BK\1,>M]J-"),>Y.T!E^Q!:II#2:\,G0G&SI91\J^Z[>Q@QUWW/T
MF`RQ7$:WU=\X\;[3N-ZO*U>AA"V%CEOR+4F1*\"7[A'.M)=>$1_O@B44EOS7
MR1<\X$U:49"%:;7=[7R2OF0LNKU>!4#[*Q+^@Z2CVHO==`U]>TJ3=K1IQ?HS
MHC_8W2[,"[KC13QI4<,V2!L7WH141L_RZ`VD93=L'6-@7=:*5<@M25UG-J^C
M17+H5V!&7;QZQGA34<6C,0>/J!K<FTG#<Y[5$B4)RB=1)_D3JIC.'I;=BE#X
M#IFWW.I2>3.:9F=Y/,`NR-0A3QDVH6FF?*,4I=6+X10S0WN<(`+-HTU;3WG)
MQ9V>L_$P#1+HM)G=]!HJ-O6J7:[U>IXK_N?U&SX1<"Y=!4D2]-E@TO3!JS$$
MU8Y54&J/ZBWUM<"X79)(DI0")L&+N5M@6O")+KQ#(\6%O)@BZP><^G/C#'L7
M&H\`RH,M0QK1@/`I0@7!R7G@,?Z[I)AN7#98*+<Q:1H7%%8JI_;.'!UF>BTB
M<;6@"\F[`-8=].>[U5&O;>[DZP/UYS,D<B*'%O3I8`J`5Y\09'^?G0UO0"HG
MU/?S.\UD;4TVU^.#PUYPTH554R6X1#.5@,-W3\RNC[L&_T*KSA1S3=>8W[LZ
MV_%PGHS3>7%"G++.0)WJ%OM'5"Q4-08<AT27&GR"VXV(HO3ZWWVA*A0J'()G
M/5=`,">+KX`,&<*VJ&WF&^97R7[+[P/@#B3\8F',2Y!BA@*]2@"@WR@%.#\Q
M1;%<AN32D/7>]_AX=?3"A#`[X)CG>^Z5%]Q9?UK]A'8[&?/C\_2^8H3L`>BJ
M"1V+DQ*ENCS"6178V4/#<L5UU4US]<^;A8-Q#?ZQD7PMY[FM_5DNQUGD4P0@
M#\V'JY9`IL8[LY$82QK"*;+,VWN;@U,/MJI^2@8H28CM<^#2?=&AM$<,^1^G
MP/7YJXK2W+9J6+1O`9Q:4[/G=ETQ[6[VI+5BBS"^%XTD@+NZJ05BMIE;A`PM
ME2M[M2&4=$D1*]$3R\,?;IR6@G&12KY+48MIY#9]F$V&BFSIE7Z.LDMQ:0N]
MS1Q<R'MT!F@\?'JBN9-1V'5U7R*7B(,^V0Y_I:LKGY))UT9L2><44XL\G`?S
MSG$3\E&&P&<1C,UWDI[B])+5$-*E-MK:%]KK`@*,1-.VOH$>K_UH;^E'*!I-
MD$'+0E*73F,H)_^6?\UZ@A*XB4\](J(465.L3'E[F6?+8)A.S.98EX:.=;1T
M*L^JD"[\=Q*#-*C9IZ.-CJN0A0XSI44[0$`LLB/26CW$C$JN;&VT)'V@<_"%
M($CH2)/_!:V-Y_*%M.N9+'#7L)&'<[<G3Y]&>/S*F-I_66U^"V.;D1\H+7^4
MWT;P0`O>V0F+8MVP13T*6$^J"L5`*@L7><Y5M":(8M5L-E2QQQ`T/8U7KXW=
M6`MY$@B7>5EL<>)$4'O4::MAWGCJB37J!O.P7O_'+KB)XTKMV)D5AR%'BE\H
MLV?WLGJTMK_.#8J9[*[L7Y`LQ_&9%2+;!.O/.BQ]%G4:!PZVK[U@90N5H/!,
MCU+&4^R4%@_DU?=V6\#[PNDM6VI@GO3?CQ4+Q>.I_/J3=<C1UT[<H2P<C^T[
M$+^I7%+6UV1""NZQ5G^"_!`Q?T:QY0EV&3:C<O&/4VBGB*.L4[&O"%2.^*.>
M<+[&#3-C0_S.LGU.ALGE?GVDRGKN!/LE4$W1;Q0>/.X]D!J1+E"U#+)U2N)]
M07B0@6.L2D-!/YD%Y/+U./+)G'"*U=A8?F^;B!W:<<NG<W?Q*\!GN!46"?#4
MZL%`+1N%4&X&M+II5AO!I`03Z$*A;=Z6;O[2*),7"GWM^#FIT(:NU=%:^*]I
M&/?3-(+QR<?1H7]<=<UZ28.Q@E0J^PK6_^.#V4YO'5$]Y?8Z#_*'+5[]!S0V
M?5LOZPJ/7*R^K?^-UU:T'-'0XEUE8]&>;!6#N0082$*S`+IYUG@T3Z+%A`PQ
M&BL:+^A4R:S_Y<[@G=-NX1"<'),&%L]TWZ"-('7*E_`^5X2#&ZG)36UH-Z)>
MNX'--8UZU2?%O>MQU_W>D-N=A*'`Z!1KW6>J6G2WW0<_^^3RD+N$4T\72Y72
MRDL%'KVR3MHI36;41BM\B<1RDS2@0;UVE6:4:.OE@WT!K9!/9C0M&'P?8WKM
MU>*#0%`>5&6U'RG&:S<2=Z-R$3^)^;F=$[L+.C:JFC:A32WP\<@`2%[GSGP1
M>ARD?A\V(C@O'TTV]>=_U8C/X/*Q"1(094!HTHQ`OOR2W;C3#=$HN#Q5A_\G
MQ"7C.=E,QX!F*"SQSQ,CPH..LPW6+6V>E?$R2?`O7]T3"MM/$LK^OQM+.I&\
MN]7G*E+PVQ=M*C/>21V8A^A&(EZ3D@@&'Y=VZ*]DW_Y`))*T;WS3=X-2:;4!
M3BNQMM(YM"D^VFD1:8W]X;C]-MQR6YSSW:+Y\K-3OZDLW9GY@`WV\4W2=HM*
M#W-88W"R].K<#.`[NW*>?'W,YBW["MC>^5C2%;!M+61O1538$UOGER3%5X;"
MH*JI(/RS:H7Z&#H=B0K?AF/87I4EKRJ'EG&K)K3A658R6NN'R(\IM*;5ZC-4
MKD@'Q[=S+:,;/@('<4N:3"N9UM`Q6S+0BM%W",J\B7E82D^DT>HI"PK>?B6+
MKC+.+TKM8^9>!2.D8V,W\I]09EN4X-M3#3Y96Q..QSJNZ#>J?>::.2USEH34
MAI_@6_ZQGQETT5V#ZL)N<?%S*LG;7+D3<U>7OFSQ/E`+$Q1$M_`?CKX=W]F<
M%M\4=1R@'U1PY(!"\FK1T2]B43UCE864$RMUP!#*]CZ:3#E>9P%0E:==\;Q>
M#,WS+DP?105X(1^@HMEDC*A(3BA(4,?^()V$\,&T#OB-G+B:L:4A,HW@3Z9:
M52M>%R6G;KUV:](SP-]0XMMSY!9'U<^K&XQ),)WTTI?];]Y.LPG6D?)S#E?;
M.S@I%974K8B'GL#P'ET+A]YU5!,??.V4LTR*#T#55S?2]GXCJ4G!#"2(48`R
MUJ]/P#_^K=0!&5[CUH^G\4\J1(6KMDX<V/Q63\M^V<(9'"'R52%4`,77Q=-,
M.7FM0&MDLTIETU31S;2?GB8$.0C'`5P3!@VU3>`0K$>RH3DULZ"GHZG&SA$_
MKZ3L7"]'?FX(?K>FW-ZE:K!D<:3RS.>Q,;!H:E%ZN5ONQ=)BK)';]0@-2QIL
MQ-#V_SJ6L;)G$U,V>4$8G($W:P%D]_]JX/C^$G@:;9%?+V)-]O*-^3NYYAHL
MMOU9>4B>6D#.4I%3^.E%>J%-R@'NK(KZ(F!\/20W9E]]=7\-_L:"R"EK:D01
MCF4ZD52C1Q)8T\(@4F9Q%!TMQ].FN+&?FO=R?>O2>:Q!Q<]P-&I]PA`@OB&\
MEBA,,L(,S$!=]V#X7O9OC)8-(B67YD`5^JV1D^E=SX=8,:]U`(6"^?.1I`NA
MZ8>2+_.#B@9KK_DYTYHCGG=>""/KRRZA`2-Z$2_?UCEI;-W3F!S6T;M.<,'#
M=A;6QEQ[OO[=WU_JY'UVVKH!V][SC"HD65=+;W_B6JC2-\/38KF>)IG-L)5<
M$`0@13CN%LS[OA91_[C_EKIR5E4)]<\B#U!1VF''2YX'JCX<ZMI9(;@S^)_%
M>I#R/;]RPT3C.TZ`U9X]>KS?'<V*&*-[@-5@*M"&2V6>N<J3$KRGTP`X:(2@
M+=1I>G?C^)`([[$H\1JS<TJ;^^HE7.N[H("-7Z.+K=O(!/]YE_8>^CF.+^X;
MS$`0V)S9!%Q1CTW6K0[/V(I?-.7T>\&IM7N-9Y8!(:DV`@?5,%F8SOR"B*Z*
MM_O++]_Q\>65L%44%M`[CT,)QXW;FGPW+K/7OD8N3<`E(O%&-KT;)..QW8NK
MV@2JF/4=0Q[7PC?D)H%+.Z^H\2$E<U>"4VC6+7_$D2<MM1W3I-N5LN\QDD#Z
MM0IE9,/.(\8*0X,\_6ZUV*!7,CBZD25^_`4^1F@&-@0\L<G<-.,X%Q$??``>
M33_D83;+?X#C8/,#@V?+X]3P;CKU[MM<L,OH:D/PV7&*TN7M)4M.8)809#/9
M'2K`3V%^>/!.,V9LS,,?``[N.-EMM`$J[#R-*-AG_2Z@4?8AI2KS,VS`\RM:
M`V%=VEOHRN4JE+P9$JEF?96_"8,O5_1;P*+23D%2^C3_"/$E^,(`$4`]BF:U
MI0'`FBCH6XIFB&%\"6J3M,_SJ5Q9I%30<FB$;KV%C3V$RUNU^\49=QCH_W^$
MTG',X';VL"YB*GUP@[6E\Z+C&BA*5:BZW9KWE^R=0_#ZCU9BSA)P1O\<9CQL
M#QD0<2%_L57BD\J4Q9FGQ(QN>H8+(")5CD@S50M?&?-/V=TN09*;5NHD^D1[
MZME#@D8!BE&E"N^%@J!MXC=B%,`?!S&$P*HVP-7*:K\Y'<N$Q>8;%1S'X$!%
M!M%*7\=WGULO_+"8CQ_[R+1^^9I?A%Z]V$[E-K.L7J"*KI&CNA3&JQXLON[6
MS48(T;:<*6"OP4@6S#7?O``.9W^2/A0>92NTT59\<UL>04_R-P!$^13_EFEY
ME1,O0+0A=!P&75Z!I^-QA_"AYR:T,;UDDC?DRB9^GZ%^"F:M%HCT3<E1\RTK
M?P>9`E2;T-S`WU?#XT%-3'IR_C_S;S$N]AS$-7"!1%CSR3D'B/TOGLN>^M[D
MO%$BC@Q#?B.PLUCEW&0^!I$-V_&9&SU5A&$6R`"9>WC3&9!]K261@Y:8]3SD
MKWN-AT0+RRGWA$K[4A4V06)GR:ZN`2ME6+I4UWF1>9(*FU56)/M0'Y12%[)[
M'^CY486U:?G4X9>KZCG5">!]=Y9K`!2OT.3W$\NF(MI/I?JGYT-BMSCC,\N?
MF%P91N"FC#[6T%<;KZJN4V1/N4"\GU$96P1HQ<I(VC<O`L:>Z0#@R7S.]G]<
MXXNZM.BT1AKC\#JS8&'R]+F5"48Y+CX#Z>LV#!+5WB4K7=`C>Q3U9AR*[$(4
MH//D8;1.!"9US>7@2_48Z3HM>_*7&X?(2/'`F6/F>9B20%8//;=237I_R7BU
MNL<@1CY.*-UT3H%3HBP%F))L/G$[HU@I;W7"<Z_6\N@->;ELUB&I)Z4.V7V/
M>*K%*ZR!2,A[;G;[Y,,QM`\H-8HZ@\26Z@BC@6#0!'Z;#J)=;H<+QW&W<A7`
M/^X3ABMJ'TA<X+VF@&?LO==!0`"3%2!XXM^X(EF):U\ZY,Z3*PTF-1TH>OF0
M1[WIC0TT"3H@C?)C%20,F1^0^7[2_?9=0+$ZM:;(F@,FK'AW%*$3(3-*0640
M?YVJXFUXSH%=`VZH`C9K\,U7PC_;<Y*;D?KP.I&&%GU7O,-R:>G$+6N@(_(?
M\6U0B"QI:I],K@Q%@33"HIX9O3,8@O'/=C?>DU>OP4!2/\OO-K7&X_&ZT!L4
MX);1=P+WFN?)')@[?*+,=M$N;ZR$XQ4KSR0WB>QW6D`,.&<>M_R`=UJ:/M5:
MK5PTWQ);!<X`*U(P<_,&TX>D&)A>%)3^*0TDH+V7[J%<8DKQF2!XO*WR]6)8
MQ8S\.!VJ8=8^C1LKMU<-8LW:R4>*?TD4,Z2<>6'U_N$`!ZV\=OYEU&OGSD(8
MR+V>#P8`2ODP,Y0[XGWF8E0^)O5`G$G-\Q@Q8]>UWG94%6E3V`5`5V"2P[LQ
MKD>OXJ\2>DUM6L4>U'2.5W2&WFVO/JU#WF3=%U#N_G^#LA)Z:9<S%JJ<GR;L
M'<,1/<E;1`72_D:7>]<K!($>XHVUY-<2'JW]X$MP5!-\\QAN0\A5)\3!=/@Y
M$U<9FV+?7+'97)-3Y_I/Z5='PSK!DBB"G>IN&AV?<GF5%R#DA?C&+4=U;'EI
M1E_$'??7Q&02$+[KZ@I1Y)'6JC!^C&[6`///(!#EB!U%>I%;1)<Z2+KG-D9G
MHTRM$K?84"3Z2)T?]6%+8+@[M5D:)'<8.CK(X(2\DQ?:9G5FL%'(HPJ$:%]5
MQ4KACW_254D`]-)AUCA6OJ]^9Y.`4EY/O8P?0=AIQMQ0*X(H?C\M]$4H5DY;
M(!P\_`^FB(83'%'UK)4:WEEK?*]*'G`RH*J#L<Q;%0&HM274Z$&_A@CQ%#D^
M<,GC0Z'3Y/#$@NSGGU`M=T+9=:1`*UV)J#_FICX)_\&D1ZXS@E.-OLDBHK?\
MGS$HI@#(_&-&O4@6=+RT-;W+"@W):)[)%5815[H&@Z+Y4'[EPO.N@S/X98(;
M(.K=ZWWU@D$OA<+0_>8-]"U>OY_MPR*63E0+@*C3G^51VG.2YL>?@WMTI7_/
M]LSZ*/JP>M:JHAFP`W1]T:)#OLLN;F_7A)Z,1C5`&.CY?EL*W"J]C6IZ(\$P
M`#T9ECA&$\*&<=^;9[CARP?%S299R.R<L'33FX<NBQ"^N]]4TN%;1&W1/&(2
M&$JKQP+5+P-46L=;:EV=KY`@&M593::*;OS9O=>0J#0G\D:7&[9,3'Q*'&EE
MDOGJ\T?UQX8$HG\Q[^GK6>T3`=(G+*M`Z$UEA5;[?P,USIL4O40;]WDXKL:[
MW7<*)S!K_9CHLD2Y+_-.1FPD7P[4<!R1!U`?JMF4XS.:*Y1)EH1$W"-0<%O(
M""IZ5G8A`1_;H[@FZ@K<=#/2O7*R.4=M_%066)T9W<2MPBH[(%MNO:\=B>8E
MMN8E5E7(#VDEM)KHDG,V\/0?UH)E8N4/&5U&NQ;.#_CN0?QTU-!^N\UN'ZE;
MFO/FE@>J@9H"PZ4S@C_U6'U5A$_MK<;MATQ&5F=ZHD838S0Z`1"\5A<E!R?*
M#(D#Q\AI=K.+^%CP?.@J&#%'`>7234@#T3,2DP"+R-5Y?_?D+@U:NDVZWVNN
M6"Z,!.;^&?00R,Y87^)ZDZK%DQ4$.N??%?W1ENA;+<?OI"-AH7#,N"]_!RBY
M&&)(DY,CFR'0/5%B]X<A5YY-`XO@+^63HGOB<CSN\898][4W`Z+,O>D3=BNH
MS$Y@D#-%)8I#+#\V/(T4QS3JM(Z>U__8RSDC"*507/@*Q7VSHXSZ?3Y<VDB.
MQ;(OKE'^%CN=`P:FNWY\>JG`N^]SN[&Y]=)7Z63,3`E3=J3CCJHM?\LQGV`:
M)V%T@&!6A/8(4B4<E":`"X)([*J8Q!95EZT&(?UDN3U"1;0^ZG9&#$CI);7[
M$((WF'[0*2\QE]"T:]+W`CV7L`.K9^QP7(<;K3`4S&%$29`R0[\++(4KQIRZ
M%Z+?+!^(YGT!=B?%5-I":F!B5S?CSI(&)10Y(4#*0R>%"!8T!FN)O(0[/KX2
MUK7Q98\E:1:<VO#*TW:N])X)AY73DUA5?'S^+(<,=W1U\Z@M>`I4U\R;8+_2
MXPY7';@K(C]-=1_\<TC5M%*AJ.9;TQ`P0G1U3[2:/C^6V\,/]B[CA\2S([*G
MXKV95^_P3X^)%2:'(7N,?,:"SX_CW_8?(*?0I;'ZT-[BECKQD41!JXT:V*=2
MRP_=Q+R]2;\I`E<A-IEK3DC&]B17DD1`M:##Y+MC17LBR`X':*%3;A8J/>8W
MK?ZOV6NQ_^2U,@.;&HR4-&F=`.J?^&QN/VR^<%'2MYL&\XU*(UZ'GY?X^K_@
M8S,9@OP&>]P_^5WC[9#2;+&K>C-1_\'&O_*^R%SNJ>F(,C(L8@4.O@9.V,_-
M>&L(^.OH7P.:)]W9Y8;?8ULCLODY]6J(3CO+=VY&R(RQ-`/^1DL?K*2NDFJ+
M/"AT+B6AH8[R!BA;U'&*X*-<1<[4XD^@!9$WX`9IF-]-O0FZTB,#G!\*7R1R
M[^[9Z!/W<GX,AI_KHONGL"G(?'A5G8+=,S1]=?,1=&H_+0UYPT^>]8Y;:$32
MI+R4J?ESQ"O'MZ')(D77\@3^R>^*I#O[MGXF[N.(QZB@DRF@D!N7@6$RA-^#
MU7!4\^W,B1H[WG\V:N)#W7OV[+[((6XIT@^%^P-KAJ-B(F>H,GKUT(PNP@<T
M?]VWFRI;;EM?3_L?_,P7^#A!P2#.$79GBE:6(@PT($41(&!D]NGPKMM<DYJD
MS3ZQS3,>8[?K9YED_&9/,HNJ@ID=V@XC5/5/9Q%3X9>_:SB>\\Q^&8J[[E?\
M"-]R#8;!OUT2J_T>D?B;^AQ9?!&B#O3/V18TT?2PS;?5%T;7J34DDC[3V8#!
M1(]_3[XH'Z8OU%CH:`.KOW[OWS]_O/SN_*4,V\"4<,')T\<DAGX$)(]NM9[&
M!Q'U#;N_0!MJPA:E^O-9HD7+2CSQDT2&6+-"H)9RM/7826[7A,1_M\GY67#L
MW%+B6YU]',;$?Q)K#$MW-<%.!JN7%./3>1V5R%!\C3<>/C/M*67FA&O'F>9_
M$60A@0#<L6I\_!"-*U9%T=BMWD\,E:Z]\?IB1MQ7-L3Y9^OO"=%-L`^Y5W4,
M3^=>#>G0<+M`A16G?4`=`3O._UR,R2LTT7;6.D#G,#=.1>S.W%@1EBB!JB7=
MM'X#[J]+&W*CLJJKU:B*+SP=,VBH=>.D%*S\NY!@`GSTF4%O?>'J6A9ZCBV#
M2E7#+WOX*'J,V/8.JU?/)KU$TL.<"$D;5PMT=I5J`;TD<CG2C4CF51"'`A9C
M7]0R`<NY'&1Z6GY!_IW"$!IP>F^(NOCO;@KK:%[L:0JIJI`<C$:LRXJAAX"I
M\)47)\0":)%""\VG]@BV5=]7:D`7.`&+:SFL@KU^;OT1AB7JX;Y<"C'#06[%
MU@5W*UKXOPINJV(A`'X"=7(*R)#GJB^(]OWG/TT+J`D!D[$!Q5Z-DG;3`'1:
MW%2HF$7I.-OT!7)+-9PNW5%.BR\ZGDJ@?UH1^Y)*W.N_@<"!-TMP=Q\Y"4GV
M-.NLL-#`+6..:8E0\BGC%%[_GM9E%J1Z_R@+2O!K"'9IDBV@!\@7LL;L^1U@
MI3C@58P;%@N!!'8F:HG0L8,56XS9;RNJ4F5!HMZE?Q0_V$,POV;;@_B0]6X5
ML_7$+I(X7H^)]T7/3CG2#_*<6^>K0]<;FINKN3T\$6I,:9Q@.3S<3/SZ_.<.
MB-D:E"?=^]Q+*T8-77T"^<_GG;\N_I=]536Q-.ZAEHB8)\:=(S4Q)AV]<D^(
MYM'K[+F/U/78ORLY3S(I:"^&6Z\_,S(^M$!V4%5O3\6B:>`$BZ*D8LUQ;SWH
M7Y;N#$[MN[!S%D:CV_>;)1A*(GW45'B;=$W=(__K3_^.1M>1X52X@@NB8.<!
MVC*Z+UG^D7<17(X<'$<EUO!\6X;>.@JX<XSX7)XV_V^L\?P=6,5/OAC-=<`6
MWEQ&R8<:90Y!)=\.EY9F&75GCT^GI%@9H?PZ9(56B*F6ZJS%+[B&JRA"CJFX
M0_-WAT:V:[9EA&D0M*=1+<S?;^QF6GB`:Y52`V&PO\XP,U(_I"\."_YU?TJD
M&Y093,V]R@2-L`P*,[J]>V%8!GTX?F'?=CU&T^7\D$L535BZ9E?FO+&^)SC0
MB2_9:=8;Q7`^J44[H+P7O15<1J;L#51L/.!G\P2OD57W>_:>TP:=]JH-]^>>
MWX0,-+.<P^80ANI0F*@6X-&&KO@#3V214^_/\!^A'BADT,38MZ*3J2\X)`U'
M)-+L47,<&GAP4"IBZJO9Z$`3XEXUQ+SF(C+876C]Z1RS2P^5\4YQ:2O!3IP9
M]8-5\ZS,*@5F"[Q#.NO;Q@7K:![7E^:J=:BA_DE=B%,#<K`<[(,%E1(.YBV)
M"TUY="B?B%IEY!U,4B<>I,#HZ!%0BT;2`),.X;I=I]/"@7'KN8(LCNHT>`.5
MJ.79:/ZA:VBJ^FUED<_9R!D^4,2H$V1TFMLA#HPI1?WT'ZB!8%K;^OF8_Z=3
MJ/M_ZK%M*:*X!%SZ[>+*J"GU[%YC\712&OWC9<H(,MS9EB"IP[_PX&P.6TFO
ML5=DXRBG@=-G6&\[_%BZQK:]T*^@(X.H9O]'HXZJ`>#VT/.9.Y`0C@!<!3[H
MU$R4>@!@>Z5N)X?S>YTN/?;.`*287&T-G-E?"LT>-K%26`LM<%Y&0'/>I%%.
MUYI]![20C$SLMP"^[D7Y3_;#ZIP9O!T;W2.XX+-[$P(4,DI9G'IRL#`U02K[
M)UU.AVJ-+6J)<D7*'6+5_+1.%%`Y4=7EJABF-1K>/#6XG*W"K.UJ&O7</%GF
M0G3"[^Y?L7X,KXR;6AQ@S,.17L"V$9`>G(@.KD_Z&-2R`['7;!+,2WXR2.4U
M`$0:.N8$(!1-+TT9U!J5`#(2"<J@%]S4]QXJQYWDNV&5<(Y>S=#*A8=?7036
M2M]L%OK7SD'SA"C/TP5,GUVD4W\-1ZU#6]A4:+R14S,ME/K),(QKX`$KD-]<
M/2D^%(S3:="#^+RJM#KB!5%_IT%D/L8)D3B%+(9<</@)DLKQ)K%C3$]!1"]Z
MON/YVPIL=-JWB`<ET0MW'Y"\7S:R6.W.&I'H$\^5JMR][]!:#DRD`]M\6IB8
M1+*UYG=BQRHU!P,&':U5L`>9](`//9HC\H.HP3.:96652K$\=("L'4Y?W58K
M@G0.DM6'"-<C'3J!1ZA2RB(,"0L.O\$=NTJM1%XOY<2^&@5'=KW<OHY9$7*A
M6</IMIREH_5:%`!P)U&PI4<578;WK3&7B:3_HTORETIAPRYH@SZX=KV5O>(0
M23'[GRQD"=P<XJ`V.1SG/N/-LS^D]@3<V[UK,-$+[&_GB($ONXB>.P)5OL7'
MV\M=$L;+S];S017=(2LGT[\%"C;Z2CV`PYO$O(X5@JWJODE7J*^!4-LOAX!V
M8H%S]R:AB:;FNV4>"1"6I,#,4B1^Y'T0LS+QZSP4N8W/B'7K;*$D..2/7`C!
M;XW^/X1DZ$3QU5\%%01F#<B^V":KA$#IV]VFO7H'77Z=(5ZN]MDY;$2[]R.^
MKZ&Q,B\N>8'S/,M&'N@K9;`WP02S)U;K&D7I[L\>-^")^BASL2KZS%(WN8RO
M/SDF2JP$_@7JA+@#I0;*G9(CXC)M04K\2`LD,6'P5MZJZMAD2SE#9O5,T!<C
MA*JS<U;]$$TOO[*==!,\Y2+R,B,%H:QI;O3XO$:+M>3Z?%3#K"THC_D*(2BM
MCQFE3NIC:U+:/C1F%U_#9\"9H'K"P$HK*QGE^W8O!>;PD/"&\8UJ>];$KS*)
M`0CN4\X@BR"0FT-2:]LZ692PVW/G_*F9\8Q]"3=_.1<6ARVJBH7TJ,V-'QQ(
M!TY2@%`KQP3TO^N>)!_#-W86JLII@60%#[O6])8%)5E$#T>"9RRQ7O%HR7?C
MV3^L'_7V0A9`[L_ZAGB%6<OVM'M7XBT>(<CE0^NUL1XU47+)S^=2<[*G06VV
M!)N8ULS[*2*U*_=P(\.U.;\;[.'6,("];C4$V2P>D%X+&Q]#[+8F$%ST<$L!
M@J"\"*U.ESW^HP>*V6>:6)XIG"?>?H]>Y6/V<@V0G+I\4+!'!@&@34UAMLZ2
MJ2RU8O4H*[78+X)(T3`&L_'YOU="7N?M'"3'))1FP?)`UAOQ9(`NI\RUHZL^
M<$][N]PN#WK]6`/XNTYXC"0AC>>GWRM(IL.YW4HDNUP@T8=X<D3KIP)\G7\V
M2QD^SWUR;0T7:<C\RHUE]MMF"OOWA[&G"/QUW'6K,8"^0W(2%Z^RC31#ET<[
MTYD\Q*,_L<EY$V!^<>I/"M6<>L8(I/"?3)@4.+W%V,K@D_Y%M^,S2<]>QN'S
M+>E<R8A*`/*'\.#QH:<7YXO2;2`7Z%0-\XQ*/L-AZZ$`G:O:GV0^)JW"%H=F
MHW*&U,?"MS,GZM#5\_4>R[OA/I:,%>==B==HO?OA"YZMF2-:7KS1AR.U+D.`
M\CW)D!IQUO,E<K*@,BO=N+5IE\]--@/?V!8[36NA%R`(&[>DVR_VGX`]M'9B
M^GXV\4#4AD*`IZ53V8`V]*^?K\%:Z1*!04,.,!^K!/)(Z`A8.4[THN6!_CL<
M^`K=7%59K#'%J31$#?#Y"7U?W,#:P+;\Q>&B+SV*N,%-AV&CC/EQX"'[7`3M
M(K>0>/Z(5C`V2S/(&8I57?>XC`V2'QO/['T:@#I9MGKPK]+^+.VV1B)FS-``
MRC,(V*9R)05-7,IPO;A8'T:'BL9QOWD-@!R-EJ2,:]'HR;PC(F"#4W^7WP2*
M:\:[T#S&9`2U-G0H+0Y7!B1ZF+*0IV,PX3+J(-O.#J>](NMI)L!G%=MUSXB5
M'P@)/8Q5^P\N<TU9"@Q%*_6;WL8K#^$Z^QM1&WO84;J"<1GRIPS:#1,Q8G+@
MM4M/#)R.TGIKCXGFV326E8OFNC+9MT`+/][R%M+SZKW[H(BV:1@/G61_+V5@
MBITD70?JCT?N]W`3C0PCN@&Y#]O56Z7V`C?P12?RT6)9%GYU*_8.4)'&]"H\
MZ^T>_POH]G#I4B;O5X'+3#(C^!`=21^3W]Y,,$I$'D6^]%NV@.`#T;8"^*>4
M"+=Z<&R"DKV;<B6N@?<JPYX[S`B.F);9`E>#/[3KL#6'Y2\P\'R@W(W\9:V\
MFOI"V8YP0H<K@`:=<Y_^<,7/9'U<18"BW!*)`WBGEQC(SNW?O],HAIE:YL6T
M\N>>IVO=(8^>QP?LCTLE-XZDWDM2^4]KX=ND*X:-"?'BNJ1($L#)I`"U%TI(
M<:-`)(2R"Z.UN-"T=%^OE4)H%B*=A,9RK-`J'S-LEN_B-8#YFR#>AY'X*#3T
M_CS.G\M_DOHV7%#HM3EYM?#@?]9"SZ31%TS*@,9R;E\$F=4I.,\Y)*0E>OIG
M4I-S>5AC?Z5(PG/*_?`O&\)I4Y)%6X7/JN11??57$M\P_=OD:K>$^7BW;4TN
MIWTU1?#8W9AW9T&UY*OY4YI=_5%\MDKD;JE^Z(EHS#BXCP=`YVWU[]2+00P5
MOJ;S/^5#ABH8(H@^%8=WO<:[+-@4<!(@!)<#ST!NO62X0M9'`;ZDK##ASAU(
MNDFE/T#"+D"%@JP.XQ5:#/-HZLOM4::='D>+)P\J1)UT9#DL=I2)&_%.IP1X
M3]4V@-K@N]\,N_%D:Z56ZE(#WIE5+*@A:\S2!MB[BDQ!XP5R6_*:R9X//1V7
MV+IORM)6*>79\4O=E!'UU).YVHSFN=UNM2^Y>K&Q`UM5T(G'*2E@/GY^$,>#
MY$=MPSH/3@%@TF^;N$2%$A\*,K/4:*DL7IF.0GY>'?!`P[`-?2*(<]^_9"+%
M8.N^(B3\;T!?37?L*;O,WMIN.M5,,L:6_^>V`FGZ1X96X*4J%#1HV>O+]0_5
MRUYF/#]P:'`@96-H;R<\/R<[/SZ`RUPGW?!(!:9E_V(T.18NZ![J7O9C]DXK
M)E&(>U:EEB<_*T@:IC>H*<9L,81M5JAO(/;YO*^3E5>M$XI\L5@#`RG9O+)<
MKEU&%SSKA?ZRA(S9X0,9`.W#VE?@1JT`*Q(Z?"=MX4UE01*#<5ZM5`,)3T/F
M%(H4ZWI.>TKP//&*"UQ(XV;S><+:;*0[&NO%ZT_;;.MK/^^(\WG>>C?Q6`!.
M.UP>A*CO3#S<,G*<X2IV#EY$:$6?P?L%>T^E[ZWD+/3)KU_;V[S8+!Q&+.:1
M$>`VZ)09QX75CMA.+T]X;A"%DN4@")[HLZ7MWTX;J%*4\,$=L7<>S7YN@2I=
M<4Q[\]E:GEK;^!WA+5%<I>(_N3ZFL\\I!TQUL!3HF<ZX%W)2IU$\/(OFD4#5
M@1_!;H.6HDK'^5BVNI5S/P19P)WL'[CE_N]RO$<S+(U_%3O^:5749Q=21]UW
M1WLPN',!;3OQ?MX?.S%"T-Y,6]4?^*87B_[28_8S<XY''F@!IN6=4-TK"@#O
M(_584[GC<]#Z3U^X9,6OL/_Z)[E$%X_F(T,NR0A7K.O'\JKV6(;IJ9M^U@PR
M4)$:GGP!B,&44->/E&>/MCCUKLCLU6,:ET:6J0QK@4/YDFS^:6@'Q/BGS?T#
MT*9,-*9TH<DOJ)L9Y?=V"MW&EDS2!-YY)5=^RPP^-.).6N#8`%`_N&OW9![<
MN]$0H*[8N)Y<$'&0?01[4-XQ*1@WH@V>;?M>WF_[M4]<SM&6T@WK_J9N$(JN
M8YF&S2KGC2MD]I;*2'>^6_N_);<2,Y#9K=_Y0;_U5EEN/5>A)E36;$:WRA3W
M"R+*B#4[X`E6UY:@78<-$==_DK?M2#\NE8\5+"O5^GTH]:J^O"T@1#),J3+`
M=;)%87Z[RD=/Q^H@=L,#MNW5%YW?(ZAQ+JH2=_5;44A^#<]"WX"'M8F=&E'W
M3$3=P=%(-ZTSJ8\>CDO_*VM9V.D1>``0:2Q'.5R:+:K,`9)!0J*=S:D7)FI3
M3Z,0O@C]8NXUT7`'="JC>V*"''MWPR=;`FC=9Q27V[=?O1T'K-@64HO\5P%]
M:F-"K-.\P5Z9DQ/(3C`L&ZRVZ].-!Z:9[3"D;+!3`QVQ"S;=(=$JD"*#O7BX
M;NMUNGQV1FNT0G%0\:9(+OL&Q1`+%1\>*E5`N(;IH$H8_3P;3JT$(P`"FAF/
M:0(#D5Z$"I^TDSS_@W8Q6+2N-A$O$YC[ZU>/'W`VY=;K7:B"%&:<3J.`AF/!
M`3Y/0&N<\G3=73#_OCFK]OS3F7'4&HDY%3HK`2GH<.4';CG11VYI^,S#)B6#
M`JV4-AQ4([N=_3]"B<`<`#OY*7S0_W0_'FR<R3_]G'SOGJC*A\73>S<KD%9G
M\`@L#I<C"<3*^F+6FD(W]*>IK_NOL:!GUPM:_L^3T$T*CI>`9#@'0`A3EE>/
M\6RGN/JRYO^`T*M$0!=RYL'LA-TO7V9JF%RYH\FH.W;=.`=/JY^$M9*\'N8!
M6Y=B2OTR&3^_0T/NFWN>:?^M6`A!74-M3I&NN%.30]VNN8*9C!1_,I^WR*A2
MR+]]>TD*>A+1-P@L$Z;Y^H=LQK5M2[=J:'G4(Z@2CY@;F_GO=3!?!^!+"/)L
M7G5)S[B03%BL24*YMMQ:,Z_F<UX;]%^VOY;5J*GZ(L@:2T;Q2KC?Z74@EI,`
M20,)/W>4#IWF$;2:3V_66"Q1#%"SX&XI8\];/]>"\6X(5ZR>[3"$4%CM?*U]
MNS9SQ9I*+38`LBY>%]9!E@DT+>27@&X>J`CW>E;SI1%."G'1!,^L(<AFO^_8
MU$15@9&2'I7MR*_=%8&>U?JA&"J@Z6V$-W^L!8P(K23VM-8F]9O3)IE$[<RY
M#GFD)%=O'6*>."TD,#>G,!6A<V[#B<:4"5;&F2C<__'B:9T/QH>Z@U!/5`Q\
M4/M(E_`NJ%I%L/P@;YAJC*I0>N\P0&MOC;NM@[4:A0V:GSAF?MPL$.^A0;3I
M&924IUPD/2O!V2>8K^FR"J*H(RF3&@N;^)ZOFNR1QCF>[@=041_(>P.:F;S)
M$Z'>S:Q#30DL7EL_V''G+JD4]6"#I<(CB2R"UU5L&JH\G0`^K"<\T5+SD/I9
MQ+K;OCJ3TY$^B=^8V..!O^:?2F?*Z<]]D,20!ZO:N!T_&3)W7J\<@"4OCSY.
MTX<3D39PEJ,3N)]OVX:L0T39;M$G439(U5#:3>PORXJ:8Q<4L.I)0R0U>8-G
M==?*QSCG,FRTF^Y6PXDUL@Q1`5M2<M%A0JIV!+NE_=#LNIIN4^#B.9<ER*/!
M1(>[?(('K3:R\5,QH[S,"%4GFR92W!E(:-G6D'^QE0K&KB&_N,!8X>["1:^Q
M;U!8($#TUNPM?0+TM='(^G,A<DKO#94&_<U52W=_6`@_UW=\J>E7K+`U6$E@
M"0HIMMY#O.*F8CU8U/3??UXW!)NUBUQT_WV9=S8##1*#\L%HF])\KO\7C"]Y
MR8D_*T3-_F#!$FP#L"+@H"'FB=$UC;U8=OF42=,.]V*J?-TP",#0)Q3D8\9I
M50?U)2>]G<NMKXW$HF1>,>,B&!#(AJ7;<EK_H3.GEVEZOLAL#"2_O\+:3S"=
MJGVNR4=M6=Q1FZ/FP*86<^T!>KI')R1XGG7!)U9(=B&A<9/UF];S=RML962I
M>S"OZ18$Q,J*VQAI/DUQ%F=)AZ384D!8@K+"6$VFE5JHD4='`X;XG0&=HB/?
M,!+!A-.[ITGIR7^PG'5@IF2:"N5J<6W`SK"6KF2K$>]?#O-[2,7$?5$>C%Z=
MH+&W;(?JZS,CNDJG1.%[2PV6^^N4/X1ZXDNW0B^6`/T?.N!NU_'/,@&>0:#P
M:F;F2)*I7P&^CRDO0$US"^EF*V[LH#:?+V"JO3>5'D@[UQACIS/B@W#S,&(#
MXNP5;`/20#W)WT4T!SI%%Z]\9^S2IKN5>'VAV0]89-//!P>CR&W]Q;GUSQNX
M3;BG.^M)]P10!U"_]XZB8A_N;FFEQFBL*<Q?MJP,NOA-LQ+M+0OZ,N%1&!G1
MS30':.,^]2=@M.H+AB/T4)@"+,O!'AJ%Q_KGC$@9X=2NR.#D]YCU-^PS\6[,
MI"4R=KVMQK2<)D.""%]31B+9G_$/F_SXUAX%Q0O*[^!2O#I1W4#.=`'ZEEZ2
M<,!O=63_4.0T>GHNEL/#-U+*:HI=,L-H_D.QGU>KT02T:H$Z;+[[36=MU8AM
M?7GF5)_KI^%_'K)@=\;[L-HJEF:O:Y2!;L5P1&Y@N0TB,CC%+F3%C9([-S']
M[R%$>0;YQNH8#Q/N;574#1[Q608C8I,;%<)\P5-`'/X#9Y89M^^YQG-?F+QB
M7C*L[79F^W]30PZWFK[)!&WRX1+E:9Y.ODGF:L.H!4KQ"C=?JC[7%*XC&\)F
M(W62G1G;3F3/JDG/><S<*GO(,;5ZF\2:'86U/71'4XZT/TON#5F8E#+E9?AO
MSDH`*K(J6;34H3<SO$*=]>X:5W':NY,]:VMPIY8\8LJ"JV<[.;N76ZPSV:,L
M!>T9<.%8DM3!^?KIXIPP8`]G$-KPG&1'!O_B98W&QO[TT)!V6'Q"9+3M/.LN
M>4[H![#'`P4//>\1;=RA&\.8*KQ$_Z>-0F]S.-5X@'N?[SFZKG'ATZ;EP*AG
M;FJ\V+%R28BDGV8Z[!,BII,QG#4D0DZ]MWN.+D1P5%(1!WH(O0M%-:]VKF1$
MYHZ7?*Q?(H#>5B<TFPKH3(-?#>;M.0M;F-CT'F.4\+8C=1`P1()UG+]LL!6*
M@T1OL74U,1VSK^4PPA?*5UYLM<T4;<>F\SA&O$3F8=/!=S16BOB_RSISSLZ4
MMO[XKC\[:'@*_<A4LM`'7#X)KPMH4"8IVK[9U1(+ULEA:MIO,KH/\@^!1S#2
MYUE=]&,M/+'Y/5X_Q"45)Q6IH*:TR$UG"4E=:B#2[&Z5+8(':YAUE>D0\3&>
M7_J#L&&X_?42#6P::-:;)FQC,+6A\W&EF8Y<&B'+WH9M`^2QPJB]2MN-DJM8
M]Q(X@T=V<^K(L>];/4+F)5=%V1-T!4GO^+LME#4V&4";M%PS"`.>]#S^O7*"
M?PR2_.@IR6ID/K)AKZ\R,MUQ;:.'42(2)5G_G?$*@ZZ-AX2JC:6(0LQJ'S0[
MG_6HG'''\/5=<"R%R[#Y1ME:(]Y8OJ+V^;6D%(@2U=-IIS]I79'_]C],?I>E
MZ[Z\88F>*$/I>-B5BA197>]YCN%:!.;"*:-)K`X0';W8GT!:*0,YT6(D.91J
M^I,TXW*.F5QBM:(%YZ"HWGW?.WV)GDHBH[#,VWMV1@M=B7)4Z2:N2=7<@`':
M,G9@(T$>NU$<^\4A'$,H"E%EW5D(SP$_6]%Q4*XGBY:!?!`/#&H%XV%ZSU%$
M@@-:KUXRM[F(K9KYQU4L*^E)TB%56'Q5MQE+!<,\;Y]OUQ-Y\)9<VM[%XG7;
M>.5G6-$DX!?MWLRG34\HK8_E<91]#UUX\UEA^VO^&FE%T!`)<QE54PA_G*4\
MW8.9?O6*U'7>["3)O"ITNUL\PS3#TD9;8P70\EFL'(QJAYU,D["O2=^!=#NZ
MR2I-$2FV3</46_YY]TA*I,QFD['_C@:`E4(EP0:89B)$?RJ;_H%,ZI!S)8K4
M>.?H[GQ^H]E5CR8VCJ&^S&7!3FEML;YE%4I0\_EDS%]F*O9+K#3V757&5,M$
M622ZLN4@&S$OO0Q%!?>%.ZZ,HTDDW8\K1`D$I4&KFT?D;BT,XZ8^77P6Z@"/
MM*)FBY_IJK\4)ZWQJ>.GHDPF1PNZ>!%A#I4NW,U2@$KEV)#?F722CY%S.50F
MAY&DX1C09!4#_Z&:8$<>%:C5W^4Y#9E12H"I06'Y[F?H@+%/3TYW0F8/`59`
MW+N=90*2\K1HWXDA&V)^93:/ZJY4VZ^TK7F=Y`Z#"Q1]0;<<'H=V"-38`?M%
MCF6^49W#E]#3X)-*YQ_$4(\0C4U/0[\'2$@Y/"QH3-D[$9M:51=M)GMJ#EL,
MT9)P";O=3EX75S'X-_1FV:Z)V<$J4W8!HN>+<D5ZT+I3&8U;'"Q^4KPKZI!O
MEQ<PH&.NDS$(6I!UIM[?AI1<W,M]0_!''(ZBEV,&-UHA9GO^P>(38YT"`8CX
M#=LZG%;/*22A%$Q&F%[?S'='U>6+C`4RJ\73]^4G@2Q/)U2B@G,JDB<%'5MS
M8&;`O,S^AJ/[1Q(('D\4R%&=*PQ]H(V2#OO5\/.=TO:QIZ*3G^$C9<JED$/^
M_PLUV4U7G=[[VEC+WM$1K\M)A&^?\CZL(O55]5IW]9W;L>'YOX_<^3Q(^([R
M6Y$+_:*1>O_(Q').2:^090-`U_T7UV";-?B)9Q4U$2!I9\/RZ=$,7<5CK)8V
MK/5*)P0@%A6\Q"9DSS>US_V.&#`SDTL8JA]I:<-`]^:X]XK+YQGESAO1`.HU
MV53MO1R]*S>]QGKR2`3U@E'Y;S;S.$7-\L;$3>B.7;G,\H2941_->/H[LS+C
MQ:J#M8"U/%OP!=E@Z57*V0Z+4OC,FDY:O6!TE1EV%M-N`3Z#0:<9M\F7>O((
MQ"&F:L41:"#&79S;8)2;+SLQ7'\H@)ADJ?G0HQ4J#J/CBR]((_+[O+GB^K&Q
M7F]GB`R-G0G)?Z9UNK(3@280DV`=6!EDP^F/+X]"IZ<$-&YYSN.B>P9+S"C:
M`RU]5KIF<#['2R^QX=]WAI+U%8#T:"FR::,2(U>5UK$`C'+SG&A.^8-Q36$S
M&9.XJ+T4`$9N]$"$4NPG4[!W.2O-=0:\751]C?-;$P>D*+]-=30'#C?:($MS
MZUS(@S)",G>&Q'1#8NDBH'5TRJL3O=GNOE"4;G:\`BX>41H.K%'K*QH[6KF&
MDK$J>TIA4!7Y)9HDL&]V+N+4;)57/RZ^?4FLW1K`S3,<A\M73(;9.,9`[)`W
M(</[K:62<4(K8FF"XH1_;/XI9[&2D!J$R9/?;MSS<0N6=1+J6'KIR'*Y04NZ
M>`&JR?W`UK8XNG=`E,`/'GBRRFCVR.IOF"5##!Y0_:7=,=?0?H*_]CO'YHAO
MEQVZ-VH"@IFF7\02]R!&BCHDAA*E!5Y-KD!F!%_=:M"5O8=!3F@TOB7HZRF3
M1?KE/+H%RI3E<,FRA\6.W8Z?+E\98P?U!]H1KRPMR6OK='N/1?,!KHQHMS8N
M%4*-G[!;N%Z/+TL91(7GK$SSVNVJ\]!X]^2]`4*+Y*5=Z!QX)*$*5#C,QJRT
M#&&"STK0:2E+A+MG#1[Z*DF0*WF/!V\I<?+R`+3UH&:*=0(.6]P?@&,-)/A&
M&D#_$`&59Q)`F!'^TOJ=RUT!C&-[CH,'AI^&2O[VGQ3A`'ESA]H-S]<9+WB[
MH-LY7&S&W58LW9H/=:I?A4G7C%QUA99+H&9J6R`!>Z6:7V3W4$6$_`FO`P]*
M`MUA4^H8QL]6;VB<08/,_8Z*Y96Z_F2DTF8%LVT!6>5B@`(I^+@FH*O,@=/8
MX",7'\,:>Q=]M'EL`*NYIIUQ^C>4FI]%*&Z=[;ZO$`Z$1G_AQ6:M>@DY@5:4
M-)[5(SK),#G\.;7.K`V\0F>@@5)I*Z%`RYO=!0<$Q[':-])D"/^75\M5JQ)G
MJ2S?E]6/\K12E7$EQ+Y^N^#RCU7H#%S5W;#N*EU0S`=T&T2SG(%%X@@]9GJF
MIW:RD)(2STZ4C;R(Q^^@22HAA*@0\_=JWX_7*4N]^4L#4)/61(@[>4[R'7(]
M^+=?+Q25O$$F,7=%KG0VR?A/`QX[.\%6T9Z\;.VTKZUG(55/W::B^=0[G.27
M-L69JW>\F^76^PQ\0_QE[@%VS_BG6-SV1?\LZ_&OE==A/'^5^V$[%-.KW_BC
M2(SB?KX.P(!1("#/M<7#&]9A9>W*+;=YC"BK$J.*M(0Y*N2Q`%]D4?CFLA,X
MGZ#*QQ-=)=VO:07C073#)4$?+7#$G7?3,9,&P2/YT=8;C3>]O`?=Z"I8`_;3
M]D(F'U]P$2AJQ'Z^;:`PB<WC`3-%2YX(5KY2<#QHLJIX.A=UJ\_S2>2%/"5<
MJ=VM:&<;(>*""$WS_B(HUGM8U?BC#M*1&@UH'2DC0/YTAMIOK(S&HKC)J^2C
MO>*6+%6P2:9R-6<6Y/?JGV<ZM$_SZ2&L._XQ5I"F-AMWSO1I'U&%_+'BCN-.
M,0!$"[V\DB]''\G9LE`;A:\T0RE7WO[6!1Y"F2%W-E4N.$'R'^3*<!@R@0<'
M%0$A$>?+I=$K!^99'IF]X&OYOFIPX=WI)GI<\Z1G^.>LURSU$C;>!/;K_O3>
M'/YPB60[6ZQK>:0N*PR,7Y`H>W?PKHZ21/^;EHM\_'9]>_EP:0I#`K?Q%EMP
M[+83RV\0*>09Z4Z33J\3!NII!*HNT[/(;I5)K271*;X<M_4<+-P9_2[^<.BJ
MBF=A=L!SV_KU+@5!6F(S2`"%5M:WL^G=CJ?0[L=,_HT=O%F"KAOEA!A4QDL4
MZE3\`-[W#;RWZUC`Y`:DMN6]*M@['!2J^9W<U!W#6LH$=5257-\:S_<&=P+P
MM9F*D?GH9])Z?B"K)QF0C%8(>V]+MN:^\P<0XA2Q+;B@M%V]4`J<789D'NDO
M0"IBGM8K1'OHW@QPP>S?61PB^/J&@\8V>V.N7??;.M%D>K:3'=^5\VJB8@U7
MI#\C*_Q0AGGCA)#>7-G+)%8DQ_+^(+.CC]C+<L&EGS&;D"A7Z;I@A?#S*7T.
M&6-;!^>9*"GAT=Y@Z/CP'ZTYZIA'_$NOP/,76Y?/)-!?!LB,LH/W_I-E38YJ
M"X=ALVIR)L,D*Z<HXYC%_AL,7+L^6"GHMAM$.Z54/==Q]05I3EQVQ(.O09F2
M[@]38L^\C`/_RP!,(RM^W2PO.=`NHE)SSQ]S:Z(S.>"K'<V7T5V];N^UE^?G
MP>+$#)++\!:F=Z52A;MM!^!8KQ",T,/./D55OPQ,,0^VE8ID3.;3_`'`+^4F
M\F\DG[.HG_E;2%8N%Y\]2!MQ"\@!_:XWM$^:$H;GI4,`76Z&A&ACU_^>^P.F
MXP4*1E4M,B+".M_BKLI(LNY"PGMK'P@&Y:ARQJZ[!'LEX._?L,!LAY.H)M?0
M<Q34.T=2.,Y##ATG]:R;$EU-IBANQ(:M^=C!.8HIG6)P9D^%MMQQ8;15)0F;
M[VF02K5VS:VU3>;FO&$5)\XA=K:%<U79,%6Y;B`FIC9Q>DM^/<[A7/SA_2_$
M7,T19S[SF-)N%B7C?_J+V\1"<:>YVT8?@/(3^XGU`>9]VO-'*0E)'*>K0=`C
M$0>;3?@NWP+O7ID:B6YO<-J&#YVA<W)VNYZ`C`!GZ/Y>/:$0$YSZ0RPJ#X*H
MI;=X$?1,E)#I\L$T!YH\7UD\B[NJSAA%'("3MMF,Z;"DC-2$G-MKIOXZ=*@.
M`C^R%9&%3&`_T5#'&5]:Q);9VB>7'?FS%B@40=_J!#_I`<Y0_,('(;+V$TI1
MF=M1>O5`=`@W-V3"_OR'L`E41MP#9%V8-,MWZ)H^WJ"L#T$7!>*T52=G5^P9
M&92A)23TD3,O]AD<^HZ]]6`L<S^-_R'."Q^V'!ZLP63^OJA7=(SWXP!;(LMZ
MDHV$B8T3</J:2;P;N&C6&X"PY+GCCS.'#L#Q1I_*%#'8#5(H.4SZS;QJ$4#B
M.#)A];Q-W%_-O?DEA*X7#<`"O$%[VH:'7RU^?QL;6,3'V2W#;#B]\/X1F"2K
M6M97J>W3:24,DC,I_OD)MQI3F=#QODV'CKITI&`X4L+Q)OA_D/)[<:Y;[&MH
M(ELH:!M(G2.7_$)FS)XGK^7=DZZ<F3O&9-J]:/%2,WUO(@L@1@J_$/)#7`L)
MD9Q4)Y)2G1A@"#Q?./CU)1H&NBOW+I1OFI#,*0*V(I(DB'2G+=.D[D)*9P#(
M$'*74@C&HMU':*88[F-[@N:::?S1J-&^$VE`L_J[`0H>;U^V3KIC00LCZY7X
MV!P(#F[QUSN'<&5`YU6.;"_E_Y4/2[<WP21H9O(Q;5(F>GLF%H'I)28K7U)'
MOLB-W=+#Z91LE8VHS(.7#5;5N$Q`/!\C<V@(VUJ-@F1EDP_=M_!5&TV78<8T
MW4A\LZJ`H=-F^GN/90O-`5DJ:CEULAE6V]I3;MW.[T+`1-?('#K,]9Y/)F(8
M2(Z0>Q:VG#4&'G;R\+FLU`*W';0LU;B(H[MVN6'K<P)\42ZKP+VJZFT5?Z%I
M]ZH&81@]7MZ:IN(_:_H2C)D:?IG?ER5W5X-6@F!R:KM7(E+P^G\ZM6$]667R
M=E^9,R*._-)S9N"%%HN12>"*B#<;K]HB_"RR,3])"@QQ$MHN]:8H3A(?$0Y7
MWJKV"]2&V1P7#.P'Q?*MAE8AM4B47KPR^JO$QF6>,"NQF3NCURI`/X+(>.C?
M]G`T2=P#-/I+1AQM['B9KVH`&VSUVGTD(=KI#!G05[_AZ3V]9F6>AQ2)*[>"
M9N,%VZ./Q2B,A]2A82WPEQJUHW#HTI8(?21XLJ00@N<)R*OIG9D134,B,OWQ
M:+(U;I#UT\/\FN%'(3O!^"UP:]';MD+.J7/4M\0%+F3:%;X@^W>3ST:?>;/U
MWI'T)@/F;-RXT%6!YA-R^UX,H>XKNZPHZV>BUHB'[,<V'9RW)1`HB"0DY_:^
M,#(TO^L4VUB\269DDX<[).'7:;>^4H?;$(!$3+(\799N<-(7UMH!M%*.1#AY
M_],+T^J=]H[!S%E\[-Y(7^LP$JY19CROA_!4FL\I!BR\^8*CXT:)X;.%EWYI
M.ZI14V9))FM7@>CME0/0U!E6!2:8=U.J?Q(1^`K%)15>J>)UK#?LBX='OXE^
MP#A+<AX$.'M#?"1D4OHE!0:O9U!23XJ^C?T%GQNO\K><R<?P;*D'B?`!/K-%
M0VR.J\0I.=VQ`4;0JXB8('^"VFU.F:9_=EJIESFT;H`^ADV+]$2,CA*M```9
M,3T\;*E.EQ[+=ZN9Y8%.U:#5,Z4S@?-*-W1!TUL/\3T"JE;O%$-7E7?8>/AX
M[].^#X-`H(A69Z*J?+EEJ]%>Q4I)6KQS@>*V#)HF"_<ZDQ@=E842R6/PG8HC
M9':VZ1X7H.LO4P>ZP3`N/'#\"!-)4/P'HO#OMR:*'.$#C<EYL]72"T"45"%#
M1+XTA$$9??>=#GQM!>*`#>S]5'O@'5ME[Y^FHQ+MVM$:)R!BVP7P='I5=9X/
MLO4/DN"@]JHC9OEWY^VC!]X$8+@=PI?^V!L\FN,D?EXX%,T/4.!.\$=:.958
M8O,\]VO!"8FRJ2BVT5UTF<"PU(>->CO[+6&O=B-\5!U-"NNQ\6D1Q2C8B<IZ
MTV^D%*@SYO:TM\XY"Y]1=53[5>1?-MK+HU?49Z7>,+=;\2`JP0:>`_'KD51Q
M$V+WU2HH/*!(8#M']1=W+*7&M.TG*U10*8_".C."AV48C"6,E__-0/U^[#-\
M^F*'!$Q^I0K(>J'FX4<;RX>O=<?%.Q@FL4FL<2X+G9A)LE5PA^(>Z#DP^8/!
MW@R7KD@6H%BP&C#=Q<R>E:F*Z@QN1A.:L>GBD>YAYL"%@T8Y4+/Y-1DT+&<@
M<K-J4+*2[O+#ACX.!=%O@Q<*=5)6]ADK0=8-$!(+/O*SO'A"[)=G39[DZ-TG
M_;*^0[UYY[/K6O+Z,>0Q&9;/IYH9<BZ8(R"K%QF<Y,3Q-P0>@]'MD[)G$P9(
M/NUA#F6D`ZV7<Z!A]8$?&,1;L:@R#3=B]C'VE1:BY%4M!:HK&?C!<S#%V.T^
MN$\\17S:FO8.&NCSB=&+2.EW6=<8YH.*Q_"N]),#%FSB!4A2](:8G^EQ4^?4
MBAB<#?(ID@J7?:U:'ETZX]?30^9-(5MMR3)I$]GYX'V??PGI.'?ZD]1,0A!K
M>T_278+ZT@KE.BX(S.-Z;=69]^(8<822[K7918WA3T\4K?C9%I17G^0(4LJ/
MZ7GLYJP1%CA`ZAU:>>L*#_H2TUHH[TF.9RU50T64US/8>7>-GN<Y!X[22B@E
M&MQG(A0[L,`>H-JM('`:<NNV&D-!-%VS31MB<9@YU-$J?KJ(LT_@4?V-#>O/
M1^W<Y$?>CA^?P@JPAC%N\KPF.;6S&:QN&-![-_OFYGS*32?I(P+QV#Z9F%1X
M2[B&5+LN94#[&Q_AVZ!77M-1<N,=&T6FBJ)JV<IK_I7;&W5"`A^Y\^;]#9!$
MH5DV$1C9(+BQ*\>6GYK_*ZK:+KGM6G".XS*2B@)/)&L%1`7FM@9!E,7-LFE8
MV2;*PA.Y:\90::@Z%O3??K9PS12?[7+S%[Y0;?LP'Y(Q46;J';G28UECTV(]
MZ>''(GDY[9?P9,J*>,T#-8M9>RH7T.UZU'/'>7TE<7CZM]'QJ%<N9]Y@@MH8
M3OSN,2]0V998M/(U*[`0YP?2KFS21&DN4013N-KN_!'-F>X0PQ&BZKUW!3=6
MQQ+^ZXW8#=+66J<G+^>E&E7CM4]!::*2U=,3B%UHR<6EG6I1\7;P?WV,B,6#
M*7#5O_G8L3T1JE2Q#*RW@3D;VY(8*0)P($V^2#@LCN8=JQ(V[@KHA!XJJL'M
M9DG!J4-NWUDR?W"?\P^4%WS*LTN*IU#B`CP"Z!,KJOGMA(MBF!37Z;P/@)KJ
M!C/P>2AU+YA0@2\<EW1BZ?-?Q_/*=*P21]N)0!/%-?KIZ]PK_/I9/=R5+^$H
M/!>R/HZ2A0T6]*W"4NLDG[-+U!,Y0UWV.BI2FCVLBRM/PHV*N4`Q7T2L)0$`
MC!.A%$7==U`N<K:@)FUY',S-KFQ<EN.!/7W%-*-60>2,8-3U$*R/413>9U.O
M1'/&*]XDQS%Q/X=6KFNO^71QX5#0OES<FO+]2Z9_*S$S!D8@AV'N)-6D7A-J
M*]?`6[PEU*""'FXXQ@!P[]`>@:0=5JN+_?NM788UN'=-+,IHE4@,D,ESEI\C
M25@I[*G.Q&):.'4R$4(4D_ZS,=L4J@\RGK4$:MJ7AKP!?*(WV5C7]V?N>?N"
MW;*+]O%;N6F+`MX\#366)V%CJ9'EHRC,I*D]I34*"N"K"0N[HX`BX)W/V>>M
M:DD4_]&*PYNN3177(]]W_YU[THIF%Q.9ZI!UE90SVR"LD=?N@"T:P=*\3F-V
M7+X&];;'IW\NAUA*.[J`ZU?_.9I6U['EOMK2_4`'SUSV0?+-MZ#:K&:2M\=3
M9`X;[F5=G=E0:%D0F"#&E,EAD<!(-H`,9U'RT@J.!.J.3'+$9+2`AC.@GMH?
M?C0TWZ5I2P";<6;QO'L/\;<,*3,_T.#T'7B\Y\YL_1X?+-^?S'E?+H$'26CE
MA697$E9S/QUVROQA)>)1_5'W5T`[S*>`M\%9+IF34*WFREL"@![+UIP(Y)GL
M(US,,)*_UC2-)`E/V`"!3I/E[+88/:R^,5=V56,`B,PDT[K&_EU^K3I<T275
MOND\ZCP,@<7+178JV@`^0""!RFP.\D2T2N(MPI*O(LTP(ME?%E!2\IT?[4`P
MU6FB#>*=^)FK,^IT7?N6U(SQ8+4.E!R'8+L37;F;Z>+,/Y,+:6,<[;3,0%[F
MA?B0#3N^H9H^3#6SF1'%_!0\(X%,2%(()W?'*@W'4EWPU/\LZB/<`9!)2\4'
M##++&)WP*3+34X`='F3Y4S3*H;XO<W\8]/Z;.,-PS;=C10B>Z[;R-0P3>H2A
MG9T?A15`IQP@CB0_!B-P@G'0E,)*]+(MXN)Q"D4-_@G*N@!@\\H"68;L4/_G
MR%I.#LI!J_5!'\Q%S/%0RF8Z=CUJCGT(@0[7K!J!B`".D)W-_:A"@6O5^5+`
M4NS/O93]YR$C7S;)DR2(7-LMH'C9V-:T8(EL</_7T'C8&X=VE7`7/0B9^RGL
M$HHA5Q]2-L`#0!>#?K"_Y-6$P=K&M`K<<6'1J$);QC&QI3XI[T?OF0QO(._*
MYN#5N`Q%+*5DQ35X@_<':S,'D,</<Q$AL0H=RE+()T<,C'UF30@QR4$41$@X
M]TD\NT3.#UR?V(UMQ^J12,%?JYK0I"ZA<98P`%L[-J(PWE>.7/E<ZX0?$(.Z
MA(F5;U9(3]]-"&Y*W/@1OU:)4*OCJH,%K*3#H@`X%?*?LT;<C$<E,9&&-UJ#
MK9N[U#S8CUB1`3)"9!C+>>&#RW?[7VF;]50&,-97\W7"X&<ZDM%/"FO+D6F+
M6"Q5,<<SK9-Y[M9YSXA?@41RR4$9ALUJJB-NMD"FXZ=8>,MKM$T0?><+DXC1
M@C*GH8-HY.F3?.N7,?]X]F_X]LR^<_!)-)R*VC*WCO4K./32-J,(S_%U6YS[
M_@+$_>!O*U!VL$J^R)B8%E44Y9"VD.5]BLH0=-3_B[>N_C_`K1-9$4H8P'??
M]'@<$#.<>:-A\=H;1[7(]Z2-F'Z]K$QB*,D9A5$`Z3V]I`NV1T/M4LSWHG\$
M\C@YOK057\I7E=-PXQ7S$BI8>_ANH#SWYB=(4!!IU2Z!L*=5,&7R<G;#E8=V
MRLT79Y`RI);:B[JW%BL51T+2(8`1OLT0N&[16%N]Z!JF!AR2.7-)JD2I8<N_
M`B86)V/EFW#+E/-(PL*4IHS5FIIRKFYRE@TR=9O6\'G0ZNESJP%1,22/:?BD
M@-I[^*+O+'S%2XNGFU3S'U+S<]O2SS_*MG<D!AKOK0.\R)-.>.K4@[4#_SMP
MFI"F4==,53C?92QDV1?``&[7BW?Z3,$ZAGN6]G84(+W+6-!U4T%AO(I6+9ET
MKB52SX#7+",F^T++ZGZ]]YD8Y.,T?>FWE=#"?=)_)[@&@OTOU5C(@>SN`,_U
M-2SUU?XB861T(]2%R;']LC"BYJGR&A"A79.FG'U2:="G^5V>+,LXSB]XO=N%
M;1:0WG@H=!'Q<!]\R"2GVM1->^@3\N)+AAFP?()+NAPHFL9N2-]BS2>.<LGD
MAY#N#3T=B8@6.L!PHYN+RF_SU?DR\19&4B;AFH01N=VS@)VZW70YRJA3R*):
MT@)_=;?16&`7D>>\+;5A=13BY"&3,M(X/A7&N4D^EU2;7E6X9Y5Z(_*46]W3
MC*MT1&KNW)3N?Z"+;QD_^$]4)+R]`:IVB`P@<L:2/4VBYK&U"5#&Z+Z[)HA8
M0C5"Q*@,F.QVU'0QXI9]?X-F.,<M&8;9=@``O(XL[HMP<<N_B0]K&N63D$2O
MS!R^H?^SNGFV$E.&&\7-T!,)>162T>K"!IT&Q6K8O1"'(T?K!'(K!*"N1L[4
M,?PK6\P4OC6YQ>QEW/"C03W+1XD",Q%7)WU4N.^DH9'LY[^[B)-HI1`H@Q;'
MEOBLLYW)?5A`GF.+`3U#J^X%5\TPM;J&5._X&@]ERA8KV%%@CTPPD;Q%1;!9
MOEHM.V7KCZ,OAUO=1%!D0ZT2M[`]SL-#$=&Y#0U+D^O#B0^I:5-DP($H(ZKO
ML<XX7O+=VX!FL'$9X/?C(6,^AY+$&DCT0*:#RIY$X(T"/C[W$$\J1'\@5E(B
MXB*9HE8QA9]U&)2`S8H=MU;2'0(^]%;GU`Y(N1NSP+6RW+X`(A(^*$0V<6T`
M/QI-7REL1BM_'C0E4RI/4B9@J)<!@1ZX>K%K)D2P7_I$:P[O0,-(DX\7/.WW
M^/Q];6""3(/@W?0>Y@B_\',;9'`7=PD32%G?XKL=-8`WN-1RAQ\Z1Y`!\T9O
M.T&I8F/>%N%:9$'%[\D/P;BE2`RQ?514I-FI)_\/,4_WPF)2J,VV-JIG081:
MX::/QGA_-[AKE__1+Z#J^/M`TWATI*FZ.>_3/\7/-,:WP\#G.>!%<$A;N[[@
MJ_0"%T^]:P0/@FA<;HS;`T+A;Z4S6F0,9&T#?O5,"VZ\&_!IIVD<HG#'7\WT
MPSPE[S8/"ED?@WD(OW%5G@T,&SR*;R+GAZI,3)$WCPK\[9[_VJ^YKC7^$`$5
M.P4>\(2]J,3B&DB[F^\1'&21P5YAWP3A<A3XDK^H(TK\$^%?,IW&?Q!SI$^(
M>!W622Y1_:9;`75J\KJ<G-=)*KU4;YR)3$*+W]0=X)3IX#QTR:'OOBOQS?4Q
MY7JN(S!N;!(3>^16D5'`P+B4/4)R(,?2&MPV9+C*3&1`7)G<TO*53K9,"'H^
M$UMDFA8^^VN]L":"=H:5(NFJ,9]HNVE`_J)PQ+2_@F:E!@2,WGJ)]^B)3=(9
M(`"[RU<,[+/8G`!Q4U>4_5-MHS3*/A3=50:.6&D9HN#J,QCE55\*3)W(_[W5
M/=>K$N+!\+T`C2>CO(?]LY-6.6YEBO6?4N-;%';`QLQ,?]']D0&B?,`0FJ]@
M7#\;II>O,X(`TC+S(3Q@)IT>MISX7C[WIIAC+(&.AQ#M'PN`5'?:?1#O'IT2
M,#6B=EPO`[(:7WQ2:?X/7A@=4R@.+2L<:?RIC%48B"G<GR>!?G1[=\<PWP+%
M)Q43*SO_/-4+U!/(A'_K`7X&?N0-+.8X=!I-_/K(A`0M[LC;_A-:9(%HFPE3
M![H!!2LS(B0F35&'C^?%N$+A+7R^0M^#,X'7J;(!>!3INHT=5J<S*X31M,X(
M=L38RQ;3F+[`JD4&X6"X[,*ZEUE-J=L/IO`,E=U2*E5`%H=CQMA*+TS)L921
M(#<6_^,<^R:\B4,&J.<=+W=)S],SZP#H@Y5115CB2+405,&(7;CQ8#PUITGF
M<)?E+ZE8FJY3@$"`[`FK%<_Z]X2TS4EP7UU.C4<=.?NQ3"#W**Z]:)?*H[F]
MSG3*Y$@;U7FV7L`!=M%B%1YN"@\S>B^NURX<725.`,V)LQD\M3K<S/>N(IK;
MOM48L%KLWF,)P5NP]T;(*3.S+77SZ=*``8L2OX/=A[_/'-:?A1%L=-`KG.N]
M$*&&`=01'/`5,UN[+DTH?J&R>TB_GI](=E8I]XE=.!\__[W%3*$QSYY_(2*4
M2&[!TSNDG'5I>*4S`G3O/<X@1),?=UE&`<FLDPU*A446A!OJ4Q*(/1B*T^-@
MT9$AG$L:V5F/.XJY29?.L5S9(=J-:<5A_C,;@`D>=)'>N=07""H0QRHK-?!<
MAS&]$9^HCTDKYSXU_42E^HQ)M=E[T[5CB_L;)N>TH*R&DHPBA07W\.JUPLS=
M0]Q:+4X+-HK*+O@ZS2%52I-27D+MZ]4Z3!/[7AI?O`F*$\S%&(#0O(K+SQK_
MVY2E^M0/)GFZX)M&YM5Q`_"#/H')BS\5&C4!^O-'@6::BF=JSRIL=0[5M9>7
M31JP8=H3XIK.'+D@ONE,AOJ9,],HOY)#VG_26EG<M4QG;$-TFJMNQ#,<S7>G
M)W\+3$.+JHU(WPH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO
M<&QI8B]L;V-A;&5S+P``````````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$V,3<R`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]A9&UI;B]P;&EB+VQO8V%L97,O96XM55,O````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`U-@`P,3<Q,C$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O;&]C86QE
M<R]E;BU54R]M97-S86=E<U]E;BU54RYP:'``````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`Q-#0S,C<R`#$P-3$U-#,Q,#4V`#`R,C0V,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`IG;&]B86P@)%!2
M3T1?3D%-12P@)&QM<V=?87)R.PIG;&]B86P@)&1E9E]D871E7V9O<FUA="P@
M)&1E9E]T:6UE7V9O<FUA="P@)&1E9E]D871E=&EM95]F;W)M870["@HO*BH*
M("H@1F]R(&UO<F4@:6YF;R!A8F]U="!T:6UE(&%N9"!D871E(&9O<FUA="!S
M964Z"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN
M9&%T92YP:'`*("HO"B1D969?9&%T95]F;W)M870)/2`G32!J+"!9)SL*)&1E
M9E]T:6UE7V9O<FUA=`D]("=H.FDZ<R!!)SL*)&1E9E]D871E=&EM95]F;W)M
M870]("=-(&HL(%D@:#II($$G.PH*)&QM<V=?87)R(#T@87)R87D@*`H*("`@
M("`@("`O+R`J*BH@5&AE('-T<FEN9W,@8F5L;W<@:&%V92!B965N(&=E;F5R
M871E9"!A=71O;6%T:6-A;&QY(&9R;VT@0$!#05!424].(&1I<F5C=&EV97,N
M"@H@("`@("`@("=U:5]?861M:6XM:6YF;U]?9&5S8W)I<'1I;VXG(#T^("=%
M9&ET($-0(&%D;6EN:7-T<F%T;W(@<&5R<V]N86P@:6YF;W)M871I;VXN)RP*
M("`@("`@("`G=6E?7V%D;6EN+6EN9F]?7V1O;F4G(#T^("=!9&UI;FES=')A
M=&]R('!E<G-O;F%L(&EN9F]R;6%T:6]N(&AA<R!B965N('5P9&%T960N)RP*
M("`@("`@("`G=6E?7V%D;6EN+6EN9F]?7W-H;W)T+71I=&QE)R`]/B`G061M
M:6X@:6YF;R<L"B`@("`@("`@)W5I7U]A9&UI;BUI;F9O7U]T:71L92<@/3X@
M)T-H86YG92!P97)S;VYA;"!I;F9O)RP*"B`@("`@("`@)W5I7U]A9&UI;BUP
M87-S=V]R9%]?9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@4&QE<VL@061M:6YI
M<W1R871O<B!P87-S=V]R9"XG+`H@("`@("`@("=U:5]?861M:6XM<&%S<W=O
M<F1?7V1O;F4G(#T^("=0;&5S:R!!9&UI;FES=')A=&]R('!A<W-W;W)D(&AA
M<R!B965N(&-H86YG960N)RP*("`@("`@("`G=6E?7V%D;6EN+7!A<W-W;W)D
M7U]S:&]R="UT:71L92<@/3X@)U!A<W-W;W)D)RP*("`@("`@("`G=6E?7V%D
M;6EN+7!A<W-W;W)D7U]T:71L92<@/3X@)T-H86YG92!P87-S=V]R9"<L"@H@
M("`@("`@("=U:5]?8VQI96YT7U]D97-C<FEP=&EO;B<@/3X@)T-L:65N="`E
M,5PG<R!A8V-O=6YT(&%N9"!D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G1?7V1I<V%B;&5D+7=A<FYI;F<G(#T^("=#;&EE;G0@)3$@:7,@9&ES86)L
M960N)RP*("`@("`@("`G=6E?7V-L:65N=%]?;F]N92UA=F%I;&%B;&4G(#T^
M("=4:&5R92!A<F4@;F\@8VQI96YT(&%C8V]U;G1S(&-O;F9I9W5R960N)RP*
M("`@("`@("`G=6E?7V-L:65N=%]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G1?7W1I=&QE)R`]/B`G0VQI96YT("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N=%]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@
M;V8@;7D@9&]M86EN<RXG+`H@("`@("`@("=U:5]?8VQI96YT7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G37D@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G1?<V5L9E]?=&ET;&4G(#T^("=->2!D;VUA:6YS)RP*("`@("`@("`G=6E?
M7V-L:65N=%]U;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=#;&EE;G1S)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7U]D97-C<FEP=&EO;B<@/3X@
M)T)A8VL@=7`O4F5S=&]R92!C;&EE;G0@<&5R<V]N86P@:6YF;R!A;F0@86-C
M;W5N="!S971T:6YG<R!A;F0O;W(@8VQI96YT(&1O;6%I;G,L('-C:&5D=6QE
M(&)A8VMU<',@=FEA(%!L97-K($)A8VMU<"!-86YA9V5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O8F%C:W5P7U]D;VYE)R`]/B`G)RP*("`@("`@("`G=6E?
M7V-L:65N="]B86-K=7!?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@
M("`@("`G=6E?7V-L:65N="]B86-K=7!?7W1I=&QE)R`]/B`G0VQI96YT("4Q
M(&)A8VMU<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W-E;&9?7V1E
M<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E('EO=7(@9&]M86EN<R!A
M;F0O;W(@86-C;W5N="!S971T:6YG<RP@<V-H961U;&4@8F%C:W5P<R!V:6$@
M4&QE<VL@0F%C:W5P($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]B
M86-K=7!?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M8F%C:W5P7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@
M("`G=6E?7V-L:65N="]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("="86-K=7`@
M36%N86=E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E(&-L:65N="!P97)S
M;VYA;"!I;F9O(&%N9"!A8V-O=6YT('-E='1I;F=S(&%N9"]O<B!C;&EE;G0@
M9&]M86EN<RP@<V-H961U;&4@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@("=U:5]?8VQI96YT
M+V)A8VMU<%]U;FMN;W=N7U]T:71L92<@/3X@)T-L:65N="!"86-K=7`G+`H@
M("`@("`@("=U:5]?8VQI96YT+V)A8VMU<%]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=#;&EE;G0@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]B
M86-K=7!?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@
M82!C;&EE;G0@=VAO<V4@86-C;W5N="!A;F0@9&]M86EN('EO=2!W86YT('1O
M(&)A8VL@=7`N)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W
M;E]?=VEZ87)D7U\R)R`]/B`G5&\@8F%C:R!U<"!T:&4@86-C;W5N="!S971T
M:6YG<R!A;F0O;W(@9&]M86EN<RP@8VQI8VL@0F%C:W5P($YO=RX@5&\@<F5S
M=&]R92!T:&4@97AI<W1I;F<@8F%C:W5P(&9I;&4L(&-L:6-K(&ET<R!N86UE
M+B!4;R!S8VAE9'5L92!B86-K=7!S+"!C;&EC:R!38VAE9'5L960@0F%C:W5P
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]D97-C
M<FEP=&EO;B<@/3X@)TQI<W0@;V8@8W5S=&]M(&)U='1O;G,@9F]R(&-L:65N
M="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]S
M:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS)RP*("`@("`@("`G=6E?
M7V-L:65N="]C=7-T;VTM8G5T=&]N<U]?=&ET;&4G(#T^("=#=7-T;VT@8G5T
M=&]N<R!O9B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O
M;2UB=71T;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!M>2!C
M=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB
M=71T;VYS7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O
M;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W-E;&9?
M7W1I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G3&ES="!O9B!A(&-L:65N="!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7W-H;W)T+71I
M=&QE)R`]/B`G0W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7W1I=&QE)R`]/B`G0VQI96YT(&-U
M<W1O;2!B=71T;VYS)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U
M='1O;G,O8W5S=&]M+6)U='1O;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@
M9&]N7"=T(&AA=F4@86YY(&-L:65N="UL979E;"!C=7-T;VT@8G5T=&]N<RXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB
M=71T;VY?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N
M7"=T(&AA=F4@86YY(&-U<W1O;2!B=71T;VYS+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D
M97-C<FEP=&EO;B<@/3X@)U)E;6]V92!C;&EE;G0M;&5V96P@8W5S=&]M(&)U
M='1O;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G0VQI96YT+6QE=F5L
M(&-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L
M971E7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I
M=&QE)R`]/B`G4F5M;W9E(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&$@8VQI96YT+6QE
M=F5L(&-U<W1O;2!B=71T;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=&ET
M;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M($)U='1O;B!296UO=F%L
M)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A(&-L:65N="!W:&]S92!C=7-T;VT@8G5T=&]N('EO=2!W86YT
M('1O(')E;6]V92!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,U]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M
M(&)U='1O;B!Y;W4@=V%N="!T;R!R96UO=F4@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=#;VYF:7)M
M(')E;6]V:6YG('1H92!C=7-T;VT@8G5T=&]N(&)Y('-E;&5C=&EN9R!T:&4@
M8VAE8VL@8F]X(&]N('1H:7,@<V-R965N(&%N9"!C;&EC:R!&:6YI<V@N)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R
M=&EE<R!O9B!C;&EE;G0M;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO
M<')O<&5R=&EE<U]?9&]N92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@<')O<&5R
M=&EE<R!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("=0<F5F97)E;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7U]T
M:71L92<@/3X@)TUO9&EF>2!C;&EE;G0@8W5S=&]M(&)U='1O;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W
M(&-L:65N="UL979E;"!C=7-T;VT@8G5T=&]N+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S
M7VYE=U]?9&]N92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@8W)E
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U
M<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G
M0W)E871E)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C
M=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T
M92!C;&EE;G0@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M($)U='1O;B!#<F5A=&EO;B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE
M8W0@82!C;&EE;G0@9F]R('=H;VT@>6]U('=A;GD@=&\@8W)E871E(&$@8W5S
M=&]M(&)U='1O;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE
M<U]N97=?7W=I>F%R9%]?,U]N97<G(#T^("=#;&EC:R!&:6YI<V@@=&\@8W)E
M871E(&-U<W1O;2!B=71T;VX@=VET:"!T:&4@9&5F:6YE9"!P<F]P97)T:65S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M161I="!P<F]P97)T:65S(&]F(&$@8VQI96YT+6QE=F5L(&-U<W1O;2!B=71T
M;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=0<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T
M=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G
M(#T^("=-;V1I9GD@8VQI96YT(&-U<W1O;2!B=71T;VXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R
M=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=-;V1I9GEI;F<@0VQI
M96YT+6QE=F5L($-U<W1O;2!"=71T;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]W:7IA<F1?7S-?=6YK;F]W;B<@/3X@)U-E;&5C="!W:&EC:"!C=7-T
M;VT@8G5T=&]N('EO=2!W86YT('1O(&UO9&EF>2!A;F0@8VQI8VL@3F5X="`^
M/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7
M:&5N(&1O;F4@=VET:"!E9&ET:6YG('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O
M;2!B=71T;VXL(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E
M>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM
M8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;VYO=VY?7W=I
M>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT('=H;W-E(&-U
M<W1O;2!B=71T;VX@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-C=7-T;VTM
M8G5T=&]N<U]?=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(V1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]
M/B`G3F\@9F%V;W)I=&4@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&%S:&)O87)D(V1O;6%I;G-?7W1I=&QE)R`]/B`G1&]M86EN<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(V9A=F]R:71E<R]T86)S7U]D97-C
M<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!T86)S(&EN($9A=F]R
M:71E<SHG+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-F879O<FET
M97-?7W1I=&QE)R`]/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D87-H8F]A<F0C:6YF;R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO
M=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@
M/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1A<VAB;V%R9"-I;F9O7U]T:71L92<@/3X@)TEN9F]R
M;6%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C;6%I;&YA
M;65S7U]D97-C<FEP=&EO;B<@/3X@)TYO(&9A=F]R:71E(&UA:6QN86UE<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(VUA:6QN86UE<U]?=&ET
M;&4G(#T^("=-86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB
M;V%R9"-Q=6EC:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*
M("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C<F5C96YT7U]D97-C<FEP
M=&EO;B<@/3X@)TYO(')E8V5N="!P86=E<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D(W)E8V5N=%]?=&ET;&4G(#T^("=296-E;G0G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T
M:6]N)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M87-H8F]A<F0C<VAO<G1C=71S7U]T:71L92<@/3X@)U-H;W)T8W5T<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7V1E<V-R
M:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N.B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7W1I
M=&QE)R`]/B`G4W1A=&ES=&EC<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S
M:&)O87)D(W1O;VQS+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H
M92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(W1O;VQS7U]D97-C<FEP=&EO;B<@/3X@
M)U-H;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS.B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D(W1O;VQS7U]T:71L92<@/3X@)U1O;VQS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?7V1E<V-R:7!T:6]N)R`]/B`G
M1&5S:W1O<"!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M87-H8F]A<F1?7W-H;W)T+71I=&QE)R`]/B`G)3%<)W,@1&5S:W1O<"<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7U]T:71L92<@/3X@)T1E<VMT
M;W`@;V8@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A
M<F1?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=->2!$97-K=&]P+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7W-E;&9?7W-H;W)T+71I=&QE)R`]
M/B`G1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7W-E
M;&9?7W1I=&QE)R`]/B`G37D@1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VQI96YT
M($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?=6YK
M;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*("`@("`@("`G=6E?
M7V-L:65N="]D87-H8F]A<F1?=6YK;F]W;E]?=&ET;&4G(#T^("=#;&EE;G0@
M1&5S:W1O<"<L"@H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T
M;VUI>F5?7V1E<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`@;V8@
M8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+V-U
M<W1O;6EZ95]?9&]N92<@/3X@)U-E='1I;F<@;V8@1&5S:W1O<"!F;W(@8VQI
M96YT("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D+V-U<W1O;6EZ95]?<VAO<G0M=&ET;&4G(#T^("=#=7-T
M;VUI>F4@1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D
M+V-U<W1O;6EZ95]?=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@
M8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O8W5S
M=&]M:7IE7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE('EO=7(@
M1&5S:W1O<"!C;VYT96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O
M87)D+V-U<W1O;6EZ95]S96QF7U]D;VYE)R`]/B`G66]U<B!$97-K=&]P('-E
M='1I;F=S(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT:71L92<@/3X@
M)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H
M8F]A<F0O8W5S=&]M:7IE7W-E;&9?7W1I=&QE)R`]/B`G0W5S=&]M:7IE(&UY
M($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T
M;VUI>F5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@1&5S
M:W1O<"!F;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H
M8F]A<F0O8W5S=&]M:7IE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0W5S
M=&]M:7IE($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?=6YK;F]W;E]?=&ET;&4G(#T^("=#=7-T;VUI>F4@8VQI
M96YT($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C
M=7-T;VUI>F5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M:7II
M;F<@0VQI96YT($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB
M;V%R9"]C=7-T;VUI>F5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^
M("=396QE8W0@82!C;&EE;G0@=VAO<V4@1&5S:W1O<"!Y;W4@=V%N="!T;R!C
M=7-T;VUI>F4@86YD(&-L:6-K($YE>'0@/CXN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7V1E<V-R:7!T
M:6]N)R`]/B`G161I="!P<F]P97)T:65S(&]F('-H;W)T8W5T("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=0<F]P97)T:65S(&]F('-H;W)T8W5T("4Q(&AA=F4@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I="<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E
M<G1I97-?7W1I=&QE)R`]/B`G161I="!S:&]R=&-U="`E,2<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W
M7U]D97-C<FEP=&EO;B<@/3X@)T-R96%T92!N97<@<VAO<G1C=70N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE
M<U]N97=?7V1O;F4G(#T^("=3:&]R=&-U="`E,2!H87,@8F5E;B!C<F5A=&5D
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R
M;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!S:&]R=&-U
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R
M;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!S:&]R=&-U="<L"@H@
M("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^("=2
M96UO=F4@86-C;W5N="!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D96QE=&5?7V1O;F4G(#T^("=#;&EE;G0@)3$@:&%S(&)E96X@<F5M
M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?<VAO<G0M=&ET
M;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?
M=&ET;&4G(#T^("=296UO=F4@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L
M:65N="]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=296UO=F4@
M82!C;&EE;G0@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&5L971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E
M(&-L:65N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9"UT:71L92<@/3X@)T-L:65N="!296UO=F%L)RP*("`@("`@("`G
M=6E?7V-L:65N="]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG
M(#T^("=396QE8W0@=VAI8V@@8VQI96YT('EO=2!W86YT('1O(')E;6]V92!A
M;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T
M95]U;FMN;W=N7U]W:7IA<F1?7S(G(#T^("=#;VYF:7)M(&-L:65N="!R96UO
M=F%L(&)Y('-E;&5C=&EN9R!T:&4@8VAE8VL@8F]X(&%N9"!C;&EC:R!&:6YI
M<V@@=&\@8V]M<&QE=&4@=&AE(')E;6]C86P@86YD(&5X:70@=&AE('=I>F%R
M9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7V1E<V-R:7!T:6]N
M)R`]/B`G36%N86=E(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;E]?9&ES86)L960M=V%R;FEN9R<@/3X@)T1O;6%I;B`E,2!I<R!D
M:7-A8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?;F]N92UA
M=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7VYO;F4M879A:6QA8FQE7U\Q
M)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7W-H;W)T+71I=&QE)R`]/B`G
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?=&ET;&4G(#T^("=$
M;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]S96QF7U]D
M97-C<FEP=&EO;B<@/3X@)TUA;F%G92!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;E]S96QF7U]D:7-A8FQE9"UW87)N:6YG)R`]
M/B`G66]U<B!D;VUA:6X@:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6Y?<V5L9E]?<75I8VLM<V5A<F-H)R`]/B`G37D@9&]M86EN
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G37D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6Y?<V5L9E]?=&ET;&4G(#T^("=->2!D;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;E]U;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=$;VUA
M:6YS)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V)A8VMU<%]?9&5S
M8W)I<'1I;VXG(#T^("="86-K('5P+U)E<W1O<F4@=&AE(&1O;6%I;BP@<V-H
M961U;&4@=&AE(&1O;6%I;B!B86-K=7!S('9I82!0;&5S:R!"86-K=7`@36%N
M86=E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?7V1O
M;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?
M7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8F%C:W5P7U]T:71L92<@/3X@)T1O;6%I;B`E,2!B86-K=7`G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("="86-K('5P+U)E<W1O<F4@>6]U<B!D;VUA:6XL('-C
M:&5D=6QE('1H92!D;VUA:6X@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C:W5P7W-E
M;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B
M86-K=7!?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("=$
M;VUA:6X@8F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C
M:W5P7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E
M(&$@9&]M86EN+"!S8VAE9'5L92!A(&1O;6%I;B!B86-K=7!S('9I82!0;&5S
M:R!"86-K=7`@36%N86=E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]B86-K=7!?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=&ET
M;&4G(#T^("=$;VUA:6X@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO8F%C:W5P7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T1O;6%I
M;B!"86-K=7`G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?
M=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA
M:6X@>6]U('=A;G0@=&\@8F%C:R!U<"!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=VEZ
M87)D7U\S)R`]/B`G5&\@8F%C:R!U<"!T:&4@9&]M86EN+"!C;&EC:R!"86-K
M=7`@3F]W+B!4;R!R97-T;W)E('1H92!E>&ES=&EN9R!B86-K=7`@9FEL92P@
M8VQI8VL@:71S(&YA;64N(%1O('-C:&5D=6QE(&)A8VMU<',L(&-L:6-K(%-C
M:&5D=6QE9"!"86-K=7`N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V-U<W1O;2UB=71T;VYS7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@9&]M
M86EN("4Q(&-U<W1O;2!B=71T;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V-U<W1O;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O
M;2!B=71T;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M
M+6)U='1O;G-?7W1I=&QE)R`]/B`G0W5S=&]M(&)U='1O;G,@9F]R(&1O;6%I
M;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!Y;W5R(&-U<W1O
M;2!B=71T;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U
M='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<U]S96QF7U]T:71L92<@/3X@)TUY(&-U<W1O;2!B=71T;VYS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!C=7-T;VT@8G5T
M=&]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?
M=6YK;F]W;E]?=&ET;&4G(#T^("=$;VUA:6X@8W5S=&]M(&)U='1O;G,G+`H*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA
M=F4@86YY(&1O;6%I;BUL979E;"!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T
M=&]N7U]N;VYE+6%V86EL86)L95]?,2<@/3X@)T-L:65N="`E,2!D;V5S;EPG
M="!H879E(&%N>2!D;VUA:6XM;&5V96P@8W5S=&]M(&)U='1O;G,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;E]?;F]N92UA=F%I;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@
M8W5S=&]M(&)U='1O;G,@9F]R(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D
M96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&1O;6%I;B!C=7-T;VT@
M8G5T=&]N("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G1&]M
M86EN(&-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O
M;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N
M)R`]/B`G4F5M;W9E(&$@9&]M86EN+6QE=F5L(&-U<W1O;2!B=71T;VXN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=2
M96UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@
M)U)E;6]V92!D;VUA:6X@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L
M971E7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@
M4F5M;W9A;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?
M,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&9R;VT@=VAO<V4@9&]M
M86EN('EO=2!W86YT('1O(')E;6]V92!A(&-U<W1O;2!B=71T;VX@86YD(&-L
M:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9G)O;2!W:&EC
M:"!Y;W4@=V%N="!T;R!R96UO=F4@82!C=7-T;VT@8G5T=&]N(&%N9"!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R
M9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M(&)U='1O;B!Y;W4@
M=V%N="!T;R!R96UO=F4@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO
M=FEN9R!T:&4@8W5S=&]M(&)U='1O;B!B>2!S96QE8W1I;F<@=&AE(&-H96-K
M(&)O>"!A;F0@8VQI8VL@1FEN:7-H('1O(&-O;7!L971E;'D@<F5M;W9E('1H
M92!B=71T;VX@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P
M<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O
M9B!D;VUA:6XM;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q('!R;W!E
M<G1I97,@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T
M:65S7U]S:&]R="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G36]D:69Y(&1O;6%I;B!C=7-T;VT@
M8G5T=&]N("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M
M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I
M<'1I;VXG(#T^("=#<F5A=&4@;F5W(&1O;6%I;BUL979E;"!C=7-T;VT@8G5T
M=&]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=#
M=7-T;VT@8G5T=&]N("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!D
M;VUA:6X@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N
M97=?7W=I>F%R9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@0W)E871I;VXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C
M=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S%?=6YK;F]W
M;B<@/3X@)U-E;&5C="!A(&-L:65N="!F;W(@=VAO<V4@9&]M86EN('EO=2!W
M86YT('1O(&-R96%T92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@
M/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9F]R('=H:6-H('EO=2!W86YT
M('1O(&-R96%T92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O
M8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO
M=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@
M;6]D:69Y(&$@8W5S=&]M(&)U='1O;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?;F5W)R`]/B`G
M0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@8W5S=&]M(&)U='1O;B!A;F0@
M97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@9&]M86EN+6QE=F5L(&-U<W1O
M;2!B=71T;VX@<')O<&5R=&EE<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=0<F]P97)T:65S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36]D:69Y(&1O
M;6%I;B!C=7-T;VT@8G5T=&]N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7W5N
M:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUO9&EF>6EN9R!$;VUA:6X@0W5S
M=&]M($)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-U<W1O;2!B=71T;VX@
M=VAI8V@@<V5T=&EN9W,@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.
M97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA
M<F1?7S4G(#T^("=7:&5N(&1O;F4@=VET:"!C:&%N9VEN9R!P<F]P97)T:65S
M(&]F('1H92!C=7-T;VT@8G5T=&]N+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@
M8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D87-H8F]A<F0C8W5S=&]M+6)U='1O;G-?7W1I=&QE
M)R`]/B`G0W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D87-H8F]A<F0C9F%V;W)I=&5S+W1A8G-?7V1E<V-R:7!T:6]N)R`]
M/B`G4VAO=R!T:&4@9F]L;&]W:6YG('1A8G,@:6X@1F%V;W)I=&5S.B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-F879O<FET97-?
M7W1I=&QE)R`]/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%S:&)O87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@
M)U-H;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(VEN9F]?7V1E
M<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N
M.B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-I;F9O
M7U]T:71L92<@/3X@)TEN9F]R;6%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%S:&)O87)D(VUA:6QN86UE<U]?9&5S8W)I<'1I;VXG(#T^
M("=.;R!F879O<FET92!M86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F0C;6%I;&YA;65S7U]T:71L92<@/3X@)TUA:6QN
M86UE<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-Q
M=6EC:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W)E8V5N=%]?9&5S8W)I
M<'1I;VXG(#T^("=.;R!R96-E;G0@<&%G97,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]D87-H8F]A<F0C<F5C96YT7U]T:71L92<@/3X@)U)E8V5N
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-S:&]R
M=&-U='-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W-H;W)T8W5T<U]?=&ET
M;&4G(#T^("=3:&]R=&-U=',G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D87-H8F]A<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=3:&]W
M('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D(W-T871I<W1I8W-?7W1I=&QE)R`]/B`G
M4W1A=&ES=&EC<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB
M;V%R9"-T;V]L<R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@
M9F]L;&]W:6YG(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0C=&]O;'-?7V1E<V-R:7!T:6]N
M)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,Z)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W1O;VQS7U]T:71L92<@/3X@
M)U1O;VQS)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D
M7U]D97-C<FEP=&EO;B<@/3X@)T1E<VMT;W`@;V8@9&]M86EN(&%D;6EN:7-T
M<F%T;W(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D7U]S:&]R="UT:71L92<@/3X@)R4Q7"=S($1E<VMT;W`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F1?7W1I=&QE)R`]/B`G1&5S
M:W1O<"!O9B!D;VUA:6X@861M:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F1?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=->2!$
M97-K=&]P+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9%]S96QF7U]S:&]R="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F1?<V5L9E]?=&ET;&4G(#T^("=-
M>2!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G1&]M86EN(&%D;6EN:7-T
M<F%T;W(@9&5S:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M87-H8F]A<F1?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G1&]M86EN(&%D;6EN(&1E<VMT;W`G+`H*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I
M<'1I;VXG(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@1&]M86EN($%D;6EN
M:7-T<F%T;W(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S
M:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@
M1&]M86EN($%D;6EN:7-T<F%T;W(@1&5S:W1O<"XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G
M1&5S:W1O<"!O9B!$;VUA:6X@061M:6YI<W1R871O<B`E,2!H87,@8F5E;B!U
M<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT
M;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S
M=&]M:7IE7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ
M95]?=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!O9B!$;VUA:6X@061M
M:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O
M8W5S=&]M:7IE7U]T:71L92<@/3X@)T-U<W1O;6EZ92!$;VUA:6X@061M:6X@
M1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@
M;7D@1&5S:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H
M8F]A<F0O8W5S=&]M:7IE7W-E;&9?7V1O;F4G(#T^("=9;W5R($1E<VMT;W`@
M<V5T=&EN9W,@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT
M:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L92<@
M/3X@)T-U<W1O;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7U]D97-C
M<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O9B!S:&]R=&-U="`E,2XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA<R!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R
M=&-U="]P<F]P97)T:65S7U]T:71L92<@/3X@)T5D:70@<VAO<G1C=70@)3$G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE
M=R!S:&]R=&-U="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H
M8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:&]R
M=&-U="`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7VYE=U]?
M<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@<VAO<G1C=70G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE
M<U]N97=?7W1I=&QE)R`]/B`G0W)E871E('-H;W)T8W5T)RP*"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<U]?9&5S8W)I<'1I;VXG(#T^
M("=,:7-T(&]F(&1O;6%I;B`E,2!D871A8F%S97,N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7U]S:&]R="UT:71L92<@/3X@)T1A
M=&%B87-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E
M<U]?=&ET;&4G(#T^("=$871A8F%S97,@;V8@9&]M86EN("4Q)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7W-E;&9?7V1E<V-R:7!T
M:6]N)R`]/B`G3&ES="!O9B!Y;W5R(&1A=&%B87-E<RXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97-?<V5L9E]?<VAO<G0M=&ET;&4G
M(#T^("=$871A8F%S97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M871A8F%S97-?<V5L9E]?=&ET;&4G(#T^("=->2!D871A8F%S97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97-?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!D871A8F%S97,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G1&%T86)A<V5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&]M86EN
M(&1A=&%B87-E<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A
M8F%S97,O9&%T86)A<V5?7V1E<V-R:7!T:6]N)R`]/B`G1&%T86)A<V4@)3$@
M=7-E<G,@86YD(%=E8D%D;6EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1A=&%B87-E<R]D871A8F%S95]?;F]N92UA=F%I;&%B;&4G(#T^("=9
M;W4@9&]N7"=T(&AA=F4@86YY(&1A=&%B87-E<RXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V5?7VYO;F4M879A:6QA
M8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1A=&%B
M87-E<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O
M9&%T86)A<V5?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO
M(&1A=&%B87-E<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7U]S:&]R="UT:71L92<@/3X@
M)R4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A
M=&%B87-E7U]T:71L92<@/3X@)T1A=&%B87-E("4Q('5S97)S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7W5N:VYO
M=VY?7V1E<V-R:7!T:6]N)R`]/B`G36%N86=E(&1A=&%B87-E('5S97)S(&%N
M9"!A8V-E<W,@5V5B061M:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G1&%T86)A<V4@=7-E<G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D871A8F%S97,O9&%T86)A<V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86YA
M9V4@9&%T86)A<V4@=7-E<G,G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^
M("=296UO=F4@9&%T86)A<V4@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?9&]N92<@/3X@)T1A
M=&%B87-E("4Q(&AA<R!B965N(')E;6]V960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?<VAO<G0M
M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D871A8F%S97,O9&%T86)A<V4O9&5L971E7U]T:71L92<@/3X@)U)E;6]V
M92!D871A8F%S92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=296UO=F4@82!D871A8F%S92XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O9&5L971E7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E;6]V92!D871A8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D+71I=&QE)R`]/B`G1&%T86)A<V4@4F5M;W9A;"<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@
M9G)O;2!W:&EC:"!W86YT('1O(')E;6]V92!A(&1A=&%B87-E(&%N9"!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO
M=VXG(#T^("=396QE8W0@82!D871A8F%S92!Y;W4@=V%N="!T;R!R96UO=F4@
M86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?
M7S4G(#T^("=#;VYF:7)M(')E;6]V:6YG('1H92!D871A8F%S92!B>2!S96QE
M8W1I;F<@=&AE(&-H96-K(&)O>"!A;F0@8VQI8VL@1FEN:7-H('1O(&-O;7!L
M971E;'D@<F5M;W9E('1H92!D871A8F%S92!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T
M86)A<V4O<')O<&5R=&EE<U]N97<M861H;V-?7W=I>F%R9%]?-%]N97<G(#T^
M("=4:&4@9&%T86)A<V4@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F
M=&5R('EO=2!C;&EC:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]P<F]P97)T:65S7VYE=U]?9&5S
M8W)I<'1I;VXG(#T^("=#<F5A=&4@82!N97<@9&%T86)A<V4N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W!R;W!E
M<G1I97-?;F5W7U]D;VYE)R`]/B`G1&%T86)A<V4@)3$@:&%S(&)E96X@8W)E
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O
M9&%T86)A<V4O<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G0W)E
M871E(&1A=&%B87-E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T
M86)A<V5S+V1A=&%B87-E+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R
M96%T92!D871A8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE
M)R`]/B`G1&%T86)A<V4@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN(&]N('=H:6-H
M('EO=2!W86YT('1O(&-R96%T92!A(&1A=&%B87-E(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D
M871A8F%S92]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\T7VYE=R<@/3X@)T-L
M:6-K($9I;FES:"!T;R!C<F5A=&4@=&AE(&1A=&%B87-E(&%N9"!E>&ET('1H
M92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]?9&5S8W)I<'1I;VXG(#T^("=!8V-E
M<W,@5V5B061M:6X@9F]R(&UA;F%G:6YG(&1A=&%B87-E("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]W96)A
M9&UI;E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V1A=&%B87-E<R]D871A8F%S92]W96)A9&UI;E]?<VAO<G0M=&ET;&4G(#T^
M("=796)!9&UI;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]?=&ET;&4G(#T^("=/<&5N(%=E8D%D
M;6EN(&9O<B!D871A8F%S92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1A=&%B87-E<R]D871A8F%S92]W96)A9&UI;E]U;FMN;W=N7U]D97-C
M<FEP=&EO;B<@/3X@)T%C8V5S<R!796)!9&UI;B!F;W(@;6%N86=I;F<@82!D
M871A8F%S92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S
M97,O9&%T86)A<V4O=V5B861M:6Y?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=796)!9&UI;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]U;FMN;W=N7U]T:71L92<@/3X@)T]P
M96X@5V5B061M:6X@9F]R(&1A=&%B87-E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?
M7W=I>F%R9"UT:71L92<@/3X@)U=E8D%D;6EN(%-T87)T=7`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O=V5B861M
M:6Y?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@9F]R('=H;W-E(&1A=&%B87-E('EO=2!W86YT('1O(&]P96X@5V5B
M061M:6X@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?
M7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&%T86)A<V4@=VAI
M8V@@>6]U('=A;G0@=&\@;6%N86=E('9I82!796)!9&UI;BXG+`H*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7U]D97-C<FEP=&EO;B<@/3X@
M)U)E;6]V92!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&5L971E7U]D;VYE)R`]/B`G1&]M86EN("4Q(&AA<R!B965N(')E;6]V
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@9&]M86EN("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G4F5M;W9E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@
M)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U
M;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE
M)R`]/B`G1&]M86EN(%)E;6]V86PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!D;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E(&%N9"!C;&EC:R!.
M97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U
M;FMN;W=N7U]W:7IA<F1?7S,G(#T^("=#;VYF:7)M(')E;6]V:6YG('1H92!D
M;VUA:6X@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K($9I
M;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ
M87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG7U]N
M;VYE+6%V86EL86)L92<@/3X@)TAO<W1I;F<@:7,@;F]T(&-O;F9I9W5R960@
M;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9U]?;F]N92UA=F%I;&%B;&5?7S(G(#T^("=(;W-T:6YG(&ES(&YO
M="!C;VYF:6=U<F5D(&]N(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1E<V-R:7!T:6]N
M)R`]/B`G06-C97-S(&1O;6%I;B`E,2!&:6QE($UA;F%G97(N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1O
M;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+V9I;&4M;6%N86=E<E]?<VAO<G0M=&ET;&4G(#T^("=&:6QE(&UA;F%G97(G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N
M86=E<E]?=&ET;&4G(#T^("=-86YA9V4@9FEL97,@;VX@9&]M86EN("4Q)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G
M97)?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=/<F=A;FEZ92!Y;W5R('=E8G-I
M=&4@9FEL97,@86YD(&1I<F5C=&]R:65S('9I82!0;&5S:R!&:6QE($UA;F%G
M97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE
M+6UA;F%G97)?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O9FEL92UM86YA9V5R7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G1FEL92!M86YA9V5R)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?<V5L9E]?=&ET;&4G(#T^("=-
M86YA9V4@9FEL97,@;VX@;7D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?9&5S8W)I
M<'1I;VXG(#T^("=/<F=A;FEZ92!A('=E8G-I=&4@9FEL97,@86YD(&1I<F5C
M=&]R:65S('9I82!0;&5S:R!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=&:6QE(&UA;F%G97(G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]T
M:71L92<@/3X@)TUA;F%G92!F:6QE<R!O;B!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N
M7U]W:7IA<F0M=&ET;&4G(#T^("=-86YA9VEN9R!&:6QE<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O9FEL92UM86YA9V5R7W5N:VYO
M=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN('=H
M:6-H(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!Y;W4@=V%N="!T;R!M86YA9V4@
M=VET:"!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R
M;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N
M9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L
M(&AO<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE
M($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<V5L9BUP:&]S=&EN9R<@/3X@)TAO<W1I;F<@:7,@;F]T('EE="!C;VYF:6=U
M<F5D(&]N('EO=7(@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L(&AO
M<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F
M:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\T)R`]/B`G5VAE;B!D;VYE
M('=I=&@@;6%N86=I;F<@9FEL97,@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN
M:7-H('1O(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]W:7IA<F1?
M7S1?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&UA;F%G:6YG(&9I;&5S(&]N
M('EO=7(@9&]M86EN+"!C;&EC:R!&:6YI<V@@=&\@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E
M<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G4V5T('5P(&AO<W1I;F<@<V5R=FEC
M97,@9F]R(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4V5T('5P
M(&AO<W1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4V5T('5P(&AO<W1I;F<@;VX@9&]M
M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P
M<F]P97)T:65S7V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG
M=7)E(&9O<G=A<F1I;F<@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]D
M;VYE)R`]/B`G1F]R=V%R9&EN9R!P<F]P97)T:65S(&]N(&1O;6%I;B`E,2!H
M879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W!R;W!E<G1I97-?9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=#;VYF:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]T:71L
M92<@/3X@)T-O;F9I9W5R92!F;W)W87)D:6YG(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]P
M:&]S=&EN9U]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@=FER='5A;"!H
M;W-T(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]P<F]P97)T:65S7W!H;W-T:6YG7U]D;VYE)R`]/B`G4&AY
M<VEC86P@:&]S=&EN9R!S971T:6YG<R!O;B!D;VUA:6X@)3$@:&%V92!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]P<F]P97)T:65S7W!H;W-T:6YG7U]S:&]R="UT:71L92<@/3X@)T-O;F9I
M9W5R92!P:'ES:6-A;"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W!H;W-T:6YG7U]T:71L92<@/3X@
M)T-O;F9I9W5R92!P:'ES:6-A;"!H;W-T:6YG(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S
M96QF+69O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&9O
M<G=A<F1I;F<@;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?
M9&]N92<@/3X@)T9O<G=A<F1I;F<@;VX@>6]U<B!D;VUA:6X@:&%S(&)E96X@
M8V]N9FEG=7)E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W!R;W!E<G1I97-?<V5L9BUF;W)W87)D:6YG7U]S:&]R="UT:71L92<@
M/3X@)T-O;F9I9W5R92!F;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?
M=&ET;&4G(#T^("=#;VYF:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T
M:6YG7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!V:7)T=6%L(&AO<W0@
M9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG7U]D;VYE)R`]/B`G
M4&AY<VEC86P@:&]S=&EN9R!S971T:6YG<R!O;B!Y;W5R(&1O;6%I;B!H879E
M(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W!R;W!E<G1I97-?<V5L9BUP:&]S=&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=#;VYF:6=U<F4@<&AY<VEC86P@:&]S=&EN9R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T
M:6YG7U]T:71L92<@/3X@)T-O;F9I9W5R92!P:'ES:6-A;"!H;W-T:6YG)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S
M7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0VQI8VL@=&\@<V5T('5P(&AO<W1I
M;F<@<V5R=FEC97,@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF7U]S:&]R="UT
M:71L92<@/3X@)U-E="!U<"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G
M4V5T('5P(&AO<W1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#
M;VYF:6=U<F4@:&]S=&EN9R!S97)V:6-E<R!F;W(@82!D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N
M:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&AO<W1I;F<G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?
M=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U<F4@:&]S=&EN9R!O;B!A(&1O
M;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#;VYF:6=U<FEN
M9R!(;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U
M<F4@:&]S=&EN9R!S97)V:6-E<R!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?=6YK
M;F]W;E]?=VEZ87)D7U\T)R`]/B`G4V5L96-T('1H92!T>7!E(&]F(&AO<W1I
M;F<@<V5R=FEC97,@>6]U('=A;G0@=&\@8V]N9FEG=7)E(&]N('1H92!D;VUA
M:6X@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]F
M;W)W87)D:6YG)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R
M=V%R9&EN9R!O;B!T:&4@9&]M86EN+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-%]P:&]S=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O
M;F9I9W5R:6YG('!H>7-I8V%L(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI
M8VL@1FEN:7-H('1O(&%P<&QY('1H92!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET
M('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF)R`]/B`G
M4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@<V5R=FEC97,@>6]U('=A;G0@
M=&\@8V]N9FEG=7)E(&]N('1H92!D;VUA:6X@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF+69O<G=A<F1I;F<G(#T^("=7
M:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!F;W)W87)D:6YG(&]N('EO=7(@
M9&]M86EN+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S
M96QF+7!H;W-T:6YG)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@
M<&AY<VEC86P@:&]S=&EN9R!O;B!Y;W5R(&1O;6%I;BP@8VQI8VL@1FEN:7-H
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M
M87!P;&EC871I;VYS7U]D97-C<FEP=&EO;B<@/3X@)TUA;F%G92!S:71E(&%P
M<&QI8V%T:6]N<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]?<VAO<G0M=&ET
M;&4G(#T^("=3:71E(&%P<&QI8V%T:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G-?7W1I=&QE)R`]
M/B`G36%N86=E('-I=&4@87!P;&EC871I;VYS(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A<'!L
M:6-A=&EO;G,@;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF
M7U]T:71L92<@/3X@)TUA;F%G92!M>2!S:71E(&%P<&QI8V%T:6]N<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A
M<'!L:6-A=&EO;G,@;VX@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U
M;FMN;W=N7U]T:71L92<@/3X@)TUA;F%G92!D;VUA:6X@<VET92!A<'!L:6-A
M=&EO;G,G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N7U]D97-C<FEP=&EO
M;B<@/3X@)U)E8V]N9FEG=7)E('-I=&4@87!P;&EC871I;VX@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T
M:6]N<R]S:71E+6%P<&QI8V%T:6]N7U]N;VYE+6%V86EL86)L92<@/3X@)UEO
M=2!D;VY<)W0@:&%V92!A;GD@:6YS=&%L;&5D('-I=&4@87!P;&EC871I;VYS
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?;F]N92UA=F%I;&%B;&5?
M7S$G(#T^("=#;&EE;G0@)3$@9&]E<VY<)W0@:&%V92!A;GD@(&EN<W1A;&QE
M9"!S:71E(&%P<&QI8V%T:6]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VY?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G3F\@<VET92!A<'!L:6-A=&EO
M;G,@87)E(&-U<G)E;G1L>2!I;G-T86QL960@;VX@9&]M86EN("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L
M:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?=&ET;&4G(#T^("=3:71E(&%P
M<&QI8V%T:6]N("4Q)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE
M=&5?7V1E<V-R:7!T:6]N)R`]/B`G56YI;G-T86QL('-I=&4@87!P;&EC871I
M;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?9&]N
M92<@/3X@)U-I=&4@87!P;&EC871I;VX@)3$@:&%S(&)E96X@=6YI;G-T86QL
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E
M+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?<VAO<G0M
M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO
M9&5L971E7U]T:71L92<@/3X@)U)E;6]V92!S:71E(&%P<&QI8V%T:6]N("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P
M<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]D
M97-C<FEP=&EO;B<@/3X@)U5N:6YS=&%L;"!A('-I=&4@87!P;&EC871I;VXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P
M<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A
M=&EO;B]D96QE=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=296UO=F4@<VET92!A
M<'!L:6-A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE=&5?
M=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G4VET92!!<'!L:6-A=&EO;B!5
M;FEN<W1A;&PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M(&]N('=H:6-H('EO=2!W86YT('1O('5N:6YS=&%L;"!A('-I=&4@87!P;&EC
M871I;VX@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI
M8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@=6YI;G-T
M86QL("!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC
M871I;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@
M=6YI;G-T86QL:6YG('1H92!S:71E(&%P<&QI8V%T:6]N(&)Y('-E;&5C=&EN
M9R!T:&4@8VAE8VL@8F]X(&%N9"!C;&EC:R!&:6YI<V@@=&\@8V]M<&QE=&5L
M>2!U;FEN<W1A;&P@:70@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]
M/B`G4F5C;VYF:6=U<F4@<VET92!A<'!L:6-A=&EO;B`E,2XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS
M+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]?9&]N92<@/3X@)U-I=&4@
M87!P;&EC871I;VX@)3$@8V]N9FEG=7)A=&EO;B!H87,@8F5E;B!U<&1A=&5D
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7U]S:&]R
M="UT:71L92<@/3X@)U)E8V]N9FEG=7)E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI
M8V%T:6]N+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4F5C;VYF:6=U<F4@<VET
M92!A<'!L:6-A=&EO;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=);G-T86QL(&$@<VET
M92!A<'!L:6-A=&EO;B!O;B!A(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P
M;&EC871I;VXO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:71E(&%P<&QI
M8V%T:6]N("4Q(&AA<R!B965N(&EN<W1A;&QE9"XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M
M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G
M26YS=&%L;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S
M7VYE=U]?=&ET;&4G(#T^("=);G-T86QL('-I=&4@87!P;&EC871I;VXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC
M871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R
M9"UT:71L92<@/3X@)U-I=&4@07!P;&EC871I;VX@26YS=&%L;&%T:6]N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI
M8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S$O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S
M)R`]/B`G4V5T('5P('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O;2!B=71T;VX@
M86YD(&-L:6-K($9I;FES:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO
M<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97,G(#T^("=3970@=7`@<')O<&5R=&EE<R!O
M9B!T:&4@8W5S=&]M(&)U='1O;B!A;F0@8VQI8VL@1FEN:7-H+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO
M;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R
M7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A
M;G0@=&\@:6YS=&%L;"!S:71E(&%P<&QI8V%T:6]N(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET
M92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE
M=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG
M(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!3970@=7`@
M<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI8VL@3F5X="`^/B!T;R!P<F]C965D
M('1O(&EN<W1A;&QI;F<@=&AE('-I=&4@87!P;&EC871I;VXN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O
M<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@
M>65T(&-O;F9I9W5R960@;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A
M;"!H;W-T:6YG(&%N9"!C;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@:6YS
M=&%L;&EN9R!T:&4@<VET92!A<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M
M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-5]N97<G(#T^
M("=396QE8W0@82!S:71E(&%P<&QI8V%T:6]N('EO=2!W86YT('1O(&EN<W1A
M;&P@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T
M:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S5?;F5W+65X=')A)R`]/B`G
M1&5F:6YE('=H870@<VAO=6QD(&)E(&1O;F4@=&\@=&AE(&5X=')A(&9I;&5S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U\U7VYE=RUI;F9O)R`]/B`G0VQI8VL@3F5X="`^/B!T;R!I;G-T
M86QL('1H92!S:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L
M:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\U7VYE=RUI;G-T86QL
M)R`]/B`G4W!E8VEF>2!T:&4@<VET92!A<'!L:6-A=&EO;B!P87)A;65T97)S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I
M97,G(#T^("=3970@=7`@<')O<&5R=&EE<R!O9B!T:&4@8W5S=&]M(&)U='1O
M;B!A;F0@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO
M;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5C;VYF
M:6=U<F4@82!S:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L
M:6-A=&EO;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M4F5C;VYF:6=U<F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R
M=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U)E8V]N9FEG=7)E('-I=&4@87!P
M;&EC871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE
M<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=3:71E($%P<&QI8V%T:6]N
M(%)E8V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(')E8V]N9FEG=7)E
M(&$@<VET92!A<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@<F5C;VYF
M:6=U<F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?
M=6YK;F]W;E]?=VEZ87)D7U\V)R`]/B`G4W!E8VEF>2!T:&4@<VET92!A<'!L
M:6-A=&EO;B!P87)A;65T97)S+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]/B`G3&ES
M="!O9B!D;VUA:6X@)3$@<W5B9&]M86EN<RXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?7W-H;W)T+71I=&QE)R`]
M/B`G4W5B9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<U]?=&ET;&4G(#T^("=3=6)D;VUA:6YS(&]F(&1O
M;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<W5B9&]M86EN<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@>6]U
M<B!S=6)D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-U8F1O
M;6%I;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U
M8F1O;6%I;G-?<V5L9E]?=&ET;&4G(#T^("=->2!S=6)D;VUA:6YS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS7W5N
M:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I
M;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=6)D;VUA:6YS)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I;B<L
M"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN7U]D97-C<FEP=&EO;B<@/3X@)U!R;W!E<G1I97,@;V8@
M<W5B9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6Y?7VYO;F4M879A:6QA8FQE)R`]
M/B`G66]U(&1O;EPG="!H879E(&%N>2!S=6)D;VUA:6YS+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6Y?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T
M(&AA=F4@86YY('-U8F1O;6%I;G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]?;F]N92UA=F%I
M;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@<W5B9&]M86EN<R!O;B!D;VUA
M:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M=6)D;VUA:6YS+W-U8F1O;6%I;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S
M=6)D;VUA:6Y?7W1I=&QE)R`]/B`G4W5B9&]M86EN("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I
M;E]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!S=6)D;VUA
M:6X@:&]S=&EN9R!S971T:6YG<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G4W5B9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]U;FMN;W=N
M7U]T:71L92<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I
M;B]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-U8F1O;6%I;B`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G,O<W5B9&]M86EN+V1E;&5T95]?9&]N92<@/3X@)U-U8F1O;6%I;B`E
M,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]T:71L
M92<@/3X@)U)E;6]V92!S=6)D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T
M95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!S=6)D;VUA:6X@
M8V]N9FEG=7)A=&EO;B!A;F0@8V]N=&5N="XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6XO9&5L971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E('-U8F1O;6%I
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M
M86EN<R]S=6)D;VUA:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)U-U8F1O;6%I;B!296UO=F%L)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@
M9G)O;2!W:&EC:"!Y;W4@=V%N="!T;R!R96UO=F4@82!S=6)D;VUA:6XN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M+W-U8F1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U7W5N:VYO=VXG
M(#T^("=396QE8W0@82!S=6)D;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN
M<R]S=6)D;VUA:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O
M;F9I<FT@<F5M;W9I;F<@=&AE('-U8F1O;6%I;B!B>2!S96QE8W1I;F<@=&AE
M(&-H96-K(&)O>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@<F5M
M;W9E(&ET(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O
M<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@<W5B9&]M86EN
M("4Q(&AO<W1I;F<@<V5T=&EN9W,N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]P<F]P97)T:65S
M7U]D;VYE)R`]/B`G4W5B9&]M86EN("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E
M96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W-H;W)T+71I
M=&QE)R`]/B`G)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W1I=&QE)R`]
M/B`G0V]N9FEG=7)E('-U8F1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R
M=&EE<U]N97<M861H;V-?7W=I>F%R9%]?-5]N97<G(#T^("=.97<@<W5B9&]M
M86EN('=I;&P@8F4@8W)E871E9"!I;6UE9&EA=&5L>2!A9G1E<B!Y;W4@8VQI
M8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]D97-C
M<FEP=&EO;B<@/3X@)T-R96%T92!N97<@<W5B9&]M86EN+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6XO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3=6)D;VUA:6X@)3$@:&%S
M(&)E96X@8W)E871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]S
M:&]R="UT:71L92<@/3X@)T-R96%T92!S=6)D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN
M+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!S=6)D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^
M("=3=6)D;VUA:6X@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?
M;F5W7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O
M;B!W:&EC:"!Y;W4@=V%N="!T;R!C<F5A=&4@82!S=6)D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U
M8F1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O
M;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI
M8VL@3F5X="`^/B!T;R!P<F]C965D('1O('-U8F1O;6%I;B!C<F5A=&EO;BXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O<')O<&5R
M=&EE<U]S96QF+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@>65T(&-O
M;F9I9W5R960@;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A;"!H;W-T
M:6YG(&%N9"!C;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@<W5B9&]M86EN
M(&-R96%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I>F%R
M9%]?-5]N97<G(#T^("=3<&5C:69Y('1H92!S=6)D;VUA:6X@:&]S=&EN9R!P
M87)A;65T97)S(&%N9"!C;&EC:R!&:6YI<V@@=&\@8W)E871E('1H92!S=6)D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M=6)D;VUA:6YS+W-U8F1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G0V]N9FEG=7)E('-U8F1O;6%I;B!H;W-T:6YG('-E='1I
M;F=S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B
M9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]S:&]R="UT
M:71L92<@/3X@)U-U8F1O;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U
M;FMN;W=N7U]T:71L92<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B
M9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G
M4W5B9&]M86EN($-O;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@=VAO<V4@<W5B9&]M86EN('EO=2!W86YT('1O(')E8V]N9FEG=7)E
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M
M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?
M=6YK;F]W;B<@/3X@)U-E;&5C="!A('-U8F1O;6%I;B!Y;W4@=V%N="!T;R!R
M96-O;F9I9W5R92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\V)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@=&AE
M('-U8F1O;6%I;B!H;W-T:6YG('-E='1I;F=S+"!C;&EC:R!&:6YI<V@@=&\@
M87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]?9&5S8W)I
M<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B`E,2!W96(@=7-E<G,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?7W-H
M;W)T+71I=&QE)R`]/B`G5V5B('5S97)S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?7W1I=&QE)R`]/B`G5V5B('5S
M97)S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES
M="!O9B!Y;W5R('=E8B!U<V5R<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]S96QF7U]S:&]R="UT:71L92<@/3X@
M)U=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?
M=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!W96(@
M=7-E<G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W
M96(M=7-E<G-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R
M<U]U;FMN;W=N7U]T:71L92<@/3X@)T1O;6%I;B!W96(@=7-E<G,G+`H*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O<')O
M<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=796(@=7-E<G,@<')E9F5R96YC
M97,@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?7V1O;F4G(#T^("=796(@
M=7-E<G,@<')E9F5R96YC97,@:&%V92!B965N('5P9&%T960@;VX@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,@9F]R('=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G5V5B
M('5S97)S('!R969E<F5N8V5S(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R('=E8B!U<V5R<R!P<F5F97)E
M;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W!R;W!E<G1I97-?<V5L9E]?9&]N92<@/3X@)UEO=7(@=V5B('5S
M97)S('!R969E<F5N8V5S(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I
M97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,@<')E9F5R96YC
M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU
M<V5R<R]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S
M('!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO
M;B<@/3X@)U=E8B!U<V5R<R!P<F5F97)E;F-E<R!O9B!A(&1O;6%I;BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,@9F]R('=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G
M(#T^("=796(@=7-E<G,@<')E9F5R96YC97,@;V8@82!D;VUA:6XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P<F]P
M97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T
M(&$@9&]M86EN(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U<F4@=V5B
M('5S97)S('!R969E<F5N8V5S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D7U\U)R`]/B`G5VAE;B!D;VYE('=I=&@@961I=&EN9R!T:&4@=V5B('5S
M97)S('!R969E<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E
M<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\U7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('EO
M=7(@=V5B('5S97)S('!R969E<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P
M;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?
M9&5S8W)I<'1I;VXG(#T^("=796(@=7-E<B`E,2!P<F]P97)T:65S+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E
M8BUU<V5R7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<)W0@:&%V92!A
M;GD@=V5B('5S97)S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R7U]N;VYE+6%V86EL86)L95]?,2<@
M/3X@)T-L:65N="`E,2!D;V5S;EPG="!H879E(&%N>2!W96(@=7-E<G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O
M=V5B+75S97)?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO
M('=E8B!U<V5R(&%C8V]U;G1S(&]N(&1O;6%I;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?
M<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R7U]T:71L92<@/3X@)U=E
M8B!U<V5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97)?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^
M("=#:&%N9V4@<&%S<W=O<F0@9F]R('=E8B!U<V5R(&%C8V]U;G0L(&QI;6ET
M(&1I<VL@<W!A8V4@=7-A9V4@86YD('-E="!U<"!S8W)I<'1S('-U<'!O<G0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E
M<G,O=V5B+75S97)?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R7W5N:VYO=VY?7W1I=&QE)R`]/B`G0V]N9FEG=7)E('=E
M8B!U<V5R(&%C8V]U;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7U]D97-C<FEP=&EO
M;B<@/3X@)T1E;&5T92!W96(@=7-E<B!A8V-O=6YT(&%N9"!C;VYT96YT+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S
M+W=E8BUU<V5R+V1E;&5T95]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&AA<R!B
M965N(')E;6]V960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7U]S:&]R="UT:71L92<@
M/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]?=&ET;&4G(#T^("=296UO
M=F4@=V5B('5S97(@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]D96QE=&5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=$96QE=&4@82!W96(@=7-E<B!A8V-O=6YT(&%N9"!C
M;VYT96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E;6]V92!W96(@=7-E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN
M;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=796(@57-E<B!296UO=F%L)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B
M+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E
M(&$@=V5B('5S97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R
M9%]?-5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@=V5B('5S97(@86-C;W5N="!Y
M;W4@=V%N="!T;R!R96UO=F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@<F5M;W9I;F<@=&AE('=E8B!U<V5R
M(&%C8V]U;G0@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K
M(&9I;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@
M=VEZ87)D+BXG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG
M(#T^("=%9&ET('!R;W!E<G1I97,@;V8@=V5B('5S97(@)3$N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S
M97(O<')O<&5R=&EE<U]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&%C8V]U;G0@
M:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?7W1I=&QE
M)R`]/B`G0V]N9FEG=7)E('=E8B!U<V5R(&%C8V]U;G0@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E
M<B]P<F]P97)T:65S7VYE=RUA9&AO8U]?=VEZ87)D7U\U7VYE=R<@/3X@)TYE
M=R!W96(@=7-E<B!A8V-O=6YT('=I;&P@8F4@8W)E871E9"!I;6UE9&EA=&5L
M>2!A9G1E<B!Y;W4@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T
M:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W('=E8B!U<V5R
M(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^
M("=796(@=7-E<B`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R
M;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!W96(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T
M92!W96(@=7-E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M
M=&ET;&4G(#T^("=796(@=7-E<B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O
M;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!C<F5A=&4@=V5B('5S97(@86-C
M;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E
M8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R
M;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N
M9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN
M9R!A;F0@8VQI8VL@3F5X="`^/B!T;R!P<F]C965D('1O(&-R96%T:6YG('=E
M8B!U<V5R(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,R]P<F]P97)T:65S7W-E;&8M<&AO<W1I;F<G(#T^("=(;W-T:6YG
M(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O;B!Y;W5R(&1O;6%I;BX@4V5T('5P
M('!H>7-I8V%L(&AO<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E
M9"!T;R!C<F5A=&EN9R!W96(@=7-E<B!A8V-O=6YT+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R
M;W!E<G1I97-?;F5W7U]W:7IA<F1?7S5?;F5W)R`]/B`G0VQI8VL@1FEN:7-H
M('1O(&-R96%T92!T:&4@=V5B('5S97(@86-C;W5N="XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P
M<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('!A
M<W-W;W)D(&9O<B!W96(@=7-E<B!A8V-O=6YT+"!L:6UI="!D:7-K('-P86-E
M('5S86=E(&%N9"!S970@=7`@<V-R:7!T<R!S=7!P;W)T+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R
M+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#
M;VYF:6=U<F4@=V5B('5S97(@86-C;W5N="<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0V]N9FEG=7)I;F<@5V5B
M(%5S97(@06-C;W5N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI
M8V@@>6]U('=A;G0@=&\@<F5C;VYF:6=U<F4@=V5B('5S97(@86-C;W5N="XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R
M<R]W96(M=7-E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-5]U;FMN
M;W=N)R`]/B`G4V5L96-T('=E8B!U<V5R(&%C8V]U;G0@>6]U('=A;G0@=&\@
M<F5C;VYF:6=U<F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F1?7S8G(#T^("=7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@
M=V5B('5S97(@86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG
M97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?7V1E
M<V-R:7!T:6]N)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="!F;W(@9&]M
M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)T1I
M<VL@<W!A8V4@=7-A9V4@;&EM:70G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G95]?=&ET;&4G
M(#T^("=$:7-K('-P86-E('5S86=E(&QI;6ET(&9O<B!D;VUA:6X@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C
M92UL:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A
M8V4@=7-A9V4@;&EM:70@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S
M86=E7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L
M:6UI="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD
M:7-K+7-P86-E+6QI;6ET+75S86=E7W-E;&9?7W1I=&QE)R`]/B`G1&ES:R!S
M<&%C92!U<V%G92!L:6UI="!F;W(@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU
M<V%G95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A
M9V4@;&EM:70@9F]R(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W5N:VYO
M=VY?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P
M86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C
M92!U<V%G92!L:6UI="!F;W(@82!D;VUA:6XG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7V1E<V-R:7!T:6]N
M)R`]/B`G1&]M86EN("4Q(&5X<&ER871I;VX@9&%T92`N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W-H;W)T
M+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W1I=&QE)R`]/B`G
M1&]M86EN("4Q(&5X<&ER871I;VX@9&%T92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E;&9?7V1E<V-R:7!T
M:6]N)R`]/B`G66]U<B!D;VUA:6X@97AP:7)A=&EO;B!D871E+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?<V5L
M9E]?=&ET;&4G(#T^("=9;W5R(&1O;6%I;B!E>'!I<F%T:6]N(&1A=&4N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I
M;VY?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$;VUA:6X@97AP:7)A=&EO
M;B!D871E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUE>'!I<F%T:6]N7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G17AP:7)A
M=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+65X<&ER871I;VY?=6YK;F]W;E]?=&ET;&4G(#T^("=$;VUA:6X@97AP
M:7)A=&EO;B!D871E)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUF=6QL+7-T871U<U]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T
M92!S=&%T=7,@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUF=6QL+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^
M("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@
M<W1A='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUF=6QL+7-T871U<U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T-O;7!L971E('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L
M9E]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L
M9E]?=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,@;V8@>6]U<B!D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US
M=&%T=7-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T
M=7,@;V8@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G0V]M<&QE=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M0V]M<&QE=&4@<W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]?9&5S8W)I<'1I;VXG(#T^("=)
M4"!A9&1R97-S(&]F(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]I;F1I8V%T;W(M:7!?7W-H;W)T+71I=&QE)R`]/B`G25`@861D
M<F5S<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUI
M<%]?=&ET;&4G(#T^("=)4"!A9&1R97-S(&]F(&1O;6%I;B`E,2<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)TE0(&%D9')E<W,@;V8@>6]U<B!D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6EP7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G25`@861D<F5S<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUI<%]S96QF7U]T:71L92<@/3X@)TE0(&%D
M9')E<W,@;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M:7!?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=)
M4"!A9&1R97-S(&]F(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUI<%]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@
M)TE0(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I
M8V%T;W(M:7!?=6YK;F]W;E]?=&ET;&4G(#T^("=)4"!A9&1R97-S(&]F(&$@
M9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@
M)TUA:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S
M+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUA:6QB;WAE<R!L:6UI
M="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7U]T:71L92<@/3X@)TUA:6QB
M;WAE<R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M
M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@
M=7-A9V4@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL
M8F]X97,M;&EM:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=-86EL8F]X97,@
M;&EM:70@=7-A9V4@9F]R('EO=7(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A
M9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@
M=7-A9V4@9F]R(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W5N:VYO
M=VY?7W-H;W)T+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL
M8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86EL8F]X
M97,@;&EM:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU
M<V%G95]?9&5S8W)I<'1I;VXG(#T^("=3=6)D;VUA:6YS(&QI;6ET('5S86=E
M(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R="UT
M:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M;6%X+7-U8F1O;6%I;G,M;&EM
M:70M=7-A9V5?7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F
M;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD
M:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@>6]U<B!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7W-H;W)T+71I=&QE
M)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU
M<V%G95]S96QF7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4@
M9F]R('EO=7(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@
M82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL
M:6UI="UU<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM
M:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUN86UE7U]D97-C<FEP=&EO;B<@/3X@)TYA;64@
M;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUN86UE7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?7W1I
M=&QE)R`]/B`G3F%M92!O9B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M;F%M95]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)TYA;64@;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?<V5L9E]?<VAO<G0M=&ET;&4G(#T^
M("=$;VUA:6X@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUN86UE7W-E;&9?7W1I=&QE)R`]/B`G3F%M92!O9B!Y;W5R(&1O
M;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUN
M86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G3F%M92!O9B!A(&1O;6%I
M;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M;F%M
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?=6YK;F]W
M;E]?=&ET;&4G(#T^("=.86UE(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T95]?9&5S8W)I<'1I;VXG
M(#T^("=(96%L=&@@<W1A=&4@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T95]?<VAO<G0M=&ET;&4G
M(#T^("=(96%L=&@@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M<W1A=&5?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUS=&%T95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TAE86QT:"!S=&%T
M92!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M<W1A=&5?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=(96%L
M=&@@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?<V5L9E]?=&ET;&4G(#T^("=(96%L=&@@<W1A=&4@;V8@>6]U
M<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=(96%L=&@@<W1A
M=&4@;V8@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+7-T871E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G2&5A
M;'1H('-T871E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+7-T871E7W5N:VYO=VY?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F
M(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUS=&%T=7,M9&5T86EL<U]?9&5S8W)I<'1I;VXG(#T^("=$971A:6QE
M9"!S=&%T=7,@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?<VAO<G0M=&ET;&4G
M(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?7W1I=&QE)R`]/B`G1&5T
M86EL960@<W1A='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)T1E=&%I;&5D('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S
M+61E=&%I;'-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T
M=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A
M='5S+61E=&%I;'-?<V5L9E]?=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,@
M;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I
M;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=$971A:6QE9"!S=&%T=7,@;V8@82!D;VUA:6XN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W5N
M:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G1&5T86EL960@<W1A='5S)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A
M:6QS7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&5T86EL960@<W1A='5S(&]F(&$@
M9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUS=&%T=7-?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&1O;6%I;B`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A
M='5S7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7-?7W1I=&QE)R`]/B`G4W1A
M='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VEN9&EC871O<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=3=&%T
M=7,@;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+7-T871U<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T
M871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS
M=&%T=7-?<V5L9E]?=&ET;&4G(#T^("=3=&%T=7,@;V8@>6]U<B!D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&$@9&]M86EN
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T
M=7-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G4W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUT<F%F9FEC+6QI;6ET+75S86=E
M7U]D97-C<FEP=&EO;B<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M=')A9F9I8RUL:6UI="UU<V%G95]?<VAO<G0M=&ET;&4G(#T^("=4<F%F
M9FEC(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?7W1I=&QE)R`]/B`G5')A
M9F9I8R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O
M<B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I
M;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]S:&]R="UT:71L
M92<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF
M7U]T:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R('EO=7(@9&]M
M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+71R
M869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=4
M<F%F9FEC(&QI;6ET('5S86=E(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A
M9V4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A
M9F9I8RUL:6UI="UU<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)U1R869F:6,@
M;&EM:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W(&]R(&5D
M:70@<F5S;W5R8V4@=7-A9V4@;&EM:71S(&9O<B!D;VUA:6X@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7U]D;VYE)R`]/B`G3&EM
M:71S(&]F(&1O;6%I;B`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]L:6UI='-?7W-H;W)T+71I=&QE)R`]/B`G
M3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7U]T
M:71L92<@/3X@)U9I97<O161I="!D;VUA:6X@)3$@;&EM:71S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7W-E;&9?7V1E<V-R:7!T:6]N
M)R`]/B`G5FEE=R!M>2!L:6UI=',N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;&EM:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]L:6UI='-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=,
M:6UI=',G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]L:6UI='-?<V5L
M9E]?=&ET;&4G(#T^("=6:65W(&UY(&QI;6ET<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@
M)U9I97<@;W(@961I="!R97-O=7)C92!U<V%G92!L:6UI=',@9F]R(&$@9&]M
M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN
M;W=N7U]S:&]R="UT:71L92<@/3X@)TQI;6ET<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O
M161I="!D;VUA:6X@;&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O
M161I=&EN9R!$;VUA:6X@3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN('=H;W-E(&QI;6ET<R!Y;W4@=V%N="!T;R!V:65W
M(&]R(&5D:70N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S
M7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W:71H(&5D:71I
M;F<@=&AE(&1O;6%I;B!L:6UI=',L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C
M:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9%]?,U]S96QF)R`]
M/B`G5VAE;B!D;VYE('=I=&@@=FEE=VEN9R!Y;W5R(&QI;6ET<RP@8VQI8VL@
M1FEN:7-H+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7U]D
M97-C<FEP=&EO;B<@/3X@)TUA;F%G92!M86EL('-Y<W1E;2!O9B!D;VUA:6X@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]?9&ES86)L
M960M=V%R;FEN9R<@/3X@)TUA:6P@<V5R=FEC92!O;B!D;VUA:6X@)3$@:7,@
M9&ES86)L960@+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6Q?
M7W-H;W)T+71I=&QE)R`]/B`G36%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6Q?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@;VX@9&]M86EN
M("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]S96QF7U]D
M97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!M86EL('-Y<W1E;2!O;B!Y;W5R
M(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W-E
M;&9?7V1I<V%B;&5D+7=A<FYI;F<G(#T^("=-86EL('-E<G9I8V4@;VX@>6]U
M<B!D;VUA:6X@:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;%]S96QF7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W-E;&9?7W1I=&QE)R`]/B`G
M36%N86=E(&UA:6PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES
M=&5M(&]N(&$@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;%]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M36%N86=E(&UA:6P@;VX@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;65?7V1E<V-R:7!T:6]N)R`]/B`G36%N86=E
M(&UA:6P@86-C;W5N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<
M)W0@:&%V92!A;GD@;6%I;&YA;65S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;65?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G
M0VQI96YT("4Q(&1O97-N7"=T(&-H879E(&%N>2!M86EL;F%M97,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]?;F]N92UA
M=F%I;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@;6%I;&YA;65S(&]N(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE7U]S:&]R="UT:71L92<@/3X@)R4Q)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]?=&ET;&4G(#T^("=-86EL;F%M
M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;65?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@>6]U<B!M86EL(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M95]S96QF7U]Q=6EC:RUS96%R8V@G(#T^("=->2!M86EL;F%M97,G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?
M7W-H;W)T+71I=&QE)R`]/B`G37D@;6%I;&YA;64G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?7W1I=&QE)R`]/B`G
M37D@;6%I;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE7W5N:VYO=VY?7W%U:6-K+7-E87)C:"<@/3X@)TUA:6QN86UE
M<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%N=&EV:7)U<R]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I
M9W5R92!A;G1I=FER=7,@<V5R=FEC92!F;W(@;6%I;"!A8V-O=6YT("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT
M:79I<G5S+W!R;W!E<G1I97-?7V1O;F4G(#T^("=!;G1I=FER=7,@<V5T=&EN
M9W,@9F]R(&UA:6QN86UE("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S
M+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER
M=7,O<')O<&5R=&EE<U]?=&ET;&4G(#T^("=3970@=7`@86YT:79I<G5S(&9O
M<B!M86EL;F%M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&5S8W)I
M<'1I;VXG(#T^("=#;VYF:6=U<F4@86YT:79I<G5S('-E<G9I8V4@9F]R('EO
M=7(@;6%I;"!A8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&]N
M92<@/3X@)T%N=&EV:7)U<R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H
M879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]S
M96QF7U]T:71L92<@/3X@)U-E="!U<"!A;G1I=FER=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P
M97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&%N
M=&EV:7)U<R!S97)V:6-E(&9O<B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M;G1I=FER=7,O<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U-E="!U
M<"!A;G1I=FER=7,@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=!;G1I=FER=7,@0V]N9FEG=7)A
M=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O86YT:79I<G5S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@9F]R('=H:6-H(&UA:6P@
M86-C;W5N="!Y;W4@=V%N="!T;R!S970@=7`@86YT:79I<G5S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P
M(&%N=&EV:7)U<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9%]?-B<@/3X@)U-E;&5C="!W:&5T:&5R(&EN8V]M:6YG(&]R(&]U=&-O;6EN
M9R!M86EL+"!O<B!B;W1H('-H;W5L9"!B92!C:&5C:V5D(&9O<B!V:7)U<V5S
M+B!7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!A;G1I=FER=7,@9F]R('1H
M92!M86EL;F%M92P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD
M(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?
M7W=I>F%R9%]?-E]S96QF)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I
M;F<@86YT:79I<G5S(&9O<B!Y;W5R(&UA:6P@86-C;W5N="P@8VQI8VL@=&\@
M87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@875T;W)E<W!O;F1E<G,@
M;VX@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<U]?9&ES86)L960M=V%R;FEN
M9R<@/3X@)U1H92!A=71O<F5S<&]N9&5R<R!S97)V:6-E(&]N(&UA:6QN86UE
M("4Q(&ES(&1I<V%B;&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G-?7W-H;W)T+71I=&QE)R`]
M/B`G)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S7U]T:71L92<@/3X@)T%U=&]R97-P;VYD97)S
M(&]N(&UA:6QN86UE("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<U]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)TUA;F%G92!Y;W5R(&%U=&]R97-P;VYD97)S+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G-?<V5L9E]?=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R
M<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE
M)R`]/B`G66]U(&1O;EPG="!H879E(&%N>2!A=71O<F5S<&]N9&5R<RXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE7U\Q)R`]
M/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&%U=&]R97-P;VYD97)S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B;&5?
M7S(G(#T^("=4:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@;VX@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B
M;&5?7S0G(#T^("=4:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@8V]N9FEG
M=7)E9"!O;B!M86EL;F%M92`E,2XG+`H*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+V%T=&%C:"UD96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&%T
M=&%C:&UE;G1S(&9R;VT@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?9&]N92<@/3X@)T%T=&%C
M:&UE;G1S(&AA=F4@8F5E;B!R96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E
M<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?
M<VAO<G0M=&ET;&4G(#T^("=296UO=F4@871T86-H;65N=',G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?=&ET;&4G(#T^("=2
M96UO=F4@871T86-H;65N=',@9G)O;2!A=71O<F5S<&]N9&5R("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S
M<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]D97-C
M<FEP=&EO;B<@/3X@)T-L:6-K('1O(')E;6]V92!A='1A8VAM96YT<R!F<F]M
M(&YE=R!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E
M<B]A='1A8V@M9&5L971E7VYE=U]?9&]N92<@/3X@)T%T=&%C:&UE;G1S(&AA
M=F4@8F5E;B!R96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E<BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]N97=?7W-H;W)T
M+71I=&QE)R`]/B`G4F5M;W9E(&%T=&%C:&UE;G1S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A
M=71O<F5S<&]N9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]T:71L92<@/3X@)U)E
M;6]V92!A='1A8VAM96YT<R!F<F]M(&$@;F5W(&%U=&]R97-P;VYD97(G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!A;B!A=71O<F5S<&]N9&5R(&%T
M=&%C:&UE;G1S("XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M+61E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92!A='1A
M8VAM96YT<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]A='1A8V@M9&5L
M971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&%N(&%U=&]R97-P;VYD
M97(@871T86-H;65N=',G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]?9&5S8W)I<'1I;VXG(#T^("=!='1A8V@@9FEL97,@=&\@875T;W)E
M<W!O;F1E<B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M7U]D;VYE)R`]/B`G071T86-H;65N=',@:&%V92!B965N(&%D9&5D('1O(&%U
M=&]R97-P;VYD97(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]?<VAO<G0M=&ET;&4G(#T^("=!='1A8V@@9FEL97,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O871T86-H7U]T:71L92<@/3X@)T%T=&%C:"!F
M:6QE<R!T;R!A=71O<F5S<&]N9&5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+V%T=&%C:%]N97=?7V1E<V-R:7!T:6]N)R`]/B`G061D(&%T=&%C
M:&UE;G0@9FEL97,@9F]R(&YE=R!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]A='1A8VA?;F5W7U]D;VYE)R`]/B`G071T86-H
M;65N=',@:&%V92!B965N(&%D9&5D('1O(&%U=&]R97-P;VYD97(@)3$N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:%]N97=?7W-H;W)T+71I
M=&QE)R`]/B`G071T86-H(&9I;&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+V%T=&%C:%]N97=?7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&YE
M=R!A=71O<F5S<&]N9&5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T%D9"!A='1A8VAM96YT
M(&9I;&5S(&9O<B!A;B!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]A='1A8VA?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=!
M='1A8V@@9FEL97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&%U=&]R97-P
M;VYD97(G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?9&5S
M8W)I<'1I;VXG(#T^("=296UO=F4@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7U]D;VYE)R`]/B`G075T;W)E
M<W!O;F1E<B`E,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]D96QE=&5?7W-H;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?=&ET;&4G(#T^("=2
M96UO=F4@875T;W)E<W!O;F1E<B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O
M;F1E<B]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$96QE=&4@
M875T;W)E<W!O;F1E<B!C;VYF:6=U<F%T:6]N(&9O<B!A(&UA:6P@86-C;W5N
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?
M7W-H;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!A=71O
M<F5S<&]N9&5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=!=71O<F5S<&]N9&5R(%)E;6]V
M86PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&]W;FEN
M9R!T:&4@9&]M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E(&%U
M=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T
M95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O
M;6%I;B!F<F]M('=H:6-H('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N
M9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W
M;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!F
M<F]M('=H:6-H('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N9&5R+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\V7W5N:VYO=VXG(#T^("=0;&5A<V4@<V5L96-T('=H:6-H(&%U=&]R
M97-P;VYD97(@>6]U('=A;G0@=&\@<F5M;W9E+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\W)R`]/B`G0V]N
M9FER;2!R96UO=FEN9R!T:&4@875T;W)E<W!O;F1E<B!B>2!S96QE8W1I;F<@
M=&AE(&-H96-K(&)O>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@
M<F5M;W9E(&ET(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O
M;F9I9W5R92!A=71O<F5S<&]N9&5R("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E
M<W!O;F1E<B]P<F]P97)T:65S7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E
M,2!C;VYF:6=U<F%T:6]N(&AA<R!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G
M4')E9F5R96YC97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R
M=&EE<U]?=&ET;&4G(#T^("=!=71O<F5S<&]N9&5R("4Q('!R969E<F5N8V5S
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]D
M97-C<FEP=&EO;B<@/3X@)T-R96%T92!N97<@875T;W)E<W!O;F1E<B!F;W(@
M82!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R
M;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E,2!H87,@
M8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P
M97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G
M0W)E871E(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9"UT:71L92<@/3X@)T%U=&]R97-P
M;VYD97(@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O
M<&5R=&EE<U]N97=?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@
M9&]M86EN(&9O<B!W:&EC:"!M86EL(&%C8V]U;G0@>6]U('=A;G0@=&\@8W)E
M871E(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U!L96%S
M92!S96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@8W)E
M871E(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S8O871T86-H)R`]/B`G4V5L96-T
M(&%T=&%C:&UE;G1S(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@961I=&EN
M9R!T:&4@875T;W)E<W!O;F1E<B!P<F]P97)T:65S+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\V+V%T=&%C
M:"<@/3X@)U-E;&5C="!A='1A8VAM96YT<R!A;F0@8VQI8VL@3TL@=&\@<F5T
M=7)N('1O(&5D:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R=&EE<RXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U
M=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?-B]A='1A8V@M9&5L971E)R`]/B`G0V]N9FER;2!A='1A8VAM96YT
M(')E;6]V86P@86YD(&-L:6-K($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H
M92!A=71O<F5S<&]N9&5R('!R;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O
M<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S8O9FEL97,O9&5L
M971E)R`]/B`G0V]N9FER;2!F:6QE<R!R96UO=F%L(&%N9"!C;&EC:R!/2R!T
M;R!R971U<FX@=&\@;6%N86=I;F<@=&AE(&%U=&]R97-P;VYD97(@871T86-H
M;65N=',N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?
M;F5W7U]W:7IA<F1?7S9?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T
M92!T:&4@875T;W)E<W!O;F1E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-R<@/3X@)U=H96X@9&]N92!W
M:71H(&-H86YG:6YG('1H92!A=71O<F5S<&]N9&5R('!R;W!E<G1I97,L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA
M<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@875T;W)E<W!O;F1E<B!S
M971T:6YG<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE
M<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E8V]N9FEG=7)E(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=!=71O<F5S<&]N9&5R(%)E8V]N9FEG=7)I;F<G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?
M7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI8V@@;6%I
M;"!A8V-O=6YT('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@
M9F]R('=H:6-H('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-B]A='1A8V@G(#T^("=396QE8W0@871T86-H;65N=',@
M86YD(&-L:6-K($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H92!A=71O<F5S
M<&]N9&5R('!R;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V+V%T=&%C:"UD96QE=&4G
M(#T^("=#;VYF:7)M(&%T=&%C:&UE;G0@<F5M;W9A;"!A;F0@8VQI8VL@3TL@
M=&\@<F5T=7)N('1O(&5D:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R
M=&EE<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F1?7S8O9FEL97,O9&5L971E)R`]/B`G0V]N9FER;2!F
M:6QE<R!R96UO=F%L(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@;6%N86=I
M;F<@=&AE(&%U=&]R97-P;VYD97(@871T86-H;65N=',N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V
M7W5N:VYO=VXG(#T^("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@
M=V%N('1O(&UA;F%G92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S<G(#T^("=7:&5N(&1O;F4@=VET
M:"!C:&%N9VEN9R!T:&4@875T;W)E<W!O;F1E<B!P<F]P97)T:65S+"!C;&EC
M:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7V1I<V%B;&5?
M7V1E<V-R:7!T:6]N)R`]/B`G1&ES86)L92!A=71O<F5S<&]N9&5R("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?9&ES86)L95]?9&]N
M92<@/3X@)T%U=&]R97-P;VYD97(@)3$@:&%S(&)E96X@9&ES86)L960N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]D:7-A8FQE7U]S:&]R
M="UT:71L92<@/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O=&]G9VQE7V1I<V%B;&5?7W1I=&QE)R`]/B`G1&ES86)L92!A=71O<F5S
M<&]N9&5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E
M;F%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD97(@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?
M7V1O;F4G(#T^("=!=71O<F5S<&]N9&5R("4Q(&AA<R!B965N(&5N86)L960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?7W-H
M;W)T+71I=&QE)R`]/B`G16YA8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE(&%U=&]R97-P
M;VYD97(@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7W5N
M:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&]R(&1I<V%B;&4@875T
M;W)E<W!O;F1E<B!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U
M=&]R97-P;VYD97(O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G
M9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G16YA8FQE+T1I<V%B;&4@875T;W)E
M<W!O;F1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA8FQI;F<O1&ES86)L:6YG($%U
M=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE
M7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI
M96YT(&]W;FEN9R!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(&5N
M86)L92!O<B!D:7-A8FQE(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A
M=71O<F5S<&]N9&5R+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W
M;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E
M;F%B;&4@;W(@9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO
M=VXG(#T^("=396QE8W0@82!M86EL;F%M92!O;B!W:&EC:"!Y;W4@=V%N="!T
M;R!E;F%B;&4@;W(@9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\V7W5N
M:VYO=VXG(#T^("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@=V%N
M="!T;R!E;F%B;&4@;W(@9&ES86)L92XG+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?
M9&ES86)L95]?9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD
M:6YG('-E<G9I8V4@;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L
M95]?9&]N92<@/3X@)T%U=&]R97-P;VYD:6YG('-E<G9I8V4@:&%S(&)E96X@
M9&ES86)L960@;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?
M9&ES86)L95]?=&ET;&4G(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E
M<G9I8V4@;VX@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7V1E<V-R
M:7!T:6]N)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@;VX@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?96YA8FQE7U]D;VYE)R`]/B`G075T
M;W)E<W!O;F1I;F<@<V5R=FEC92!H87,@8F5E;B!E;F%B;&5D(&]N("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O=&]G9VQE7V5N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%
M;F%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G
M16YA8FQE(&%U=&]R97-P;VYD97)S('-E<G9I8V4@;VX@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+W1O9V=L95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O
M<B!D:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@9F]R(&$@;6%I;"!A
M8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I
M=&QE)R`]/B`G16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U
M;FMN;W=N7U]T:71L92<@/3X@)T5N86)L92]$:7-A8FQE(&%U=&]R97-P;VYD
M97)S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE
M)R`]/B`G16YA8FQI;F<O1&ES86)L:6YG($%U=&]R97-P;VYD:6YG(%-E<G9I
M8V4@;VX@36%I;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]W
M:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-L:65N="!O=VYI;F<@
M=&AE(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E;F%B;&4@;W(@9&ES
M86)L92!A=71O<F5S<&]N9&EN9R!S97)V:6-E(&9O<B!M86EL;F%M92XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@
M/3X@)U-E;&5C="!A(&1O;6%I;B!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W
M86YT('1O(&5N86)L92!O<B!D:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I
M8V4@9F]R(&UA:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?
M7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@;VX@
M=VAI8V@@>6]U('=A;G0@=&\@96YA8FQE(&]R(&1I<V%B;&4@875T;W)E<W!O
M;F1I;F<@<V5R=FEC92XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E
M(&UA:6QN86UE("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O9&5L971E7U]D;VYE)R`]/B`G36%I;&YA;64@)3$@:&%S
M(&)E96X@<F5M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E
M;&5T95]?=&ET;&4G(#T^("=296UO=F4@;6%I;&YA;64@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E;&5T95]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!A(&UA:6P@86-C;W5N="XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E
M;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N
M:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&UA:6QN86UE)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W
M;E]?=VEZ87)D+71I=&QE)R`]/B`G36%I;&YA;64@4F5M;W9A;"<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M('1O(')E;6]V92!A(&UA:6QN86UE(&9R;VTN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!T;R!R96UO
M=F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO
M=FEN9R!T:&4@;6%I;&YA;64@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@
M86YD(&-L:6-K(&9I;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@
M97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G
M0V]N9FEG=7)E(&UA:6P@9F]R=V%R9&EN9R!O;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?7V1O
M;F4G(#T^("=-86EL(&9O<G=A<F1I;F<@<V5T=&EN9W,@9F]R(&UA:6QN86UE
M("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=&;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]F;W)W87)D:6YG7U]T:71L92<@/3X@)U-E="!U<"!F
M;W)W87)D:6YG(&9O<B!M86EL;F%M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)T-O;F9I9W5R92`@;6%I;"!F;W)W87)D:6YG(&9O<B!Y
M;W5R(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?<V5L9E]?9&]N92<@/3X@)TUA
M:6P@9F]R=V%R9&EN9R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H879E
M(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?<V5L9E]?<VAO<G0M=&ET;&4G(#T^
M("=&;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]F;W)W87)D:6YG7W-E;&9?7W1I=&QE)R`]/B`G4V5T('5P
M(&9O<G=A<F1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^
M("=#;VYF:6=U<F4@9F]R=V%R9&EN9R!S97)V:6-E(&]N(&$@;6%I;"!A8V-O
M=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T9O<G=A
M<F1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?=&ET;&4G(#T^("=3970@=7`@;6%I
M;"!F;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]F;W)W87)D:6YG7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)TUA:6P@1F]R=V%R9&EN9R!3971U<"<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]W
M:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI
M8V@@;6%I;&YA;64@>6]U('=A;G0@=&\@<V5T('5P(&UA:6P@9F]R=V%R9&EN
M9RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V9O<G=A<F1I;F=?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P
M(&UA:6P@9F]R=V%R9&EN9RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?=VEZ87)D7U\U
M)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!F
M;W(@=&AE(&UA:6QN86UE+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8V]N9FEG
M=7)A=&EO;B!A;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N
M7U]W:7IA<F1?7S5?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R
M:6YG(&UA:6P@9F]R=V%R9&EN9R!F;W(@>6]U<B!M86EL;F%M92P@8VQI8VL@
M1FEN:7-H('1O(&%P<&QY(&-O;F9I9W5R871I;VX@86YD(&5X:70@=&AE('=I
M>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]M86EL8F]X+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N
M9FEG=7)E(&UA:6QB;W@@;VX@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=-86EL8F]X("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E
M96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^
M("=#;VYF:6=U<F4@;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7U]T:71L92<@
M/3X@)TUA:6QB;W@@)3$@<')O<&5R=&EE<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W-E
M;&9?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E('EO=7(@;6%I;&)O>"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA
M:6QB;W@O<')O<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G66]U<B!M86EL8F]X
M(&-O;F9I9W5R871I;VX@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R
M=&EE<U]S96QF7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M86EL8F]X
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M
M86EL8F]X+W!R;W!E<G1I97-?<V5L9E]?=&ET;&4G(#T^("=->2!M86EL8F]X
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M
M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#
M;VYF:6=U<F4@;6%I;&)O>"!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O
M<&5R=&EE<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M
M86EL8F]X)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#
M;VYF:6=U<F4@;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W5N:VYO=VY?7W=I
M>F%R9"UT:71L92<@/3X@)TUA:6QB;W@@0V]N9FEG=7)A=&EO;B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@9&]M86EN('1O(&-O;F9I9W5R92!M86EL8F]X(&]N+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@;6%I;&YA;64@=&\@8V]N9FEG=7)E(&UA:6QB;W@@;VXN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V)R`]/B`G5VAE;B!D;VYE
M('=I=&@@8V]N9FEG=7)I;F<@;6%I;&)O>"!O;B!T:&4@;6%I;&YA;64L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA
M<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V7W-E;&8G
M(#T^("=7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!Y;W5R(&UA:6QB;W@L
M(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('!R;W!E
M<G1I97,@;V8@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7U]D;VYE)R`]/B`G4')O
M<&5R=&EE<R!O9B!M86EL;F%M92`E,2!H879E(&)E96X@=7!D871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E
M<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O
M<&5R=&EE<U]?=&ET;&4G(#T^("=-86EL;F%M92`E,2!P<F]P97)T:65S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7VYE=RUA9&AO8U]?=VEZ87)D7U\T7VYE=R<@/3X@)TYN97<@;6%I
M;&YA;64@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C
M;&EC:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N97<M8F5F;W)E+6%N=&EV:7)U<U]?
M=VEZ87)D7U\T7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E871E('1H
M92!M86EL;F%M92!A;F0@<')O8V5E9"!T;R!C;VYF:6=U<FEN9R!A;G1I+79I
M<G5S('-E='1I;F=S+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C<F5A=&4@=&AE
M(&UA:6QN86UE(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=RUB
M969O<F4M<W!A;2UF:6QT97)?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R
M=&EE<R<@/3X@)U-P96-I9GD@<&%R86UE=&5R<R!O9B!$<BY796(@86YT:79I
M<G5S(&-O;F9I9W5R871I;VXN($-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T
M;R!A;G1I+7-P86T@9FEL=&5R(&-O;F9I9W5R871I;VXN($-L:6-K($9I;FES
M:"!T;R!S879E($1R+E=E8B!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]P<F]P97)T:65S7VYE=RUB969O<F4M<W!A;2UF:6QT97)?7W=I>F%R
M9%]?-%]N97<G(#T^("=#;&EC:R!.97AT(#X^('1O(&-R96%T92!T:&4@;6%I
M;&YA;64@86YD('!R;V-E960@=&\@8V]N9FEG=7)I;F<@86YT:2US<&%M(&9I
M;'1E<B!F;W(@=&AE(&UA:6QN86UE+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C
M<F5A=&4@=&AE(&UA:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N
M)R`]/B`G0W)E871E(&YE=R!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=U]?
M9&]N92<@/3X@)TUA:6QN86UE("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T
M:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@;6%I;&YA;64G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E
M<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!M86EL;F%M92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE
M<U]N97=?7W=I>F%R9"UT:71L92<@/3X@)T-R96%T:6YG($UA:6QN86UE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@8W)E871E(&UA:6QN86UE+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O
M<&5R=&EE<U]N97=?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R=&EE<R<@
M/3X@)T-L:6-K($9I;FES:"!T;R!S879E($1R+E=E8B!C;VYF:6=U<F%T:6]N
M(&%N9"!F:6YI<V@@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?
M7S0O<W!A;2UF:6QT97(O<')O<&5R=&EE<R<@/3X@)T-O;F9I9W5R92!T:&4@
M86YT:2US<&%M(&9I;'1E<B!A;F0@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H
M86YG97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S1?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@;6%I
M;&YA;64@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("=%9&ET('!R;W!E<G1I97,@;V8@>6]U<B!M86EL(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]P<F]P97)T:65S7W-E;&9?7V1O;F4G(#T^("=0<F]P97)T:65S(&]F
M('EO=7(@;6%I;&YA;64@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R
M=&EE<U]S96QF7U]T:71L92<@/3X@)T5D:70@;7D@86-C;W5N="<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE
M<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T-H86YG92!P87-S=V]R9"!A
M;F0@:6YT97)F86-E(&%N9"!S97-S:6]N('!R969E<F5N8V5S(&9O<B!A(&UA
M:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=-86EL;F%M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE
M)R`]/B`G161I="!M86EL;F%M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9"UT:71L92<@/3X@)T5D:71I;F<@36%I;&YA;64@4')O<&5R
M=&EE<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U
M<F4@;6%I;&YA;64N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN
M;W=N)R`]/B`G4V5L96-T('=H:6-H(&UA:6QN86UE('EO=2!W86YT('1O(&-O
M;F9I9W5R92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G5VAE
M;B!D;VYE('=I=&@@8VAA;F=I;F<@;6%I;&YA;64@<')O<&5R=&EE<RP@8VQI
M8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD(&5X:70@=&AE('=I>F%R
M9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U7W-E;&8G(#T^("=7:&5N
M(&1O;F4@=VET:"!C:&%N9VEN9R!M86EL;F%M92!P<F]P97)T:65S+"!C;&EC
M:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N
M9FEG=7)E('-P86T@9FEL=&5R(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R
M+W!R;W!E<G1I97-?7V1O;F4G(#T^("=3<&%M(&9I;'1E<B!S971T:6YG<R!F
M;W(@;6%I;&YA;64@)3$@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P
M<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)U-P86T@9FEL=&5R)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I
M;'1E<B]P<F]P97)T:65S7U]T:71L92<@/3X@)T-O;F9I9W5R92!S<&%M(&9I
M;'1E<B!F;W(@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?96YA
M8FQE7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!A;F0@8V]N9FEG=7)E('-P
M86T@9FEL=&5R(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I
M97-?96YA8FQE7U]D;VYE)R`]/B`G4W!A;2!F:6QT97(@9F]R(&UA:6QN86UE
M("4Q(&AA<R!B965N(&5N86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7V5N
M86)L95]?<VAO<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O
M<')O<&5R=&EE<U]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE+T-O;F9I9W5R
M92!S<&%M(&9I;'1E<B!F;W(@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E
M<G1I97-?<V5L9BUE;F%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%N
M9"!C;VYF:6=U<F4@9FEL=&5R(&9O<B!Y;W5R(&UA:6P@86-C;W5N="XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM
M9FEL=&5R+W!R;W!E<G1I97-?<V5L9BUE;F%B;&5?7V1O;F4G(#T^("=3<&%M
M(&9I;'1E<B!F;W(@>6]U<B!M86EL;F%M92!H87,@8F5E;B!E;F%B;&5D+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A
M;2UF:6QT97(O<')O<&5R=&EE<U]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G
M(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF+65N
M86)L95]?=&ET;&4G(#T^("=%;F%B;&4@86YD(&-O;F9I9W5R92!S<&%M(&9I
M;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<B!F;W(@>6]U<B!M86EL(&%C8V]U
M;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W-E;&9?7V1O;F4G(#T^("=3<&%M
M(&9I;'1E<B!S971T:6YG<R!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R
M+W!R;W!E<G1I97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF7U]T:71L92<@/3X@)T-O;F9I
M9W5R92!S<&%M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<FEN9R!S
M971T:6YG<R!F;W(@82!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4W!A;2!F:6QT97(G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM
M9FEL=&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U
M<F4@<W!A;2!F:6QT97(@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U-P86T@9FEL=&5R(&-O
M;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@
M;6%I;&YA;64@>6]U('=A;G0@=&\@8V]N9FEG=7)E('-P86T@9FEL=&5R:6YG
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK
M;F]W;B<@/3X@)U-E;&5C="!O;B!W:&EC:"!M86EL;F%M92!Y;W4@=V%N="!T
M;R!C;VYF:6=U<F4@<W!A;2!F:6QT97)I;F<N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)U=H96X@9&]N92!W:71H(&-O
M;F9I9W5R:6YG('-P86T@9FEL=&5R(&9O<B!T:&4@;6%I;&YA;64L(&-L:6-K
M($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S
M<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-E]E;F%B
M;&4G(#T^("=7:&5N('EO=2!C;&EC:R!&:6YI<V@L('-P86T@9FEL=&5R(&9O
M<B!T:&4@;6%I;&YA;64@=VEL;"!B92!E;F%B;&5D+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S9?<V5L9B<@/3X@)U=H96X@9&]N
M92!W:71H(&-O;F9I9W5R:6YG('-P86T@9FEL=&5R(&9O<B!Y;W5R(&UA:6QN
M86UE+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-E]S96QF+65N86)L92<@/3X@)U=H96X@>6]U(&-L:6-K
M($9I;FES:"P@<W!A;2!F:6QT97(@9F]R('EO=7(@;6%I;&YA;64@=VEL;"!B
M92!E;F%B;&5D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@
M<WES=&5M(&]N(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+W!R;W!E<G1I97-?7V1O;F4G(#T^("=-86EL('-Y<W1E;2!O
M;B!D;VUA:6X@)3$@:&%S(&)E96X@8V]N9FEG=7)E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE
M)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]P<F]P97)T:65S7U]T:71L92<@/3X@)TUA;F%G
M92!M86EL(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-O
M;F9I9W5R92!M86EL('-Y<W1E;2!O;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?<V5L9E]?9&]N
M92<@/3X@)TUA:6P@<WES=&5M(&]N('EO=7(@9&]M86EN(&AA<R!B965N(&-O
M;F9I9W5R960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&UA
M:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G36%N86=E(&UA:6PG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@;6%I;"!S>7-T96T@;VX@
M82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E
M(&UA:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@
M;VX@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUA:6P@<WES
M=&5M(&-O;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG
M(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@8V]N
M9FEG=7)E(&UA:6P@<WES=&5M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7
M:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L
M:6-K($9I;FES:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\T7W-E;&8G(#T^("=7:&5N
M(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L:6-K
M($9I;FES:"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T
M;V=G;&5?9&ES86)L95]?9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&UA:6P@
M<V5R=FEC97,@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO=&]G9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=-86EL('-E
M<G9I8V5S(&]N(&1O;6%I;B`E,2!H879E(&)E96X@9&ES86)L960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES86)L95]?=&ET;&4G(#T^("=$:7-A
M8FQE(&UA:6P@;VX@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T5N
M86)L92!M86EL('-E<G9I8V5S(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]D;VYE)R`]
M/B`G36%I;"!S97)V:6-E<R!O;B!D;VUA:6X@)3$@:&%V92!B965N(&5N86)L
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?
M96YA8FQE7U]S:&]R="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7V5N86)L95]?=&ET;&4G(#T^
M("=%;F%B;&4@;6%I;"!O;B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+W1O9V=L95]S96QF+61I<V%B;&5?7V1E<V-R:7!T
M:6]N)R`]/B`G0VQI8VL@=&\@9&ES86)L92!M86EL('-E<G9I8V5S(&]N('EO
M=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M=&]G9VQE7W-E;&8M9&ES86)L95]?9&]N92<@/3X@)TUA:6P@<V5R=FEC97,@
M;VX@>6]U<B!D;VUA:6X@:&%V92!B965N(&1I<V%B;&5D+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]T;V=G;&5?<V5L9BUD:7-A8FQE7U]T:71L92<@/3X@
M)T1I<V%B;&4@;6%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO=&]G9VQE7W-E;&8M96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T-L:6-K
M('1O(&5N86)L92!M86EL('-E<G9I8V5S(&]N('EO=7(@9&]M86EN+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M96YA
M8FQE7U]D;VYE)R`]/B`G36%I;"!S97)V:6-E<R!O;B!Y;W5R(&1O;6%I;B!H
M879E(&)E96X@96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+W1O9V=L95]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%
M;F%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W1O9V=L
M95]S96QF+65N86)L95]?=&ET;&4G(#T^("=%;F%B;&4@;6%I;"<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G0VQI8VL@=&\@96YA8FQE(&]R(&1I<V%B;&4@;6%I;"!S
M97)V:6-E<R!O;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+W1O9V=L95]S96QF7U]S:&]R="UT:71L92<@/3X@)T5N
M86)L92]D:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]T;V=G;&5?<V5L9E]?=&ET;&4G(#T^("=%;F%B;&4O1&ES86)L92!M86EL
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=%;F%B;&4@;W(@9&ES86)L92!M86EL
M('-E<G9I8V5S(&]N(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+W1O9V=L95]U;FMN;W=N7U]T:71L92<@/3X@)T5N86)L92]$:7-A8FQE
M(&UA:6P@;VX@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA8FQI
M;F<O1&ES86)L:6YG($UA:6P@4V5R=FEC97,@;VX@1&]M86EN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@;VX@=VAI8V@@9&]M86EN('EO
M=2!W86YT('1O(&5N86)L92!O<B!D:7-A8FQE(&UA:6P@<V5R=FEC97,N)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?7V1E<V-R
M:7!T:6]N)R`]/B`G4V5T('5P(&1O;6%I;B!A9&UI;FES=')A=&]R(&%C8V]U
M;G0@9F]R(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]P<F]P97)T:65S7U]D;VYE)R`]/B`G1&]M86EN(&%D;6EN(&%C8V]U;G0@
M)3$@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]P<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!P<F]P
M97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE
M<U]?=&ET;&4G(#T^("=3970@=7`@9&]M86EN(&%D;6EN(&9O<B!D;VUA:6X@
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE
M=RUA9&AO8U]?=VEZ87)D7U\R7VYE=R<@/3X@)TYE=R!D;VUA:6X@=VEL;"!B
M92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC:R!.97AT(#X^
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W
M7U]D97-C<FEP=&EO;B<@/3X@)T-R96%T92!A;F0@8V]N9FEG=7)E(&YE=R!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE
M<U]N97=?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@8W)E871E9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?
M<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E
M871E(&1O;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^("=$;VUA:6X@0W)E871I;VXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@82!C;&EE;G0@9F]R('=H
M;VT@>6]U('=A;G0@=&\@8W)E871E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S(O:&]S
M=&EN9R]P<F]P97)T:65S)R`]/B`G4V5L96-T('1H92!D97-I<F5D(&AO<W1I
M;F<@='EP92!F;W(@=&AE(&1O;6%I;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ
M87)D7U\R+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG)R`]/B`G5VAE
M;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!O;B!T:&4@9&]M
M86EN+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@=&AE(&-O;F9I9W5R871I;VX@
M86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R+VAO<W1I;F<O<')O<&5R
M=&EE<U]P:&]S=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R:6YG
M('!H>7-I8V%L(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN:7-H
M('1O(&%P<&QY(&%L;"!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,B]L:6UI=',G(#T^("=#;&EC:R!.97AT(#X^('1O('!R;V-E960@
M=&\@8V]N9FEG=7)I;F<@:&]S=&EN9R!F;W(@=&AE(&1O;6%I;BX@0VQI8VL@
M1FEN:7-H('1O(&%P<&QY(&1O;6%I;B!L:6UI=',@86YD(&5X:70@=&AE('=I
M>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S
M7VYE=U]?=VEZ87)D7U\R7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E
M871E('1H92!D;VUA:6X@86YD('!R;V-E960@=&\@8V]N9FEG=7)I;F<@9&]M
M86EN(&QI;6ET<RX@0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@9&]M86EN
M('=I=&AO=70@:71S(&9U<G1H97(@8V]N9FEG=7)I;F<@86YD(&5X:70@=&AE
M('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T
M:65S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('EO=7(@<&%S<W=O
M<F0@86YD('!E<G-O;F%L(&EN9F\L('-E="!U<"!#4"!A<'!E87)A;F-E(&%N
M9"!V:65W('EO=7(@<&5R;6ES<VEO;G,N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO<')O<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G4')O<&5R=&EE
M<R!O9B!Y;W5R(&1O;6%I;B!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G161I="!M
M>2!A8V-O=6YT)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R
M=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!D;VUA:6X@
M861M:6YI<W1R871O<B!A8V-O=6YT(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M4V5T('5P(&1O;6%I;B!A9&UI;B!F;W(@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=3971T:6YG(%5P($1O;6%I;B!!9&UI;FES=')A=&]R($%C8V]U
M;G0G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!S970@=7`@9&]M86EN(&%D;6EN:7-T
M<F%T;W(@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W
M:71H('-P96-I9GEI;F<@<')O<&5R=&EE<R!O9B!D;VUA:6X@861M:6YI<W1R
M871O<B!A8V-O=6YT+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A
M;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S7W-E;&8G(#T^("=7
M:&5N(&1O;F4@=VET:"!S<&5C:69Y:6YG('!R;W!E<G1I97,@;V8@9&]M86EN
M(&%D;6EN:7-T<F%T;W(@86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY
M(&-H86YG97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO=&]G9VQE7V1I<V%B;&5?7V1E<V-R:7!T:6]N)R`]
M/B`G1&ES86)L92!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO=&]G9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S
M(&)E96X@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M=&]G9VQE7V1I<V%B;&5?7W-H;W)T+71I=&QE)R`]/B`G1&ES86)L92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L95]D:7-A8FQE7U]T:71L
M92<@/3X@)T1I<V%B;&4@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO=&]G9VQE7V5N86)L95]?9&5S8W)I<'1I;VXG(#T^("=%;F%B
M;&4@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O
M9V=L95]E;F%B;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@96YA
M8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]T;V=G;&5?96YA
M8FQE7U]S:&]R="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L
M95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE
M(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T5N86)L92]D:7-A8FQE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W1I
M=&QE)R`]/B`G16YA8FQE+T1I<V%B;&4@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)T5N86)L:6YG+T1I<V%B;&EN9R!$;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO
M=VXG(#T^("=396QE8W0@=VAI8V@@9&]M86EN('EO=2!W86YT('1O(&5N86)L
M92!O<B!D:7-A8FQE+B<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUC;VUP86YY+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&%N>2!N86UE
M(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUC;VUP86YY+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&%N>2!N86UE
M)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]M<&%N>2UN86UE
M7U]T:71L92<@/3X@)T-O;7!A;GD@;F%M92!O9B!C;&EE;G0@)3$G+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VUP86YY+6YA;65?<V5L9E]?
M9&5S8W)I<'1I;VXG(#T^("=9;W5R(&-O;7!A;GD@;F%M92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]S96QF7U]S:&]R
M="UT:71L92<@/3X@)T-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]S96QF7U]T:71L92<@/3X@)UEO
M=7(@8V]M<&%N>2!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M8V]M<&%N>2UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]M
M<&%N>2!N86UE(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]U;FMN;W=N7U]S:&]R="UT:71L92<@
M/3X@)T-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6-O;7!A;GDM;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;7!A;GD@
M;F%M92!O9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUC;VYT86-T+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]N=&%C="!N
M86UE(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUC;VYT86-T+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]N=&%C="!N
M86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]N=&%C="UN
M86UE7U]T:71L92<@/3X@)T-O;G1A8W0@;F%M92!O9B!C;&EE;G0@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VYT86-T+6YA;65?<V5L
M9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R(&-O;G1A8W0@;F%M92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]S
M:&]R="UT:71L92<@/3X@)T-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]T:71L92<@/3X@
M)UEO=7(@8V]N=&%C="!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M8V]N=&%C="UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M0V]N=&%C="!N86UE(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)T-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6-O;G1A8W0M;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;G1A
M8W0@;F%M92!O9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN
M9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@
M/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET
M+75S86=E7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A
M9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E
M+6QI;6ET+75S86=E7U]T:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A
M9V4@9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&1I<VL@<W!A8V4@;&EM:70@=7-A9V4G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!L:6UI="!U<V%G92<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM
M:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=9;W5R(&1I<VL@<W!A8V4@;&EM
M:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K
M+7-P86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M1&ES:R!S<&%C92!L:6UI="!U<V%G92!F;W(@82!C;&EE;G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@
M=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P
M86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C
M92!L:6UI="!U<V%G92!F;W(@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L
M:65N="]I;F1I8V%T;W(M96UA:6Q?7V1E<V-R:7!T:6]N)R`]/B`G16UA:6P@
M861D<F5S<R!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I
M;F1I8V%T;W(M96UA:6Q?7W-H;W)T+71I=&QE)R`]/B`G16UA:6P@861D<F5S
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+65M86EL7U]T:71L
M92<@/3X@)T5M86EL(&%D9')E<W,@;V8@8VQI96YT("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M96UA:6Q?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUE;6%I;%]S96QF7U]S:&]R="UT:71L92<@/3X@)T5M86EL
M(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUE;6%I
M;%]S96QF7U]T:71L92<@/3X@)UEO=7(@96UA:6P@861D<F5S<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+65M86EL7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G16UA:6P@861D<F5S<R!O9B!A(&-L:65N="XG+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUE;6%I;%]U;FMN;W=N7U]S:&]R
M="UT:71L92<@/3X@)T5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUE;6%I;%]U;FMN;W=N7U]T:71L92<@/3X@)T5M86EL
M(&%D9')E<W,@;V8@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]I
M;F1I8V%T;W(M9G5L;"US=&%T=7-?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&QE
M=&4@<W1A='5S(&9O<B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?7W-H;W)T+71I=&QE)R`]/B`G0V]M
M<&QE=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M9G5L;"US=&%T=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S(&9O<B!C
M;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL
M+7-T871U<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@8V]M<&QE=&4@
M<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US
M=&%T=7-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL+7-T871U<U]S
M96QF7U]T:71L92<@/3X@)UEO=7(@8V]M<&QE=&4@<W1A='5S)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK;F]W;E]?
M9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+69U;&PM<W1A='5S
M7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S)RP*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK
M;F]W;E]?=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT
M)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS
M+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)TUA>&EM=6T@9&]M86EN
M<R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R
M="UT:71L92<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET
M+75S86=E7U]T:71L92<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G
M92!F;W(@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M;6%X+61O;6%I;G,M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&UA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S
M86=E7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI
M;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X
M+61O;6%I;G,M;&EM:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=9;W5R(&UA
M>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E
M(&9O<B!A(&-L:65N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R
M+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE
M)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+61O;6%I;G,M;&EM:70M=7-A9V5?
M=6YK;F]W;E]?=&ET;&4G(#T^("=-87AI;75M(&1O;6%I;G,@;&EM:70@=7-A
M9V4@9F]R(&$@8VQI96YT)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?7V1E<V-R:7!T:6]N)R`]
M/B`G36%X:6UU;2!M86EL8F]X97,@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O
M>&5S+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUA>&EM=6T@;6%I
M;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G95]?=&ET;&4G(#T^("=-
M87AI;75M(&UA:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q)RP*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL
M:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@;6%X:6UU
M;2!M86EL8F]X97,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G36%X:6UU;2!M86EL8F]X97,@;&EM:70@=7-A9V4G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O>&5S
M+6QI;6ET+75S86=E7W-E;&9?7W1I=&QE)R`]/B`G66]U<B!M87AI;75M(&UA
M:6QB;WAE<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=-87AI;75M(&UA:6QB;WAE<R!L:6UI="!U<V%G92!F
M;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU
M<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI
M;6ET('5S86=E(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T95]?9&5S8W)I<'1I;VXG(#T^("=3=&%T92!O9B!C
M;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A
M=&5?7W-H;W)T+71I=&QE)R`]/B`G4W1A=&4G+`H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUS=&%T95]?=&ET;&4G(#T^("=3=&%T92!O9B!C;&EE
M;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T95]S
M96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@<W1A=&4G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T95]S96QF7U]S:&]R="UT:71L92<@
M/3X@)U-T871E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A
M=&5?<V5L9E]?=&ET;&4G(#T^("=9;W5R('-T871E)RP*("`@("`@("`G=6E?
M7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=3=&%T92!O9B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U-T
M871E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?=6YK
M;F]W;E]?=&ET;&4G(#T^("=3=&%T92!O9B!A(&-L:65N="<L"@H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?9&5S8W)I
M<'1I;VXG(#T^("=$971A:6QE9"!S=&%T=7,@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?
M<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?=&ET;&4G(#T^
M("=$971A:6QE9"!S=&%T=7,@9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G66]U<B!D971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)T1E=&%I;&5D('-T871U<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7W1I=&QE)R`]
M/B`G66]U<B!D971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N7U]D97-C<FEP=&EO
M;B<@/3X@)T1E=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?=6YK;F]W
M;E]?<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N
M7U]T:71L92<@/3X@)T1E=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0G+`H*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A='5S7U]D97-C<FEP
M=&EO;B<@/3X@)U-T871U<R!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^("=3
M=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?
M7W1I=&QE)R`]/B`G4W1A='5S(&9O<B!C;&EE;G0@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R('-T871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+7-T871U<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<U]S96QF7U]T:71L
M92<@/3X@)UEO=7(@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M<W1A='5S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S
M(&9O<B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUS=&%T=7-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?=6YK;F]W;E]?
M=&ET;&4G(#T^("=3=&%T=7,@9F]R(&$@8VQI96YT)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?7V1E<V-R
M:7!T:6]N)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM
M:70M=7-A9V5?7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G
M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM
M:70M=7-A9V5?7W1I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@
M8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M=')A
M9F9I8RUL:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@
M=')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?<V5L9E]?<VAO<G0M=&ET;&4G
M(#T^("=4<F%F9FEC(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]T:71L92<@
M/3X@)UEO=7(@=')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?
M9&5S8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O<B!A(&-L
M:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUT<F%F9FEC
M+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I
M8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R
M+71R869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=4<F%F
M9FEC(&QI;6ET('5S86=E(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?
M8VQI96YT+VEP+7!O;VQ?7V1E<V-R:7!T:6]N)R`]/B`G061D+U)E;6]V92!)
M4"!A9&1R97-S97,@86YD(&%S<VEG;B!34TP@8V5R=&EF:6-A=&5S(&9O<B!C
M;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L7U]S:&]R
M="UT:71L92<@/3X@)TE0('!O;VPG+`H@("`@("`@("=U:5]?8VQI96YT+VEP
M+7!O;VQ?7W1I=&QE)R`]/B`G0VQI96YT("4Q($E0('!O;VPG+`H@("`@("`@
M("=U:5]?8VQI96YT+VEP+7!O;VQ?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W('EO=7(@25`@<&]O;"XG+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O
M;VQ?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=)4"!P;V]L)RP*("`@("`@("`G
M=6E?7V-L:65N="]I<"UP;V]L7W-E;&9?7W1I=&QE)R`]/B`G37D@25`@<&]O
M;"<L"@H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?
M9&5S8W)I<'1I;VXG(#T^("=3970@=7`@25`@<&]O;"!F;W(@8VQI96YT("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7U]D
M;VYE)R`]/B`G0VQI96YT("4Q($E0('!O;VP@:&%S(&)E96X@=7!D871E9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("=)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I
M<"UP;V]L+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4V5T('5P($E0('!O;VP@
M9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G5FEE=R!Y;W5R($E0
M('!O;VPN)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L+W!R;W!E<G1I
M97-?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M
M<&]O;"]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@25`@
M<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S
M7W-E;&9?7W1I=&QE)R`]/B`G37D@25`@<&]O;"<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N
M)R`]/B`G061D+U)E;6]V92!)4"!A9&1R97-S97,@=&\O9G)O;2!C;&EE;G0@
M25`@<&]O;"P@86YD(&UA;F%G92!34TP@8V5R=&EF:6-A=&5S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G25`@<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G4V5T('5P
M(&-L:65N="!)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0VQI96YT
M($E0(%!O;VP@0V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N
M)R`]/B`G4V5L96-T(&$@8VQI96YT('=H;W-E($E0('!O;VP@>6]U('=A;G0@
M=&\@8V]N9FEG=7)E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W
M:71H(&5D:71I;F<@=&AE(&-L:65N="!)4"!P;V]L+"!C;&EC:R!&:6YI<V@@
M=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W
M(&]R(&5D:70@;&EM:71S(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?
M8VQI96YT+VQI;6ET<U]?9&]N92<@/3X@)TQI;6ET<R!O9B!C;&EE;G0@)3$@
M:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?7W-H;W)T+71I=&QE)R`]/B`G3&EM:71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]L:6UI='-?7W1I=&QE)R`]/B`G5FEE=R!O<B!E9&ET(&QI;6ET<R!O
M9B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VQI;6ET<U]S96QF
M7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;7D@;&EM:71S+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O;&EM:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@
M("=U:5]?8VQI96YT+VQI;6ET<U]S96QF7U]S:&]R="UT:71L92<@/3X@)TQI
M;6ET<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O;&EM:71S7W-E;&9?7W1I=&QE
M)R`]/B`G5FEE=R!M>2!L:6UI=',G+`H@("`@("`@("=U:5]?8VQI96YT+VQI
M;6ET<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I="!L
M:6UI=',@;V8@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=,:6UI=',G+`H@("`@("`@
M("=U:5]?8VQI96YT+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<@
M;W(@961I="!L:6UI=',@;V8@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI
M96YT+VQI;6ET<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=6:65W:6YG
M(&]R(&5D:71I;F<@82!C;&EE;G0@;&EM:71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]L:6UI='-?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=0
M;&5A<V4@<V5L96-T(&$@8VQI96YT('=H;W-E(&QI;6ET<R!T;R!V:65W(&]R
M(&5D:70N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI='-?=6YK;F]W;E]?
M=VEZ87)D7U\R)R`]/B`G069T97(@961I=&EN9R!T:&4@8VQI96YT(&QI;6ET
M<RP@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O;&EM:71S
M7W5N:VYO=VY?7W=I>F%R9%]?,E]S96QF)R`]/B`G069T97(@=FEE=VEN9R!Y
M;W5R(&QI;6ET<RP@8VQI8VL@1FEN:7-H+B<L"@H@("`@("`@("=U:5]?8VQI
M96YT+W!E<FUI<W-I;VYS7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I
M="!P97)M:7-S:6]N<R!F;W(@8VQI96YT(&%C8V]U;G0@)3$N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]?9&]N92<@/3X@)U!E<FUI<W-I
M;VYS(&]F(&-L:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+W!E<FUI<W-I;VYS7U]S:&]R="UT:71L92<@/3X@)U!E
M<FUI<W-I;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]?
M=&ET;&4G(#T^("=#;&EE;G0@)3$@<&5R;6ES<VEO;G,G+`H@("`@("`@("=U
M:5]?8VQI96YT+W!E<FUI<W-I;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G
M5FEE=R!Y;W5R('!E<FUI<W-I;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<&5R;6ES<VEO;G-?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O<&5R;6ES<VEO;G-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=097)M
M:7-S:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<&5R;6ES<VEO;G-?<V5L
M9E]?=&ET;&4G(#T^("=->2!P97)M:7-S:6]N<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O<&5R;6ES<VEO;G-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W(&]R(&5D:70@<&5R;6ES<VEO;G,@9F]R(&$@8VQI96YT(&%C8V]U;G0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U!E<FUI<W-I;VYS)RP*("`@("`@("`G=6E?7V-L
M:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O161I
M="!C;&EE;G0@<&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI96YT+W!E
M<FUI<W-I;VYS7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O
M161I=&EN9R!#;&EE;G0@4&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI
M96YT+W!E<FUI<W-I;VYS7W5N:VYO=VY?7W=I>F%R9%]?,2]P<F]P97)T:65S
M7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET:"!V:65W:6YG('EO=7(@<&5R;6ES
M<VEO;G,L(&-L:6-K($9I;FES:"!T;R!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E
M>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S
M:6]N<U]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A
M(&-L:65N="!W:&]S92!P97)M:7-S:6]N<R!Y;W4@=V%N="!T;R!V:65W+V5D
M:70N)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N
M7U]W:7IA<F1?7S(G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C
M;&EE;G0@<&5R;6ES<VEO;G,L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N
M9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O<')E9F5R96YC97-?7V1E<V-R:7!T:6]N)R`]/B`G161I="!S97-S:6]N
M(&%N9"!I;G1E<F9A8V4@<')E9F5R96YC97,@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7U]D;VYE)R`]/B`G4')E
M9F5R96YC97,@9F]R(&-L:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7U]S:&]R="UT:71L92<@
M/3X@)U!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E
M;F-E<U]?=&ET;&4G(#T^("=#;&EE;G0@)3$@<')E9F5R96YC97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W-E;&9?7V1E<V-R:7!T:6]N
M)R`]/B`G161I="!Y;W5R('-E<W-I;VX@86YD(&EN=&5R9F%C92!P<F5F97)E
M;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')E9F5R96YC97-?<V5L9E]?
M9&]N92<@/3X@)UEO=7(@<')E9F5R96YC97,@:&%V92!B965N('5P9&%T960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)TUY('!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L
M:65N="]P<F5F97)E;F-E<U]S96QF7U]T:71L92<@/3X@)TUY('!R969E<F5N
M8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@0U`@<V5S<VEO;B!A;F0@:6YT97)F
M86-E('!R969E<F5N8V5S(&9O<B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?
M8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M4')E9F5R96YC97,G+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G161I="!C;&EE;G0@<')E9F5R96YC97,G
M+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W=I
M>F%R9"UT:71L92<@/3X@)T5D:71I;F<@0VQI96YT(%!R969E<F5N8V5S)RP*
M("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N7U]W:7IA
M<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!C;&EE;G0@=VAO<V4@<V5S<VEO
M;B!A;F0@:6YT97)F86-E('!R969E<F5N8V5S('EO=2!W86YT('1O(&UA;F%G
M92XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?
M7W=I>F%R9%]?,B<@/3X@)T%F=&5R(&5D:71I;F<@=&AE(&-L:65N="!P<F5F
M97)E;F-E<RP@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<')E9F5R96YC97-?=6YK;F]W;E]?=VEZ87)D7U\R7W-E;&8G(#T^("=!9G1E
M<B!E9&ET:6YG('EO=7(@<')E9F5R96YC97,L(&-L:6-K($9I;FES:"XG+`H*
M("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@
M/3X@)T5D:70@<&5R<V]N86P@:6YF;W)M871I;VX@;V8@8VQI96YT("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?9&]N92<@/3X@)U!E
M<G-O;F%L(&EN9F]R;6%T:6]N(&]F(&-L:65N="`E,2!H87,@8F5E;B!U<&1A
M=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?<VAO<G0M
M=&ET;&4G(#T^("=097)S;VYA;"!I;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O<')O<&5R=&EE<U]?=&ET;&4G(#T^("=#;&EE;G0@)3$@<&5R
M<V]N86P@:6YF;R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N
M97<M861H;V-?7W=I>F%R9%]?,5]N97<G(#T^("=4:&4@8VQI96YT(&%C8V]U
M;G0@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N
M97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE=R!C;&EE;G0@86-C;W5N
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?;F5W7U]D;VYE
M)R`]/B`G0VQI96YT("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#
M<F5A=&4@8VQI96YT)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7VYE=U]?=&ET;&4G(#T^("=#<F5A=&4@8VQI96YT)RP*("`@("`@("`G=6E?
M7V-L:65N="]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]/B`G0VQI
M96YT($-R96%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7VYE=U]?=VEZ87)D7U\Q+VEP+7!O;VPO<')O<&5R=&EE<R<@/3X@)U=H96X@
M9&]N92!W:71H(&-O;F9I9W5R:6YG('1H92!C;&EE;G0@25`@<&]O;"P@8VQI
M8VL@1FEN:7-H('1O(&-O;7!L971E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,2]L:6UI=',G(#T^("=#;&EC:R!.
M97AT(#X^('1O('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT('!E<FUI
M<W-I;VYS+B!#;&EC:R!&:6YI<V@@=&\@87!P;'D@=&AE(&QI;6ET<R!A;F0@
M97AI="!T:&ES('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F1?7S$O<&5R;6ES<VEO;G,G(#T^("=#;&EC:R!.
M97AT(#X^('1O('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT($E0('!O
M;VPN($-L:6-K($9I;FES:"!T;R!A<'!L>2!T:&4@<&5R;6ES<VEO;G,@86YD
M(&5X:70@=&AI<R!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P
M97)T:65S7VYE=U]?=VEZ87)D7U\Q7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@
M=&\@8W)E871E('1H92!C;&EE;G0@86-C;W5N="!A;F0@<')O8V5E9"!T;R!C
M;VYF:6=U<FEN9R!R97-O=7)C92!U<V%G92!L:6UI=',N($-L:6-K($9I;FES
M:"!T;R!C<F5A=&4@=&AE(&%C8V]U;G0@=VET:&]U="!I=',@9G5R=&AE<B!C
M;VYF:6=U<FEN9RXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('EO=7(@<&5R<V]N86P@:6YF
M;W)M871I;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7W-E
M;&9?7V1O;F4G(#T^("=9;W5R('!E<G-O;F%L(&EN9F]R;6%T:6]N(&AA<R!B
M965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@<&5R<V]N86P@:6YF;W)M871I
M;VXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?<V5L9E]?=&ET
M;&4G(#T^("=->2!P97)S;VYA;"!I;F9O)RP*("`@("`@("`G=6E?7V-L:65N
M="]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G161I="!A
M(&-L:65N="!P97)S;VYA;"!I;F9O<FUA=&EO;BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=0
M97)S;VYA;"!I;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O
M<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)T5D:70@8VQI96YT('!E<G-O
M;F%L(&EN9F\G+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G161I=&EN9R!#;&EE;G0@4&5R<V]N
M86P@26YF;W)M871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@8VQI
M96YT('=H;W-E('!E<G-O;F%L(&EN9F\@>6]U('=A;G0@=&\@8VAA;F=E+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA
M<F1?7S(G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C;&EE;G0@
M:6YF;RP@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]S
M96QF)R`]/B`G5VAE;B!D;VYE('=I=&@@961I=&EN9R!Y;W5R(&EN9F\L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+W1O9V=L95]D:7-A8FQE7U]D97-C<FEP=&EO;B<@/3X@)T1I<V%B
M;&4@8VQI96YT(&%C8V]U;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]T
M;V=G;&5?9&ES86)L95]?9&]N92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!D
M:7-A8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]D:7-A8FQE
M7U]S:&]R="UT:71L92<@/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI
M96YT+W1O9V=L95]D:7-A8FQE7U]T:71L92<@/3X@)T1I<V%B;&4@8VQI96YT
M("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?96YA8FQE7U]D97-C
M<FEP=&EO;B<@/3X@)T5N86)L92!C;&EE;G0@86-C;W5N="`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+W1O9V=L95]E;F%B;&5?7V1O;F4G(#T^("=#;&EE
M;G0@)3$@:&%S(&)E96X@96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]E;F%B;&5?7W-H;W)T+71I=&QE)R`]/B`G16YA8FQE)RP*("`@
M("`@("`G=6E?7V-L:65N="]T;V=G;&5?96YA8FQE7U]T:71L92<@/3X@)T5N
M86)L92!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]U
M;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE(&$@
M8VQI96YT(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=%;F%B;&4O9&ES86)L92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O=&]G9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M16YA8FQE+T1I<V%B;&4@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=%;F%B;&EN9R]$
M:7-A8FQI;F<@0VQI96YT($%C8V]U;G0G+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C
M="!A(&-L:65N="!A8V-O=6YT('EO=2!W86YT('1O(&5N86)L92]D:7-A8FQE
M+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G-?7V1E<V-R:7!T:6]N
M)R`]/B`G4V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;G,N)RP*("`@("`@("`G
M=6E?7V-U<W1O;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B
M=71T;VYS)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS7U]T:71L92<@
M/3X@)U-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VYS)RP*"B`@("`@("`@)W5I
M7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N7U]N;VYE+6%V86EL86)L
M92<@/3X@)UEO=2!D;VY<)W0@8W5R<F5N=&QY(&AA=F4@86YY(&-U<W1O;2!B
M=71T;VYS+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-E<G9E
M<BUW:61E(&-U<W1O;2!B=71T;VX@)3$N)RP*("`@("`@("`G=6E?7V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G4V5R
M=F5R+7=I9&4@8W5S=&]M(&)U='1O;B`E,2!H87,@8F5E;B!R96UO=F5D+B<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?
M8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I=&QE)R`]
M/B`G4F5M;W9E(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=296UO=F4@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O
M;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@
M("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE
M=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N
M(')E;6]V86PG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^
M("=396QE8W0@=VAI8V@@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;B!Y;W4@
M=V%N="!T;R!R96UO=F4N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@
M)T-O;F9I<FT@<F5M;W9I;F<@=&AE('-E<G9E<BUW:61E(&-U<W1O;2!B=71T
M;VX@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K(&9I;FES
M:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE
M<R!O9B!S97)V97(M=VED92!C=7-T;VT@8G5T=&]N("4Q+B<L"B`@("`@("`@
M)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?
M7V1O;F4G(#T^("=0<F]P97)T:65S(&]F(&-U<W1O;2!B=71T;VX@)3$@:&%V
M92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("=0
M<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO<')O<&5R=&EE<U]?=&ET;&4G(#T^("=-;V1I9GD@<V5R=F5R
M(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG
M(#T^("=#<F5A=&4@;F5W('-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VXN)RP*
M("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O
M<&5R=&EE<U]N97=?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q(&AA<R!B
M965N(&-R96%T960G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#
M<F5A=&4G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7VYE=U]?=&ET;&4G(#T^("=#<F5A=&4@<V5R=F5R
M(&-U<W1O;2!B=71T;VXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O
M8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]
M/B`G0W5S=&]M(&)U='1O;B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S)?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@8W5S
M=&]M(&)U='1O;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G161I="!P<F]P97)T:65S(&]F(&$@<V5R=F5R+7=I9&4@8W5S=&]M(&)U
M='1O;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')O
M<&5R=&EE<R<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=-;V1I9GD@
M<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D+71I=&QE)R`]/B`G36]D:69Y:6YG(%-E<G9E<BUW:61E($-U<W1O
M;2!"=71T;VXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N
M)R`]/B`G4V5L96-T('=H:6-H(&-U<W1O;2!B=71T;VX@>6]U('=A;G0@=&\@
M;6]D:69Y+B<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S)R`]/B`G5VAE
M;B!D;VYE('=I=&@@;6]D:69Y:6YG('1H92!S97)V97(M=VED92!C=7-T;VT@
M8G5T=&]N+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI
M="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?9&%S:&)O87)D(V-L:65N
M='-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@9F%V;W)I=&4@8VQI96YT<R<L"B`@
M("`@("`@)W5I7U]D87-H8F]A<F0C8VQI96YT<U]?=&ET;&4G(#T^("=#;&EE
M;G1S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-C=7-T;VTM8G5T=&]N<U]?
M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@)W5I7U]D87-H
M8F]A<F0C9&]M86EN<U]?9&5S8W)I<'1I;VXG(#T^("=.;R!F879O<FET92!D
M;VUA:6YS)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-D;VUA:6YS7U]T:71L
M92<@/3X@)T1O;6%I;G,G+`H@("`@("`@("=U:5]?9&%S:&)O87)D(V9A=F]R
M:71E<R]T86)S7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O;&QO=VEN
M9R!T86)S(&EN($9A=F]R:71E<SHG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M(V9A=F]R:71E<U]?=&ET;&4G(#T^("=&879O<FET97,G+`H@("`@("`@("=U
M:5]?9&%S:&)O87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@)U-H
M;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@/3X@)U-H
M;W<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D(VEN9F]?7W1I=&QE)R`]/B`G4V5R=F5R($EN9F]R;6%T:6]N
M)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-M86EL;F%M97-?7V1E<V-R:7!T
M:6]N)R`]/B`G3F\@9F%V;W)I=&4@;6%I;&YA;65S)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-M86EL;F%M97-?7W1I=&QE)R`]/B`G36%I;&YA;65S)RP*
M("`@("`@("`G=6E?7V1A<VAB;V%R9"-Q=6EC:RUS96%R8VA?7W1I=&QE)R`]
M/B`G475I8VL@<V5A<F-H)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-R96-E
M;G1?7V1E<V-R:7!T:6]N)R`]/B`G3F\@<F5C96YT('!A9V5S)RP*("`@("`@
M("`G=6E?7V1A<VAB;V%R9"-R96-E;G1?7W1I=&QE)R`]/B`G4F5C96YT)RP*
M("`@("`@("`G=6E?7V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T:6]N
M)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-S
M:&]R=&-U='-?7W1I=&QE)R`]/B`G4VAO<G1C=71S)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-S=&%T:7-T:6-S+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^
M("=3:&]W('1H92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L
M"B`@("`@("`@)W5I7U]D87-H8F]A<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I
M;VXG(#T^("=3:&]W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-T
M871I<W1I8W,G+`H@("`@("`@("=U:5]?9&%S:&)O87)D(W1O;VQS+V9O;W1E
M<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H92!F;VQL;W=I;F<@8G5T=&]N
M<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0C=&]O
M;'-?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&)U='1O
M;G,Z)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-T;V]L<U]?=&ET;&4G(#T^
M("=4;V]L<R<L"B`@("`@("`@)W5I7U]D87-H8F]A<F1?7V1E<V-R:7!T:6]N
M)R`]/B`G061M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@)W5I7U]D
M87-H8F]A<F1?7W-H;W)T+71I=&QE)R`]/B`G1&5S:W1O<"<L"B`@("`@("`@
M)W5I7U]D87-H8F]A<F1?7W1I=&QE)R`]/B`G061M:6YI<W1R871O<B!$97-K
M=&]P)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9%]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)TUY($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9%]S
M96QF7U]S:&]R="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D7W-E;&9?7W1I=&QE)R`]/B`G37D@1&5S:W1O<"<L"@H@("`@
M("`@("=U:5]?9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^
M("=#=7-T;VUI>F4@061M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@
M)W5I7U]D87-H8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G061M:6X@1&5S
M:W1O<"!H87,@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A
M<F0O8W5S=&]M:7IE7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K
M=&]P)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]C=7-T;VUI>F5?7W1I=&QE
M)R`]/B`G0W5S=&]M:7IE($%D;6EN($1E<VMT;W`G+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-U
M<W1O;6EZ92!Y;W5R($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R
M9"]C=7-T;VUI>F5?<V5L9E]?9&]N92<@/3X@)UEO=7(@1&5S:W1O<"!H87,@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O8W5S=&]M
M:7IE7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`G
M+`H@("`@("`@("=U:5]?9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L
M92<@/3X@)T-U<W1O;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]D
M87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^
M("=%9&ET('-H;W)T8W5T("4Q+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O
M<VAO<G1C=70O<')O<&5R=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA
M<R!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]S:&]R
M=&-U="]P<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@
M("`@("=U:5]?9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W1I=&QE
M)R`]/B`G161I="!S:&]R=&-U="`E,2<L"B`@("`@("`@)W5I7U]D87-H8F]A
M<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G
M0W)E871E(&YE=R!S:&]R=&-U="XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G4VAO<G1C=70@
M)3$@:&%S(&)E96X@8W)E871E9"XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R
M96%T92!S:&]R=&-U="<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E871E(&YE=R!S:&]R
M=&-U="<L"@H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-L:65N=',M;G5M8F5R
M7U]D97-C<FEP=&EO;B<@/3X@)TYU;6)E<B!O9B!C;&EE;G1S+B<L"B`@("`@
M("`@)W5I7U]I;F1I8V%T;W(M8VQI96YT<RUN=6UB97)?7W-H;W)T+71I=&QE
M)R`]/B`G3G5M8F5R(&]F(&-L:65N=',G+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+6-L:65N=',M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!C;&EE
M;G1S)RP*"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M8W!U7U]D97-C<FEP=&EO
M;B<@/3X@)T-052XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P=5]?<VAO
M<G0M=&ET;&4G(#T^("=#4%4G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P
M=5]?=&ET;&4G(#T^("=#4%4G+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUD
M:7-K+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A9V4N
M)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUD:7-K+75S86=E7U]S:&]R="UT
M:71L92<@/3X@)T1I<VL@<W!A8V4@=7-A9V4G+`H@("`@("`@("=U:5]?:6YD
M:6-A=&]R+61I<VLM=7-A9V5?7W1I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G
M92<L"@H@("`@("`@("=U:5]?:6YD:6-A=&]R+61O;6%I;G,M;G5M8F5R7U]D
M97-C<FEP=&EO;B<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS+B<L"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M9&]M86EN<RUN=6UB97)?7W-H;W)T+71I=&QE)R`]
M/B`G3G5M8F5R(&]F(&1O;6%I;G,G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R
M+61O;6%I;G,M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS
M)RP*"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M:&]S=&YA;65?7V1E<V-R:7!T
M:6]N)R`]/B`G2&]S=&YA;64N)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUH
M;W-T;F%M95]?<VAO<G0M=&ET;&4G(#T^("=(;W-T;F%M92<L"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M:&]S=&YA;65?7W1I=&QE)R`]/B`G2&]S=&YA;64G
M+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUL:6-E;G-E+65X<&ER871I;VY?
M7V1E<V-R:7!T:6]N)R`]/B`G3&EC96YS92!K97D@97AP:7)A=&EO;B!D871E
M+B<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N
M7U]S:&]R="UT:71L92<@/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T
M92<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N
M7U]T:71L92<@/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T92<L"@H@
M("`@("`@("=U:5]?:6YD:6-A=&]R+6QI8V5N<V4M:V5Y+6ED7U]D97-C<FEP
M=&EO;B<@/3X@)TQI8V5N<V4@:V5Y(&YU;6)E<BXG+`H@("`@("`@("=U:5]?
M:6YD:6-A=&]R+6QI8V5N<V4M:V5Y+6ED7U]S:&]R="UT:71L92<@/3X@)TQI
M8V5N<V4@:V5Y(&YU;6)E<B<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC
M96YS92UK97DM:61?7W1I=&QE)R`]/B`G3&EC96YS92!K97D@;G5M8F5R)RP*
M"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&]A9"UA=F%R86=E7U]D97-C<FEP
M=&EO;B<@/3X@)T%V97)A9V4@;&]A9"XG+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+6QO860M879A<F%G95]?<VAO<G0M=&ET;&4G(#T^("=!=F5R86=E(&QO
M860G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6QO860M879A<F%G95]?=&ET
M;&4G(#T^("=!=F5R86=E(&QO860G+`H*("`@("`@("`G=6E?7VEN9&EC871O
M<BUM96TM=7-A9V5?7V1E<V-R:7!T:6]N)R`]/B`G365M;W)Y('5S86=E+B<L
M"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;65M+75S86=E7U]S:&]R="UT:71L
M92<@/3X@)TUE;6]R>2!U<V%G92<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M
M;65M+75S86=E7U]T:71L92<@/3X@)TUE;6]R>2!U<V%G92<L"@H@("`@("`@
M("=U:5]?:6YD:6-A=&]R+6]S7U]D97-C<FEP=&EO;B<@/3X@)T]P97)A=&EN
M9R!S>7-T96TN)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUO<U]?<VAO<G0M
M=&ET;&4G(#T^("=/<&5R871I;F<@<WES=&5M)RP*("`@("`@("`G=6E?7VEN
M9&EC871O<BUO<U]?=&ET;&4G(#T^("=/<&5R871I;F<@<WES=&5M)RP*"B`@
M("`@("`@)W5I7U]I;F1I8V%T;W(M=7!T:6UE7U]D97-C<FEP=&EO;B<@/3X@
M)U5P=&EM92XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+75P=&EM95]?<VAO
M<G0M=&ET;&4G(#T^("=5<'1I;64G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R
M+75P=&EM95]?=&ET;&4G(#T^("=5<'1I;64G+`H*("`@("`@("`G=6E?7VEN
M9&EC871O<BUV97)S:6]N7U]D97-C<FEP=&EO;B<@/3X@)U!L97-K('9E<G-I
M;VXN)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUV97)S:6]N7U]S:&]R="UT
M:71L92<@/3X@)U!L97-K('9E<G-I;VXG+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+79E<G-I;VY?7W1I=&QE)R`]/B`G4&QE<VL@=F5R<VEO;B<L"@H@("`@
M("`@("=U:5]?;&EC96YS95]?9&5S8W)I<'1I;VXG(#T^("=6:65W('EO=7(@
M;&EC96YS92!I;F9O+"!O<F1E<B!N97<@;&EC96YS92!K97DL(')E=')I979E
M(&%N9"!U<&QO860@8V]M;6]N(&%N9"!A9&1I=&EO;F%L(&QI8V5N<V4@:V5Y
M<RXG+`H@("`@("`@("=U:5]?;&EC96YS95]?<VAO<G0M=&ET;&4G(#T^("=,
M:6-E;G-E)RP*("`@("`@("`G=6E?7VQI8V5N<V5?7W1I=&QE)R`]/B`G36%N
M86=E(%!L97-K(&QI8V5N<V4G+`H*("`@("`@("`G=6E?7VYE=W,O9&ES;6ES
M<U]?9&5S8W)I<'1I;VXG(#T^("=#;&EC:R!T;R!C;VUP;&5T96QY(&-L;W-E
M('1H92!.97=S(&9R86UE+B!0;&5S:R!W:6QL(&YO="!S:&]W('1H:7,@9G)A
M;64@=6YT:6P@3F5W<R!A<G1I8VQE<R!A<F4@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?;F5W<R]D:7-M:7-S7U]D;VYE)R`]/B`G4&QE<VL@3F5W<R!H879E
M(&)E96X@8VQO<V5D+B<L"B`@("`@("`@)W5I7U]N97=S+V1I<VUI<W-?7W1I
M=&QE)R`]/B`G0VQO<V4@;F5W<R<L"@H@("`@("`@("=U:5]?<V5R=F5R7U]D
M97-C<FEP=&EO;B<@/3X@)U-E<G9E<B!M86YA9V5M96YT+B<L"B`@("`@("`@
M)W5I7U]S97)V97)?7W-H;W)T+71I=&QE)R`]/B`G4V5R=F5R)RP*("`@("`@
M("`G=6E?7W-E<G9E<E]?=&ET;&4G(#T^("=397)V97(@;6%N86=E;65N="<L
M"@H@("`@("`@("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?7V1E<V-R:7!T
M:6]N)R`]/B`G57!D871E('EO=7(@8V]N=')O;"!P86YE;"!O<B!I=',@8V]M
M<&]N96YT<RXG+`H@("`@("`@("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?
M7W-H;W)T+71I=&QE)R`]/B`G57!D871E<B<L"B`@("`@("`@)W5I7U]S97)V
M97(O875T;VEN<W1A;&QE<E]?=&ET;&4G(#T^("=5<&1A=&5R)RP*"B`@("`@
M("`@)W5I7U]S97)V97(O:6YT97)F86-E7U]D97-C<FEP=&EO;B<@/3X@)U-E
M="!U<"!$97-K=&]P('!R97-E=',L(&EN=&5R9F%C92!T96UP;&%T97,L('-K
M:6YS(&%N9"!L;V-A;&5S+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F
M86-E7U]S:&]R="UT:71L92<@/3X@)TEN=&5R9F%C92!P<F5F97)E;F-E<R<L
M"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E7U]T:71L92<@/3X@)U-E
M="!U<"!S97)V97(@:6YT97)F86-E('!R969E<F5N8V5S)RP*"B`@("`@("`@
M)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S7U]D97-C
M<FEP=&EO;B<@/3X@)TUA;F%G92!$97-K=&]P('!R97-E=',N)RP*("`@("`@
M("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W-H
M;W)T+71I=&QE)R`]/B`G1&5S:W1O<"!P<F5S971S)RP*("`@("`@("`G=6E?
M7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W1I=&QE)R`]
M/B`G36%N86=E($1E<VMT;W`@<')E<V5T<R<L"@H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?7V1E<V-R
M:7!T:6]N)R`]/B`G4F5M;W9E($1E<VMT;W`@<')E<V5T<RXG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE
M=&5?7V1O;F4G(#T^("=396QE8W1E9"!D97-K=&]P('!R97-E=',@:&%V92!B
M965N(')E;6]V960N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O
M9&%S:&)O87)D+7!R97-E=',O9&5L971E7U]S:&]R="UT:71L92<@/3X@)U)E
M;6]V92<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R
M9"UP<F5S971S+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@1&5S:W1O<"!P
M<F5S971S)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O
M87)D+7!R97-E=',O9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M4F5M;W9E(&$@1&5S:W1O<"!P<F5S970G+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?
M=&ET;&4G(#T^("=296UO=F4@82!$97-K=&]P('!R97-E="<L"@H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET($1E<VMT;W`@
M<')E<V5T("4Q+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A
M<VAB;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7U]D;VYE)R`]/B`G
M1&5S:W1O<"!P<F5S970@)3$@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@
M)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S+W!R97-E
M="]P<F]P97)T:65S7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P<F5S970@
M)3$G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M
M<')E<V5T<R]P<F5S970O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]
M/B`G0W)E871E(&YE=R!$97-K=&]P('!R97-E="!B87-E9"!O;B!T:&4@<')E
M<V5T("4Q+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB
M;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?9&]N92<@/3X@
M)T1E<VMT;W`@<')E<V5T("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@
M("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O<')E
M<V5T+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-O<'D@)3$G
M+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E
M<V5T<R]P<F5S970O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0V]P>2!$
M97-K=&]P('!R97-E="`E,2<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F
M86-E+V1A<VAB;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D+71I=&QE)R`]/B`G1&5S:W1O<"!0<F5S970@0W)E871I;VXG+`H@
M("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T
M<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@
M)T5D:70@82!$97-K=&]P('!R97-E="XG+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE
M<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@("`@("=U
M:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O
M<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P
M<F5S970G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A
M<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M
M=&ET;&4G(#T^("=%9&ET:6YG(&$@1&5S:W1O<"!P<F5S970G+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@
M)U-E;&5C="!W:&EC:"!$97-K=&]P('!R97-E="!Y;W4@=V%N="!T;R!E9&ET
M+B<L"@H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M
M<')E<V5T<R]U<&QO861?7V1E<V-R:7!T:6]N)R`]/B`G57!L;V%D($1E<VMT
M;W`@<')E<V5T<R!T;R!S97)V97(N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I
M;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]D;VYE)R`]/B`G
M1&5S:W1O<"!P<F5S971S(&AA=F4@8F5E;B!U<&QO861E9"XG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]U<&QO
M861?7W-H;W)T+71I=&QE)R`]/B`G57!L;V%D)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]T:71L
M92<@/3X@)U5P;&]A9"!$97-K=&]P('!R97-E=',G+`H*("`@("`@("`G=6E?
M7W-E<G9E<B]I<"UA9&1R97-S97-?7V1E<V-R:7!T:6]N)R`]/B`G061D($E0
M(&%D9')E<W-E<R!T;R!A;F0@<F5M;W9E(&9R;VT@=&AE(&YE='=O<FL@:6YT
M97)F86-E<RXG+`H@("`@("`@("=U:5]?<V5R=F5R+VEP+6%D9')E<W-E<U]?
M<VAO<G0M=&ET;&4G(#T^("=)4"!A9&1R97-S97,G+`H@("`@("`@("=U:5]?
M<V5R=F5R+VEP+6%D9')E<W-E<U]?=&ET;&4G(#T^("=-86YA9V4@25`@861D
M<F5S<V5S)RP*"B`@("`@("`@)W5I7U]S97)V97(O;6%I;%]?9&5S8W)I<'1I
M;VXG(#T^("=#;VYF:6=U<F4@<V5R=F5R+7=I9&4@;6%I;"!S>7-T96TN)RP*
M("`@("`@("`G=6E?7W-E<G9E<B]M86EL7U]S:&]R="UT:71L92<@/3X@)TUA
M:6PG+`H@("`@("`@("=U:5]?<V5R=F5R+VUA:6Q?7W1I=&QE)R`]/B`G4V5R
M=F5R+7=I9&4@;6%I;"!P<F5F97)E;F-E<R<L"@H@("`@("`@("=U:5]?<V5R
M=F5R+W!R969E<F5N8V5S7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!S97)V
M97(@<')E9F5R96YC97,N)RP*("`@("`@("`G=6E?7W-E<G9E<B]P<F5F97)E
M;F-E<U]?9&]N92<@/3X@)U-E<G9E<B!P<F5F97)E;F-E<R!H879E(&)E96X@
M=7!D871E9"XG+`H@("`@("`@("=U:5]?<V5R=F5R+W!R969E<F5N8V5S7U]S
M:&]R="UT:71L92<@/3X@)U!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]P<F5F97)E;F-E<U]?=&ET;&4G(#T^("=397)V97(@<')E9F5R96YC
M97,G+`H*("`@("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?9&5S8W)I<'1I
M;VXG(#T^("=3=&%R="P@<W1O<"!O<B!R97-T87)T(&-O;G1R;VP@<&%N96P@
M<V5R=FEC97,N)RP*("`@("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?<VAO
M<G0M=&ET;&4G(#T^("=397)V:6-E<R<L"B`@("`@("`@)W5I7U]S97)V97(O
M<V5R=FEC97-?7W1I=&QE)R`]/B`G36%N86=E('-E<G9I8V5S)RP*"B`@("`@
M("`@)W5I7U]S97)V97(O<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W('-Y<W1E;2!S=&%T:7-T:6-S+B<L"B`@("`@("`@)W5I7U]S97)V97(O
M<W1A=&ES=&EC<U]?<VAO<G0M=&ET;&4G(#T^("=S=&%T:7-T:6-S)RP*("`@
M("`@("`G=6E?7W-E<G9E<B]S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-Y<W1E
M;2!S=&%T:7-T:6-S)RP*"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D97-C<FEP
M=&EO;B<@/3X@)U-U8FUI="!A(')E<75E<W0@9F]R(%!L97-K('1E8VAN:6-A
M;"!S=7!P;W)T+B<L"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D;VYE)R`]/B`G
M5&5C:&YI8V%L('-U<'!O<G0@<&%G92!H87,@8F5E;B!O<&5N960N)RP*("`@
M("`@("`G=6E?7W-U<'!O<G1?7W-H;W)T+71I=&QE)R`]/B`G4W5P<&]R="<L
M"B`@("`@("`@)W5I7U]S=7!P;W)T7U]T:71L92<@/3X@)U1E8VAN:6-A;"!S
M=7!P;W)T)RP*"B`@("`@("`@+R\@*BHJ(%1H92!S=')I;F=S(&%B;W9E(&AA
M=F4@8F5E;B!G96YE<F%T960@875T;VUA=&EC86QL>2!F<F]M($!`0T%05$E/
M3B!D:7)E8W1I=F5S+@H*"2\O(&%K<W,@<&%R=`H*"2=?7U]?9&5T86EL<R<@
M/3X@)R@E,2DG+`H))U]?7U]L:7-T7V5M<'1Y)R`]/B`G)RP*"2=?7U]?;&ES
M=%]F:7)S=%]I=&5M)R`]/B`G)3$G+`H))U]?7U]L:7-T7VET96TG(#T^("<L
M("4Q)RP*"2=?7U]?;&ES=%]L87-T7VET96TG(#T^("<L("4Q)RP*"@DG7U]S
M:&]W7VAI9&5?=&ET;&4G(#T^("=-:6YI;6EZ92]297-T;W)E)RP*"2=?7U50
M3$]!1%]%4E)?1D]235]325I%)R`]/B`B57!L;V%D960@9FEL92!E>&-E961S
M('1H92!A;&QO=V5D('-I>F4@;V8@)3$B+`H))U]?55!,3T%$7T524E])3DE?
M4TE:12<@/3X@(E5P;&]A9&5D(&9I;&4@97AC965D<R!T:&4@86QL;W=E9"!S
M:7IE(BP*"2=?7U503$]!1%]%4E)?3D]?1DE,12<@/3X@(DYO(&9I;&4@<F5C
M96EV960B+`H))U]?55!,3T%$7T524E]/2R<@/3X@(D9I;&4@<W5C8V5S<V9U
M;&QY('5P;&]A9&5D(BP*"2=?7U503$]!1%]%4E)?4$%25$E!3"<@/3X@(D9I
M;&4@=V%S('!A<G1I86QL>2!U<&QO861E9"P@<&QE87-E('1R>2!A9V%I;B(L
M"@DG7U]A9&UI;E]S97)V97)?;F]T7W)E<W!O;F0G(#T^("))9B`E,2!D;V5S
M(&YO="!R97-P;VYD+"!P;&5A<V4@86-C97-S('1H92!S97)V97(@86YD(')E
M<W1A<G0@=&AE(&%D;6EN:7-T<F%T:79E('=E8B!S97)V97(@96YG:6YE(&UA
M;G5A;&QY+B(L"@DG7U]A8V-O=6YT<R<@/3X@(D%C8V]U;G1S(BP*"2=?7V%D
M9')E<W,G(#T^(")!9&1R97-S(BP*"2=?7V%D9')E<W-E<R<@/3X@(D%D9')E
M<W-E<R(L"@DG7U]A8VQ?<F5C;W)D<R<)/3X@)T%#3"!296-O<F1S)RP*"2=?
M7V%D;6EN7W)E<&]S:71O<GDG(#T^(")!9&UI;FES=')A=&]R)W,@<F5P;W-I
M=&]R>2(L"@DG7U]A;&PG(#T^(")!3$PB+`H))U]?86QL;W=?;75L=&EP;'E?
M;&]G:6XG(#T^(")!;&QO=R!M=6QT:7!L92!S97-S:6]N<R(L"@DG7U]A;&QO
M=V5D)R`]/B`B06QL;W=E9"(L"@DG7U]A;F]N9G1P7W-T871U<R<@/3X@(D%N
M;VYY;6]U<R!&5%`B+`H))U]?87!A8VAE7V5R<F1O8W,G(#T^(")#=7-T;VT@
M17)R;W(@1&]C=6UE;G1S(BP*"2=?7V%P86-H95]R97-T87)T)R`]/B`B+BXN
M)3$@=V5B+7-E<G9E<B!I<R!B96EN9R!R97-T87)T960L('!L96%S92!W86ET
M+BXN(BP*"2=?7V%S<"<@/3X@(DUI8W)O<V]F="!!4U`B+`H))U]?87-P7V1O
M=%]N970G(#T^(")-:6-R;W-O9G0@05-0+DY%5"(L"@DG7U]A<W!?9&]T7VYE
M=%]S=7!P;W)T)R`]/B`B36EC<F]S;V9T($%34"Y.150@<W5P<&]R="(L"@DG
M7U]A<W!?=6YI>%]S=7!P;W)T)R`]/B`B07!A8VAE($%34"!S=7!P;W)T(BP*
M"2=?7V%S<%]W:6Y?<W5P<&]R="<@/3X@(DUI8W)O<V]F="!!4U`@<W5P<&]R
M="(L"@DG7U]A='1A8VAM96YT<R<@/3X@(D%T=&%C:&UE;G1S(BP*"2=?7V%T
M=&%C:&UE;G1S7VQI<W0G(#T^(")!='1A8VAM96YT<R(L"@DG7U]A=71H;W(G
M(#T^("=!=71H;W(G+`H))U]?875T;W)E<W!?;F%M95]A;')E861Y7V5X:7-T
M<R<@/3X@(D%U=&]R97-P;VYD97(@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI
M<W1S+B(L"@DG7U]A=71O<F5S<&]N9&5R)R`]/B`B075T;W)E<W!O;F1E<B`@
M(BP*"2=?7V%U=&]R97-P;VYD97)S)R`]/B`B075T;W)E<W!O;F1E<G,B+`H)
M)U]?875T;W)E<W!O;F1E<G-?;&ES="<@/3X@(D%U=&]R97-P;VYD97)S(BP*
M"2=?7V%U=&]R97-P;VYD97)?871T86-H;65N=%]F:6QE<R<@/3X@(D%U=&]R
M97-P;VYD97(@071T86-H;65N="!&:6QE<R(L"@DG7U]A=71O7W5P9&%T97-?
M;&ES="<@/3X@)T%V86EL86)L92!5<&1A=&5S)RP*"2=?7V%V86EL)R`]/B`B
M079A:6QA8FQE(BP*"2=?7V)I;F1?<W1A='5S)R`]/B`B1$Y3(%-E<G9E<B!S
M=&%T=7,B+`H))U]?8G5?:7-?;F]T7VEN<W1A;&QE9"<@/3X@(E1H:7,@<V5R
M=FEC92!I<R!N;W0@8W5R<F5N=&QY(&%V86EL86)L92P@8F5C875S92!T:&4@
M8F%C:W5P('5T:6QI=&EE<R!W97)E(&YO="!I;G-T86QL960N(BP*"2=?7V)U
M7VYO=%]S=7!P;W)T7VEN7VME>2<@/3X@(D)A8VMU<"!C87!A8FEL:71Y(&ES
M(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y+B(L"@DG7U]B>71E
M<R<@/3X@(F)Y=&5S(BP*"2=?7V-A;E]N;W1?=7-E7W)E<V5R=F5D7W=O<F1S
M)R`]/B`B66]U(&-A;FYO="!U<V4@=&AE(')E<V5R=F5D('=O<F1S+B(L"@DG
M7U]C97)T:69I8V%T92<@/3X@(D-E<G1I9FEC871E(BP*"2=?7V-E<G1I9FEC
M871E<R<@/3X@(D-E<G1I9FEC871E<R(L"@DG7U]C97)T:69I8V%T97-?;&ES
M="<@/3X@(D-E<G1I9FEC871E<R(L"@DG7U]C9VE?<W5P<&]R="<@/3X@(D-'
M22!S=7!P;W)T(BP*"2=?7V-H86YG95]D871E)R`]/B`B36]D:69I8V%T:6]N
M(&1A=&4B+`H))U]?8VAO;W-E7VQO9V\G(#T^(")#:&]O<V4@;F5W(&QO9V\@
M9FEL92(L"@DG7U]C:71Y)R`]/B`B0VET>2(L"@DG7U]C;%]N;W1?97AI<W0G
M(#T^(")#;&EE;G0@86-C;W5N="!D;V5S(&YO="!E>&ES="XB+`H))U]?8VQI
M96YT)R`]/B`B0VQI96YT(BP*"2=?7V-L:65N=%]C87)D)R`]/B`B0VQI96YT
M(&-A<F0B+`H))U]?8VQI96YT7V-O;G1A8W1?;F%M92<@/3X@(D-L:65N="!C
M;VYT86-T(&YA;64B+`H))U]?8VQI96YT7V9O<FTG(#T^(")#;&EE;G0@9F]R
M;2(L"@DG7U]C;&EE;G1?:7!?<&]O;"<@/3X@(D-L:65N="=S($E0('!O;VPB
M+`H))U]?8VQI96YT7VQI;6ET<R<@/3X@(D-L:65N="!A8V-O=6YT(&QI;6ET
M<R(L"@DG7U]C;&EE;G1?<&5R;6ES<VEO;G,G(#T^(")#;&EE;G0@<&5R;6ES
M<VEO;G,B+`H))U]?8VQI96YT7W!R969E<F5N8V5S)R`]/B`B0VQI96YT('!R
M969E<F5N8V5S(BP*"2=?7V-L:65N=%]S=&%T=7,G(#T^(")#;&EE;G0@<W1A
M='5S(BP*"2=?7V-L:65N=%]N86UE)R`]/B`B0VQI96YT)W,@;F%M92(L"@DG
M7U]C;&EE;G1?=&]T86PG(#T^(")#;&EE;G0@5&]T86PB+`H))U]?8VQI96YT
M7W=I=&A?;&]G:6Y?;F%M95]A;')E861Y7V5X:7-T<R<@/3X@(D-L:65N="!W
M:71H(&QO9VEN(&YA;64@7"(E,5PB(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]C
M;&EE;G1?9&]M=7-E<E]W:71H7VQO9VEN7V%L<F5A9'E?97AI<W1S)R`]/B`B
M3&]G:6X@;F%M92`G)3$G(&ES(&%L<F5A9'D@:6X@=7-E(&)Y('1H92!A9&UI
M;FES=')A=&]R(&]F(&1O;6%I;B`G)3$G+B(L"@DG7U]C;&EE;G1S)R`]/B`B
M0VQI96YT<R(L"@DG7U]C;&EE;G1S7V=L;V)A;%]C:&%N9V5S)R`]/B`B1W)O
M=7`@3W!E<F%T:6]N<R!O;B!#;&EE;G0@06-C;W5N=',B+`H))U]?8VQI96YT
M<U]L:7-T)R`]/B`B0VQI96YT<R(L"@DG7U]C;61?;F]T7V9O=6YD)R`]/B`B
M56YK;F]W;B!C;VUM86YD.B`E,2(L"@DG7U]C;VQD9G5S:6]N7VYO=%]S=7!P
M;W)T7VEN7VME>2<@/3X@(D-O;&1&=7-I;VX@:7,@;F]T('-U<'!O<G1E9"!B
M>2!T:&4@;&EC96YS92!K97DB+`H))U]?8V]L9&9U<VEO;E]S=&%T=7,G(#T^
M("=#;VQD1G5S:6]N('-T871U<R<L"@DG7U]C;VQD9G5S:6]N7W-U<'!O<G0G
M(#T^(")#;VQD1G5S:6]N('-U<'!O<G0B+`H))U]?8V]M;6%N9"<@/3X@)T-O
M;6UA;F0G+`H))U]?8V]M;65N=',G(#T^(")#;VUM96YT<R(L"@DG7U]C;VUP
M86YY7VYA;64G(#T^(")#;VUP86YY(&YA;64B+`H))U]?8V]M<&]N96YT7W9E
M<G-I;VXG(#T^(")#;VUP;VYE;G0@=F5R<VEO;B(L"@DG7U]A;&QO=U]Z;VYE
M7W1R86YS9F5R7VQI<W0G(#T^("=#;VUM;VX@06QL;W<@6F]N92!4<F%N<V9E
M<B!!0TPG+`H))U]?8V]M<&]N96YT7VYO=%]I;G-T86QL960G(#T^(")#;VUP
M;VYE;G0@)3$@=V%S(&YO="!I;G-T86QL960B+`H))U]?8V]N9FER;5]D96PG
M(#T^(")9;W4@;75S="!C;VYF:7)M(&1E;&5T:6]N+B(L"@DG7U]C;VYF:7)M
M7W-T;W`G(#T^(")9;W4@;75S="!C;VYF:7)M('!R;V-E<W,@<W1O<'!I;F<N
M(BP*"2=?7V-O;F9I<FU?<&%S<W=D)R`]/B`B0V]N9FER;2`E,2!087-S=V]R
M9"(L"@DG7U]C;VYF:7)M7W!A<W-W9%]S:6YG;&4G(#T^(")#;VYF:7)M(%!A
M<W-W;W)D(BP*"2=?7V-O;F9I<FU?<F5M;W9A;"<@/3X@(D-O;F9I<FT@<F5M
M;W9A;"(L"@DG7U]C;VYH96QP)R`]/B`B0V]N=&5X="!H96QP('1I<"(L"@DG
M7U]C;VYT86-T7VYA;64G(#T^(")#;VYT86-T(&YA;64B+`H))U]?8V]U;G1R
M>2<@/3X@(D-O=6YT<GDB+`H))U]?8V]U;G1R:65S)R`]/B`G0V]U;G1R>2<L
M"@DG7U]C;W5N=')Y7W5N:VYO=VXG(#T^("=5;F%B;&4@=&\@<F5C;V=N:7IE
M('1H92!C;W5N=')Y('-U8F-O9&4N)RP*"2=?7V-R96%T95]D;VUA:6XG(#T^
M("=#<F5A=&4@;F5W(&1O;6%I;B<L"@DG7U]C<GEP=&5D)R`]/B`G96YC<GEP
M=&5D)RP*"2=?7V-P7V%C8V5S<R<@/3X@(D-O;G1R;VP@<&%N96P@86-C97-S
M(BP*"2=?7V-P7W5S97(G(#T^(")#;VYT<F]L(%!A;F5L(%5S97(B+`H))U]?
M8W)E871E)R`]/B`B0W)E871E(BP*"2=?7V-R96%T95]C;&EE;G1?=&5M<&QA
M=&5?=VET:&]U=%]T96UP;&%T92<@/3X@(D-R96%T92!C;&EE;G0@=VET:&]U
M="!T96UP;&%T92(L"@DG7U]C<F5A=&5?9&]M86EN7V9O<B<@/3X@(D-R96%T
M92!N97<@9&]M86EN(&9O<B`\8CXE,3PO8CXB+`H))U]?8W)E871E7V1O;6%I
M;E]T96UP;&%T95]W:71H;W5T7W1E;7!L871E)R`]/B`B0W)E871E(&1O;6%I
M;B!W:71H;W5T('1E;7!L871E(BP*"2=?7V-R96%T:6]N7V1A=&4G(#T^(")#
M<F5A=&EO;B!D871E(BP*"2=?7V-R;VYT86)?=6YI>"<@/3X@(D-R;VYT86(B
M+`H))U]?8W)O;G1A8E]W:6XG(#T^(")38VAE9'5L97(B+`H))U]?8W1?8VUD
M)R`]/B`B0V]M;6%N9"(L"@DG7U]C=%]D;VTG(#T^(")$87D@;V8@=&AE($UO
M;G1H(BP*"2=?7V-T7V1O;5\G(#T^(")$32(L"@DG7U]C=%]D;W<G(#T^(")$
M87D@;V8@=&AE(%=E96LB+`H))U]?8W1?9&]W7R<@/3X@(D17(BP*"2=?7V-T
M7V5N86)L960G(#T^(")3=&%T=7,B+`H))U]?8W1?96YA8FQE9%\G(#T^(")3
M(BP*"2=?7V-T7VAO=7(G(#T^(")(;W5R(BP*"2=?7V-T7VAO=7)?)R`]/B`B
M2"(L"@DG7U]C=%]M:6YU=&4G(#T^(")-:6YU=&4B+`H))U]?8W1?;6EN=71E
M7R<@/3X@(DUI;B(L"@DG7U]C=%]M;VYT:"<@/3X@(DUO;G1H(BP*"2=?7V-T
M7VUO;G1H7R<@/3X@(DTB+`H))U]?8W1?;6]N=&A?96YT97)?861V)R`]/B`B
M16YT97(@=&AE('9A;'5E(BP*"2=?7V-T7VAI;G1?=6YI>%]F;W)M870G(#T^
M(")I;B!53DE8(&-R;VYT86(@9F]R;6%T(&4N9RXB+`H))U]?8W1?;6]N=&A?
M96YT97(G(#T^(")396QE8W0@=&AE(&UO;G1H(BP*"2=?7V-T7V1O=U]E;G1E
M<E]A9'8G(#T^(")%;G1E<B!T:&4@=F%L=64B+`H))U]?8W1?9&]W7V5N=&5R
M)R`]/B`B4V5L96-T('1H92!D87D@;V8@=V5E:R(L"@DG7U]C=%]M;VYT:%]J
M86XG(#T^("=*86YU87)Y)RP*"2=?7V-T7VUO;G1H7V9E8B<@/3X@)T9E8G)U
M87)Y)RP*"2=?7V-T7VUO;G1H7VUA<B<@/3X@)TUA<F-H)RP*"2=?7V-T7VUO
M;G1H7V%P<B<@/3X@)T%P<FEL)RP*"2=?7V-T7VUO;G1H7VUA>2<@/3X@)TUA
M>2<L"@DG7U]C=%]M;VYT:%]J=6XG(#T^("=*=6YE)RP*"2=?7V-T7VUO;G1H
M7VIU;"<@/3X@)TIU;'DG+`H))U]?8W1?;6]N=&A?875G)R`]/B`G075G=7-T
M)RP*"2=?7V-T7VUO;G1H7W-E<"<@/3X@)U-E<'1E;6)E<B<L"@DG7U]C=%]M
M;VYT:%]O8W0G(#T^("=/8W1O8F5R)RP*"2=?7V-T7VUO;G1H7VYO=B<@/3X@
M)TYO=F5M8F5R)RP*"2=?7V-T7VUO;G1H7V1E8R<@/3X@)T1E8V5M8F5R)RP*
M"2=?7V-T7V1O=U]S=6XG(#T^("=3=6YD87DG+`H))U]?8W1?9&]W7VUO;B<@
M/3X@)TUO;F1A>2<L"@DG7U]C=%]D;W=?='5E)R`]/B`G5'5E<V1A>2<L"@DG
M7U]C=%]D;W=?=V5D)R`]/B`G5V5D;F5S9&%Y)RP*"2=?7V-T7V1O=U]T:'4G
M(#T^("=4:'5R<V1A>2<L"@DG7U]C=%]D;W=?9G)I)R`]/B`G1G)I9&%Y)RP*
M"2=?7V-T7V1O=U]S870G(#T^("=3871U<F1A>2<L"@DG7U]C=7-T;VU?8G5T
M=&]N)R`]/B`B0W5S=&]M(&)U='1O;B(L"@DG7U]C=7-T;VU?8G5T=&]N<R<@
M/3X@(D-U<W1O;2!B=71T;VYS(BP*"2=?7V-U<W1O;5]B=71T;VYS7VQI<W0G
M(#T^(")#=7-T;VT@8G5T=&]N<R(L"@DG7U]D86EL>2<@/3X@(D1A:6QY(BP*
M"2=?7V1A;&EA<U]N;W1?97AI<W0G(#T^("=$;VUA:6X@86QI87,@9&]E<R!N
M;W0@97AI<W0N)RP*"2=?7V1A=&%B87-E7VYO=%]A8W1I=F%T960G(#T^("(E
M,2!W87,@;F]T(&%C=&EV871E9"!I;B!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T
M:6]N('-E8W1I;VXN(BP*"2=?7V1A=&%B87-E7VYO=%]I;G-T86QL960G(#T^
M(")$871A8F%S92`E,2!I<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]D871A8F%S
M95]N;W1?<G5N)R`]/B`B1&%T86)A<V4@)3$@:7,@;F]T(')U;FYI;F<N(BP*
M"2=?7V1A=&%B87-E<R<@/3X@(D1A=&%B87-E<R(L"@DG7U]D871A8F%S97-?
M;&ES="<@/3X@(D1A=&%B87-E<R(L"@DG7U]D871A8F%S95]T>7!E7VYO=%]S
M=7!P;W)T961?8GE?:V5Y)R`]/B`G5&AI<R!T>7!E(&]F(&1A=&%B87-E(&ES
M(&YO="!S=7!P;W)T960@8GD@>6]U<B!L:6-E;G-E(&ME>2<L"@DG7U]D871E
M7VEM;65D:6%T96QY)R`]/B`B=&]D87DB+`H))U]?9&%T95]N979E<B<@/3X@
M(FYE=F5R(BP*"2=?7V1A>2AS*2<@/3X@(D1A>2AS*2(L"@DG7U]D87DP)R`]
M/B`B4W5N(BP*"2=?7V1A>3$G(#T^(")-;VXB+`H))U]?9&%Y,B<@/3X@(E1U
M97,B+`H))U]?9&%Y,R<@/3X@(E=E9"(L"@DG7U]D87DT)R`]/B`B5&AU<G,B
M+`H))U]?9&%Y-2<@/3X@(D9R:2(L"@DG7U]D87DV)R`]/B`B4V%T(BP*"2=?
M7V1A>7,G(#T^("(E,2!D87DH<RDB+`H))U]?1&%Y<R<@/3X@(D1A>7,B+`H)
M)U]?9&)?861M:6Y?;&]G:6Y?96UP='DG(#T^(")9;W4@:&%V92!E;G1E<F5D
M(&%N(&5M<'1Y(&QO9VEN+"!D:7-A8FQI;F<@8V]N=')O;"!O=F5R("4Q(&EN
M('1H92!I;G1E<F9A8V4N($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=?
M7V1B7V%L<F5A9'E?97AI<W0G(#T^(")$871A8F%S92`E,2!A;')E861Y(&5X
M:7-T<RXB+`H))U]?9&)?96YG:6YE)R`]/B`B1&%T86)A<V4@16YG:6YE(BP)
M+R\@:6YD:7)E8W0*"2=?7V1B7W1Y<&4G(#T^(")$871A8F%S92!T>7!E(BP*
M"2=?7V1B7W5S97(G(#T^(")$871A8F%S92!U<V5R(BP*"2=?7V1B7W5S97)S
M)R`]/B`B1&%T86)A<V4@=7-E<G,B+`H))U]?9&)?<V5R=F5R)R`]/B`G1&%T
M86)A<V4@<V5R=F5R)RP*"2=?7V1E8W)E;65N="<@/3X@(D1E8W)E87-E("@M
M*2(L"2\O(&EN9&ER96-T"@DG7U]D969?9&]M86EN)R`]/B`B1&5F875L="!D
M;VUA:6XB+`H))U]?9&5F875L=%]F;W)?;7ES<6PG(#T^("=D969A=6QT(&9O
M<B!->5-13"<L"@DG7U]D969A=6QT7V9O<E]P;W-T9W)E<W%L)R`]/B`G9&5F
M875L="!F;W(@4&]S=&=R95-13"<L"@DG7U]D96QE=&4G(#T^(")$96QE=&4B
M+`H))U]?9&5M;R<@/3X@(E1H:7,@9G5N8W1I;VX@:7,@9&ES86)L960@:6X@
M9&5M;R!V97)S:6]N+B(L"@DG7U]D:7)E8W1O<GDG(#T^(")$:7)E8W1O<GDB
M+`H))U]?9&ES86)L95]L;V-K7W-C<F5E;B<@/3X@)U!R979E;G0@=7-E<G,@
M9G)O;2!W;W)K:6YG('=I=&@@=&AE(&-O;G1R;VP@<&%N96P@=6YT:6P@:6YT
M97)F86-E('-C<F5E;G,@87)E(&-O;7!L971E;'D@;&]A9&5D+B<L"@DG7U]D
M:7-M:7-S7VYE=W,_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O
M;7!L971E;'D@:&ED92!T:&4@;F5W<R!B;&]C:S]<;EQN5&AE(&YE=W,@=VEL
M;"!N;W0@8F4@<VAO=VX@86YY;6]R92!U;G1I;"!T:&5R92!I<R!S;VUE(&UO
M<F4@;F5W<R!S;VUE9&%Y+B!)9B!Y;W4@=V]U;&0@<F%T:&5R(&QI:V4@=&\@
M<V5E('1H97-E(&YE=W,@86=A:6X@<V]M971I;64L('EO=2!C86X@;6EN:6UI
M>F4@=&AE(&)L;V-K(&EN<W1E860@8GD@8VQI8VMI;F<@;VX@:71S('1I=&QE
M(&)A<BXB+`H))U]?9&5F875L=%]B86-K=7!?8V]M;65N="<@/3X@(B4Q(&)A
M8VMU<"Y<;D-R96%T:6]N(&1A=&4Z("4R(BP*"2=?7V1E<V-R:7!T:6]N)R`]
M/B`B1&5S8W)I<'1I;VXB+`H))U]?9&ES86)L960G(#T^(")D:7-A8FQE9"(L
M"@DG7U]D:7-K7W-P86-E7VQI;6ET)R`]/B`B1&ES:R!S<&%C92!L:6UI="(L
M"@DG7U]D:7-K7W5S86=E7V)Y)R`]/B`B1&ES:R!S<&%C92!U<V5D(&)Y("4Q
M(BP*"2=?7V1N<R<@/3X@(D1.4R(L"@DG7U]D;G-?<F5C;W)D7V%L<F5A9'E?
M97AI<W0G(#T^(")$3E,@<F5C;W)D(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]D
M;G-?;6%S=&5R7W-H;W5L9%]B95]R96UO=&4G(#T^(")9;W4@<VAO=6QD(&AA
M=F4@='=O(&1I9F9E<F5N="!A=71H;W)I=&%T:79E(&YA;64@<V5R=F5R<R!O
M;B!S97!A<F%T92!H;W-T<RXB+`H))U]?9&YS7W)E8V]R9%]N;W1?97AI<W0G
M(#T^(")$3E,@<F5C;W)D(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]D;G-?<V5R
M=F5R)R`]/B`B1$Y3('-E<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]D;VU?:61?
M:7-?=6YD969I;F5D)R`]/B`B1&]M86EN(&ED(&ES('5N9&5F:6YE9"XB+`H)
M)U]?9&]M7VYA;64G(#T^(")$;VUA:6X@;F%M92(L"@DG7U]D;VU?;F%M95]I
M<U]I;G9A;&ED)R`]/B`B1&]M86EN(&YA;64@:7,@:6YV86QI9"X@4&QE87-E
M(&UA:V4@<W5R92!Y;W5R(&1O;6%I;B!N86UE(&-O;7!R:7-E<R!O;FQY(&%L
M<&AA;G5M97)I8RP@9&]T(&%N9"!H>7!H96X@<WEM8F]L<RP@86YD(&ES(&YO
M="!G<F5A=&5R('1H86X@,C4U('-Y;6)O;',@:6X@;&5N9W1H+B!%86-H('!A
M<G0@;V8@=&AE(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U;&0@;F]T
M(&5X8V5E9"`V,R!S>6UB;VQS+B(L"@DG7U]D;VU?;F]T7V5X:7-T)R`]/B`B
M1&]M86EN(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]D;VUA:6XG(#T^(")$;VUA
M:6X@)3$B+`H))U]?9&]M86EN7V9O<FTG(#T^(")$;VUA:6X@9F]R;2(L"@DG
M7U]D;VUA:6Y?:7-?='5R;F5D7V]F9E]F;W)?8F%C:W5P)R`]/B`B1&]M86EN
M("4Q(&ES('1E;7!O<F%R:6QY('1U<FYE9"!O9F8@9F]R(&)A8VMU<"]R97-T
M;W)I;F<@86YD(&ES(&YO="!C=7)R96YT;'D@879A:6QA8FQE+B(L"@DG7U]D
M;VUA:6Y?;&EM:71S)R`]/B`B1&]M86EN(&QI;6ET<R(L"@DG7U]D;VUA:6Y?
M;F%M92<@/3X@(D1O;6%I;B!N86UE(BP*"2=?7VUA:6Q?;F%M95]I;E]!4T-)
M25]F;W)M)R`]/B`B36%I;"!N86UE(&EN($%30TE)(&9O<FUA="(L"@DG7U]M
M97-S86=E7V5R<F]R)R`]/B`G17)R;W(G+`H))U]?;65S<V%G95]W87)N:6YG
M)R`]/B`G5V%R;FEN9R<L"@DG7U]M97-S86=E7VEN9F\G(#T^("=);F9O<FUA
M=&EO;B<L"@DG7U]D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]/B`B1&]M
M86EN(&YA;64@:6X@05-#24D@9F]R;6%T(BP*"2=?7V1O;6%I;E]R97!O<VET
M;W)Y)R`]/B`B4F5P;W-I=&]R>2!O9B!D;VUA:6X@)3$B+`H))U]?9&]M86EN
M7W-T871U<R<@/3X@(D1O;6%I;B!S=&%T=7,B+`H))U]?9&]M86EN7V1N<R<@
M/3X@)T1O;6%I;B!$3E,@>F]N92<L"@DG7U]D;VUA:6Y?=&]T86PG(#T^(")$
M;VUA:6X@5&]T86PB+`H))U]?9&]M86EN7W5S97(G(#T^(")$;VUA:6X@861M
M:6YI<W1R871O<B(L"@DG7U]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG7U]D
M;VUA:6YS7V=L;V)A;%]C:&%N9V5S)R`]/B`B1W)O=7`@3W!E<F%T:6]N<R!O
M;B!$;VUA:6YS(BP*"2=?7VUA:6QN86UE<U]G;&]B86Q?8VAA;F=E<R<@/3X@
M(D=R;W5P($]P97)A=&EO;G,@;VX@36%I;"!.86UE<R(L"@DG7U]M:6=R871I
M;VY?;6%N86=E<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R)RP*"2=?7V)A8VMU
M<%]M86YA9V5R)R`]/B`G0F%C:W5P($UA;F%G97(G+`H))U]?9&]M86EN<U]L
M:7-T)R`]/B`B1&]M86EN<R(L"@DG7U]D;VUA:6Y?<F5S;VQV97-?=&]?86YO
M=&AE<E]I<"<@/3X@(E1H92!D;VUA:6X@<F5S;VQV97,@=&\@86YO=&AE<B!)
M4"!A9&1R97-S("@E,2DN(%!L96%S92!C;W)R96-T($1.4R!S971T:6YG<RXB
M+`H))U]?9&]U8FQE7W=W=U]W87)N:6YG)R`]/B`B5&AE(&1O;6%I;B!N86UE
M(&)E9VEN<R!W:71H('=W=RP@86QT:&]U9V@@=&AE(%=75R!P<F5F:7@@:7,@
M96YA8FQE9"Y<;E!R;V-E960@86YY=V%Y/R(L"@DG7U]D<VUA:6PG(#T^(")-
M86EL('-E<G9I8V4B+`H))U]?9'-M86EL;&ES="<@/3X@(DUA:6QI;F<@;&ES
M="!S97)V:6-E(BP*"2=?7V1S<E]D8B<@/3X@(D1"(BP*"2=?7V1S<E]D;F%M
M92<@/3X@(D1O;6%I;B!N86UE(BP*"2=?7V1S<E]D=2<@/3X@(D15(BP*"2=?
M7V1S<E]M82<@/3X@(DU!(BP*"2=?7V1S<E]M9R<@/3X@(DU'(BP*"2=?7V1S
M<E]M;"<@/3X@(DU,(BP*"2=?7V1S<E]M;B<@/3X@(DU";W@B+`H))U]?9'-R
M7VUR)R`]/B`B35(B+`H))U]?9'-R7W!N86UE)R`]/B`B0VQI96YT)W,@;F%M
M92(L"@DG7U]D<W)?<V0G(#T^(")31"(L"@DG7U]D<W)?='(G(#T^(")44B(L
M"@DG7U]D<W)?=W4G(#T^(")752(L"@DG7U]D<W1O;6-A="<@/3X@(E1O;6-A
M="!S97)V:6-E(BP*"2=?7V1U;7!?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA
M;64B+`H))U]?9'5M<'-?=&]T7W-I>F4G(#T^(")4;W1A;"!S:7IE(&]F(&)A
M8VMU<"!F:6QE<R(L"@DG7U]E;6%I;"<@/3X@(D4M;6%I;"(L"@DG7U]E;6%I
M;%]A9&1R7VES7VEN=F%L:60G(#T^(")%+6UA:6P@861D<F5S<R!I<R!I;G9A
M;&ED+B(L"@DG7U]E;F%B;&5D)R`]/B`B96YA8FQE9"(L"@DG7U]E;G1E<E]C
M97)T7W1E>'0G(#T^(")%;G1E<B!C97)T:69I8V%T92!T97AT(BP*"2=?7V5N
M=&5R7VQO9V]?=7)L)R`]/B`B16YT97(@;F5W(%523"!F;W(@;&]G;R(L"@DG
M7U]E;G1E<E]S:7IE)R`]/B`B16YT97(@<VEZ92(L"@DG7U]E=F5N="<@/3X@
M)T5V96YT)RP*"2=?7V5V96YT7VAA;F1L97(G(#T^("=%=F5N="!H86YD;&5R
M)RP*"2=?7V5V96YT7VAA;F1L97)S)R`]/B`G179E;G0@:&%N9&QE<G,G+`H)
M)U]?97AC;'5S:79E)R`]/B`B17AC;'5S:79E(BP*"2=?7V5X<&ER871I;VY?
M9&%T92<@/3X@(D5X<&ER871I;VX@9&%T92(L"@DG7U]F87@G(#T^(")&87@B
M+`H))U]?9FEL92<@/3X@(D9I;&4B+`H))U]?9FEL95]I<U]E;7!T>2<@/3X@
M(D9I;&4@:7,@96UP='DN(BP*"2=?7V9I;&5?;F%M92<@/3X@(D9I;&4@;F%M
M92(L"@DG7U]F:6QE7W1Y<&4G(#T^("=&:6QE('1Y<&4G+`H))U]?9FEL96UA
M;F%G97(G(#T^(")&:6QE($UA;F%G97(B+`H))U]?9FEL97!A=&A?:7-?96UP
M='DG(#T^(")0871H('1O(&9I;&4@:7,@96UP='DB+`H))U]?9FEL97-?;&ES
M="<@/3X@(D9I;&5S(BP*"2=?7V9P7W-S;%]U;FEX7W-U<'!O<G0G(#T^(")&
M<F]N=%!A9V4@;W9E<B!34TP@<W5P<&]R="(L"@DG7U]F<%]S<VQ?=VEN7W-U
M<'!O<G0G(#T^(")-:6-R;W-O9G0@1G)O;G1086=E(&]V97(@4U-,('-U<'!O
M<G0B+`H))U]?9G!?=6YI>%]A=71H)R`]/B`B1G)O;G1086=E(&%U=&AO<FEN
M9R(L"@DG7U]F<%]U;FEX7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@<W5P<&]R
M="(L"@DG7U]F<%]W:6Y?875T:"<@/3X@(DUI8W)O<V]F="!&<F]N=%!A9V4@
M875T:&]R:6YG(BP*"2=?7V9P7W=I;E]S=7!P;W)T)R`]/B`B36EC<F]S;V9T
M($9R;VYT4&%G92!S=7!P;W)T(BP*"2=?7V9R;VYT<&%G92<@/3X@(DUI8W)O
M<V]F="!&<F]N=%!A9V4B+`H))U]?9G1P)R`]/B`B1E10(BP)+R\@*VEN9&ER
M96-T"@DG7U]F='!?<V5T=&EN9W,G(#T^(")&5%`@<V5T=&EN9W,B+`H))U]?
M9G1P7W-E<G8G(#T^(")&5%`@<V5R=F5R(BP)+R\@:6YD:7)E8W0*"2=?7V9T
M<%]S97)V97)?<&%R86UE=&5R<U]A<F5?96UP='DG(#T^(")9;W4@<VAO=6QD
M('-E="!T:&4@1E10(&%C8V]U;G0@<')O<&5R=&EE<R!F:7)S="$B+`H))U]?
M9G1P7W-T871U<R<@/3X@(D944"!S97)V97(@<W1A='5S(BP*"2=?7V9U;&Q?
M9&%Y,"<@/3X@(E-U;F1A>2(L"@DG7U]F=6QL7V1A>3$G(#T^(")-;VYD87DB
M+`H))U]?9G5L;%]D87DR)R`]/B`B5'5E<V1A>2(L"@DG7U]F=6QL7V1A>3,G
M(#T^(")7961N97-D87DB+`H))U]?9G5L;%]D87DT)R`]/B`B5&AU<G-D87DB
M+`H))U]?9G5L;%]D87DU)R`]/B`B1G)I9&%Y(BP*"2=?7V9U;&Q?9&%Y-B<@
M/3X@(E-A='5R9&%Y(BP*"2=?7V9U;&Q?;6]N=&@Q)R`]/B`B2F%N=6%R>2(L
M"@DG7U]F=6QL7VUO;G1H,3`G(#T^(")/8W1O8F5R(BP*"2=?7V9U;&Q?;6]N
M=&@Q,2<@/3X@(DYO=F5M8F5R(BP*"2=?7V9U;&Q?;6]N=&@Q,B<@/3X@(D1E
M8V5M8F5R(BP*"2=?7V9U;&Q?;6]N=&@R)R`]/B`B1F5B<G5A<GDB+`H))U]?
M9G5L;%]M;VYT:#,G(#T^(")-87)C:"(L"@DG7U]F=6QL7VUO;G1H-"<@/3X@
M(D%P<FEL(BP*"2=?7V9U;&Q?;6]N=&@U)R`]/B`B36%Y(BP*"2=?7V9U;&Q?
M;6]N=&@V)R`]/B`B2G5N92(L"@DG7U]F=6QL7VUO;G1H-R<@/3X@(DIU;'DB
M+`H))U]?9G5L;%]M;VYT:#@G(#T^(")!=6=U<W0B+`H))U]?9G5L;%]M;VYT
M:#DG(#T^(")397!T96UB97(B+`H))U]?9V5N97)A;"<@/3X@(D=E;F5R86PB
M+`H))U]?9VEG82<@/3X@(D<B+`H))U]?9W)O=7`G(#T^(")'<F]U<"(L"@DG
M7U]H)R`]/B`B2"(L"@DG7U]H87)D7V1I<VM?<75O=&$G(#T^(")(87)D(&1I
M<VL@<75O=&$B+`H))U]?:&%R9%]D:7-K7W%U;W1A7VYO=%]S=7!P;W)T960G
M(#T^(")H87)D(&1I<VL@<75O=&$@:7,@;F]T('-U<'!O<G1E9"(L"@DG7U]H
M96%D97)?=&5X=%]I<U]I;G9A;&ED)R`]/B`B2&5A9&5R('1E>'0@:7,@:6YV
M86QI9"XB+`H))U]?:&5L<"<@/3X@(DAE;'`B+`H))U]?:&5L<%]T;W!I8U]N
M;W1?9F]U;F0G(#T^("=4:&4@:&5L<"!T;W!I8R!Y;W4@<F5Q=65S=&5D("@E
M,2D@9&]E<R!N;W0@97AI<W0N)RP*"2=?7VAO;64G(#T^(")(;VUE(BP*"2=?
M7VAO<W1I;F<G(#T^(")(;W-T:6YG(BP*"2=?7VAO<W1I;F=?:7!?9&YS7VEP
M7VYO=%]E<75I=B<@/3X@(DYO;F4@;V8@25`@861D<F5S<V5S('-P96-I9FEE
M9"!I;B!!($1.4R!R96-O<F1S(&UA=&-H('1H92!)4"!A9&1R97-S('5S960@
M9F]R(&AO<W1I;F<B+`H))U]?:&]S=&EN9U]S8W)I<'1I;F<G(#T^(")(;W-T
M:6YG('-C<FEP=&EN9R!S=7!P;W)T(BP*"2=?7VAO<W1I;F=?<V5T=7!?<&%G
M95]T:71L92<@/3X@(E!H>7-I8V%L(&AO<W1I;F<@<V5T=7`@<&%G92!F;W(@
M9&]M86EN("4Q(BP*"2=?7VAO<W1I;F=?=&ET;&4G(#T^(")(;W-T:6YG("@E
M,2DB+`H))U]?:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R!T>7!E(BP*"2=?
M7VAO<W1N86UE)R`]/B`B2&]S=&YA;64B+`H))U]?:&]S=&YA;65?:7-?96UP
M='DG(#T^(")(;W-T;F%M92!I<R!E;7!T>2XB+`H))U]?2&]U<G,G(#T^("=(
M;W5R<R<L"@DG7U]H<W1?='EP95]I;F-O<G)E8W0G(#T^(")(;W-T:6YG('1Y
M<&4@:7,@:6YC;W)R96-T+B(L"@DG7U]H='1P)R`]/B`B2%144"(L"2\O:6YD
M:7)E8W0*"2=?7VAT>7!E)R`]/B`B2"(L"@DG7U]I9&QE7W1I;64G(#T^("))
M9&QE('1I;64B+`H))U]?:69A8V4G(#T^("));G1E<F9A8V4B+`H))U]?:6UA
M9V4G(#T^("));6%G92(L"@DG7U]I;6%P7W-T871U<R<@/3X@(DE-05`@4V5R
M=F5R('-T871U<R(L"@DG7U]I;B<@/3X@(DEN(BP*"2=?7VEN7R4G(#T^(")I
M;B`E(BP*"2=?7VEN8V]R<F5C=%]D871A8F%S97-?;&]G:6Y?<&%S<R<@/3X@
M(EEO=2!S<&5C:69I960@:6YC;W)R96-T(&-R961E;G1I86QS(&9O<B!A8V-E
M<W,@=&\@4&]S=&=R95-13"XB+`H))U]?:6YC;W)R96-T7VEP7V]R7VYE='=O
M<FM?861D<F5S<R<@/3X@)TEN8V]R<F5C="!)4"!A9&1R97-S(&]R(&YE='=O
M<FLN)RP*"2=?7VEN8W)E;65N="<@/3X@(DEN8W)E87-E("@K*2(L"2\O(&EN
M9&ER96-T"@DG7U]I;F9O)R`]/B`G26YF;R<L"@DG7U]I;G-T86QL)R`]/B`B
M26YS=&%L;"(L"@DG7U]I;G-T86QL7W!R969I>"<@/3X@(DEN<W1A;&P@<')E
M9FEX(BP*"2=?7VEN=&5R9F%C95]S:VEN)R`]/B`B26YT97)F86-E('-K:6XB
M+`H))U]?:6YV86QI9%]C97)T7VED)R`]/B`B26YV86QI9"!C97)T:69I8V%T
M92!I9"(L"@DG7U]I;G9A;&ED7V-O;G1E>'0G(#T^("));G9A;&ED(&-O;G1E
M>'0Z("4Q(BP*"2=?7VEN=F%L:61?9&)?=7-R7VYA;64G(#T^(")$871A8F%S
M92!U<V5R(&YA;64@:7,@:6YV86QI9"XB+`H))U]?:6YV86QI9%]D:7)?;F%M
M92<@/3X@(D1I<F5C=&]R>2!N86UE(&ES(&EN=F%L:60B+`H))U]?:6YV86QI
M9%]D;VU?;F%M92<@/3X@(D1O;6%I;B!N86UE(&ES(&EN=F%L:60N(BP*"2=?
M7VEN=F%L:61?9FEL96YA;64G(#T^("));G9A;&ED(&9I;&5N86UE+B!$;R!N
M;W0@=7-E('-I;F=L92!Q=6]T97,@86YD+V]R(%PB+BXO7"(@8V]M8FEN871I
M;VXN(BP*"2=?7VEN=F%L:61?:60G(#T^("));G9A;&ED(&ED96YT:69I97(N
M(BP*"2=?7VEN=F%L:61?;6%X7V)U='1O;E]L96XG(#T^("));F%P<')O<')I
M871E('9A;'5E(&9O<B!N=6UB97(@;V8@8VAA<F%C=&5R<RX@66]U('-H;W5L
M9"!U<V4@;VYL>2!D:6=I=',N(BP*"2=?7VEN=F%L:61?;6%X7VQE='1E<E]S
M:7IE)R`]/B`B36%X:6UU;2!L971T97(@<VEZ92!I<R!I;G9A;&ED+B(L"@DG
M7U]I;G9A;&ED7W!D:7)?;F%M92<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<GD@
M;F%M92!I<R!I;G9A;&ED+B(L"@DG7U]I;G9A;&ED7W)E<W1A<G1?87!A8VAE
M7VEN=&5R=F%L)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86P@:7,@:6YV
M86QI9"(L"@DG7U]I;G9A;&ED7W1M<&Q?;F%M92<@/3X@(E1E;7!L871E(&YA
M;64@:7,@:6YV86QI9"XB+`H))U]?:6YV86QI9%]V86QU92<@/3X@(DEM<')O
M<&5R('9A;'5E+B(L"@DG7U]I<%]A9&1R)R`]/B`B25`@061D<F5S<R(L"@DG
M7U]I<%]A9&1R97-S7V%N9%]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B
M;F5T($UA<VLB+`H))U]?:7!?;6%S:R<@/3X@(E-U8FYE="!-87-K(BP*"2=?
M7VEP7V%L:6%S7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B;F5T($UA
M<VLB+`H))VEP7V%L:6%S7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B
M;F5T($UA<VLB+`H))U]?:7!?861D<E]F;W)M)R`]/B`B25`@061D<F5S<R!F
M;W)M(BP*"2=?7VEP7V%D9')?:7-?:6YV86QI9"<@/3X@(DE0(&%D9')E<W,@
M:7,@:6YV86QI9"XB+`H))U]?:7!?861D<E]L:7-T)R`]/B`B25`@061D<F5S
M<V5S(BP*"2=?7VEP7V%D9')E<W-?9&]E<U]N;W1?97AI<W0G(#T^("))4"!A
M9&1R97-S(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]I<%]A9&1R97-S97,G(#T^
M("))4"!!9&1R97-S97,B+`H))U]?:7!?861D<F5S<U]A;F1?;6%S:U]H:6YT
M)R`]/B`G12YG+B`E,2<L"@DG7U]I<U]O=VYE<B<@/3X@(D\B+`H))U]?:F%V
M85]E;F=I;F4G(#T^(")*879A(BP)+R\@:6YD:7)E8W0*"2=?7VID:R<@/3X@
M(DI$2R(L"@DG7U]K8B<@/3X@(DM"(BP*"2=?7VMB<',G(#T^(")+0B]S(BP*
M"2=?7VMB>71E<R<@/3X@(FMI;&]B>71E<R(L"@DG7U]K97E?;&EM:71S7V5X
M8V5E9&EN9R<@/3X@(E1H:7,@86-T:6]N(&5X8V5E9',@=&AE(&QI;6ET<R!D
M969I;F5D(&)Y('EO=7(@<V]F='=A<F4@;&EC96YS92X@268@>6]U(')E8V5I
M=F5D('1H:7,@;65S<V%G92!Y;W4@;6%Y(&-O;G1A8W0@>6]U<B!P<F]V:61E
M<B!O<B!T:&4@;6%N=69A8W1U<F5R('1O(&-L87)I9GD@;W(@97AT96YD('1H
M92!L:6UI=',@;V8@=&AI<R!L:6-E;G-E+B(L"@DG7U]K:6QO)R`]/B`B2R(L
M"@DG7U]K97EW;W)D<R<@/3X@)TME>7=O<F1S)RP*"2=?7VQA;F=?=6YK;F]W
M;B<@/3X@)U5N86)L92!T;R!R96-O9VYI>F4@=&AE(&QA;F=U86=E+B<L"@DG
M7U]L86YG=6%G97,G(#T^("=,86YG=6%G92<L"@DG7U]L96%R;E]M;W)E)R`]
M/B`G3&5A<FX@;6]R92<L"@DG7U]L;V-A;&5S)R`]/B`B3&%N9W5A9V4@<&%C
M:W,B+`H))U]?;&EM:70G(#T^("),:6UI="(L"@DG7U]L:6UI=',G(#T^("),
M:6UI=',B+`H))U]?;&EN:U]U<FQ?:7-?:6YV86QI9"<@/3X@(DQO9V\@55),
M(&ES(&EN=F%L:60N(BP*"2=?7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L
M"@DG7U]L:71E<F%L7V)Y=&5S)R`]/B`B0B(L"@DG7U]P<F]C97-S:6YG)R`]
M/B`B4&QE87-E('=A:70N/&)R/DQO861I;F<@+BXN(BP*"2=?7VQO8V%L92<@
M/3X@(DEN=&5R9F%C92!L86YG=6%G92(L"@DG7U]L;V-A;&5?:7-?;F]T7V1E
M9FEN960G(#T^("));G1E<F9A8V4@;&%N9W5A9V4@:7,@;F]T(&1E9FEN960N
M(BP*"2=?7VQO8V%L7W-E<G9E<E]M>7-Q;"<@/3X@)TQO8V%L($UY4U%,('-E
M<G9E<B<L"@DG7U]L;V-A;%]S97)V97)?<&]S=&=R97-Q;"<@/3X@)TQO8V%L
M(%!O<W1G<F5344P@<V5R=F5R)RP*"2=?7VQO9U]F:6QE<R<@/3X@(DQO9R!F
M:6QE<R(L"@DG7U]C;VYF:6=?9FEL97,G(#T^("=#;VYF:6<@9FEL97,G+`H)
M)U]?8VAR;V]T7V9I;&5S)R`]/B`G0VAR;V]T960@96YV:7)O;FUE;G0G+`H)
M)U]?;&]G:6XG(#T^("(E,2!,;V=I;B(L"@DG7U]L;V=I;C$G(#T^("),;V=I
M;B(L"@DG7U]L;V=I;E]D:7-A8FQE9"<@/3X@(DQO9VEN(&1I<V%B;&5D(BP*
M"2=?7VQO9VEN7V5N86)L960G(#T^("),;V=I;B!E;F%B;&5D(BP*"2=?7VQO
M9VEN7VEN8V]R<F5C="<@/3X@(DQO9VEN(&ES(&EN8V]R<F5C="XB+`H))U]?
M;&]G:6Y?;F%M92<@/3X@(B4Q(&QO9VEN(&YA;64B+`H))U]?;&]G:6Y?;F%M
M95]I<U]I;G9A;&ED)R`]/B`B)3$@;&]G:6X@;F%M92!I<R!I;G9A;&ED+B(L
M"@DG7U]L;V=O;E]T:6UE)R`]/B`B3&]G;VX@=&EM92(L"@DG7U]L;V=O=70G
M(#T^("),;V<@;W5T(BP*"2=?7VUA)R`]/B`B36%I;"!A;&EA<V5S(BP*"2=?
M7VUA:6PG(#T^(")-86EL(BP*"2=?7VUA:6Q?86QI87-?;F%M92<@/3X@(DUA
M:6P@86QI87,@;F%M92(L"@DG7U]M86EL7V5X8VAA;F=E<E]N86UE7VES7VEN
M=F%L:60G(#T^(")-86EL(&5X8VAA;F=E<B!N86UE(&ES(&EN=F%L:60N(BP*
M"2=?7VUA:6Q?9W)O=7!S)R`]/B`B36%I;"!G<F]U<',B+`H))U]?;6%I;%]L
M:7-T7V5N9VEN92<@/3X@(DUA:6QI;F<@;&ES="!S;V9T=V%R92(L"@DG7U]M
M86EL7VYA;64G(#T^(")-86EL(&YA;64B+`H))U]?;6%I;%]N86UE7V9O<FTG
M(#T^(")-86EL(&YA;64@9F]R;2(L"@DG7U]M86EL7VYA;65S)R`]/B`B36%I
M;"!N86UE<R(L"@DG7U]M86EL7VYA;65S7VQI<W0G(#T^(")-86EL(&YA;65S
M(BP*"2=?7VUA:6Q?<V5R=B<@/3X@(DUA:6P@<V5R=F5R(BP*"2=?7VUA:6Q?
M=7-E<B<@/3X@)TUA:6P@=7-E<B<L"@DG7U]M86EL9W)O=7`G(#T^(")-86EL
M(&=R;W5P(BP*"2=?7VUA:6QL:7-T)R`]/B`B36%I;&EN9R!L:7-T(BP*"2=?
M7VUA:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))U]?;6%I;&QI<W1?
M;65M8F5R<R<@/3X@)TUA:6QI;F<@;&ES="!M96UB97)S)RP*"2=?7VUA:6QL
M:7-T7VUE;6)E<B<@/3X@)TUA:6QI;F<@;&ES="!M96UB97(G+`H))U]?;6%I
M;&YA;64G(#T^(")-86EL(&YA;64B+`H))U]?;6%I;&YA;65?<F5D:7)?<V5L
M9B<@/3X@(DUA:6P@;F%M92!C86YN;W0@8F4@<F5D:7)E8W1E9"!T;R!I='-E
M;&8N(BP*"2=?7VUA<W1E<B<@/3X@(DUA<W1E<B(L"@DG7U]M87A?9&]M7VYU
M;5]R96%C:&5D7V9O<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@
M9&]M86EN<R!H87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O
M=6YT+B(L"@DG7U]M87A?9FEL95]S:7IE7V%V86EL86)L92<@/3X@(DUA>&EM
M=6T@9FEL97-I>F4@86QL;W=E9"`E,2(L"@DG7U]M87A?<W5B9&]M7VYU;5]R
M96%C:&5D7V9O<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@<W5B
M9&]M86EN<R!H87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O
M=6YT+B(L"@DG7U]M87A?<W5B9&]M7VYU;5]R96%C:&5D7V9O<E]D;VTG(#T^
M(")4:&4@;&EM:70@;VX@;G5M8F5R(&]F('-U8F1O;6%I;G,@:&%S(&)E96X@
M<F5A8VAE9"!F;W(@=&AE(&1O;6%I;BXB+`H))U]?;6%X7W-U8F1O;5]N=6U?
M<F5A8VAE9%]F;W)?:V5Y)R`]/B`B5&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S
M=6)D;VUA:6YS(&%L;&]W960@8GD@=&AE(&QI8V5N<V4@:V5Y(&AA<R!B965N
M(')E86-H960N(BP*"2=?7VUA>%]T<F%F9FEC7VQI;6ET)R`]/B`B5')A9F9I
M8R!L:6UI="(L"@DG7U]M87AI;75M7V5X8VQ?:7!?;G5M)R`]/B`B36%I;"!N
M86UE<R(L"@DG7U]M8B<@/3X@(DU"(BP*"2=?7VUB>71E<R<@/3X@(FUE9V%B
M>71E<R(L"@DG7U]M8E]M;VYT:"<@/3X@(DU"+VUO;G1H(BP*"2=?7VUE9V$G
M(#T^(")-(BP*"2=?7TUI;G5T97,G(#T^("=-:6YU=&5S)RP*"2=?7VUL<U]N
M;W1?:6Y?:V5Y)R`]/B`B66]U<B!P<F]D=6-T(&ME>2!D;V5S(&YO="!S=7!P
M;W)T(&UU;'1I;&EN9W5A;"!I;G1E<F9A8V4N(BP*"2=?7VUO9&EF:6-A=&EO
M;E]D871E)R`]/B`B36]D:69I8V%T:6]N(&1A=&4B+`H))U]?;6]D=6QE)R`]
M/B`B36]D=6QE(BP*"2=?7VUO9'5L97,G(#T^(")-;V1U;&5S(BP*"2=?7VUO
M;G1H)R`]/B`B36]N=&@B+`H))U]?;6]N=&@H<RDG(#T^(")-;VYT:"AS*2(L
M"@DG7U]M;VYT:#$G(#T^(")*86XB+`H))U]?;6]N=&@Q,"<@/3X@(D]C="(L
M"@DG7U]M;VYT:#$Q)R`]/B`B3F]V(BP*"2=?7VUO;G1H,3(G(#T^(")$96,B
M+`H))U]?;6]N=&@R)R`]/B`B1F5B(BP*"2=?7VUO;G1H,R<@/3X@(DUA<B(L
M"@DG7U]M;VYT:#0G(#T^(")!<')I;"(L"@DG7U]M;VYT:#4G(#T^(")-87DB
M+`H))U]?;6]N=&@V)R`]/B`B2G5N92(L"@DG7U]M;VYT:#<G(#T^(")*=6QY
M(BP*"2=?7VUO;G1H."<@/3X@(D%U9R(L"@DG7U]M;VYT:#DG(#T^(")397!T
M(BP*"2=?7VUO;G1H;'DG(#T^(")-;VYT:&QY(BP*"2=?7VUO;G1H<R<@/3X@
M(DUO;G1H<R(L"@DG7U]M;W9E9%]P97)M86YE;G1L>2<@/3X@)TUO=F5D(%!E
M<FUA;F5N=&QY)RP*"2=?7VUS<W%L)R`]/B`B36EC<F]S;V9T(%-13"!S97)V
M97(B+`H))U]?;7-S<6Q?<W1A='5S)R`]/B`B36EC<F]S;V9T(%-13"!S97)V
M97(@<W1A='5S(BP*"2=?7VUU;'1I<&QY7VQO9VEN7V1E;GDG(#T^(")5;F%B
M;&4@=&\@;&]G('EO=2!O;BX@06YO=&AE<B!U<V5R('=I=&@@=&AE('-A;64@
M;&]G:6X@;F%M92`H)3$I(&ES(&%L<F5A9'D@;&]G9V5D(&EN('1O('1H92!C
M;VYT<F]L('!A;F5L+B(L"@DG7U]M>7-Q;"<@/3X@(DUY4U%,(BP*"2=?7VUY
M<W%L7W-T871U<R<@/3X@(E-13"!S97)V97(@<W1A='5S(BP*"2=?7VUY<W%L
M7W9E<G-I;VXG(#T^(")->7-Q;"!V97)S:6]N(BP*"2=?7VYA;64G(#T^(").
M86UE(BP*"2=?7VYA;65?:6YV86QI9"<@/3X@(DYA;64@:7,@:6YV86QI9"XB
M+`H))U]?;F%M97-E<G9E<B<@/3X@(FYA;65S97)V97(B+`H))U]?;F5T=V]R
M:R<@/3X@(DYE='=O<FLB+`H))U]?;F5T=V]R:W,G(#T^(").971W;W)K<R(L
M"@DG7U]N971W;W)K<U]L:7-T)R`]/B`B3F5T=V]R:W,B+`H))U]?;F5W7W!A
M<W-W9"<@/3X@(DYE=R`E,2!P87-S=V]R9"(L"@DG7U]N97=?<&%S<W=D7W-I
M;F=L92<@/3X@(DYE=R!P87-S=V]R9"(L"@DG7U]N;R<@/3X@(DYO(BP*"2=?
M7VYO7VEP7V%D9')E<W-?=VET:%]P<F]P97)L>5]T>7!E7V%V86EL86)L92<@
M/3X@(E5N86)L92!T;R!R97-T;W)E('1H92!B86-K960@=7`@9&%T82!B96-A
M=7-E('1H97)E(&%R92!N;R!S=6ET86)L92!)4"!A9&1R97-S97,@<F5Q=6ER
M960@9F]R(')E<W1O<FEN9RXB+`H))U]?;F]?8VQI96YT<U]S<&5C:69I960G
M(#T^(").;R!C;&EE;G0@86-C;W5N=',@<W!E8VEF:65D+B(L"@DG7U]N;U]C
M;VUM96YT<R<@/3X@(DYO(&-O;6UE;G1S+B(L"@DG7U]N;U]I<%]S<&5C:69I
M960G(#T^(").;R!I<"!S<&5C:69I960N(BP*"2=?7VYO7W-I=&5?87!P<U]S
M<&5C:69I960G(#T^(").;R!S:71E(&%P<&QI8V%T:6]N<R!S96QE8W1E9"XB
M+`H))U]?;F]C:&%N9V4G(#T^(")$;R!N;W0@8VAA;F=E(BP*"2=?7VYO;&]G
M:6XG(#T^(")&;W)B:61D96XB+`H))U]?;F]N92<@/3X@(DYO;F4B+`H))U]?
M;F]T7V-O;F9I9W5R960G(#T^(").;W0@8V]N9FEG=7)E9"(L"@DG7U]N;W1?
M<W5P<&]R=&5D7V)Y7V9T<"<@/3X@(BAN;W0@<W5P<&]R=&5D(&)Y($944"!S
M97)V97(I(BP*"2=?7VYO=%]S=7!P;W)T961?8GE?;6%I;&UN9R<@/3X@(FYO
M="!S=7!P;W)T960@8GD@=&AE(&UA:6P@<V5R=F5R(BP*"2=?7VYO=&EF:6-A
M=&EO;B<@/3X@(DYO=&EF:6-A=&EO;B(L"@DG7U]N;W1I9FEC871I;VYS)R`]
M/B`B3F]T:69I8V%T:6]N<R(L"@DG7U]N=6U?9&ES<&QA>65D)R`]/B`B)3$@
M;V8@)3(@9&ES<&QA>65D(BP*"2=?7VYU;5]I<U]I;G9A;&ED)R`]/B`B3G5M
M8F5R(&ES(&EN=F%L:60N(BP*"2=?7V]B:F5C=%]N;W1?9F]U;F0G(#T^("=/
M8FIE8W0@;F]T(&9O=6YD.B`E,2<L"@DG7U]O9E]A;&PG(#T^("(E(&]F($%L
M;"(L"@DG7U]O9F8G(#T^(")/9F8B+`H))U]?;VLG(#T^(")/2R(L"@DG7U]O
M;&1?<&%S<W=D)R`]/B`B3VQD("4Q('!A<W-W;W)D(BP*"2=?7V]L9%]P87-S
M=V1?<VEN9VQE)R`]/B`B3VQD('!A<W-W;W)D(BP*"2=?7V]N)R`]/B`B3VXB
M+`H))U]?;W1H97)S)R`]/B`B3W1H97)S(BP*"2=?7V]T:&5R7VEP7U]W:6QL
M7V)E7V%D9&5D)R`]/B`G3W1H97(@879A:6QA8FQE($E0(&%D9')E<W-E<R`H
M=VEL;"!B92!A9&1E9"!T;R!T:&4@8VQI96YT7"=S($E0('!O;VPI)RP*"2=?
M7V]U="<@/3X@(D]U="(L"@DG7U]O=VYE<B<@/3X@(D]W;F5R(BP*"2=?7W`G
M(#T^(")0(BP*"2=?7W!A<W-W9"<@/3X@(B4Q(%!A<W-W;W)D(BP*"2=?7W!A
M<W-W9%]S:6YG;&4G(#T^(")087-S=V]R9"(L"@DG7U]P87-S=V1?:&EN="<@
M/3X@(D%T(&QE87-T(#4@8VAA<F%C=&5R<RP@;F\@;F%T:6]N86P@8VAA<F%C
M=&5R<R(L"@DG7U]P87-S=V1?:7-?:6YV86QI9"<@/3X@(B4Q(%!A<W-W;W)D
M(&ES(&EN=F%L:60N(BP*"2=?7W!A<W-W9%]N;W1?;6%T8V@G(#T^(")087-S
M=V]R9',@9&\@;F]T(&UA=&-H(2(L"@DG7U]P871H)R`]/B`B4&%T:"(L"@DG
M7U]P97)L7W5N:7A?<W5P<&]R="<@/3X@(FUO9%]P97)L('-U<'!O<G0B+`H)
M)U]?<&5R;%]W:6Y?<W5P<&]R="<@/3X@(E!E<FP@<W5P<&]R="(L"@DG7U]P
M97)M7V1E;FEE9"<@/3X@(E!E<FUI<W-I;VX@9&5N:65D+B(L"@DG7U]P97)M
M:7-S:6]N<R<@/3X@(E!E<FUI<W-I;VYS(BP*"2=?7W!E<G-O;F%L7VYA;64G
M(#T^(")097)S;VYA;"!N86UE(BP*"2=?7W!G7V%D;6EN7VYO=%]A8W1I=F%T
M960G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@86-T:79A=&5D(&EN('1H92!S
M97)V97(@861M:6YI<W1R871I;VX@<V5C=&EO;BXB+`H))U]?<&=?;F]T7VEN
M<W0G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]P
M9U]N;W1?<G5N7V]R7VEN<W0G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@:6YS
M=&%L;&5D(&]R(&ES(&YO="!R=6YN:6YG+B(L"@DG7U]P:&]N92<@/3X@(E!H
M;VYE(BP*"2=?7W!H;W-T:6YG)R`]/B`B4&AY<VEC86P@:&]S=&EN9R(L"@DG
M7U]P:'!?<W5P<&]R="<@/3X@(E!(4"!S=7!P;W)T(BP*"2=?7W!H<%]S869E
M7VUO9&4G(#T^(")02%`@)W-A9F5?;6]D92<@;VXB+`H))U]?<&AP7W9E<G-I
M;VXG(#T^(")02%`@=F5R<VEO;B(L"@DG7U]P:'ES:6-A;"<@/3X@(E!H>7-I
M8V%L(&AO<W1I;F<B+`H))U]?<&QE<VM?<W1A=%]P9&ER)R`]/B`B4')O=&5C
M="!D:7)E8W1O<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A=%]D
M:7)?;F%M92<@/3X@(D1O;6%I;B!S=&%T:7-T:6-S(BP*"2=?7W!L97-K7W-T
M871?<')O=&5C="<@/3X@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D('!R;W1E
M8W1E9"!D:7)E8W1O<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A
M=%]P<F]T96-T7VEN<W1A;&PG(#T^(")A8V-E<W-I8FQE('9I82!P87-S=V]R
M9"!P<F]T96-T960@9&ER96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=?7W!L
M97-K7W-T871?=V5B<W1A=%]N;W1?86-T:79A=&4G(#T^(")796(@<W1A=&ES
M=&EC<R!A<F4@;F]T(&5N86)L960N(BP*"2=?7W!O<#-?:6UA<"<@/3X@(E!/
M4#,O24U!4"(L"2\O(&EN9&ER96-T"@DG7U]P;W`S7W-T871U<R<@/3X@(E!/
M4#,@<V5R=F5R('-T871U<R(L"@DG7U]P;W!E;E]E<G)O<B<@/3X@(D%N(&5R
M<F]R(&]C8W5R<F5D('=H:6QE(&-A;&QI;F<@=&AE('!O<&5N(&9U;F-T:6]N
M+B(L"@DG7U]P;W)T)R`]/B`G4&]R="<L"@DG7U]P;W-T9W)E<R<@/3X@(E!O
M<W1G<F5344PB+`H))U]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F5344PB+`H)
M)U]?<&]S=&=R97-Q;%]S=&%T=7,G(#T^(")0;W-T9W)E4U%,('-T871U<R(L
M"@DG7U]P<F5F97)E;F-E<R<@/3X@(E!R969E<F5N8V5S(BP*"2=?7V%D;6EN
M:7-T<F%T;W)?<')E9F5R96YC97,G(#T^(")!9&UI;FES=')A=&]R)W,@4')E
M9F5R96YC97,B+`H))U]?86-C;W5N=%]P<F5F97)E;F-E<R<@/3X@(D%C8V]U
M;G0@4')E9F5R96YC97,B+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S7V=E
M;F5R86PG(#T^("='96YE<F%L)RP*"2=?7VEN=&5R9F%C95]P<F5F97)E;F-E
M<U]D969A=6QT)R`]/B`G1&5F875L="!);G1E<F9A8V4@4')E9F5R96YC97,G
M+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S7V%D;6EN)R`]/B`B061M:6YI
M<W1R871O<B=S($EN=&5R9F%C92!0<F5F97)E;F-E<R(L"@DG<V5R=F5R7W!R
M969E<F5N8V5S7U]D969A=6QT7VET;7!L)R`]/B`G1&5F875L="!I;G1E<F9A
M8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92<L"@DG<V5R=F5R7W!R969E<F5N
M8V5S7U]A9&UI;E]I=&UP;"<@/3X@(D%D;6EN:7-T<F%T;W(G<R!I;G1E<F9A
M8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92(L"@DG7U]I;G1E<F9A8V5?=&5M
M<&QA=&4G(#T^("=);G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92<L
M"@DG7U]S>7-T96U?<')E9F5R96YC97,G(#T^(")3>7-T96T@<')E9F5R96YC
M97,B+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S)R`]/B`B26YT97)F86-E
M('!R969E<F5N8V5S(BP*"2=?7W!R:6]R:71Y)R`]/B`G4')I;W)I='DG+`H)
M)U]?<')I;W)I='E?:&EG:&5S="<@/3X@)VAI9VAE<W0G+`H))U]?<')I;W)I
M='E?:&EG:"<@/3X@)VAI9V@G+`H))U]?<')I;W)I='E?;F]R;6%L)R`]/B`G
M;F]R;6%L)RP*"2=?7W!R:6]R:71Y7VQO=R<@/3X@)VQO=R<L"@DG7U]P<FEO
M<FET>5]L;W=E<W0G(#T^("=L;W=E<W0G+`H))U]?<')I;W)I='E?;W1H97(G
M(#T^("=C=7-T;VTG+`H))U]?<')O8V5E9#\G(#T^(")$;R!Y;W4@=V%N="!T
M;R!P<F]C965D/R(L"@DG7U]P<F]C96YT)R`]/B`B)2(L"@DG7U]P<F]T96-T
M7V1I<E]U<V5R)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U<V5R(BP*"2=?
M7W!R;W1E8W1?9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U
M<V5R<R(L"@DG7U]P<F]T96-T7V1I<G,G(#T^(")0<F]T96-T960@9&ER96-T
M;W)I97,B+`H))U]?<')O=FED97)?8V]N=&%C=%]N86UE)R`]/B`B4')O=FED
M97(G<R!C;VYT86-T(&YA;64B+`H))U]?<'0G(#T^(")U;FET<R(L"@DG7U]P
M>71H;VY?=6YI>%]S=7!P;W)T)R`]/B`B;6]D7W!Y=&AO;B!S=7!P;W)T(BP*
M"2=?7W!Y=&AO;E]W:6Y?<W5P<&]R="<@/3X@(E!Y=&AO;B!S=7!P;W)T(BP*
M"2=?7W%U;W1A)R`]/B`B475O=&$B+`H))U]?<B<@/3X@(E(B+`H))U]?<F5C
M;VYF:6=U<F4G(#T^(")296-O;F9I9W5R92(L"@DG7U]R96-O<F1?='EP92<@
M/3X@(E)E8V]R9"!T>7!E(BP*"2=?7W)E;&5A<V4G(#T^(")296QE87-E(BP*
M"2=?7W)E;6]T95]D8E]N;W1?<W5P<&]R=&5D7V)Y7VME>2<@/3X@)U)E;6]T
M92!D871A8F%S92!H;W-T:6YG(&ES(&YO="!S=7!P;W)T960@8GD@>6]U<B!L
M:6-E;G-E(&ME>2XG+`H))U]?<F5M;W9E)R`]/B`B4F5M;W9E(BP*"2=?7W)E
M;6]V95]C;VYF:7)M871I;VXG(#T^(")296UO=F%L(&-O;F9I<FUA=&EO;B(L
M"@DG7U]R97!O<G0G(#T^(")297!O<G0B+`H))U]?<F5P;W)T7V%U=&\G(#T^
M("=$96QI=F5R>2!S8VAE9'5L92<L"@DG7U]R97!O<G1?9F]R;2<@/3X@(E)E
M<&]R="!F;W)M(BP*"2=?7W)E<&]R=%]S:7IE7VYA)R`]/B`B4V5R=FEC92!I
M<R!U;F%V86EL86)L92(L"@DG7U]R97!O<G1S7VQI<W0G(#T^(")297!O<G1S
M(BP*"2=?7W)E<75E<W1E9"<@/3X@(E)E<75E<W1E9"(L"@DG7U]R97%U:7)E
M9%]F:65L9',G(#T^(")297%U:7)E9"!F:65L9',B+`H))U]?<F5S<%]N86UE
M7VEN=F%L:60G(#T^(")!=71O<F5S<&]N9&5R(&YA;64@:7,@:6YV86QI9"X@
M57-E(&]N;'D@86QP:&%N=6UE<FEC+"!D;W1S+"!U;F1E<G-C;W)E(&%N9"!W
M:&ET92!S<&%C97,@<WEM8F]L<RXB+`H))U]?8R<@/3X@(D$B+"`O+R!!8V-E
M<W,@=&\@8V]N=')O;"!P86YE;`H))U]?<R<@/3X@(E,B+`H))U]?<V5R=F5R
M7VYA;65?:7-?:6YV86QI9"<@/3X@(E-E<G9E<B!N86UE(&ES(&EN=F%L:60N
M(BP*"2=?7W-C<F5E;G-H;W1S)R`]/B`G4V-R965N<VAO=',G+`H))U]?<V-R
M:7!T7W=A<FYI;F<G(#T^(")">2!R96UO=FEN9R!T:&4@<V-R:7!T:6YG(&-A
M<&%B:6QI='D@9G)O;2!T:&ES(&1O;6%I;B!A;&P@:6YF;'5E;F-E9"!S8W)I
M<'1S('=I;&P@8F4@9&ES<&QA>65D(&EN('!L86EN('1E>'0@=VAE;B!C86QL
M960@8GD@82!B<F]W<V5R+B`@270@:7,@861V:7-A8FQE(&9O<B!T:&4@861M
M:6YI<W1R871O<B!T;R!R96UO=F4@86QL(&1E<&5N9&5N="!S8W)I<'1S(&9R
M;VT@=&AE(&=I=F5N(&1O;6%I;BXB+`H))U]?<V5C)R`]/B`B4V5C;VYD<R(L
M"@DG7U]S965?;&ES=%]O9E]L;V=G961?:6XG(#T^(")3964@=&AE(&QI<W0@
M;V8@8W5R<F5N=&QY(&QO9V=E9"!O;B!U<V5R<RXB+`H))U]?<V5L96-T7V-E
M<G1S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!C97)T:69I8V%T97,@=&\@8F4@
M<F5M;W9E9"XB+`H))U]?<V5L96-T7V-L:65N='-?=&]?<F5M;W9E)R`]/B`B
M4V5L96-T(&-L:65N="!A8V-O=6YT<R!T;R!B92!R96UO=F5D+B(L"@DG7U]S
M96QE8W1?9&]M86EN<U]T;U]D969A=6QT7VAO<W0G(#T^(")396QE8W0@82!D
M;VUA:6X@=&\@<V5T(&%S(&1E9F%U;'0N(BP*"2=?7W-E;&5C=%]D;VUA:6YS
M7W1O7W)E;6]V92<@/3X@(E-E;&5C="!D;VUA:6YS('1O(&)E(')E;6]V960N
M(BP*"2=?7W-E;&5C=%]F:6QE<U]T;U]R96UO=F4G(#T^(")396QE8W0@9FEL
M97,@=&\@8F4@<F5M;W9E9"XB+`H))U]?<V5L96-T7VEP)R`]/B`B4V5L96-T
M(&%N($E0(&%D9')E<W,B+`H))U]?<V5L96-T7VEP7W1O7W)E;6]V92<@/3X@
M(E-E;&5C="!A;B!)4"!A9&1R97-S('1O(&)E(')E;6]V960N(BP*"2=?7W-E
M;&5C=%]T96UP;&%T92<@/3X@(E-E;&5C="!T96UP;&%T92(L"@DG7U]S96QE
M8W1?=&5M<&QA=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!T96UP;&%T97,@
M=&\@8F4@<F5M;W9E9"XB+`H))U]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*"2=?
M7W-E<G9E<G-?;&ES="<@/3X@(E-L879E(%-E<G9E<G,B+`H))U]?<V5R=F5R
M7W1O=&%L)R`]/B`B4V5R=F5R(%1O=&%L(BP*"2=?7W-E<G9I8V4G(#T^(")3
M97)V:6-E(BP*"2=?7W-E<G9I8V5S)R`]/B`B4V5R=FEC97,B+`H))U]?<V5S
M<VEO;G,G(#T^(")397-S:6]N<R(L"@DG7U]S97-S:6]N<U]L:7-T)R`]/B`B
M4V5S<VEO;G,B+`H))U]?<V5T)R`]/B`B16YA8FQE(BP*"2=?7W-E='5P7VQO
M9V]?<')E9B<@/3X@(E-E="!U<"!L;V=O('!R;W!E<G1I97,B+`H))U]?<VAA
M<F5D)R`]/B`B4VAA<F5D(BP*"2=?7W-H961U;&5D7V)A8VMU<"<@/3X@(E-H
M961U;&5D($)A8VMU<"(L"@DG7U]S:&5L;%]A8V-E<W-?=V%R;FEN9R<@/3X@
M(D%L;&]W:6YG('-H96QL(&%C8V5S<R!T;R!T:&4@<WES=&5M(&ES(&AI9VAL
M>2!D86YG97)O=7,@9F]R('1H92!S>7-T96T@<V5C=7)I='DN($%L;&]W(&%C
M8V5S<R!T;R!T:&4@<WES=&5M(&]N;'D@:68@>6]U(&-L96%R;'D@=6YD97)S
M=&%N9"!W:&%T('EO=2!A<F4@9&]I;F<L(&%N9"!O;FQY('1O('1R=7-T960@
M=7-E<G,N($1O('EO=2!R96%L;'D@=V%N="!T;R!A;&QO=R!A8V-E<W,_(BP*
M"2=?7W-I=&5A<'!?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B4VET92!A<'!L
M:6-A=&EO;G,@87)E(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y
M(BP*"2=?7W-I=&5A<'!?8V%N;F]T7W)E8V]N9FEG=7)E7W=I=&A?<F5M;W1E
M7V1A=&%B87-E)R`]/B`G5&AE(&-O;F9I9W5R871I;VX@;V8@=&AI<R!S:71E
M(&%P<&QI8V%T:6]N(&AA<R!B965N(&-H86YG960@;6%N=6%L;'DN($EN(&]R
M9&5R('1O('!R;W1E8W0@=&AE(&UA;G5A;"!M;V1I9FEC871I;VYS+"!R96-O
M;F9I9W5R871I;VX@=&AR;W5G:"!0;&5S:R!I<R!D:7-A;&QO=V5D+B<L"@DG
M7U]S:71E87!P7VQO8V%L7V1B7V1I<V%L;&]W960G(#T^("=!(')E;6]T92!D
M871A8F%S92!S97)V97(@:&%S(&)E96X@<V5L96-T960@87,@=&AE(&1E9F%U
M;'0@9&%T86)A<V4@;&]C871I;VXL(&)U="!T:&ES('-I=&4@87!P;&EC871I
M;VX@:7,@=6YA8FQE('1O('5S92!A(')E;6]T92!D871A8F%S92X@5&AE('-I
M=&4@87!P;&EC871I;VX@8V%N;F]T(&)E(&EN<W1A;&QE9"X@06X@=7!G<F%D
M92!O9B!T:&4@<VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(')E8V]M;65N
M9&5D+B<L"@DG7U]S:71E87!P7W)E;6]T95]D871A8F%S92<@/3X@)U1H92!D
M871A8F%S92!C86X@8F4@:&]S=&5D(&]N(&$@<F5M;W1E('-E<G9E<BXG+`H)
M)U]?<VET95]A<'!L:6-A=&EO;B<@/3X@(E-I=&4@07!P;&EC871I;VXB+`H)
M)U]?<VET95]A<'!L:6-A=&EO;E]P86-K86=E)R`]/B`B4VET92!!<'!L:6-A
M=&EO;B!086-K86=E(BP*"2=?7W-I=&5?87!P;&EC871I;VY?<&%C:V%G97,G
M(#T^(")3:71E($%P<&QI8V%T:6]N(%!A8VMA9V5S(BP*"2=?7W-I=&5?87!P
M;&EC871I;VYS)R`]/B`B4VET92!!<'!L:6-A=&EO;G,B+`H))U]?<VET95]M
M86YA9V5M96YT)R`]/B`B5V5B(%!U8FQI<VAI;F<B+`DO+R!I;F1I<F5C=`H)
M)U]?<VEZ92<@/3X@(E-I>F4B+`H))U]?<VME;&5T;VXG(#T^(")3:V5L971O
M;B(L"@DG7U]S:VEN<R<@/3X@)U-K:6YS)RP*"2=?7W-M='`G(#T^(")33510
M(BP)+R\@:6YD:7)E8W0*"2=?7W-M='!?<W1A='5S)R`]/B`B4TU44"!S97)V
M97(@<W1A='5S(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O<E]I;G9A
M;&ED)R`]/B`B4V]M92!F:65L9',@87)E(&5M<'1Y(&]R(&-O;G1A:6X@86X@
M:6UP<F]P97(@=F%L=64N(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O
M<E]I;G9A;&ED7V]R7VQO;F<G(#T^(")3;VUE(&9I96QD<R!A<F4@96UP='D@
M;W(@8V]N=&%I;B!A;B!I;7!R;W!E<B!V86QU92X@5&AE('9A;'5E<R!S:&]U
M;&0@8F4@;&EM:71E9"!T;R`V-"!C:&%R86-T97)S+B!)9B!Y;W4@87)E('5S
M:6YG(&%N(&EN=&5R;F%T:6]N86QI>F5D(&1O;6%I;B!N86UE+"!M86ME('-U
M<F4@96%C:"!P87)T(&]F('1H92!D;VUA:6X@;F%M92!B971W965N(&1O=',@
M9&]E<R!N;W0@97AC965D(#8S('-Y;6)O;',@=VAE;B!T<F%N<V9O<FUE9"!T
M;R!!4T-)22!F;W)M870N(BP*"2=?7W-P86UA<W-A<W-I;B<@/3X@(E-P86U!
M<W-A<W-I;B(L"@DG7U]S<&%M87-S87-S:6Y?<W1A='5S)R`]/B`B4W!A;4%S
M<V%S<VEN('-T871U<R(L"@DG7U]S<&QI=&5D7V)A8VMU<"<@/3X@(BAM=6QT
M:79O;'5M92!B86-K=7`I(BP*"2=?7W-P;&ET7V)A8VMU<%]F:6QE)R`]/B`B
M0W)E871E(&$@;75L=&EV;VQU;64@8F%C:W5P(BP*"2=?7W-P;&ET7V)A8VMU
M<%]S:7IE)R`]/B`B5F]L=6UE('-I>F4B+`H))U]?<W!L:71?8F%C:W5P7VQE
M<W-?=&AA;E\U,#`G(#T^(")6;VQU;64@<VEZ97,@;&5S<R!T:&%N(#4P,"!M
M96=A8GET97,@87)E(&YO="!S=7!P;W)T960B+`H))U]?<W-I)R`]/B`B4U-)
M(BP*"2=?7W-S:5]S=7!P;W)T)R`]/B`B4U-)('-U<'!O<G0B+`H))U]?<W-L
M)R`]/B`G4U-,)RP*"2=?7W-S;%]S=7!P;W)T)R`]/B`B4U-,('-U<'!O<G0B
M+`H))U]?<V%M95]S<VPG(#T^(")5<V4@82!S:6YG;&4@9&ER96-T;W)Y(&9O
M<B!H;W5S:6YG(%-33"!A;F0@;F]N+5-33"!C;VYT96YT(BP*"2=?7W-A;65?
M<W-L7V-U)R`]/B`B0V]M;6]N(%-33"].;VXM4U-,(&-O;G1E;G0B+`H))U]?
M<W1A=&4G(#T^(")3=&%T92]0<F]V:6YC92(L"@H))U]?<W1A='5S7U]!8W1I
M=F4G(#T^("=!8W1I=F4G+`H))U]?<W1A='5S7U]A8W1I=F4G(#T^("=A8W1I
M=F4G+`H))U]?<W1A='5S7U]087-S:79E)R`]/B`G1&ES86)L960G+`H))U]?
M<W1A='5S7U]P87-S:79E)R`]/B`G9&ES86)L960G+`H))U]?<W1A='5S7U]O
M9F8G(#T^("=D:7-A8FQE9"<L"@DG7U]S=&%T=7-?7W=I=&A?<&%R96YT)R`]
M/B`G9&ES86)L960G+`H))U]?<W1A='5S7U]B86-K=7!?<F5S=&]R92<@/3X@
M)W1E;7!O<F%R:6QY('-U<W!E;F1E9"!F;W(@8F%C:VEN9R!U<"!O<B!R97-T
M;W)I;F<G+`H))U]?<W1A='5S7U]A9&UI;B<@/3X@)V1I<V%B;&5D(&)Y(&%D
M;6EN)RP*"2=?7W-T871U<U]?<F5S<V5L97(G(#T^("=D:7-A8FQE9"!B>2!R
M97-E;&QE<B<L"@DG7U]S=&%T=7-?7V-L:65N="<@/3X@)V1I<V%B;&5D(&)Y
M(&-L:65N="<L"@DG7U]S=&%T=7-?7W5N:VYO=VXG(#T^("=S=&%T=7,@:7,@
M=6YK;F]W;B<L"@H))U]?<W1A='5S7V]F)R`]/B`B)3$@<W1A='5S(BP*"@DO
M+R!E;F0@;V8@86MS<R!P87)T"@H)+R\@<VAR86UK;R!P87)T"@H))U]?<W1U
M;FYE;"<@/3X@(E-T=6YN96PB+`H))U]?<W1U;FYE;%]S97)V97(G(#T^(")3
M='5N;F5L('-E<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]S=6)D;VUA:6XG(#T^
M(")3=6)D;VUA:6XB+`H))U]?<W5B9&]M86EN7VYA;64G(#T^(")3=6)D;VUA
M:6X@;F%M92(L"@DG7U]S=6)D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]
M/B`B26X@05-#24D@9F]R;6%T(BP*"2=?7W-U8F1O;6%I;G,G(#T^(")3=6)D
M;VUA:6YS(BP*"2=?7W-U8F1O;6%I;G-?;&ES="<@/3X@(E-U8F1O;6%I;G,B
M+`H))U]?<W5B9&]M86EN<U]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3=6)D
M;VUA:6X@;W!E<F%T:6]N<R!A<F4@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC
M96YS92!K97DB+`H))U]?<WES7W5S97)?='EP92<@/3X@(D944"!U<V5R(BP*
M"2=?7W-Y<U]U<V5R7W1Y<&5?;6%I;B<@/3X@(E5S92!T:&4@1E10('5S97(@
M86-C;W5N="!O9B!T:&4@;6%I;B!D;VUA:6XB+`H))U]?<WES7W5S97)?='EP
M95]N871I=F4G(#T^(")#<F5A=&4@82!S97!A<F%T92!&5%`@=7-E<B!A8V-O
M=6YT(&9O<B!T:&ES('-U8F1O;6%I;B(L"@DG7U]T)R`]/B`B5"(L"@DG7U]T
M87)G971?9&]M86EN)R`]/B`B5&%R9V5T(&1O;6%I;B(L"@DG7U]T87-K)R`]
M/B`G5&%S:R<L"@DG7U]T87-K<U]L:7-T)R`]/B`G5&%S:W,G+`H))U]?=&5M
M<&QA=&4G(#T^(")496UP;&%T92(L"@DG7U]T96UP;&%T95]N;W1?86-C97!T
M960G(#T^(")5;F%B;&4@=&\@86-C97!T('1H92!T96UP;&%T93H@=&AE(&9O
M;&QO=VEN9R!L:6UI=&%T:6]N<R!A<F4@97AC965D960N(BP*"2=?7W1E;7!L
M871E<R<@/3X@(E1E;7!L871E<R(L"@DG7U]T96UP;&%T97-?;&ES="<@/3X@
M(E1E;7!L871E<R(L"@DG7U]T97)A)R`]/B`B5"(L"@DG7U]T97AT)R`]/B`B
M5&5X="(L"@DG7U]T:71L92<@/3X@(E1I=&QE(BP*"2=?7W1O;6-A="<@/3X@
M(E1O;6-A="(L"@DG7U]T;VUC871?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B
M5&]M8V%T(&ES(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y(BP*
M"2=?7W-P86UA<W-A<W-I;E]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3<&%M
M07-S87-S:6X@:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DB
M+`H))U]?=&]M8V%T7W-T871U<R<@/3X@(E1O;6-A="!S=&%T=7,B+`H))U]?
M=&]O;',G(#T^(")4;V]L<R(L"@DG7U]T;W1A;"<@/3X@(E1O=&%L("4Q(BP*
M"2=?7W1O=&%L7W-I>F4G(#T^(")4;W1A;"!S:7IE(BP*"2=?7W1O=&%L7W5S
M960G(#T^(")4;W1A;"!5<V5D(BP*"2=?7W1T<R<@/3X@(DAE;'`@1&5S:R(L
M"@DG7U]T<F%F9FEC)R`]/B`B5')A9F9I8R(L"@DG7U]T<F%F9FEC7V)Y7V-L
M:65N="<@/3X@(E1R869F:6,@8GD@8VQI96YT(BP*"2=?7W1R869F:6-?8GE?
M9&]M86EN)R`]/B`B5')A9F9I8R!B>2!D;VUA:6XB+`H))U]?=')A9F9I8U]B
M>5]S97)V:6-E)R`]/B`B5')A9F9I8R!B>2!S97)V:6-E(BP*"2=?7W1R869F
M:6-?:&ES=&]R>2<@/3X@(E1R869F:6,@:&ES=&]R>2(L"@DG7U]U;F%B;&5?
M8VAA;F=E7VQO8V%L92<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&EN=&5R
M9F%C92!L86YG=6%G93H@)3$B+`H))U]?=6YA8FQE7V-R96%T95]N97=?9&]M
M)R`]/B`B56YA8FQE('1O(&-R96%T92!N97<@9&]M86EN.B`E,2(L"@DG7U]U
M;F%B;&5?9&5F:6YE7V1O;5]N86UE)R`]/B`B56YA8FQE('1O(&1E9FEN92!D
M;VUA:6X@;F%M93H@)3$B+`H))U]?=6YA8FQE7V1E9FEN95]N96-E<W-A<GE?
M<')O<&5R=&EE<R<@/3X@(E5N86)L92!T;R!D969I;F4@86QL(')E<75I<F5D
M('!R;W!E<G1I97,N(BP*"2=?7W5N86)L95]D969I;F5?<')O<&5R=&EE<R<@
M/3X@(E5N86)L92!T;R!D969I;F4@<')O<&5R=&EE<SH@)3$B+`H))U]?=6YA
M8FQE7V5X96-?=71I;"<@/3X@(E5N86)L92!T;R!E>&5C=71E('5T:6QI='DZ
M("4Q(BP*"2=?7W5N86)L95]G96YE<F%T95]C97)T)R`]/B`B56YA8FQE('1O
M(&=E;F5R871E(&-E<G1I9FEC871E.B`E,2(L"@DG7U]U;F%B;&5?9V5N97)A
M=&5?8W-R)R`]/B`B56YA8FQE('1O(&=E;F5R871E($-34CH@)3$B+`H))U]?
M=6YA8FQE7V=E=%]D;G-?85]R96-S)R`]/B`B56YA8FQE('1O(')E=')I979E
M(&EP(&%D9')E<W-E<R!F;W(@02!$3E,@<F5C;W)D<R!F;W(@=&AI<R!H;W-T
M:6YG(&%C8V]U;G0Z("4Q(BP*"2=?7W5N86)L95]G971?;6)O>%]Q=6]T82<@
M/3X@(E5N86)L92!T;R!R971R:65V92!T:&4@:6YF;W)M871I;VX@;VX@=&AE
M(&UA:6QB;W@@<VEZ92!L:6UI="XB+`H))U]?=6YA8FQE7W)E9&ER96-T7W1O
M7VUY<V5L9B<@/3X@(E5N86)L92!T;R!R961I<F5C="!T;R!O;F5S96QF+B(L
M"@DG7U]U;F%B;&5?<F5M;W9E7V-L:65N="<@/3X@(E5N86)L92!T;R!R96UO
M=F4@8VQI96YT.B`E,2(L"@DG7U]U;F%B;&5?<V5T7W5P7VUB;WA?<75O=&$G
M(#T^(")5;F%B;&4@=&\@<V5T('1H92!M86EL8F]X('-I>F4@;&EM:70@9F]R
M('1H92!D;VUA:6XZ("4Q(BP*"2=?7W5N86)L95]S971U<%]P87-S)R`]/B`B
M56YA8FQE('1O('-E="!P87-S=V]R9#H@)3$B+`H))U]?=6YA8FQE7W1O7V-R
M96%T95]N97=?86-C;W5N="<@/3X@(E5N86)L92!T;R!C<F5A=&4@;F5W(&%C
M8V]U;G0Z("4Q(BP*"2=?7W5N86)L95]T;U]D969I;F5?9&)?<VEZ92<@/3X@
M(E5N86)L92!T;R!D969I;F4@=&AE(&1A=&%B87-E('-I>F4B+`H))U]?=6YA
M8FQE7W1O7V5N86)L95]S:&]R=%]N86UE<R<@/3X@(E5N86)L92!T;R!A;&QO
M=R!T:&4@=7-E(&]F('-H;W)T(&UA:6P@;F%M97,@9F]R(%!/4#,O24U!4"!A
M8V-O=6YT<RXB+`H))U]?=6YA8FQE7W1O7V9E=&-H7V1A=&%?9G)O;5]S=6)M
M:70G(#T^(")5;F%B;&4@=&\@9F5T8V@@=&AE('-U8FUI='1E9"!D871A.B`E
M,2(L"@DG7U]U;F%B;&5?=&]?;W!E;E]F:6QE)R`]/B`B56YA8FQE('1O(&]P
M96X@=&AE(&9I;&4@)3$Z("4R+B(L"@DG7U]U;F%B;&5?=&]?=7!D871E7W-U
M8F1O;6%I;B<@/3X@(E5N86)L92!T;R!M86ME(&-H86YG97,@=&\@=&AE('-U
M8F1O;6%I;CH@)3$B+`H))U]?=6YA8FQE7W5P9&%T95]C;%]D871A)R`]/B`B
M56YA8FQE('1O('5P9&%T92!C;&EE;G0@9&%T83H@)3$B+`H))U]?=6YA8FQE
M7W5P9&%T95]D8E]P87)A;7,G(#T^(")5;F%B;&4@=&\@=7!D871E(&1A=&%B
M87-E('!A<F%M971E<G,Z("4Q(BP*"2=?7W5N86)L95]U<&1A=&5?9&]M7V1A
M=&$G(#T^(")5;F%B;&4@=&\@=7!D871E(&1O;6%I;B!D871A.B`E,2(L"@DG
M7U]U;F1E9FEN960G(#T^(")U;F1E9FEN960B+`H))U]?=6YI;G-T86QL)R`]
M/B`B56YI;G-T86QL(BP*"2=?7W5N:VYO=VY?97)R;W(G(#T^(")5;FMN;W=N
M(&5R<F]R(BP*"2=?7W5N;&EM:71E9"<@/3X@(E5N;&EM:71E9"(L"@DG7U]U
M;FQI;6ET961?;&]W97(G(#T^(")5;FQI;6ET960B+`H))U]?=6YS970G(#T^
M(")$:7-A8FQE(BP*"2=?7W5P9&%T92<@/3X@(E5P9&%T92(L"@DG7U]U<&QO
M861?8V5R=%]F:6QE)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&9I;&4@(BP*
M"2=?7W5P;&]A9&5D7V9I;&5?:7-?:6YV86QI9"<@/3X@(E5P;&]A9&5D(&9I
M;&4@:7,@:6YV86QI9#H@)3$B+`H))U]?=7)L)R`]/B`B55),(BP*"2=?7W5S
M86=E)R`]/B`B1&ES:R!U<V%G92(L"@DG7U]U<V5D)R`]/B`B57-E9"(L"@DG
M7U]U<V5R)R`]/B`B57-E<B(L"@DG7U]U<V5R7V%L<F5A9'E?97AI<W0G(#T^
M(")5<V5R("4Q(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]U<V5R7V%L<F5A9'E?
M97AI<W1S)R`]/B`B57-E<B`E,2!A;')E861Y(&5X:7-T<RXB+`H))U]?=7-E
M<E]A;')E861Y7VQO9V=E9"<@/3X@(D%N;W1H97(@=7-E<B!W:71H('1H92!S
M86UE(&QO9VEN("@E,2D@:7,@86QR96%D>2!L;V=G960@;VX@=&\@=&AE("!C
M;VYT<F]L('!A;F5L+B(L"@DG7U]V86QU92<@/3X@(E9A;'5E(BP*"2=?7W9E
M<G-I;VXG(#T^(")697)S:6]N(BP*"2=?7W9H7W1Y<&4G(#T^(")6:7)T=6%L
M(&AO<W0@='EP92(L"@DG7U]V:&]S='-?87!A8VAE7W-T871U<R<@/3X@(E=E
M8B!S97)V97(@<W1A='5S(BP*"2=?7W=R;VYG7V-H87)S971?8V]N=F5R<VEO
M;B<@/3X@)U=R;VYG(&-H87)S970L(&-O;G9E<G-I;VX@9G)O;2`B)3$B('1O
M("(E,B(@:7,@;F]T(&%L;&]W960G+`H))U]?=V%R;FEN9U\G(#T^(")787)N
M:6YG(2(L"@DG7U]W87)N:6YG7V5X8VQ?:7!?;G5M)R`]/B`B17AC;'5S:79E
M($E0(&%D9')E<W,B+`H))U]?=V%R;FEN9U]E>'!I<F%T:6]N)R`]/B`B17AP
M:7)A=&EO;B!D871E(BP*"2=?7W=E8E]A<'!S)R`]/B`B2F%V82!A<'!L:6-A
M=&EO;G,B+`H))U]?=V5B7W-C<FEP=&EN9R<@/3X@(E=E8B!S8W)I<'1I;F<B
M+`DO+R!I;F1I<F5C=`H))U]?=V5B7W-E<G8G(#T^(")796(@<V5R=F5R(BP)
M+R\@:6YD:7)E8W0*"2=?7W=E8E]S=&%T:7-T:6,G(#T^(")796(@<W1A=&ES
M=&EC<R(L"2\O(&EN9&ER96-T"@DG7U]W96)M86EL)R`]/B`B5V5B36%I;"(L
M"2\O("MI;F1I<F5C=`H))U]?=V5B<W1A=%]N;W1?:6YS=&%L;&5D)R`]/B`B
M5V5B86QI>F5R(&ES(&YO="!C=7)R96YT;'D@:6YS=&%L;&5D(&]N('1H92!S
M97)V97(N($-O;G1A8W0@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R('1O(&AA
M=F4@=&AE(%=E8F%L:7IE<B!I;G-T86QL960N(BP*"2=?7W=E8G-T871?<W5P
M<&]R="<@/3X@(E=E8B!S=&%T:7-T:6-S(BP*"2=?7W=E8G5S97(G(#T^(")7
M96(@=7-E<B(L"@DG7U]W96)U<V5R<U]L:7-T)R`]/B`B5V5B('5S97)S(BP*
M"2=?7W=E96ML>2<@/3X@(E=E96ML>2(L"@DG7U]W:&%T<U]N97=?:6Y?=F5R
M<VEO;B<@/3X@(E=H870G<R!N97<@:6X@4&QE<VL@)3$_(BP*"2=?7W=R;VYG
M7VAO<W1I;F=?='EP95]?;F]N92<@/3X@)U1H97)E(&ES(&YO('!H>7-I8V%L
M(&AO<W1I;F<@8V]N9FEG=7)E9"!O;B!T:&ES(&1O;6%I;BXG+`H))U]?=W)O
M;F=?:&]S=&EN9U]T>7!E7U]S=&1?9G=D)R`]/B`G5&AI<R!D;VUA:6X@:&%S
M('-T86YD87)D(&9O<G=A<F1I;F<@8V]N9FEG=7)E9"X@5&AI<R!O<&5R871I
M;VX@:7,@879A:6QA8FQE(&]N;'D@9F]R(&1O;6%I;G,@=VET:"!P:'ES:6-A
M;"!H;W-T:6YG+B<L"@DG7U]W<F]N9U]H;W-T:6YG7W1Y<&5?7V9R;5]F=V0G
M(#T^("=4:&ES(&1O;6%I;B!H87,@9G)A;64@9F]R=V%R9&EN9R!C;VYF:6=U
M<F5D+B!4:&ES(&]P97)A=&EO;B!I<R!A=F%I;&%B;&4@;VYL>2!F;W(@9&]M
M86EN<R!W:71H('!H>7-I8V%L(&AO<W1I;F<N)RP*"2=?7W=U)R`]/B`B5V5B
M('5S97)S(BP*"2=?7W=W=R<@/3X@(E=75R(L"@DG7U]W=W=?<')E9FEX)R`]
M/B`B5U=7('!R969I>"(L"@DG7U]W=W=?<')E9FEX7W=A<U]C:&%N9V5D)R`]
M/B`B5U=7('!R969I>"!W87,@8VAA;F=E9"X@0F4@<W5R92!T;R!M;V1I9GD@
M=&AE(%-33"!C97)T:69I8V%T92!A8V-O<F1I;F=L>2XB+`H))U]?>65A<B<@
M/3X@(EEE87(B+`H))U]?>65A<BAS*2<@/3X@(EEE87(H<RDB+`H))U]?>65S
M)R`]/B`B665S(BP*"2=?7WEO=2<@/3X@(EEO=2(L"@DG7U]Z:7!?8V]D92<@
M/3X@(E!O<W1A;"]:25`@8V]D92(L"@DG7U]F;W)M7VYO<FUA;"<@/3X@(DYO
M<FUA;"(L"@DG7U]F;W)M7V%D=F%N8V5D)R`]/B`B061V86YC960B+`H*"2=?
M7VUA>%]D;VUA:6YS7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@)3(@9&]M86EN
M*',I('5S960[("4S(&%V86EL86)L92<L"@DG7U]M87A?9&]M86EN<U]N;U]L
M:6UI=%]U<V%G92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D;VUA:6YS('5S960G
M+`H))U]?;6%X7VUA:6QB;WAE<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R
M(&UA:6QB;W@H97,I('5S960[("4S(&%V86EL86)L92<L"@DG7U]M87A?;6%I
M;&)O>&5S7VYO7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@=6YL:6UI=&5D(&UA
M:6QB;WAE<R!U<V5D)RP*"2=?7V1I<VM?<W!A8V5?;&EM:71?=7-A9V4G(#T^
M("<E,2!O9B`E,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?9&ES:U]S<&%C
M95]N;U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D:7-K('-P
M86-E('5S960G+`H))U]?=')A9F9I8U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F
M("4R('5S960[("4S(&%V86EL86)L92<L"@DG7U]T<F%F9FEC7VYO7VQI;6ET
M7W5S86=E)R`]/B`G)3$@;V8@=6YL:6UI=&5D('1R869F:6,@=7-E9"<L"@DG
M7U]M87A?<W5B9&]M86EN<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R('-U
M8F1O;6%I;BAS*2!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?;6%X7W-U8F1O
M;6%I;G-?;F]?;&EM:71?=7-A9V4G(#T^("<E,2!O9B!U;FQI;6ET960@<W5B
M9&]M86EN<R!U<V5D)RP*"@DG7U]M96U?=7-A9V5?:6YF;R<@/3X@)R4Q(&]F
M("4R('5S960[("4S(&%V86EL86)L92<L"@DG7U]D:7-K7W5S86=E7VEN9F\G
M(#T^("<E,2!O9B`E,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H*"2=A8W1I;VYL
M;V=?7V-O;F9I<FU?8VQE86Y?;&]G)R`]/B`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!T:&4@<V5L96-T960@86-T:6]N(&QO9R!R96-O<F1S
M/R(L"@DG86-T:6]N;&]G7U]D:6=I=%]E>'!E8W1E9"<@/3X@(D$@;G5M8F5R
M(&5X<&5C=&5D.B`E,2(L"@DG86-T:6]N;&]G7U]D;VYT7W)E;6]V95]R96-S
M)R`]/B`B9&\@;F]T(')E;6]V92!R96-O<F1S(BP*"2=A8W1I;VYL;V=?7V9R
M;VU?9&%T92<@/3X@(F9R;VTZ(BP*"2=A8W1I;VYL;V=?7VEN8V]R<F5C=%]R
M;W1A=&EO;B<@/3X@(DEN=F%L:60@;&]G(')O=&%T:6]N('!A<F%M971E<G,@
M<W!E8VEF:65D.B`E,2(L"@DG86-T:6]N;&]G7U]J<U]I;F-O<G)E8W1?9&%T
M92<@/3X@(DEN=F%L:60@9&%T92!S<&5C:69I960B+`H))V%C=&EO;FQO9U]?
M:G-?:6YC;W)R96-T7VYU;5]P97)I;V1S)R`]/B`B26YV86QI9"!R;W1A=&EO
M;B!P97)I;V0@<W!E8VEF:65D(BP*"2=A8W1I;VYL;V=?7VIS7VEN8V]R<F5C
M=%]N=6U?<F5C;W)D<R<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(')E8V]R9',@
M<W!E8VEF:65D(BP*"2=A8W1I;VYL;V=?7VQO9V=E9%]A8W1I;VYS)R`]/B`B
M3&]G9V5D(&%C=&EO;G,B+`H))V%C=&EO;FQO9U]?<&5R:6]D7V1A>2<@/3X@
M(F1A>7,B+`H))V%C=&EO;FQO9U]?<&5R:6]D7VUO;G1H)R`]/B`B;6]N=&AS
M(BP*"2=A8W1I;VYL;V=?7W!E<FEO9%]W965K)R`]/B`B=V5E:W,B+`H))V%C
M=&EO;FQO9U]?<V5T=&EN9W,G(#T^(")!8W1I;VX@;&]G('-E='1I;F=S(BP*
M"2=A8W1I;VYL;V=?7W-T;W)E7VQO9W-?:6Y?9&(G(#T^(")3=&]R92!R96-O
M<F1S(&EN('1H92!D871A8F%S92(L"@DG86-T:6]N;&]G7U]S=&]R95]N=6UB
M97(G(#T^(")E;G1R:65S(BP*"2=A8W1I;VYL;V=?7W1O7V1A=&4G(#T^(")T
M;SHB+`H))V%C=&EO;FQO9U]?=6YK;F]W;E]R;W1?<&5R:6]D)R`]/B`B56YK
M;F]W;B!R;W1A=&EO;B!P97)I;V0Z("4Q(BP*"2=A8W1I;VYL;V=?7W5N:VYO
M=VY?<F]T7W1Y<&4G(#T^(")5;FMN;W=N(')O=&%T:6]N('1Y<&4Z("4Q(BP*
M"2=A8W1I;VYL;V=?7W=R;VYG7V1A=&5?<&5R:6]D)R`]/B`B26YV86QI9"!D
M871E(BP*"2=A8W1I;VYL;V=?7W-E<W-I;VY?<')E9F5R96YC97,G(#T^("=,
M;V=I;B!S971T:6YG<R<L"@H))V%C=&EO;FQO9U]?861M:6Y?:6YF;R<@/3X@
M)T%D;6EN:7-T<F%T;W(@:6YF;W)M871I;VXG+`H))V%C=&EO;FQO9U]?<V5R
M=FEC92<@/3X@)U-E<G9I8V4G+`H))V%C=&EO;FQO9U]?:7!?861D<B<@/3X@
M)TE0(&%D9')E<W,G+`H))V%C=&EO;FQO9U]?8VQI96YT)R`]/B`G0VQI96YT
M(&%C8V]U;G0G+`H))V%C=&EO;FQO9U]?8VQI96YT7W-T871U<R<@/3X@)T-L
M:65N="!A8V-O=6YT('-T871U<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?<')E
M9F5R96YC97,G(#T^(")#;&EE;G0G<R!I;G1E<F9A8V4@<')E9F5R96YC97,B
M+`H))V%C=&EO;FQO9U]?8VQI96YT7VQI;6ET<R<@/3X@)T-L:65N="!A8V-O
M=6YT(&QI;6ET<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?;&EM:71?<VEZ92<@
M/3X@(D1I<VL@<W!A8V4@;&EM:70@9F]R(&-L:65N="!A8V-O=6YT(BP*"2=A
M8W1I;VYL;V=?7V-L:65N=%]L:6UI=%]T<F%F9FEC)R`]/B`B5')A9F9I8R!L
M:6UI="!F;W(@8VQI96YT(&%C8V]U;G0B+`H))V%C=&EO;FQO9U]?8VQI96YT
M7W!E<FUI<W-I;VYS)R`]/B`B0VQI96YT)W,@<&5R;6ES<VEO;G,B+`H))V%C
M=&EO;FQO9U]?8VQI96YT7VEP7W!O;VPG(#T^(")#;&EE;G0G<R!)4"!P;V]L
M(BP*"2=A8W1I;VYL;V=?7V-L:65N=%]S:71E87!P)R`]/B`B0VQI96YT)W,@
M<VET92!A<'!L:6-A=&EO;B!P;V]L(BP*"2=A8W1I;VYL;V=?7V1O;6%I;E]U
M<V5R)R`]/B`G1&]M86EN(&%D;6EN:7-T<F%T;W(@86-C;W5N="<L"@DG86-T
M:6]N;&]G7U]D;VUA:6XG(#T^("=$;VUA:6XG+`H))V%C=&EO;FQO9U]?9&]M
M86EN7V]W;F5R)R`]/B`G1&]M86EN(&]W;F5R)RP*"2=A8W1I;VYL;V=?7V1O
M;6%I;E]S=&%T=7,G(#T^("=$;VUA:6X@<W1A='5S)RP*"2=A8W1I;VYL;V=?
M7V1O;6%I;E]D;G,G(#T^("=$;VUA:6X@1$Y3('IO;F4G+`H))V%C=&EO;FQO
M9U]?<W5B9&]M86EN)R`]/B`G4W5B9&]M86EN)RP*"2=A8W1I;VYL;V=?7V1A
M<VAB;V%R9%]P<F5S970G(#T^("=$97-K=&]P('!R97-E="<L"@DG86-T:6]N
M;&]G7U]D;VUA:6Y?86QI87,G(#T^("=$;VUA:6X@86QI87,G+`H))V%C=&EO
M;FQO9U]?9&]M86EN7V%L:6%S7V1N<R<@/3X@)T1O;6%I;B!A;&EA<R!$3E,@
M>F]N92<L"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71S)R`]/B`G1&]M86EN
M(&QI;6ET<R<L"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71?<VEZ92<@/3X@
M)T1I<VL@<W!A8V4@;&EM:70@9F]R(&1O;6%I;B<L"@DG86-T:6]N;&]G7U]D
M;VUA:6Y?;&EM:71?=')A9F9I8R<@/3X@)U1R869F:6,@;&EM:70@9F]R(&1O
M;6%I;B<L"@DG86-T:6]N;&]G7U]C<%]U<V5R)R`]/B`G0V]N=')O;"!P86YE
M;"!U<V5R)RP*"2=A8W1I;VYL;V=?7VUA:6QN86UE)R`]/B`G36%I;"!N86UE
M)RP*"2=A8W1I;VYL;V=?7VUA:6QL:7-T)R`]/B`G36%I;&EN9R!L:7-T)RP*
M"2=A8W1I;VYL;V=?7W!H;W-T:6YG)R`]/B`G4&AY<VEC86P@:&]S=&EN9R<L
M"@DG86-T:6]N;&]G7U]F;W)W87)D:6YG)R`]/B`G4W1A;F1A<F0@;W(@9G)A
M;64@9F]R=V%R9&EN9R!H;W-T:6YG)RP*"2=A8W1I;VYL;V=?7W=E8G5S97(G
M(#T^("=796(@=7-E<B!A8V-O=6YT)RP*"2=A8W1I;VYL;V=?7W-I=&5?87!P
M;&EC871I;VXG(#T^("=3:71E(&%P<&QI8V%T:6]N)RP*"2=A8W1I;VYL;V=?
M7W-I=&5?87!P;&EC871I;VY?<&%C:V%G92<@/3X@)U-I=&4@87!P;&EC871I
M;VX@<&%C:V%G92<L"@DG86-T:6]N;&]G7U]L:6-E;G-E)R`]/B`G3&EC96YS
M92!K97DG+`H*"2=A8W1I;VYL;V=?7VQI;6ET7W)E86-H960G(#T^("=R96%C
M:&5D)RP*"2=A8W1I;VYL;V=?7V%D9&5D)R`]/B`G861D960G+`H))V%C=&EO
M;FQO9U]?<F5M;W9E9"<@/3X@)W)E;6]V960G+`H))V%C=&EO;FQO9U]?8VAA
M;F=E)R`]/B`G8VAA;F=E9"<L"@DG86-T:6]N;&]G7U]U<&1A=&4G(#T^("=U
M<&1A=&5D)RP*"2=A8W1I;VYL;V=?7V5X<&ER960G(#T^("=E>'!I<F5D)RP*
M"2=A8W1I;VYL;V=?7V-R96%T92<@/3X@)V-R96%T960G+`H))V%C=&EO;FQO
M9U]?9&5L971E)R`]/B`G9&5L971E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E
M7W-T;W`G(#T^("=S=&]P<&5D)RP*"2=A8W1I;VYL;V=?7W-E<G9I8V5?<F5S
M=&%R="<@/3X@)W)E<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E7W-T
M87)T)R`]/B`G<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]L;V=I;B<@/3X@)VQO
M9V=E9"!I;B<L"@DG86-T:6]N;&]G7U]L;V=O=70G(#T^("=L;V=G960@;W5T
M)RP*"2=A8W1I;VYL;V=?7VEN<W1A;&PG(#T^("=I;G-T86QL960G+`H))V%C
M=&EO;FQO9U]?=6YI;G-T86QL)R`]/B`G=6YI;G-T86QL960G+`H))V%C=&EO
M;FQO9U]?<F5C;VYF:6=U<F4G(#T^("=R96-O;F9I9W5R960G+`H*"2=A9&UI
M;E]E9%]?961I=%]A9&UI;FES=')A=&]R7VEN9F\G(#T^(")%9&ET(&%D;6EN
M:7-T<F%T;W(@:6YF;W)M871I;VXB+`H))V%D;6EN7V5D7U]I7W=O=6QD7VQI
M:V5?<F5C:65V95]A;FYO=6YC92<@/3X@(DD@=V]U;&0@;&EK92!T;R!R96-E
M:79E('!E<FEO9&EC(&4M;6%I;',@9G)O;2!35W-O9G0L($EN8RX@86YN;W5N
M8VEN9R!N97<@<')O9'5C=',L(&1I<V-O=6YT<R!A;F0@;6]R92XB+`H))V%D
M;6EN7V5D7U]C<F5A=&5?9&5F875L=%]C;&EE;G0G(#T^("))('=O=6QD(&QI
M:V4@=&\@8W)E871E(&$@9&5F875L="!C;&EE;G0@86-C;W5N="XB+`H))V%D
M;6EN7V5D7U]U;F%B;&5?=7!D871E)R`]/B`B56YA8FQE('1O('5P9&%T92!A
M9&UI;FES=')A=&]R(&EN9F]R;6%T:6]N.B`E,2(L"@DG86YO;F9T<%]?86QL
M;W=?=7!L;V%D7VEN8V]M:6YG)R`]/B`B06QL;W<@=7!L;V%D:6YG('1O(&EN
M8V]M:6YG(&1I<F5C=&]R>2(L"@DG86YO;F9T<%]?86QL;W=?8W)E871E7V1I
M<G,G(#T^("=!;&QO=R!C<F5A=&EO;B!O9B!D:7)E8W1O<FEE<R!I;B!T:&4@
M:6YC;VUI;F<@9&ER96-T;W)Y)RP*"2=A;F]N9G1P7U]A;&QO=U]D;W=N;&]A
M9%]I;F-O;6EN9R<@/3X@)T%L;&]W(&1O=VYL;V%D:6YG(&9R;VT@=&AE(&EN
M8V]M:6YG(&1I<F5C=&]R>2<L"@DG86YO;F9T<%]?86YO;F9T<%]F;W)?9&]M
M86EN)R`]/B`B06YO;GEM;W5S($944"!A8V-O=6YT(&9O<B!T:&4@9&]M86EN
M(BP*"2=A;F]N9G1P7U]D:7-P;&%Y7VQO9VEN)R`]/B`G1&ES<&QA>2!L;V=I
M;B!M97-S86=E)RP*"2=A;F]N9G1P7U]L;V=I;E]T97AT)R`]/B`G365S<V%G
M92!T97AT)RP*"2=A;F]N9G1P7U]L;V=I;E]T97AT7VQI;6ET)R`]/B`B26YV
M86QI9"!M97-S86=E('1E>'0@;&5N9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O
M(#8U-3,S(&-H87)A8W1E<G,N(BP*"2=A;F]N9G1P7U]L;V=I;E]T97AT7V%S
M8VEI)R`]/B`B02!M97-S86=E('1E>'0@8V%N(&-O;G1A:6X@;VYL>2!!4T-)
M22!C:&%R86-T97)S+B(L"@DG86YO;F9T<%]?96YA8FQE9%]O;E]O=&AE<E]I
M<"<@/3X@(FES('5S960@;VX@86YO=&AE<B!)4"!A9&1R97-S(BP*"2=A;F]N
M9G1P7U]I;G9A;&ED7V)A;F1W:61T:"<@/3X@(DEN=F%L:60@9&]W;FQO860@
M8F%N9'=I9'1H('9A;'5E+"!O;FQY(&1I9VET<R!A<F4@86QL;W=E9"XB+`H)
M)V%N;VYF='!?7VEN=F%L:61?;6%X7V-O;FXG(#T^("));G9A;&ED(&YU;6)E
M<B!O9B!M87AI;75M('-I;75L=&%N96]U<R!C;VYN96-T:6]N<RP@;VYL>2!D
M:6=I=',@87)E(&%L;&]W960B+`H))V%N;VYF='!?7VEN=F%L:61?<75O=&$G
M(#T^("));G9A;&ED(&1I<VL@<W!A8V4@=F%L=64L(&]N;'D@9&EG:71S(&%R
M92!A;&QO=V5D+B(L"@DG86YO;F9T<%]?:7!?861D<F5S7W1Y<&5?<VAA<F5D
M)R`]/B`B2&]S=&EN9R!I<R!B87-E9"!O;B!T:&4@<VAA<F5D(&EP(&%D9')E
M<W,N(BP*"2=A;F]N9G1P7U]L:6UI=%]I;F-O;6EN9U]D:7-K7W-P86-E)R`]
M/B`B3&EM:70@9&ES:R!S<&%C92!I;B!T:&4@:6YC;VUI;F<@9&ER96-T;W)Y
M(BP*"2=A;F]N9G1P7U]L:6UI=%]M87AI;75M7V)A;F1W:61T:"<@/3X@(DQI
M;6ET(&1O=VYL;V%D(&)A;F1W:61T:"!F;W(@=&AI<R!V:7)T=6%L($944"!D
M;VUA:6XB+`H))V%N;VYF='!?7VQI;6ET7VUA>&EM=6U?8V]N;F5C=&EO;G,G
M(#T^("),:6UI="!N=6UB97(@;V8@<VEM=6QT86YE;W5S(&-O;FYE8W1I;VYS
M(BP*"2=A;F]N9G1P7U]U;F%B;&5?8W)E871E)R`]/B`B56YA8FQE('1O(&-R
M96%T92!A;F]N>6UO=7,@1E10(&%C8V]U;G0Z("4Q(BP*"2=A;F]N9G1P7U]U
M;F%B;&5?96YA8FQE)R`]/B`B1F%I;&5D('1O(&5N86)L92!A;F]N>6UO=7,@
M1E10(&%C8V]U;G0Z("4Q(BP*"2=A;F]N9G1P7U]U;F%B;&5?:6YI="<@/3X@
M(E5N86)L92!T;R!I;FET:6%L:7IE(&%N;VYY;6]U<R!&5%`@86-C;W5N=#H@
M)3$B+`H))V%N;VYF='!?7W5N86)L95]P=71?8V]N9B<@/3X@(E5N86)L92!T
M;R!P=70@8V]N9FEG=7)A=&EO;B!F:6QE.B`E,2(L"@DG86YO;F9T<%]?=6YA
M8FQE7W-E=%]Q=6]T82<@/3X@(E5N86)L92!T;R!S970@=&AE(&EN8V]M:6YG
M(&1I<F5C=&]R>2!D:7-K('-P86-E(&QI;6ET.B`E,2(L"@DG86YO;F9T<%]?
M=6YA8FQE7W5P9&%T92<@/3X@(E5N86)L92!T;R!U<&1A=&4@86YO;GEM;W5S
M($944"!A8V-O=6YT('!R;W!E<G1I97,Z("4Q(BP*"2=A=71H7U]U<&1A=&5?
M861M:6Y?:6YF;R<@/3X@(E!L96%S92!E;G1E<B!A9&UI;FES=')A=&]R)W,@
M:6YF;W)M871I;VXN(%1H:7,@:6YF;W)M871I;VX@:7,@<F5Q=6ER960@=&\@
M;W!E<F%T92`E,2XB+`H))V%U=&A?7W5P9&%T95]C;%]E;6%I;%]A;F1?<&AO
M;F4G(#T^(")0;&5A<V4@96YT97(@>6]U<B!E+6UA:6P@86YD('!H;VYE(&YU
M;6)E<BX@5&AE>2!W:6QL(&)E('5S960@=&\@;F]T:69Y('EO=2!O9B!P;W-S
M:6)L92!P<F]B;&5M<RXB+`H))V%U=&A?7WEO=5]N;W1?:&%V95]P97)M)R`]
M/B`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VYS('1O(&UA;F%G92!T:&ES
M(&1O;6%I;BXB+`H))V%U=&A?7VME>5]E>'!I<F5D7V%D;6EN)R`]/B`G66]U
M<B!L:6-E;G-E(&ME>2!H87,@97AP:7)E9"X@5&\@8V]N=&EN=64@=7-I;F<@
M>6]U<B!#;VYT<F]L(%!A;F5L('EO=2!M=7-T('!U<F-H87-E(&$@;F]N+65X
M<&ER:6YG(&-O;6UE<F-I86P@;&EC96YS92XG+`H))V%U=&A?7VME>5]E>'!I
M<F5D7V-L:65N="<@/3X@)U1H92!L:6-E;G-E(&ME>2!H87,@97AP:7)E9"X@
M4&QE87-E(&-O;G1A8W0@>6]U<B!S97)V:6-E('!R;W9I9&5R+B<L"@DG875T
M;VEN<W1A;&QE<E]?;F]T7VEN<W1A;&QE9"<@/3X@)T%U=&]I;G-T86QL97(@
M8V]M<&]N96YT(&ES(&YO="!I;G-T86QL960N)RP*"2=A=71O:6YS=&%L;&5R
M7U]R96QE87-E7V%C=&EO;B<@/3X@)T%V86EL86)L92!O<&5R871I;VYS)RP*
M"2=A=71O:6YS=&%L;&5R7U]R96QE87-E7V%C=&EO;E]I8V]N)R`]/B`G4R<L
M"@DG875T;VEN<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!G<F%D92<@/3X@
M)U5P9W)A9&EN9R!T;R!T:&4@;F5W(&-O;G1R;VP@<&%N96P@=F5R<VEO;B<L
M"@DG875T;VEN<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!D871E)R`]/B`G
M57!D871I;F<@;W(@861D:6YG(&YE=R!C;VUP;VYE;G1S)RP*"2=A=71O:6YS
M=&%L;&5R7U]R96QE87-E7V%C=&EO;E]U<#)D871E)R`]/B`G66]U(&AA=F4@
M86X@=7`@=&\@9&%T92!V97)S:6]N)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP
M;VYE;G1?86-T:6]N)R`]/B`G4W1A='5S)RP*"2=A=71O:6YS=&%L;&5R7U]C
M;VUP;VYE;G1?86-T:6]N7VEC;VXG(#T^("=3)RP*"2=A=71O:6YS=&%L;&5R
M7U]C;VUP;VYE;G1?86-T:6]N7VEN<W1A;&PG(#T^("=.;W0@:6YS=&%L;&5D
M)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE;G1?86-T:6]N7W5P9&%T92<@
M/3X@)T%N('5P9&%T92!I<R!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?
M7V-O;7!O;F5N=%]A8W1I;VY?=7!G<F%D92<@/3X@)T%N('5P9&%T92!I<R!A
M=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N=%]A8W1I;VY?
M=7`R9&%T92<@/3X@)UEO=2!H879E(&%N('5P('1O(&1A=&4@=F5R<VEO;B<L
M"@DG875T;VEN<W1A;&QE<E]?8V]M<&]N96YT7V%C=&EO;E]E<G)O<B<@/3X@
M)U5P9&%T97,@87)E(&YO="!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?
M7V-O;7!O;F5N=%]S97)V97)B=6EL9'1I;64G(#T^("=,871E<W0@<F5L96%S
M92<L"@DG875T;VEN<W1A;&QE<E]?8V]M<&]N96YT7VQO8V%L8G5I;&1T:6UE
M)R`]/B`G66]U<B!R96QE87-E)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE
M;G0G(#T^("=#;VUP;VYE;G0G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N
M=',G(#T^("=#;VUP;VYE;G1S)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE
M;G1S7W1I=&QE)R`]/B`G)3$@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE
M<E]?8V]M<&]N96YT7V1E<&5N9&5N8WE?;F]T92<@/3X@)W)E<75I<F5D(&9O
M<B!I;G-T86QL871I;VX@;V8@=&AE(&-O;7!O;F5N=',@>6]U('-E;&5C=&5D
M)RP*"2=A=71O:6YS=&%L;&5R7U]I;G-T86QL7V-O;F9I<FTG(#T^("=997,L
M($D@=VES:"!T;R!I;G-T86QL('1H97-E(&-O;7!O;F5N=',G+`H))V%U=&]I
M;G-T86QL97)?7VEN<W1A;&Q?8V]N9FER;5]R97%U97-T)R`]/B`G4&QE87-E
M('-E;&5C="!T:&4@8VAE8VMB;W@@=&\@8V]N9FER;2XG+`H))V%U=&]I;G-T
M86QL97)?7VEN<W1A;&Q?=&ET;&4G(#T^("=#;VYF:7)M($EN<W1A;&QA=&EO
M;B!O9B!T:&4@4V5L96-T960@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE
M<E]?:V5R;F5L7W5P9&%T95]C;VYF:7)M)R`]/B`G0V]N9FER;2!T:&4@:V5R
M;F5L('5P9&%T92<L"@DG875T;VEN<W1A;&QE<E]?:V5Y7W5P9&%T95]C;VYF
M:7)M)R`]/B`G0V]N9FER;2!S:VEP<&EN9R!K97D@=7!D871E(&%N9"!I;G-T
M86QL:6YG('1H92!D969A=6QT(&ME>2<L"@DG875T;VEN<W1A;&QE<E]?:V5Y
M7W5P9&%T95]C;VYF:7)M7W)E<75E<W0G(#T^("=0;&5A<V4@8VAE8VL@=&AE
M(&-H96-K8F]X('1O(&-O;F9I<FTN)RP*"2=A=71O:6YS=&%L;&5R7U]K97E?
M=7!D871E7V9A:6QE9"<@/3XG/'`^4&QE<VL@:7,@=6YA8FQE('1O('5P9&%T
M92!Y;W5R('!R;V1U8W0@;&EC96YS92X\+W`^)PH)"2X@)SQP/B4Q/"]P/B<*
M"0DN("<\<#Y#;VYT:6YU:6YG('=I=&@@=&AE('5P9W)A9&4@=VET:&]U="!H
M879I;F<@86X@87!P<F]P<FEA=&4@<')O9'5C="!L:6-E;G-E('=I;&P@<F5S
M=6QT(&EN('1H92!I;G-T86QL871I;VX@;V8@82!D969A=6QT(&QI8V5N<V4@
M=VET:"!L:6UI=&5D(&9U;F-T:6]N86QI='DN($%D;6EN:7-T<F%T;W)S(&%R
M92!A9'9I<V5D('1O(&9I<G-T(&%C<75I<F4@=&AE(&%P<')O<')I871E(&QI
M8V5N<V4@8F5F;W)E(&-O;G1I;G5I;F<@=VET:"!T:&4@<')O9'5C="!U<&=R
M861E+CPO<#XG+`H))V%U=&]I;G-T86QL97)?7V5M86EL)R`]/B`G4V5N9"!N
M;W1I8V4@=&\G+`H))V%U=&]I;G-T86QL97)?7V5M86EL7V%D;6EN)R`]/B`B
M061M:6YI<W1R871O<B=S(&4M;6%I;"(L"@DG875T;VEN<W1A;&QE<E]?96UA
M:6Q?96UA:6PG(#T^("=#=7-T;VT@92UM86EL(&%D9')E<W,N+BXG+`H))V%U
M=&]I;G-T86QL97)?7W)E;&5A<V4G(#T^("=296QE87-E(&YA;64G+`H))V%U
M=&]I;G-T86QL97)?7W)E;&5A<V5S)R`]/B`G079A:6QA8FQE(')E;&5A<V5S
M)RP*"2=A=71O:6YS=&%L;&5R7U]R96QE87-E<U]T:71L92<@/3X@)U!L97-K
M(%5P9&%T97(G+`H))V%U=&]I;G-T86QL97)?7W-E;&5C=%]C;VUP;VYE;G1S
M7W1O7VEN<W1A;&PG(#T^("=396QE8W0@=&AE(&-O;7!O;F5N=',@=&\@8F4@
M:6YS=&%L;&5D)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?97)R;W(G(#T^
M("=%<G)O<CH@)3$N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L
M;%]E<G)O<B<@/3X@)TEN<W1A;&QA=&EO;B!C;W5L9"!N;W0@8F4@<W1A<G1E
M9#H@)3$N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]B=7-Y
M)R`]/B`G26YS=&%L;&%T:6]N(&-O=6QD(&YO="!B92!S=&%R=&5D.B!A;F]T
M:&5R(&EN<W1A;&QA=&EO;B!P<F]C961U<F4@:7,@8W5R<F5N=&QY(')U;FYI
M;F<N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]O:R<@/3X@
M)TEN<W1A;&QA=&EO;B!S=&%R=&5D+B!9;W4@=VEL;"!B92!N;W1I9FEE9"!O
M9B!I;G-T86QL871I;VX@<')O9W)E<W,@8GD@92UM86EL("@E,2DN)RP*"2=A
M=71O:6YS=&%L;&5R7U]S=&%T=7-?<75E<GE?8G5S>2<@/3X@)TEN<W1A;&QA
M=&EO;B!I<R!I;B!P<F]G<F5S<RXG+`H))V%U=&]I;G-T86QL97)?7W-T871U
M<U]Q=65R>5]E<G)O<B<@/3X@)U5N86)L92!T;R!R971R:65V92!I;G-T86QL
M871I;VX@<W1A='5S.B`E,2<L"@DG875T;VEN<W1A;&QE<E]?8V]N9FEG=7)E
M7W1I=&QE)R`]/B`G57!D871E<B!3971T:6YG<R<L"@DG875T;VEN<W1A;&QE
M<E]?<')E9F5R96YC97-?;&5G96YD)R`]/B`G4V5T=&EN9W,G+`H))V%U=&]I
M;G-T86QL97)?7W-O=7)C95]T>7!E)R`]/B`G4V]U<F-E('1Y<&4G+`H))V%U
M=&]I;G-T86QL97)?7W-O=7)C95]T>7!E7VEN=F%L:60G(#T^("=);G9A;&ED
M('-O=7)C92!T>7!E)RP*"2=A=71O:6YS=&%L;&5R7U]S;W5R8V5?='EP95]P
M;&5S:R<@/3X@)U!L97-K('5P9&%T92!S97)V97(G+`H))V%U=&]I;G-T86QL
M97)?7W-O=7)C95]T>7!E7VYE='=O<FLG(#T^("=.971W;W)K('-T;W)A9V4G
M+`H))V%U=&]I;G-T86QL97)?7W-O=7)C95]I;G9A;&ED)R`]/B`G26YV86QI
M9"!S;W5R8V4G+`H))V%U=&]I;G-T86QL97)?7W-O=7)C95]I;G9A;&ED7VYE
M='=O<FLG(#T^("=);G9A;&ED('-O=7)C92!54DP@*'-A;7!L93H@:'1T<#HO
M+W-O=7)C92P@9G1P.B\O<V]U<F-E*2<L"@DG875T;VEN<W1A;&QE<E]?<V]U
M<F-E)R`]/B`G4V]U<F-E(%523"<L"@DG875T;VEN<W1A;&QE<E]?=&%R9V5T
M)R`]/B`G5&5M<&]R87)Y(&1O=VYL;V%D(&1I<F5C=&]R>2<L"@DG875T;VEN
M<W1A;&QE<E]?=&%R9V5T7VEN=F%L:60G(#T^(")3<&5C:69Y(&%B<V]L=71E
M('!A=&@B+`H))V%U=&]I;G-T86QL97)?7V-H96-K7W5P9&%T97,G(#T^("=#
M:&5C:R!F;W(@=7!D871E<R!U<&]N(&%D;6EN:7-T<F%T;W)<)W,@;&]G:6X@
M=&\@8V]N=')O;"!P86YE;"XG+`H))V%U=&]I;G-T86QL97)?7V-H96-K7W5P
M9&%T97-?=V%R;FEN9R<@/3X@)TYE=R`\82!H<F5F/2(E,2(^=7!D871E<SPO
M83X@87)E(&%V86EL86)L92!F;W(@)3(@)RP*"2=B86-K=7!?7W!E<FEO9"<)
M/3X@)T)A8VMU<"!P97)I;V0G+`H))V)A8VMU<%]?<F5P;W-I=&]R>2<]/B`G
M0F%C:W5P(&9I;&5S(')E<&]S:71O<GD@;&]C871I;VXG+`H))V)A8VMU<%]?
M;6%X7V1U;7!?9FEL97,G"3T^("=.=6UB97(@;V8@8F%C:W5P(&9I;&5S('-T
M;W)E9"!I;B!R97!O<VET;W)Y)RP*"2=B86-K=7!?7V9I;&5N86UE7W!R969I
M>"<]/B`G061D('!R969I>"!T;R!B86-K=7`@9FEL92!N86UE<R<L"@DG8F%C
M:W5P7U]E<G)O<E]N;W1I9GE?96UA:6PG(#T^("=396YD(&YO=&EF:6-A=&EO
M;B!O;B!E<G)O<G,@:68@86YY(&]C8W5R(&1U<FEN9R!B86-K=7`@=&\@96UA
M:6PG+`H))V)A8VMU<%]?9'5M<%]I;F9O)R`]/B`B0F%C:W5P(&EN9F]R;6%T
M:6]N(BP*"2=B86-K=7!?7V1U;7!?9FEL95]N86UE7VYO=%]D969I;F5D)R`]
M/B`B0F%C:W5P(&9I;&4@;F%M92!I<R!N;W0@<W!E8VEF:65D(BP*"2=B86-K
M=7!?7V9T<%]A8V-O=6YT)R`]/B`B1E10(&%C8V]U;G0@9F]R(')E;6]T92!R
M97!O<VET;W)Y(BP*"2=B86-K=7!?7V-R;VY?8F%C:W5P7W1A<VM?<')E9G,G
M(#T^(")38VAE9'5L960@0F%C:W5P(BP*"2=B86-K=7!?7V9T<%]A8V-O=6YT
M7V9O<E]B86-K=7`G(#T^(")&5%`@86-C;W5N="!P<F5F97)E;F-E<R(L"@DG
M8F%C:W5P7U]L;V-A;%]F:6QE)R`]/B`G3&]C86P@8F%C:W5P(&9I;&4G+`H)
M)V)A8VMU<%]?9&]M86EN7V1U;7!S)R`]/B`G;&]C86P@<F5P;W-I=&]R>2<L
M"@DG8F%C:W5P7U]D;VUA:6Y?9G1P)R`]/B`G<F5M;W1E($944"!S97)V97(G
M+`H))V)A8VMU<%]?=W)O;F=?<&%T:"<@/3X@(DEN8V]R<F5C="!P871H('1O
M('1H92!B86-K=7`@9FEL97,@<F5P;W-I=&]R>3H@1&\@;F]T('5S92!T:&4@
M<V5Q=65N8V4@;V8@8VAA<F%C=&5R<R`N+B\N+B\B+`H))V)A8VMU<%]?=6YA
M8FQE7W1O7V-O;FYE8W1?=&]?9G1P7W-E<G9E<B<]/B`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@1E10('-E<G9E<CH@)3$B+`H))V)A8VMU<%]?8F%C:W5P7W1A
M<VM?9&]E<U]N;W1?97AI<W0G(#T^(")"86-K=7`@=&%S:R!D;V5S(&YO="!E
M>&ES="P@>6]U('-H;W5L9"!C<F5A=&4@:70@8F5F;W)E('1U<FYI;F<@;VXN
M(BP*"2=B86-K=7!?7W)E<W1O<F5?<&%R86US)R`]/B`B4F5S=&]R92!P87)A
M;65T97)S(BP*"2=B86-K=7!?7V-O;F9I<FUA=&EO;B<@/3X@(E=A<FYI;F<Z
M('1H92!D;VUA:6X@=VEL;"!N;W0@8F4@879A:6QA8FQE(&1U<FEN9R!B86-K
M=7`O<F5S=&]R:6YG+B(L"@DG8F%C:W5P7U]D=6UP9FEL95]I<U]N;W1?97AI
M<W0G(#T^(")"86-K=7`@9FEL92!D;V5S(&YO="!E>&ES="XB+`H))V)A8VMU
M<%]?8F%C:W5P7VUE=&AO9"<)/3X@)T)A8VMU<"!M971H;V0G+`H))V)A8VMU
M<%]?9'5M<&9I;&5?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA;64B+`H))V)A
M8VMU<%]?9'5M<&9I;&5?;F%M95]I<U]I;G9A;&ED)R`]/B`B0F%C:W5P(&9I
M;&4@;F%M92!I<R!I;G9A;&ED.B!5<V4@;VYL>2!A;'!H86YU;65R:6,L(&1A
M<V@L(&1O="!A;F0@=6YD97)S8V]R92!S>6UB;VQS+"!D;R!N;W0@=7-E(&YA
M;64@;&EK92!D97-C<FEP=&EO;BXJ(&%S(&)A8VMU<"!F:6QE(&YA;64N(BP*
M"2=B86-K=7!?7V1U;7!F:6QE7VYA;65?:7-?;F]T7V1E9FEN960G(#T^(")"
M86-K=7`@9FEL92!N86UE(&ES('5N9&5F:6YE9"XB+`H))V)A8VMU<%]?96UA
M:6Q?<F5Q=6ER960G(#T^(")9;W5R(&4M;6%I;"!A9&1R97-S(&ES(')E<75I
M<F5D('1O(&ME97`@>6]U(&EN9F]R;65D(&]F('1H92!B86-K=7`O<F5S=&]R
M:6YG('!R;V-E9'5R92!P<F]G<F5S<RX@4&QE87-E('-P96-I9GD@>6]U<B!E
M+6UA:6P@:6X@=&AE(&%C8V]U;G0@9&5T86EL<RXB+`H))V)A8VMU<%]?97)R
M;W)?9'5R:6YG7V)A8VMU<"<@/3X@(E5N86)L92!T;R!C<F5A=&4@=&AE(&)A
M8VMU<"!F:6QE.B`E,2(L"@DG8F%C:W5P7U]I;G!U=%]E;6%I;%]W87)N:6YG
M)R`]/B`B66]U('-H;W5L9"!E:71H97(@<W!E8VEF>2!E+6UA:6P@9F]R(&YO
M=&EF:6-A=&EO;B!O<B!D97-E;&5C="!T:&4@8VAE8VMB;W@N(BP*"2=B86-K
M=7!?7VUA:V5?9&]W;FQO860G(#T^(")D;R!N;W0@<W1O<F4@=&AE(&)A8VMU
M<"!F:6QE(&EN(')E<&]S:71O<GDL(&]N;'D@9&]W;FQO860@:70B+`H))V)A
M8VMU<%]?;6%K95]D=6UP)R`]/B`G8W)E871E(&)A8VMU<"!F:6QE(&%N9"!S
M=&]R92!I;B!L;V-A;"!R97!O<VET;W)Y)RP*"2=B86-K=7!?7VUA:V5D=6UP
M7W1O7V9T<"<@/3X@)V-R96%T92!B86-K=7`@9FEL92!A;F0@<W1O<F4@;VX@
M<F5M;W1E($944"!S97)V97(G+`H))V)A8VMU<%]?9G1P7W-E<G9E<B<@/3X@
M(D944"!S97)V97(B+`H))V)A8VMU<%]?9G1P7V)A<V5D:7(G(#T^(")0871H
M('1O(&)A8VMU<"!F:6QE<R!R97!O<VET;W)Y(&]N($944"!S97)V97(B+`H)
M)V)A8VMU<%]?;F]T:69I8V%T:6]N7V5M86EL)R`]/B`B3F]T:69Y(&)Y(&4M
M;6%I;"(L"@DG8F%C:W5P7U]N;W1I9GE?96UA:6Q?:7-?:6YV86QI9"<@/3X@
M(DEN8V]R<F5C="!E+6UA:6P@861D<F5S<R!F;W(@8F%C:W5P+W)E<W1O<FEN
M9R!P<F]G<F5S<R!N;W1I9FEC871I;VX@:7,@<W!E8VEF:65D+B(L"@DG8F%C
M:W5P7U]R97-T;W)E7VEP)R`]/B`B25`@861D<F5S<R!F;W(@<F5S=&]R871I
M;VXB+`H))V)A8VMU<%]?<V5L96-T7V1U;7!F:6QE)R`]/B`B4V5L96-T(&$@
M8F%C:W5P(&9I;&4N(BP*"2=B86-K=7!?7W1I;64G(#T^(")"86-K=7`@=&EM
M92(L"@DG8F%C:W5P7U]V:65W7V1U;7!?:6YF;R<@/3X@(E9I97<@=&AE(&)A
M8VMU<"!I;F9O<FUA=&EO;B!F;W(@9&]M86EN("4Q(BP*"2=B86-K=7!?7W=R
M;VYG7V1O;6%I;E]N86UE)R`]/B`B5&AE(&)A8VMU<"!F:6QE(&-O;G1A:6YS
M('1H92!D871A(&]F(&1O;6%I;B`E,2!A;F0@=&AE<F5F;W)E(&-A;FYO="!B
M92!R97-T;W)E9"!O;B!D;VUA:6X@)3(B+`H))V)A8VMU<%]?:6YC;W)R96-T
M7V9T<%]U<V5R7V]R7W!A<W-W9"<@/3X@(DEN8V]R<F5C="!&5%`@=7-E<B!O
M<B!P87-S=V]R9"X@4&QE87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R
M=&EE<R(L"@DG8F%C:W5P7U]A8V-E<W-?9&5N:65D)R`]/B`B06-C97-S(&1E
M;FEE9"X@4&QE87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R=&EE<R(L
M"@DG8F%C:W5P7U]C;W5L9&YO=%]R97-O;'9E7VAO<W0G(#T^(")#;W5L9&XG
M="!R97-O;'9E(&AO<W0@)3$B+`H))V)A8VMU<%]?<F5S=&]R95]F<F]M)R`]
M/B`B4F5S=&]R92`E,2(L"@DG8F%C:W5P7U]D;VUA:6Y?<V5S<VEO;E]F86EL
M960G(#T^("=$;VUA:6X@)3$@=V%S(&YO="!B86-K960@=7`G+`H))V)A8VMU
M<%]?8VQI96YT7W-E<W-I;VY?9F%I;&5D)R`]/B`G0VQI96YT("4Q('=A<R!N
M;W0@8F%C:V5D('5P)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7W)E<W1O
M<F5?9F%I;&5D)R`]/B`G1&]M86EN("4Q('=A<R!N;W0@<F5S=&]R960G+`H)
M)V)A8VMU<%]?8VQI96YT7W-E<W-I;VY?<F5S=&]R95]F86EL960G(#T^("=#
M;&EE;G0@)3$@=V%S(&YO="!R97-T;W)E9"<L"@DG8F%C:W5P7U]D;VUA:6Y?
M<V5S<VEO;E]C;VUP;&5T92<@/3X@)T1O;6%I;B`E,2!W87,@8F%C:V5D('5P
M)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7V)A8VMU<"<@/3X@)T)A8VMU
M<"!O9B!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8VQI96YT7W-E<W-I;VY?8F%C
M:W5P)R`]/B`G0F%C:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA
M:6Y?<W1O<%]T:71L92<@/3X@)T-A;F-E;&QI;F<@8F%C:W5P(&]F(&1O;6%I
M;B`E,2<L"@DG8F%C:W5P7U]C;&EE;G1?<W1O<%]T:71L92<@/3X@)T-A;F-E
M;&QI;F<@8F%C:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?
M<F5S=&]R95]S=&]P7W1I=&QE)R`]/B`G0V%N8V5L;&QI;F<@<F5S=&]R92!O
M9B!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8VQI96YT7W)E<W1O<F5?<W1O<%]T
M:71L92<@/3X@)T-A;F-E;&QI;F<@<F5S=&]R92!O9B!C;&EE;G0@)3$G+`H)
M)V)A8VMU<%]?9&]M86EN7W-E<W-I;VY?8F%C:W5P7W-T;W`G(#T^("=9;W4@
M87)E(&%B;W5T('1O(&-A;F-E;"!T:&4@86-T:79E(&)A8VMU<"!P<F]C97-S
M(2!"86-K=7`@9FEL92!W:6QL(&YO="!B92!C<F5A=&5D+B<L"@DG8F%C:W5P
M7U]B86-K=7!?<W1O<%]C;VYF:7)M)R`]/B`G665S+"!)('=A;G0@=&\@<W1O
M<"!T:&4@8F%C:W5P('!R;V-E<W,G+`H))V)A8VMU<%]?<F5S=&]R95]S=&]P
M7V-O;F9I<FTG(#T^("=997,L($D@=V%N="!T;R!S=&]P('1H92!R97-T;W)E
M('!R;V-E<W,G+`H))V)A8VMU<%]?9&]M86EN7W-E<W-I;VY?<F5S=&]R92<@
M/3X@)U)E<W1O<F4@;V8@9&]M86EN("4Q)RP*"2=B86-K=7!?7V1O;6%I;E]S
M97-S:6]N7W)E<W1O<F5?<W1O<"<@/3X@)UEO=2!A<F4@86)O=70@=&\@8V%N
M8V5L('1H92!A8W1I=F4@<F5S=&]R92!P<F]C97-S(2<L"@DG8F%C:W5P7U]D
M;VUA:6Y?8F%C:W5P7V9I;&5?:6YF;R<@/3X@)T1O;6%I;B!"86-K=7`@1FEL
M92!);F9O<FUA=&EO;B<L"@DG8F%C:W5P7U]D;VUA:6Y?8F%C:W5P7V9I;&5?
M;&ES="<@/3X@)V5X:7-T:6YG(&)A8VMU<"!F:6QE<R<L"@DG8F%C:W5P7U]D
M;VUA:6Y?8F%C:W5P7W!R;V=R97-S)R`]/B`G4')O9W)E<W,@;V8@9&]M86EN
M("4Q(&)A8VMU<"<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P<F]G<F5S
M<R<@/3X@)U!R;V=R97-S(&]F(&1O;6%I;B`E,2!R97-T;W)E)RP*"2=B86-K
M=7!?7V1O;6%I;E]B86-K=7!?<')O9W)E<W-?96QA<'-E9%]T:6UE)R`]/B`G
M16QA<'-E9"!T:6UE.B`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P
M<F]G<F5S<U]E;&%P<V5D7W1I;64G(#T^("=%;&%P<V5D('1I;64Z("4Q)RP*
M"2=B86-K=7!?7VEP7VUA<%]L96=E;F0G(#T^("=)4"!-87!P:6YG)RP*"2=B
M86-K=7!?7VEP7VUA<%]L:7-T7V-O=6YT)R`]/B`G25`@061D<F5S<V5S)RP*
M"2=B86-K=7!?7V1O;6%I;E]R97-T;W)E7W-E<W-I;VY?8V]M<&QE=&4G(#T^
M("=$;VUA:6X@)3$@:7,@<F5S=&]R960G+`H))V)A8VMU<%]?9&]M86EN7W)E
M<W1O<F5?<V5S<VEO;E]C;VUP;&5T95]M97-S86=E)R`]/B`G1&]M86EN("4Q
M(&AA<R!B965N(')E<W1O<F5D)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?
M9FEL95]D96QE=&4G(#T^("=4:&4@9F]L;&]W:6YG(&)A8VMU<"!F:6QE<R!W
M:6QL(&)E(')E;6]V960Z)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?9FEL
M95]F;W)?<F5M;W9E)R`]/B`G4V5L96-T(&)A8VMU<"!F:6QE<R!Y;W4@=VES
M:"!T;R!R96UO=F4G+`H))V)A8VMU<%]?8F%C:W5P7V]V97)W<FET95]F:6QE
M7V-O;F9I<FTG(#T^("=297!L86-E;65N="!C;VYF:7)M871I;VXG+`H))V)A
M8VMU<%]?8F%C:W5P7V]V97)W<FET95]F:6QE7V-O;F9I<FU?=&5X="<@/3X@
M)T)A8VMU<"!F:6QE('=I=&@@=&AE(&YA;64@(B4Q(B!A;')E861Y(&5X:7-T
M<RX@1&\@>6]U('=A;G0@=&\@<F5P;&%C92!I=#\G+`H))V)A8VMU<%]?8F%C
M:W5P7V-O;F9I<FU?;W9E<G=R:71E)R`]/B`G0V]N9FER;2!F:6QE(')E<&QA
M8V5M96YT)RP*"2=B86-K=7!?7V)A8VMU<%]O=F5R=W)I=&5?;&5G96YG)R`]
M/B`G4F5P;&%C92<L"@DG8F%C:W5P7U]B86-K=7!?;F]T7V-O;G1A:6Y?9&]M
M86EN)R`]/B`G0F%C:W5P(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!I;F9O<FUA
M=&EO;B!A8F]U="!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8F%C:W5P7VYO=%]C
M;VYT86EN7V-L:65N="<@/3X@)T)A8VMU<"!F:6QE(&1O97,@;F]T(&-O;G1A
M:6X@:6YF;W)M871I;VX@86)O=70@8VQI96YT("4Q)RP*"2=B86-K=7!?7V)A
M8VMU<%]C;&EE;G1?:6YF;R<@/3X@(D)A8VMU<"!C;&EE;G0G<R!P<F5F97)E
M;F-E<R!A;F0@86-C;W5N="!D971A:6QS(BP*"2=B86-K=7!?7V-L:65N=%]B
M86-K=7!?<')O9W)E<W,G(#T^("=0<F]G<F5S<R!O9B!#;&EE;G0@)3$@0F%C
M:W5P)RP*"2=B86-K=7!?7V-L:65N=%]S97-S:6]N7V-O;7!L971E)R`]/B`G
M0VQI96YT("4Q(&ES(&)A8VME9"!U<"<L"@DG8F%C:W5P7U]C;&EE;G1?8F%C
M:W5P7V9I;&5?:6YF;R<@/3X@)T-L:65N="!"86-K=7`@1FEL92!);F9O<FUA
M=&EO;B<L"@DG8F%C:W5P7U]R97-T;W)E7V-L:65N=%]I;F9O)R`]/B`B4F5S
M=&]R92!C;&EE;G0G<R!P<F5F97)E;F-E<R!A;F0@86-C;W5N="!D971A:6QS
M(BP*"2=B86-K=7!?7V-L:65N=%]S97-S:6]N7W)E<W1O<F4G(#T^("=297-T
M;W)I;F<@0VQI96YT("4Q)RP*"2=B86-K=7!?7V-L:65N=%]D8E]S97)V97)?
M;6%P)R`]/B`G1&%T86)A<V4@4V5R=F5R<R!-87!P:6YG)RP*"2=B86-K=7!?
M7V1O;6%I;E]D8E]S97)V97)?;6%P)R`]/B`G1&%T86)A<V4@4V5R=F5R<R!-
M87!P:6YG)RP*"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W-E<W-I;VY?8V]M
M<&QE=&5?;65S<V%G92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!R97-T;W)E
M9"XG+`H))V)A8VMU<%]?8VQI96YT7W)E<W1O<F5?<V5S<VEO;E]C;VUP;&5T
M92<@/3X@)T-L:65N="`E,2!R97-T;W)E9"<L"@DG8F%C:W5P7U]R97-T;W)E
M7W-E;&5C=%]S;VUE)R`]/B`G4&QE87-E('-E;&5C="!O8FIE8W1S('EO=2!W
M:7-H('1O(')E<W1O<F4N)RP*"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W!R
M;V=R97-S)R`]/B`G4')O9W)E<W,@;V8@0VQI96YT("4Q(%)E<W1O<F4G+`H)
M)V)A8VMU<%]?;F5W7V)A8VMU<"<@/3X@)T-R96%T:6YG($YE=R!"86-K=7`G
M+`H))V)A8VMU<%]?9&]N92<@/3X@)T1O;F4Z)RP*"2=B86-K=7!?7V1O;F5?
M9&]M86EN<R<@/3X@)R4Q(&1O;6%I;BAS*2!O=70@;V8@)3(G+`H))V)A8VMU
M<%]?9&]N95]C;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I(&]U="!O9B`E,B<L
M"@DG8F%C:W5P7U]R96UA:6YI;F<G(#T^("=296UA:6YI;F<Z)RP*"2=B86-K
M=7!?7W)E;6%I;FEN9U]D;VUA:6YS)R`]/B`G)3$@9&]M86EN*',I)RP*"2=B
M86-K=7!?7W)E;6%I;FEN9U]C;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I)RP*
M"2=B86-K=7!?7V]V97)A;&Q?8F%C:W5P7W!R;V=R97-S)R`]/B`G3W9E<F%L
M;"!B86-K=7`@<')O9W)E<W,G+`H))V)A8VMU<%]?8V]M;65N=%]N7V$G(#T^
M("=N+V$G+`H))V)A8VMU<%]?8V]M;6%N9%]I9VYO<F4G(#T^("=#;VUM86YD
M("(E,2(@:7,@:6=N;W)E9"<L"@DG8F%C:W5P7U]N;W1?8F%C:W5P7V9I;&4G
M(#T^("=.;W0@82!B86-K=7`@9FEL92<L"@DG8F%C:W5P7U]D8E]S97)V97)?
M;6%P<&EN9R<@/3X@)U-E;&5C="!T:&4@9&%T86)A<V4@<V5R=F5R(&-O;F9I
M9W5R960@:6X@4&QE<VL@=&\@=VAI8V@@>6]U('=I<V@@=&\@;6%P('1H92!D
M871A8F%S92!S97)V97(@9G)O;2!B86-K=7`N)RP*"2=B86-K=7!?7W5N86)L
M95]U<&1A=&4G(#T^("=5;F%B;&4@=&\@=7!D871E('-C:&5D=6QE9"!B86-K
M=7`@:6YF;W)M871I;VXZ("4Q)RP*"2=B86-K=7!?7VYO7V]B:F5C=',G(#T^
M("=T:&5R92!A<F4@;F\@;V)J96-T<R!F;W(@8F%C:W5P)RP*"2=B86-K=7!?
M7V-L:5]W87)N:6YG7VYO=%]E;F]U9VA?:7`G(#T^("=705).24Y'.B!N;W0@
M96YO=6=H($E0(&%D9')E<W-E<R!T;R!P97)F;W)M(&1E9F%U;'0@25`@;6%P
M<&EN9SH@)RP*"2=B=%]B86-K=7!?;F]W)R`]/B`B0F%C:W5P($YO=R(L"@DG
M8G1?;F5W7W)E<W1O<F4G(#T^(")297-T;W)E(BP*"2=B=%]B86-K=7!?<V-H
M961U;&4G(#T^(")38VAE9'5L960@0F%C:W5P(BP*"2=B86-K=7!?97AI<W1?
M8F%C:W5P<R<@/3X@(D5X:7-T:6YG(&)A8VMU<"!F:6QE<R(L"@DG8F%C:W5P
M7V1I86QO9U]?<&%G95]T:71L92<@/3X@(D)A8VMU<"!&:6QE($-R96%T:6]N
M(BP*"2=B86-K=7!?9&EA;&]G7U]P;&5A<V5?=V%I="<@/3X@(E1H92!B86-K
M=7`@<')O8V5S<R!I<R!A8F]U="!T;R!B96=I;BX@)3$@5&AI<R!O<&5R871I
M;VX@;6EG:'0@=&%K92!S;VUE('1I;64N("4R(%!L96%S92!W86ET+BXN("4S
M(BP*"2=D=6UP7V9I;&5?7VEN8V]R<F5C=%]F:6QE;F%M92<@/3X@(E1H92!F
M:6QE<R!Y;W4@<W!E8VEF:65D(&%R92!N;W0@<&%R=',@;V8@=&AE('-A;64@
M;75L=&DM=F]L=6UE(&)A8VMU<"XB+`H))V1U;7!?9FEL95]?:6YC;W)R96-T
M7W-E<75E;F-E)R`]/B`B5W)O;F<@<V5Q=65N8V4@;V8@=F]L=6UE<R!S<&5C
M:69I960A(BP*"2=B=%]A8V-E<'0G(#T^(")!8V-E<'0B+`H))V)T7V%C8V5S
M<R<@/3X@(D%C8V5S<R(L"@DG8G1?86-T:6]N7VQO9R<@/3X@(D%C=&EO;B!,
M;V<B+`H))V)T7V%D9"<@/3X@(D%D9"(L"@DG8G1?861D7V-L:65N="<@/3X@
M(D%D9"!.97<@0VQI96YT(BP*"2=B=%]D871A8F%S95]S97)V97)?861D)R`]
M/B`G061D($1A=&%B87-E(%-E<G9E<B<L"@DG8G1?861D7VYE=U]C871E9V]R
M>2<@/3X@(D%D9"!.97<@0V%T96=O<GDB+`H))V)T7V%D9%]N97=?<')I;W)I
M='DG(#T^(")!9&0@3F5W(%!R:6]R:71Y(BP*"2=B=%]A9&1?;F5W7W%U975E
M)R`]/B`B061D($YE=R!1=65U92(L"@DG8G1?861D7VYE=U]T:6-K970G(#T^
M(")!9&0@3F5W(%1I8VME="(L"@DG8G1?861D7W-E<G9I8V5S)R`]/B`B061D
M(%-E<G9I8V5S(BP*"2=B=%]A9&1?861D<F5S<U]T;U]A8VPG(#T^("=!9&0@
M3F5W($%D9')E<W,G+`H))V)T7V%D9%]T;R<@/3X@(CP\($%D9"(L"@DG8G1?
M=&]?861D)R`]/B`B061D(#X^(BP*"2=B=%]T;U]E>&-L=7-I=F4G(#T^("(\
M/"!%>&-L=7-I=F4B+`H))V)T7W1O7W-H87)E9"<@/3X@(E-H87)E9"`^/B(L
M"@DG8G1?86YO;F9T<%]S=&%T<R<@/3X@(D%N;VXN1E10(%-T871S(BP*"2=B
M=%]A;F]N>6UO=7-?9G1P)R`]/B`B06YO;GEM;W5S($944"(L"@DG8G1?871T
M86-H)R`]/B`B071T86-H(BP*"2=B=%]A=71O:6YS=&%L;&5R)R`]/B`G57!D
M871E<B<L"@DG8G1?8F%C:R<@/3X@(CP\($)A8VLB+`H))V)T7V)A8VMU<"<@
M/3X@(D)A8VL@=7`B+`H))V)T7V)U>5]C97)T<R<@/3X@(D)U>2!#97)T<R(L
M"@DG8G1?8FQO8VME9%]D;VUA:6YS)R`]/B`G0FQA8VL@3&ES="<L"@DG8G1?
M8FQO8VME9%]D;VUA:6Y?861D)R`]/B`G061D($1O;6%I;B<L"@DG8G1?8V%N
M8V5L)R`]/B`B0V%N8V5L(BP*"2=B=%]C87)D)R`]/B`B0V%R9"(L"@DG8G1?
M8V5R="<@/3X@(D-E<G1I9FEC871E(BP*"2=B=%]C97)T7V%D9"<@/3X@(D%D
M9"!.97<@0V5R=&EF:6-A=&4B+`H))V)T7V-E<G1?8G5Y)R`]/B`B0G5Y($-E
M<G0B+`H))V)T7V-E<G1?<F5Q=65S="<@/3X@(E)E<75E<W0B+`H))V)T7V-E
M<G1?<V5L9E]S:6=N)R`]/B`B4V5L9BU3:6=N960B+`H))V)T7V-E<G1?=FEE
M=R<@/3X@(E9I97<@0V5R=',B+`H))V)T7V-E<G1I9FEC871E<R<@/3X@(D-E
M<G1I9FEC871E<R(L"@DG8G1?8V9?8V]N9FEG=7)E)R`]/B`B0V]L9$9U<VEO
M;B!3971T:6YG<R(L"@DG8G1?8VAA;F=E7W!A<W-W9"<@/3X@(D-H86YG92!0
M87-S=V]R9"(L"@DG8G1?8VQE86Y?;&]G)R`]/B`B0VQE87(@3&]G(BP*"2=B
M=%]C;&5A<B<@/3X@(D-L96%R(BP*"2=B=%]C;&EE;G1?=&5M<&QA=&5S)R`]
M/B`B0VQI96YT(%1E;7!L871E<R(L"@DG8G1?8VQI96YT<R<@/3X@(D-L:65N
M=',B+`H))V)T7V-O9&5P86=E7V-H86YG92<@/3X@)T-H86YG92!%;F-O9&EN
M9R<L"@DG8G1?8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT($EN9F\B+`H))V)T
M7V-O;6UO;E]A8VPG(#T^("=#;VUM;VX@04-,)RP*"2=B=%]C;VYF:6=U<F5?
M;6%I;&QI<W1S)R`]/B`B4V5T(%5P($UA:6QM86XB+`H))V)T7V-O;F9I9W5R
M95]O9&)C)R`]/B`B3T1"0R!3971T:6YG<R(L"@DG8G1?8V]P>2<@/3X@(D-O
M<'DB+`H))V)T7V-O<'E?;6]V92<@/3X@(D-O<'DO36]V92(L"@DG8G1?8W)E
M871E)R`]/B`B0W)E871E(BP*"2=B=%]C<F5A=&5?86-C;W5N="<@/3X@(D-R
M96%T92!.97<@06-C;W5N="(L"@DG8G1?8W)E871E7V1I<B<@/3X@(D%D9"!.
M97<@1&ER96-T;W)Y(BP*"2=B=%]C<F5A=&5?9FEL92<@/3X@(D%D9"!.97<@
M1FEL92(L"@DG8G1?8V]U;G1?<VEZ92<@/3X@(D-A;&-U;&%T92!3:7IE(BP*
M"2=B=%]C<F]N=&%B7W5N:7@G(#T^(")#<F]N=&%B(BP*"2=B=%]C<F]N=&%B
M7W=I;B<@/3X@(E-C:&5D=6QE<B(L"@DG8G1?8W5S=&]M7V)U='1O;E]N97<G
M(#T^(")!9&0@3F5W($)U='1O;B(L"@DG8G1?8W5S=&]M7V)U='1O;G,G(#T^
M(")#=7-T;VT@0G5T=&]N<R(L"@DG8G1?8W5S=&]M:7IE)R`]/B`B0W5S=&]M
M:7IE(BP*"2=B=%]D871A8F%S97,G(#T^(")$871A8F%S97,B+`H))V)T7V1A
M=&%B87-E7W-E<G9E<G,G(#T^("=$871A8F%S92!397)V97)S)RP*"2=B=%]D
M8E]U<W)?;F5W)R`]/B`B061D($YE=R!$871A8F%S92!5<V5R(BP*"2=B=%]D
M8E]N97<G(#T^(")!9&0@3F5W($1A=&%B87-E(BP*"2=B=%]D8E]P:'!M>6%D
M;6EN)R`]/B`B37E344P@061M:6XB+`H))V)T7V1B7W!H<'!G861M:6XG(#T^
M(")0;W-T9W)E4U%,($%D;6EN(BP*"2=B=%]D8G5S97)?9&5F875L="<@/3X@
M(D1E9F%U;'0@9F]R($1"(%=E8D%D;6EN(BP*"2=B=%]D96-L:6YE)R`]/B`B
M1&5C;&EN92(L"@DG8G1?9&5F875L="<@/3X@(D1E9F%U;'0B+`H))V)T7V1E
M9F%U;'1S)R`]/B`B1&5F875L=',B+`H))V)T7V1E;&5T92<@/3X@(D1E;&5T
M92(L"@DG8G1?9&ER96-T;W)I97,G(#T^(")$:7)E8W1O<FEE<R(L"@DG8G1?
M9&ES86)L92<@/3X@(D1I<V%B;&4B+`H))V)T7V1N<R<@/3X@(D1.4R(L"@DG
M8G1?9&YS7V%D9"<@/3X@(D%D9"!.97<@4F5C;W)D(BP*"2=B=%]D;G-R96-O
M<F1?861D)R`]/B`B061D($YE=R!296-O<F0B+`H))V)T7V1N<U]S;V$G(#T^
M(")33T$@4')E9F5R96YC97,B+`H))V)T7V1N<U]P<F5F97)E;F-E<R<@/3X@
M(D1.4R!0<F5F97)E;F-E<R(L"@DG8G1?9&]?8F%C:W5P)R`]/B`B0F%C:R!5
M<"(L"@DG8G1?9&]?<F5S=&]R92<@/3X@(E)E<W1O<F4B+`H))V)T7V1O7W5P
M;&]A9"<@/3X@(E5P;&]A9"(L"@DG8G1?9&]M86EN7W1E;7!L871E<R<@/3X@
M(D1O;6%I;B!496UP;&%T97,B+`H))V)T7V1O;6%I;E]U<V5R)R`]/B`B1&]M
M86EN($%D;6EN:7-T<F%T;W(B+`H))V)T7V1O;6%I;E]U<V5R7W!A<W-W9"<@
M/3X@(D1O;6%I;B!!9&UI;FES=')A=&]R(%!A<W-W;W)D(BP*"2=B=%]D;VUA
M:6YS)R`]/B`B1&]M86EN<R(L"@DG8G1?9&]W;FQO860G(#T^(")$;W=N;&]A
M9"(L"@DG8G1?9&]W;FQO861?;&]G)R`]/B`B1&]W;FQO860B+`H))V)T7V5D
M:70G(#T^(")%9&ET(BP*"2=B=%]E;F%B;&4G(#T^(")%;F%B;&4B+`H))V)T
M7V5V96YT;6=R)R`]/B`G179E;G0@36%N86=E<B<L"@DG8G1?979E;G1?:&%N
M9&QE<E]A9&0G(#T^("=!9&0@3F5W($5V96YT($AA;F1L97(G+`H))V)T7V5X
M<&]R="<@/3X@)T5X<&]R="<L"@DG8G1?97AT<F%S)R`]/B`B17AT<F%S(BP*
M"2=B=%]F:6QE7VUA;F%G97(G(#T^(")&:6QE($UA;F%G97(B+`H))V)T7V9I
M;FES:"<@/3X@(D9I;FES:"(L"@DG8G1?9G1P7V%C8V]U;G0G(#T^(")&5%`@
M06-C;W5N="!0<F]P97)T:65S(BP*"2=B=%]F;W)G971?<&%S<W=O<F0G(#T^
M(")&;W)G;W0@4&%S<W=O<F0_(BP*"2=B=%]F<%]S<VQ?=V5B861M:6XG(#T^
M(")&4"U34TP@5V5B861M:6XB+`H))V)T7V9P7W=E8F%D;6EN)R`]/B`B1E`@
M5V5B861M:6XB+`H))V)T7V9T<%]S=&%T<R<@/3X@(D944"!3=&%T<R(L"@DG
M8G1?9V5T7W!A<W-W;W)D)R`]/B`B1V5T(%!A<W-W;W)D(BP*"2=B=%]G;&]B
M86Q?8VAA;F=E<R<@/3X@(D=R;W5P($]P97)A=&EO;G,B+`H))V)T7VAE;'`G
M(#T^(")(96QP(BP*"2=B=%]H:61E7V%L:6%S97,G(#T^(")(:61E($%L:6%S
M97,B+`H))V)T7VAI9&5?=&]O;&)A<B<@/3X@)TAI9&4@=&]O;&)A<B<L"@DG
M8G1?:&ED95]S=6)D;VUA:6YS)R`]/B`B2&ED92!3=6)D;VUA:6YS(BP*"2=B
M=%]H;VUE)R`]/B`B2&]M92(L"@DG8G1?:&]S=&EN9R<@/3X@(DAO<W1I;F<B
M+`H))V)T7VEN<W1A;&PG(#T^("));G-T86QL(BP*"2=B=%]I;G1E<F9A8V5?
M;6%N86=E;65N="<@/3X@(DEN=&5R9F%C92!-86YA9V5M96YT(BP*"2=B=%]I
M<%]A;&EA<VEN9R<@/3X@(DE0($%D9')E<W-E<R(L"@DG8G1?:7!?861D)R`]
M/B`B061D($YE=R!)4"!!9&1R97-S(BP*"2=B=%]I<%]P;V]L)R`]/B`B25`@
M4&]O;"(L"@DG8G1?:V5Y7VEN9F\G(#T^("),:6-E;G-E($UA;F%G96UE;G0B
M+`H))V)T7VME>5]B=7EO;FQI;F5?861D;VYS)R`]/B`G3W)D97(@0V]N=')O
M;"!086YE;"!!9&0M3VYS)RP*"2=B=%]K97E?8G5Y;VYL:6YE7W5P9W)A9&5S
M)R`]/B`G3W)D97(@0V]N=')O;"!086YE;"!5<&=R861E<R<L"@DG8G1?:V5Y
M7V)U>6]N;&EN95]N97<G(#T^("=/<F1E<B!.97<@2V5Y)RP*"2=B=%]K97E?
M=7!D871E)R`]/B`G4F5T<FEE=F4@2V5Y<R<L"@DG8G1?:V5Y7W5P;&]A9"<@
M/3X@)U5P;&]A9"!+97DG+`H))V)T7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL
M;V%D($ME>2<L"@DG8G1?:V5Y7W)E=F5R="<@/3X@)U)O;&P@0F%C:R!+97DG
M+`H))V)T7VQI;6ET<R<@/3X@(DQI;6ET<R(L"@DG8G1?;&]C86QE7V%D9"<@
M/3X@)T%D9"!,;V-A;&4G+`H))V)T7VQO8V%L97,G(#T^("=,;V-A;&5S)RP*
M"2=B=%]L;V=?;6%N86=E<B<@/3X@(DQO9R!-86YA9V5R(BP*"2=B=%]L;V=I
M;B<@/3X@(DQO9VEN(BP*"2=B=%]L;V=O)R`]/B`B3&]G;R!3971U<"(L"@DG
M8G1?;&]G;U]D969A=6QT)R`]/B`B1&5F875L="!,;V=O(BP*"2=B=%]L;V=O
M7W-E;F1?;&EN:R<@/3X@(D%T=&%C:"!,:6YK(BP*"2=B=%]L;V=O7W-E;F1?
M;&]G;R<@/3X@(D%T=&%C:"!,;V=O(BP*"2=B=%]L;V=O=70G(#T^("),;V<@
M3W5T(BP*"2=B=%]L;V=R;W1A=&EO;B<@/3X@(DQO9R!2;W1A=&EO;B(L"@DG
M8G1?;6%I;"<@/3X@(DUA:6PB+`H))V)T7VUA:6Q?86QI87-?861D)R`]/B`B
M061D($YE=R!-86EL($%L:6%S(BP*"2=B=%]M86EL7V%L:6%S97,G(#T^(")-
M86EL($%L:6%S97,B+`H))V)T7VUA:6Q?9W)O=7!?861D)R`]/B`B061D($YE
M=R!-96UB97(B+`H))V)T7VUA:6Q?9W)O=7!S)R`]/B`B1W)O=7!S(BP*"2=B
M=%]M86EL7V1R=V5B)R`]/B`G1'(N5V5B)RP*"2=B=%]M86EL7VYA;65?861D
M)R`]/B`B061D($YE=R!-86EL($YA;64B+`H))V)T7VUA:6Q?<')E9F5R96YC
M97,G(#T^(")0<F5F97)E;F-E<R(L"@DG8G1?;6%I;%]G<F]U<"<@/3X@(DUA
M:6P@1W)O=7`B+`H))V)T7VUA:6Q?;6%I;&)O>"<@/3X@(DUA:6QB;W@B+`H)
M)V)T7VUA:6Q?<F5D:7)E8W0G(#T^(")2961I<F5C="(L"@DG8G1?;6%I;%]R
M97-P7V%D9"<@/3X@(D%D9"!.97<@075T;W)E<W!O;F1E<B(L"@DG8G1?;6%I
M;%]R97-P7V%T=&%C:%]A9&0G(#T^(")!9&0@3F5W($%T=&%C:&UE;G0B+`H)
M)V)T7VUA:6Q?<F5S<%]F:6QE<R<@/3X@(D%T=&%C:&UE;G0@1FEL97,B+`H)
M)V)T7VUA:6Q?<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*"2=B
M=%]M86EL7W-P86UF:6QT97(G(#T^(")3<&%M($9I;'1E<B(L"@DG8G1?;6%I
M;%]W96)M86EL)R`]/B`B5V5B36%I;"(L"@DG8G1?;6%I;&QI<W1?;F5W)R`]
M/B`B061D($YE=R!-86EL:6YG($QI<W0B+`H))V)T7VUA:6QL:7-T7VUE;6)E
M<E]N97<G(#T^(")!9&0@3F5W($UE;6)E<B(L"@DG8G1?;6%I;&QI<W1S)R`]
M/B`B36%I;&EN9R!,:7-T<R(L"@DG8G1?;6%I;&UA;B<@/3X@(DUA:6QM86XB
M+`H))V)T7VUA:V5?9'5M<"<@/3X@(D-R96%T92!"86-K=7`B+`H))V)T7VUA
M;F%G92<@/3X@(DUA;F%G92(L"@DG8G1?;6%S=&5R)R`]/B`B36%S=&5R(BP*
M"2=B=%]M:6=R871I;VY?;6%N86=E<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R
M)RP*"2=B=%]M:6=R871E)R`]/B`G36EG<F%T92<L"@DG8G1?;6]D=6QE<U]A
M9&0G(#T^("=!9&0@36]D=6QE)RP*"2=B=%]M;V1U;&5S7VUA;F%G92<@/3X@
M)TUA;F%G92!-;V1U;&5S)RP*"2=B=%]M;W9E)R`]/B`B36]V92(L"@DG8G1?
M;7!C)R`]/B`B37E0;&5S:RYC;VTB+`H))V)T7VYE=U]C;&EE;G0G(#T^(")!
M9&0@3F5W($-L:65N="!!8V-O=6YT(BP*"2=B=%]N97=?9&]M86EN)R`]/B`B
M061D($YE=R!$;VUA:6XB+`H))V)T7VYE>'0G(#T^(").97AT(#X^(BP*"2=B
M=%]N97AT7W!A9V4G(#T^(").97AT(BP*"2=B=%]N971W;W)K7V%D9"<@/3X@
M(D%D9"!.97<@3F5T=V]R:R(L"@DG8G1?;F]T:69I8V%T:6]N<R<@/3X@(DYO
M=&EF:6-A=&EO;G,B+`H))V)T7V]D8F-?9'-N7V%D9"<@/3X@(D%D9"!.97<@
M3T1"0R!$4TXB+`H))V)T7V]F9B<@/3X@(D]F9B(L"@DG8G1?;VLG(#T^(")/
M2R(L"@DG8G1?;VXG(#T^(")/;B(L"@DG8G1?;VY?;V9F)R`]/B`B3VXO3V9F
M(BP*"2=B=%]P9%]N97<G(#T^(")!9&0@3F5W($1I<F5C=&]R>2(L"@DG8G1?
M<&1?=7-E<E]N97<G(#T^(")!9&0@3F5W(%5S97(B+`H))V)T7W!E<FUI<W-I
M;VYS)R`]/B`B4&5R;6ES<VEO;G,B+`H))V)T7W!H<&UY861M:6XG(#T^(")0
M:'!->4%D;6EN(BP*"2=B=%]P:'!P9V%D;6EN)R`]/B`B4&AP4&=!9&UI;B(L
M"@DG8G1?<&]S=&=R95]S<6PG(#T^(")0;W-T9W)E4U%,(BP*"2=B=%]P<F5F
M97)E;F-E<R<@/3X@(E!R969E<F5N8V5S(BP*"2=B=%]P<F5V7W!A9V4G(#T^
M(")0<F5V(BP*"2=B=%]P<F5V:65W)R`]/B`G4VET92!0<F5V:65W)RP*"2=B
M=%]P<FEN="<@/3X@(E!R:6YT(BP*"2=B=%]R96)O;W0G(#T^(")296)O;W0B
M+`H))V)T7W)E9G)E<V@G(#T^(")2969R97-H(BP*"2=B=%]R96=I<W1E<B<@
M/3X@(E)E9VES=&5R(BP*"2=B=%]R96UO=F4G(#T^(")296UO=F4B+`H))V)T
M7W)E;6]V95]F<F]M)R`]/B`B4F5M;W9E(#X^(BP*"2=B=%]F<F]M7W)E;6]V
M92<@/3X@(CP\(%)E;6]V92(L"@DG8G1?<F5M;W9E7W-E;&5C=&5D)R`]/B`B
M4F5M;W9E(%-E;&5C=&5D(BP*"2=B=%]R97!A:7)?:7`G(#T^(")297!A:7(@
M25`B+`H))V)T7W)E<&]R="<@/3X@(E)E<&]R="(L"@DG8G1?<F5P;W)T7V%U
M=&\G(#T^("=297!O<G0@1&5L:79E<GDG+`H))V)T7W)E<&]R=%]A=71O7VYE
M=R<@/3X@)T%D9"!$96QI=F5R>2!38VAE9'5L92<L"@DG8G1?<F5P;W)T7VYE
M=R<@/3X@(D%D9"!.97<@3&%Y;W5T(BP*"2=B=%]R97)E861?:7`G(#T^(")2
M97)E860@25`B+`H))V)T7W)E<V5T)R`]/B`B4F5S970B+`H))V)T7W)E<W1A
M<G1?<V5R=FEC97,G(#T^(")397)V:6-E($UA;F%G96UE;G0B+`H))V)T7W-A
M=F4G(#T^(")3879E(BP*"2=B=%]S96%R8V@G(#T^(")396%R8V@B+`H))V)T
M7W-E;F1?8GE?96UA:6PG(#T^(")396YD($)Y($4M36%I;"(L"@DG8G1?<V5N
M9%]F:6QE)R`]/B`B4V5N9"!&:6QE(BP*"2=B=%]S96YD7VUA:6PG(#T^(")3
M96YD($UA:6PB+`H))V)T7W-E;F1?<&%S<W=D)R`]/B`B4V5N9"!087-S=V]R
M9"(L"@DG8G1?<V5N9%]T97AT)R`]/B`B4V5N9"!497AT(BP*"2=B=%]S97)V
M97(G(#T^(")397)V97(B+`H))V)T7W-E<G9E<E]A9&0G(#T^(")!9&0@3F5W
M(%-E<G9E<B(L"@DG8G1?<V5R=F5R7W!R969E<F5N8V5S)R`]/B`B4V5R=F5R
M(%!R969E<F5N8V5S(BP*"2=B=%]S97)V97)S7VQI<W0G(#T^(")397)V97)S
M(BP*"2=B=%]S97-S:6]N7W-E='5P)R`]/B`B3&]G:6X@4V5T=&EN9W,B+`H)
M)V)T7W-E<W-I;VYS)R`]/B`B4V5S<VEO;G,B+`H))V)T7W-E="<@/3X@(E-E
M="(L"@DG8G1?<V5T7V%S7V1E9F%U;'0G(#T^(")3970@07,@1&5F875L="(L
M"@DG8G1?<V5T=7`G(#T^(")3971U<"(L"@DG8G1?<VAO=U]A;&EA<V5S)R`]
M/B`B4VAO=R!!;&EA<V5S(BP*"2=B=%]S:&]W7V%L;"<@/3X@(E-H;W<@06QL
M(BP*"2=B=%]S:&]W7W-U8F1O;6%I;G,G(#T^(")3:&]W(%-U8F1O;6%I;G,B
M+`H))V)T7W-H=71D;W=N)R`]/B`B4VAU="!$;W=N(BP*"2=B=%]S:71E7V%P
M<'!K9W,G(#T^(")!<'!L:6-A=&EO;B!6875L="(L"@DG8G1?<VET95]A<'!P
M;V]L)R`]/B`B07!P;&EC871I;VX@4&]O;"(L"@DG8G1?<VET95]A<'!S)R`]
M/B`B07!P;&EC871I;VX@5F%U;'0B+`H))V)T7W-I=&5?87!P7V%D9"<@/3X@
M(D%D9"!.97<@07!P;&EC871I;VXB+`H))V)T7W-I=&5?87!P7W!K9U]N97<G
M(#T^(")!9&0@3F5W($%P<&QI8V%T:6]N(%!A8VMA9V4B+`H))V)T7V%D9&ET
M:6]N86Q?:V5Y7W5P;&]A9"<@/3X@)U5P;&]A9"!.97<@2V5Y)RP*"2=B=%]A
M9&1I=&EO;F%L7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL;V%D($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?<F5M;W9E)R`]/B`G4F5M;W9E($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?86-T:79A=&4G(#T^("=!8W1I=F%T92<L"@DG
M8G1?<VET95]B=6EL9&5R)R`]/B`B36%M8F\@0TU3(BP*"2=B=%]S:V5L971O
M;B<@/3X@(E-K96QE=&]N(BP*"2=B=%]S:VEN<R<@/3X@)U-K:6YS)RP*"2=B
M=%]S:VEN7V%D9"<@/3X@)T%D9"!.97<@4VMI;B<L"@DG8G1?<VMI;E]M86YU
M86PG(#T^("=3:VEN<R!2969E<F5N8V4G+`H))V)T7W-K:6Y?9&]W;FQO860G
M(#T^("=$;W=N;&]A9"!3:VEN)RP*"2=B=%]S:VEN7W)E<&QA8V4G(#T^("=5
M<&1A=&4@4VMI;B<L"@DG8G1?<W!A;6%S<V%S<VEN)R`]/B`B4W!A;4%S<V%S
M<VEN(BP*"2=B=%]S<&%M87-S87-S:6Y?=')A:6XG(#T^(")4<F%I;FEN9R(L
M"@DG8G1?<W!A;69I;'1E<B<@/3X@(E-P86T@1FEL=&5R(BP*"2=B=%]S<VAT
M97)M)R`]/B`G4U-((%1E<FUI;F%L)RP*"2=B=%]S=&%T:7-T:6-S)R`]/B`B
M4W1A=&ES=&EC<R(L"@DG8G1?<W5B9&]M86EN7VYE=R<@/3X@(D%D9"!.97<@
M4W5B9&]M86EN(BP*"2=B=%]S=6)D;VUA:6YS)R`]/B`B4W5B9&]M86EN<R(L
M"@DG8G1?<W5B;6ET)R`]/B`B4W5B;6ET(BP*"2=B=%]S=6UM87)Y7W)E<&]R
M="<@/3X@(E-U;6UA<GD@4F5P;W)T(BP*"2=B=%]S=7!P;W)T)R`]/B`B4W5P
M<&]R="(L"@DG8G1?<W=I=&-H)R`]/B`B4W=I=&-H(BP*"2=B=%]S>7-T96U?
M=&EM92<@/3X@(E-Y<W1E;2!4:6UE(BP*"2=B=%]T87-K7VYE=R<@/3X@(D%D
M9"!.97<@5&%S:R(L"@DG8G1?9&]M7W1M<&Q?861D)R`]/B`G061D($YE=R!$
M;VUA:6X@5&5M<&QA=&4G+`H))V)T7V-L7W1M<&Q?861D)R`]/B`G061D($YE
M=R!#;&EE;G0@5&5M<&QA=&4G+`H))V)T7V-R;VY?8F%C:W5P)R`]/B`G4V-H
M961U;&5D($)A8VMU<"!3971T:6YG<R<L"@DG8G1?=&5S="<@/3X@(E1E<W0@
M0V]N;F5C=&EO;B(L"@DG8G1?=&5X="<@/3X@(E1E>'0B+`H))V)T7W1O=6-H
M)R`]/B`B5&]U8V@B+`H))V)T7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=B
M=%]T<F%F9FEC7VAI<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))V)T
M7W1T<U]G;&]B86Q?;&ES="<@/3X@(E-E<G9E<G,B+`H))V)T7W1T<U]T:6-K
M971S7V%L;"<@/3X@(D%L;"(L"@DG8G1?='1S7W1I8VME='-?86QL;W!E;F5D
M)R`]/B`B06QL($]P96YE9"(L"@DG8G1?='1S7W1I8VME='-?8VQO<V5D)R`]
M/B`B0VQO<V5D(BP*"2=B=%]T='-?=&EC:V5T<U]N97<G(#T^(").97<B+`H)
M)V)T7W1T<U]T:6-K971S7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B+`H))V)T
M7W1T<U]C871S)R`]/B`B0V%T96=O<FEE<R(L"@DG8G1?='1S7V=E;F5R86Q?
M8V]N9FEG)R`]/B`B1V5N97)A;"!3971T:6YG<R(L"@DG8G1?='1S7VUA:6Q?
M9V%T92<@/3X@(DUA:6P@1V%T92!3971T:6YG<R(L"@DG8G1?='1S7W!R:6]R
M:71I97,G(#T^(")0<FEO<FET:65S(BP*"2=B=%]T='-?<75E=65S)R`]/B`B
M475E=65S(BP*"2=B=%]U<%]L979E;"<@/3X@(E5P($QE=F5L(BP*"2=B=%]U
M<&1A=&4G(#T^(")5<&1A=&4B+`H))V)T7W5P;&]A9"<@/3X@(E5P;&]A9"(L
M"@DG8G1?=7!L;V%D7V9R;VU?9G1P)R`]/B`B1E10(%5P;&]A9"(L"@DG8G1?
M=V5B7V%P<%]N97<G(#T^(")!9&0@3F5W($IA=F$@07!P;&EC871I;VXB+`H)
M)V)T7W=E8E]A<'!S)R`]/B`B5&]M8V%T(BP*"2=B=%]W96)?<W1A=',G(#T^
M(")796(@4W1A=',B+`H))V)T7W=E8E]S=&%T<U]S<VPG(#T^(")796(@4W1A
M=',@4U-,(BP*"2=B=%]W96)?=7-E<E]A9&0G(#T^(")!9&0@3F5W(%=E8B!5
M<V5R(BP*"2=B=%]W96)?=7-E<G,G(#T^(")796(@57-E<G,B+`H))V)T7W=E
M8F%D;6EN)R`]/B`B1$(@5V5B061M:6XB+`H))V)T7W=E8F%L:7IE<B<@/3X@
M(E=E8F%L:7IE<B(L"@DG8G1?=V5B86QI>F5R7W!R969E<F5N8V5S)R`]/B`B
M5V5B(%-T871I<W1I8W,@4')E9F5R96YC97,B+`H))V)T7VAI9&1E;BUR969E
M<G)E<BUA9&0G(#T^("=(:61E($5N=')I97,G+`H))V)T7V=R;W5P+7)E9F5R
M<F5R+6%D9"<@/3X@)T=R;W5P(%)E9F5R<F5R<R<L"@DG8G1?=VAA='-?;F5W
M7V9U;&PG(#T^(")3964@=&AE(&9U;&P@;&ES="!O9B!C:&%N9V5S(BP*"2=B
M=%]W:&ET95]L:7-T)R`]/B`B5VAI=&4@3&ES="(L"@DG8G1?=VAI=&5?;&ES
M=%]A9&0G(#T^(")!9&0@3F5T=V]R:R(L"@DG8V5R=%]?861D7VYE=U]C97)T
M)R`]/B`B061D($YE=R!#97)T:69I8V%T92(L"@DG8V5R=%]?861M:6Y?<V5R
M=F5R7VYO=%]R97-P;VYD)R`]/B`B268@)3$@9&]E<R!N;W0@<F5S<&]N9"P@
M<&QE87-E(&%C8V5S<R!T:&4@<V5R=F5R(&%N9"!R97-T87)T('1H92!A9&UI
M;FES=')A=&EV92!W96(@<V5R=F5R(&5N9VEN92!M86YU86QL>2XB+`H))V-E
M<G1?7V-E<G1S7W1R86YS9F5R<F5D7W1O7V%D;6EN7W)E<"<@/3X@(E1H92!F
M;VQL;W=I;F<@8V5R=&EF:6-A=&5S(&%R92!S=&EL;"!I;B!U<V4@86YD('1H
M97)E9F]R92!C86YN;W0@8F4@<F5M;W9E9"`Z("4Q.R!!;&P@;V8@=&AE;2!W
M:6QL(&)E('!L86-E9"!T;R!T:&4@861M:6YI<W1R871O<B=S(&-E<G1I9FEC
M871E(')E<&]S:71O<GDN(BP*"2=C97)T7U]C:&]O<V5?8V5R="<@/3X@(E-E
M;&5C="!A(&-E<G1I9FEC871E(&9I;&4N(BP*"2=C97)T7U]I;G9A;&ED7W5P
M;%]C97)T)R`]/B`B57!L;V%D960@8V5R=&EF:6-A=&4@:7,@:6YV86QI9"XB
M+`H))V-E<G1?7VYO7V-E<G1?;W)?<'9T:V5Y)R`]/B`B56YA8FQE('1O(&EN
M<W1A;&P@=&AE(&1E9F%U;'0@8V5R=&EF:6-A=&4Z(&YO(&-E<G1I9FEC871E
M('=I=&@@<')I=F%T92!K97D@<V5L96-T960N(BP*"2=C97)T7U]O;FQY7V]N
M95]C97)T7V-A;E]B95]D969A=6QT)R`]/B`B3VYL>2!O;F4@8V5R=&EF:6-A
M=&4@8V%N(&)E('-E="!A<R!D969A=6QT+B(L"@DG8V5R=%]?;VYL>5]O;F5?
M8V5R=%]C86Y?<V5T=7!?;VY?8W`G(#T^(")/;FQY(&]N92!C97)T:69I8V%T
M92!C86X@8F4@:6YS=&%L;&5D(&EN=&\@=&AE($-O;G1R;VP@4&%N96PN(BP*
M"2=C97)T7U]P<FEV871E7VME>5]F;W5N9"<@/3X@(E1H92!P<FEV871E(&ME
M>2!F;W(@=&AE('5P;&]A9&5D(&-E<G1I9FEC871E('=A<R!F;W5N9"!U;F1E
M<B!N86UE("4Q+B!#97)T:69I8V%T92!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(L"@DG8V5R=%]?<V5L96-T7V-E<G1?9F]R7VEN<W1A;&Q?;VY?8W`G(#T^
M(")396QE8W0@=&AE(&-E<G1I9FEC871E('1O(&EN<W1A;&P@:6YT;R!T:&4@
M0V]N=')O;"!086YE;"XB+`H))V-E<G1?7W-E;&5C=%]C97)T7V9O<E]S971?
M9&5F875L="<@/3X@(E-E;&5C="!A(&-E<G1I9FEC871E('1O('-E="!A<R!D
M969A=6QT+B(L"@DG8V5R=%]?<W-L7V-E<G1?<F5L;V%D)R`]/B`B+BXN4U-,
M(&-E<G1I9FEC871E(&ES(&)E:6YG(')E;&]A9&5D+"!P;&5A<V4@=V%I="XN
M+B(L"@DG8V5R=%]?=&ET;&5?8W`G(#T^(")#97)T:69I8V%T92!R97!O<VET
M;W)Y(BP*"2=C97)T7U]T:71L95]D;VUA:6XG(#T^(")#97)T:69I8V%T92!R
M97!O<VET;W)Y(&9O<B!D;VUA:6X@/&(^)3$\+V(^(BP*"2=C97)T7U]U;F%B
M;&5?9FEN9%]A<'!R7W!V=%]K97DG(#T^(")5;F%B;&4@=&\@9FEN9"!T:&4@
M87!P<F]P<FEA=&4@<')I=F%T92!K97D@9F]R('1H92!C97)T:69I8V%T92XB
M+`H))V-E<G1?7W5N86)L95]I;G-T86QL7V-E<G1?;VY?8W`G(#T^(")5;F%B
M;&4@=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T:&4@0V]N=')O
M;"!086YE;#H@=&AE('!R:79A=&4@:V5Y(&%N9"!C97)T:69I8V%T92!C;VYT
M96YT<R!A<F4@;6ES<VEN9RXB+`H))V-E<G1?7W5N86)L95]T;U]U<&QO860G
M(#T^("=5;F%B;&4@=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T
M:&4@0V]N=')O;"!086YE;#H@)3$G+`H))V-E<G1?7W5N86)L95]T;U]D96QE
M=&5?8V5R=&EF:6-A=&5S)R`]/B`B56YA8FQE('1O(')E;6]V92!C97)T:69I
M8V%T97,Z("(L"@DG8V5R=%]?=7!L;V%D7V-E<G0G(#T^(")5<&QO860@8V5R
M=&EF:6-A=&4@9FEL92!A;F0@9FEN9"!M871C:&EN9R!P<FEV871E(&ME>2!I
M;B!T:&4@<F5P;W-I=&]R>2XB+`H))V-E<G1?7W5P;&]A9%]C97)T7V)Y7W!V
M=%]K97DG(#T^(")&:6YD('1H92!A<'!R;W!R:6%T92!P<FEV871E(&ME>2!T
M;R!T:&4@8V5R=&EF:6-A=&4B+`H))V-E<G1?861D7U]B:71S)R`]/B`B0FET
M<R(L"@DG8V5R=%]A9&1?7V-A7V-E<G0G(#T^(")#02!C97)T:69I8V%T92(L
M"@DG8V5R=%]A9&1?7V-E<G0G(#T^(")#97)T:69I8V%T92(L"@DG8V5R=%]A
M9&1?7V-E<G1?;F%M92<@/3X@(D-E<G1I9FEC871E(&YA;64B+`H))V-E<G1?
M861D7U]C:71Y)R`]/B`B3&]C871I;VX@*$-I='DI(BP*"2=C97)T7V%D9%]?
M96YT97)?8V5R=%]N86UE)R`]/B`B16YT97(@8V5R=&EF:6-A=&4@;F%M92XB
M+`H))V-E<G1?861D7U]E;G1E<E]P=G1?:V5Y7V-E<G1?9FEL92<@/3X@(D5N
M=&5R('!R:79A=&4@:V5Y(&%N9"!C97)T:69I8V%T92!F:6QE+B(L"@DG8V5R
M=%]A9&1?7V5N=&5R7W!V=%]K97E?8V5R=%]T97AT)R`]/B`B16YT97(@<')I
M=F%T92!K97D@86YD(&-E<G1I9FEC871E('1E>'0N(BP*"2=C97)T7V%D9%]?
M;W)G86YI>F%T:6]N7VYA;64G(#T^(")/<F=A;FEZ871I;VX@;F%M92`H8V]M
M<&%N>2DB+`H))V-E<G1?861D7U]O<F=A;FEZ871I;VY?=6YI=%]N86UE)R`]
M/B`B3W)G86YI>F%T:6]N(&1E<&%R=&UE;G0O9&EV:7-I;VX@;F%M92(L"@DG
M8V5R=%]A9&1?7W!R:79A=&5?:V5Y7V%N9%]C<W)?<V5N=%]E;6%I;"<@/3X@
M(E1H92!G96YE<F%T960@<')I=F%T92!K97D@86YD($-34B!H879E(&)E96X@
M<V5N="!T;R!E+6UA:6PZ("4Q(BP*"2=C97)T7V%D9%]?<'9T7VME>2<@/3X@
M(E!R:79A=&4@:V5Y(BP*"2=C97)T7V%D9%]?<W1A=&4G(#T^(")3=&%T92!O
M<B!P<F]V:6YC92(L"@DG8V5R=%]A9&1?7W1I=&QE7V-P)R`]/B`B0W)E871E
M(&$@;F5W(%-33"!C97)T:69I8V%T92(L"@DG8V5R=%]A9&1?7W1I=&QE7V1O
M;6%I;B<@/3X@(D-R96%T92!A(&YE=R!34TP@8V5R=&EF:6-A=&4@9F]R(&1O
M;6%I;B`\8CXE,3PO8CXB+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7V-A7V-E
M<G0G(#T^(")5;F%B;&4@=&\@<V5T('1H92!#02!C97)T:69I8V%T93H@)3$B
M+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7V-E<G0G(#T^(")5;F%B;&4@=&\@
M<V5T('1H92!C97)T:69I8V%T93H@)3$B+`H))V-E<G1?861D7U]U;F%B;&5?
M<V5T7W!R:79A=&5?:V5Y)R`]/B`B56YA8FQE('1O('-E="!T:&4@<')I=F%T
M92!K97DZ("4Q(BP*"2=C97)T7V%D9%]?=7!L;V%D7V-E<G1?9FEL97,G(#T^
M(")5<&QO860@8V5R=&EF:6-A=&4@9FEL97,B+`H))V-E<G1?861D7U]U<&QO
M861?8V5R=%]T97AT)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&%S('1E>'0B
M+`H))V-E<G1?961I=%]?8V]M<&]N96YT7V%B<V5N="<@/3X@(D-O;7!O;F5N
M="!I<R!M:7-S:6YG(BP*"2=C97)T7V5D:71?7V-S<B<@/3X@(D-34B(L"@DG
M8V5R=%]E9&ET7U]O=F5R;&]A9%]C85]C97)T7V-O;F9I<FT_)R`]/B`B3W9E
M<G=R:71E('1H92!E>&ES=&EN9R!#02!C97)T:69I8V%T93\B+`H))V-E<G1?
M961I=%]?;W9E<FQO861?8V5R=%]C;VYF:7)M/R<@/3X@(D]V97)W<FET92!T
M:&4@97AI<W1I;F<@0V5R=&EF:6-A=&4_(BP*"2=C97)T7V5D:71?7W)E;6]V
M95]C85]C;VYF:7)M/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R
M96UO=F4@=&AE($-!(&-E<G1I9FEC871E/R(L"@DG8V5R=%]E9&ET7U]T:71L
M95]C<"<@/3X@(E-33"!C97)T:69I8V%T92(L"@DG8V5R=%]E9&ET7U]T:71L
M95]D;VUA:6XG(#T^(")34TP@8V5R=&EF:6-A=&4@9F]R(&1O;6%I;B`\8CXE
M,3PO8CXB+`H))V-E<G1I9FEC871E<U]L:7-T7U]C97)T:69I8V%T95]U<V5D
M7V%S7V1E9F%U;'0G(#T^(")O;F4@;V8@=&AE(&-E<G1I9FEC871E('EO=2!A
M<F4@9V]I;F<@=&\@9&5L971E(&ES('5S960@87,@=&AE($1E9F%U;'0@0V5R
M=&EF:6-A=&4N(BP*"2=C97)T:69I8V%T97-?;&ES=%]?8V5R=&EF:6-A=&5S
M)R`]/B`B4U-,(&-E<G1I9FEC871E<R(L"@DG8V5R=&EF:6-A=&5S7VQI<W1?
M7V-E<G1I9FEC871E<U]A<W-I9VYE9%]O;E]I<"<@/3X@(F]N92!O<B!S979E
M<F%L(&-E<G1I9FEC871E<R!A<F4@87-S:6=N960@=&\@=&AE($E0(&%D9')E
M<W-E<RXB+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V%?8V5R
M="<@/3X@(D$B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V5R
M="<@/3X@(D,B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8W-R
M)R`]/B`B4B(L"@DG8V5R=&EF:6-A=&5S7VQI<W1?7W1A8E]T:71L95]I<%]U
M<V%G92<@/3X@(E5S960B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET
M;&5?;F%M92<@/3X@(D-E<G1I9FEC871E($YA;64B+`H))V-E<G1I9FEC871E
M<U]L:7-T7U]T86)?=&ET;&5?<'9T7VME>2<@/3X@(DLB+`H))V-F7V-O;F9?
M7W!A9V5?=&ET;&4G(#T^(")#;VQD1G5S:6]N(%-E='1I;F=S(BP*"2=C9E]C
M;VYF7U]P871H)R`]/B`B0V]L9$9U<VEO;B!I;G-T86QL871I;VX@<&%T:"(L
M"@DG8V9?8V]N9E]?=W)O;F=?<&%T:%]E;G1E<F5D)R`]/B`B26YC;W)R96-T
M(&EN<W1A;&QA=&EO;B!P871H+B(L"@DG8VA?<&%S<U]?861M:6Y?<&%S<R<@
M/3X@(D%D;6EN:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG8VA?<&%S<U]?;VQD
M7W!A<W,G(#T^(")/;&0@<&%S<W=O<F0B+`H))V-H7W!A<W-?7W!A<W-?8V]N
M9FER;2<@/3X@(D-O;F9I<FTB+`H))V-H7W!A<W-?7W5N86)L95]C:&%N9V5?
M861M:6Y?<&%S<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&%D;6EN:7-T
M<F%T;W(G<R!P87-S=V]R9#H@)3$B+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]E
M;6%I;%]S=6)J96-T)R`]/B`G4&QE<VL@<&%S<W=O<F0@<F5M:6YD97(G+`H*
M"@DG8VA?<&%S<U]B>5]S96-R971?7V5M86EL7V)O9'DG(#T^(")$96%R("4R
M+%QN("4S7&Y<;B!4;R!S970@=7`@82!N97<@<&%S<W=O<F0L('!L96%S92!F
M;VQL;W<@=&AE(&QI;FLZ("4Q(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S
M<V%G95]S96YD)R`]/B`G)3$G+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]M97-S
M86=E7W-E;F1?97)R;W(G(#T^("=5;F%B;&4@=&\@<V5N9"!T:&4@<V5C<F5T
M(&-O9&4Z("4Q)RP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S<V%G95]S96-R
M971?<F5Q=65S=%]A9&UI;B<@/3X@)U1H92!I;G-T<G5C=&EO;G,@;VX@8VAA
M;F=I;F<@>6]U<B!P87-S=V]R9"!H879E(&)E96X@<V5N="!T;R!Y;W5R(&4M
M;6%I;"XG+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]E;6%I;%]S96-R971?<F5Q
M=65S=%]A9&UI;B<@/3X@(EEO=2!R97%U97-T960@=&AE(&-O;G1R;VP@<&%N
M96P@=&\@<V5N9"!Y;W4@>6]U<B!P87-S=V]R9"!B>2!E+6UA:6PN($9O<B!S
M96-U<FET>2!R96%S;VYS+"!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0@8V%N
M;F]T(&)E('-E;G0@8GD@92UM86EL+B!(;W=E=F5R+"!Y;W4@8V%N('-E="!U
M<"!A(&YE=R!P87-S=V]R9"!U<VEN9R!T:&4@<V5C<F5T(&-O9&4@>6]U('=I
M;&P@9FEN9"!I;B!T:&ES(&QE='1E<BXB+`H))V-H7W!A<W-?8GE?<V5C<F5T
M7U]M97-S86=E7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W4@<F5Q
M=65S=&5D('1H92!C;VYT<F]L('!A;F5L('1O('-E;F0@>6]U('EO=7(@<&%S
M<W=O<F0@8GD@92UM86EL+B!!<R!Y;W4@<&%S<W=O<F0@=V%S('-T;W)E9"!I
M;B!T:&4@<WES=&5M(&EN('1H92!E;F-R>7!T960@9F]R;2P@:70@;6%D92!N
M;R!S96YS92!T;R!S96YD(&ET(&)Y(&4M;6%I;#H@>6]U('=O=6QD('-I;7!L
M>2!N;W0@8F4@86)L92!T;R!U<V4@:70N($AO=V5V97(L('EO=2!C86X@<V5T
M('5P(&$@;F5W('!A<W-W;W)D('5S:6YG('1H92!S96-R970@8V]D92!Y;W4@
M=VEL;"!F:6YD(&EN('1H:7,@;&5T=&5R+B(L"@DG8VA?<&%S<U]B>5]S96-R
M971?7V5M86EL7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W5R('!A
M<W-W;W)D(&-O=6QD(&YO="!B92!S96YT(&)E8V%U<V4@:70@:7,@<W1O<F5D
M(&EN('1H92!E;F-R>7!T960@9F]R;2XB+`H))V-H7W!A<W-?8GE?<V5C<F5T
M7U]M97-S86=E7W=R;VYG7VQO9VEN)R`]/B`B5&AE(&QO9VEN(&YA;64@>6]U
M('-P96-I9FEE9"!D;V5S(&YO="!M871C:"!T:&4@<V5C<F5T(&-O9&4N($$@
M;F5W('-E8W)E="!C;V1E('=A<R!G96YE<F%T960@86YD('-E;G0@=&\@>6]U
M<B!E+6UA:6PN(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?96UA:6Q?=W)O;F=?
M;&]G:6XG(#T^("=9;W4@=')I960@=&\@<V5T('5P(&$@;F5W('!A<W-W;W)D
M('5S:6YG('1H92!S96-R970@8V]D92!B=70@96YT97)E9"!T:&4@=W)O;F<@
M;&]G:6X@;F%M92X@66]U('=I;&P@9FEN9"!A(&YE=R!S96-R970@8V]D92!I
M;B!T:&ES(&QE='1E<BXG+`H*"2=C:%]P87-S7V)Y7W-E8W)E=%]?:6YV86QI
M9%]S96-R970G(#T^("=);G9A;&ED('-E8W)E="!C;V1E(2<L"@DG8VA?<&%S
M<U]B>5]S96-R971?7W1I=&QE)R`]/B`G0VAA;F=E(%EO=7(@4&%S<W=O<F0G
M+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]S96-R970G(#T^("=396-R970@8V]D
M92<L"@H))V-H96-K7VUA:6Q?8WEC;&5?7V%L:6%S97,G(#T^(")-86EL(&-Y
M8VQI;F<@:7,@9&5T96-T960L('1H92!A9&1R97-S(%PB)3%<(B!I<R!C;VYT
M86EN960@:6X@=&AE(&%L:6%S97,@;V8@=&AI<R!M86EL(&YA;64N(BP*"2=C
M:&5C:U]M86EL7V-Y8VQE7U]A=71O<F5S<&]N9&5R<R<@/3X@(DUA:6P@8WEC
M;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O;G1A
M:6YE9"!I;B!T:&4@875T;W)E<W!O;F1E<G,@;V8@=&AI<R!M86EL(&YA;64N
M(BP*"2=C:&5C:U]M86EL7V-Y8VQE7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@
M8WEC;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O
M;G1A:6YE9"!I;B!T:&4@;6%I;"!G<F]U<"!O9B!T:&ES(&UA:6P@;F%M92XB
M+`H))V-H96-K7VUA:6Q?8WEC;&5?7VUA:6Q?;F%M92<@/3X@(DUA:6P@8WEC
M;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&-O:6YC:61E
M<R!W:71H('1H:7,@;6%I;"!N86UE+B(L"@DG8VAE8VM?;6%I;%]C>6-L95]?
M<F5D:7)E8W0G(#T^(")-86EL(&-Y8VQI;F<@:7,@9&5T96-T960L('1H92!A
M9&1R97-S(%PB)3%<(B!C;VEN8VED97,@=VET:"!T:&4@<F5D:7)E8W0@;V8@
M=&AI<R!M86EL(&YA;64N(BP*"2=C:&M?:G-?7V5N=&5R7VQO9VEN7V%N9%]P
M87-S=V0G(#T^(")%;G1E<B!L;V=I;B!N86UE(&%N9"!P87-S=V]R9"XB+`H)
M)V-H:U]J<U]?96YT97)?;&]G:6Y?;F%M92<@/3X@(D5N=&5R(&QO9VEN(&YA
M;64N(BP*"2=C:&M?:G-?7V5N=&5R7W!A<W-W9"<@/3X@(D5N=&5R('!A<W-W
M;W)D+B(L"@H))V)T7V-H86YG95]O=VYE<B<@/3X@(D-H86YG92!/=VYE<B(L
M"@DG8VAO=VY?7W-E;&5C=%]T:71L92<@/3X@(E-E;&5C="!T:&4@;F5W(&]W
M;F5R(BP*"2=C:&]W;E]?8VAE8VM?=&ET;&4G(#T^(")#:&%N9V4@9&]M86EN
M(&]W;F5R(BP*"2=C:&]W;E]?;F5W7V]W;F5R)R`]/B`B3F5W(&]W;F5R(BP*
M"2=C:&]W;E]?<V5L96-T961?9&]M86EN<R<@/3X@(E-E;&5C=&5D(&1O;6%I
M;G,B+`H))V-H;W=N7U]L:6UI='-?;&5G96YD)R`]/B`B4F5S;W5R8V5S(BP*
M"2=C:&]W;E]?;&EM:71?;F%M92<@/3X@(E)E<V]U<F-E(&YA;64B+`H))V-H
M;W=N7U]L:6UI=%]V86QU92<@/3X@(D%L;&]C871E9"!R97-O=7)C97,B+`H)
M)V-H;W=N7U]L:6UI=%]A<W-I9VYE9%]B969O<F4G(#T^(")"969O<F4@=')A
M;G-F97(B+`H))V-H;W=N7U]L:6UI=%]A<W-I9VYE9%]A9G1E<B<@/3X@(D%F
M=&5R('1R86YS9F5R(BP*"2=C:&]W;E]?97)R;W)?9&]M86EN<U]E>&-L=61E
M)R`]/B`B4V]M92!P<F]B;&5M<R!W97)E(&5N8V]U;G1E<F5D(&1U<FEN9R!A
M='1E;7!T('1O('1R86YS9F5R('-O;64@;V8@=&AE(&1O;6%I;G,@=&\@82!N
M97<@;W=N97(N(%1H97-E(&1O;6%I;G,@;F%M97,@87)E(&AI9VAL:6=H=&5D
M+B(L"@DG8VAO=VY?7V5R<F]R7VQI;6ET<R<@/3X@(D1O;6%I;B!T<F%N<V9E
M<B!I<R!I;7!O<W-I8FQE+B!4:&ES(&1O;6%I;B!R97%U:7)E<R!M;W)E(')E
M<V]U<F-E<R!T:&%N(&1E<W1I;F%T:6]N('5S97(@86-C;W5N="!C86X@<')O
M=FED92XB+`H))V-H;W=N7U]E<G)O<E]N;U]D;VUA:6YS)R`]/B`B56YA8FQE
M('1O(&-O;G1I;G5E(&1O;6%I;B!T<F%N<V9E<CH@;F\@9&]M86EN<R!S96QE
M8W1E9"XB+`H))V-H;W=N7U]E<G)O<E]E;7!T>5]I<%]P;V]L)R`]/B`B56YA
M8FQE('1O(&-O;G1I;G5E(&1O;6%I;B!T<F%N<V9E<CH@25`@<&]O;"!O9B!T
M:&4@8VQI96YT(&ES(&5M<'1Y+B!0;&5A<V4@87-S:6=N(&%N($E0(&%D9')E
M<W,@=&\@=&AE(&-L:65N="!F:7)S="XB+`H))V-H;W=N7U]I<%]N;W1?:6Y?
M8VQI96YT7W!O;VPG(#T^(")4:&4@25`@861D<F5S<R!A<W-O8VEA=&5D('=I
M=&@@=&AI<R!D;VUA:6X@=V%S(&YO="!A<W-I9VYE9"!T;R!)4"!P;V]L(&]F
M('1H92!N97<@9&]M86EN(&]W;F5R+B(L"@DG8VAO=VY?7V%L<F5A9'E?;W=N
M961?8GE?8VQI96YT)R`]/B`B5&AI<R!D;VUA:6X@;F%M92!A;')E861Y(&)E
M;&]N9W,@=&\@=&AI<R!U<V5R+B(L"@DG8VAO=VY?7W!L96%S95]S96QE8W1?
M;F5W7V1O;6%I;E]O=VYE<B<@/3X@)U!L96%S92!S96QE8W0@=&AE(&YE=R!O
M=VYE<B!F;W(@=&AI<R!D;VUA:6XN)RP*"2=C:&]W;E]?;VQD7VEP7V%D9')E
M<W,G(#T^("=4:&4@8W5R<F5N="!)4"!A9&1R97-S)RP*"2=C:&]W;E]?;F5W
M7VEP7V%D9')E<W,G(#T^("=4:&4@;F5W($E0(&%D9')E<W,G+`H))V-H;W=N
M7U]I<%]A9&1R97-S7W=A<FXG(#T^("=4:&4@25`@861D<F5S<R!A<W-O8VEA
M=&5D('=I=&@@=&AI<R!D;VUA:6X@9&]E<R!N;W0@8F5L;VYG('1O('1H92!P
M;V]L(&]F('1H92!N97<@9&]M86EN(&]W;F5R.B!P;&5A<V4@8VAE8VL@=&AE
M('9A;'5E<R!S96QE8W1E9"!F;W(@25`@;6%P<&EN9R<L"@H)+R\@96YD(&]F
M('-H<F%M:V\@<&%R=`H*"@DO+R!S97)G92!P87)T"@H))V-H:U]J<U]?=V%R
M;FEN9U]A8F]U=%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E
M<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O
M;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B
M96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B!4:&4@<&%S<W=O<F0@
M<VAO=6QD(&YO="!C;VYT86EN('1H92!L;V=I;B!N86UE+B(L"@DG8VAK7VIS
M7U]W87)N:6YG7V%B;W5T7V9T<%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N
M('5S92!A;'!H86YU;65R:6,L(&1A<V@@86YD('5N9&5R<V-O<F4@<WEM8F]L
M<R!I;B!T:&4@;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A8F]U
M=%]L;V=I;E]S>6YT87A?=VEN)R`]/B`B66]U(&-A;B!U<V4@;&]W97)C87-E
M(&%L<&AA;G5M97)I8RP@9&%S:"!A;F0@=6YD97)S8V]R92!S>6UB;VQS(&EN
M('1H92!L;V=I;B!N86UE+B!4:&4@;&]G:6X@;F%M92!S:&]U;&0@8F5G:6X@
M=VET:"!A;B!A;'!H86)E=&EC('-Y;6)O;"XB+`H))V-H:U]J<U]?=V%R;FEN
M9U]A8F]U=%]P87-S=V1?<WEN=&%X)R`]/B`B1&\@;F]T('5S92!Q=6]T97,L
M('-P86-E(&%N9"!N871I;VYA;"!A;'!H86)E="!C:&%R86-T97)S(&EN(&$@
M<&%S<W=O<F0N7&Y4:&4@<&%S<W=O<F0@;&5N9W1H('-H;W5L9"!B92!F<F]M
M(#4@=&\@,30@8VAA<F%C=&5R<RX@5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@
M8V]N=&%I;B!T:&4@;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A
M8F]U=%]P;&5S:U]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E
M<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O
M;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B
M96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L"@DG8VAK7VIS7U]W
M87)N:6YG7V%B;W5T7W!L97-K7VQO9VEN7W-Y;G1A>%]W:6XG(#T^(")9;W4@
M8V%N('5S92!L;W=E<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E
M<G-C;W)E('-Y;6)O;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N
M86UE('-H;W5L9"!B96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L
M"@DG8VAK7VIS7U]W87)N:6YG7V%B;W5T7W!L97-K7W!A<W-W9%]S>6YT87@G
M(#T^(")$;R!N;W0@=7-E('%U;W1E<RP@<W!A8V4@86YD(&YA=&EO;F%L(&%L
M<&AA8F5T(&-H87)A8W1E<G,@:6X@82!P87-S=V]R9"Y<;E1H92!P87-S=V]R
M9"!S:&]U;&0@8F4@8F5T=V5E;B`U(&%N9"`Q-"!C:&%R86-T97)S(&%N9"!S
M:&]U;&0@;F]T(&-O;G1A:6X@=&AE(&QO9VEN(&YA;64N(BP*"2=C:&M?:G-?
M7W=A<FYI;F=?86)O=71?<&%M7W!A<W-W9%]E<G)O<B<@/3X@(E=R;VYG('-Y
M<W1E;2!U<V5R(&%C8V]U;G0@<W!E8VEF:6-A=&EO;CH@)3$B+`H))V-L7V5D
M7U]E9&ET7V-L)R`]/B`B)3$G<R!A8V-O=6YT(&1E=&%I;',B+`H))V-L7VQI
M;6ET<U]?8VPG(#T^(")#;&EE;G0@)3$G<R!L:6UI=',B+`H))V-L7VQO9V]?
M7W-E='5P7VQO9V]?<')E9B<@/3X@(E-E="!L;V=O('!R;W!E<G1I97,@9F]R
M(&-L:65N="`E,2(L"@DG8VQ?;F5W7U]E;G1E<E]N97=?8VQ?9&%T82<@/3X@
M(D5N=&5R('1H92!I;F9O<FUA=&EO;B!O;B!N97<@8VQI96YT(BP*"2=C;%]P
M97)M7U]A;&Q?:7`G(#T^(")!;&P@879A:6QA8FQE($E0<R(L"@DG8VQ?<&5R
M;5]?86QL7VEP7V)A<V5D7VAS=%]W:6QL7V)E7VYB)R`]/B`B06QL(&EP+6)A
M<V5D(&AO<W1I;F<@86-C;W5N=',@9F]R(&-L:65N="!W:6QL(&)E('1R86YS
M9F5R<F5D('1O($YA;64M8F%S960N(BP*"2=C;%]P97)M7U]A;&QO=U]C;&EE
M;G1?8W)E871E7V1O;6%I;B<@/3X@(E1H92!F:65L9',@>6]U(&%R92!T<GEI
M;F<@=&\@<V5L96-T(&%R92!O;FQY(&%P<&QI8V%B;&4@=&\@0VQI96YT<R!W
M:&\@87)E(&%L;&]W960@=&\@8W)E871E(&1O;6%I;G,N(BP*"2=C;%]P97)M
M7U]A;&QO=U]C<F5A=&5?;F)?=U]I<"<@/3X@(D-L:65N="!C86X@8W)E871E
M($YA;64M8F%S960@:&]S=&EN9R!U<VEN9R`E,2(L"@DG8VQ?<&5R;5]?86QL
M;W=?8W)E871I;VY?:7!?8F%S961?:&]S=&EN9R<@/3X@(D%L;&]W($E0+6)A
M<V5D(&AO<W1I;F<@86-C;W5N=',@8W)E871I;VXB+`H))V-L7W!E<FU?7V%V
M86EL86)L95]I<',G(#T^(")!=F%I;&%B;&4@25!S(BP*"2=C;%]P97)M7U]C
M:&%N9V5?;&EM:71S)R`]/B`B1&]M86EN(&QI;6ET<R!A9&IU<W1M96YT(BP*
M"2=C;%]P97)M7U]C;%]D:7-K7W-P86-E)R`]/B`B5&]T86P@9&ES:R!S<&%C
M92!A=F%I;&%B;&4B+`H))V-L7W!E<FU?7V-L7V5X<&ER871I;VXG(#T^(")#
M;&EE;G0@86-C;W5N="!V86QI9&ET>2!P97)I;V0B+`H))V-L7W!E<FU?7V-L
M7VUA>%]B;W@G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL8F]X97,B+`H)
M)V-L7W!E<FU?7V-L7VUA>%]D8B<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&1A
M=&%B87-E<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7V1O;2<@/3X@(DUA>&EM=6T@
M;G5M8F5R(&]F(&1O;6%I;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]M86EL;&ES
M=',G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=C
M;%]P97)M7U]C;%]M87A?;6<G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL
M(&=R;W5P<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7W)E9&ER)R`]/B`B36%X:6UU
M;2!N=6UB97(@;V8@<F5D:7)E8W1S(BP*"2=C;%]P97)M7U]C;%]M87A?<F5S
M<"<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&%U=&]R97-P;VYD97)S(BP*"2=C
M;%]P97)M7U]C;%]M87A?<W5B9&]M)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@
M<W5B9&]M86EN<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7W1R869F:6,G(#T^(")4
M;W1A;"!A;6]U;G0@;V8@=')A9F9I8R!A=F%I;&%B;&4B+`H))V-L7W!E<FU?
M7V-L7VUA>%]W96)A<'!S)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@2F%V82!A
M<'!L:6-A=&EO;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]W=2<@/3X@(DUA>&EM
M=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG8VQ?<&5R;5]?8VQ?;6)O>%]Q
M=6]T82<@/3X@(E1H92!M86EL8F]X('-I>F4@;&EM:70@<V5T(&9O<B!T:&ES
M('5S97(@86-C;W5N="(L"@DG8VQ?<&5R;5]?8W)E871E7V1O;6%I;G,G(#T^
M(")$;VUA:6X@8W)E871I;VXB+`H))V-L7W!E<FU?7V-U<G)E;G1?;6%X:6UU
M;5]E>'!?9&%T92<@/3X@(E1H92!C=7)R96YT(&UA>&EM=6T@=F%L=64@;V8@
M9&]M86EN('9A;&ED:71Y('!E<FEO9"!I<R`E,3L@<F5Q=65S=&5D("4R7&XB
M+`H))V-L7W!E<FU?7V-U<G)E;G1?;6%X:6UU;5]M86EL8F]X7W%U;W1A)R`]
M/B`B5&AE(&-U<G)E;G1L>2!D969I;F5D(&QI;6ET(&]N(&%M;W5N="!O9B!D
M:7-K('-P86-E(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X97,@=6YD
M97(@=&AI<R!U<V5R(&%C8V]U;G0@:7,@)3$[(')E<75E<W1E9"`E,EQN(BP*
M"2=C;%]P97)M7U]C=7)R96YT7W1O=&%L7W)E<75E<W1E9"<@/3X@(E1H92!C
M=7)R96YT('1O=&%L('9A;'5E(&]F(&1O;6%I;B!L:6UI=',@9F]R("4Q(&ES
M("4R.R!R97%U97-T960@)3-<;B(L"@DG8VQ?<&5R;5]?8W5R<F5N=%]T;W1A
M;%]R97%U97-T961?9&]M)R`]/B`B0W5R<F5N="!N=6UB97(@;V8@)3$@8F5L
M;VYG:6YG('1O('1H:7,@8VQI96YT(&ES("4R.R!R97%U97-T960@)3-<;B(L
M"@DG8VQ?<&5R;5]?9&ES:U]S<&%C92<@/3X@(FUA>&EM=6T@86UO=6YT(&]F
M(&1I<VL@<W!A8V4B+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]S=&1G=6DG(#T^
M("=5<V5R(&EN=&5R9F%C92<L"@DG8VQ?<&5R;5]?;6%N86=E7V1A<VAB;V%R
M9"<@/3X@)T1E<VMT;W`@;6%N86=E;65N="<L"@DG8VQ?<&5R;5]?9&%S:&)O
M87)D7V%N9%]S=&1G=6DG(#T^("=$97-K=&]P(&%N9"!S=&%N9&%R9"!I;G1E
M<F9A8V4@87)E(&%L;&]W960G+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]O;FQY
M)R`]/B`G3VYL>2!$97-K=&]P(&EN=&5R9F%C92!I<R!A;&QO=V5D)RP*"2=C
M;%]P97)M7U]S=&1G=6E?;VYL>2<@/3X@)T]N;'D@<W1A;F1A<F0@:6YT97)F
M86-E(&ES(&%L;&]W960G+`H))V-L7W!E<FU?7V5D:71?8VPG(#T^(")#;&EE
M;G0@)3$G<R!P97)M:7-S:6]N<R(L"@DG8VQ?<&5R;5]?97AP7V1A=&5?97AC
M965D960G(#T^(")4:&4@=F%L:61I='D@<&5R:6]D('EO=2!A<F4@=')Y:6YG
M('1O('-E="!E>&-E961S('1H92!L:6UI="!S<&5C:69I960@=VET:&EN(&EN
M9&EV:61U86P@9&]M86EN<R!R96QA=&5D('1O('1H:7,@8VQI96YT+EQN(BP*
M"2=C;%]P97)M7U]I;G9A;&ED7W9A;'5E)R`]/B`B26YV86QI9"!V86QU92P@
M;VYL>2!D:6=I=',@87)E(&%L;&]W960N(BP*"2=C;%]P97)M7U]L:6UI=%]D
M:7-K7W-P86-E)R`]/B`B)3$@3&EM:70@=&AE('1O=&%L(&%M;W5N="!O9B!D
M:7-K('-P86-E(BP*"2=C;%]P97)M7U]L:6UI=%]E>'!I<F%T:6]N)R`]/B`B
M)3$@3&EM:70@=&AE('9A;&ED:71Y('!E<FEO9"!F;W(@=&AE(&-L:65N="!A
M8V-O=6YT(BP*"2=C;%]P97)M7U]L:6UI=%]M87A?8F]X)R`]/B`B)3$@3&EM
M:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG8VQ?<&5R
M;5]?;&EM:71?;6%X7V1B)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M
M8F5R(&]F(&1A=&%B87-E<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7V1O;2<@
M/3X@(B4Q($QI;6ET('1H92!M87AI;75M(&YU;6)E<B!O9B!D;VUA:6YS(BP*
M"2=C;%]P97)M7U]L:6UI=%]M87A?;6%I;&QI<W1S)R`]/B`B)3$@3&EM:70@
M=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V-L7W!E
M<FU?7VQI;6ET7VUA>%]M9R<@/3X@(B4Q($QI;6ET('1H92!M87AI;75M(&YU
M;6)E<B!O9B!M86EL(&=R;W5P<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W)E
M9&ER)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(')E9&ER
M96-T<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W)E<W`G(#T^("(E,2!,:6UI
M="!T:&4@;6%X:6UU;2!N=6UB97(@;V8@875T;W)E<W!O;F1E<G,B+`H))V-L
M7W!E<FU?7VQI;6ET7VUA>%]S=6)D;VTG(#T^("(E,2!,:6UI="!T:&4@;6%X
M:6UU;2!N=6UB97(@;V8@<W5B9&]M86EN<R(L"@DG8VQ?<&5R;5]?;&EM:71?
M;6%X7W1R869F:6,G(#T^("(E,2!,:6UI="!T:&4@=&]T86P@86UO=6YT(&]F
M('1R869F:6,B+`H))V-L7W!E<FU?7VQI;6ET7VUA>%]W96)A<'!S)R`]/B`B
M)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F($IA=F$@87!P;&EC871I
M;VYS(BP*"2=C;%]P97)M7U]L:6UI=%]M87A?=W4G(#T^("(E,2!,:6UI="!T
M:&4@;6%X:6UU;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C;%]P97)M7U]L
M:6UI=%]M8F]X7W%U;W1A)R`]/B`B)3$@4V5T('1H92!M86EL8F]X('%U;W1A
M(BP*"2=C;%]P97)M7U]L:6UI='-?97AC965D960G(#T^(")/;F4@;W(@<V5V
M97)A;"!L:6UI=',@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&%R92!A;')E861Y
M(&5X8V5E9&5D(&)Y('1H92!L:6UI=',@9&5F:6YE9"!W:71H:6X@:6YD:79I
M9'5A;"!D;VUA:6YS(&)E;&]N9VEN9R!T;R!T:&ES(&-L:65N="Y<;E1H92!T
M;W1A;"!L:6UI="!F;W(@=&AE(&-L:65N="!M=7-T(&)E(&UO<F4@;W(@97%U
M86P@=&\@=&AE('1O=&%L('-U;2!O9B!T:&4@9&]M86EN(&QI;6ET<R!D969I
M;F5D(&9O<B!T:&ES(&-L:65N="!A8V-O=6YT+EQN(BP*"2=C;%]P97)M7U]M
M86EL8F]X7W%U;W1A7V5X8V5E9&5D)R`]/B`B5&AE(&QI;6ET(&]N(&%M;W5N
M="!O9B!D:7-K('-P86-E(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X
M97,@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&5X8V5E9',@=&AE(&QI;6ET(&1E
M9FEN960@=VET:&EN(&EN9&EV:61U86P@9&]M86EN<R!R96QA=&5D('1O('1H
M:7,@8VQI96YT(&%C8V]U;G0N7&XB+`H))V-L7W!E<FU?7VUA:6QB;WA?<75O
M=&%?97AC965D<U]S97)V97)?;&EM:70G(#T^(")4:&4@;&EM:70@;VX@86UO
M=6YT(&]F(&1I<VL@<W!A8V4@86QL;V-A=&5D(&9O<B!H;W5S:6YG(&UA:6QB
M;WAE<R!Y;W4@87)E('1R>6EN9R!T;R!S970@97AC965D<R!T:&4@;&EM:71A
M=&EO;B!I;7!O<V5D(&%T('1H92!S97)V97(@;&5V96PN(BP*"2=C;%]P97)M
M7U]M86ME7V1U;7!S)R`]/B`B0F%C:W5P+W)E<W1O<F4@9G5N8W1I;VYS(BP*
M"2=C;%]P97)M7U]M86YA9V5?86YO;F9T<"<@/3X@(D%N;VYY;6]U<R!&5%`@
M;6%N86=E;65N="(L"@DG8VQ?<&5R;5]R96UO=&5?86-C97-S7VEN=&5R9F%C
M92<@/3X@(D%B:6QI='D@=&\@=7-E(')E;6]T92!834P@:6YT97)F86-E(BP*
M"2=C;%]P97)M7U]M86YA9V5?8W)O;G1A8E]W:6XG(#T^(")38VAE9'5L97(@
M;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7V-R;VYT86)?=6YI>"<@
M/3X@(D-R;VYT86(@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7V1N
M<R<@/3X@(D1.4R!Z;VYE(&UA;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G
M95]F='!?<&%S<W=O<F0G(#T^(")-86YA9V4@1E10('!A<W-W;W)D(BP*"2=C
M;%]P97)M7U]M86YA9V5?;&]G)R`]/B`B3&]G(')O=&%T:6]N(&UA;F%G96UE
M;G0B+`H))V-L7W!E<FU?7VUA;F%G95]M86EL;&ES=',G(#T^(")-86EL:6YG
M(&QI<W1S(&UA;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G95]N;W1?8VAR
M;V]T7W-H96QL)R`]/B`G3F]N+6-H<F]O=&5D('-H96QL(&UA;F%G96UE;G0G
M+`H))V-L7W!E<FU?7VUA;F%G95]D<G=E8B<@/3X@)T1R+E=E8B!A;G1I=FER
M=7,@;6%N86=E;65N="<L"@DG8VQ?<&5R;5]?;6%N86=E7W!H;W-T:6YG)R`]
M/B`B4&AY<VEC86P@:&]S=&EN9R!M86YA9V5M96YT(BP*"2=C;%]P97)M7U]M
M86YA9V5?<75O=&$G(#T^(")(87)D(&1I<VL@<75O=&$@87-S:6=N;65N="(L
M"@DG8VQ?<&5R;5]?;6%N86=E7W-H7V%C8V5S<R<@/3X@(DUA;F%G96UE;G0@
M;V8@<VAE;&P@86-C97-S('1O('-E<G9E<B(L"@DG8VQ?<&5R;5]?;6%N86=E
M7W-H7V%C8V5S<U]D:7-A8FQE9"<@/3X@)T-L:65N="!C86YN;W0@86QL;W<@
M;W(@9&ES86QL;W<@<VAE;&P@86-C97-S)RP*"2=C;%]P97)M7U]M86YA9V5?
M<VA?86-C97-S7V-H<F]O=&5D)R`]/B`G0VQI96YT(&-A;B!A;&QO=R!A8V-E
M<W,@;VYL>2!T;R!A(&-H<F]O=&5D(&5N=FER;VYM96YT)RP*"2=C;%]P97)M
M7U]M86YA9V5?<VA?86-C97-S7V%N>2<@/3X@)T-L:65N="!C86X@86QL;W<@
M86-C97-S('1O(&%N>2!T>7!E(&]F('-H96QL)RP*"2=C;%]P97)M7U]M86YA
M9V5?<W5B9&]M86EN<R<@/3X@(E-U8F1O;6%I;G,@;6%N86=E;65N="(L"@DG
M8VQ?<&5R;5]?;6%N86=E7V1O;6%I;E]A;&EA<V5S)R`]/B`B1&]M86EN(&%L
M:6%S97,@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7W=E8F%P<',G
M(#T^(")*879A(&%P<&QI8V%T:6]N<R!M86YA9V5M96YT(BP*"2=C;%]P97)M
M7U]M87A?8F]X)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;&)O>&5S(BP*
M"2=C;%]P97)M7U]M87A?9&(G(#T^(")M87AI;75M(&YU;6)E<B!O9B!D871A
M8F%S97,B+`H))V-L7W!E<FU?7VUA>%]D;VTG(#T^(")D;VUA:6YS(BP*"2=C
M;%]P97)M7U]M87A?;6%I;&QI<W1S)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@
M;6%I;&EN9R!L:7-T<R(L"@DG8VQ?<&5R;5]?;6%X7VUG)R`]/B`B;6%X:6UU
M;2!N=6UB97(@;V8@;6%I;"!G<F]U<',B+`H))V-L7W!E<FU?7VUA>%]R961I
M<B<@/3X@(FUA>&EM=6T@;G5M8F5R(&]F(')E9&ER96-T<R(L"@DG8VQ?<&5R
M;5]?;6%X7W)E<W`G(#T^(")M87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N
M9&5R<R(L"@DG8VQ?<&5R;5]?;6%X7W-U8F1O;2<@/3X@(G-U8F1O;6%I;G,B
M+`H))V-L7W!E<FU?7VUA>%]T<F%F9FEC)R`]/B`B;6%X:6UU;2!A;6]U;G0@
M;V8@=')A9F9I8R(L"@DG8VQ?<&5R;5]?;6%X7W=E8F%P<',G(#T^(")M87AI
M;75M(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQ?<&5R;5]?
M;6%X7W=U)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C
M;%]P97)M7U]M8F]X7W%U;W1A)R`]/B`B;6%I;&)O>"!Q=6]T82(L"@DG8VQ?
M<&5R;5]?;F]T7V%L;&]W7V-R96%T95]N8E]H<W0G(#T^(")#;&EE;G0@8V%N
M;F]T(&-R96%T92!.86UE+6)A<V5D(&AO<W1I;F<N(BP*"2=C;%]P97)M7U]C
M<%]A8V-E<W,G(#T^("=!8V-E<W,@=&\@8V]N=')O;"!P86YE;"<L"@DG8VQ?
M<&5R;5]?<V5L96-T7VEP7V%D9')S)R`]/B`B4V5L96-T(&EP(&%D9')E<W-E
M<R(L"@DG8VQ?<&5R;5]?<VET95]B=6EL9&5R)PD]/B`G57-E(&]F($UA;6)O
M(&-O;G1E;G0@;6%N86=E;65N="!S>7-T96TG+`H))V-L7W!E<FU?7W1H:7-?
M:7!?=7-E9%]V<G1?:'-T)R`]/B`B5&AI<R!I<"!A9&1R97-S(&ES('5S960@
M8GD@=FER='5A;"!H;W-T:6YG+EQN5&\@9&5L971E('1H:7,@:7`@861D<F5S
M<RP@<F5M;W9E(&AO<W1I;F<@<V5R=FEC92!O<B!C:&%N9V4@:71S('1Y<&4@
M=&\@3F%M92UB87-E9"XB+`H))V-L7W!E<FU?7W5N86)L95]O9F9?:7!B7V-R
M96%T:6YG)R`]/B`B0VQI96YT(&%L<F5A9'D@:&%S($E0+6)A<V5D(&AO<W1I
M;F<@<V5R=FEC92!S970M=7`N(%1O(&1E86-T:79A=&4@=&AI<R!F96%T=7)E
M(&9O<B!T:&4@0VQI96YT+"!D97-E;&5C="!T:&4@7")$;VUA:6X@8W)E871I
M;VY<(B!C:&5C:V)O>"!O<B!R96UO=F4@86QL($E0+6)A<V5D(&AO<W1I;F<@
M86-C;W5N=',N(BP*"2=C;%]P97)M7U]U;F%B;&5?;V9F7VYB7V-R96%T:6YG
M)R`]/B`B0VQI96YT(&%L<F5A9'D@:&%S($YA;64M8F%S960@:&]S=&EN9R!S
M97)V:6-E('-E="UU<"X@5&\@9&5A8W1I=F%T92!T:&ES(&9E871U<F4@9F]R
M('1H92!#;&EE;G0L(&1E<V5L96-T('1H92!<(D1O;6%I;B!C<F5A=&EO;EPB
M(&-H96-K8F]X(&]R(')E;6]V92!A;&P@3F%M92UB87-E9"!H;W-T:6YG(&%C
M8V]U;G1S+B(L"@DG8VQ?<&5R;5]?=6YA8FQE7W-E=%]D;VUA:6Y?;&EM:70G
M(#T^(")5;F%B;&4@=&\@;&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&1O
M;6%I;G,Z(&-L:65N="!A;')E861Y(&AA<R`E,2!D;VUA:6YS(BP*"2=C;%]P
M97)M7U]U;F%B;&5?=7!D871E7V-L:65N=%]L:6UI=&%T:6]N<R<@/3X@(E5N
M86)L92!T;R!M;V1I9GD@=&AE(&QI;6ET<R!O9B!C;&EE;G0@86-C;W5N=#H@
M)3$B+`H))V-L7W!R969?7V5D:71?8VPG(#T^(")#;&EE;G0@)3$G<R!P<F5F
M97)E;F-E<R(L"@DG8VQ?=')A9F9I8U]H:7-T;W)Y7U]T:71L92<@/3X@(D-L
M:65N="`\8CXE,3PO8CXG<R!T<F%F9FEC(&AI<W1O<GDB+`H))V-L87-S7V%N
M;VYF='!?7V-R96%T95]F='!?9&]M86EN)R`]/B`B3F\@=FER='5A;"!&5%`@
M9&]M86EN(&9O<B!T:&ES(&1O;5]I9"P@=')Y(&-R96%T:6YG(&ET(&9I<G-T
M+B(L"@DG8VQA<W-?86YO;F9T<%]?:6YC;VUI;F=?9&ES:U]S<&%C95]S:&]U
M;&1?8F5?;&]W97(G(#T^(")4:&4@9&ES:R!S<&%C92!L:6UI="!Y;W4@87)E
M('1R>6EN9R!T;R!S970@*"4Q*2!S:&]U;&0@;F]T(&5X8V5E9"!T:&4@=&]T
M86P@9&ES:R!S<&%C92!L:6UI="!D969I;F5D(&%T('1H92!D;VUA:6X@;&5V
M96P@*"4R*2(L"@DG8VQA<W-?86YO;F9T<%]?:6YV86QI9%]I;G!U=%]O;FQY
M7V1I9VET<R<@/3X@(DEN=F%L:60@=F%L=64@<W!E8VEF:65D+"!O;FQY(&1I
M9VET<R!A<F4@86QL;W=E9"(L"@DG8VQA<W-?86YO;F9T<%]?=6YA8FQE7V-H
M86YG95]O=VYE<G-H:7!S)R`]/B`B56YA8FQE('1O(&-H86YG92!O=VYE<G-H
M:7`@;W(@<&5R;6ES<VEO;G,@9F]R('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG
M8VQA<W-?86YO;F9T<%]?=6YA8FQE7V-O<'E?<75O=&%?9FEL92<@/3X@(E5N
M86)L92!T;R!C;W!Y('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG8VQA<W-?86YO
M;F9T<%]?=6YA8FQE7V=E=%]D:7-K7W5S86=E)R`]/B`B56YA8FQE('1O(')E
M=')I979E(&1I<VL@=7-A9V4@:6YF;W)M871I;VX@;VX@=&AE(&EN8V]M:6YG
M(&1I<F5C=&]R>3H@)3$B+`H))V-L87-S7V%N;VYF='!?7W5N86)L95]P87)S
M95]Q=6]T85]F:6QE)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!Q=6]T82!F
M:6QE+B(L"@DG8VQA<W-?86YO;F9T<%]?=6YA8FQE7W)E861?<75O=&%?9FEL
M92<@/3X@(E5N86)L92!T;R!R96%D('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG
M8VQA<W-?86YO;F9T<%]?=6YA8FQE7W5P9&%T95]Q=6]T82<@/3X@(E5N86)L
M92!T;R!U<&1A=&4@<75O=&$Z('1H92!F:6QE<R!I;B!T:&4@:6YC;VUI;F<@
M9&ER96-T;W)Y('5S92`E,2!+0G,@;V8@9&ES:R!S<&%C92P@=VAI8V@@97AC
M965D<R!T:&4@;F5W('%U;W1A('9A;'5E(BP*"2=C;&%S<U]A;F]N9G1P7U]U
M;F%B;&5?=W)I=&5?=&5M<%]F:6QE)R`]/B`B56YA8FQE('1O('=R:71E('1O
M('1H92!T96UP;W)A<GD@9FEL93H@)3$B+`H))V-L87-S7V)S9&]M86EN7U]W
M87)N7VUA>%]D871E7U\G(#T^(")4:&4@=F%L:61I='D@<&5R:6]D('=A<R!S
M970@=&\@)3$B+`H))V-L87-S7V-L:65N=%]?8VQI96YT7V-R96%T:6]N7VYO
M=&EF:6-A=&EO;B<@/3X@(D-L:65N="!C<F5A=&EO;B!N;W1I8V4N(BP*"2=C
M;&%S<U]C;&EE;G1?7V-L:65N=%]W:71H7V-O;G1A8W1?;F%M95]A;')E861Y
M7V5X:7-T<R<@/3X@(D-L:65N="!W:71H(&YA;64@)3$@86QR96%D>2!E>&ES
M=',N(BP*"2=C;&%S<U]C;&EE;G1?7V-L:65N=%]W:71H7VQO9VEN7VYA;65?
M861M:6Y?86QR96%D>5]E>&ES=',G(#T^(")4:&4@=7-E<B!W:71H(&QO9VEN
M(&YA;64@861M:6X@86QR96%D>2!E>&ES=',N(BP*"2=C;&%S<U]C;&EE;G1?
M7V1I<VM?<W!A8V4G(#T^(")$:7-K('-P86-E(BP*"2=C;&%S<U]C;&EE;G1?
M7VEN=F%L:61?;6%X7V1O;2<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(&1O;6%I
M;G,@=F%L=64L(&]N;'D@9&EG:71S(&%R92!A;&QO=V5D+B(L"@DG8VQA<W-?
M8VQI96YT7U]L:6UI=%]E>&-E960G(#T^("(E,3H@<F5Q=65S=&5D("T@)3(L
M(&UA>&EM=6T@879A:6QA8FQE("T@)3,B+`H))V-L87-S7V-L:65N=%]?;&EM
M:71?97AC965D7W5N;&EM:71E9"<@/3X@(B4Q.B!R97%U97-T960@+2!U;FQI
M;6ET960L(&UA>&EM=6T@879A:6QA8FQE("T@)3(B+`H))V-L87-S7V-L:65N
M=%]?;6%X7V)O>"<@/3X@(DUA:6QB;WAE<R(L"@DG8VQA<W-?8VQI96YT7U]M
M87A?9&(G(#T^(")$871A8F%S97,B+`H))V-L87-S7V-L:65N=%]?;6%X7VUA
M:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))V-L87-S7V-L:65N=%]?
M;6%X7VUG)R`]/B`B36%I;"!G<F]U<',B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W)E9&ER)R`]/B`B4F5D:7)E8W1S(BP*"2=C;&%S<U]C;&EE;G1?7VUA>%]R
M97-P)R`]/B`B075T;W)E<W!O;F1E<G,B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W-U8F1O;2<@/3X@(E-U8F1O;6%I;G,B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W1R869F:6,G(#T^(")-87AI;75M('1R869F:6,B+`H))V-L87-S7V-L:65N
M=%]?;6%X7W=E8F%P<',G(#T^(")*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQA
M<W-?8VQI96YT7U]M87A?=W4G(#T^(")796(@=7-E<G,B+`H))V-L87-S7V-L
M:65N=%]?;6)O>%]Q=6]T82<@/3X@(DUA:6QB;W@@<75O=&$B+`H))V-L87-S
M7V-L:65N=%]?=6YA8FQE7V1E9FEN95]C;%]S=&%T=7,G(#T^(")5;F%B;&4@
M=&\@9&5F:6YE('-T871U<R!O9B!C;&EE;G0@86-C;W5N=#H@)3$B+`H))V-L
M87-S7V-L:65N=%]?=6YA8FQE7V1E9FEN95]I;F%C=&EV95]D;VTG(#T^(")5
M;F%B;&4@=&\@9&5F:6YE(&EN86-T:79E(&1O;6%I;G,@)3$B+`H))V-L87-S
M7V-L:65N=%]?=6YA8FQE7V1E;%]I<"<@/3X@(E5N86)L92!T;R!R96UO=F4@
M25!S.B`E,2(L"@DG8VQA<W-?9&)?7V1B7VYA;65?;F]T7W-E="<@/3X@(D1A
M=&%B87-E(&YA;64@:7,@;F]T(&1E9FEN960N(BP*"2=C;&%S<U]D8E]?9&)?
M;F]T7V5X:7-T7V9O<E]C=7)R7V1O;2<@/3X@(E1H92!D871A8F%S92!D;V5S
M(&YO="!E>&ES="!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;&%S<U]D8E]?:6YV
M86QI9%]D8E]O<E]D;VU?;F%M92<@/3X@(E1H92!D;VUA:6X@;W(@9&%T86)A
M<V4@:60@:7,@:6YV86QI9"!O<B!D871A8F%S92!N86UE(&ES(&YO="!D969I
M;F5D+B(L"@DG8VQA<W-?9&)?7VEN=F%L:61?<&%S<R<@/3X@(E1H92!P87-S
M=V]R9"!I<R!I;G9A;&ED+B(L"@DG8VQA<W-?9&)?7VUA:6QG<G!?;65M8F5R
M7V5X:7-T)R`]/B`B5&AE(&UA:6P@9W)O=7`@;65M8F5R(&%L<F5A9'D@97AI
M<W1S+B(L"@DG8VQA<W-?9&)?7V%C8V5S<U]H;W-T<U]N;W1S=7!P;W)T)R`]
M/B`G06-C97-S(&AO<W1S('-E='1I;F<@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M=&AI<R!D871A8F%S92!T>7!E)RP*"2=C;&%S<U]D8E]?=6YA8FQE7V%D9"<@
M/3X@)U5N86)L92!T;R!A9&0@86-C97-S(&AO<W0@<F5C;W)D.B`E,2<L"@DG
M8VQA<W-?9&)?7W5N86)L95]D96PG(#T^("=5;F%B;&4@=&\@9&5L971E(&%C
M8V5S<R!H;W-T(')E8V]R9#H@)3$G+`H))V-L87-S7V1B7U]I;F-?=7-E<E]N
M;W1?97AI<W0G(#T^("=$871A8F%S92!U<V5R("(E,2(@9&]E<R!N;W0@97AI
M<W0G+`H))V-L87-S7V1B7U]I;F-?86-C97-S7W)E8V]R9%]E>&ES="<@/3X@
M)U1H:7,@86-C97-S(')E8V]R9"!A;')E861Y(&5X:7-T<R<L"@DG8VQA<W-?
M9&)?7VEN8U]A8V-E<W-?<F5C;W)D7VYO=%]E>&ES="<@/3X@)T=I=F5N(&%C
M8V5S<R!R96-O<F0@9&]E<R!N;W0@97AI<W0G+`H))V-L87-S7V1B7U]I;F-?
M=6YA8FQE7V1E;%]L87-T7W)E8V]R9"<@/3X@)U5N86)L92!T;R!D96QE=&4@
M=&AE(&QA<W0@86-C97-S(&AO<W0@<F5C;W)D)RP*"2=C;&%S<U]D;VUT;7!L
M961I=&9O<FU?7V1N<U]M87-T97(G(#T^(")-87-T97(B+`H))V-L87-S7V1O
M;71M<&QE9&ET9F]R;5]?9&YS7W-L879E)R`]/B`B4VQA=F4B+`H))V-L87-S
M7V1O;71M<&QE9&ET9F]R;5]?9&YS7W1Y<&4G(#T^(")4>7!E(&]F(&1O;6%I
M;B!$3E,@>F]N92(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?861M:6XG
M(#T^(")A9&UI;B(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT
M)R`]/B`B8VQI96YT(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE
M;G1?8W)E871I;VY?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($-R96%T:6]N
M(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE;G1?97AP7W=A<FYI
M;F=?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($5X<&ER871I;VX@5V%R;FEN
M9R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT7V5X<&ER871I
M;VY?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($5X<&ER960B+`H))V-L87-S
M7VYO=&EF:6-A=&EO;F9O<FU?7V1A>7,G(#T^("(@9&%Y<R!I;B!A9'9A;F-E
M(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]D;VUA:6Y?8W)E871I;VY?
M=&5X="<@/3X@(D1O;6%I;B!#<F5A=&EO;B(L"@DG8VQA<W-?;F]T:69I8V%T
M:6]N9F]R;5]?9&]M86EN7V5X<%]W87)N:6YG7W1E>'0G(#T^(")$;VUA:6X@
M17AP:7)A=&EO;B!787)N:6YG(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M
M7U]D;VUA:6Y?97AP:7)A=&EO;E]T97AT)R`]/B`B1&]M86EN($5X<&ER960B
M+`H))V-L87-S7VYO=&EF:6-A=&EO;F9O<FU?7V1O;6%I;E]L:6UI='-?97AC
M965D7W1E>'0G(#T^(")!8V-O=6YT($QI;6ET($YO=&EC97,B+`H))V-L87-S
M7VYO=&EF:6-A=&EO;F9O<FU?7V1O;6%I;E]U<V5R)R`]/B`B9&]M86EN(&%D
M;6EN:7-T<F%T;W(B+`H))V-L87-S7VYO=&EF:6-A=&EO;F9O<FU?7V5M86EL
M7V%D9')E<W,G(#T^(")E+6UA:6P@861D<F5S<R(L"@DG8VQA<W-?;F]T:69I
M8V%T:6]N9F]R;5]?979E;G0G(#T^(")%=F5N="(L"@DG8VQA<W-?;F]T:69I
M8V%T:6]N9F]R;5]?97AP:7)A=&EO;E]T:6UE)R`]/B`B4V5N9"!%>'!I<F%T
M:6]N(%=A<FYI;F=S("(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?:6YV
M86QI9%]E;6%I;"<@/3X@(DEN8V]R<F5C="!E+6UA:6P@861D<F5S<R!S<&5C
M:69I960N(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]I;G9A;&ED7V5X
M<%]T:6UE)R`]/B`B3G5M8F5R(&]F(&1A>7,@:7,@:6YV86QI9"XB+`H))V-L
M87-S7VYO=&EF:6-A=&EO;F9O<FU?7W-E;F1?;F]T:69?=&\G(#T^(")396YD
M(&YO=&EC92!T;R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC:V5T
M7V-L;W-E9%]T97AT)R`]/B`B5&EC:V5T($-L;W-E9"(L"@DG8VQA<W-?;F]T
M:69I8V%T:6]N9F]R;5]?=&EC:V5T7V-O;6UE;G1E9%]T97AT)R`]/B`B5&EC
M:V5T($-O;6UE;G1E9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC
M:V5T7V-R96%T961?=&5X="<@/3X@(E1I8VME="!#<F5A=&5D(BP*"2=C;&%S
M<U]N;W1I9FEC871I;VYF;W)M7U]T:6-K971?<F5O<&5N961?=&5X="<@/3X@
M(E1I8VME="!296]P96YE9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?
M=&ET;&4G(#T^(").;W1I9FEC871I;VX@<W5B<V-R:7!T:6]N(BP*"2=C;&%S
M<U]S<VQC97)T:69I8V%T95]?8V%?;F]T7W-I9VYS)R`]/B`B(%1H92!#02!C
M97)T:69I8V%T92!D;V5S(&YO="!S:6=N('1H92!C97)T:69I8V%T92XB+`H)
M)V-L87-S7W-S;&-E<G1I9FEC871E7U]C85]N;W1?<VEG;G-?=V%R;B<@/3X@
M(E=A<FYI;F<Z('1H92!#02!C97)T:69I8V%T92!D;V5S(&YO="!S:6=N('1H
M92!C97)T:69I8V%T92XB+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]I;F-O
M;7!A=&EB;&5?<'9T7VME>5]C97)T)R`]/B`B26YC;VUP871I8FQE('!R:79A
M=&4@:V5Y+V-E<G1I9FEC871E('!A:7(B+`H))V-L87-S7W-S;&-E<G1I9FEC
M871E7U]I;G9A;&ED7V-E<G1?9F]R;6%T)R`]/B`B26YV86QI9"!C97)T:69I
M8V%T92!F;W)M870N(BP*"2=C;&%S<U]S<VQC97)T:69I8V%T95]?:6YV86QI
M9%]P<FEV871E7VME>5]F;W)M870G(#T^("));G9A;&ED('!R:79A=&4@:V5Y
M(&9O<FUA="XB+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]P<F]B7VEN=F%L
M:61?<')I=E]K97DG(#T^(")0<F]B86)L>2P@=&AE('!R:79A=&4@:V5Y(&9O
M<FUA="!I<R!I;G9A;&ED+B(L"@DG8VQA<W-?=')A9F9I8VAI<W1O<GE?7VYO
M7V1A=&%?879A:6QA8FQE)R`]/B`B3F\@9&%T82!A=F%I;&%B;&4N(BP*"2=C
M;&%S<U]T<F%F9FEC:&ES=&]R>5]?<F5T96Y?<')E9B<@/3X@)U1R869F:6,@
M<W1A=&ES=&EC<R!R971E;G1I;VX@<')E9F5R96YC97,G+`H))V-L87-S7W1R
M869F:6-H:7-T;W)Y7U]T<F%F9FEC7W5S86=E)R`]/B`B5')A9F9I8R!U<V%G
M92(L"@DG8VQI96YT=')A9F9I8VQI<W1?:&5A9&5R)R`]/B`B5')A9F9I8R!A
M="!D;VUA:6YS(BP*"2=C;&EE;G1T<F%F9FEC;&ES=%]H96%D97)?;V9?8VQI
M96YT7U\G(#T^(")4<F%F9FEC(&%T('1H92!D;VUA:6YS(&]F(&-L:65N="`E
M,2(L"@H))V-L:7-T7U]F:7)S="<@/3X@)T9I<G-T)RP*"2=C;&ES=%]?;&%S
M="<@/3X@)TQA<W0G+`H))V-L:7-T7U]P<F5V)R`]/B`G)FQT.R9L=#LG+`H)
M)V-L:7-T7U]N97AT)R`]/B`G)F=T.R9G=#LG+`H))V-L:7-T7U]P86=E)R`]
M/B`G4&%G97,G+`H))V-L:7-T7U]P86=E7W-I>F4G(#T^("=.=6UB97(@;V8@
M96YT<FEE<R!P97(@<&%G92<L"@DG8VQI<W1?7VEN9F\G(#T^("<E-"`E,2!T
M;W1A;"<L"@DG8VQI<W1?7VEN9F]?96UP='DG(#T^("=.;R`E,2<L"@DG8VQI
M<W1?7VEN9F]?9FEL=&5R)R`]/B`G)34@)3$@9F]U;F0G+`H))V-L:7-T7U]I
M;F9O7W!A9VEN9R<@/3X@)R4R+24S("4Q(&]F("4T('1O=&%L)RP*"2=C;&ES
M=%]?:6YF;U]P86=I;F=?9FEL=&5R)R`]/B`G)3(M)3,@)3$@;V8@)34@9F]U
M;F0G+`H))V-L:7-T7U]S96%R8VA?<VAO=R<@/3X@)U-H;W<@4V5A<F-H)RP*
M"2=C;&ES=%]?<V5A<F-H7VAI9&4G(#T^("=(:61E(%-E87)C:"<L"@H))V-M
M9%]D;G-?7V%?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T)R`]/B`B4W5C:"!!
M(')E8V]R9"!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;G-?7V-A;F]N:6-A
M;%]D;VU?;F%M95]I<U]I;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N
M86UE(&ES(&EN=F%L:60N(BP*"2=C;61?9&YS7U]C;F%M95]D;G-?<F5C;W)D
M7V%L<F5A9'E?97AI<W0G(#T^(")3=6-H($-.04U%(')E8V]R9"!A;')E861Y
M(&5X:7-T<RXB+`H))V-M9%]D;G-?7V-N86UE7VEN7W)R7V-O;6)I;F%T:6]N
M)R`]/B`G5&AE<F4@:7,@:6YC;W)R96-T(&-O;6)I;F%T:6]N(&]F(')E<V]U
M<F-E(')E8V]R9',@:6X@=&AE('IO;F4G+`H))V-M9%]D;G-?7V-N86UE7V-O
M97AI<W1?=VET:%]D871A)R`]/B`G02!#3D%-12!R96-O<F0@8V%N;F]T(&-O
M97AI<W0@=VET:"!O=&AE<B!R97-O=7)C92!R96-O<F1S(&EN('1H92!S86UE
M('IO;F4N)RP*"2=C;61?9&YS7U]D;G-?<F5C;W)D7W1Y<&5?:7-?:6YV86QI
M9"<@/3X@(E)E<V]U<F-E(')E8V]R9"!T>7!E(&ES(&EN=F%L:60N(BP*"2=C
M;61?9&YS7U]E>'1?:&]S=%]I<U]N;W1?<F5S;VQV960G(#T^(")5;F%B;&4@
M=&\@<F5S;VQV92!T:&4@8V%N;VYI8V%L(&YA;64@)3$N(BP*"2=C;61?9&YS
M7U]D;VUA:6Y?<F5S=&]R95]D;G-?>F]N95]F86EL961?861D7W)E8V]R9"<@
M/3X@)U5N86)L92!T;R!R97-T;W)E('1H92!$3E,@>F]N93H@86X@97)R;W(@
M;V-C=7)E9"!W:&EL92!A9&1I;F<@=&AE("4Q(')E8V]R9"<L"@DG8VUD7V1N
M<U]?;6%I;%]D;VU?;F%M95]I<U]I;G9A;&ED)R`]/B`B36%I;"!E>&-H86YG
M97(@;F%M92!I<R!I;G9A;&ED+B(L"@DG8VUD7V1N<U]?;7A?<')I;W)I='E?
M:7-?:6YV86QI9"<@/3X@(DU8('!R:6]R:71Y(&ES(&EN=F%L:60N(BP*"2=C
M;61?9&YS7U]N86UE7W-E<G9E<E]I<U]I;G9A;&ED)R`]/B`B3F%M92!S97)V
M97(@:7,@:6YV86QI9"XB+`H))V-M9%]D;G-?7VYE='=O<FM?;6%S:U]S:&]U
M;&1?8F5?,C1?,39?;W)?."<@/3X@(DYE='=O<FL@;6%S:R!V86QU92!S:&]U
M;&0@8F4@,C0L(#$V(&]R(#@N(BP*"2=C;61?9&YS7U]T:&ES7V1N<U]R96-O
M<F1?86QR96%D>5]E>&ES=',G(#T^(")3=6-H(')E<V]U<F-E(')E8V]R9"!A
M;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;G-?7W5N86)L95]A9&1?<F5C;W)D
M)R`]/B`B56YA8FQE('1O(&%D9"`G)3$G(')E8V]R9#H@)3(B+`H))V-M9%]D
M;G-?7W5N86)L95]A9&1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@861D($$@
M<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]C;F%M95]R96-O
M<F0G(#T^(")5;F%B;&4@=&\@861D($-.04U%(')E8V]R9#H@)3$B+`H))V-M
M9%]D;G-?7W5N86)L95]A9&1?9&YS7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A
M9&0@<F5S;W5R8V4@<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D
M9%]E>'1?;G-?<F5C;W)D)R`]/B`B56YA8FQE('1O(&%D9"!%6%1?3E,@<F5C
M;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]N<U]R96-O<F0G(#T^
M(")5;F%B;&4@=&\@861D($Y3(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N
M86)L95]A9&1?<'1R7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A9&0@4%12(')E
M8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N86)L95]A9&1?='AT7W)E8V]R9"<@
M/3X@(E5N86)L92!T;R!A9&0@5%A4(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?
M7W5N86)L95]C<F5A=&5?9&YS7WIO;F4G(#T^(")5;F%B;&4@=&\@8W)E871E
M('1H92!$3E,@>F]N92`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V1E9FEN95]D
M;G-?<F5C;W)D)R`]/B`B56YA8FQE('1O(&1E9FEN92!T:&4@<F5S;W5R8V4@
M<F5C;W)D("4Q(BP*"2=C;61?9&YS7U]U;F%B;&5?9V5T7V1E9F%U;'1?9&YS
M7WIO;F5?<W1A='5S7W-E=%]T<G5E)R`]/B`B56YA8FQE('1O(')E=')I979E
M('1H92!D969A=6QT($1.4R!Z;VYE('-T871U<SH@)3$B+`H))V-M9%]D;G-?
M7W5N86)L95]I;G-E<G1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@:6YS97)T
M($$@<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7VEN<V5R=%]M>%]R
M96-O<F0G(#T^(")5;F%B;&4@=&\@:6YS97)T($U8(')E8V]R9#H@)3$B+`H)
M)V-M9%]D;G-?7W5N86)L95]I;G-E<G1?;G-?<F5C;W)D)R`]/B`B56YA8FQE
M('1O(&EN<V5R="!.4R!R96-O<F0Z("4Q(BP*"2=C;61?9&YS7U]U;F%B;&5?
M<V5T7V1N<U]Z;VYE7W-T871U<R<@/3X@(E5N86)L92!T;R!S970@=&AE($1.
M4R!Z;VYE('-T871U<SH@)3$B+`H))V-M9%]D;VUA:6YS7U]D;VU?86QR96%D
M>5]E>&ES=',G(#T^(")$;VUA:6X@)3$@86QR96%D>2!E>&ES=',N(BP*"2=C
M;61?9&]M86EN<U]?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@(E-U
M8V@@1$Y3(')E8V]R9"!F;W(@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B(L
M"@DG8VUD7V1O;6%I;G-?7V1O;5]A;')E861Y7V5X:7-T<S$G(#T^(")4:&5R
M92!A<F4@)3(@<W5B9&]M86EN<R!I;B!T:&ES(&1O;6%I;BX@1&]M86EN("4Q
M(&%L<F5A9'D@97AI<W1S+B(L"@DG8VUD7V1O;6%I;G-?7V1O;5]A;')E861Y
M7V5X:7-T<S(G(#T^(")T:&4@<W5B9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S
M+B(L"@DG8VUD7V1O;6%I;G-?7W-U8F1O;5]A;')E861Y7V5X:7-T<R<@/3X@
M(E1H92!S=6)D;VUA:6X@=VET:"!S=6-H(&YA;64@86QR96%D>2!E>&ES=',N
M(BP*"2=C;61?9&]M86EN<U]?9&%L:6%S7V%L<F5A9'E?97AI<W1S)R`]/B`B
M5&AI<R!A;&EA<R!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;VUA:6YS7U]U
M;F%B;&5?9&5L7VUA:6Q?9F]R7V1O;2<@/3X@(E5N86)L92!T;R!D96QE=&4@
M=&AE(&UA:6P@<V5R=FEC97,@9F]R(&1O;6%I;CH@)3$B+`H))V-M9%]D;VUA
M:6YS7U]U;F%B;&5?9&5L971E7V%N;VYY;6]U<U]F='`G(#T^(")5;F%B;&4@
M=&\@9&5L971E(&%N;VYY;6]U<R!&5%`@86-C;W5N="!F;W(@9&]M86EN.B`E
M,2(L"@DG8VUD7V1O;6%I;G-?7W5N86)L95]U<&1A=&5?9&]M7W!A<F%M)R`]
M/B`B56YA8FQE('1O('5P9&%T92!T:&4@9&]M86EN('!A<F%M971E<G,Z("4Q
M+B(L"@DG8VUD7V1O;6%I;G-?7W5N86)L95]R96YA;65?8VQI96YT7V5X:7-T
M)R`]/B`B9&]M86EN(&%D;6EN:7-T<F%T;W(G<R!L;V=I;B!N86UE(&ES(&%L
M<F5A9'D@:6X@=7-E+B(L"@DG8VUD7VAO<W1I;F=?7VAS=%]T>7!E7VES7VYO
M=%]P:'ES:6-A;%]H<W0G(#T^(")(;W-T:6YG('1Y<&4@:7,@;F]T('!H>7-I
M8V%L+B(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@
M(E5N86)L92!T;R!C<F5A=&4@=7-E<B`E,CH@)3$B+`H))V-M9%]H;W-T:6YG
M7U]U;F%B;&5?9&5F:6YE7VEP7V%D9')?9F]R7VYA;65?8F%S961?=FER='5A
M;%]H;W-T<R<@/3X@(E5N86)L92!T;R!D969I;F4@25`@861D<F5S<R!F;W(@
M=&AE(&YA;64M8F%S960@=FER='5A;"!H;W-T<SH@)3$B+`H))V-M9%]H;W-T
M:6YG7U]U;F%B;&5?9&5L7V]L9%]H<W0G(#T^(")5;F%B;&4@=&\@9&5L971E
M('1H92!P<F5V:6]U<VQY('-E="!U<"!H;W-T:6YG.B`E,2(L"@DG8VUD7VAO
M<W1I;F=?7W5N86)L95]D96Q?<')O=&5C=&5D7V1I<F5C=&]R>2<@/3X@(E5N
M86)L92!T;R!D96QE=&4@<')O=&5C=&5D(&1I<F5C=&]R>3H@)3$B+`H))V-M
M9%]H;W-T:6YG7U]U;F%B;&5?9&5L7W=E8E]U<V5R)R`]/B`B56YA8FQE('1O
M(&1E;&5T92!W96(@=7-E<CH@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?
M;6%K92]U<&1A=&5?=FER='5A;%]H;W-T)R`]/B`B56YA8FQE('1O(&-R96%T
M92!O<B!U<&1A=&4@=&AE(%9I<G1U86P@2&]S=#H@)3$B+`H))V-M9%]H;W-T
M:6YG7U]U;F%B;&5?;6%K95]F<F%M95]F;W)W87)D7VAS="<@/3X@(E5N86)L
M92!T;R!S970@=7`@=&AE(&9R86UE(&9O<G=A<F1I;F<@:&]S=&EN9RXB+`H)
M)V-M9%]H;W-T:6YG7U]U;F%B;&5?<F5B=6EL9%]F='!?8V]N9FEG)R`]/B`B
M56YA8FQE('1O(')E8G5I;&0@=&AE('!R;V9T<&0@8V]N9FEG=7)A=&EO;B!F
M:6QE.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]S971?=7!?<W-L)R`]
M/B`B56YA8FQE('1O('-E="!U<"!34TP@)3$B+`H))V-M9%]H;W-T:6YG7U]U
M;F%B;&5?=6YP<F]T96-T7W-S;%]D:7)E8W1O<GDG(#T^(")5;F%B;&4@=&\@
M<F5M;W9E('!R;W1E8W1I;VX@9G)O;2!T:&4@4U-,(&1I<F5C=&]R>3H@)3$B
M+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?=7!D871E7V1E<W1?=7)L)R`]/B`B
M56YA8FQE('1O('5P9&%T92!T:&4@9&5S=&EN871I;VX@55),("4Q(BP*"2=C
M;61?:&]S=&EN9U]?=6YA8FQE7W5P9&%T95]D;G-?>F]N95]F;W)?9&]M7W5N
M86)L95]E>&5C7W5T:6PG(#T^(")5;F%B;&4@=&\@=7!D871E('1H92!$3E,@
M>F]N92!F;W(@=&AE(&1O;6%I;CH@=71I;&ET>2!E>&5C=71I;VX@9F%I;&5D
M+B(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]U<&1A=&5?9G1P7W!A<W-W9"<@
M/3X@(E5N86)L92!T;R!U<&1A=&4@1E10('!A<W-W;W)D("4Q(BP*"2=C;61?
M:&]S=&EN9U]?=6YA8FQE7W5P9&%T95]U<V5R)R`]/B`B56YA8FQE('1O('5P
M9&%T92!U<V5R("4R.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N:VYO=VY?:'-T
M7W1Y<&4G(#T^(")5;FMN;W=N(&AO<W1I;F<@='EP92XB+`H))V-M9%]H;W-T
M:6YG7U]Y;W5?;F]T7VAA=F5?<&5R;6ES<VEO;E]D96Q?:'-T)R`]/B`B66]U
M(&1O(&YO="!H879E('1H92!P97)M:7-S:6]N('1O('1E<FUI;F%T92!H;W-T
M:6YG('-E<G9I8V4N(BP*"2=C;61?;6%I;%]?861D<E]A;')E861Y7W5S961?
M:6Y?;6%I;%]R961I<F5C="<@/3X@(D%D9')E<W,@)3$@:7,@86QR96%D>2!B
M96EN9R!U<V5D(&EN(&$@;6%I;"!R961I<F5C="XB+`H))V-M9%]M86EL7U]A
M;&EA<U]A;')E861Y7V5X:7-T<R<@/3X@(F%L:6%S(&%L<F5A9'D@97AI<W1S
M+B(L"@DG8VUD7VUA:6Q?7V%U=&]R97-P7VED7V%N9%]M86EL;F%M95]I9%]N
M;W1?;6%T8V@G(#T^(")!=71O<F5S<&]N9&5R(&ED(&%N9"!M86EL(&YA;64@
M:60@9&\@;F]T(&UA=&-H(2(L"@DG8VUD7VUA:6Q?7V%U=&]R97-P7VED7VES
M7W5N9&5F:6YE9"<@/3X@(D%U=&]R97-P;VYD97(@:60@:7,@=6YD969I;F5D
M+B(L"@DG8VUD7VUA:6Q?7VUA:6Q?86QI87-?86QR96%D>5]E>&ES='-?:6Y?
M;6%I;%]N86UE)R`]/B`B5&AE(&UA:6P@86QI87,@=VET:"!S=6-H(&YA;64@
M86QR96%D>2!E>&ES=',@9F]R('1H92!M86EL(&YA;64@)3$B+`H))V-M9%]M
M86EL7U]M86EL7VYA;65?86QR96%D>5]E>&ES='-?:6Y?;6%I;&QI<W1S)R`]
M/B`B36%I;"!N86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL:6YG(&QI<W0B
M+`H))V-M9%]M86EL7U]M86EL7VYA;65?86QR961Y7V5X:7-T7VEN7V1O;2<@
M/3X@(E1H92!M86EL(&YA;64@)3$@:7,@86QR96%D>2!I;B!T:&4@9&]M86EN
M(BP*"2=C;61?;6%I;%]?;6%I;%]N86UE7VYO=%]E>&ES="<@/3X@(E1H92!M
M86EL(&YA;64@9&]E<R!N;W0@97AI<W0N(BP*"2=C;61?;6%I;%]?;6%I;%]N
M86UE7W!A<W-W9%]P87)T)R`]/B`B5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@
M8V]N=&%I;B!M86EL(&YA;64@87,@:71S('!A<G0N(BP*"2=C;61?;6%I;%]?
M;6%I;%]P87-S=V1?:6YC;W)R96-T)R`]/B`B7&Y4:&4@<&%S<W=O<F0@:7,@
M:6YC;W)R96-T+"!U<V4@870@;&5A<W0@-2!C:&%R86-T97)S+B!4:&4@<&%S
M<W=O<F0@<VAO=6QD(&YO="!C;VYT86EN(&UA:6P@;F%M92!A<R!I=',@<&%R
M="Y<;D]N;'D@3&%T:6X@8VAA<F%C=&5R<RP@;F\@9&EC=&EO;F%R>2!W;W)D
M<R`H;W!T:6]N86PI+B(L"@DG8VUD7VUA:6Q?7VUA:6Q?<F5D:7)E8W1?861D
M<E]I<U]I;G9A;&ED)R`]/B`B36%I;"!R961I<F5C="!A9&1R97-S(&ES(&EN
M=F%L:60N(BP*"2=C;61?;6%I;%]?;6%I;&QI<W1?86QR96%D>5]E>&ES=%]I
M;E]T:&ES7V1O;2<@/3X@(DUA:6QI;F<@;&ES="`E,2!A;')E861Y(&5X:7-T
M<R!O;B!T:&ES(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M86EL;&ES=%]A;')E
M861Y7V5X:7-T<R<@/3X@(FUA:6QI;F<@;&ES="!A;')E861Y(&5X:7-T<RXB
M+`H))V-M9%]M86EL7U]M86EL;F%M95]A;')E861Y7V5X:7-T7VEN7VUG)R`]
M/B`B36%I;"!N86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL(&=R;W5P+B(L
M"@DG8VUD7VUA:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?<F5D:7(G
M(#T^(")-86EL(&YA;64@)3$@:7,@86QR96%D>2!I;B!A(')E9&ER96-T+B(L
M"@DG8VUD7VUA:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?=&AI<U]D
M;VTG(#T^(")-86EL(&YA;64@)3$@86QR96%D>2!E>&ES=',@:6X@=&AI<R!D
M;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%I;&YA;65?86QR96%D>5]E>&ES=',G
M(#T^(")M86EL(&YA;64@86QR96%D>2!E>&ES=',N(BP*"2=C;61?;6%I;%]?
M;6%I;&YA;65?:7-?:6YV86QI9"<@/3X@(DUA:6P@;F%M92`E,2!I<R!I;G9A
M;&ED+B(L"@DG8VUD7VUA:6Q?7VUA:6QN86UE7W5N86)L95]U<&1A=&4G(#T^
M(")5;F%B;&4@=&\@=7!D871E('1H92!M86EL(&YA;64@<')O<&5R=&EE<SHB
M+`H))V-M9%]M86EL7U]M87A?875T;W)E<W!?<F5A8VAE9%]F;W)?=&AI<U]D
M;VTG(#T^(")-87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N9&5R<R!I<R!R
M96%C:&5D(&9O<B!T:&ES(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M87A?;6%I
M;%]G<F]U<'-?;G5M7VAA<U]B965N7W)E86-H961?9F]R7W1H:7-?9&]M)R`]
M/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;"!G<F]U<',@:&%S(&)E96X@<F5A
M8VAE9"!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7VYU;5]O
M9E]R961I<F5C='-?:&%S7V)E96Y?<F5A8VAE9%]F;W)?=&AI<U]D;VTG(#T^
M(")M87AI;75M(&YU;6)E<B!O9B!R961I<F5C=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7W!O<W1B;WAE
M<U]N=6U?:&%S7V)E96Y?<F5A8VAE9"<@/3X@(FUA>&EM=6T@;G5M8F5R(&]F
M(&UA:6QB;WAE<R!H87,@8F5E;B!R96%C:&5D+B(L"@DG8VUD7VUA:6Q?7VYO
M7VUE;6)E<G-?<W!E8VEF:65D)R`]/B`B;F\@;65M8F5R<R!S<&5C:69I960N
M(BP*"2=C;61?;6%I;%]?=&AE7W!A<W-W9%]I<U]T;V]?<VEM<&QE7V-H;V]S
M95]A;F]T:&5R)R`]/B`B5&AE('!A<W-W;W)D(&ES('1O;R!S:6UP;&4L('!L
M96%S92!C:&]O<V4@86YO=&AE<BXB+`H))V-M9%]M86EL7U]T:&ES7V%D9')?
M86QR96%D>5]E>&ES=%]I;E]M9U]O<E]M;B<@/3X@(E1H:7,@861D<F5S<R!I
M<R!A;')E861Y(&EN(&$@;6%I;"!G<F]U<"!O<B!M86EL(&YA;64N(BP*"2=C
M;61?;6%I;%]?=6YA8FQE7V1E9FEN95]A=71O<F5S<%]I9"<@/3X@(E5N86)L
M92!T;R!D969I;F4@875T;W)E<W!O;F1E<B!I9"`E,2(L"@DG8VUD7VUA:6Q?
M7W5N86)L95]D96Q?;6%I;%]F;W)?9&]M)R`]/B`B56YA8FQE('1O(')E;6]V
M92!T:&4@;6%I;"!S97)V:6-E(&9R;VT@9&]M86EN("4Q(BP*"2=C;61?;6%I
M;%]?=6YA8FQE7V1E;%]M86EL7W)E9&ER96-T:6]N)R`]/B`B56YA8FQE('1O
M(')E;6]V92!M86EL(')E9&ER96-T:6]N("4Q(BP*"2=C;61?;6%I;%]?=6YA
M8FQE7W)E;6]V95]A=71O<F5S<"<@/3X@(E5N86)L92!T;R!R96UO=F4@875T
M;W)E<W!O;F1E<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E;6]V95]M
M86EL7V=R;W5P7VUE;6)E<G,G(#T^(")5;F%B;&4@=&\@<F5M;W9E('1H92!M
M86EL(&=R;W5P(&UE;6)E<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E
M;6]V95]R961I<F5C="<@/3X@(E5N86)L92!T;R!R96UO=F4@<F5D:7)E8W0Z
M("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W1U<FY?;V9F7VUA:6Q?9W)O=7`G
M(#T^(")&86EL960@=&\@9&ES86)L92!T:&4@;6%I;"!G<F]U<#H@)3$B+`H)
M)V-M9%]M86EL7U]U;F%B;&5?=7!D871E7VUA:6Q?<F5D:7)E8W0G(#T^(")5
M;F%B;&4@=&\@=7!D871E('1H92!M86EL(')E9&ER96-T("4Q(BP*"2=C;61?
M;6%I;%]?=6YA8FQE7W5P9&%T95]M8F]X7W%U;W1A)R`]/B`B56YA8FQE('1O
M('5P9&%T92!T:&4@;6%I;&)O>"!Q=6]T82XB+`H))V-M9%]M86EL7U]U<&QO
M861E9%]F:6QE7VES7W1O;U]B:6<G(#T^(")5<&QO861E9"!F:6QE('-I>F4@
M:7,@=&]O(&QA<F=E+B(L"@DG8VUD7VUA:6Q?7V%D9&ET:6]N86QL>2<@/3X@
M(D%D9&ET:6]N86QL>3H@(BP*"2=C;61?<&1?7VEN=F%L:61?;&]G:6XG(#T^
M("));F-O<G)E8W0@;&]G:6XN(BP*"2=C;61?<&1?7W1H:7-?=7-E<E]A;')E
M861Y7V5X:7-T)R`]/B`B4W5C:"!U<V5R(&%L<F5A9'D@97AI<W1S+B(L"@DG
M8VUD7W!D7U]U;F%B;&5?9&5F:6YE7VAS=%]T>7!E)R`]/B`B56YA8FQE('1O
M(&1E9FEN92!H;W-T:6YG('1Y<&4N(BP*"2=C;61?<&1?7W5N86)L95]U<&1?
M<&1?=7-R)R`]/B`B56YA8FQE('1O('5P9&%T92!P<F]T96-T960@9&ER96-T
M;W)Y('5S97(@<')O<&5R=&EE<SH@)3$B+`H))V-M9%]P9%]?=7-E<E]I<U]U
M;F1E9FEN960G(#T^(")5<V5R(&ES('5N9&5F:6YE9"XB+`H))V-M9%]S97)V
M97)?7VYO7V5N;W5G:%]F<F5E7V1I<VM?<W!A8V4G(#T^(").;W0@96YO=6=H
M(&1I<VL@<W!A8V4N(BP*"2=C;61?<V5R=F5R7U]O;&1?<&%S<W=D7VES7VEN
M8V]R<F5C=%]P;&5A<V5?=')Y7V%G86EN)R`]/B`B;VQD('!A<W-W;W)D(&ES
M(&EN8V]R<F5C="X@4&QE87-E+"!T<GD@86=A:6XN(BP*"2=C;61?=V5B7W5S
M<E]?;6%X7W=E8E]U<V5R<U]R96%C:&5D7V9O<E]T:&ES7V1O;2<@/3X@(FUA
M>&EM=6T@=V5B('5S97)S(&QI;6ET(&ES(')E86-H960@9F]R('1H:7,@9&]M
M86EN+B(L"@DG8VUD7W=E8E]U<W)?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@
M(G5N86)L92!T;R!C<F5A=&4@<WES=&5M('5S97(Z("4Q(BP*"2=C;61?=V5B
M7W5S<E]?=6YA8FQE7V1E9FEN95]M87A?=V5B7W5S97)S7VQI;6ET)R`]/B`B
M=6YA8FQE('1O(&1E9FEN92!M87AI;75M('=E8B!U<V5R<R!L:6UI=#H@)3$B
M+`H))V-M9%]W96)?=7-R7U]U<V5R7V%L<F5A9'E?97AI<W1S)R`]/B`B=7-E
M<B!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]W96)?=7-R7U]W96)?=7-E<E]N
M86UE7VES7VEN=F%L:60G(#T^(")W96(@=7-E<B!N86UE("4Q(&ES(&EN=F%L
M:60N(BP*"2=C;61?=V5B7W5S<E]?=V5B7W5S97)?;F]T7V5X:7-T)R`]/B`B
M=V5B('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=C;VUM;VY?9G5N8U]?97AE
M8U]B861?87)G=6UE;G0G(#T^(")E>&5C(&%R9W5M96YT('-H;W5L9"!N;W0@
M8V]N=&%I;B!S:6YG;&4@<75O=&4@<WEM8F]L+B(L"@DG8V]M;6]N7V%C;%]?
M861D7V%D9')E<W,G(#T^("=!9&0@=&\@0V]M;6]N($%L;&]W(%IO;F4@5')A
M;G-F97(@04-,)RP*"2=C;VUM;VY?86-L7V%D9%]R96-O<F0G(#T^("=!9&0@
M82!!0TP@<F5C;W)D)RP*"2=E;G1E<E]I<%]O<E]N971W;W)K7V%D9')E<W,G
M(#T^("=%;G1E<B!)4"!O<B!N971W;W)K(&%D9')E<W,G+`H))U]?96]L)R`]
M/B`G3&EN92!B<F5A:W,G+`H))V5O;%]?;F]N92<@/3X@)V1O(&YO="!M;V1I
M9GDG+`H))V5O;%]?;&8G(#T^("=I;B!5;FEX('-T>6QE)RP*"2=E;VQ?7V-R
M)R`]/B`G:6X@36%C3U,@<W1Y;&4G+`H))V5O;%]?8W)L9B<@/3X@)VEN(%=I
M;F1O=W,@<W1Y;&4G+`H))V5O;%]?8FEN87)Y7V9I;&4G(#T^("=5;F%B;&4@
M=&\@8VAA;F=E(&QI;F4@8G)E86L@<W1Y;&4@:6X@8FEN87)Y(&9I;&4N)RP*
M"2=C;VUP7VEN9F]?7VAE861E<B<@/3X@)T-O;7!O;F5N=',G+`H))V-O;7!?
M:6YF;U]?8V]M<%]N86UE)R`]/B`B0V]M<&]N96YT(&YA;64B+`H))V-O;7!?
M:6YF;U]?8V]M<%]V97)S:6]N)R`]/B`B0V]M<&]N96YT('9E<G-I;VXB+`H)
M)V-O;7!?:6YF;U]?=&ET;&4G(#T^("));F9O<FUA=&EO;B!O;B`E,2!C;VUP
M;VYE;G1S(BP*"2=C;VYF:6=U<F5?7V9U;&Q?:&]S=&YA;65?:&EN="<@/3X@
M)U-P96-I9GD@=&AE(&9U;&QY('%U86QI9FEE9"!D;VUA:6X@;F%M92!F;W(@
M=&AI<R!S97)V97(N($5X86UP;&4Z(&AO<W1N86UE+F1O;6%I;BYC;VTG+`H)
M)V-O;F9I9W5R95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G0G(#T^("=3<&5C
M:69Y('1H92!)4"!A9&1R97-S('1H870@=VEL;"!B92!U<V5D(&%S('1H92!M
M86EN('-E<G9E<B!)4"!A9&1R97-S+B!396QE8W0@86X@97AI<W1I;F<@25`@
M861D<F5S<R!O<B!C;&EC:R!!9&0@25`@061D<F5S<R!T;R!A9&0@82!N97<@
M25`@861D<F5S<R!T;R!T:&4@<WES=&5M+B!)9B!Y;W4@=V%N="!T:&4@;F5W
M($E0(&%D9')E<W,@=&\@8F4@<VAA<F5D(&)E='=E96X@<V5V97)A;"!C;&EE
M;G0@86-C;W5N=',L('-E;&5C="!T:&4@4VAA<F5D(&-H96-K(&)O>"XG+`H)
M)V-O;F9I9W5R95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G1?<V5L96-T7V]N
M;'DG(#T^("=3<&5C:69Y('1H92!)4"!A9&1R97-S('1H870@=VEL;"!B92!U
M<V5D(&%S('1H92!M86EN($E0(&%D9')E<W,@9F]R('1H:7,@<V5R=F5R+B<L
M"@DG8V]N9FEG=7)E7U]S:&%R961?:7!?861D<F5S<U]H:6YT)R`]/B`G66]U
M(&-A;B!C:&%N9V4@=&AE('1Y<&4@;V8@97AI<W1I;F<@25`@861D<F5S<V5S
M(&9R;VT@97AC;'5S:79E('1O('-H87)E9"X@4VAA<F5D($E0(&%D9')E<W-E
M<R!C86X@8F4@87-S:6=N960@=&\@;75L=&EP;&4@8VQI96YT(&%C8V]U;G1S
M+B!4;R!C:&%N9V4@=&AE($E0(&%D9')E<W,@='EP92!F<F]M(&5X8VQU<VEV
M92!T;R!S:&%R960L('-E;&5C="!)4"!A9&1R97-S97,@:6X@=&AE(&QI<W0@
M;V8@97AC;'5S:79E($E0(&%D9')E<W-E<RP@86YD(&-L:6-K(%-H87)E9"XG
M+`H))U]?9&5F875L=%]I<%]A9&1R97-S)R`]/B`G1&5F875L="!)4"!!9&1R
M97-S)RP*"2=C;VYF:6=U<F5?7V1E9F%U;'1?:7!?<V5L96-T)R`]/B`G4V5L
M96-T(&%N(&%D9')E<W,G+`H))V-O;F9I9W5R95]?9&5F875L=%]I<%]N97<G
M(#T^("=!9&0@25`@061D<F5S<R<L"@DG8V]N9FEG=7)E7U]I<%]I;G1E<F9A
M8V4G(#T^("=);G1E<F9A8V4G+`H))V-O;F9I9W5R95]?:7!?861D<F5S<R<@
M/3X@)TE0($%D9')E<W,G+`H))V-O;F9I9W5R95]?:7!?<VAA<F5D)R`]/B`G
M4VAA<F5D)RP*"2=C;VYF:6=U<F5?7W-E;&5C=%]E>&QU<VEV95]I<',G(#T^
M("=%>&-L=7-I=F4@25`@861D<F5S<V5S)RP*"2=C;VYF:6=U<F5?7W-E;&5C
M=%]S:&%R961?:7!S)R`]/B`G4VAA<F5D($E0(&%D9')E<W-E<R<L"@DG8V]N
M9FEG=7)E7U]A9&UI;E]P87-S=V]R9%]C:&%N9V4G(#T^(")0;&5A<V4@8VAA
M;F=E('1H92!D969A=6QT(&%D;6EN:7-T<F%T;W(@<&%S<W=O<F0N(BP*"2=C
M;VYF:6=U<F5?7V5R<F]R7VYA;65D7W)E<W1A<G0G(#T^(").86UE9"!R97-T
M87)T(&5R<F]R+B!&;W(@<')O<&5R(&YA;65D('=O<FL@>6]U('-H;W5L9"!R
M97-T87)T(&ET+B(L"@DG8V]N9FEG=7)E7U]F:6QL7V9O;&QO=VEN9U]F:65L
M9',G(#T^(")&:6QL('1H92!R97%U97-T960@:6YF;W)M871I;VX@:6YT;R!T
M:&4@87!P<F]P<FEA=&4@9FEE;&1S+B!4:&ES(&EN9F]R;6%T:6]N(&ES(')E
M<75I<F5D(&9O<B`E,2!T;R!W;W)K+B(L"@DG8V]N9FEG=7)E7U]F=6QL7VAO
M<W1N86UE)R`]/B`B1G5L;"!H;W-T;F%M92(L"@DG8V]N9FEG=7)E7U]U;F%B
M;&5?8V]N9FEG=7)E)R`]/B`B56YA8FQE('1O(&-O;F9I9W5R93H@)3$B+`H)
M)V-P7V%C8V5S<U]A9&UI;E]D96YY)R`]/B`B06-C97-S(&9O<B!A9&UI;FES
M=')A=&]R(&9R;VT@861D<F5S<R`G)3$G(&ES(')E<W1R:6-T960@:6X@86-C
M;W)D86YC92!W:71H($E0($%C8V5S<R!R97-T<FEC=&EO;B!P;VQI8WD@8W5R
M<F5N=&QY(&%P<&QI960N(BP*"2=C<%]A8V-E<W-?8W5R<E]I<%]A8V-E<W-?
M9&5N>2<@/3X@(E=A<FYI;F<A(2$@5&AE(&%C8V5S<R!R97-T<FEC=&EO;B!P
M;VQI8WD@86YD('1H92!L:7-T(&]F(&YE='=O<FMS(&%R92!C=7)R96YT;'D@
M8V]N9FEG=7)E9"!T:&4@=V%Y('EO=2!W:6QL(&YO="!B92!A8FQE('1O(&QO
M9VEN('=I=&@@861M:6YI<W1R871O<B=S(')I9VAT<R!F<F]M('EO=7(@25`@
M861D<F5S<R`G)3$G+B(L"@DG8W!?86-C97-S7V5D:71?:&5A9&5R)R`]/B`B
M3F5T=V]R:R!E9&ET:6YG(BP*"2=C<%]A8V-E<W-?97AI<W1S)R`]/B`B5&AE
M(&YE='=O<FL@:7,@86QR96%D>2!I;B!T:&4@25`@86-C97-S(')E<W1R:6-T
M:6]N(&QI<W0N(BP*"2=C<%]A8V-E<W-?:&5A9&5R)R`]/B`B25`@86-C97-S
M(')E<W1R:6-T:6]N(&UA;F%G96UE;G0B+`H))V-P7V%C8V5S<U]P;VQI8WDG
M(#T^(")#;VYT<F]L('!A;F5L(&%C8V5S<R!W:71H(&%D;6EN:7-T<F%T;W(G
M<R!P<FEV:6QE9V5S(BP*"2=C<%]A8V-E<W-?<&]L:6-Y7V%L;&]W)R`]/B`B
M06QL;W=E9"P@97AC;'5D:6YG('1H92!N971W;W)K<R!I;B!T:&4@;&ES="XB
M+`H))V-P7V%C8V5S<U]P;VQI8WE?9&5N>2<@/3X@(D1E;FEE9"!F<F]M('1H
M92!N971W;W)K<R!T:&%T(&%R92!N;W0@;&ES=&5D+B(L"@DG8W!?86-C97-S
M7W)E;6]V95]H96%D97(G(#T^(").971W;W)K(')E;6]V86PB+`H))V-P7V%C
M8V5S<U]S96QE8W1?:7`G(#T^(")396QE8W0@;VYE(&]R('-E=F5R86P@;F5T
M=V]R:W,@9G)O;2!T:&4@25`@86-C97-S(')E<W1R:6-T:6]N(&QI<W0N(BP*
M"2=C<%]A8V-E<W-?<W=I=&-H7V-O;F9I<FUA=&EO;B<@/3X@(D-H86YG92!T
M:&4@86-C97-S('!O;&EC>3\B+`H))V-P7V%C8V5S<U]S=VET8VA?9&5N>5]E
M<G)O<B<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&%C8V5S<R!P;VQI8WDZ
M(&YO(&YE='=O<FMS('-P96-I9FEE9"(L"@DG8W!?86-C97-S7W-W:71C:%]D
M96YY7VYO=R<@/3X@(E1H92!A8V-E<W,@<&]L:6-Y('=A<R!C:&%N9V5D(&)E
M8V%U<V4@=&AE<F4@87)E(&YO(&YE='=O<FMS('-P96-I9FEE9"XB+`H))V-P
M7V%C8V5S<U]?;F5T=V]R:U]A9&1R97-S)R`]/B`G4W5B;F5T(&]R($E0(&%D
M9')E<W,G+`H))V-P7V%C8V5S<U]?;F5T=V]R:U]M87-K)R`]/B`G4W5B;F5T
M(&UA<VLG+`H))V-R96%T95]D;VUA:6Y?=V%R;E]?)R`]/B`B5&AE(&9O;&QO
M=VEN9R!E>&-E<'1I;VYS('=E<F4@;6%D92!D=7)I;F<@9&]M86EN(&-R96%T
M:6]N.B(L"@DG8W)E871E7V1O;6%I;E]?8VQI96YT7W-E;&5C="<@/3X@)U-E
M;&5C="!T:&4@8VQI96YT('1O(&-R96%T92!T:&4@9&]M86EN(&9O<B<L"@DG
M8W)O;G1A8E]?8W)O;G1A8E]E;G1R>5]E>&ES=',G(#T^(")4:&4@)3$@=&%S
M:R!A;')E861Y(&5X:7-T<R(L"@DG8W)O;G1A8E]?8W)O;G1A8E]E;G1R>5]N
M;W1?97AI<W1S)R`]/B`B5&AE("4Q('1A<VL@9&]E<R!N;W0@97AI<W0B+`H)
M)V-R;VYT86)?7VEN=F%L:61?=F%L=65S7V9O=6YD)R`]/B`B5&AE<F4@87)E
M(&EN8V]R<F5C="!P87)A;65T97(@=F%L=65S(BP*"2=C<F]N=&%B7V5D:71?
M7V-R;VYT86)?;V9?7R<@/3X@(D5D:71I;F<@=&AE("4Q('1A<VL@;V8@)3(B
M+`H))V-R;VYT86)?961I=%]?8VUD7VUA>%]L96XG(#T^(")4:&4@8V]M;6%N
M9"!Y;W4@<W!E8VEF:65D(&5X8V5E9',@=&AE(&%L;&]W960@;&5N9W1H("@E
M,2!S>6UB;VQS*2XB+`H))V-R;VYT86)?;&ES=%]?;6%I;%]T;U]?)R`]/B`B
M4V5N9"`E,2!M97-S86=E<R!T;R!A9&1R97-S("4R(BP*"2=C<F]N=&%B7VQI
M<W1?7VUA:6Q?=&]?:7-?:6YV86QI9"<@/3X@(E1H92!A9&1R97-S(&9O<B`E
M,2!M97-S86=E<R!D96QI=F5R>2!I<R!I;F-O<G)E8W0B+`H))V-R;VYT86)?
M;&ES=%]?<F5M;W9E7V]N7W5S97)?7R<@/3X@(E)E;6]V92!T:&4@<V-H961U
M;&5D('1A<VMS(&]F("4R(BP*"2=C<F]N=&%B7VQI<W1?7W-E;&5C=%]T;U]R
M96UO=F4G(#T^(")396QE8W0@=&AE("4Q('1A<VMS('1O(&)E(')E;6]V960N
M(BP*"2=C<F]N=&%B7VQI<W1?7W-H;W=?8W)O;G1A8E]O9E]?)R`]/B`B4VAO
M=R`E,2!O9B`E,B(L"@DG8W)O;G1A8E]L:7-T7U]S>7-U<V5R7VQI<W1?96UP
M='DG(#T^(")4:&5R92!A<F4@;F\@)3$@=&%S:W,@879A:6QA8FQE(BP*"2=C
M<F]N=&%B7VQI<W1?7W1A<VMS)R`]/B`B)3$@=&%S:W,B+`H*"2=C=7-T;VU?
M8G5T=&]N7U]S;W)T7VME>2<)"3T^("=0<FEO<FET>2<L"@DG8W5S=&]M7V)U
M='1O;E]?<&QA8V4G"0D)/3X@)TQO8V%T:6]N)RP*"2=C=7-T;VU?8G5T=&]N
M7U]P;&%C95]N879I9V%T:6]N)PD]/B`G3F%V:6=A=&EO;B!P86YE;"<L"@DG
M8W5S=&]M7V)U='1O;E]?<&QA8V5?861M:6XG"0D]/B`G061M:6YI<W1R871O
M<EPG<R!$97-K=&]P)RP*"2=C=7-T;VU?8G5T=&]N7U]P;&%C95]C;&EE;G0G
M"0D]/B`G0VQI96YT7"=S($1E<VMT;W`@+R!(;VUE('!A9V4G+`H))V-U<W1O
M;5]B=71T;VY?7W!L86-E7V1O;6%I;B<)"3T^("=$;VUA:6X@3W=N97)<)W,@
M1&5S:W1O<"`O($AO;64@<&%G92<L"@DG8W5S=&]M7V)U='1O;E]?<'5B;&EC
M)PD)"3T^("=6:7-I8FQE('1O(&%L;"!S=6(M;&]G:6YS)RP*"2=C=7-T;VU?
M8G5T=&]N7U]I;6%G92<)"0D]/B`G0F%C:V=R;W5N9"!I;6%G92<L"@DG8W5S
M=&]M7V)U='1O;E]?8V]N:&5L<"<)"3T^(")#;VYT97AT(&AE;'`@=&EP(&-O
M;G1E;G1S(BP*"2=C=7-T;VU?8G5T=&]N7U]E9&ET)PD)"3T^(")#=7-T;VT@
M0G5T=&]N(%!R;W!E<G1I97,B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?
M8VQI96YT7V-N86UE)PD]/B`B26YC;'5D92!C;&EE;G0G<R!C;VUP86YY(&YA
M;64B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7V5M86EL)R`]
M/B`B26YC;'5D92!C;&EE;G0G<R!E+6UA:6PB+`H))V-U<W1O;5]B=71T;VY?
M7VEN8VQU9&5?8VQI96YT7VED)R`]/B`B26YC;'5D92!C;&EE;G0@:60B+`H)
M)V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7W!N86UE)R`]/B`B26YC
M;'5D92!C;&EE;G0G<R!C;VYT86-T(&YA;64B+`H))V-U<W1O;5]B=71T;VY?
M7VEN8VQU9&5?9&]M86EN7VED)R`]/B`B26YC;'5D92!D;VUA:6X@:60B+`H)
M)V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?9&]M86EN7VYA;64G(#T^("));F-L
M=61E(&1O;6%I;B!N86UE(BP*"2=C=7-T;VU?8G5T=&]N7U]I;F-L=61E7V9T
M<%]U<V5R)R`]/B`B26YC;'5D92!&5%`@3&]G:6XB+`H))V-U<W1O;5]B=71T
M;VY?7VEN8VQU9&5?9G1P7W!A<W,G(#T^("));F-L=61E($944"!P87-S=V]R
M9"(L"@DG8W5S=&]M7V)U='1O;E]?:6YT97)N86Q?;W!E;B<@/3X@(D]P96X@
M55),(&EN('1H92!#;VYT<F]L(%!A;F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]T
M97AT)R`]/B`B0G5T=&]N(&QA8F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]U<FPG
M(#T^(")54DPB+`H*"2=C=7-T;VU?8G5T=&]N<U]?96UP='E?<V5L96-T:6]N
M)R`]/B`B4V5L96-T('1H92!B=71T;VYS('1O(&)E(')E;6]V960N(BP*"2=C
M=7-T;VU?8G5T=&]N<U]?;F%M92<@/3X@(DQA8F5L(BP*"2=C=7-T;VU?8G5T
M=&]N<U]?<'5B;&EC)R`]/B`G02<L+R]"=71T;VX@86-C97-S:6)I;&ET>2!P
M<F]P97)T>0H))V-U<W1O;5]B=71T;VYS7U]S;W)T7VME>2<@/3X@)U!R:6]R
M:71Y)RP@+R]4:&ES(&ES('1H92!L:7-T('1I=&QE('=H:6-H(&EN9&EC871E
M<R!T:&4@;W)D97(@;V8@=&AE(&-U<G)E;G0@8G5T=&]N"@DG8W5S=&]M7V)U
M='1O;G-?7W!L86-E)R`]/B`G3"<L+R],;V-A=&EO;@H))V-U<W1O;5]B=71T
M;VYS7U]R96UO=F4G(#T^(")4:&4@9F]L;&]W:6YG(&)U='1O;G,@=VEL;"!B
M92!R96UO=F5D.B(L"@DG8G1?9&]M86EN7V%L:6%S97,G(#T^("=$;VUA:6X@
M06QI87-E<R<L"@DG8G1?9&]M86EN7V%L:6%S7V%D9"<@/3X@)T%D9"!$;VUA
M:6X@06QI87,G+`H))W!B7U]D;VUA:6Y?86QI87-E<R<@/3X@)T1O;6%I;B!A
M;&EA<V5S)RP*"2=D87-H8F]A<F1?7VYA=E]B=71T;VY?;F%M92<@/3X@(D1E
M<VMT;W`B+`H))V1A;&EA<U]?;&ES=%]T:71L92<@/3X@)T1O;6%I;B!A;&EA
M<V5S(&]F('1H92!D;VUA:6X@)3$G+`H))V1A;&EA<U]?;&ES=%]L96=E;F0G
M(#T^("=$;VUA:6X@86QI87-E<R<L"@DG9&%L:6%S7U]L:7-T7VAE861E<B<@
M/3X@)T1O;6%I;B!A;&EA<V5S)RP*"2=D86QI87-?7VQI<W1?<W1A='5S)R`]
M/B`G4R<L"@DG9&%L:6%S7U]L:7-T7VYA;64G(#T^("=$;VUA:6X@86QI87,@
M;F%M92<L"@DG9&%L:6%S7U]L:7-T7V%S8VEI7VYA;64G(#T^("=);B!!4T-)
M22!F;W)M870G+`H))V1A;&EA<U]?<F5M;W9E7W1I=&QE)R`]/B`G5&AE(&9O
M;&QO=VEN9R!D;VUA:6X@86QI87-E<R!O9B!T:&4@9&]M86EN("4Q('=I;&P@
M8F4@<F5M;W9E9#HG+`H))V1A;&EA<U]?<V5L96-T7V1O;6%I;E]A;&EA<V5S
M7W1O7W)E;6]V92<@/3X@)U-E;&5C="!T:&4@9&]M86EN(&%L:6%S97,@=&\@
M8F4@<F5M;W9E9"XG+`H))V1A;&EA<U]?8V]N=')O;%]T:71L92<@/3X@)T1O
M;6%I;B!A;&EA<R`E,2<L"@DG9&%L:6%S7U]C;VYT<F]L7VEN9F]?;&5G96YD
M)R`]/B`G26YF;R<L"@DG9&%L:6%S7U]C;VYT<F]L7W-T871U<U]T:71L92<@
M/3X@)U,G+`H))V1A;&EA<U]?8V]N=')O;%]N86UE7W1I=&QE)R`]/B`G4V5R
M=FEC92!N86UE)RP*"2=D86QI87-?7V-O;G1R;VQ?9&5T86EL<U]T:71L92<@
M/3X@)T1E=&%I;',G+`H))V1A;&EA<U]?<V5R=FEC95]M86EL)R`]/B`G36%I
M;"<L"@DG9&%L:6%S7U]S97)V:6-E7W=E8B<@/3X@)U=E8B<L"@DG9&%L:6%S
M7U]D;VUA:6Y?<V5R=FEC95]M86EL7V5N86)L960G(#T^("=-86EL('-E<G9I
M8V4@:7,@96YA8FQE9"!O;B!T:&4@9&]M86EN+B<L"@DG9&%L:6%S7U]D;VUA
M:6Y?<V5R=FEC95]M86EL7V1I<V%B;&5D)R`]/B`G36%I;"!S97)V:6-E(&ES
M(&1I<V%B;&5D(&]N('1H92!D;VUA:6XN)RP*"2=D86QI87-?7V1O;6%I;E]S
M97)V:6-E7VUA:6Q?;7@G(#T^("<E,2!U<V5D(&%S(&UA:6P@97AC:&%N9V5R
M+B<L"@DG9&%L:6%S7U]E9&ET7W1I=&QE)R`]/B`G1&]M86EN(&%L:6%S('!R
M969E<F5N8V5S)RP*"2=D86QI87-?7V%D9%]T:71L92<@/3X@)T%D9"!D;VUA
M:6X@86QI87,G+`H))V1A;&EA<U]?961I=%]L96=E;F0G(#T^("=0<F5F97)E
M;F-E<R<L"@DG9&%L:6%S7U]E9&ET7VYA;64G(#T^("=$;VUA:6X@86QI87,@
M;F%M92<L"@DG9&%L:6%S7U]I;G9A;&ED7W9A;'5E<R<@/3X@)U1H92!D;VUA
M:6X@;F%M92!Y;W4@<W!E8VEF:65D(&ES(&EN=F%L:60N($1O;6%I;B!N86UE
M<R!C86X@8V]M<')I<V4@;&5T=&5R<RP*9&EG:71S(&%N9"!H>7!H96YS+B!%
M86-H('!A<G0@;V8@=&AE(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U
M;&0@;F]T(&)E"FQO;F=E<B!T:&%N(#8S('-Y;6)O;',N)RP*"2=D86QI87-?
M7V1O;6%I;E]A;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!N86UE(&]F
M(&1O;6%I;B!A;&EA<R`E,2P@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B<L
M"@DG9&%L:6%S7U]W=W=?<')E9FEX7V1O;6%I;E]A;')E861Y7V5X:7-T<R<@
M/3X@)TEN8V]R<F5C="!N86UE(&]F(&1O;6%I;B!A;&EA<R!W=W<N)3$L('1H
M:7,@86QI87,@:7,@86QR96%D>2!C<F5A=&5D(&9O<B!T:&4@9&]M86EN("4Q
M+B<L"@DG9&%L:6%S7U]W96)M86EL7V5N86)L961?9&]M86EN7V%L<F5A9'E?
M97AI<W1S)R`]/B`G26YC;W)R96-T(&1O;6%I;B!A;&EA<R!N86UE.B!4:&5R
M92!I<R!A;')E861Y("!T:&4@9&]M86EN(&YA;64@=V5B;6%I;"XE,2XG+`H)
M)V1A;&EA<U]?;&ES='-?96YA8FQE9%]D;VUA:6Y?86QR96%D>5]E>&ES=',G
M(#T^("=);F-O<G)E8W0@9&]M86EN(&%L:6%S(&YA;64Z($$@9&]M86EN('=I
M=&@@;F%M92`@;&ES=',N)3$@86QR96%D>2!E>&ES=',N)RP*"2=D86QI87-?
M7W-U8F1O;5]A;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!D;VUA:6X@
M86QI87,@;F%M93H@02!D;VUA:6X@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI
M<W1S+B<L"@DG9&%L:6%S7U]D;G-?<F5C;W)D7V%L<F5A9'E?97AI<W1S)R`]
M/B`G4W5C:"!R97-O=7)C92!R96-O<F0@:7,@86QR96%D>2!I;B!T:&4@>F]N
M92!O9B!T:&4@9&]M86EN("`E,2XG+`H))V1A;&EA<U]?9&%L:6%S7V%L<F5A
M9'E?97AI<W1S)R`]/B`G1&]M86EN(&%L:6%S("4Q(&%L<F5A9'D@97AI<W1S
M+B<L"@DG9&%L:6%S7U]M86EL7W1U<FY?;VY?9F%I;&5D)R`]/B`G56YA8FQE
M('1O('1U<FX@;VX@;6%I;"!S97)V:6-E.B`E,2<L"@DG9&%L:6%S7U]W96)?
M='5R;E]O;E]F86EL960G(#T^("=5;F%B;&4@=&\@='5R;B!O;B!796(@<V5R
M=FEC93H@)3$G+`H))V1A=&%B87-E<U]?9&)?861M:6Y?;&]G:6XG(#T^("(E
M,2!A9&UI;FES=')A=&]R)W,@;&]G:6XB+`H))V1A=&%B87-E<U]?;F]T7VEN
M<W1A;&QE9"<@/3X@(BAN;W0@:6YS=&%L;&5D*2(L"@DG9&%T86)A<V5S7U]N
M;W1?<W5P<&]R=&5D7VQI8V5N<V4G(#T^("(H;F]T('-U<'!O<G1E9"!B>2!Y
M;W5R(&QI8V5N<V4@:V5Y*2(L"@DG9&%T86)A<V5S7U]T:71L92<@/3X@(D1A
M=&%B87-E($UA;F%G96UE;G0@86YD($%D;6EN:7-T<F%T;W(G<R!#<F5D96YT
M:6%L<R(L"@DG9&%T86)A<V5S7U]U;F%B;&5?8V]N;F5C="<@/3X@(E5N86)L
M92!T;R!A8V-E<W,@9&%T86)A<V4N($EN8V]R<F5C="!P87)A;65T97)S+B(L
M"@DG9&%T86)A<V5S7U]I;F-O<G)E8W1?9&)?861M:6Y?;&]G:6XG(#T^("=4
M:&4@;&]G:6X@;F%M92!C86X@8V]N=&%I;B!O;FQY(&%L<&AA;G5M97)I8RP@
M9&%S:"!A;F0@=6YD97)S8V]R92!S>6UB;VQS+"!A;F0@<VAO=6QD(&)E9VEN
M('=I=&@@86X@86QP:&%B971I8R!S>6UB;VPN)RP*"2=D871A8F%S97-?7VEN
M8V]R<F5C=%]D8E]A9&UI;E]P87-S=V0G(#T^("=4:&4@<&%S<W=O<F0@<VAO
M=6QD(&YO="!C;VYT86EN('1H92!L;V=I;B!N86UE+B<L"@DG9&%T86)A<V5?
M:&]S=&EN9U]P<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO8V%L
M7V1B7W1E>'0G(#T^("=);G-T86QL871I;VX@;V8@<VET92!A<'!L:6-A=&EO
M;G,@=&AA="!D;R!N;W0@<W5P<&]R="!R96UO=&4@9&%T86)A<V5S)RP*"2=D
M871A8F%S95]H;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I=&5A
M<'!?;&]C86Q?9&)?=')U95]T97AT)R`]/B`G06QL;W<@;&]C86P@:&]S=&EN
M9R!O9B!D871A8F%S97,@9F]R('1H97-E('-I=&4@87!P;&EC871I;VYS)RP*
M"2=D871A8F%S95]H;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I
M=&5A<'!?;&]C86Q?9&)?9F%L<V5?=&5X="<@/3X@)T1I<V%L;&]W(&EN<W1A
M;&QA=&EO;B!O9B!T:&5S92!S:71E(&%P<&QI8V%T:6]N<R<L"@DG9&%T86)A
M<V5?:&]S=&EN9U]P<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO
M8V%L7V1B7VAI;G0G(#T^("=4:&ES('!R969E<F5N8V4@:7,@;VYL>2!I;B!E
M9F9E8W0@=VAE;B!A(')E;6]T92!D871A8F%S92!S97)V97(@:7,@<V5L96-T
M960@87,@9&5F875L="XG+`H))V1A=&%B87-E7VAO<W1I;F=?<')E9F5R96YC
M97-?9F]R;5]?=&ET;&4G(#T^("=$871A8F%S92!H;W-T:6YG('!R969E<F5N
M8V5S)RP*"2=D871A8F%S95]S97)V97)S7V9O<FU?7W1I=&QE)R`]/B`G1&%T
M86)A<V4@<V5R=F5R<R<L"@DG9&%T86)A<V5?<V5R=F5R<U]F;W)M7U]S97)V
M97)?;&ES=%]L96=E;F0G(#T^("=$871A8F%S92!S97)V97)S)RP))V1A=&%B
M87-E7W-E<G9E<G-?9F]R;5]?<F5M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@
M)TYO(&1A=&%B87-E('-E<G9E<G,@<V5L96-T960N)RP*"2=D871A8F%S95]S
M97)V97)S7V9O<FU?7W)E;6]V95]T:71L92<@/3X@)U1H92!F;VQL;W=I;F<@
M9&%T86)A<V4@<V5R=F5R<R!W:6QL(&)E(')E;6]V960Z)RP*"2=D871A8F%S
M95]S97)V97)?9&%T86)A<V5?;&ES=%]?8VQI96YT)R`]/B`G0VQI96YT)RP*
M"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?9&]M86EN)R`]/B`G
M1&]M86EN)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?:&5A
M9&5R)R`]/B`G1&%T86)A<V5S)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A
M<V5?;&ES=%]?;F%M92<@/3X@)TYA;64G+`H))V1A=&%B87-E7W-E<G9E<E]D
M871A8F%S97-?9F]R;5]?9&%T86)A<V5S7VQI<W1?;&5G96YD)R`]/B`G1&%T
M86)A<V5S)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E
M;6]V95]E;7!T>5]S96QE8W1I;VXG(#T^("=.;R!D871A8F%S97,@<V5L96-T
M960N)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E;6]V
M95]T:71L92<@/3X@)U1H92!F;VQL;W=I;F<@9&%T86)A<V5S('=I;&P@8F4@
M<F5M;W9E9#HG+`H))V1A=&%B87-E7W-E<G9E<E]D871A8F%S97-?9F]R;5]?
M=&%B)R`]/B`G1&%T86)A<V5S("@E,2DG+`H))V1A=&%B87-E7W-E<G9E<E]E
M9&ET7V9O<FU?7V%D;6EN7VQO9VEN)R`]/B`B061M:6YI<W1R871O<B=S(&QO
M9VEN(&YA;64B+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN
M7W!A<W-W;W)D7V]L9"<@/3X@(D-U<G)E;G0@861M:6YI<W1R871O<B=S('!A
M<W-W;W)D(BP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]A9&UI;E]P
M87-S=V]R9"<@/3X@(DYE=R!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0B+`H)
M)V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN7W!A<W-W;W)D,B<@
M/3X@(D-O;F9I<FT@;F5W(&%D;6EN:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG
M9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?9&5F875L="<@/3X@)U5S92!T
M:&ES('-E<G9E<B!A<R!D969A=6QT(&9O<B`E,2<L"@DG9&%T86)A<V5?<V5R
M=F5R7V5D:71?9F]R;5]?9'5P;&EC871E)R`]/B`G02!D871A8F%S92!S97)V
M97(@=VET:"!T:&ES(&-O;6)I;F%T:6]N(&]F(&AO<W0@861D<F5S<R!A;F0@
M<&]R="!N=6UB97(@:7,@86QR96%D>2!R96=I<W1E<F5D+B<L"@DG9&%T86)A
M<V5?<V5R=F5R7V5D:71?9F]R;5]?:&]S="<@/3X@)TAO<W0@;F%M92!O<B!)
M4"!A9&1R97-S)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]L96=E
M;F1?875T:&5N=&EC871I;VXG(#T^("=!=71H96YT:6-A=&EO;B<L"@DG9&%T
M86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?;&5G96YD7V=E;F5R86PG(#T^("='
M96YE<F%L)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]P87-S=V]R
M9%]W87)N:6YG7W!O<W1G<F5S<6PG(#T^("=)9B!Y;W4@8VAA;F=E('1H92!L
M;V=I;B!O<B!P87-S=V]R9"!B96QO=RP@=&AE(%!O<W1G<F5344P@=7-E<B!A
M8V-O=6YT('=I=&@@861M:6YI<W1R871I=F4@<FEG:'1S('=I;&P@8F4@=7!D
M871E9"XG+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7W!O<G0G(#T^
M("=0;W)T(&YU;6)E<B<L"@DG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?
M<&]R=%]H:6YT)R`]/B`G3&5A=F4@8FQA;FL@9F]R('1H92!D969A=6QT('!O
M<G0@;G5M8F5R)RPG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?=&%B)R`]
M/B`G1&%T86)A<V4@<V5R=F5R)RP*"2=D871A8F%S95]S97)V97)?961I=%]F
M;W)M7U]T:71L95]N97<G(#T^("=.97<@9&%T86)A<V4@<V5R=F5R)RP*"2=D
M871A8F%S95]S97)V97)?961I=%]F;W)M7U]T:71L95]E9&ET)R`]/B`G1&%T
M86)A<V4@<V5R=F5R("4Q)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M
M7U]T>7!E)R`]/B`G1&%T86)A<V4@<V5R=F5R('1Y<&4G+`H))V1A=&%B87-E
M7W-E<G9E<E]E9&ET7V9O<FU?7W5N:7A?<V]C:V5T)R`]/B`G*&QO8V%L(&-O
M;FYE8W1I;VXI)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7V-O;G-U;'1?
M861M:6XG(#T^("=0;&5A<V4@8V]N=&%C="!T:&4@<V5R=F5R(&%D;6EN:7-T
M<F%T;W(N)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?7V-O;FYE
M8W1I;VY?9F%I;&5D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C;VYT<F]L
M('1H:7,@9&%T86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E(&]F(&YE='=O
M<FL@<')O8FQE;7,N)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?
M7W!E<FUI<W-I;VY?9&5N:65D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C
M;VYT<F]L('1H:7,@9&%T86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E('1H
M92!S=7!P;&EE9"!A8V-O=6YT(&1O97,@;F]T('!O<W-E<W,@861M:6YI<W1R
M871I=F4@<')I=FEL96=E<RXG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?
M;&%S=%]?8W)E9&5N=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U
M<'!L>2!V86QI9"!A9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D
M(&)E9F]R92!0;&5S:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?;&%S=%]?;W1H97)?97)R;W(G(#T^
M("=4:&4@;&%S="!A='1E;7!T('1O(&-O;G1R;VP@=&AI<R!D871A8F%S92!S
M97)V97(@9F%I;&5D+B<L"@DG9&%T86)A<V5?<V5R=F5R7V5R<F]R7U]R96%L
M7U]C;VYN96-T:6]N7V9A:6QE9"<@/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A
M=&%B87-E('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P
M<F]B;&5M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?<&5R
M;6ES<VEO;E]D96YI960G(#T^("=#;VYN96-T:6]N('1O('1H92!D871A8F%S
M92!S97)V97(@:&%S(&9A:6QE9"!B96-A=7-E('1H92!S=7!P;&EE9"!A8V-O
M=6YT(&1O97,@;F]T('!O<W-E<W,@861M:6YI<W1R871I=F4@<')I=FEL96=E
M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?9'5P;&EC871E
M7V]B:F5C="<@/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@82!N86UE(&-L87-H.B<L"@DG9&%T
M86)A<V5?<V5R=F5R7V5R<F]R7U]R96%L7U]U;F%C8V5P=&%B;&5?;F%M92<@
M/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D(&)E8V%U<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M93HG+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?=6YA8V-E<'1A8FQE7W!A<W-W
M;W)D)R`]/B`G0V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&AA
M<R!F86EL960@8F5C875S92!O9B!A;B!U;F%C8V5P=&%B;&4@<&%S<W=O<F0Z
M)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7W)E86Q?7V-R961E;G1I86QS
M7VYO=%]S970G(#T^(")0;&5S:R!C86YN;W0@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4@<V5R=F5R(&)E8V%U<V4@=F%L:60@861M:6YI<W1R871O<B=S(&QO
M9VEN(&%N9"!P87-S=V]R9"!H879E(&YO="!B965N('-P96-I9FEE9"XB+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?;W1H97)?97)R;W(G(#T^
M("=#;VYN96-T:6]N('1O('1H92!D871A8F%S92!S97)V97(@:&%S(&9A:6QE
M9#HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?8V]N;F5C=&EO
M;E]F86EL960G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P<F]B;&5M
M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?<&5R;6ES<VEO
M;E]D96YI960G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@=&AE('-U<'!L:65D(&%C8V]U
M;G0@9&]E<R!N;W0@<&]S<V5S<R!A9&UI;FES=')A=&EV92!P<FEV:6QE9V5S
M.B<L"@DG9&%T86)A<V5?<V5R=F5R7V5R<F]R7U]T97-T7U]D=7!L:6-A=&5?
M;V)J96-T)R`]/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A8F%S92!S
M97)V97(@:&%S(&9A:6QE9"!B96-A=7-E(&]F(&$@;F%M92!C;&%S:#HG+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A8FQE7VYA
M;64G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M
M93HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A
M8FQE7W!A<W-W;W)D)R`]/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A
M8F%S92!S97)V97(@:&%S(&9A:6QE9"!B96-A=7-E(&]F(&%N('5N86-C97!T
M86)L92!P87-S=V]R9#HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S
M=%]?8W)E9&5N=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U<'!L
M>2!V86QI9"!A9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D(&)E
M9F]R92!0;&5S:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?;W1H97)?97)R;W(G(#T^("=4
M97-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D.B<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAE861E<B<@/3X@)T1A
M=&%B87-E('-E<G9E<G,G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]L87-T
M7V5R<F]R)R`]/B`G4R<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7W1Y<&4G
M(#T^("=397)V97(@='EP92<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAO
M<W0G(#T^("=(;W-T(&YA;64G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]P
M;W)T)R`]/B`G4&]R="<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7V1B8V]U
M;G0G(#T^("=$871A8F%S97,G+`H))V1B7U]C<F5A=&5?;F5W7V1B)R`]/B`B
M061D(&YE=R!D871A8F%S92(L"@DG9&)?7V1B7V%D9"<@/3X@(D%D9"!.97<@
M1&%T86)A<V4B+`H))V1B7U]D8E]F;W)?9&]M)R`]/B`B1&%T86)A<V5S(&9O
M<B!D;VUA:6X@)3$B+`H))V1B7U]D8E]I9%]U;F1E9FEN960G(#T^(")$871A
M8F%S92!I9"!I<R!U;F1E9FEN960N(BP*"2=D8E]?9&)?;F%M92<@/3X@(D1A
M=&%B87-E(&YA;64B+`H))V1B7U]D8E]N;W1?97AI<W0G(#T^(")$871A8F%S
M92!D;V5S(&YO="!E>&ES="XB+`H))V1B7U]D8E]T>7!E)R`]/B`B5'EP92(L
M"@DG9&)?7V1B7W-E<G9E<B<@/3X@(D1A=&%B87-E('-E<G9E<B(L"@DG9&)?
M<V5R=F5R7VYO=%]E>&ES="<@/3X@(D1A=&%B87-E('-E<G9E<B!D;V5S(&YO
M="!E>&ES="XB+`H))V1B7U]D8E]U<V5R7VYO=%]E>&ES="<@/3X@(D1A=&%B
M87-E('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=D8E]?9&]M86EN7VYO=%]E
M>&ES="<@/3X@(D1O;6%I;B!D;V5S(&YO="!E>&ES="XB+`H))V1B7U]E;G1E
M<E]D8E]N86UE)R`]/B`B16YT97(@;F5W(&1A=&%B87-E(&YA;64N(BP*"2=D
M8E]?:6YV86QI9%]D8E]I9"<@/3X@(D1A=&%B87-E(&ED96YT:69I97(@:7,@
M:6YV86QI9"XB+`H))V1B7U]I;G9A;&ED7V1B7VYA;64G(#T^(")$871A8F%S
M92!N86UE(&ES(&EN=F%L:60N(%1H92!D871A8F%S92!N86UE('-H;W5L9"!C
M;VYT86EN(&]N;'D@3&%T:6X@86QP:&%B970@<WEM8F]L<RP@9&EG:71S(&]R
M(&1A<V@N($ET(&-A;FYO="!B92!L;VYG97(@=&AA;B`V,R!S>6UB;VQS+B(L
M"@DG9&)?7VUA>%]D8E]R96%C:&5D7V9O<E]D;VTG(#T^(")4:&4@;&EM:70@
M;VX@;G5M8F5R(&]F(&1A=&%B87-E<R!I<R!R96%C:&5D(&9O<B!T:&ES(&1O
M;6%I;BXB+`H))V1B7U]N;VYD969A=6QT7W-E<G9E<E]N;W1?86QL;W=E9"<@
M/3X@)T]N;'D@=&AE(&%D;6EN:7-T<F%T;W(@8V%N(&-H;V]S92!S97)V97)S
M(&9O<B!D871A8F%S92!H;W-T:6YG+B<L"@DG9&)?7W!O<W1G<F5S7VYO=%]C
M;VYN96-T7V9O<E]A9&UI;B<@/3X@(E5N86)L92!T;R!C;VYN96-T('1O(%!O
M<W1G<F5344PN($5N86)L92!0;W-T9W)E4U%,('-U<'!O<G0@;VX@=&AE('-E
M<G9E<B!A9&UI;FES=')A=&EO;B!P86=E+B(L"@DG9&)?7W!O<W1G<F5S7VYO
M=%]C;VYN96-T7V9O<E]C;&EE;G0G(#T^(")5;F%B;&4@=&\@8V]N;F5C="!T
M;R!0;W-T9W)E4U%,+B!2969E<B!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&9O<B!H96QP+B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6XG(#T^
M(")4:&4@9F]L;&]W:6YG(&1A=&%B87-E<R!W:6QL(&)E(')E;6]V960@9G)O
M;2!T:&4@9&]M86EN("4Q.B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6Y?
M;V9?8VPG(#T^(")4:&4@9F]L;&]W:6YG(&1A=&%B87-E<R!F;W(@9&]M86EN
M("4R(&]W;F5D(&)Y(&-L:65N="`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=D
M8E]?<F5M;W9E7V1B7VQI;FME9%]R97-O=7)C92<@/3X@)U1H:7,@9&%T86)A
M<V4@:7,@:6X@=7-E(&)Y(&$@<VET92!A<'!L:6-A=&EO;BX@270@8V%N(&)E
M(')E;6]V960@;VYL>2!A9G1E<B!U;FEN<W1A;&QI;F<@=&AI<R!S:71E(&%P
M<&QI8V%T:6]N+B<L"@DG9&)?7W)E;6]V95]D8E]U<V5R<R<@/3X@(E1H92!F
M;VQL;W=I;F<@=7-E<G,@;V8@9&%T86)A<V4@)3(@:6X@9&]M86EN("4Q('=I
M;&P@8F4@<F5M;W9E9#HB+`H))V1B7U]R96UO=F5?9&)?=7-E<G-?;V9?8VPG
M(#T^(")4:&4@9F]L;&]W:6YG('5S97)S(&]F(&1A=&%B87-E("4S(&EN(&1O
M;6%I;B`E,B!O=VYE9"!B>2!T:&4@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E
M9#HB+`H))V1B7U]S96QE8W1?9&)?9F]R7W)E;6]V92<@/3X@(E-E;&5C="!T
M:&4@9&%T86)A<V5S('1O(&)E(')E;6]V960N(BP*"2=D8E]?<V5L96-T7V1B
M7W5S97)S7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE(&1A=&%B87-E('5S
M97)S('1O(&)E(')E;6]V960N(BP*"2=D8E]?=6YA8FQE7V-R96%T95]D8E]U
M<V5R)R`]/B`B56YA8FQE('1O(&-R96%T92!T:&4@9&%T86)A<V4@=7-E<CH@
M)3$B+`H))V1B7U]U;F%B;&5?9&5F:6YE7V1B7VYA;64G(#T^(")5;F%B;&4@
M=&\@9&5F:6YE('1H92!D871A8F%S92!N86UE.B`E,2(L"@DG9&)?7W5N86)L
M95]D969I;F5?9&)?=7-E<B<@/3X@(E5N86)L92!T;R!D969I;F4@=&AE(&1A
M=&%B87-E('5S97(Z("4Q(BP*"2=D8E]?=6YA8FQE7V1E9FEN95]D8E]U<V5R
M<R<@/3X@(E5N86)L92!T;R!D969I;F4@9&%T86)A<V4@=7-E<G,Z("4Q(BP*
M"2=D8E]?=6YA8FQE7W-E;&5C=%]D;VU?;F%M92<@/3X@(E5N86)L92!T;R!S
M96QE8W0@9&]M86EN(&YA;64Z("4Q(BP*"2=D8E]E9&ET7U]D8E]F;W)?9&]M
M)R`]/B`B57-E<G,@9F]R(&1A=&%B87-E("4Q(&]N(&1O;6%I;B`E,B(L"@DG
M9&)?961I=%]?:6YV86QI9%]D8E]N86UE)R`]/B`B5&AE(&1A=&%B87-E(&YA
M;64@:7,@:6YV86QI9"XB+`H))V1B7V5D:71?7VYO7W5S97)S)R`]/B`B5&AE
M<F4@87)E(&YO('5S97)S('=I=&@@8W)E9&5N=&EA;',@9F]R('1H:7,@9&%T
M86)A<V4N(BP*"2=D8E]E9&ET7U]U;F%B;&5?9&5F:6YE7V1B7W5S<G,G(#T^
M(")5;F%B;&4@=&\@9&5F:6YE('1H92!D871A8F%S92!U<V5R<SH@)3$B+`H)
M)V1B7V5D:71?7W5N86)L95]S96QE8W1?9&)?=7-R)R`]/B`B56YA8FQE('1O
M('-E;&5C="!T:&4@9&%T86)A<V4@=7-E<BXB+`H))V1B7V5D:71?7V1B7W5S
M97)?<&%S<W=O<F1?9F]R7R<@/3X@(E!L96%S92!T>7!E(&EN('1H92!P87-S
M=V]R9"!T;R!L;V<@:6X@87,@=&AE(&1A=&%B87-E('5S97(@)3$@(BP*"2=D
M8E]L:7-T7U]T86)?=&ET;&5?9&)?='EP92<@/3X@(E0B+`H))V1B7W5S<E]E
M9&ET7U]A9&1?9&)?=7-R)R`]/B`B5&AE(&1A=&%B87-E('5S97(@861D:71I
M;VXB+`H))V1B7W5S<E]E9&ET7U]D8E]U<W)?;F%M92<@/3X@(D1A=&%B87-E
M('5S97(@;F%M92(L"@DG9&)?=7-R7V5D:71?7V5D:71?9&)?=7-R)R`]/B`B
M4V5T('5P(&-R961E;G1I86QS(&9O<B!D871A8F%S92!U<V5R(&%C8V]U;G0B
M+`H))V1B7W5S<E]E9&ET7U]F;W)?9&(G(#T^("(@:6X@)3$@9&%T86)A<V4B
M+`H))V1B7W5S<E]E9&ET7U]N;W1?8W)E871E7W!A<W,G(#T^(")4:&ES(&]P
M97)A=&EO;B!W:6QL(')E<W5L="!I;B!C<F5A=&EN9R!A(&1A=&%B87-E('5S
M97(@86-C;W5N="!W:71H;W5T('!A<W-W;W)D+EQN1&\@>6]U('=I<V@@=&\@
M8W)E871E(&$@=7-E<B!W:71H;W5T(&%S<VEG;FEN9R!A('!A<W-W;W)D/R(L
M"@DG9&)U<V5R7U]O;FQY7V]N95]U<V5R7V-A;E]B95]D969A=6QT)R`]/B`B
M3VYL>2!O;F4@=7-E<B!C86X@8F4@<V5T(&%S(&1E9F%U;'0N(BP*"2=D8E]S
M97)V97)?7V-A;FYO=%]D96QE=&5?9&5F875L="<@/3X@(E1H92!D969A=6QT
M(&1A=&%B87-E('-E<G9E<B!C86YN;W0@8F4@9&5L971E9"XB+`H))V1B7W-E
M<G9E<E]?8V%N;F]T7V1E;&5T95]L;V-A;"<@/3X@(E1H92!L;V-A;"!D871A
M8F%S92!S97)V97(@8V%N;F]T(&)E(&1E;&5T960N(BP*"2=D8E]S97)V97)?
M7V-A;FYO=%]D96QE=&5?=7-E9"<@/3X@)T$@9&%T86)A<V4@<V5R=F5R(&-A
M;FYO="!B92!D96QE=&5D('=H:6QE('1H97)E(&%R92!D871A8F%S97,@:&]S
M=&5D(&]N(&ET+B<L"@DG9&5M;U]?9&ES86)L961?:6Y?9&5M;R<@/3X@(E1H
M:7,@;W!E<F%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&1E;6\@=F5R
M<VEO;BXB+`H))V1N<U]?861D7V1N<U]M87-T97)?<V5R=F5R)R`]/B`B061D
M($1.4R!M87-T97(@<V5R=F5R(BP*"2=D;G-?7V%D9%]D;G-?<F5C;W)D)R`]
M/B`B061D(')E<V]U<F-E(')E8V]R9"(L"@DG9&YS7U]A9&1?;F%M97-E<G9E
M<B<@/3X@(D%D9"!N86UE<V5R=F5R(BP*"2=D;G-?7V1N<U]R96-O<F1?;F]T
M7V5X:7-T)R`]/B`B5&AE<F4@:7,@;F\@<W5C:"!R97-O=7)C92!R96-O<F0@
M:6X@=&AE('IO;F4N(BP*"2=D;G-?7V1N<U]Z;VYE7V9O<E]D;VUA:6XG(#T^
M(")$3E,@>F]N92!F;W(@=&AE(&1O;6%I;B(L"@DG9&YS7U]D;G-?>F]N95]L
M96=E;F0G(#T^("=297-O=7)C92!R96-O<F1S)RP*"2=D;G-?7V1N<U]Z;VYE
M7VUA<W1E<E]T:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@82!P<FEM
M87)Y(&YA;65S97)V97(@9F]R('1H92!$3E,@>F]N92`E,2<L"@DG9&YS7U]D
M;G-?>F]N95]S;&%V95]T:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@
M82!S96-O;F1A<GD@;F%M97-E<G9E<B!F;W(@=&AE($1.4R!Z;VYE("4Q)RP*
M"2=D;G-?7V1N<U]Z;VYE7V]F9E]T:71L92<@/3X@)TYA;65S97)V97)S(&9O
M<B!T:&4@1$Y3('IO;F4@)3$G+`H))V1N<U]?861D7V1N<U]R96-O<F1?;6%S
M=&5R7W1I=&QE)R`]/B`G061D(')E<V]U<F-E(')E8V]R9"!T;R!T:&4@>F]N
M92<L"@DG9&YS7U]A9&1?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@)T%D
M9"!P<FEM87)Y($1.4R!S97)V97(G+`H))V1N<U]?861D7V1N<U]R96-O<F1?
M;V9F7W1I=&QE)R`]/B`G061D(&YA;65S97)V97(G+`H))V1N<U]?961I=%]D
M;G-?<F5C;W)D7VUA<W1E<E]T:71L92<@/3X@)T5D:70@<F5S;W5R8V4@<F5C
M;W)D)RP*"2=D;G-?7V5D:71?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@
M)T5D:70@<V5R=F5R(')E8V]R9"<L"@DG9&YS7U]E9&ET7V1N<U]R96-O<F1?
M;V9F7W1I=&QE)R`]/B`G161I="!N86UE<V5R=F5R)RP*"2=D;G-?7V1N<U]R
M96-O<F1?:6YV86QI9%]V86QU97,G(#T^("=4:&5R92!A<F4@:6YC;W)R96-T
M('!A<F%M971E<B!V86QU97,N)RP*"2=D;G-?7V1N<U]Z;VYE7VEN=F%L:61?
M=F%L=65S)R`]/B`G5&AE<F4@87)E(&EN8V]R<F5C="!P87)A;65T97(@=F%L
M=65S+B<L"@DG9&YS7U]D;G-?<V]A7W1I=&QE)R`]/B`G4T]!(%!R969E<F5N
M8V5S)RP*"2=D;G-?7V1N<U]S;V%?;&5G96YD)R`]/B`G4T]!(%!R969E<F5N
M8V5S)RP*"2=D;G-?7V1N<U]S;V%?='1L)R`]/B`G5%1,)RP*"2=D;G-?7V1N
M<U]S;V%?<F5F<F5S:"<@/3X@)U)E9G)E<V@G+`H))V1N<U]?9&YS7W-O85]R
M971R>2<@/3X@)U)E=')Y)RP*"2=D;G-?7V1N<U]S;V%?97AP:7)E)R`]/B`G
M17AP:7)E)RP*"2=D;G-?7V1N<U]S;V%?;6EN:6UU;2<@/3X@)TUI;FEM=6TG
M+`H))V1N<U]?9&YS7W-O85]T=&Q?97)R;W(G(#T^("=45$P@=F%L=64@:7,@
M:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N
M)RP*"2=D;G-?7V1N<U]S;V%?<F5F<F5S:%]E<G)O<B<@/3X@)U)E9G)E<V@@
M=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@
M-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]S;V%?<F5T<GE?97)R;W(G(#T^("=2
M971R>2!V86QU92!I<R!I;G9A;&ED+B!)="!C86X@8F4@9G)O;2`Q('-E8V]N
M9"!T;R`V."!Y96%R<RXG+`H))V1N<U]?9&YS7W-O85]E>'!I<F5?97)R;W(G
M(#T^("=%>'!I<F4@=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@
M,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]S;V%?;6EN:6UU
M;5]E<G)O<B<@/3X@)TUI;FEM=6T@=F%L=64@:7,@:6YV86QI9"X@270@8V%N
M(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]D
M969A=6QT7W1I=&QE)R`]/B`G4F5S=&]R92!T:&4@1$Y3('IO;F4N)RP*"2=D
M;G-?7V1N<U]D969A=6QT7VQE9V5N9"<@/3X@)UIO;F4@<F5S=&]R:6YG(&]P
M=&EO;G,N)RP*"2=D;G-?7V1N<U]D969A=6QT7W1E>'0G(#T^("=#:&]O<V4@
M=&AE('-E='1I;F=S(&9O<B!R97-T;W)I;F<@=&AE($1.4R!Z;VYE+"!C;VYF
M:7)M('1H96T@86YD(&-L:6-K($]++B<L"@DG9&YS7U]D;G-?9&5F875L=%]C
M;VYF:7)M)R`]/B`G0V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*
M"2=D;G-?7V1N<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A
M<V4@8V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*"@DG9&YS7W1?
M7V1N<U]D969A=6QT7W1I=&QE)R`]/B`G4F5S=&]R92!T:&4@;W)I9VEN86P@
M1$Y3('IO;F4@=&5M<&QA=&4N)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?;&5G
M96YD)R`]/B`G4F5S=&]R:6YG(&]P=&EO;G,N)RP*"2=D;G-?=%]?9&YS7V1E
M9F%U;'1?=&5X="<@/3X@)T-H;V]S92!T:&4@<V5T=&EN9W,@9F]R(')E<W1O
M<FEN9R!T:&4@1$Y3('IO;F4@=&5M<&QA=&4L(&-O;F9I<FT@=&AE;2!A;F0@
M8VQI8VL@3TLN)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?8V]N9FER;2<@/3X@
M)T-O;F9I<FT@<F5S=&]R:6YG(&]F($1.4R!Z;VYE('1E;7!L871E+B<L"@DG
M9&YS7W1?7V1N<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A
M<V4@8V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4@=&5M<&QA=&4N)RP*
M"2=D;G-?=%]?9&YS7WIO;F5?;V9F7W)E;6]V95]T:71L92<@/3X@(E1H92!F
M;VQL;W=I;F<@<F5S;W5R8V4@<F5C;W)D<R!F;W(@1$Y3('IO;F4@=&5M<&QA
M=&4@=VEL;"!B92!R96UO=F5D.B(L"@DG9&YS7W1?7V1N<U]Z;VYE7VUA<W1E
M<E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E
M8V]R9',@=VEL;"!B92!R96UO=F5D(&9R;VT@1$Y3('IO;F4@=&5M<&QA=&4Z
M(BP*"2=D;G-?=%]?861D7V1N<U]R96-O<F1?;6%S=&5R7W1I=&QE)R`]/B`G
M061D(')E<V]U<F-E(')E8V]R9"!T;R!T:&4@>F]N92!T96UP;&%T92<L"@DG
M9&YS7W1?7V%D9%]D;G-?<F5C;W)D7V]F9E]T:71L92<@/3X@)T%D9"!N86UE
M<V5R=F5R)RP*"2=D;G-?=%]?961I=%]D;G-?<F5C;W)D7VUA<W1E<E]T:71L
M92<@/3X@)T5D:70@<F5S;W5R8V4@<F5C;W)D)RP*"2=D;G-?=%]?961I=%]D
M;G-?<F5C;W)D7V]F9E]T:71L92<@/3X@)T5D:70@;F%M97-E<G9E<B<L"@DG
M9&YS7W1?7W-E;&5C=%]R96-O<F1?=&]?<F5M;W9E)R`]/B`G4V5L96-T(')E
M8V]R9',@=&\@8F4@<F5M;W9E9"!F<F]M('1H92!$3E,@=&5M<&QA=&4N)RP*
M"@DG9&YS7U]U;FET7W-E8V]N9',G(#T^("=S96-O;F1S)RP*"2=D;G-?7W5N
M:71?;6EN=71E<R<@/3X@)VUI;G5T97,G+`H))V1N<U]?=6YI=%]H;W5R<R<@
M/3X@)VAO=7)S)RP*"2=D;G-?7W5N:71?9&%Y<R<@/3X@)V1A>7,G+`H))V1N
M<U]?=6YI=%]W965K<R<@/3X@)W=E96MS)RP*"2=D;G-?7V1N<U]Z;VYE7V]F
M9E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E
M8V]R9',@=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE('IO;F4@)3$Z(BP*"2=D
M;G-?7V1N<U]Z;VYE7VUA<W1E<E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L
M;&]W:6YG(')E<V]U<F-E(')E8V]R9',@9F]R($1.4R!Z;VYE("4Q('=I;&P@
M8F4@<F5M;W9E9#HB+`H))V1N<U]?9&YS7WIO;F5?<VQA=F5?<F5M;W9E7W1I
M=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!P<FEM87)Y(&YA;65S97)V97(@<F5C
M;W)D<R!F;W(@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&YS7U]D;G-?>F]N
M95]S=&%T=7,G(#T^(")$3E,@>F]N92!S=&%T=7,N(BP*"2=D;G-?7V1N<U]Z
M;VYE7W1E;7!L871E)R`]/B`B1$Y3('IO;F4@=&5M<&QA=&4B+`H))V1N<U]?
M9&YS7WIO;F5?=&5M<&QA=&5?<F5S=&]R95]D969A=6QT)R`]/B`B4F5S=&]R
M92!T:&4@9&5F875L="!$3E,@>F]N92!T96UP;&%T92(L"@DG9&YS7U]D;G-?
M>F]N95]T96UP;&%T95]R97-T;W)E7V1E9F%U;'1?8V]N9FER;2<@/3X@(E)E
M<W1O<FEN9R!T:&4@<W1A;F1A<F0@1$Y3('IO;F4@=&5M<&QA=&4@=VEL;"!D
M:7-C87)D('1H92!C=7)R96YT;'D@=7-E9"!T96UP;&%T92P@<')O8V5E9"!A
M;GEW87D_(BP*"2=D;G-?7V1N<U]Z;VYE7W1E;7!L871E7W)E<W1O<F5?9&5F
M875L=%]E<G)O<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!T:&4@1$Y3('IO;F4@
M=&5M<&QA=&4Z(BP*"2=D;G-?7VAO<W0G(#T^(")(;W-T(BP*"2=D;G-?7VEN
M=F%L:61?:7!?861D<F5S<R<@/3X@(DE0(&%D9')E<W,@;V8@;F5W(&UA<W1E
M<B!$3E,@<V5R=F5R(&ES(&EN=F%L:60@;W(@96UP='DN(BP*"2=D;G-?7VEP
M7V%D9')E<W,G(#T^("))4"!!9&1R97-S(BP*"2=D;G-?7VUA<W1E<E]D;G-?
M='EP92<@/3X@(FES(&$@;6%S=&5R($1.4R!S97)V97(B+`H))V1N<U]?;6%S
M=&5R<R<@/3X@(D1.4R!M87-T97(@<V5R=F5R<R(L"@DG9&YS7U]S;V%?;6EN
M:6UU;5]T;V]?;&%R9V4G(#T^("=#86-H:6YG(&YE9V%T:79E(')E<W!O;G-E
M<R!F;W(@;6]R92!T:&%N('1H<F5E(&AO=7)S(&ES(&YO="!R96-O;6UE;F1E
M9"XG+`H))V1N<U]?<V5L96-T7VUA<W1E<G-?=&]?<F5M;W9E)R`]/B`B4V5L
M96-T(')E8V]R9',@=&\@8F4@<F5M;W9E9"XB+`H))V1N<U]?<V5L96-T7W1E
M;7!L871E7W)E8V]R9%]T;U]R96UO=F4G(#T^("=396QE8W0@<F5C;W)D<R!T
M;R!B92!R96UO=F5D+B<L"@DG9&YS7U]S96QE8W1?8V]M;6]N7V%C;%]R96-O
M<F1?=&]?<F5M;W9E)R`]/B`G4V5L96-T($%#3"!R96-O<F1S(&9O<B!R96UO
M=FEN9RXG+`H))V1N<U]?<V5L96-T7W)E8V]R9%]T;U]R96UO=F4G(#T^("=3
M96QE8W0@<F5S;W5R8V4@<F5C;W)D<R!T;R!B92!R96UO=F5D+B<L"@DG9&YS
M7U]N86UE<V5R=F5R<U]F;W)?9&]M86EN)R`]/B`B3F%M97-E<G9E<G,@9F]R
M('1H92!D;VUA:6XB+`H))V1N<U]?;G,G(#T^(").86UE('-E<G9E<B(L"@DG
M9&YS7U]N<U]R96-O<F0G(#T^(").86UE('-E<G9E<G,B+`H))V1N<U]?<F5M
M;W9E7V1N<U]M87-T97)S7V]N7V1O;6%I;B<@/3X@(E1H92!F;VQL;W=I;F<@
M1$Y3(&UA<W1E<B!S97)V97)S(&9O<B!D;VUA:6X@)3(@;W=N960@8GD@8VQI
M96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB+`H))V1N<U]?<F5M;W9E7V1N<U]Z
M;VYE7V]F7V1O;6%I;E]?)R`]/B`B1$Y3(')E8V]R9',@<F5M;W9A;"!F<F]M
M(&1O;6%I;B`E,2(L"@DG9&YS7U]R96UO=F5?9&YS7WIO;F5?=&5M<&QA=&5?
M7R<@/3X@(E1H92!F;VQL;W=I;F<@<F5S;W5R8V4@<F5C;W)D<R!W:6QL(&)E
M(')E;6]V960@9G)O;2!T:&4@=&5M<&QA=&4Z(BP*"2=D;G-?7W)E;6]V95]C
M;VUM;VY?86-L7W)E8V]R9"<@/3X@(E1H92!F;VQL;W=I;F<@04-,(')E8V]R
M9',@=VEL;"!B92!R96UO=F5D(BP*"2=D;G-?7W)E;6]V95]T:&ES7V1N<U]R
M96-O<F0_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E;6]V92!T
M:&ES($1.4R!R96-O<F0_(BP*"2=D;G-?7W)E<W1O<F5?9&5F875L="<@/3X@
M(E)E<W1O<FEN9R!T:&4@1$Y3('IO;F4@8GD@=&AE('1E;7!L871E(BP*"2=D
M;G-?7W)E<W1O<F5?9&5F875L=%]C;VYF:7)M)R`]/B`B4F5S=&]R:6YG('1H
M92!$3E,@>F]N92!W:6QL(&1I<V-A<F0@=&AE(&-U<G)E;G0@1$Y3('IO;F4@
M8V]N9FEG=7)A=&EO;BP@<')O8V5E9"!A;GEW87D_(BP*"2=D;G-?7W)E<W1O
M<F5?9&5F875L=%]E<G)O<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!$3E,@>F]N
M93HB+`H))V1N<U]?<VQA=F5?9&YS7W1Y<&4G(#T^(")I<R!A('-E8V]N9&%R
M>2!N86UE('-E<G9E<B(L"@DG9&YS7U]S=6)D;VUA:6Y?9&YS7W)E8U]R96UO
M=F5D)R`]/B`B5&AE($$@<F5C;W)D(&AA<R!B965N(')E;6]V960@9G)O;2!T
M:&4@<W5B9&]M86EN('IO;F4@)3$B+`H))V1N<U]?='EP92<@/3X@(E)E8V]R
M9"!T>7!E(BP*"2=D;G-?7W5N86)L95]A8W1I=F%T92]D96%C=&EV871E7V1N
M<R<@/3X@(E5N86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E($1.4SH@)3$B
M+`H))V1N<U]?=6YA8FQE7V%D9%]D;G-?;6%S=&5R7V1U<&QI8V%T95]E;G1R
M>2<@/3X@(E5N86)L92!T;R!A9&0@1$Y3(&UA<W1E<B!S97)V97(Z(&1U<&QI
M8V%T92!E;G1R>2XB+`H))V1N<U]?=6YA8FQE7V1E9FEN95]D;G-?<F5C;W)D
M)R`]/B`B56YA8FQE('1O(&1E9FEN92!T:&4@1$Y3(')E8V]R9#H@)3$B+`H)
M)V1N<U]?=6YA8FQE7V=E=%]D;G-?=&5M<&QA=&5?<W1A='5S)R`]/B`B56YA
M8FQE('1O(')E=')I979E('1H92!$3E,@=&5M<&QA=&4@<W1A='5S+B(L"@DG
M9&YS7U]U;F%B;&5?<F5M;W9E7V1N<U]R96,G(#T^(")5;F%B;&4@=&\@<F5M
M;W9E('1H92!$3E,@<F5C;W)D.B`E,2(L"@DG9&YS7U]V86PG(#T^(")686QU
M92(L"@DG9&YS7U]W87)N:6YG<U]?)R`]/B`B5&AE(')E<W5L="!O9B!$3E,@
M>F]N92!M;V1I9FEC871I;VXZ(BP*"2=D;G-?7WEO=5]N;W1?:&%V95]P97)M
M7VUA;F%G95]D;G,G(#T^(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T
M;R!M86YA9V4@=&AE($1.4R!Z;VYE(&9O<B!T:&ES(&1O;6%I;BXB+`H))V1N
M<U]?>F]N95]R96-O<F0G(#T^(")$3E,@<F5C;W)D<R(L"@DG9&YS7U]D;G-?
M<')E9F5R96YC97-?9F]R;2<@/3X@)T1.4R!P<F5F97)E;F-E<R<L"@DG9&YS
M7U]D;G-?<F5C=7)S:6]N7W-E='1I;F=S)R`]/B`G1$Y3(')E8W5R<VEO;B!S
M971T:6YG<R<L"@DG9&YS7U]A;&QO=U]R96-U<G-I;VXG(#T^("=!;&QO=R!R
M96-U<G-I;VXG+`H))V1N<U]A9&1?7V%D9%]R96-?9F]R7WIO;F4G(#T^(")!
M9&0@)3$@9F]R('IO;F4@)3(B+`H))V1N<U]A9&1?7V-A;F]N:6-A;%]D;VU?
M;F%M95]I<U]I;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N86UE(&ES
M(&EN=F%L:60N(BP*"2=D;G-?861D7U]E;G1E<E]C86YO;FEC86Q?;F%M92<@
M/3X@(D5N=&5R(&$@8V%N;VYI8V%L(&YA;64B+`H))V1N<U]A9&1?7V5N=&5R
M7V1O;5]N86UE)R`]/B`B16YT97(@9&]M86EN(&YA;64B+`H))V1N<U]A9&1?
M7V5N=&5R7VEP7V%D9')E<W,G(#T^(")%;G1E<B!)4"!A9&1R97-S(BP*"2=D
M;G-?861D7U]E;G1E<E]I<%]M87-K)R`]/B`B16YT97(@25`O;6%S:R(L"@DG
M9&YS7V%D9%]?96YT97)?;6%I;%]D;VUA:6XG(#T^(")%;G1E<B!M86EL(&1O
M;6%I;B(L"@DG9&YS7V%D9%]?96YT97)?;6%I;%]E>&-H86YG97(G(#T^(")%
M;G1E<B!M86EL(&5X8VAA;F=E<B(L"@DG9&YS7V%D9%]?96YT97)?;F%M97-E
M<G9E<B<@/3X@(D5N=&5R(&YA;65S97)V97(B+`H))V1N<U]A9&1?7V5N=&5R
M7W1X=%]R96-O<F0G(#T^(")%;G1E<B!46%0@<F5C;W)D(BP*"2=D;G-?861D
M7U]I;G9A;&ED7VEP)R`]/B`B25`@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG
M9&YS7V%D9%]?;&]W)R`]/B`B;&]W(BP*"2=D;G-?861D7U]M86EL7V1O;5]N
M86UE7VES7VEN=F%L:60G(#T^(")-86EL(&1O;6%I;B!N86UE(&ES(&EN=F%L
M:60N(BP*"2=D;G-?861D7U]N86UE<V5R=F5R7VES7VEN=F%L:60G(#T^(").
M86UE<V5R=F5R(&ES(&EN=F%L:60N(BP*"2=D;G-?861D7U]R96-O<F0G(#T^
M("(E,2!R96-O<F0B+`H))V1N<U]A9&1?7W-E;&5C=%]P<F5F97)?9F]R7VUA
M:6Q?97AC:&%N9V5?<V5R=F5R)R`]/B`B4W!E8VEF>2!P<FEO<FET>2!O9B!M
M86EL(&5X8VAA;F=E('-E<G9E<B(L"@DG9&YS7V%D9%]?=6YA8FQE7VEN<V5R
M=%]N97=?9&YS7W)E8R<@/3X@(E5N86)L92!T;R!I;G-E<G0@;F5W($1.4R!R
M96-O<F0Z("4Q(BP*"2=D;G-?861D7U]V97)Y7VAI9V@G(#T^(")V97)Y(&AI
M9V@B+`H))V1N<U]C:&5C:U]?=&5S=%]D;G-?>F]N92<@/3X@(E1E<W0@1$Y3
M('IO;F4@)3$@;VX@)3(B+`H))V1N<U]C:&5C:U]?=6YA8FQE7V=E=%]D;VU?
M<')O<&5R=&EE<R<@/3X@(E5N86)L92!T;R!R971R:65V92!D;VUA:6X@<')O
M<&5R=&EE<SH@)3$B+`H))V1O;5]C=')L7U]A;&QO=V5D)R`]/B`B06QL;W=E
M9"(L"@DG9&]M7V-T<FQ?7V1B)R`]/B`B1&%T86)A<V5S(BP*"2=D;VU?8W1R
M;%]?9&5L7VAS=%]O;E]D;VTG(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@<F5M;W9E(&AO<W1I;F<@8V]N9FEG=7)A=&EO;B!F<F]M(&1O;6%I;B`E
M,3\B+`H))V1O;5]C=')L7U]D:7-K7W-P86-E)R`]/B`B1&ES:R!S<&%C92(L
M"@DG9&]M7V-T<FQ?7V1O;5]A9&TG(#T^(")$;VUA:6X@)3$@;V8@)3(B+`H)
M)V1O;5]C=')L7U]D;VU?8VPG(#T^(")$;VUA:6X@)3$B+`H))V1O;5]C=')L
M7U]D;VUA:6Y?:&%S7V9O<G=A<F1I;F=?=VET:%]U;F1E9FEN961?9G=D7W5R
M;"<@/3X@(D1O;6%I;B!H87,@9F]R=V%R9&EN9R!S970@=7`@=VET:"!U;F1E
M9FEN960@9F]R=V%R9&EN9R!54DPB+`H))V1O;5]C=')L7U]D;VUA:6Y?:&%S
M7V9R86UE7V9O<G=A<F1I;F<G(#T^(")$;VUA:6X@:&%S(&9R86UE(&9O<G=A
M<F1I;F<@=&\@=&AE(%523"`E,2(L"@DG9&]M7V-T<FQ?7V1O;6%I;E]H87-?
M;F]?:&]S=&EN9R<@/3X@(D1O;6%I;B!H87,@;F\@:&]S=&EN9R!C;VYF:6=U
M<F5D(BP*"2=D;VU?8W1R;%]?9&]M86EN7VAA<U]P:'ES:6-A;%]H;W-T:6YG
M)R`]/B`B1&]M86EN(&AA<R!P:'ES:6-A;"!H;W-T:6YG(&]N($E0("4Q(BP*
M"2=D;VU?8W1R;%]?9&]M86EN7VAA<U]S=&%N9&%R9%]F;W)W87)D:6YG)R`]
M/B`B1&]M86EN(&AA<R!S=&%N9&%R9"!F;W)W87)D:6YG('1O('1H92!54DP@
M)3$B+`H))V1O;5]C=')L7U]M86EL;&ES=',G(#T^(")-86EL:6YG(&QI<W1S
M(BP*"2=D;VU?8W1R;%]?;6)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=D;VU?
M8W1R;%]?;6<G(#T^(")-86EL(&=R;W5P<R(L"@DG9&]M7V-T<FQ?7W)E9&ER
M)R`]/B`B4F5D:7)E8W1S(BP*"2=D;VU?8W1R;%]?<F5S;W5R8V5?;F%M92<@
M/3X@(E)E<V]U<F-E(BP*"2=D;VU?8W1R;%]?<F5S<"<@/3X@(D%U=&]R97-P
M;VYD97)S(BP*"2=D;VU?8W1R;%]?<W5B9&]M)R`]/B`B4W5B9&]M86EN<R(L
M"@DG9&]M7V-T<FQ?7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=D;VU?8W1R
M;%]?=6YA8FQE7V%C=&EV871E+V1E86-T:79A=&5?9&]M)R`]/B`B56YA8FQE
M('1O(&%C=&EV871E+V1E86-T:79A=&4@9&]M86EN.B`E,2(L"@DG9&]M7V-T
M<FQ?7W5S960G(#T^(")5<V5D(BP*"2=D;VU?8W1R;%]?=V5B87!P<R<@/3X@
M(DIA=F$@87!P;&EC871I;VYS(BP*"2=D;VU?8W1R;%]?>6]U7W=A;G1?8VAA
M;F=E7W1H95]S=&%T=7-?;V9?=&AE7V1O;6%I;C\_)R`]/B`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@9&]M86EN/R(L
M"@DO+R!E;F0@;V8@<V5R9V4@<&%R=`H*"2\O(&UA=F5R:6-K('!A<G0*"@DG
M9&]M7V-T<FQ?7W=U)R`]/B`B5V5B('5S97)S(BP*"2=D;VU?<')E9E]?8F]U
M;F-E7W=I=&A?<&AR87-E)R`]/B`B0F]U;F-E('=I=&@@;65S<V%G92(L"@DG
M9&]M7W!R969?7V-A=&-H7V%D9'(G(#T^(")&;W)W87)D('1O(&%D9')E<W,B
M+`H))V1O;5]P<F5F7U]R96IE8W0G(#T^("=296IE8W0G+`H))V1O;5]P<F5F
M7U]C;VYF:7)M7V1O;6%I;E]R96UO=FEN9R<@/3X@(E!L96%S92P@9&\@;F]T
M(&9O<F=E="!T;R!I;F9O<FT@=&AE(&1O;6%I;B!V:7-I=&]R<R!O9B!T:&4@
M9&]M86EN(&YA;64@8VAA;F=E+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5N86UE('1H92!D;VUA:6X_(BP*"2=D;VU?<')E9E]?9&)?:6YC;VYS>7-T
M96YC>2<@/3X@(F1A=&%B87-E(&EN8V]N<VES=&5N8WDN(BP*"2=D;VU?<')E
M9E]?9&)S)R`]/B`B9&%T86)A<V5S(BP*"2=D;VU?<')E9E]?9&5L971E7W1R
M869F:6-?<W1A="<@/3X@(E)E=&%I;B!T<F%F9FEC('-T871I<W1I8W,B+`H)
M)V1O;5]P<F5F7U]D96QE=&5?=')A9F9I8U]S=&%T7V]L9&5R)R`]/B`B4F5T
M86EN('1R869F:6,@<W1A=&ES=&EC<R(L"@DG9&]M7W!R969?7V1O7VYO=%]U
M<V5?<WEM8F]L7V%P;W-T<F]F)R`]/B`B1&\@;F]T('5S92!A<&]S=')O<&AE
M+"!R979E<G-E(&%P;W-T<F]P:&4L('-E;6EC;VQO;B!O<B!E;7!T>2!V86QU
M92!I;B!T:&4@8F]U;F-E(&UE<W-A9V4@9FEE;&0N(BP*"2=D;VU?<')E9E]?
M9&]M7VQE=F5L7VYA;65?8V]N9FQI8W0G(#T^(")4:&4@9&]M86EN(&%D;6EN
M:7-T<F%T;W(G<R!L;V=I;B!N86UE(&-O;F9L:6-T<R!W:71H(&QO9VEN(&YA
M;64@;V8@;VYE(&]F('1H92!C;&EE;G1S+B(L"@DG9&]M7W!R969?7VEN=F%L
M:61?9&ES:U]S<&%C95]L:6UI="<@/3X@(DEN=F%L:60@9&ES:R!S<&%C92!L
M:6UI="XB+`H))V1O;5]P<F5F7U]I;G9A;&ED7V5X<&ER871I;VY?9&%T95]L
M:6UI="<@/3X@(DEN=F%L:60@=F%L:61I='D@<&5R:6]D+B(L"@DG9&]M7W!R
M969?7VEN=F%L:61?;6%X7W1R869F:6-?;&EM:70G(#T^("));G9A;&ED('1R
M869F:6,@;&EM:70N(BP*"2=D;VU?<')E9E]?;&EM:71S7V]F7V1O;2<@/3X@
M(DQI;6ET<R!F;W(@9&]M86EN("4Q(BP*"2=D;VU?<')E9E]?;6%I;%]G<G!S
M)R`]/B`B;6%I;"!G<F]U<',B+`H))V1O;5]P<F5F7U]M86EL7VYO;F5X:7-T
M96YT7W5S97(G(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V1O
M;5]P<F5F7U]M86EL7W)E9&ER<R<@/3X@(FUA:6P@<F5D:7)E8W1S(BP*"2=D
M;VU?<')E9E]?;6%I;%]R97-P<R<@/3X@(FUA:6P@875T;W)E<W!O;F1E<G,B
M+`H))V1O;5]P<F5F7U]M87A?;&EM:71?:7-?:6YV86QI9"<@/3X@(B4Q(&ES
M(&EN=F%L:60N(BP*"2=D;VU?<')E9E]?;6%X7VYU;5]O9E\E;V)J96-T<U]I
M<U]I;G9A;&ED)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@)3$@:7,@:6YV86QI
M9"XB+`H))V1O;5]P<F5F7U]N97=?;&EM:71?;&5S<U]C=7)R96YT;'E?=7-E
M9"<@/3X@(B4Q.B!R97%U97-T960@+2`E,BP@8W5R<F5N=&QY('5S960@+2`E
M,R(L"@DG9&]M7W!R969?7V]L9&5R7W1H870G(#T^("(@9F]R("(L"@DG9&]M
M7W!R969?7W!O<W1B;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG9&]M7W!R969?
M7W!R969E<F5N8V5S7V]F7V1O;2<@/3X@(E!R969E<F5N8V5S(&9O<B!D;VUA
M:6X@)3$B+`H))V1O;5]P<F5F7U]R961I<F5C=%]T;U]I='-E;&8G(#T^(")4
M:&4@9&]M86EN('=I;&P@:&%V92!T:&4@9F]R=V%R9&EN9R!S970@=&\@:71S
M96QF(BP*"2=D;VU?<')E9E]?=')A9E]S=&%T7W=I;&Q?;F]T7V1E;&5T92<@
M/3X@(E1R869F:6,@<W1A=&ES=&EC<R!W:6QL(&YO="!B92!D96QE=&5D+B(L
M"@DG9&]M7W!R969?7W1R869F:6-?;&]G9VEN9U]P97)I;V1?8V]U;&1N=%]B
M95]L;W=E<B<@/3X@(EEO=2!S<&5C:69I960@=&AE(&1O;6%I;B!T<F%F9FEC
M('-T871I<W1I8W,@<F5T96YT:6]N('1I;64@=&\@8F4@;&5S<R!T:&%N('1H
M92!T;W1A;"!V86QU92!D969I;F5D(&9O<B!T:&4@<V5R=F5R("@E,2!M;VYT
M:"AS*2DN(%1H92!S=&%T:7-T:6-S(')E=&5N=&EO;B!P97)I;V0@:7,@<V5T
M(&5Q=6%L('1O('1H92!D969A=6QT('9A;'5E(&9O<B!T:&4@<V5R=F5R("@E
M,2!M;VYT:"AS*2DN(BP*"2=D;VU?<')E9E]?=6YA8FQE7V%D9%]W=W=?<')E
M9FEX7VEN7V1O;2<@/3X@(E5N86)L92!T;R!A9&0@82!W=W<@<')E9FEX('1O
M(&1O;6%I;CH@)3$B+`H))V1O;5]P<F5F7U]U;F%B;&5?9&5F:6YE7W!H>7-I
M8V%L7VAS=%]P87)A;2<@/3X@(E5N86)L92!T;R!D969I;F4@<&AY<VEC86P@
M:&]S=&EN9R!P87)A;65T97)S.B`E,2(L"@DG9&]M7W!R969?7W5N86)L95]R
M96YA;65?9&]M86EN)R`]/B`B56YA8FQE('1O(')E;F%M92!T:&4@9&]M86EN
M(BP*"2=D;VU?<')E9E]?=6YA8FQE7W-E=%]U<%]M8F]X7W%U;W1A)R`]/B`B
M56YA8FQE('1O('-E="!T:&4@;6%I;&)O>"!Q=6]T82!F;W(@=&AI<R!D;VUA
M:6XZ("4Q(BP*"2=D;VU?<')E9E]?=6YA8FQE7W-E=%]U<%]W96)?=7-E<E]S
M8W)I<'0G(#T^(")5;F%B;&4@=&\@<V5T('5P('-C<FEP=&EN9R!F;W(@=V5B
M('5S97)S.B`E,2(L"@DG9&]M7W!R969?7W5N;&EM:71E9"<@/3X@(E5N;&EM
M:71E9"(L"@DG9&]M7W!R969?7W=E8E]U<W)S)R`]/B`B=V5B('5S97)S(BP*
M"2=D;VU?<')E9E]?=V5B=7-E<G-?<V-R:7!T)R`]/B`B06QL;W<@=&AE('=E
M8B!U<V5R<R!S8W)I<'1I;F<B+`H))V1O;5]P<F5F7U]Y;W5?86QR96%D>5]H
M879E7R5O8FIE8W0G(#T^(")9;W4@86QR96%D>2!H879E("4Q(BP*"2=D;VU?
M8VQI7U]W87)N:6YG7VEG;F]R95]Q=6]T82<@/3X@)U=!4DY)3D<Z($]P=&EO
M;B`B+6AA<F1?<75O=&$B(&ES(&EG;F]R960Z(&AA<F0@9&ES:R!Q=6]T82!I
M<R!N;W0@<W5P<&]R=&5D)RP*"2=D;VU?=7-E<E]C;&EE;G1?;&]G:6Y?97AI
M<W0G(#T^(")5;F%B;&4@=&\@86QL;W<@9&]M86EN(&%D;6EN:7-T<F%T;W(G
M<R!A8V-E<W,@=&\@8V]N=')O;"!P86YE;"!O;B!T:&4@9&]M86EN("4Q.B!L
M;V=I;B!N86UE(&ES(&%L<F5A9'D@:6X@=7-E+B(L"@DG9&]M7W1R869F:6-?
M:&ES=&]R>5]?=&ET;&4G(#T^(")$;VUA:6X@/'-P86X@8VQA<W,]7")N86UE
M7"(^)3$\+W-P86X^('1R869F:6,@:&ES=&]R>2XB+`H))V1O;6%I;E]?<W5B
M9&]M86EN7V5X:7-T<R<@/3X@(E1H97)E(&ES(&$@<W5B9&]M86EN('=I=&@@
M;F%M92`E,2XE,BXB+`H))V1O;6%I;E]?9&%L:6%S7V5X:7-T<R<@/3X@(E1H
M97)E(&ES(&$@9&]M86EN(&%L:6%S('=I=&@@;F%M92`E,2XE,BXB+`H))V1O
M;6%I;E]?=6YA8FQE7W1O7W1U<FY?;VY?<V5R=FEC92<@/3X@(D9A:6QE9"!T
M;R!E;F%B;&4@=&AE("4Q('-E<G9I8V4B+`H))V1O;6%I;G-?7V-H86YG95]T
M:&5?<W1A='5S7V]F7V1O;6%I;C\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@8VAA;F=E('1H92!S=&%T=7,@;V8@9&]M86EN("4Q/R(L"@DG9&]M
M86EN<U]?8VQI96YT7VEN9F\G(#T^("(E,2!D;VUA:6YS+"`E,B!A8W1I=F4@
M9&]M86EN<RP@)3,@9&ES:R!S<&%C92!U<V5D+"`E-"!T<F%F9FEC('5S960B
M+`H))V1O;6%I;G-?7V-L:65N=%]I;F9O7VAI9&EN9U]T<F%F9FEC)R`]/B`B
M)3$@9&]M86EN<RP@)3(@86-T:79E(&1O;6%I;G,L("4S(&1I<VL@<W!A8V4@
M=7-E9"(L"@DG9&]M86EN<U]?<F5M;W9E7V1O;2<@/3X@(E1H92!F;VQL;W=I
M;F<@9&]M86EN<R!W:6QL(&)E(')E;6]V960Z(BP*"2=D;VUA:6YS7U]R96UO
M=F5?9&]M7V9O<E]C;"<@/3X@(E1H92!F;VQL;W=I;F<@9&]M86EN<R!O=VYE
M9"!B>2!C;&EE;G0@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&]M86EN<U]?
M<V5L96-T7V1O;5]F;W)?<F5M;W9E)R`]/B`B4V5L96-T(&1O;6%I;G,@=&\@
M8F4@<F5M;W9E9"XB+`H))V1O;6%I;G-?7W5N86)L95]T;U]C:&%N9V5?8VQI
M96YT7W-T871U<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&-L:65N="!A
M8V-O=6YT('-T871U<SH@)3$B+`H))V1O;6%I;G-?7W5N86)L95]U<&1A=&5?
M87!A8VAE7W-E='1I;F=S)R`]/B`B56YA8FQE('1O('5P9&%T92!!<&%C:&4@
M<V5T=&EN9W,B+`H))V1O;6%I;G-?7WEO=5]D;U]N;W1?:&%V95]P97)M:7-S
M:6]N<U]T;U]D96QE=&5?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N<R!T;R!D96QE=&4@9&]M86EN<RXB+`H))V1O;6%I;G-?7WEO
M=5]W86YT7V-H86YG95]T:&5?<W1A='5S7V]F7W1H95]C;#\_)R`]/B`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@8VQI
M96YT(&%C8V]U;G0_(BP*"2=D;VUA:6YS7U]Y;W5?=V%N=%]C:&%N9V5?=&AE
M7V-P7V%C8V5S<U]O9E]T:&5?8VP_/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!P97)F;W)M('1H:7,@;W!E<F%T:6]N/R(L"@DG9&]M86EN<U]L
M:7-T7U]U;F%B;&5?<F5M;W9E7V1O;7,G(#T^(")5;F%B;&4@=&\@<F5M;W9E
M(&1O;6%I;G,Z("4Q(BP*"2=D;VUA:6YT<F%F9FEC;&ES=%]H96%D97)?;V9?
M9&]M86EN7U\G(#T^(")4<F%F9FEC(&%T(&1O;6%I;B`E,2(L"@DG9'-?7V%N
M;VYY;6]U<U]F='`G(#T^(")!;F]N>6UO=7,@1E10(BP*"2=D<G=E8E]?<&%G
M971I=&QE)R`]/B`G1'(N5V5B($%N=&EV:7)U<R!0<F5F97)E;F-E<R<L"@DG
M9')W96)?7V1R=V5B)R`]/B`G06YT:79I<G5S(&UA:6P@8VAE8VMI;F<G+`H)
M)V1R=V5B7U]D<G=E8E]D:7)E8W1I;VXG(#T^("=#:&5C:VEN9R!M86EL(&9O
M<B!V:7)U<V5S)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V]F9B<@/3X@
M)T1I<V%B;&5D)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V%N>2<@/3X@
M)TEN8V]M:6YG(&%N9"!O=71G;VEN9R!M86EL)RP*"2=D<G=E8E]?9')W96)?
M9&ER96-T:6]N7V9R;VTG(#T^("=/=71G;VEN9R!M86EL(&]N;'DG+`H))V1R
M=V5B7U]D<G=E8E]D:7)E8W1I;VY?=&\G(#T^("=);F-O;6EN9R!M86EL(&]N
M;'DG+`H))V1R=V5B7U]D:7-A8FQE7W)E87-O;E]K97DG(#T^("=$<BY796(@
M:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DN)RP*"2=D<G=E
M8E]?9&ES86)L95]R96%S;VY?<&5R;2<@/3X@)UEO=2!H879E(&YO('!E<FUI
M<W-I;VX@=&\@;6%N86=E($1R+E=E8B!A;G1I=FER=7,N)RP*"2=D<G=E8E]?
M9&ES86)L95]R96%S;VY?:6YS=&%L;"<@/3X@)T1R+E=E8B!A;G1I=FER=7,@
M:7,@;F]T(&EN<W1A;&QE9"XG+`H))V1S7U]D;G,G(#T^(")$3E,@6F]N92(L
M"@DG9'-?7VUA:6PG(#T^(")-86EL(BP*"2=D<U]?=&]M8V%T)R`]/B`B5&]M
M8V%T(BP*"2=D<W)?7V]F7V-L:65N=%]T:71L92<@/3X@(D1O;6%I;B!3=6UM
M87)Y(%)E<&]R="!O9B`E,2(L"@DG9'-R7U]R97!O<G1?:&%S7V)E96Y?<V5N
M=%]E;6%I;"<@/3X@(D1O;6%I;B!3=6UM87)Y(%)E<&]R="!H87,@8F5E;B!S
M96YT('1O(&4M;6%I;#H@)3$B+`H))V1S<E]?=&ET;&4G(#T^(")$;VUA:6X@
M4W5M;6%R>2!297!O<G0B+`H))V1U;7!?9FEL95]?<F5M;W9E)PD]/B`B4F5M
M;W9E(BP*"2=D=6UP7V9I;&5?7V%D9"<)/3X@(E-P96-I9GD@=&AE(&YE>'0@
M=F]L=6UE(BP*"2=D=6UP<U]L:7-T7U]D96QE=&EO;E]P86=E7W1I=&QE)R`]
M/B`B5&AE(&9O;&QO=VEN9R!B86-K=7`@9FEL97,@;V8@9&]M86EN("4Q('=I
M;&P@8F4@<F5M;W9E9#HB+`H))V1U;7!S7VQI<W1?7W5P;&%D7V1U;7!?9FEL
M97,G(#T^(")5<&QO860@8F%C:W5P(&9I;&4B+`H))V1U;7!S7VQI<W1?7V1U
M;7!?9FEL97,G(#T^(")"86-K=7`@9FEL97,B+`H))V1U;7!S7VQI<W1?7V1U
M;7!F:6QE7V%L<F5A9'E?97AI<W1S)R`]/B`B5&AE(&9I;&4@)3$@86QR96%D
M>2!E>&ES=',N(BP*"2=D=6UP<U]L:7-T7U]D=6UP9FEL95]I<U]I;G9A;&ED
M)R`]/B`B5&AE(&9I;&4@)3$@:7,@;F]T(&$@=F%L:60@9&]M86EN(&)A8VMU
M<"!F:6QE+B(L"@DG9'5M<'-?;&ES=%]?<&%G95]T:71L92<@/3X@(D)A8VMU
M<"!F:6QE<R!R97!O<VET;W)Y(BP*"2=D=6UP<U]U<&QO861?7W!A9V5?=&ET
M;&4G(#T^(")5<&QO861I;F<@0F%C:W5P($9I;&5S('1O(%)E<&]S:71O<GDB
M+`H))V1U;7!S7VQI<W1?7W)E<&]S:71O<GE?:7-?;F]T7V5X:7-T)R`]/B`B
M0F%C:W5P(&9I;&5S(')E<&]S:71O<GD@9&]E<R!N;W0@97AI<W0B+`H))V1U
M;7!S7VQI<W1?7W1O=&%L7W-I>F4G(#T^(")4;W1A;"!S:7IE.B`E,2(L"@DG
M9'5M<'-?;&ES=%]?=6YA8FQE7W1O7W)E;6]V92<@/3X@(E5N86)L92!T;R!R
M96UO=F4@=&AE(&)A8VMU<"!F:6QE.B`E,2(L"@DG9'5M<'-?;&ES=%]?9'5M
M<&9I;&5?8V%N7V-O;F9L:6-T)R`]/B`B5&AE(&9I;&4@;F%M92!Y;W4@<W!E
M8VEF:65D(&-O;F9L:6-T<R!W:71H(&9I;&4@)3'"H%!L96%S92P@<W!E8VEF
M>2!A;F]T:&5R(&9I;&4@;F%M92XB+`H))V1U<W)?961?7V%L;&]W7V1L7W5S
M<E]A8V-E<W,G(#T^(")!;&QO=R!D;VUA:6X@861M:6YI<W1R871O<B=S(&%C
M8V5S<R(L"@DG9'5S<E]E9%]?:6YF;W)M871I;VXG(#T^(")%9&ET('1H92!P
M<F]P97)T:65S(&]F(&1O;6%I;B!A9&UI;FES=')A=&]R)W,@86-C;W5N="(L
M"@DG9'5S<E]E9%]?;&]C86QE)R`]/B`B1&]M86EN(&%D;6EN:7-T<F%T;W(G
M<R!L86YG=6%G92(L"@DG9'5S<E]E9%]?<VMI;B<@/3X@(D1O;6%I;B!A9&UI
M;FES=')A=&]R)W,@:6YT97)F86-E('-K:6XB+`H))V5S<U]?97)R;W(G(#T^
M(")%<G)O<B(L"@DG979E;G1?:&%N9&QE<E]E9&ET7U]T:71L92<@/3X@)T5V
M96YT($AA;F1L97(@4')O<&5R=&EE<R<L"@DG979E;G1?:&%N9&QE<G-?<F5M
M;W9E7U]T:71L92<@/3X@)U)E;6]V92!T:&4@<V5L96-T960@979E;G0@:&%N
M9&QE<G,G+`H))V5V96YT7VAA;F1L97)S7W)E;6]V95]?<V5L96-T7V5V96YT
M7VAA;F1L97)S7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&5V96YT(&AA
M;F1L97)S('1O(&)E(')E;6]V960N)RP*"2=E=F5N=%]H86YD;&5R<U]L:7-T
M7U]T:71L92<@/3X@)T5V96YT($UA;F%G97(G+`H))V5X86UP;&5?7R<@/3X@
M(D5X86UP;&4Z("4Q(BP*"2=E>'1R87-?7V)U>5]N97=?:V5Y)R`]/B`B66]U
M<B!C=7)R96YT(&QI8V5N<V4@:V5Y(&1O97,@;F]T(&%L;&]W('EO=2!T;R!M
M;V1I9GD@=&AE<V4@;V)J96-T<RX@268@>6]U('=I<V@@=&\@8F4@86)L92!T
M;R!D;R!T:&%T+"!Y;W4@<VAO=6QD('!U<F-H87-E(&$@;F5W(&QI8V5N<V4@
M:V5Y(BP*"@DG9F5A='5R95]?9&5S:W1O<%]?:&5A9&5R)R`]/B`G1&5S:W1O
M<"<L"@DG9F5A='5R95]?9&5S:W1O<%]?861M:6XG(#T^("=4:&4@<&%G92!Y
M;W4@87)E(&-U<G)E;G1L>2!O;B!I<R!T:&4@;F5W('1A<VLM;W)I96YT960@
M1&5S:W1O<"P@=VAI8V@@9VEV97,@>6]U('%U:6-K(&%C8V5S<R!T;R!Y;W5R
M(&1A:6QY('1A<VMS+"!R97-O=7)C97,@=7-A9V4@<W1A=&ES=&EC<RP@86YD
M(&]F9F5R<R!A(&AA;F1Y('-T;W)A9V4@9F]R('EO=7(@9F%V;W)I=&4@<&QA
M8V5S(&EN(%!L97-K+B!$97-K=&]P(&ES(&%C8V5S<VEB;&4@9G)O;2!T:&4@
M;&5F="!M96YU(&%T(&%N>2!T:6UE+B<L"@DG9F5A='5R95]?9&5S:W1O<%]?
M8VQI96YT)R`]/B`G5&AE('!A9V4@>6]U(&%R92!C=7)R96YT;'D@;VX@:7,@
M=&AE(&YE=R!T87-K+6]R:65N=&5D($1E<VMT;W`L('=H:6-H(&=I=F5S('EO
M=2!Q=6EC:R!A8V-E<W,@=&\@>6]U<B!D86EL>2!T87-K<RP@<F5S;W5R8V5S
M('5S86=E('-T871I<W1I8W,L(&%N9"!O9F9E<G,@82!H86YD>2!S=&]R86=E
M(&9O<B!Y;W5R(&9A=F]R:71E('!L86-E<R!I;B!0;&5S:RX@1&5S:W1O<"!I
M<R!A8V-E<W-I8FQE(&9R;VT@=&AE(&QE9G0@;65N=2!A="!A;GD@=&EM92XG
M+`H))V9E871U<F5?7V1E<VMT;W!?7V1O;6%I;B<@/3X@)U1H92!P86=E('EO
M=2!A<F4@8W5R<F5N=&QY(&]N(&ES('1H92!N97<@=&%S:RUO<FEE;G1E9"!$
M97-K=&]P+"!W:&EC:"!G:79E<R!Y;W4@<75I8VL@86-C97-S('1O('EO=7(@
M9&%I;'D@=&%S:W,L(')E<V]U<F-E<R!U<V%G92!S=&%T:7-T:6-S+"!A;F0@
M;V9F97)S(&$@:&%N9'D@<W1O<F%G92!F;W(@>6]U<B!F879O<FET92!P;&%C
M97,@:6X@4&QE<VLN($1E<VMT;W`@:7,@86-C97-S:6)L92!F<F]M('1H92!L
M969T(&UE;G4@870@86YY('1I;64N)RP*"2=F96%T=7)E7U]D;VUA:6Y?86QI
M87-E<U]?:&5A9&5R)R`]/B`G1&]M86EN($%L:6%S97,G+`H))V9E871U<F5?
M7V1O;6%I;E]A;&EA<V5S7U]C;&EE;G0G(#T^("=4:&ES(&YE=R!F96%T=7)E
M(&%L;&]W<R!Y;W4@=&\@<V5T('5P(&%L=&5R;F%T:79E(&YA;65S(&9O<B!Y
M;W5R(&1O;6%I;G,@=VET:"!N;R!A9&1I=&EO;F%L(&-O<W0N($1O;6%I;B!A
M;&EA<V5S(&%C="!A<R!N:6-K;F%M97,@9F]R('EO=7(@=V5B<VET97,@86YD
M(&4M;6%I;"!A9&1R97-S97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE
M(&)Y('-E;&5C=&EN9R!A(&1O;6%I;B!O;B!Y;W5R($AO;64@4&%G92!A;F0@
M8VQI8VMI;F<@7"=$;VUA:6X@06QI87-E<UPG+B<L"@DG9F5A='5R95]?9&]M
M86EN7V%L:6%S97-?7V1O;6%I;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL
M;W=S('EO=2!T;R!S970@=7`@86QT97)N871I=F4@;F%M97,@9F]R('EO=7(@
M9&]M86EN('=I=&@@;F\@861D:71I;VYA;"!C;W-T+B!$;VUA:6X@86QI87-E
M<R!A8W0@87,@;FEC:VYA;65S(&9O<B!Y;W5R('=E8G-I=&4@86YD(&4M;6%I
M;"!A9&1R97-S97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE(&)Y(&-L
M:6-K:6YG(%PG1&]M86EN($%L:6%S97-<)R!O;B!Y;W5R($AO;64@<&%G92XG
M+`H))V9E871U<F5?7V1O;6%I;E]A;&EA<V5S7U]Q=6EC:U]L:6YK)R`]/B`G
M1V\@=&\@1&]M86EN($%L:6%S97,@;6%N86=E;65N="<L"@DG9F5A='5R95]?
M=V%T8VAD;V<R7U]H96%D97(G(#T^("=7871C:&1O9R`R+C`G+`H))V9E871U
M<F5?7W=A=&-H9&]G,E]?861M:6XG(#T^("=4:&4@<V5C;VYD(&5D:71O;B!O
M9B!7871C:&1O9R!M;V1U;&4@(&UO;FET;W)S('9I=&%L(%!L97-K('-E<G9I
M8V5S(&QI:V4@07!A8VAE(%=E8B!397)V97(L(&YO=&EF>6EN9R!Y;W4@=FEA
M(&4M;6%I;"!I;B!C87-E(&]F('-E<G9I8V4@:7-S=65S+B!7871C:&1O9R`R
M+C`@;F]W(&%L<V\@;6]N:71O<G,@>6]U<B!H87)D(&1I<VMS('1O(&5N<W5R
M92!Y;W4@=V]N7"=T(')U;B!O=70@;V8@<W1O<F%G92!U;F5X<&5C=&5D;'DL
M('-C86YS('EO=7(@<V5R=F5R(&9O<B!S96-U<FET>2!V=6QN97)A8FEL:71I
M97,@<W5C:"!A<R!R;V]T:VET<RP@8F%C:V1O;W)S(&%N9"!L;V-A;"!E>'!L
M;VET<RP@86YD(&1I<W!L87ES($-052!A;F0@4D%-('5S86=E('-T871I<W1I
M8W,N(%1O(&%C8V5S<R!7871C:&1O9R`R+C`L(&-L:6-K($UO9'5L97,@:6X@
M=&AE(&QE9G0@;65N=2P@=&AE;B!C;&EC:R!7871C:&1O9R!O;B!T:&4@($UO
M9'5L97,@<&%G92XG+`H))V9E871U<F5?7W=A=&-H9&]G,E]?<75I8VM?;&EN
M:R<@/3X@)T=O('1O(%=A=&-H9&]G(#(N,"<L"@DG9F5A='5R95]?<F5M;W1E
M7V1B7U]H96%D97(G(#T^("=296UO=&4@1&%T86)A<V4@2&]S=&EN9R<L"@DG
M9F5A='5R95]?<F5M;W1E7V1B7U]A9&UI;B<@/3X@)TEN(&%D9&ET:6]N('1O
M(&AO<W1I;F<@;&]C86P@9&%T86)A<V5S+"!0;&5S:R`X(&-A;B!H;W-T('5S
M97)S7"<@9&%T82!O;B!R96UO=&4@9&%T86)A<V4@<V5R=F5R<RX@66]U(&-A
M;B!E=F5N(&AA=F4@<V5V97)A;"!0;&5S:R!S97)V97)S(&AO<W1I;F<@=&AE
M:7(@=7-E<G-<)R!D871A8F%S97,@;VX@82!S:6YG;&4@9&5D:6-A=&5D(&UA
M8VAI;F4N($)O=&@@37E344P@*&EN8VQU9&EN9R!->5-13"`T+C$I(&%N9"!0
M;W-T9W)E4U%,(&%R92!S=7!P;W)T960N(%1O(&%C8V5S<R!$871A8F%S92!3
M97)V97)S(&UA;F%G96UE;G0@<&%G92P@8VQI8VL@1&%T86)A<V4@4V5R=F5R
M<R!O;B!397)V97(@061M:6YI<W1R871I;VX@<&%G92XG+`H))V9E871U<F5?
M7W)E;6]T95]D8E]?<75I8VM?;&EN:R<@/3X@)T=O('1O($1A=&%B87-E(%-E
M<G9E<G,@;6%N86=E;65N="<L"@DG9F5A='5R95]?;6%I;%]Q=65U95]?:&5A
M9&5R)R`]/B`G36%I;"!1=65U92!-86YA9V5M96YT)RP*"2=F96%T=7)E7U]M
M86EL7W%U975E7U]A9&UI;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL;W=S
M(&%D;6EN:7-T<F%T;W)S('1O(&UA;F%G92!T:&4@46UA:6P@;65S<V%G92!Q
M=65U92!D:7)E8W1L>2!F<F]M(%!L97-K+B!7:71H('1H:7,@9F5A='5R92P@
M>6]U(&-A;B!M86YU86QL>2!D96QE=&4@<W!A;2!A;F0@;W1H97(@=6YW86YT
M960@;6%I;"!F<F]M('1H92!Q=65U92P@=7-I;F<@<75I8VL@86YD(&EN='5I
M=&EV92!S;W)T:6YG(&]P=&EO;G,N(%1O(&%C8V5S<R!-86EL('%U975E(&UA
M;F%G96UE;G0@<&%G92P@8VQI8VL@36%I;"!O;B!T:&4@4V5R=F5R($%D;6EN
M:7-T<F%T:6]N('!A9V4@86YD('-E;&5C="!T:&4@36%I;"!1=65U92!T86(N
M)RP*"2=F96%T=7)E7U]M86EL7W%U975E7U]Q=6EC:U]L:6YK)R`]/B`G1V\@
M=&\@36%I;"!1=65U92!M86YA9V5M96YT)RP*"2=F96%T=7)E7U]S;V%?7VAE
M861E<B<@/3X@)T1.4R!33T$@4F5C;W)D<R!-86YA9V5M96YT)RP*"2=F96%T
M=7)E7U]S;V%?7V-L:65N="<@/3X@)U-T87)T($]F($%U=&AO<FET>2`H4T]!
M*2!R96-O<F1S(&%R92!S<&5C:6%L('1Y<&4@;V8@1$Y3(')E8V]R9',@=&AA
M="!D969I;F4@=&AE('!A<F%M971E<G,@;V8@1$Y3(')E8V]R9',@8V%C:&EN
M9RX@4W1A<G1I;F<@=VET:"!0;&5S:R`X+"!Y;W4@:&%V92!F=6QL(&-O;G1R
M;VP@;W9E<B!$3E,@4T]!(')E8V]R9',L('=H:6-H(&QE=',@>6]U('-P96-I
M9GD@=F%R:6]U<R!T:6UE;W5T<R!T;R!F:6YE+71U;F4@=&AE(&1O;6%I;B!N
M86UE('-E<G9I8V4N(%1O(&%C8V5S<R!33T$@<F5C;W)D<R!M86YA9V5M96YT
M+"!S96QE8W0@82!D;VUA:6X@;VX@>6]U<B!(;VUE('!A9V4L(&-L:6-K($1.
M4R!A;F0@8VQI8VL@4T]!(%!R969E<F5N8V5S+B<L"@DG9F5A='5R95]?<V]A
M7U]D;VUA:6XG(#T^("=3=&%R="!/9B!!=71H;W)I='D@*%-/02D@<F5C;W)D
M<R!A<F4@<W!E8VEA;"!T>7!E(&]F($1.4R!R96-O<F1S('1H870@9&5F:6YE
M('1H92!P87)A;65T97)S(&]F($1.4R!R96-O<F1S(&-A8VAI;F<N(%-T87)T
M:6YG('=I=&@@4&QE<VL@."P@>6]U(&AA=F4@9G5L;"!C;VYT<F]L(&]V97(@
M1$Y3(%-/02!R96-O<F1S+"!W:&EC:"!L971S('EO=2!S<&5C:69Y('9A<FEO
M=7,@=&EM96]U=',@=&\@9FEN92UT=6YE('1H92!D;VUA:6X@;F%M92!S97)V
M:6-E+B!4;R!A8V-E<W,@4T]!(')E8V]R9',@;6%N86=E;65N="P@8VQI8VL@
M1$Y3(&]N('EO=7(@2&]M92!P86=E(&%N9"!C;&EC:R!33T$@4')E9F5R96YC
M97,N)RP*"2=F96%T=7)E7U]S;V%?7W%U:6-K7VQI;FLG(#T^("=';R!T;R!3
M3T$@4F5C;W)D<R!M86YA9V5M96YT('!A9V4G+`H*"2=F:6QE;6%N86=E<E]?
M:71E;7,G(#T^("=F:6QE<R!A;F0@9&ER96-T;W)I97,@:6X@)3$G+`H))V9I
M;&5M86YA9V5R7U]C:&1I<E]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-H86YG
M92!D:7)E8W1O<GD@=&\@)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?8VAM;V1?
M9&ER)R`]/B`B0VAA;F=E('!E<FUI<W-I;VYS(&9O<B!D:7)E8W1O<GD@)3$B
M+`H))V9I;&5M86YA9V5R7U]C:&UO9%]E<G)O<E]?)R`]/B`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N<R!F;W(@9FEL92`E,3H@)3(B+`H))V9I;&5M
M86YA9V5R7U]C:&UO9%]F:6QE)R`]/B`B0VAA;F=E('!E<FUI<W-I;VYS(&9O
M<B!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?8V]P>5]E<G)O<E]?)R`]/B`B
M56YA8FQE('1O(&-O<'D@)3$@=&\@)3(Z("4S(BP*"2=F:6QE;6%N86=E<E]?
M8V]P>5]M;W9E)R`]/B`B0V]P>2`H;6]V92D@9FEL97,@9G)O;2`E,2(L"@DG
M9FEL96UA;F%G97)?7V-O=6YT7W-I>F5?7R<@/3X@)U-E;&5C=&EO;B!S:7IE
M.B`E,2<L"@DG9FEL96UA;F%G97)?7V-O=6YT7W-I>F5?97)R;W)?7R<@/3X@
M)U5N86)L92!T;R!C86QC=6QA=&4@<VEZ92!F;W(@)3$Z("4R)RP*"2=F:6QE
M;6%N86=E<E]?8V]U;G1?<VEZ95]N;W1E)R`]/B`G5&AE('1O=&%L('-I>F4@
M;V8@9FEL97,@86YD('-U8F1I<F5C=&]R:65S+B<L"@DG9FEL96UA;F%G97)?
M7V-R96%T95]D:7(G(#T^(")$:7)E8W1O<GD@8W)E871I;VXB+`H))V9I;&5M
M86YA9V5R7U]C<F5A=&5?9&ER7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@8W)E
M871E(&1I<F5C=&]R>2`E,3H@)3(B+`H))V9I;&5M86YA9V5R7U]C<F5A=&5?
M9FEL92<@/3X@(D9I;&4@8W)E871I;VXB+`H))V9I;&5M86YA9V5R7U]C<F5A
M=&5?9FEL95]?)R`]/B`B0W)E871E(&9I;&4@)3$B+`H))V9I;&5M86YA9V5R
M7U]C<F5A=&5?9FEL95]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-R96%T92!F
M:6QE("4Q.B`E,B(L"@DG9FEL96UA;F%G97)?7V-R96%T95]F:6QE7VAT;6PG
M(#T^(")5<V4@:'1M;"!T96UP;&%T92(L"@DG9FEL96UA;F%G97)?7V1E;6\G
M(#T^(")4:&ES(&]P97)A=&EO;B!I<R!N;W0@879A:6QA8FQE(&EN('1H92!D
M96UO('9E<G-I;VXN(BP*"2=F:6QE;6%N86=E<E]?9&5S=&EN871I;VXG(#T^
M(")$97-T:6YA=&EO;B(L"@DG9FEL96UA;F%G97)?7V1I<E]N;W1?97AI<W1S
M)R`]/B`B1&ER96-T;W)Y("4Q(&1O97,@;F]T(&5X:7-T+B(L"@DG9FEL96UA
M;F%G97)?7V1I<FYA;64G(#T^(")$:7)E8W1O<GD@;F%M92(L"@DG9FEL96UA
M;F%G97)?7V9I;&5N86UE)R`]/B`B1FEL92!N86UE(BP*"2=F:6QE;6%N86=E
M<E]?:7-?;F]?<W5C:"<@/3X@(E1H97)E(&ES(&YO(&9I;&4@;W(@9&ER96-T
M;W)Y('=I=&@@;F%M92`E,2(L"@DG9FEL96UA;F%G97)?7V)I;F%R>5]D871A
M7V%C8V5S<R<@/3X@)U1H:7,@9FEL92!M87D@8F4@82!B:6YA<GD@9FEL92X@
M1&\@>6]U('=A;G0@=&\@;W!E;B!I=#\G+`H))V9I;&5M86YA9V5R7U]E9&ET
M)R`]/B`B161I="!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?961I=%]E<G)O
M<E]?)R`]/B`B56YA8FQE('1O(&5D:70@9FEL92`E,3H@)3(B+`H))V9I;&5M
M86YA9V5R7U]E;7!T>5]S96QE8W1I;VXG(#T^(").;R!F:6QE*',I('-E;&5C
M=&5D+B(L"@DG9FEL96UA;F%G97)?7V9I;&5?97AI<W1S)R`]/B`B1FEL92`E
M,2!A;')E861Y(&5X:7-T<RXB+`H))V9I;&5M86YA9V5R7U]M;W9E7V5R<F]R
M7U\G(#T^(")5;F%B;&4@=&\@;6]V92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M
M86YA9V5R7U]N97=?9&ER)R`]/B`B1&ER96-T;W)Y(&YA;64B+`H))V9I;&5M
M86YA9V5R7U]N97=?9&ER7W1I=&QE)R`]/B`B0W)E871E(&YE=R!D:7)E8W1O
M<GD@:6X@)3$B+`H))V9I;&5M86YA9V5R7U]N97=?9FEL95]T:71L92<@/3X@
M(D-R96%T92!N97<@9FEL92!I;B`E,2(L"@DG9FEL96UA;F%G97)?7VYO=%]A
M;&QO=V5D)R`]/B`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C:&%N9V4@<&5R
M;6ES<VEO;G,@9F]R('1H92!F:6QE+B(L"@DG9FEL96UA;F%G97)?7W)?;6]D
M92<@/3X@(E)E860@;6]D92(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]D:7(G
M(#T^("),:7-T(&1I<F5C=&]R>2(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]F
M:6QE)R`]/B`B4F5A9"!D871A(BP*"2=F:6QE;6%N86=E<E]?<F5M;W9E)R`]
M/B`B4F5M;W9E(&9I;&5S(&9R;VT@)3$B+`H))V9I;&5M86YA9V5R7U]R96UO
M=F5?97)R;W)?7R<@/3X@(E5N86)L92!T;R!R96UO=F4@9FEL92`E,3H@)3(B
M+`H))V9I;&5M86YA9V5R7U]R96YA;65?9&ER)R`]/B`B4F5N86UE(&1I<F5C
M=&]R>2`E,2(L"@DG9FEL96UA;F%G97)?7W)E;F%M95]E<G)O<E]?)R`]/B`B
M56YA8FQE('1O(')E;F%M92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M86YA9V5R
M7U]R96YA;65?9FEL92<@/3X@(E)E;F%M92!F:6QE("4Q(BP*"2=F:6QE;6%N
M86=E<E]?<V5T7W=I;E]P97)M:7-S:6]N<U]D:7(G(#T^(")3970@<&5R;6ES
M<VEO;G,@9F]R("4Q(&9O;&1E<B(L"@DG9FEL96UA;F%G97)?7W-E=%]W:6Y?
M<&5R;6ES<VEO;G-?9FEL92<@/3X@(E-E="!P97)M:7-S:6]N<R!F;W(@)3$@
M9FEL92(L"@DG9FEL96UA;F%G97)?7W-H;W<G(#T^(")3:&]W(&9I;&4@)3$B
M+`H))V9I;&5M86YA9V5R7U]S:&]W7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@
M<VAO=R!F:6QE("4Q.B`E,B(L"@DG9FEL96UA;F%G97)?7W-O=7)C92<@/3X@
M(E-O=7)C92(L"@DG9FEL96UA;F%G97)?7W1O=6-H7V-O;F9I<FTG(#T^(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@
M;V8@=&AE('-E;&5C=&5D(&9I;&5S/R(L"@DG9FEL96UA;F%G97)?7W1O=6-H
M7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@
M9F]R(&9I;&4@)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?;F]?<&5R;7-?;W)?
M=6YS=7!P;W)T961?9FEL95]T>7!E)R`]/B`G56YA8FQE('1O(')E860@=&AE
M(&9I;&4@;W(@=&AE(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N)RP*
M"2=F:6QE;6%N86=E<E]?=7!L;V%D7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@
M=7!L;V%D("4Q('1O("4R.B`E,R(L"@DG9FEL96UA;F%G97)?7W5P;&]A9%]F
M:6QE)R`]/B`B57!L;V%D(&9I;&4B+`H))V9I;&5M86YA9V5R7U]U<&QO861?
M9FEL95]S<F,G(#T^(")&:6QE('-O=7)C92(L"@DG9FEL96UA;F%G97)?7W5S
M97)N86UE)R`]/B`B57-E<B(L"@DG9FEL96UA;F%G97)?7W=?;6]D92<@/3X@
M(E=R:71E(&UO9&4B+`H))V9I;&5M86YA9V5R7U]W7W!E<FU?9&ER)R`]/B`B
M0W)E871E(&9I;&5S(BP*"2=F:6QE;6%N86=E<E]?=U]P97)M7V9I;&4G(#T^
M(")7<FET92!D871A(BP*"2=F:6QE;6%N86=E<E]?>%]M;V1E)R`]/B`B17AE
M8W5T92]S96%R8V@@;6]D92(L"@DG9FEL96UA;F%G97)?7WA?<&5R;5]D:7(G
M(#T^(")4<F%V97)S92!D:7)E8W1O<GDB+`H))V9I;&5M86YA9V5R7U]X7W!E
M<FU?9FEL92<@/3X@(D5X96-U=&4@9FEL92(L"@DG9FEL96UA;F%G97)?7W5N
M86)L95]T;U]R97-O;'9E7W)E86QP871H)R`]/B`B56YA8FQE('1O(')E<V]L
M=F4@<&%T:"!T;R!F:6QE("4Q(BP@+R]T;R!C:&5C:PH))V9I;&5M86YA9V5R
M7U]A8V-E<W-?=&]?<F5A;'!A=&A?9&5N:65D)R`]/B`B4&5R;6ES<VEO;B!D
M96YI960@=&\@)3$@+3X@)3(B+"`O+W1O(&-H96-K"@DG9V-H7U]A8W1I;VXG
M(#T^(")!8W1I;VXB+`H))V=C:%]?869T97)?9&5C<F5A<VEN9U]F;W)?=&AE
M7W9A;'5E7VYU;6)E<E]W:6QL7V)E8V%M95]N96=A=&EV92<@/3X@(D%F=&5R
M(&1E8W)E87-I;F<@=&AE('-P96-I9FEE9"!V86QU92P@:70@=VEL;"!B96-O
M;64@;F5G871I=F4N(BP*"2=G8VA?7V-A=&AE9V]R>2<@/3X@(D-A=&5G;W)Y
M(BP*"2=G8VA?7V-L:65N=%]P86=E7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T
M:6]N<R!O;B!C;&EE;G0@86-C;W5N=',B+`H))V=C:%]?8VQI96YT<U]S96QE
M8W1I;VXG(#T^(")-;V1I9FEE9"!A8V-O=6YT<R`H)3$I(BP*"2=G8VA?7V1O
M;6%I;E]P86=E7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T:6]N<R!O;B!D;VUA
M:6YS(BP*"2=G8VA?7V1O;6%I;G-?<V5L96-T:6]N)R`]/B`B36]D:69I960@
M9&]M86EN<R`H)3$I(BP*"2=G8VA?7VUA:6QN86UE<U]S96QE8W1I;VXG(#T^
M(")-;V1I9FEE9"!M86EL(&YA;65S("@E,2DB+`H))V=C:%]?:&]S=&EN9R<@
M/3X@(DAO<W1I;F<B+`H))V=C:%]?:&]S=&EN9U]A<&%C:&5?97)R;W)?9&]C
M<R<@/3X@(D-U<W1O;2!E<G)O<B!D;V-U;65N=',B+`H))V=C:%]?:&]S=&EN
M9U]C9VDG(#T^(")#1TD@<W5P<&]R="(L"@DG9V-H7U]H;W-T:6YG7VQO9U]R
M;W1A=&EO;B<@/3X@(DQO9R!R;W1A=&EO;B!S=&%T=7,B+`H))V=C:%]?:&]S
M=&EN9U]L;V=?<F]T871I;VY?8V]M<')E<W,G(#T^("),;V<@9FEL97,@8V]M
M<')E<W-I;VXB+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T871I;VY?;6%I;'1O
M)R`]/B`B1&5L:79E<B!P<F]C97-S960@;&]G(&9I;&5S('1O(BP*"2=G8VA?
M7VAO<W1I;F=?;&]G7W)O=&%T:6]N7VUA>%]F:6QE<R<@/3X@(DYU;6)E<B!O
M9B!L;V<@9FEL92!I;G-T86YC97,B+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T
M871I;VY?<&5R:6]D)R`]/B`B3&]G(')O=&%T:6]N(&-O;F1I=&EO;B(L"@DG
M9V-H7U]H;W-T:6YG7VQO9U]R;W1A=&EO;E]T:71L92<@/3X@(DQO9R!R;W1A
M=&EO;B(L"@DG9V-H7U]H;W-T:6YG7W!D:7)?<&QE<VM?<W1A="<@/3X@(E!R
M;W1E8W0@9&ER96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=G8VA?7VAO<W1I
M;F=?<&AP)R`]/B`B4$A0('-U<'!O<G0B+`H))V=C:%]?:&]S=&EN9U]S:&5L
M;"<@/3X@(E-H96QL(&%C8V5S<R(L"@DG9V-H7U]H;W-T:6YG7W-S:2<@/3X@
M(E-322!S=7!P;W)T(BP*"2=G8VA?7VAO<W1I;F=?<W-L)R`]/B`B4U-,('-U
M<'!O<G0B+`H))V=C:%]?:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R(L"@DG
M9V-H7U]H;W-T:6YG7W=E8G-T870G(#T^(")796(@<W1A=&ES=&EC<R(L"@DG
M9V-H7U]I;G9A;&ED7V1A=&5?=F%L=64G(#T^("));F-O<G)E8W0@9&%T92!V
M86QU92XB+`H))V=C:%]?:6YV86QI9%]L;V=R;W1A=&5?<&%R86US)R`]/B`B
M3&]G(')O=&%T:6]N(&-O;F9I9R!I<R!N;W0@>65T(&-R96%T960@9F]R('1H
M:7,@9&]M86EN+"!T;R!C<F5A=&4@:70@>6]U(&YE960@=&\@9FEL;"!O=70@
M86QL('1H92!F:65L9',@97AC97!T(&9O<B`E,2XB+`H))V=C:%]?:71?:7-?
M:6UP;W-S:6)L95]T;U]D96-R96%S95]N=6UB97)?;6]R95]T:&%N7S$P,%]P
M97)C96YT<R<@/3X@(E5N86)L92!T;R!D96-R96%S92!T:&4@;G5M8F5R(&)Y
M(&UO<F4@=&AA;B`Q,#`E+B(L"@DG9V-H7U]I=%]I<U]I;7!O<W-I8FQE7W1O
M7VEN8W)E87-E7V]R7V1E8W)E87-E7W5N;&EM:71E9%]V86QU92<@/3X@(E5N
M86)L92!T;R!I;F-R96%S92!O<B!D96-R96%S92!T:&4@=F%L=64@+2!I="!I
M<R!U;FQI;6ET960N(BP*"2=G8VA?7VQI;5]D:7-K7W-P86-E)R`]/B`B3&EM
M:70@=&]T86P@9&ES:R!S<&%C92(L"@DG9V-H7U]L:6U?97AP:7)A=&EO;B<@
M/3X@(DQI;6ET('1H92!V86QI9&ET>2!P97)I;V0B+`H))V=C:%]?;&EM7VUA
M>%]B;W@G(#T^("),:6UI="!T:&4@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG
M9V-H7U]L:6U?;6%X7V1B)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!D871A
M8F%S97,B+`H))V=C:%]?;&EM7VUA>%]D;VTG(#T^("),:6UI="!T:&4@;G5M
M8F5R(&]F(&1O;6%I;G,B+`H))V=C:%]?;&EM7VUA>%]M86EL;&ES=',G(#T^
M("),:6UI="!T:&4@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V=C:%]?
M;&EM7VUA>%]M9R<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@;6%I;"!G<F]U
M<',B+`H))V=C:%]?;&EM7VUA>%]R961I<B<@/3X@(DQI;6ET('1H92!N=6UB
M97(@;V8@;6%I;"!R961I<F5C=',B+`H))V=C:%]?;&EM7VUA>%]R97-P)R`]
M/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!M86EL(&%U=&]R97-P;VYD97)S(BP*
M"2=G8VA?7VQI;5]M87A?<W5B9&]M)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O
M9B!S=6)D;VUA:6YS(BP*"2=G8VA?7VQI;5]M87A?=')A9F9I8R<@/3X@(DQI
M;6ET('1O=&%L(&%M;W5N="!O9B!T<F%F9FEC(BP*"2=G8VA?7VQI;5]M87A?
M=V5B87!P<R<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@2F%V82!A<'!L:6-A
M=&EO;G,B+`H))V=C:%]?;&EM7VUA>%]W=2<@/3X@(DQI;6ET('1H92!N=6UB
M97(@;V8@=V5B('5S97)S(BP*"2=G8VA?7VQI;5]M8F]X7W%U;W1A)R`]/B`B
M4V5T('1H92!M86EL8F]X('%U;W1A(BP*"2=G8VA?7VQI;5]T>7!E)R`]/B`B
M3&EM:70B+`H))V=C:%]?;&EM:71?;75S=%]B95]I;G1E9V5R7W!O<VET:79E
M7VYU;6)E<B<@/3X@(E1H92!L:6UI="!V86QU92!M=7-T(&)E(&$@<&]S:71I
M=F4@:6YT96=E<BXB+`H))V=C:%]?;F5W7VQI;6ET7W9A;'5E7V)E='=E96Y?
M>F5R;U]A;F1?:V)Y=&4G(#T^(")4:&4@;F5W(&QI;6ET('9A;'5E(&-A;B!B
M92!E:71H97(@,"P@,2!+:6QO8GET92!O<B!G<F5A=&5R+B(L"@DG9V-H7U]N
M97=?;&EM:71?=F%L=65?8F5T=V5E;E]Z97)O7V%N9%]M8GET92<@/3X@(E1H
M92!N97<@;&EM:70@=F%L=64@8V%N(&)E(&5I=&AE<B`P+"`Q($UE9V%B>71E
M(&]R(&=R96%T97(N(BP*"2=G8VA?7VQI;6ET7W9A;'5E7VES7V]U=%]O9E]R
M86YG92<@/3X@(E1H92!L:6UI="!V86QU92!S<&5C:69I960@97AC965D<R!T
M:&4@<F%N9V4@;V8@86QL;W=A8FQE('9A;'5E<RXB+`H))V=C:%]?;&EM:71S
M)R`]/B`B3&EM:71S(BP*"2=G8VA?7VUA:6QN86UE7W!A9V5?=&ET;&4G(#T^
M("='<F]U<"!O<&5R871I;VYS(&]N(&UA:6P@;F%M97,G+`H))V=C:%]?;6Y?
M;F]?875T;W)E<W!O;F1E<B<@/3X@)U1H97)E(&%R92!N;R!A=71O<F5S<&]N
M9&5R<R!S970M=7`@9F]R('1H92!M86EL(&YA;64N)RP*"2=G8VA?7VYE=U]C
M;&EE;G1?;&EM:71?:7-?;&5S<U]T:&%N7V1O;6%I;E]L:6UI=',G(#T^(")4
M:&4@<W!E8VEF:65D(&QI;6ET('9A;'5E(&ES(&QE<W,@=&AA;B!T:&4@=&]T
M86P@;V8@86QL(&QI;6ET<R!D969I;F5D(&9O<B!T:&ES(&-L:65N="=S(&1O
M;6%I;G,B+`H))V=C:%]?;F5W7VQI;6ET7W9A;'5E7W=I;&Q?8F5C86UE7V]U
M=%]O9E]R86YG92<@/3X@(D-H86YG:6YG('1H92!V86QU92!T;R!T:&4@;&5V
M96P@<W!E8VEF:65D('=I;&P@<F5S=6QT(&EN(&5X8V5E9&EN9R!T:&4@;6%X
M:6UU;2!A;&QO=V%B;&4@9&EG:70@=F%L=64N(BP*"2=G8VA?7VYO7V-L:65N
M='-?<V5L96-T960G(#T^(").;R!C;&EE;G0@86-C;W5N=',@<V5L96-T960B
M+`H))V=C:%]?;F]?9&]M86EN<U]S96QE8W1E9"<@/3X@(DYO(&1O;6%I;G,@
M<V5L96-T960B+`H))V=C:%]?;F]?;6%I;&YA;65S7W-E;&5C=&5D)R`]/B`G
M3F\@;6%I;"!N86UE<R!S96QE8W1E9"<L"@DG9V-H7U]P87)A;65T<B<@/3X@
M(E!A<F%M971E<B(L"@DG9V-H7U]P97)M7V-H86YG95]L:6UI=',G(#T^(")!
M8FEL:71Y('1O(&UO9&EF>2!D;VUA:6X@;&EM:71S(BP*"2=G8VA?7W!E<FU?
M8W)E871E7V1O;6%I;G,G(#T^(")!8FEL:71Y('1O(&-R96%T92!D;VUA:6YS
M(BP*"2=G8VA?7W!E<FU?='EP92<@/3X@(E!E<FUI<W-I;VXB+`H))V=C:%]?
M<&5R;6ES<VEO;G,G(#T^(")097)M:7-S:6]N<R(L"@DG9V-H7U]P<F5F7V%L
M;&]W7W-C<FEP=&EN9R<@/3X@(D%L;&]W('1H92!W96(@=7-E<G,@<V-R:7!T
M:6YG(BP*"2=G8VA?7W!R969?9&5L971E7W-T871I<W1I8R<@/3X@(E)E=&%I
M;B!T<F%F9FEC('-T871I<W1I8W,@9F]R(BP*"2=G8VA?7W!R969?;6%I;&UA
M;E]N;W1?:6YS=&%L;&5D7V]R7V-O;F8G(#T^(")-86EL;6%N(%-E<G9E<B!%
M>'1E;G-I;VYS(&%R92!N;W0@8W5R<F5N=&QY(&EN<W1A;&QE9"!O<B!P<F]P
M97)L>2!C;VYF:6=U<F5D(&]N('1H92!S97)V97(N(BP*"2=G8VA?7W!R969?
M;F]N97AI<W0G(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V=C
M:%]?<')E9E]T>7!E)R`]/B`B4')E9F5R96YC92(L"@DG9V-H7U]P<F5F7W=E
M8E]M86EL)R`]/B`B5V5B36%I;"(L"@DG9V-H7U]P<F5F7W=W=U]P<F5F:7@G
M(#T^(")75U<@<')E9FEX(BP*"2=G8VA?7W!R969E<F5N8V5S)R`]/B`B4')E
M9F5R96YC97,B+`H))V=C:%]?<F5J96-T:6]N)R`]/B`B4F5J96-T:6]N(')E
M87-O;B(L"@DG9V-H7U]S97)V7V%N;VYY;6]U<U]F='`G(#T^(")!;F]N>6UO
M=7,@1E10(BP*"2=G8VA?7W-E<G9?9&YS)R`]/B`B1$Y3('IO;F4B+`H))V=C
M:%]?<V5R=E]M86EL)R`]/B`B36%I;"(L"@DG9V-H7U]S97)V7VUA:6QL:7-T
M<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))V=C:%]?<V5R=E]T;VUC870G(#T^
M(")4;VUC870B+`H))V=C:%]?<V5R=E]T>7!E)R`]/B`B4V5R=FEC92(L"@DG
M9V-H7U]S97)V:6-E<R<@/3X@(E-E<G9I8V5S(BP*"2=G8VA?7W)E:F5C=%]L
M96=E;F0G(#T^(")4:&4@9W)O=7`@;W!E<F%T:6]N<R!H879E(&)E96X@<W5C
M8V5S<V9U;&QY('!E<F9O<FUE9"P@97AC97!T(&9O<B!T:&4@9F]L;&]W:6YG
M(&]B:F5C=',Z(BP*"2=G8VA?7W9A;'5E)R`]/B`B5F%L=64B+`H))V=C:%]?
M=F%L=65?;75S=%]B95]I;G1E9V5R7W!O<VET:79E7VYU;6)E<B<@/3X@(E1H
M92!V86QU92!M=7-T(&)E(&$@<&]S:71I=F4@:6YT96=E<BXB+`H))V=E=%]P
M87-S=V]R9%]?861M:6Y?<&%S<W=O<F0G(#T^(")4:&4@861M:6YI<W1R871O
M<B=S('!A<W-W;W)D(&-A;FYO="!B92!S96YT(&)Y(&4M;6%I;"!F;W(@<V5C
M=7)I='D@<F5A<V]N<RX@66]U(&-A;B!L;V]K(&ET('5P(&EN('1H92`O971C
M+W!S82\N<'-A+G-H861O=R!F:6QE(&QO8V%T960@;VX@>6]U<B!0;&5S:R!H
M;W-T+"!O;F-E('EO=2!A<F4@;&]G9V5D(&]N(&%S('5S97(@<F]O="XB+`H)
M)V=E=%]P87-S=V]R9%]?96YC<GEP=&5D7W!A<W-W;W)D)R`]/B`B56YA8FQE
M('1O('-E;F0@=&AE('!A<W-W;W)D(&EN9F]R;6%T:6]N.B!T:&4@<&%S<W=O
M<F0@:7,@<W1O<F5D(&5N8W)Y<'1E9"XB+`H))V=E=%]P87-S=V]R9%]?:6YV
M86QI9%]L;V=I;E]O<E]E;6%I;"<@/3X@(DED96YT:69I8V%T:6]N(&9A:6QE
M9#H@:6YV86QI9"!L;V=I;B!O<B!E+6UA:6P@861D<F5S<R!S<&5C:69I960N
M(%!L96%S92P@=')Y(&%G86EN+B(L"@DG9V5T7W!A<W-W;W)D7U]L86)E;"<@
M/3X@(D=E="!P87-S=V]R9"(L"@DG9V5T7W!A<W-W;W)D7U]M86EL7V5R<F]R
M)R`]/B`B06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-E
M;F0@=&AE('!A<W-W;W)D('1O(&4M;6%I;"`E,3H@)3(B+`H))V=E=%]P87-S
M=V]R9%]?;6%I;%]O:R<@/3X@(E1H92!P87-S=V]R9"!H87,@8F5E;B!S=6-C
M97-S9G5L;'D@<V5N="!T;R!E+6UA:6PZ("4Q+B(L"@DG9V5T7W!A<W-W;W)D
M7U]M97-S86=E)R`]/B`B66]U<B!L;V=I;B!N86UE(&9O<B!A8V-E<W-I;F<@
M=&AE('-Y<W1E;3H@)3%<;EEO=7(@<&%S<W=O<F0@:7,@)3(B+`H))V=E=%]P
M87-S=V]R9%]?<W5B:F5C="<@/3X@(E!A<W-W;W)D(&9O<B!A8V-E<W,@=&\@
M<WES=&5M(BP*"2=G971?<&%S<W=O<F1?7W=A<FYI;F<G(#T^("(\8CY!='1E
M;G1I;VXA(2$\+V(^/&)R/EQN4V5N9&EN9R!P87-S=V]R9"!B>2!E+6UA:6P@
M:7,@:6YS96-U<F4A/&)R/EQN16YT97(@>6]U<B!L;V=I;B!N86UE(&%N9"!E
M+6UA:6P@<F5G:7-T97)E9"!I;B!T:&4@<WES=&5M(&9O<B!P87-S=V]R9"!D
M96QI=F5R>2XB+`H))V=R;W5P<U]?879A:6QA8FQE)R`]/B`B079A:6QA8FQE
M(&UA:6P@9W)O=7!S(BP*"2=G<F]U<'-?7V=R;W5P<U]F;W)?;6%I;&YA;64G
M(#T^(")-86EL(&=R;W5P<R!F;W(@=&AE(&UA:6P@;F%M92`E,2(L"@DG9W)O
M=7!S7U]M96UB97)?;V8G(#T^(")-96UB97(@;V8@=&AE(&9O;&QO=VEN9R!M
M86EL(&=R;W5P<R(L"@DG:&5L<%]?:&5L<%]A<F5A)R`]/B`B2&5L<"!A<F5A
M+B(L"@DG:'-T7V1E9E]?875T:%]D:7-A8FQE9"<@/3X@(F1I<V%B;&5D(BP*
M"2=H<W1?9&5F7U]A=71H7V5N86)L960G(#T^(")E;F%B;&5D(BP*"2=H<W1?
M9&5F7U]C:&%N9V5?8W5R<E]D;G-?:7`G(#T^(")4:&4@8W5R<F5N="!)4"!A
M9&1R97-S(&]F('1H92!!($1.4R!R96-O<F0@=VEL;"!B92!C:&%N9V5D(BP*
M"2=H<W1?9&5F7U]C<E]H;W-T:6YG7VEP7V1N<U]I<%]N;W1?97%U:78G(#T^
M(").;VYE(&]F('1H92!)4"!A9&1R97-S97,@;V8@=&AE($$@1$Y3(')E8V]R
M9"!M871C:"!W:71H($E0(&%D9')E<W,@87-S:6=N960@=&\@=&AE(&AO<W1I
M;F<@86-C;W5N="!B96EN9R!C<F5A=&5D(BP*"2=H<W1?9&5F7U]D97-T7W5R
M;"<@/3X@(D1E<W1I;F%T:6]N(%523"(L"@DG:'-T7V1E9E]?9&ES:U]Q=6]T
M82<@/3X@(D1I<VL@<75O=&$B+`H))VAS=%]D969?7V1I<VM?<W!A8V5?;&EM
M:71?97AC965D7VEN8V]M:6YG7W%U;W1A)R`]/B`B5&AE(&1I<VL@<W!A8V4@
M;&EM:70@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&ES(&5X8V5E9&5D(&)Y('1H
M92!D:7-K('-P86-E(&QI;6ET(&EN('1H92!A;F]N>6UO=7,@1E10(&EN8V]M
M:6YG(&1I<F5C=&]R>2X@5&AE(&1I<VL@<W!A8V4@;&EM:70@:6X@=&AE(&%N
M;VYY;6]U<R!&5%`@:6YC;VUI;F<@9&ER96-T;W)Y(&UU<W0@;F]T(&5X8V5E
M9"!T:&4@9&]M86EN(&1I<VL@<W!A8V4@;&EM:70N(BP*"2=H<W1?9&5F7U]F
M<%]A9&UI;E]L;V=I;B<@/3X@(D9R;VYT4&%G92!!9&UI;FES=')A=&]R)W,@
M3&]G:6XB+`H))VAS=%]D969?7V9P7V%D;6EN7VQO9VEN7VES7VEN=F%L:60G
M(#T^(")&<F]N=%!A9V4@061M:6YI<W1R871O<B=S($QO9VEN(&ES(&EN=F%L
M:60N(BP*"2=H<W1?9&5F7U]F<%]A9&UI;E]P87-S=V0G(#T^(")&<F]N=%!A
M9V4@061M:6XG<R!087-S=V]R9"(L"@DG:'-T7V1E9E]?9G!?97AT96YT:6]N
M7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@97AT96YS:6]N<R!S=7!P;W)T+B(L
M"@DG:'-T7V1E9E]?9G)A;65?9F]R=V%R9&EN9U]D969I;FET:6]N)R`]/B`B
M1G)A;64@9F]R=V%R9&EN9R!A<W-I9VYM96YT(&9O<B!D;VUA:6X@)3$B+`H)
M)VAS=%]D969?7V9T<'5S97)?9F]R7VAS=%]N;W1?97AI<W1?:6Y?<WES=&5M
M)R`]/B`B5T%23DE.1RX@1E10('5S97(@)3$@:7,@=7-E9"!I;B!A(&AO<W1I
M;F<@86-C;W5N="!B=70@9&]E<R!N;W0@97AI<W0@:6X@=&AE('-Y<W1E;2XB
M+`H))VAS=%]D969?7VAS=%]T>7!E7VES7VYO=%]D969I;F5D)R`]/B`B2&]S
M=&EN9R!T>7!E(&ES(&YO="!D969I;F5D(BP*"2=H<W1?9&5F7U]I<%]B87-E
M9"<@/3X@(DE0+6)A<V5D(BP*"2=H<W1?9&5F7U]N86UE7V)A<V5D7W!O=V5R
M7V%N;VYY;6]U<U]F='!?9&]W;B<@/3X@(E1R86YS9F5R<FEN9R!Y;W5R(&AO
M<W1I;F<@86-C;W5N="!T;R!S:&%R960@:7`@861D<F5S<R!W:6QL(&1I<V%B
M;&4@>6]U<B!A;F]N>6UO=7,@1E10(&1O;6%I;BX@4')O8V5E9"!A;GEW87D_
M(BP*"2=H<W1?9&5F7U]P87-S=V]R9%]I<U]I;G9A;&ED7W!A<W-W;W)D7W-Y
M;G1A>"<@/3X@(E!A<W-W;W)D(&ES(&EN=F%L:60N7&Y$;R!N;W0@=7-E('-I
M;F=L92!Q=6]T92!A;F0@;F%T:6]N86P@86QP:&%B970@8VAA<F%C=&5R<R!I
M;B!A('!A<W-W;W)D+EQN5&AE('!A<W-W;W)D(&QE;F=T:"!S:&]U;&0@8F4@
M9G)O;2`U('1O(#$T(&-H87)A8W1E<G,N(%1H92!P87-S=V]R9"!S:&]U;&0@
M;F]T(&-O;G1A:6X@=&AE('5S97(@;F%M92XB+`H))VAS=%]D969?7W-H96QL
M)R`]/B`B4VAE;&P@86-C97-S('1O('-E<G9E<B!W:71H($944"!U<V5R)W,@
M8W)E9&5N=&EA;',B+`H))VAS=%]D969?7W-T86YD87)D7V9O<G=A<F1I;F=?
M9&5F:6YI=&EO;B<@/3X@(E-T86YD87)D(&9O<G=A<F1I;F<@87-S:6=N;65N
M="!F;W(@9&]M86EN("4Q(BP*"2=H<W1?9&5F7U]T:71L95]N86UE7V)A<V5D
M)R`]/B`B3F%M92UB87-E9"(L"@DG:'-T7V1E9E]?=6YA8FQE7V-R96%T92]U
M<&1A=&5?<&AY<VEC7VAS="<@/3X@(E5N86)L92!T;R!C<F5A=&4O=7!D871E
M('!H>7-I8V%L(&AO<W1I;F<Z("4Q(BP*"2=H<W1?9&5F7U]U;F%B;&5?8W)E
M871E+W5P9&%T95]S=&1?9G=D)R`]/B`B56YA8FQE('1O(&-R96%T92]U<&1A
M=&4@<W1A;F1A<F0@9F]R=V%R9&EN9SH@)3$B+`H))VAS=%]D969?7W5N86)L
M95]C<F5A=&5?9F]R=V%R9&EN9U]M>7-E;&8G(#T^(")5;F%B;&4@=&\@8W)E
M871E(&9O<G=A<F1I;F<@=&\@=&AE(&1O;6%I;B!I='-E;&8N(BP*"2=H<W1?
M9&5F7U]U;F%B;&5?='5R;E]S<VQ?;V9F7W=H:6QE7V9P7W-S;%]O;B<@/3X@
M(E5N86)L92!T;R!T=7)N(&]F9B!34TP@<W5P<&]R=#H@1G)O;G1086=E(&]V
M97(@4U-,('-U<'!O<G0@:7,@96YA8FQE9"XB+`H))VAS=%]D969?7W5N86)L
M95]T=7)N7V9P7W-S;"<@/3X@(E5N86)L92!T;R!T=7)N(&]N($9R;VYT4&%G
M92!O=F5R(%-33"!S=7!P;W)T.B!34TP@<W5P<&]R="!I<R!D:7-A8FQE9"XB
M+`H))VAS=%]D969?7W5N86)L95]T=7)N7V]N7W-S;%]C97)T7VYO=%]D969I
M;F5D)R`]/B`B56YA8FQE('1O('1U<FX@;VX@4U-,('-U<'!O<G0Z(&YO(%-3
M3"!C97)T:69I8V%T92!I;G-T86QL960B+`H))VAS=%]D969?7W5R;%]I<U]I
M;G9A;&ED)R`]/B`B55),(&ES(&EN=F%L:60N(BP*"2=H<W1?9&5F7U]V:7)T
M=6%L7VAO<W1?86-C97-S)R`]/B`B5FER='5A;"!H;W-T(&%C8V5S<R!F;W(@
M9&]M86EN("4Q(BP*"2=H<W1?9&5F7U]V:7)T=6%L7VAO<W1?=7-E<U]N;VY?
M97AI<W1E9%]I<%]A9&1R97-S)R`]/B`B5T%23DE.1RX@5&AI<R!V:7)T=6%L
M(&AO<W0@:7,@=7-I;F<@82!N;VYE>&ES=&5N="!)4"!A9&1R97-S(&9O<B!H
M;W-T:6YG+B(L"@DG:'-T7V1E9E]?>6]U7VAA=F5?;F]?:7!S)R`]/B`B66]U
M(&AA=F4@;F\@:7`@861D<F5S<V5S(&%V86EL86)L92!A;F0@>6]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@3F%M92UB87-E9"!H;W-T:6YG+B(L"@DG
M:'-T7V1E9E]?>6]U7W1U<FYE9%]O9F9?9G!?<W-L7W-U<'!O<G1?86QL7V9P
M7W-E='1I;F=S7W=I;&Q?8F5?9&5S=')O>65D7V]K/R<@/3X@(EEO=2!H879E
M('1U<FYE9"!O9F8@=&AE($9R;VYT4&%G92!O=F5R(%-33"!S=7!P;W)T+B!!
M;&P@1G)O;G1086=E('-E='1I;F=S('=I;&P@8F4@9&ES8V%R9&5D+B!$;R!Y
M;W4@=V%N="!T;R!P<F]C965D/R(L"@DG:'-T7V1E9E]?>6]U7W1U<FYE9%]O
M9F9?9G!?<W5P<&]R=%]A;&Q?9G!?<V5T=&EN9W-?=VEL;%]B95]D97-T<F]Y
M961?;VL_)R`]/B`B66]U(&AA=F4@='5R;F5D(&]F9B!T:&4@1G)O;G1086=E
M('-U<'!O<G0N($%L;"!&<F]N=%!A9V4@<V5T=&EN9W,@=VEL;"!B92!D:7-C
M87)D960N($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=H<W1?<V5L7U]H
M96%D97(G(#T^("`@(E1O(&AO<W0@82!W96(@<VET92!O;B!T:&ES(&UA8VAI
M;F4L('-E;&5C="!T:&4@4&AY<VEC86P@:&]S=&EN9R!O<'1I;VXN(%5P;VX@
M8V]M<&QE=&EO;B!O9B!T:&ES('!R;V-E9'5R92P@>6]U<B!C;VYT<F]L('!A
M;F5L('=I;&P@<V5T('5P('1H92!D;VUA:6X@;F%M92!S97)V97(@;VX@=&AI
M<R!M86-H:6YE('1O('-E<G9E('1H92!N97<@9&]M86EN(&YA;64@86YD('!R
M97!A<F4@=&AE('=E8B!S97)V97(@=&\@<V5R=F4@=&AE(&YE=R!W96(@<VET
M93H@82!N97<@>F]N92!F:6QE('=I=&@@87!P<F]P<FEA=&4@<F5S;W5R8V4@
M<F5C;W)D<R!W:6QL(&)E(&%D9&5D('1O('1H92!D;VUA:6X@;F%M92!S97)V
M97(G<R!C;VYF:6=U<F%T:6]N(&9I;&5S+"!A('=E8B!S<&%C92!W:6QL(&)E
M(&-R96%T960@:6YS:61E('1H92!W96(@<V5R=F5R)W,@9&ER96-T;W)Y+"!A
M;F0@;F5C97-S87)Y('5S97(@86-C;W5N=',@=VEL;"!B92!C<F5A=&5D(&]N
M('1H92!S97)V97(N7&Y.;W1E.B!)9B!T:&4@<VET92!I<R!H;W-T960@;VX@
M86YO=&AE<B!M86-H:6YE+"!A;F0@>6]U('=I<V@@=&\@<V5T('5P('EO=7(@
M8V]N=')O;"!P86YE;"=S($1.4R!S97)V97(@;VYL>2!T;R!S97)V92!T:&4@
M1$Y3('IO;F4@9F]R('1H870@<VET92P@<V5L96-T(&5I=&AE<B!&<F%M92!F
M;W)W87)D:6YG(&]R(%-T86YD87)D(&9O<G=A<F1I;F<@;W!T:6]N+B!7:71H
M('-T86YD87)D(&9O<G=A<F1I;F<L(&$@=7-E<B!I<R!R961I<F5C=&5D('1O
M('1H92!S:71E(&%N9"!T:&4@86-T=6%L('-I=&4G<R!54DP@:7,@<VAO=VX@
M:6X@=&AE('5S97(G<R!B<F]W<V5R+"!S;R!T:&4@=7-E<B!A;'=A>7,@:VYO
M=W,@=&AA="!H92!O<B!S:&4@:7,@<F5D:7)E8W1E9"!T;R!A;F]T:&5R(%52
M3"X@5VET:"!F<F%M92!F;W)W87)D:6YG+"!A('5S97(@:7,@<F5D:7)E8W1E
M9"!T;R!T:&4@<VET92!W:71H;W5T(&MN;W=I;F<@=&AA="!T:&4@<VET92!A
M8W1U86QL>2!R97-I9&5S(&%T(&%N;W1H97(@;&]C871I;VXN(BP*"2=H<W1?
M<V5L7U]P:'ES:6-A;%]H<W0G"3T^(")0:'ES:6-A;"!H;W-T:6YG(BP*"2=H
M<W1?<V5L7U]S96QE8W1?:'-T7W1Y<&4G(#T^(")396QE8W0@=&AE('1Y<&4@
M;V8@:&]S=&EN9R!F;W(@=&AE(&1O;6%I;B(L"@DG:'-T7W-E;%]?<V5L96-T
M7VAS=%]T>7!E7W=A<FYI;F<G(#T^(")396QE8W0@=&AE('1Y<&4@;V8@:&]S
M=&EN9R!F;W(@=&AE(&1O;6%I;B$B+`H))VAS=%]S96Q?7W-T86YD87)D7V9R
M=R<)/3X@(E-T86YD87)D(&9O<G=A<F1I;F<B+`H))VAS=%]S96Q?7V9R86UE
M7V9R=R<)/3X@(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?8VAO;W-E7VAS=%]T
M>7!E)R`]/B`B4V5L96-T('1H92!R97%U:7)E9"!H;W-T:6YG('1Y<&4N(BP*
M"2=?7V9R86UE7V9R=R<@/3X@(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?:&]S
M=&EN9U]E>&ES=',G(#T^(")5;F%B;&4@=&\@8W)E871E(&AO<W1I;F<L(&%S
M(&ET(&ES(&%L<F5A9'D@8V]N9FEG=7)E9"!F;W(@=&AI<R!D;VUA:6XN(%EO
M=2!W:6QL(&)E(')E9&ER96-T960@=&\@=&AE(&AO<W1I;F<@;6%N86=E;65N
M="!P86=E+B(L"@DG7U]N;U]H<W1?8V]N9B<@/3X@(E1H97)E(&ES(&YO(&AO
M<W1I;F<@8V]N9FEG=7)E9"!F;W(@>6]U<B!D;VUA:6XN(BP*"2=?7W!H>7-I
M8V%L7VAS="<@/3X@(E!H>7-I8V%L(&AO<W1I;F<B+`H))U]?<V5L96-T7VAS
M=%]T>7!E)R`]/B`B4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@9F]R('1H
M92!D;VUA:6XB+`H))U]?<W1A;F1A<F1?9G)W)R`]/B`B4W1A;F1A<F0@9F]R
M=V%R9&EN9R(L"@DG7U]W87)N:6YG)R`]/B`B5V%R;FEN9R$@06QL(&]F('1H
M92!P<F5V:6]U<VQY('-E="!P87)A;65T97)S('=I;&P@8F4@9&ES8V%R9&5D
M+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!H;W-T:6YG
M('1Y<&4_(BP*"2=I7V-L7R$G(#T^(")297-O=7)C92!U<V%G92!O9B!T:&4@
M8VQI96YT(&ES(&5X8V5E9&EN9R!L:6UI=',N(BP*"2=I7V-L7V]F9B<@/3X@
M(D-L:65N="!I<R!I;F%C=&EV92XB+`H))VE?8VQ?;V9F7V)Y7V%D;6EN)R`]
M/B`B0VQI96YT(&%C8V]U;G0@:7,@9&ES86)L960@8GD@861M:6YI<W1R871O
M<BXB+`H))VE?8VQ?;V9F7V5X<&ER960G(#T^(")#;&EE;G0@86-C;W5N="!I
M<R!E>'!I<F5D+B(L"@DG:5]C;%]O:R<@/3X@(E)E<V]U<F-E('5S86=E(&]F
M('1H92!C;&EE;G0@:7,@=VET:&EN(&QI;6ET<RXB+`H))VE?8VQ?;VXG(#T^
M(")#;&EE;G0@:7,@86-T:79E+B(L"@DG:5]D;VU?(2<@/3X@(D1I<VL@<W!A
M8V4@86YD+V]R('1R869F:6,@;&EM:71S(&%R92!E>&-E961E9"!I;B!T:&4@
M9&]M86EN+B(L"@DG:5]D;VU?;V9F)R`]/B`B1&]M86EN(&ES(&EN86-T:79E
M+B(L"@DG:5]D;VU?;V9F7V)A8VMU<%]R97-T;W)E)R`]/B`B1&]M86EN(&ES
M('1E;7!O<F%R:6QY(&1I<V%B;&5D(&9O<B!B86-K=7`O<F5S=&]R:6YG+B(L
M"@DG:5]D;VU?;V9F7V)Y7V%D;6EN)R`]/B`B1&]M86EN(&ES(&1I<V%B;&5D
M(&)Y(&%D;6EN:7-T<F%T;W(B+`H))VE?9&]M7V]F9E]B>5]C;&EE;G0G(#T^
M(")$;VUA:6X@:7,@9&ES86)L960@8GD@8VQI96YT(BP*"2=I7V1O;5]O9F9?
M8GE?<F5S96QL97(G(#T^(")$;VUA:6X@:7,@9&ES86)L960@8GD@<F5S96QL
M97(B+`H))VE?9&]M7V]F9E]E>'!I<F5D)R`]/B`B1&]M86EN(&ES(&5X<&ER
M960B+`H))VE?9&]M7V]F9E]W:71H7W!A<F5N="<@/3X@(D-L:65N="!I<R!D
M:7-A8FQE9"!A;&]N9R!W:71H(&AI<R]H97(@9&]M86EN(BP*"2=I7V1O;5]O
M:R<@/3X@(D1O;6%I;B!I<R!A;&P@<FEG:'0N(BP*"2=I7V1O;5]O;B<@/3X@
M(D1O;6%I;B!I<R!A8W1I=F4N(BP*"2=I<%]A9&1R7U]A;')E861Y7V5X:7-T
M<R<@/3X@(DE0(&%D9')E<W,@)3$@86QR96%D>2!E>&ES=',N(BP*"2=I<%]A
M9&1R7U]C86YT7V%D9"<@/3X@(DE0("4Q(&1O97,@;F]T(&5X:7-T(&]R(&)E
M;&]N9W,@=&\@25`@<&]O;"!O9B!A;F]T:&5R(&-L:65N="(L"@DG:7!?861D
M<E]?8VQ?9&]M86EN<U]L:7-T7V9O<E]I<"<@/3X@(E1H92!D;VUA:6YS(&]F
M(&-L:65N="`E,2!T:&%T('5S92`E,B!I<"!A9&1R97-S("4S(BP*"2=I<%]A
M9&1R7U]C;%]L:7-T7V9O<E]I<"<@/3X@(D-L:65N=',@=7-I;F<@)3$@25`@
M861D<F5S<R`E,B(L"@DG:7!?861D<E]?8VQ?;&ES=%]F;W)?:7!?861D)R`]
M/B`B061D($E0(&%D9')E<W,@=&\@8VQI96YT<R!P;V]L(BP*"2=I<%]A9&1R
M7U]D;VUA:6YS7VQI<W1?9F]R7VEP)R`]/B`B1&]M86EN<R!U<VEN9R`E,2!)
M4"!A9&1R97-S("4R(BP*"2=I<%]A9&1R7U]I<%]U<V5D7V)Y7VAS=%]O<E]F
M<G<G(#T^("))4"!A9&1R97-S("4Q(&ES('5S960@9F]R(&AO<W1I;F<@;W(@
M9F]R=V%R9&EN9RXB+`H))VEP7V%D9')?7W)E;6]V95]I<%]A9&1R)R`]/B`B
M5&AE<V4@:7`@861D<F5S<V5S('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!S
M>7-T96TZ(BP*"2=I<%]A9&1R7U]S96QE8W1?8VQI96YT<R<@/3X@(E-E;&5C
M="!C;&EE;G1S(BP*"2=I<%]A9&1R7U]S96QE8W1?:7!?861D<E]T;U]R96UO
M=F4G(#T^(")396QE8W0@=&AE($E0(&%D9')E<W,@=&\@8F4@<F5M;W9E9"XB
M+`H))VEP7V%D9')?7W5N86QL;W=E9%]B>5]L:6-E;G-E)R`]/B`B4&QE<VL@
M:7,@;F]T(&QI8V5N<V5D('1O('=O<FL@;VX@25`@861D<F5S<R`E,2Y<;D%L
M;&]W960@25`@<F%N9V5S(&%R93H@)3(N(BP*"2=I<%]A;&EA<U]?861D7VEP
M)R`]/B`B061D($E0(&%D9')E<W,B+`H))VEP7V%L:6%S7U]A9&1R7V%L<F5A
M9'E?97AI<W0G(#T^(")A9&1R97-S(&%L<F5A9'D@97AI<W1S+B(L"@DG:7!?
M86QI87-?7V%L:6%S7VUA;F%G92<@/3X@(DE0(&%D9')E<W-E<R!M86YA9V5M
M96YT(BP*"2=I<%]A;&EA<U]?86QI87-E<R<@/3X@(DE0($%D9')E<W-E<R`B
M+`H))VEP7V%L:6%S7U]I;G1E<F9A8V4G(#T^("));G1E<F9A8V4@(BP*"2=I
M<%]A;&EA<U]?:6YV86QI9%]I<%]N;5]B<V1?=G)T7VAS=',G(#T^("(E,2!)
M4"!A9&1R97-S(&9O<B!N86UE+6)A<V5D('9I<G1U86P@:&]S=&EN9R!I<R!I
M;G9A;&ED+B(L"@DG:7!?86QI87-?7VEN=F%L:61?:7!?;W)?;F5T;6%S:R<@
M/3X@(DEN=F%L:60@25`@861D<F5S<R]N971M87-K('!A:7(N(BP*"2=I<%]A
M;&EA<U]?:7!?8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!I<R!T:&4@
M;6%I;B!S97)V97(@25`L('=H:6-H(&-A;FYO="!B92!R96UO=F5D+B(L"@DG
M:7!?86QI87-?7VEP7VYO=%]E>&ES="<@/3X@(FEP(&%D9')E<W,@)3$@9&]E
M<R!N;W0@97AI<W0N(BP*"2=I<%]A;&EA<U]?:7!?861D<F5S<U]A;F1?;6%S
M:R<@/3X@)TE0(&%D9')E<W,@86YD('-U8FYE="!M87-K)RP*"2=I<%]A;&EA
M<U]?<F5M;W9E7W-E;&5C=&5D7VEP7V%L:6%S97,_)R`]/B`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<V5L96-T960@25`@861D<F5S
M<V5S/R(L"@DG:7!?86QI87-?7W-E;&5C=%]I<"<@/3X@(E-E;&5C="!A="!L
M96%S="!O;F4@25`@861D<F5S<R!F<F]M('1H92!L:7-T('1O(')E;6]V92!I
M="XB+`H))VEP7V%L:6%S7U]T:&ES7VEP7W5S961?9F]R7V1O;6%I;B<@/3X@
M(B@E,2D@=&AI<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&1O;6%I;B`E,BXB
M+`H))VEP7V%L:6%S7U]T:&ES7VEP7W5S961?9F]R7VYM7V)S9%]V<G1?:'-T
M<R<@/3X@(B@E,2D@=&AI<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&YA;64M
M8F%S960@=FER='5A;"!H;W-T<RXB+`H))VEP7V%L:6%S7U]T>7!E)R`]/B`B
M25`@='EP92(L"@DG:7!?86QI87-?7W5N86)L95]A9&1?:7`G(#T^(")5;F%B
M;&4@=&\@861D($E0.B`E,2(L"@DG:7!?86QI87-?7W5N86)L95]R96UO=F5?
M:7`G(#T^(")5;F%B;&4@=&\@<F5M;W9E($E0.B`E,2(L"@DG:7!?8W1R;%]?
M86YO;GEM;W5S7V9T<%]E>&ES='-?:6Y?9&]M86EN)R`]/B`B66]U(&-A;FYO
M="!C:&%N9V4@=&AE($E0(&%D9')E<W,@='EP92!T;R!S:&%R960L(&%S(&ET
M('=I;&P@;6%K92!!;F]N>6UO=7,@1E10(&9O<B!D;VUA:6X@)R4Q)R!U;F%V
M86EL86)L92XB+`H))VEP7V-T<FQ?7VEP7V%D9'(G(#T^("))4"!A9&1R97-S
M("4R(&]N('1H92!I;G1E<F9A8V4@)3$B+`H))VEP7V-T<FQ?7VEP7V5X:7-T
M<U]M86YY7W!O;VQS)R`]/B`B66]U(&-A;FYO="!C:&%N9V4@25`@='EP92X@
M25`@861D<F5S<R!B96QO;F=S('1O('1H92!P;V]L<R!O9B!S979E<F%L(&-L
M:65N=',@870@=&AE('-A;64@=&EM92XB+`H))VEP7V-T<FQ?7W-S;%]C97)T
M)R`]/B`B4U-,($-E<G1I9FEC871E(BP*"2=I<%]P;V]L7U]I<%]A9&1R97-S
M7VES7V%B<V5N9%]I;E]P;V]L)R`]/B`B25`@861D<F5S<R!I<R!M:7-S:6YG
M+B(L"@DG:7!?<&]O;%]?:7!?<&]O;%]F;W)?8VQI96YT)R`]/B`B25`@<&]O
M;"!O9B!C;&EE;G0@)3$B+`H))VEP7W!O;VQ?7VYO7V-L:65N<U]A=F%I;"<@
M/3X@(E1H97)E(&%R92!N;R!C;&EE;G1S(&%V86EL86)L92(L"@DG:7!?<&]O
M;%]?;F]?=F%C86YT7VEP<R<@/3X@(E1H97)E(&%R92!N;R!V86-A;G0@25!S
M(BP*"2=I<%]P;V]L7U]P;V]L7VES7V5M<'1Y)R`]/B`B0VQI96YT)W,@25`@
M<&]O;"!I<R!E;7!T>2X@5&\@861D(&%N($E0(&%D9')E<W,L('EO=2!S:&]U
M;&0@=7-E('1H92!#;&EE;G0G<R!)4"!P;V]L(&UA;F%G96UE;G0@9G5N8W1I
M;VYS(&%V86EL86)L92!F<F]M('1H92!#;&EE;G0G<R!(;VUE(%!A9V4N(BP*
M"2=I<%]P;V]L7U]R96UO=F5?:7!?861D<B<@/3X@(E1H97-E(&EP(&%D9')E
M<W-E<R!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4@<&]O;"`E,3HB+`H))VEP
M7W!O;VQ?7W-E;&5C=%]F<F5E7VEP<R<@/3X@(E9A8V%N="!)4',B+`H))VEP
M7W!O;VQ?7W5S961?:7!S)R`]/B`B0VQI96YT)W,@25`@<&]O;"(L"@DG;&EC
M96YS95]?:5]A9W)E92<@/3X@(DD@86=R964@=&\@=&AE('1E<FUS(&]F('1H
M:7,@;&EC96YS92!A9W)E96UE;G0N(BP*"2=L:6-E;G-E7U]N;W1?<VAO=R<@
M/3X@(D1O(&YO="!S:&]W(&ET(&%G86EN+B(L"@DG;&EC96YS95]?=6YA8FQE
M7V]P96Y?;&EC96YS95]F:6QE)R`]/B`B56YA8FQE('1O(&]P96X@=&AE(&QI
M8V5N<V4@9FEL93H@)3$B+`H))VQI8V5N<V5?7WEO=5]S:&]U;&1?86-C97!T
M)R`]/B`B26X@;W)D97(@=&\@=7-E("104D]$7TY!344@>6]U('-H;W5L9"!A
M9W)E92!T;R!T:&4@=&5R;7,@;V8@=&AI<R!L:6-E;G-E+B(L"@DG;&EM:71?
M7V1A=&5?:6Y?<&%S="<@/3X@(E9A;&ED:71Y('!E<FEO9"!I<R!I;G9A;&ED
M+B`E,2!I<R!I;B!T:&4@<&%S="XB+`H))VQI;6ET7U]D:7-K7W-P86-E)R`]
M/B`B1&ES:R!S<&%C92(L"@DG;&EM:71?7V5N=&5R7V1A=&4G(#T^(")%;G1E
M<B!D871E(BP*"2=L:6UI=%]?97AP:7)A=&EO;B<@/3X@(E9A;&ED:71Y('!E
M<FEO9"(L"@DG;&EM:71?7VUA>%]B;W@G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!M86EL8F]X97,B+`H))VQI;6ET7U]M87A?9&(G(#T^(")-87AI;75M(&YU
M;6)E<B!O9B!D871A8F%S97,B+`H))VQI;6ET7U]M87A?9&]M)R`]/B`B36%X
M:6UU;2!N=6UB97(@;V8@9&]M86EN<R(L"@DG;&EM:71?7VUA>%]M86EL;&ES
M=',G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=L
M:6UI=%]?;6%X7VUG)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@;6%I;"!G<F]U
M<',B+`H))VQI;6ET7U]M87A?<F5D:7(G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!M86EL(')E9&ER96-T<R(L"@DG;&EM:71?7VUA>%]R97-P)R`]/B`B36%X
M:6UU;2!N=6UB97(@;V8@;6%I;"!A=71O<F5S<&]N9&5R<R(L"@DG;&EM:71?
M7VUA>%]S=6)D;VTG(#T^(")-87AI;75M(&YU;6)E<B!O9B!S=6)D;VUA:6YS
M(BP*"2=L:6UI=%]?;6%X7W1R869F:6,G(#T^(")-87AI;75M(&%M;W5N="!O
M9B!T<F%F9FEC(BP*"2=L:6UI=%]?;6%X7W=E8F%P<',G(#T^(")-87AI;75M
M(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG;&EM:71?7VUA>%]W
M=2<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG;&EM:71?
M7VUB;WA?<75O=&$G(#T^(")3970@=&AE(&UA:6QB;W@@<75O=&$B+`H))VQI
M;6ET7U]U;FET<U]D:7-K7W-P86-E)R`]/B`B34(B+`H))VQI;6ET7U]U;FET
M<U]M87A?8F]X)R`]/B`B;6%I;&)O>&5S(BP*"2=L:6UI=%]?=6YI='-?;6%X
M7VUN)R`]/B`B;F%M97,B+`H))VQI;6ET7U]U;FET<U]M87A?9&(G(#T^(")D
M871A8F%S97,B+`H))VQI;6ET7U]U;FET<U]M87A?8VPG(#T^(")C;&EE;G1S
M(BP*"2=L:6UI=%]?=6YI='-?;6%X7V1O;2<@/3X@(F1O;6%I;G,B+`H))VQI
M;6ET7U]U;FET<U]M87A?;6%I;&QI<W1S)R`]/B`B;6%I;&EN9R!L:7-T<R(L
M"@DG;&EM:71?7W5N:71S7VUA>%]M9R<@/3X@(FUA:6P@9W)O=7!S(BP*"2=L
M:6UI=%]?=6YI='-?;6%X7W)E9&ER)R`]/B`B<F5D:7)E8W1S(BP*"2=L:6UI
M=%]?=6YI='-?;6%X7W)E<W`G(#T^(")A=71O<F5S<&]N9&5R<R(L"@DG;&EM
M:71?7W5N:71S7VUA>%]S=6)D;VTG(#T^(")S=6)D;VUA:6YS(BP*"2=L:6UI
M=%]?=6YI='-?;6%X7W1R869F:6,G(#T^(")-0B]M;VYT:"(L"@DG;&EM:71?
M7W5N:71S7VUA>%]W96)A<'!S)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H)
M)VQI;6ET7U]U;FET<U]M87A?=W4G(#T^(")W96(@=7-E<G,B+`H))VQI;6ET
M7U]U;FET<U]M8F]X7W%U;W1A)R`]/B`B2T(B+`H*"2=L;V-A;&5?=7!L;V%D
M7U]T:71L92<@/3X@)T%D9"!,;V-A;&4G+`H))VQO8V%L95]U<&QO861?7V9I
M;&5?;F%M92<@(#T^("=0871H('1O('1H92!L86YG=6%G92!P86-K(&9I;&4@
M;&]C871I;VXG+`H))VQO8V%L95]U<&QO861?7W5N86)L95]T;U]I;G-T86QL
M)R`@/3X@)U5N86)L92!T;R!I;G-T86QL('1H92!L86YG=6%G92!P86-K(&9I
M;&4G+`H))VQO8V%L97-?;&ES=%]?=&ET;&4G("`@("`@(#T^("=,86YG=6%G
M92!P86-K<R!R97!O<VET;W)Y)RP*"2=L;V-A;&5S7VQI<W1?7VQE9V5N9"<@
M("`@("`@/3X@)T%V86EL86)L92!L86YG=6%G97,G+`H))VQO8V%L97-?;&ES
M=%]?86-T:79E7W1I=&QE)PD]/B`G4R<L"@DG;&]C86QE<U]L:7-T7U]L;V-A
M;&5?=&ET;&4G"3T^("=,86YG=6%G92!P86-K)RP*"2=L;V-A;&5S7VQI<W1?
M7VQA;F=?=&ET;&4G"0D]/B`G3&%N9W5A9V4G+`H))VQO8V%L97-?;&ES=%]?
M8V]U;G1R>5]T:71L92<)/3X@)T-O=6YT<GDG+`H))VQO8V%L97-?;&ES=%]?
M=7-E9%]T:71L92<)"3T^("=5<V5D)RP*"@DG;&]C86QE<U]R96UO=F5?7W1I
M=&QE)R`@("`@/3X@)TQO8V%L97,@4F5M;W9A;"<L"@DG;&]C86QE<U]R96UO
M=F5?7W-E;&5C=%]L;V-A;&5S7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE
M(&QO8V%L97,@=&\@8F4@<F5M;W9E9"XG+`H))VQO8V%L97-?7V-A;E]N;W1?
M<F5M;W9E)R`@(#T^("=5;F%B;&4@=&\@<F5M;W9E('1H92!L86YG=6%G92!P
M86-K(&9O<B!L;V-A;&4@)3$Z("4R)RP*"@DG;&]G7V9I;&5?=FEE=V5R7U]F
M:6QE7VYA;65?:7-?=6YD969I;F5D)R`]/B`B4W!E8VEF>2!T:&4@;&]G(&9I
M;&5N86UE(&9O<B!V:65W:6YG+B(L"@DG;&]G7V9I;&5S7U]D96QE=&EO;E]P
M86=E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!L;V<@9FEL97,@9F]R(&1O
M;6%I;B`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=L;V=?9FEL97-?7VEN=F%L
M:61?=F%L=65?;&EN97-?9F]R7W9I97<G(#T^("));G9A;&ED(&YU;6)E<B!O
M9B!L:6YE<R!S<&5C:69I960N(BP*"2=L;V=?9FEL97-?7VQI;F5S7V]F7VQO
M9V9I;&5?9F]R7W9I97<G(#T^("),:6YE<R!O9B!L;V<@9FEL92!T;R!B92!D
M:7-P;&%Y960@*&9R;VT@=&AE(&5N9"!O9B!T:&4@9FEL92DB+`H))VQO9U]F
M:6QE<U]?;&]G7V9I;&5?8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!L
M;V<@9FEL92!I<R!A8W1I=F4@86YD('1H97)E9F]R92!C86YN;W0@8F4@9&5L
M971E9"XB+`H))VQO9U]F:6QE<U]?;&]G7V9I;&5S)R`]/B`B3&]G(&9I;&5S
M(BP*"2=L;V=?9FEL97-?7W!A9V5?=&ET;&4G(#T^("),;V<@9FEL97,@;6%N
M86=E;65N="!F;W(@9&]M86EN("4Q(BP*"2=L;V=?9FEL97-?7W-E;&5C=%]F
M:6QE<U]F;W)?<F5M;W9E)R`]/B`B3F\@;&]G(&9I;&5S('-E;&5C=&5D(&9O
M<B!R96UO=F%L+B(L"@DG;&]G7V9I;&5S7U]T;W1A;%]L;V=F:6QE<U]S:7IE
M)R`]/B`B3&]G(&9I;&5S('1O=&%L('-I>F4Z("4Q(BP*"2=L;V=?<F]T7U]C
M;VUP<F5S<R<@/3X@(D-O;7!R97-S(&QO9R!F:6QE<R(L"@DG;&]G7W)O=%]?
M;&]G7W)O=%]P97)I;V0G(#T^("),;V<@<F]T871I;VX@8V]N9&ET:6]N(BP*
M"2=L;V=?<F]T7U]L;V=?<F]T7W-I>F4G(#T^(")B>2!S:7IE(BP*"2=L;V=?
M<F]T7U]L;V=?<F]T7W1I;64G(#T^(")B>2!T:6UE(BP*"2=L;V=?<F]T7U]L
M;V=R;W1A=&EO;E]E;F%B;&4G(#T^(")%;F%B;&4@;&]G(')O=&%T:6]N(BP*
M"2=L;V=?<F]T7U]M86EL)R`]/B`B4V5N9"!P<F]C97-S960@;&]G(&9I;&5S
M('1O(&4M;6%I;"(L"@DG;&]G7W)O=%]?;6%X7VYU;6)E<E]O9E]L;V=F:6QE
M<R<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&QO9R!F:6QE<R(L"@DG;&]G7W)O
M=%]?<&%G95]T:71L92<@/3X@(DQO9R!R;W1A=&EO;B!P<F5F97)E;F-E<R!F
M;W(@9&]M86EN("4Q(BP*"2=L;V=?<F]T7U]T:6UE7W!E<FEO9"<@/3X@(G!E
M<FEO9"(L"@DG;&]G:6Y?=7!?7V%C8V5S<U]D96YI961?86-C;W5N=%]D:7-A
M8FQE9"<@/3X@(D%C8V5S<R!D96YI960N(%EO=7(@86-C;W5N="!H87,@8F5E
M;B!D:7-A8FQE9"XB+`H))VQO9VEN7W5P7U]D969A=6QT7VQO8V%L92<@/3X@
M)U5S97(@9&5F875L="<L"@DG;&]G:6Y?=7!?7V5N=&5R7VQO9VEN7V%N9%]P
M87-S=V0G(#T^(")%;G1E<B!Y;W5R(&QO9VEN(&YA;64@86YD('!A<W-W;W)D
M+B(L"@DG;&]G:6Y?=7!?7V9O<F=O=%]P87-S=V]R9%]L86)E;"<@/3X@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(L"@DG;&]G:6Y?=7!?7V9O<F=O=%]P87-S
M=V]R9%]T97AT)R`]/B`B268@>6]U(&9O<F=O="!Y;W5R('!A<W-W;W)D('=E
M('=I;&P@=')Y('1O(&AE;'`@>6]U(&)Y('-E;F1I;F<@:70@;W5T('1O('EO
M=7(@92UM86EL+B(L"@DG;&]G:6Y?=7!?7VQO9VEN7VAA<U]B965N7VQO8VME
M9"<@/3X@(D%C8V5S<R!D96YI960N(BP*"2=L;V=I;E]U<%]?;&]G:6Y?;&%B
M96Q?<&QE<VLG(#T^("),;V=I;B!4;R`E,2(L"@DG;&]G:6Y?=7!?7VQO9VEN
M7W1E>'0G(#T^(")%;G1E<B!T:&4@;&]G:6X@;F%M92!I;G1O(%PB3&]G:6Y<
M(B!A;F0@<&%S<W=O<F0@:6YT;R!T:&4@7")087-S=V]R9%PB(&9I96QD<R!R
M97-P96-T:79E;'DN(%1H96X@8VQI8VL@7"),;V=I;EPB+B(L"@DG;&]G:6Y?
M=7!?7W5N86)L95]T;U]C:&5C:U]P87-S)R`]/B`B56YA8FQE('1O(&-H96-K
M('!A<W-W;W)D.B`E,2(L"@DG;&]C86QE<U]L:7-T7U]M;'-?;&EM:70G(#T^
M(")4:&4@;&EM:70@;VX@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&QA;F=U86=E
M('!A8VMS(&ES(&5X8V5E9&5D+B!!8W1I=F4@;&%N9W5A9V5S("4Q+B!!;&QO
M=V5D(&QA;F=U86=E<R`E,BXB+`H))VQO9VEN7W5P7U]S:&]R=%]W87)N:6YG
M7VQI;6ET<U]L:6-E;F-E7VME>2<@/3X@(D%C8V5S<R!T;R!T:&4@8V]N=')O
M;"!P86YE;"!I<R!T96UP;W)A<FEL>2!U;F%V86EL86)L92X@4&QE87-E(&-O
M;G1A8W0@>6]U<B!P<F]V:61E<B!F;W(@9&5T86EL<RXB+`H))VQO9VEN7W5P
M7U]G<F%C95]P97)I;V0G(#T^("=9;W4@87)E(&-U<G)E;G1L>2!O<&5R871I
M;F<@=VET:&EN('1H92!G<F%C92!P97)I;V0@;V8@>6]U<B!P<F]D=6-T(&QI
M8V5N<V4@*"4S*2X@5&\@=7!D871E('EO=7(@<')O9'5C="!L:6-E;G-E('5S
M92!T:&4@4F5T<FEE=F4@2V5Y<R!F=6YC=&EO;B!O9B`E,4QI8V5N<V4@36%N
M86=E<B4R+B<L"@DG;&]G:6Y?=7!?7W!A<G1N97)?;&EC96YS95]M97-S86=E
M)R`]/B`G66]U(&%R92!C=7)R96YT;'D@;W!E<F%T:6YG('=I=&@@82!L:6UI
M=&5D('!R;V1U8W0@;&EC96YS92!T:&%T(')E<75I<F5S(')E9VES=')A=&EO
M;B!P<FEO<B!T;R!A8W1I=F%T:6YG('1H92!F=6QL(&9E871U<F4@<V5T+B`@
M5&\@=7!D871E('EO=7(@<')O9'5C="!L:6-E;G-E('-E;&5C="!T:&4@4F5T
M<FEE=F4@2V5Y<R!O<'1I;VX@9G)O;2!W:71H:6X@)3%,:6-E;G-E($UA;F%G
M97(E,BXG+`H))VUA7U]C<F5A=&5?=&ET;&4G(#T^("=#<F5A=&EN9R!M86EL
M(&%L:6%S(&9O<B`E,2<L"@DG;6%?7V5D:71?=&ET;&4G(#T^(")%9&ET(&UA
M:6P@86QI87,@)3$B+`H))VUA7U]E;G1E<E]N97=?86QI87,G(#T^(")%;G1E
M<B!N97<@86QI87,N(BP*"2=M85]?:6YV86QI9%]A;&EA<R<@/3X@(DEN=F%L
M:60@;6%I;"!A;&EA<RXB+`H))VUA7U]M86EL7V%L:6%S97-?;6%I;&YA;64G
M(#T^(")-86EL(&%L:6%S97,@9F]R(&UA:6P@;F%M92`E,2(L"@DG;6%?7VUA
M:6QN86UE7V1O97-?;F]T7V5X:7-T)R`]/B`B36%I;"!N86UE(&1O97,@;F]T
M(&5X:7-T+B(L"@DG;6%?7W-E;&5C=%]M85]F;W)?<F5M;W9E)R`]/B`B4V5L
M96-T(&UA:6P@86QI87-E<R!T;R!B92!R96UO=F5D+B(L"@DG;6%?7W5N86)L
M95]T;U]A9&1?;F5W7VUA)R`]/B`B56YA8FQE('1O(&%D9"!N97<@;6%I;"!A
M;&EA<SH@)3$B+`H))VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97,G(#T^
M(").86UE<R!F;W(@4$]0,R])34%0(&UA:6P@86-C;W5N=',B+`H))VUA:6Q?
M7V%L;&]W7W-H;W)T7W!O<#-?;F%M97-?9&ES86)L960G(#T^(")/;FQY('5S
M92!O9B!F=6QL(%!/4#,O24U!4"!M86EL(&%C8V]U;G1S(&YA;65S(&ES(&%L
M;&]W960B+`H))VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97-?96YA8FQE
M9"<@/3X@(E5S92!O9B!S:&]R="`H=V5B;6%S=&5R*2!A;F0@9G5L;"`H=V5B
M;6%S=&5R0&1O;6%I;BYC;VTI(%!/4#,O24U!4"!M86EL(&%C8V]U;G0@;F%M
M97,@:7,@86QL;W=E9"(L"@DG;6%I;%]?8F%D9&]M86EN7V5X:7-T<R<@/3X@
M(E5N86)L92!T;R!A9&0@9&]M86EN('1O('1H92!B;&%C:R!L:7-T.B!S=6-H
M(&1O;6%I;B!A;')E861Y(&5X:7-T<R(L"@DG;6%I;%]?8FQO8VM?;6%I;%]F
M<F]M7V1O;7,G(#T^(")";&%C:R!,:7-T(BP*"2=M86EL7U]B;&]C:V5R<R<@
M/3X@(D)L;V-K960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME<G-?<F5M;W9E
M)R`]/B`B4F5M;W9E(&)L;V-K960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME
M<E]A9&0G(#T^(")!9&0@9&]M86EN<R!T;R!B;&%C:R!L:7-T(BP*"2=M86EL
M7U]C;&]S960G(#T^(")C;&]S960B+`H))VUA:6Q?7V-R>7!T961?<&%S<W=D
M7VUA=&-H)R`]/B`B5&AE<F4@87)E(&UA:6P@;F%M97,@;6%T8VAI;F<@=&AE
M(&5N8W)Y<'1E9"!P87-S=V]R9',N(BP*"2=M86EL7U]D;VU?:6Y?;&ES="<@
M/3X@(D1O;6%I;B!I<R!A;')E861Y(&EN('1H92!B;&%C:R!L:7-T+B(L"@DG
M;6%I;%]?96YA8FQE7W)B;"<@/3X@(D5N86)L92!-05!3('-P86T@<')O=&5C
M=&EO;B(L"@DG;6%I;%]?96YT97)?<F)L7W-E<G9E<B<@/3X@(E1Y<&4@:6X@
M=&AE($U!4%,@>F]N92XB+`H))VUA:6Q?7V5N=&5R7W)I9VAT7VEP7VUA<VLG
M(#T^(")%;G1E<B!T:&4@:7`@;6%S:R!B971W965N(#$@86YD(#,R(BP*"2=M
M86EL7U]E;G1E<E]R:6=H=%]I<%]M87-K7S(T)R`]/B`B16YT97(@=&AE(&EP
M(&UA<VL@8F5T=V5E;B`R-"!A;F0@,S(B+`H))VUA:6Q?7VEN<W1A;&Q?<F)L
M<VUT<&1?<')O9W)A;2<@/3X@(DEN<W1A;&P@=&AE(')B;'-M='`@<V]F='=A
M<F4N(BP*"2=M86EL7U]I;G9A;&ED7V1O;5]N86UE)R`]/B`B1&]M86EN(&YA
M;64@)3$@:7,@:6YV86QI9"XB+`H))VUA:6Q?7VEN=F%L:61?<&]P7VQO8VM?
M=&EM92<@/3X@(E!/4#,@;&]C:R!T:6UE(&ES(&EN=F%L:60N(BP*"2=M86EL
M7U]I;G9A;&ED7W)B;%]S97)V97(G(#T^(")-05!3('IO;F4@;F%M92!I<R!I
M;G9A;&ED+B(L"@DG;6%I;%]?:7!?86YD7VUA<VLG(#T^("))4"!A9&1R97-S
M+VUA<VLB+`H))VUA:6Q?7VEP7V%N9%]M87-K7V5X:7-T<R<@/3X@(E-U8V@@
M:7`@861D<F5S<R]N971M87-K('!A:7(@86QR96%D>2!E>&ES=',N(BP*"2=M
M86EL7U]I<%]O<E]M87-K7VES7VEN=F%L:60G(#T^("))4"!A9&1R97-S+VYE
M="!M87-K('!A:7(@:7,@:6YV86QI9"XB+`H))VUA:6Q?7VQO8VM?=&EM92<@
M/3X@(FQO8VL@=&EM92(L"@DG;6%I;%]?;6%I;%]O<'1I;VYS)R`]/B`B36%X
M:6UU;2!L971T97(@<VEZ92!A;F0@<F5L87D@;6]D92!P87)A;65T97)S(BP*
M"2=M86EL7U]M86EL;F%M97-?<&%S<W=D7VUA=&-H)R`]/B`B5&AE<F4@87)E
M(&UA:6P@;F%M92!A;F0@<&%S<W=O<F0@<&%I<G,@;6%T8VAI;F<N(BP*"2=M
M86EL7U]S96QE8W1?9&]M86EN<U]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!D;VUA:6YS('1O(&)E(')E;6]V960N(BP*"@DO+R!E;F0@;V8@;6%V97)I
M8VL@<&%R=`H*"@DO+R!K;V]P97(@<&%R=`H*"2=M86EL7U]M87A?<VEZ92<@
M/3X@(DUA>&EM=6T@;&5T=&5R('-I>F4B+`H))VUA:6Q?7VUB;WA?<75O=&$G
M(#T^(")-86EL8F]X('%U;W1A(BP*"2=M86EL7U]M:6XG(#T^(")-:6XB+`H)
M)VUA:6Q?7W1O=&%L7V9I;&5S7W-I>F4G(#T^(")4;W1A;"!R97!O<VET;W)Y
M('-I>F4Z("4Q(BP*"2=M86EL7U]F:6QE;F%M95]A;')E861Y7VEN7W)E<&]S
M:71O<GDG(#T^(")&:6QE('=I=&@@<W5C:"!N86UE(&ES(&%L<F5A9'D@:6X@
M<F5P;W-I=&]R>2(L"@DG;6%I;%]?;F]?=VAI=&5?;&ES=%]M87-K7V9E871U
M<F5?,C0G(#T^(")0;&5A<V4L('5S92`R-"!O<B!H:6=H97(@87,@;6%S:R!V
M86QU92Y<;EEO=7(@;6%I;"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S971T
M:6YG(&UA<VMS+B!792!C86X@;VYL>2!E;75L871E('-E='1I;F<@;6%S:R!F
M;W(@=F%L=65S(&YO="!L97-S('1H86X@,C0N(BP*"2=M86EL7U]O<&5N)R`]
M/B`B;W!E;B(L"@DG;6%I;%]?;W!E;E]R96QA>5]W87)N:6YG)R`]/B`B4V5T
M=&EN9R!Y;W5R(&UA:6P@<F5L87D@=&\@;W!E;B!E>'!O<V5S('EO=7(@;6%I
M;"!S97)V97(@=&\@<W!A;6UI;F<@86)U<V4N7&Y<;DET('-H;W5L9"!O;FQY
M(&)E('5S960@9F]R('1E;7!O<F%R>2!T97-T:6YG(&]F('EO=7(@;6%I;"!S
M97)V97(@;W(@:6X@:6YS=&%N8V5S('=H97)E('EO=2!A<F4@;W!E<F%T:6YG
M(%!L97-K(&9R;VT@:6YT97)N86P@;F5T=V]R:R!N;W0@86-C97-S:6)L92!V
M:6$@=&AE($EN=&5R;F5T+EQN7&Y!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M:V5E<"!T:&ES('-E='1I;F<_(BP*"2=M86EL7U]P;W`S)R`]/B`B4$]0,R(L
M"@DG;6%I;%]?<')E9F5R96YC97,G(#T^(")-86EL('!R969E<F5N8V5S(BP*
M"2=M86EL7U]R8FQ?>F]N97,G(#T^(")-05!3('IO;F5S(BP*"2=M86EL7U]R
M96QA>5]F<F]M7VEP)R`]/B`B5VAI=&4@3&ES="(L"@DG;6%I;%]?<F5L87EI
M;F<G(#T^(")296QA>6EN9R(L"@DG;6%I;%]?<F5Q<E]A=71H)R`]/B`B875T
M:&]R:7IA=&EO;B!I<R!R97%U:7)E9#H@(BP*"2=M86EL7U]S;71P)R`]/B`B
M4TU44"(L"@DG;6%I;%]?=6YA8FQE7V%D9%]N97=?;6%I;%]N86UE)R`]/B`B
M56YA8FQE('1O(&%D9"!N97<@;6%I;"!N86UE.B`E,2(L"@DG;6%I;%]?=VAI
M=&5?;&ES="<@/3X@(E=H:71E($QI<W0B+`H))VUA:6Q?7W=H:71E7VQI<W1?
M861D)R`]/B`G061D($YE=R!.971W;W)K)RP*"2=M86EL7U]W:&ET95]L:7-T
M7W)E;6]V92<@/3X@)U1H92!F;VQL;W=I;F<@;F5T=V]R:W,@=VEL;"!B92!R
M96UO=F5D.B<L"@DG;6%I;%]?=VAI=&5?;&ES=%]M96UB97(G(#T^("=!;&QO
M=V5D(&YE='=O<FMS)RP*"2=M86EL7U]W:&ET95]L:7-T7V5M<'1Y7W-E;&5C
M=&EO;E]F;W)?<F5M;W9E)R`]/B`G4V5L96-T('1H92!E;G1R:65S('1O(&)E
M(')E;6]V960N)RP*"2=M86EL7W%U975E7U]T;V]L<U]L96=E;F0G(#T^("=4
M;V]L<R<L"@DG;6%I;%]Q=65U95]?:6YF;U]L96=E;F0G(#T^("=);F9O)RP*
M"2=M86EL7W%U975E7U]M97-S86=E<U]L:7-T7VQE9V5N9"<@/3X@)TUE<W-A
M9V5S(&EN(&UA:6P@<75E=64G+`H))VUA:6Q?<75E=65?7W$G(#T^("=1)RP*
M"2=M86EL7W%U975E7U]S=6)J96-T)R`]/B`G4W5B:F5C="<L"@DG;6%I;%]Q
M=65U95]?96YV96QO<&5?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U
M975E7U]E;G9E;&]P95]R96-I<&EE;G1S)R`]/B`G4F5C:7!I96YT<R<L"@DG
M;6%I;%]Q=65U95]?9&%T92<@/3X@)T1A=&4G+`H))VUA:6Q?<75E=65?7V%G
M92<@/3X@)T%G92<L"@DG;6%I;%]Q=65U95]?<VEZ92<@/3X@)U-I>F4G+`H)
M)VUA:6Q?<75E=65?7VUE<W-A9V5S)R`]/B`G;65S<V%G97,G+`H))VUA:6Q?
M<75E=65?7VEN9F]?=&5X="<@/3X@)TUE<W-A9V5S(&EN('%U975E.B`E,2!N
M;W0@<')E<')O8V5S<V5D+"`E,B!L;V-A;"P@)3,@<F5M;W1E+"`E-"!T;W1A
M;"XG+`H))VUA:6Q?<75E=65?7W-E;&5C=%]?86QL)R`]/B`G06QL)RP*"2=M
M86EL7W%U975E7U]S96QE8W1?7W1O9&\G(#T^("=.;W0@4')E<')O8V5S<V5D
M)RP*"2=M86EL7W%U975E7U]S96QE8W1?7W)E;6]T92<@/3X@)U)E;6]T92<L
M"@DG;6%I;%]Q=65U95]?<V5L96-T7U]L;V-A;"<@/3X@)TQO8V%L)RP*"2=M
M86EL7W%U975E7U]S96QE8W1?7VQO8V%L7V%N9%]R96UO=&4G(#T^("=,;V-A
M;"!A;F0@4F5M;W1E)RP*"2=M86EL7W%U975E7U]Q=65U92<@/3X@)U%U975E
M<R<L"@DG;6%I;%]Q=65U95]?96YV96QO<&4G(#T^("=%;G9E;&]P92<L"@DG
M;6%I;%]Q=65U95]?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U975E
M7U]R96-I<&EE;G0G(#T^("=296-I<&EE;G0G+`H))VUA:6Q?<75E=65?7W-T
M87)T7V1A=&4G(#T^("=3=&%R="<L"@DG;6%I;%]Q=65U95]?96YD7V1A=&4G
M(#T^("=%;F0G+`H))VUA:6Q?<75E=65?7VUI;E]A9V4G(#T^("=-:6YI;75M
M)RP*"2=M86EL7W%U975E7U]M87A?86=E)R`]/B`G36%X:6UU;2<L"@DG;6%I
M;%]Q=65U95]?;6EN7W-I>F4G(#T^("=-:6YI;75M)RP*"2=M86EL7W%U975E
M7U]M87A?<VEZ92<@/3X@)TUA>&EM=6TG+`H))VUA:6Q?<75E=65?7V5M<'1Y
M7W-E;&5C=&EO;B<@/3X@)TYO(&UE<W-A9V5S('-E;&5C=&5D+B<L"@DG;6%I
M;%]Q=65U95]?<F5M;W9E7VUE<W-A9V5S7V-O;F9I<FTG(#T^("=$;R!Y;W4@
M<F5A;&QY('=A;G0@=&\@<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F
M<F]M('1H92!Q=65U93\G+`H))VUA:6Q?<75E=65?7VYO=%]A;&QO=V5D7V)Y
M7VQI8V5N<V5?:V5Y)R`]/B`G36%I;"!Q=65U92!M86YA9V5M96YT(&ES(&YO
M="!A;&QO=V5D(&)Y('1H92!L:6-E;G-E(&ME>2XG+`H))V)T7W-H;W=?861V
M86YC961?<V5A<F-H)R`]/B`G4VAO=R!!9'9A;F-E9"!396%R8V@G+`H))V)T
M7VAI9&5?861V86YC961?<V5A<F-H)R`]/B`G2&ED92!!9'9A;F-E9"!396%R
M8V@G+`H))VUA:6QL:7-T7U\G(#T^(")-86EL:6YG(&QI<W0@)3$B+`H))VUA
M:6QL:7-T7U]A;')E861Y7V5X:7-T<R<@/3X@(DUA:6QI;F<@;&ES="!A;')E
M861Y(&5X:7-T<RXB+`H))VUA:6QL:7-T7U]C<F5A=&5?;6%I;&QI<W1?9F]R
M)R`]/B`B0W)E871E(&$@;6%I;&EN9R!L:7-T(&9O<B!D;VUA:6X@)3$B+`H)
M)VUA:6QL:7-T7U]E;6%I;%]?)R`]/B`B36%I;&EN9R!L:7-T(&%D;6EN:7-T
M<F%T;W(G<R!E;6%I;"`E,2(L"@DG;6%I;&QI<W1?7VEN=F%L:61?96UA:6PG
M(#T^(")!9&UI;FES=')A=&]R)W,@96UA:6P@:7,@:6YV86QI9"(L"@DG;6%I
M;&QI<W1?7VEN=F%L:61?;F%M92<@/3X@(E1H92!M86EL:6YG(&QI<W0@;F%M
M92!I<R!I;G9A;&ED(BP*"2=M86EL;&ES=%]?:6YV97)T7V]N7V]F9C\G(#T^
M(")#:&%N9V4@=&AE('-T871E(&]F('-E;&5C=&5D(&UA:6QI;F<@;&ES=',_
M(BP*"2=M86EL;&ES=%]?:6YV97)T7V]N7V]F9E]O;F4_)R`]/B`B0VAA;F=E
M('1H92!S=&%T92!O9B!T:&4@;6%I;&EN9R!L:7-T/R(L"@DG;6%I;&QI<W1?
M7VUA:6Q?86QI87-?86QR96%D>5]E>&ES='-?:6Y?=&AI<U]D;VUA:6XG(#T^
M(")4:&4@;6%I;"!A;&EA<R`E,2!A;')E861Y(&5X:7-T<R!I;B!T:&ES(&1O
M;6%I;B(L"@DG;6%I;&QI<W1?7VYA;65?7R<@/3X@(DUA:6QI;F<@;&ES="!N
M86UE("4Q(BP*"2=M86EL;&ES=%]?;F5W7U\G(#T^(")#<F5A=&4@;F5W(&UA
M:6QI;F<@;&ES="`E,2(L"@DG;6%I;&QI<W1?7VYO=&EF>5]?)R`]/B`B3F]T
M:69Y(&%D;6EN:7-T<F%T;W(@;V8@=&AE(&UA:6QI;F<@;&ES="!C<F5A=&EO
M;B(L"@DG;6%I;&QI<W1S7U\G(#T^(")-86EL:6YG(&QI<W1S("4Q(BP*"2=M
M86EL;&ES='-?7VQI;6ET7V-L7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AE(&-L:65N="`H;&EM:70Z("4Q+"!U<V5D.B`E,BDB+`H))VUA
M:6QL:7-T<U]?;&EM:71?9&]M7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AE(&1O;6%I;BXB+`H))VUA:6QL:7-T<U]?;&ES="<@/3X@(DUA
M:6QI;F<@;&ES=',B+`H))VUA:6QL:7-T<U]?;&ES='-?;V9?9&]M86EN7U\G
M(#T^(")-86EL:6YG(&QI<W1S(&EN(&1O;6%I;B`E,2(L"@DG;6%I;&QI<W1S
M7U]M86EL;6%N7VYO=%]I;G-T86QL961?;W)?8V]N9B<@/3X@(EQN36%I;&UA
M;B!397)V97(@17AT96YS:6]N<R!A<F4@;F]T(&-U<G)E;G1L>2!I;G-T86QL
M960@;W(@8V]N9FEG=7)E9%QN;VX@=&AE('-E<G9E<BX@0V]N=&%C="!T:&4@
M<V5R=F5R(&%D;6EN:7-T<F%T;W(@=&\@:&%V92!T:&4@36%I;&UA;B!397)V
M97(@17AT96YS:6]N<R!I;G-T86QL960@;W(@<')O<&5R;'D@8V]N9FEG=7)E
M9"XB+`H))VUA:6QL:7-T<U]?<F5M;W9E7VUA:6QL:7-T<U]O;E]D;VUA:6XG
M(#T^(")296UO=FEN9R!M86EL:6YG(&QI<W1S(&9R;VT@9&]M86EN("4Q+B(L
M"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7VEN=F5R=%]O;E]O
M9F8G(#T^(")9;W4@<VAO=6QD('-E;&5C="!A="!L96%S="!O;F4@;6%I;&EN
M9R!L:7-T+B(L"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7W)E
M;6]V92<@/3X@(E-E;&5C="!T:&4@;6%I;&EN9R!L:7-T<R!T;R!B92!R96UO
M=F5D+B(L"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1S7W1O7W)E;6]V
M92<@/3X@(E-E;&5C="!O;F4@;W(@<V5V97)A;"!M86EL:6YG(&QI<W1S('1O
M(&)E(')E;6]V960N(BP*"2=M86EL;&ES='-?7W-T871U<R<@/3X@(DUA:6QI
M;F<@;&ES="!S97)V:6-E(&ES(&5N86)L960B+`H))VUA:6QL:7-T<U]?=6YA
M8FQE7W1O7V1E;&5T95]?)R`]/B`B56YA8FQE('1O(&1E;&5T92!T:&4@;6%I
M;&EN9R!L:7-T.B`E,2(L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT)R`]
M/B`G66]U(&-A;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C875S
M92!T:&4@36%I;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O<B!C
M;VYF:6=U<F5D+B<L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7V%D;6EN
M)R`]/B`G66]U(&-A;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C
M875S92!T:&4@36%I;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O
M<B!C;VYF:6=U<F5D+B!0;&5A<V4@=7-E('1H92!-86EL;6%N(&-O;F9I9W5R
M871I;VX@9G5N8W1I;VX@870@=&AE(%-E<G9E<B!!9&UI;FES=')A=&EO;B!0
M86=E+B<L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7W5S97(G(#T^("=9
M;W4@8V%N;F]T(&UA;F%G92!T:&4@;6%I;&EN9R!L:7-T<R!B96-A=7-E('1H
M92!-86EL;6%N(&-O;7!O;F5N="!I<R!N;W0@:6YS=&%L;&5D(&]R(&-O;F9I
M9W5R960N(%!L96%S92!C;VYT86-T('EO=7(@<V5R=F5R(&%D;6EN:7-T<F%T
M;W(@=&\@:&%V92!T:&4@36%I;&UA;B!I;G-T86QL960N)RP*"2=M86EL;&ES
M='-?8V]N9E]?<&%G95]T:71L92<@/3X@(D-O;F9I9W5R:6YG($UA:6QI;F<@
M3&ES=',@36%N86=E<B(L"@DG;6%I;&QI<W1S7V-O;F9?7W-U8V-E<W-F=6PG
M(#T^("=4:&4@36%I;&UA;B!S;V9T=V%R92!H87,@8F5E;B!S=6-C97-S9G5L
M;'D@8V]N9FEG=7)E9"P@<V\@=&AE(%-E="!5<"!-86EL;6%N(&)U='1O;B!W
M:6QL(&YO(&QO;F=E<B!B92!A8V-E<W-I8FQE(&9R;VT@=&AE(%-E<G9E<B!!
M9&UI;FES=')A=&EO;B!S8W)E96XN)RP*"2=M86EL;&ES=%]M96UB97)?961I
M=%]?=&ET;&4G(#T^(")!9&0@3F5W(%-U8G-C<FEB97(B+`H))VUA:6QL:7-T
M7VUE;6)E<G-?7W1I=&QE)R`]/B`G)3$@4W5B<V-R:6)E<G,G+`H))VUA:6QL
M:7-T7VUE;6)E<G-?7W-E;&5C=%]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!S=6)S8W)I8F5R<R!T;R!B92!R96UO=F5D+B(L"@DG;6%I;&QI<W1?;65M
M8F5R<U]R96UO=F5?7W1I=&QE)R`]/B`G4F5M;W9E(&UA:6QI;F<@;&ES="!S
M=6)S8W)I8F5R<R<L"@DG;6%I;&QI<W1?;65M8F5R7U]A;')E861Y7V5X:7-T
M<R<@/3X@)TUA:6QI;F<@;&ES="!S=6)S8W)I8F5R(&%L<F5A9'D@97AI<W1S
M+B<L"@DG;6%I;&QI<W1?;65M8F5R7U]N;W1?97AI<W1S)R`]/B`G5&AE<F4@
M:7,@;F\@<W5C:"!U<V5R(&]N('1H92!M86EL:6YG(&QI<W0N)RP*"2=M86YA
M9V5R7U]A8V-E<W-?9&5N:65D)R`]/B`B06-C97-S(&1E;FEE9#H@)3$B+`H)
M)VUA;F%G97)?7V%D;6EN)R`]/B`B061M:6YI<W1R871O<B(L"@DG;6%N86=E
M<E]?8VQI96YT)R`]/B`B0VQI96YT(BP*"2=M86YA9V5R7U]D;VUA:6XG(#T^
M(")$;VUA:6XB+`H))VUA;F%G97)?7V1O;6%I;E]C;%]L:6UI=%]E>&-E961I
M;F<G(#T^(")4:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1O;6%I;G,@:7,@<F5A
M8VAE9"!F;W(@=&AI<R!C;&EE;G0@86-C;W5N="(L"@DG;6%N86=E<E]?9&]M
M86EN7VES7VYO=%]Y;W5R<R<@/3X@(D1O;6%I;B`E,2!D;V5S(&YO="!B96QO
M;F<@=&\@>6]U(BP*"2=M86YA9V5R7U]D;VUA:6Y?:V5Y7VQI;6ET7V5X8V5E
M9&EN9R<@/3X@(E1H92!L:6UI="!O;B!D;VUA:6X@8W)E871I;VX@9&5F:6YE
M9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y(&ES(')E86-H960B+`H))VUA;F%G97)?
M7VYO7W!E<FU?=&]?8V%L;"<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@<&5R
M;6ES<VEO;B!T;R!C86QL("4Q(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O7V-R
M96%T95]D;VUA:6YS)R`]/B`B66]U(&1O(&YO="!H879E('1H92!P97)M:7-S
M:6]N('1O(&-R96%T92!D;VUA:6YS(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O
M7VUO9&EF>5]D;VUA:6XG(#T^(")9;W4@9&\@;F]T(&AA=F4@=&AE('!E<FUI
M<W-I;VX@=&\@;6]D:69Y(&1O;6%I;B`E,2(L"@DG;6%N86=E<E]?;F]?<&5R
M;5]T;U]M;V1I9GE?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@
M<&5R;6ES<VEO;B!T;R!M;V1I9GD@9&]M86EN<R(L"@DG;6%N86=E<E]?;F]?
M<&5R;5]T;U]R96UO=F5?9&]M86EN)R`]/B`B66]U(&1O(&YO="!H879E('1H
M92!P97)M:7-S:6]N('1O(')E;6]V92!D;VUA:6X@)3$B+`H))VUA;F%G97)?
M7VYO7W!E<FU?=&]?<F5M;W9E7V1O;6%I;G,G(#T^(")9;W4@9&\@;F]T(&AA
M=F4@=&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E(&1O;6%I;G,B+`H))VUA;F%G
M97)?7VYO9&5?9&]E<VYT7V5X:7-T)R`]/B`B)3$@9&]E<R!N;W0@97AI<W0B
M+`H))VUA;F%G97)?7W5S97)?9&ES86)L960G(#T^(")9;W5R(&%C8V]U;G0@
M:7,@9&ES86)L960N(%EO=2!C86YN;W0@;W!E<F%T92!T:&4@<WES=&5M+B(L
M"@DG;6)O>%]Q=6]T85]U;G-U<'!O<G1E9"<@/3X@(FYO="!S=7!P;W)T960@
M8GD@=&AE(&UA:6P@<V5R=F5R(BP*"2=M;E]?871T86-H7W)E;6]V92<@/3X@
M(E)E;6]V92!A='1A8VAM96YT<R(L"@DG;6Y?7V%T=&%C:%]S96QE8W1?9F]R
M7W)E;6]V92<@/3X@(E-E;&5C="!A='1A8VAM96YT<R!T;R!B92!R96UO=F5D
M+B(L"@DG;6Y?7V-R96%T95]T:71L92<@/3X@(D-R96%T92!M86EL(&YA;64B
M+`H))VUN7U]E9&ET7W1I=&QE)R`]/B`B4')E9F5R96YC97,B+`H))VUN7U]F
M:6QE<U]L:7-T7W1I=&QE)R`]/B`B071T86-H;65N="!&:6QE<R(L"@DG;6Y?
M7V9I;&5S7W)E;6]V92<@/3X@(E)E;6]V92!F:6QE<R!F<F]M(&%T=&%C:&UE
M;G1S(')E<&]S:71O<GDN(%1H:7,@9FEL97,@87)E('!O<W-I8FQY('5S960@
M8GD@875T;W)E<W!O;F1E<G,N(%1H97D@=VEL;"!B92!R96UO=F5D(&9R;VT@
M8F]T:#H@=&AE(')E<&]S:71O<GD@86YD(&%U=&]R97-P;VYD97)S('5S:6YG
M('1H96TN(BP*"2=M;E]?9FEL97-?<V5L96-T7V9O<E]R96UO=F4G(#T^(")3
M96QE8W0@9FEL97,@=&\@8F4@<F5M;W9E9"XB+`H))VUN7U]M86EL7V%L:6%S
M7V9O<FTG(#T^(")-86EL(&%L:6%S(&9O<FTB+`H))VUN7U]M86EL7V%L:6%S
M97-?;&ES="<@/3X@(DUA:6P@86QI87-E<R(L"@DG;6Y?7VUA:6QB;W@G(#T^
M(")-86EL8F]X(&UA;F%G96UE;G0B+`H))VUN7U]R961I<E]R96UO=F4G(#T^
M(")296UO=F4@;65M8F5R<R(L"@DG;6Y?7W)E9&ER7W-E;&5C=%]F;W)?<F5M
M;W9E)R`]/B`B4V5L96-T('1H92!M96UB97)S('1O(&)E(')E;6]V960N(BP*
M"2=M;E]?<F5S<%]R96UO=F4G(#T^(")296UO=F4@;6%I;"!A=71O<F5S<&]N
M9&5R<R(L"@DG;6Y?7W)E<W!?<V5L96-T7V9O<E]R96UO=F4G(#T^(")396QE
M8W0@=&AE(&%U=&]R97-P;VYD97)S('1O(&)E(')E;6]V960N(BP*"2=M;E]?
M<V5L96-T7V9I;&5S7V9O<E]A='1A8V@G(#T^(")396QE8W0@=&AE(&9I;&5S
M('1O(&)E(&%T=&%C:&5D+B(L"@DG;6Y?7W-E;&5C=%]M;E]F;W)?<F5M;W9E
M)R`]/B`B4V5L96-T('1H92!M86EL(&YA;65S('1O(&)E(')E;6]V960N(BP*
M"2=M;E]?=6YA8FQE7V1E9FEN95]M;B<@/3X@(E5N86)L92!T;R!D969I;F4@
M;6%I;"!N86UE<SH@)3$B+`H))VUN7U]U;F%B;&5?<F5M;W9E7VUB;WA?<75O
M=&$G(#T^(")5;F%B;&4@=&\@<F5S970@=&AE(&QI;6ET(&]N(&UA:6QB;W@@
M<VEZ93H@)3$B+`H))VUN7U]U<&QO861?9FEL92<@/3X@(E5P;&]A9"!F:6QE
M(BP*"2=M;E]E9&ET7U]A9&1?;6%I;%]G<F]U<%]M96UB97)S7V]R7W1U<FY?
M;V9F7V)O>"<@/3X@(EEO=2!S:&]U;&0@861D(&$@;6%I;"!G<F]U<"!M96UB
M97(@8F5F;W)E(&5N86)L:6YG('1H92!M86EL(&=R;W5P+B(L"@DG;6Y?961I
M=%]?861D7W)E<W!?;W)?='5R;E]O9F9?8F]X)R`]/B`B66]U('-H;W5L9"!A
M9&0@875T;W)E<W!O;F1E<B!O<B!D97-E;&5C="!T:&4@875T;W)E<W!O;F1E
M<B!C:&5C:V)O>"XB+`H))VUN7V5D:71?7V%T=&%C:&UE;G1S)R`]/B`B071T
M86-H;65N=',B+`H))VUN7V5D:71?7V1O;5]Q=6]T85]L97-S7W1H96Y?<75O
M=&$G(#T^(")4:&4@<VEZ92!O9B!T:&ES(&UA:6QB;W@@;75S="!N;W0@97AC
M965D('1H92!L:6UI="!O;B!A;6]U;G0@;V8@9&ES:R!S<&%C92!A;&QO8V%T
M960@9F]R(&AO=7-I;F<@;6%I;&)O>&5S(&EN('1H:7,@9&]M86EN+B(L"@DG
M;6Y?961I=%]?96YT97)?97AT97)N86Q?<F-P;G1?96UA:6PG(#T^(")%;G1E
M<B!E>'1E<FYA;"!M86EL(&=R;W5P(&UE;6)E<B=S(&4M;6%I;"(L"@DG;6Y?
M961I=%]?96YT97)?;6%I;%]R961I<E]O<E]T=7)N7V]F9E]B;W@G(#T^(")9
M;W4@<VAO=6QD(&5N=&5R(&$@;6%I;"!R961I<F5C="!O<B!D97-E;&5C="!T
M:&4@<F5D:7)E8W0@8VAE8VMB;W@N(BP*"2=M;E]E9&ET7U]E>'1?<F-P;G1?
M96UA:6Q?:6YV86QI9"<@/3X@(D5X=&5R;F%L(')E8VEP:65N="!E+6UA:6P@
M861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?9FEL95]E>&ES=',G
M(#T^(")&:6QE(&5X:7-T<RX@3W9E<G=R:71E/R(L"@DG;6Y?961I=%]?9FEL
M97-?9&5L9%]F<F]M7W)E<&]S:71O<GDG(#T^(")4:&5S92!F:6QE<R!W:6QL
M(&)E(&1E;&5T960@9G)O;2!R97!O<VET;W)Y(&%N9"!A=71O<F5S<&]N9&5R
M<R!C;VYT86EN:6YG('1H96TN($1O('EO=2!W86YT('1O('!R;V-E960_(BP*
M"2=M;E]E9&ET7U]M86EL7VYA;64G(#T^(")-86EL(&YA;64B+`H))VUN7V5D
M:71?7VUA:6Q?;F%M95]I;G9A;&ED)R`]/B`B36%I;"!N86UE(&ES(&EN=F%L
M:60N(BP*"2=M;E]E9&ET7U]M86EL7W)E9&ER)R`]/B`B36%I;"!R961I<F5C
M=',B+`H))VUN7V5D:71?7VUA:6Q?<F5D:7)?861D)R`]/B`B061D($UA:6P@
M1W)O=7`@365M8F5R(BP*"2=M;E]E9&ET7U]M86EL7W)E<W!S)R`]/B`B36%I
M;"!A=71O<F5S<&]N9&5R<R(L"@DG;6Y?961I=%]?;6%I;&)O>"<@/3X@(DUA
M:6QB;W@B+`H))VUN7V5D:71?7VUA:6QG<F]U<"<@/3X@(DUA:6P@9W)O=7`B
M+`H))VUN7V5D:71?7VUA:6QG<F]U<%]A9&1R97-S97,G(#T^(")-86EL(&=R
M;W5P(&UE;6)E<G,B+`H))VUN7V5D:71?7VUA:6QG<F]U<%]D:7-A8FQE9"<@
M/3X@(D%V86EL86)L92!O;FQY('=H96X@;6%I;"!N86UE(&ES(&%L<F5A9'D@
M861D960B+`H))VUN7V5D:71?7VUA>%]D;VU?<75O=&$G(#T^(")$969A=6QT
M(&9O<B!T:&4@9&]M86EN("@E,2DB+`H))VUN7V5D:71?7VUB;WA?<75O=&%?
M:6YV86QI9"<@/3X@(DEC;W)R96-T(&UA:6QB;W@@<VEZ92!S<&5C:69I960N
M(BP*"2=M;E]E9&ET7U]N97=?<F5S<%]N86UE)R`]/B`B3F5W(&%U=&]R97-P
M;VYD97(@;F%M92(L"@DG;6Y?961I=%]?;F]?875T;W)E<W!O;F1E<G,G(#T^
M(")9;W4@<VAO=6QD(&%D9"!A="!L96%S="!O;F4@875T;W)E<W!O;F1E<B!B
M969O<F4@='5R;FEN9R!T:&4@875T;W)E<W!O;F1E<B!S97)V:6-E(&]N+V]F
M9BXB+`H))VUN7V5D:71?7VYO7V9I;&5?<V5L)R`]/B`B3F\@9FEL97,@<V5L
M96-T960N(BP*"2=M;E]E9&ET7U]N;U]M86EL7V%D9')E<W-E<R<@/3X@(DYO
M(&4M;6%I;"!A9&1R97-S97,@:&%V92!B965N(&5N=&5R960@;W(@<V5L96-T
M960N(BP*"2=M;E]E9&ET7U]N;VYE)R`]/B`B3F]N92(L"@DG;6Y?961I=%]?
M;F]T7V-R96%T95]P87-S)R`]/B`B5&AI<R!W:6QL(&YO="!C<F5A=&4@82!P
M87-S=V]R9"!F;W(@=&AI<R!A8V-O=6YT+EQN5VET:&]U="!P87-S=V]R9"P@
M=7-E<B!W:6QL(&YO="!B92!A8FQE('1O('9I97<@86YD+V]R('-E;F0@;6%I
M;"XB+`H))VUN7V5D:71?7W)E9&ER7V5M86EL7VEN=F%L:60G(#T^(")2961I
M<F5C="!E+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?
M<F5D:7)E8W0G(#T^(")2961I<F5C="(L"@DG;6Y?961I=%]?<F5D:7)E8W1?
M861D<B<@/3X@(E)E9&ER96-T(&%D9')E<W,B+`H))VUN7V5D:71?7W)E;6]V
M95]A=71O<F5S<#\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!A=71O<F5S<&]N9&5R/R(L"@DG;6Y?961I=%]?<F5M;W9E7W)C
M<&YT<S\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M97-E(')E8VEP:65N=',_(BP*"2=M;E]E9&ET7U]R97!O<VET;W)Y)R`]/B`B
M4F5P;W-I=&]R>2(L"@DG;6Y?961I=%]?<F5S<'-?871T86-H)R`]/B`B075T
M;W)E<W!O;F1E<B!A='1A8VAM96YT(&9I;&5S(BP*"2=M;E]E9&ET7U]S96QE
M8W1?<F-P;G1?9G)O;5]L:7-T)R`]/B`B4V5L96-T(&%T(&QE87-T(&]N92!R
M96-I<&EE;G0@9G)O;2!T:&4@;&ES="!T;R!R96UO=F4@:70N(BP*"2=M;E]E
M9&ET7U]S96QE8W1?<F5G:7-T97)E9%]U<V5R<R<@/3X@(E-E;&5C="!R96=I
M<W1E<F5D('5S97)S(BP*"2=M;E]E9&ET7U]S96QE8W1E9%]P;W-T8F]X7VAA
M=F5?;F]T7W-E='5P7W!A<W-W9"<@/3X@(EEO=2!H879E(&-H;W-E;B!T;R!H
M879E(&$@;6%I;&)O>"!B=70@:&%V92!N;W0@<V5T('5P('1H92!P87-S=V]R
M9"!F;W(@:70N(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7VUA:6Q?
M9W)O=7`G(#T^(")5;F%B;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!M86EL
M(&=R;W5P.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7V%C=%]D96%C=%]M86EL
M7W)E9&ER)R`]/B`B56YA8FQE('1O(&%C=&EV871E+V1E86-T:79A=&4@;6%I
M;"!R961I<F5C=#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]A8W1?9&5A8W1?
M<&]S=&)O>"<@/3X@(E5N86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E(&UA
M:6QB;W@Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7W)E<W`G
M(#T^(")5;F%B;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!A=71O<F5S<&]N
M9&5R<SH@)3$B+`H))VUN7V5D:71?7W5N86)L95]A9&1?871T86-H)R`]/B`B
M56YA8FQE('1O(&%D9"!A='1A8VAM96YT(&9I;&4Z("4Q(BP*"2=M;E]E9&ET
M7U]U;F%B;&5?861D7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O
M(&%D9"!M86EL(&=R;W5P(&UE;6)E<CH@)3$B+`H))VUN7V5D:71?7W5N86)L
M95]A9&1?<F5S<"<@/3X@(E5N86)L92!T;R!A9&0@875T;W)E<W!O;F1E<CH@
M)3$B+`H))VUN7V5D:71?7W5N86)L95]C:&%N9V5?;6%I;%]N86UE)R`]/B`B
M56YA8FQE('1O(&-H86YG92!M86EL(&YA;64Z("4Q(BP*"2=M;E]E9&ET7U]U
M;F%B;&5?9&5A8W1I=F%T95]M86EL7V=R;W5P)R`]/B`B56YA8FQE('1O(&1E
M86-T:79A=&4@;6%I;"!G<F]U<#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]D
M96%C=&EV871E7W)E<W`G(#T^(")5;F%B;&4@=&\@9&5A8W1I=F%T92!M86EL
M(&%U=&]R97-P;VYD97)S.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7V1E9FEN
M95]R97-P7VED)R`]/B`B56YA8FQE('1O(&1E9FEN92!A=71O<F5S<&]N9&5R
M(&ED.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7W)E;6]V95]A='1A8V@G(#T^
M(")5;F%B;&4@=&\@<F5M;W9E(&%T=&%C:&UE;G0@9FEL92AS*3H@)3$B+`H)
M)VUN7V5D:71?7W5N86)L95]R96UO=F5?875T;W)E<W`G(#T^(")5;F%B;&4@
M=&\@<F5M;W9E(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B
M;&5?<F5M;W9E7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O(')E
M;6]V92!M86EL(&=R;W5P(&UE;6)E<G,Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B
M;&5?<V5T=7!?;6%I;%]R961I<B<@/3X@(E5N86)L92!T;R!S970@=7`@;6%I
M;"!R961I<F5C="!A9&1R97-S.B`E,2(L"@DG;6Y?961I=%]?=W)O;F=?=V%Y
M)PD)"3T^("=4:&4@;65S<V%G97,@861D<F5S<V5D('1O("4Q('=I;&P@;F]T
M(&)E(&1E;&EV97)E9"P@87,@=&AE(&UA:6P@;F%M92!I<R!N96ET:&5R(&$@
M;6%I;&)O>"P@;F]R(')E9&ER96-T+"!M86EL(&=R;W5P+"!O<B!A=71O<F5S
M<&]N9&5R+B<L"@DG;6Y?;&ES=%]?;6%I;%]N86UE<U]F;W)?9&]M86EN)R`]
M/B`B36%I;"!N86UE<R!F;W(@9&]M86EN("4Q(BP*"2=M;E]L:7-T7U]S85]C
M86YN;W1?=6YA8FQE)R`]/B`B0V%N;F]T(&5N86)L92!S<&%M(&9I;'1E<FEN
M9R(L"@DG;6Y?;&ES=%]?=&%B7V-P7V%C8V5S<R<@/3X@(DPB+`H))VUN7VQI
M<W1?7W1A8E]T:71L95]C;&EE;G0G(#T^("=#;&EE;G0G+`H))VUN7VQI<W1?
M7W1A8E]T:71L95]D;VUA:6XG(#T^("=$;VUA:6XG+`H))VUN7VQI<W1?7W1A
M8E]T:71L95]A=71O<F5S<"<@/3X@(D$B+`H))VUN7VQI<W1?7W1A8E]T:71L
M95]B;W@G(#T^(")"(BP*"2=M;E]L:7-T7U]T86)?=&ET;&5?9W)O=7`G(#T^
M(")'(BP*"2=M;E]L:7-T7U]T86)?=&ET;&5?;F%M92<@/3X@(DYA;64B+`H)
M)VUN7VQI<W1?7W1A8E]T:71L95]R961I<F5C="<@/3X@(E(B+`H))VUN7VQI
M<W1?7W1A8E]T:71L95]S<&%M9FEL=&5R)R`]/B`B4R(L"@DG;6Y?;&ES=%]?
M=&%B7W1I=&QE7V1R=V5B)R`]/B`G058G+`H))VUN7VQI<W1?7W5N86)L95]R
M96UO=F5?;6YS)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@;6%I;"!N86UE
M<SH@)3$B+`H*"2=M;V1S7VUA;F%G7U]T:71L92<)"0D)/3X@)TUO9'5L97,@
M;6%N86=E;65N="<L"@DG;6]D<U]M86YA9U]?96UP='E?<V5L96-T:6]N7V9O
M<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&UO9'5L97,@=&\@8F4@<F5M;W9E
M9"XG+`H))VUO9'-?;6%N86=?7V-A;E]N;W1?<F5M;W9E)PD]/B`G56YA8FQE
M('1O(')E;6]V92!M;V1U;&4@)3$Z("4R)RP*"2=M;V1S7W)E;6]V95]?=&ET
M;&4G"0D)/3X@)TUO9'5L92!R96UO=F%L)RP*"2=M;V1U;&5?=7!L;V%D7U]T
M:71L92<@/3X@)U5P;&]A9"!.97<@36]D=6QE)RP*"2=M;V1U;&5?=7!L;V%D
M7U]F:6QE7VYA;64G"3T^("=0871H('1O('1H92!M;V1U;&4@<&%C:V%G92!F
M:6QE)RP*"2=M;V1U;&5?=7!L;V%D7U]M;V1U;&5?=V%S7VEN<W1A;&QE9"<@
M/3X@)U1H:7,@;6]D=6QE(&ES(&%L<F5A9'D@:6YS=&%L;&5D+B!)9B!Y;W4@
M=VES:"!T;R!I;G-T86QL(&$@;F5W97(@=F5R<VEO;B!O9B!T:&ES(&UO9'5L
M92P@<&QE87-E(&1E:6YS=&%L;"!T:&4@;6]D=6QE('1H<F]U9V@@=&AE(&-O
M;G1R;VP@<&%N96PL(&%N9"!T:&5N('1R>2!I;G-T86QL:6YG+B<L"@DG;6]D
M=6QE7W5P;&]A9%]?=6YA8FQE7W1O7VEN<W1A;&PG"3T^("=5;F%B;&4@=&\@
M:6YS=&%L;"!T:&4@;6]D=6QE('!A8VMA9V4@9FEL92<L"@H))VUP8U]?=6YA
M8FQE7V)U>5]C97)T7W5N86)L95]G96YE<F%T95]C<W(G(#T^(")5;F%B;&4@
M=&\@<'5R8VAA<V4@82!C97)T:69I8V%T93H@=6YA8FQE('1O(&=E;F5R871E
M('1H92!#4U(Z("4Q(BP*"2=M<&-?7W5N86)L95]B=7E?8V5R=%]U;F%B;&5?
M<W1O<F5?<')I=F%T95]K97DG(#T^(")5;F%B;&4@=&\@<'5R8VAA<V4@82!C
M97)T:69I8V%T93H@=6YA8FQE('1O('-T;W)E('1H92!P<FEV871E(&ME>3H@
M)3$B+`H))VYE=W-?87)T:6-L97-?=&ET;&4G(#T^("=0;&5S:R!.97=S)RP*
M"2=N879?7V-U<W1O;5]B=71T;VYS)R`]/B`G0W5S=&]M)RP*"2=N879?7V=E
M;F5R86PG(#T^("='96YE<F%L)RP*"2=N879?7W-Y<W1E;2<@/3X@)U-Y<W1E
M;2<L"@DG;F%V7U]H96QP7V%N9%]S=7!P;W)T)R`]/B`G2&5L<"`F(%-U<'!O
M<G0G+`H))VYO7W!S85]M86EL<U]M871C:&5D)R`]/B`B3F\@;6%I;"!A8V-O
M=6YT<R!M871C:&EN9R!Y;W5R(&-R:71E<FEA(BP*"2=N;W1I9FEC871I;VY?
M=&5X=%]?:6YV86QI9%]T97AT7VQE;F=T:"<@/3X@(DEN=F%L:60@;F]T:6-E
M('1E>'0@;&5N9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O(#8U-3,S(&-H87)A
M8W1E<G,N(BP*"2=N;W1I9FEC871I;VY?=&5X=%]?=&5X="<@/3X@(DYO=&EC
M92!T97AT(BP*"2=N;W1I9FEC871I;VY?=&5X=%]?=&ET;&4G(#T^(")%9&ET
M(&YO=&EC92(L"@DG;F]T:69I8V%T:6]N7W1E>'1?7W5N86)L95]S971?=&5X
M="<@/3X@(E5N86)L92!T;R!M;V1I9GD@;F]T:6-E('1E>'0Z("(L"@DG;F]T
M:69I8V%T:6]N<U]?=6YA8FQE7W1O7W5P9&%T92<@/3X@(E5N86)L92!T;R!U
M<&1A=&4@;F]T:69I8V%T:6]N.B`E,2(L"@DG;V1B8U]?8V%N=%]A9&1?9'-N
M)R`]/B`B56YA8FQE('1O(&%D9"!$4TX@)3$Z("4R(BP*"2=O9&)C7U]C86YT
M7V)U:6QD7V-O;FYE8W1I;VY?<W1R:6YG)R`]/B`B56YA8FQE('1O(&-O;FYE
M8W0@=7-I;F<@=&AE('!A<F%M971E<G,@<W!E8VEF:65D+"!P;&5A<V4@=')Y
M(&%G86EN('5S:6YG(&1I9F9E<F5N="!P87)A;65T97)S+B!5=&EL:71Y(&AA
M<R!R971U<FYE9#H@)3$B+`H))V]D8F-?7V-A;G1?8V]N;F5C="<@/3X@(E5N
M86)L92!T;R!C;VYN96-T('1O('1H92!D871A('-O=7)C92!U<VEN9R!T:&4@
M9&5F:6YE9"!S971T:6YG<RX@4V5R=F5R(&AA<R!R971U<FYE9#H@)3$B+`H)
M)V]D8F-?7V-A;G1?9&5L971E7V1S;B<@/3X@(E5N86)L92!T;R!D96QE=&4@
M1%-.("4Q.B`E,B(L"@DG;V1B8U]?8V%N=%]G971?9')I=F5R<R<@/3X@(E5N
M86)L92!T;R!R971R:65V92!A(&QI<W0@;V8@3T1"0R!D<FEV97)S.B`E,2(L
M"@DG;V1B8U]?8V%N=%]G971?;&ES="<@/3X@(E5N86)L92!T;R!R971R:65V
M92!A(&QI<W0@;V8@97AI<W1I;F<@1%-.<SH@)3$B+`H))V]D8F-?7V-A;G1?
M<&%R<V5?<W1R:6YG)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!C;VYN96-T
M:6]N('-T<FEN9R(L"@DG;V1B8U]?8V]N;F5C=%]S=6-C97-S)R`]/B`B0V]N
M;F5C=&EO;B!S=6-C97-S9G5L(BP*"2=O9&)C7U]D<FEV97)?;F]T7W-E="<@
M/3X@(D1R:79E<B!I<R!N;W0@<V5T(BP*"2=O9&)C7U]D<FEV97)?;W)?;F%M
M95]N;W1?<V5T)R`]/B`B1')I=F5R(&]R(&YA;64@;V8@=&AE($]$0D,@8V]N
M;F5C=&EO;B!W97)E(&YO="!S970B+`H))V]D8F-?7V1S;E]A;')E861Y7V5X
M:7-T<R<@/3X@(D133B!W:71H('1H:7,@;F%M92`H)3$I(&%L<F5A9'D@97AI
M<W1S(&EN('1H92!S>7-T96TB+`H))V]D8F-?7V1S;E]N;W1?97AI<W1S)R`]
M/B`B5&AI<R!$4TX@9&]E<R!N;W0@97AI<W0B+`H))V]D8F-?7V5N=&5R7V-O
M;FYE8W1I;VY?<&%R86US)R`]/B`B66]U('-H;W5L9"!S<&5C:69Y('1H92!O
M<'1I;VYS('1O(&)E('5S960@8GD@=&AE(&1R:79E<BX@069T97(@>6]U(&AA
M=F4@<W5P<&QI960@86QL('1H92!R97%U:7)E9"!D871A+"!Y;W4@=VEL;"!N
M965D('1O(&-L:6-K($9I;FES:"!I;B!O<F1E<B!T;R!C;VUP;&5T92!T:&4@
M3T1"0R!$4TX@8V]N9FEG=7)A=&EO;BXB+`H))V]D8F-?7V5N=&5R7V1S;E]N
M86UE)R`]/B`B16YT97(@1%-.(&YA;64B+`H))V]D8F-?7VEN=F%L:61?9'-N
M7VYA;64G(#T^(")7<F]N9R!S>6YT87@@9F]R($]$0D,@8V]N;F5C=&EO;B!N
M86UE("@E,2DZ('!L96%S92!U<V4@;VYL>2!A;'!H86YU;65R:6,@<WEM8F]L
M<RXB+`H))V]D8F-?7VYO7W-U8VA?9')I=F5R)R`]/B`B3T1"0R!D<FEV97(@
M=VET:"!S=6-H(&YA;64@*"4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*"2=O9&)C
M7U]R96UO=F5?<&%G95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@3T1"0R!$
M4TX@8V]N;F5C=&EO;G,@=VEL;"!B92!R96UO=F5D.B(L"@DG;V1B8U]?<V5L
M96-T7V1S;E]T;U]R96UO=F4G(#T^(")396QE8W0@1%-.<R!T;R!B92!R96UO
M=F5D+B(L"@DG;V1B8U]A9&1?;F5W)R`]/B`B061D(&YE=R!$4TX@8V]N;F5C
M=&EO;B(L"@DG;V1B8U]D<FEV97(G(#T^(")$<FEV97(B+`H))V]D8F-?9'-N
M7V1E<V-R:7!T:6]N)R`]/B`B0V]N;F5C=&EO;B!D97-C<FEP=&EO;B(L"@DG
M;V1B8U]D<VY?;&ES="<@/3X@(D]$0D,@1%-.(&-O;FYE8W1I;VYS(BP*"2=O
M9&)C7V1S;E]N86UE)R`]/B`B0V]N;F5C=&EO;B!N86UE(BP*"2=O9&)C7V1S
M;E]S>7-T96TG(#T^(")3>7-T96T@1%-.(BP*"2=O9&)C7V1S;E]T97AT)R`]
M/B`B3T1"0R!$4TXB+`H))V]D8F-?<F5Q7V9I96QD7VYO=%]S970G(#T^(")2
M97%U:7)E9"!P87)A;65T97)S(&%R92!N;W0@<W5P<&QI960N(BP*"2=P8E]?
M86QI87-E<R<@/3X@(D%L:6%S97,B+`H))W!B7U]A;F]N9G1P)R`]/B`B06YO
M;GEM;W5S($944"(L"@DG<&)?7V%U=&]I;G-T86QL97)?<F5L96%S97,G(#T^
M("=5<&1A=&5R)RP*"2=P8E]?8V5R="<@/3X@(D-E<G1I9FEC871E<R(L"@DG
M<&)?7V-L7W!O;VPG(#T^("))4"!A9&1R97-S97,B+`H))W!B7U]C;%]P;V]L
M7V-T<FPG(#T^("(E,2(L"@DG<&)?7V-L7W!R968G(#T^(")0<F5F97)E;F-E
M<R(L"@DG<&)?7V-L7W)P="<@/3X@(E)E<&]R="(L"@DG<&)?7V-L7W)P=%]L
M:7-T)R`]/B`B0W5S=&]M:7IE(BP*"2=P8E]?8VQ?=&5M<&QA=&5S)R`]/B`B
M0VQI96YT('1E;7!L871E<R(L"@DG<&)?7V-L7W1R869F:6,G(#T^(")4<F%F
M9FEC(BP*"2=P8E]?8VQ?=')A9F9I8U]H:7-T;W)Y)R`]/B`B5')A9F9I8R!H
M:7-T;W)Y(BP*"2=P8E]?8VQ?=')A9F9I8U]O9B<@/3X@(E1R869F:6,@;V8@
M)3$B+`H))W!B7U]C;&EE;G0G(#T^("(E,2(L"@DG<&)?7V-L:65N=',G(#T^
M(")#;&EE;G1S(BP*"2=P8E]?8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT(&EN
M9F\B+`H))W!B7U]C;VUM;VY?86-L)R`]/B`G06QL;W<@5')A;G-F97(@04-,
M)RP*"2=P8E]?8W!?86-C97-S)R`]/B`B06-C97-S(BP*"2=P8E]?8W)O;G1A
M8B<@/3X@(E-C:&5D=6QE<B(L"@DG<&)?7V-U<W1O;5]B=71T;VYS)R`]/B`B
M0W5S=&]M($)U='1O;G,B+`H))W!B7U]D8B<@/3X@(D1A=&%B87-E<R(L"@DG
M<&)?7V1B7V5D:70G(#T^("(E,2(L"@DG<&)?7V1B7W-E<G9E<E]E9&ET)R`]
M/B`G)3$G+`H))W!B7U]D8E]S97)V97)S)R`]/B`G1&%T86)A<V4@<V5R=F5R
M<R<L"@DG<&)?7V1L7W5S<E]E9"<@/3X@(D1O;6%I;B!A9&UI;FES=')A=&]R
M(BP*"2=P8E]?9&YS)R`]/B`B1$Y3(BP*"2=P8E]?9&YS7W1E;7!L871E)R`]
M/B`B1$Y3(BP*"2=P8E]?9&YS7W0G(#T^(")$3E,B+`H))W!B7U]D;VU?8W1R
M;"<@/3X@(B4Q(BP*"2=P8E]?9&]M7VQI;2<@/3X@(D1O;6%I;B!L:6UI=',B
M+`H))W!B7U]D;VU?<')E9B<@/3X@(E!R969E<F5N8V5S(BP*"2=P8E]?9&]M
M7W-U;5]R97!O<G0G(#T^(")$;VUA:6X@4W5M;6%R>2!297!O<G0B+`H))W!B
M7U]D;VU?=&5M<&QA=&5S)R`]/B`B1&]M86EN(%1E;7!L871E<R(L"@DG<&)?
M7V1O;5]T<F%F9FEC)R`]/B`B5')A9F9I8R!O9B`E,2(L"@DG<&)?7V1O;5]T
M<F%F9FEC7VAI<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))W!B7U]D
M;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<&)?7V1U;7!S7VQI<W0G(#T^(")"
M86-K=7`@1FEL97,@4F5P;W-I=&]R>2(L"@DG<&)?7V5V96YT7VAA;F1L97)S
M)R`]/B`G179E;G0@;6%N86=E<B<L"@DG<&)?7V9O<G=A<F1I;F=?<V5T=7`G
M(#T^(")&;W)W87)D:6YG(%-E='5P(BP*"2=P8E]?9FEL96UA;F%G97(G(#T^
M(")&:6QE($UA;F%G97(B+`H))W!B7U]G;&]B86QC:&%N9V5S)R`]/B`B1W)O
M=7`@3W!E<F%T:6]N<R(L"@DG<&)?7VEP7V%L:6%S:6YG)R`]/B`B25`@061D
M<F5S<V5S(BP*"2=P8E]?:7!?9&]M86EN<R<@/3X@(D1O;6%I;G,B+`H))W!B
M7U]I<%]C;&EE;G1S)R`]/B`B25`@061D<F5S<V5S(')E;6]V86PB+`H))W!B
M7U]L:6-E;G-E7VUA;F%G96UE;G0G(#T^("=,:6-E;G-E($UA;F%G96UE;G0G
M+`H))W!B7U]L;V-A;&5S)R`]/B`G3&]C86QE<R<L"@DG<&)?7VQO9U]F:6QE
M<R<@/3X@(DQO9R!F:6QE<R(L"@DG<&)?7VUA:6PG(#T^("=-86EL)RP*"2=P
M8E]?;6%I;%]B;&]C:V5D7V1O;6%I;G,G(#T^("=";&%C:R!L:7-T)RP*"2=P
M8E]?;6%I;%]N86UE7V9I;&5S)R`]/B`B071T86-H;65N="!F:6QE<R(L"@DG
M<&)?7VUA:6Q?;F%M95]E9&ET)R`]/B`B)3$B+`H))W!B7U]M86EL7VYA;65?
M;6%I;%]G<F]U<"<@/3X@(DUA:6P@9W)O=7`B+`H))W!B7U]M86EL7VYA;65?
M<F5D:7)E8W1S)R`]/B`B4F5D:7)E8W1S(BP*"2=P8E]?;6%I;%]N86UE7W)E
M<W!?871T86-H7V%D9"<@/3X@(DYE=R!A='1A8VAM96YT(BP*"2=P8E]?;6%I
M;%]N86UE7W)E<W!?961I="<@/3X@(B4Q(BP*"2=P8E]?;6%I;%]N86UE7W)E
M<W!O;F1E<G,G(#T^(")!=71O<F5S<&]N9&5R<R(L"@DG<&)?7VUA:6Q?;F%M
M97,G(#T^(")-86EL(BP*"2=P8E]?;6%I;%]W:&ET95]L:7-T)R`]/B`G5VAI
M=&4@;&ES="<L"@DG<&)?7VUA:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B
M+`H))W!B7U]M;V1U;&5S)R`]/B`G36]D=6QE<R<L"@DG<&)?7VUO9'5L97-?
M;6%N86=E;65N="<@/3X@)TUA;F%G92!-;V1U;&5S)RP*"2=P8E]?;F]T:69I
M8V%T:6]N<R<@/3X@(DYO=&EF:6-A=&EO;G,B+`H))W!B7U]O9&)C)R`]/B`B
M3T1"0R(L"@DG<&)?7W!H;W-T:6YG7W-E='5P)R`]/B`B4&AY<VEC86P@:&]S
M=&EN9R!S971U<"(L"@DG<&)?7W!R=&1?9&ER<R<@/3X@(E!R;W1E8W1E9"!D
M:7)E8W1O<FEE<R(L"@DG<&)?7W!R=&1I<E]E9&ET)R`]/B`B)3$B+`H))W!B
M7U]R97!O<G0G(#T^(")297!O<G0B+`H))W!B7U]R97!O<G1?875T;R<@/3X@
M(D1E;&EV97)Y('-C:&5D=6QE(&9O<B`E,2(L"@DG<&)?7W)E<&]R=%]L:7-T
M)R`]/B`B0W5S=&]M:7IE(BP*"2=P8E]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*
M"2=P8E]?<V5R=F5R7VEN9F\G(#T^(")3;&%V92!S97)V97(@:6YF;W)M871I
M;VXB+`H))W!B7U]S97)V97)?=')A9F9I8R<@/3X@(E-E<G9E<B!T<F%F9FEC
M(BP*"2=P8E]?<V5R=F5R<U]L:7-T)R`]/B`B4VQA=F4@<V5R=F5R(&%C8V]U
M;G1S(BP*"2=P8E]?<V5S<VEO;G,G(#T^(")397-S:6]N<R(L"@DG<&)?7W-A
M<'!?<&]O;"<@/3X@(D%P<&QI8V%T:6]N(%!O;VPB+`H))W!B7U]S:71E87!P
M7VEN<W1A;&PG(#T^(")3:71E($%P<&QI8V%T:6]N($EN<W1A;&QA=&EO;B(L
M"@DG<&)?7W-I=&5?87!P7W!K9W,G(#T^(")3:71E($%P<&QI8V%T:6]N(%!A
M8VMA9V5S(BP*"2=P8E]?<VET95]A<'!S)R`]/B`B4VET92!!<'!L:6-A=&EO
M;G,B+`H))W!B7U]A9&1I=&EO;F%L7VME>5]I;F9O)R`]/B`G2V5Y(%!R;W!E
M<G1I97,G+`H))W!B7U]A9&1I=&EO;F%L7VME>5]P<F]P97)T:65S)R`]/B`G
M2V5Y(%!R;W!E<G1I97,G+`H))W!B7U]S:V5L971O;B<@/3X@(E-K96QE=&]N
M($UA;F%G96UE;G0B+`H))W!B7U]S:VEN<R<@/3X@)U-K:6YS)RP*"2=P8E]?
M<VMI;E]I;F9O)R`]/B`G)3$G+`H))W!B7U]S<&%M87-S87-S:6XG(#T^(")3
M<&%M07-S87-S:6XB+`H))W!B7U]S=&%T:7-T:6-S)R`]/B`B4W1A=&ES=&EC
M<R(L"@DG<&)?7W-U8F1O;6%I;G,G(#T^(")3=6)D;VUA:6YS(BP*"2=P8E]?
M=&5M<&QA=&5S)R`]/B`B5&5M<&QA=&5S(BP*"2=P8E]?=&EC:V5T<R<@/3X@
M(E1I8VME=',B+`H))W!B7U]T=',G(#T^(")4:6-K971S(BP*"2=P8E]?=V5B
M7V%P<',G(#T^(")4;VUC870B+`H))W!B7U]W96)?=7-E<G,G(#T^(")796(@
M=7-E<G,B+`H))W!B7U]W96)A;&EZ97)?<')E9F5R96YC97,G(#T^("=796(@
M4W1A=&ES=&EC<R!0<F5F97)E;F-E<R<L"@DG<&1I<E]?96YT97)?9&ER7VYA
M;64G(#T^(")%;G1E<B!D:7)E8W1O<GD@;F%M92XB+`H))W!D:7)?7VEN=F%L
M:61?:'-T)R`]/B`B2&]S=&EN9R!T>7!E(&ES(&EN=F%L:60N($UU<W0@8F4@
M<&AY<VEC86PN(BP*"2=P9&ER7U]P9%]I9%]I<U]U;F1E9FEN960G(#T^(")0
M<F]T96-T960@9&ER96-T;W)Y(&ED(&ES('5N9&5F:6YE9"XB+`H))W!D:7)?
M7W!D:7)?97AI<W0G(#T^(")$:7)E8W1O<GD@=VET:"!T:&ES(&YA;64@:7,@
M86QR96%D>2!P<F]T96-T960N(BP*"2=P9&ER7U]P9&ER7VYO=%]E>&ES="<@
M/3X@(E!R;W1E8W1E9"!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(BP*"2=P
M9&ER7U]P9&ER7W5S<E]N;W1?97AI<W0G(#T^(")0<F]T96-T960@9&ER96-T
M;W)Y('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=P9&ER7U]P<F1I<G-?9F]R
M7V1O;6%I;B<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<FEE<R!F;W(@9&]M86EN
M("4Q(BP*"2=P9&ER7U]R96UO=F5?<&1I<E]U<W)S)R`]/B`B5&AE(&9O;&QO
M=VEN9R!U<V5R<R!O9B!P<F]T96-T960@9&ER96-T;W)Y("4R(&EN(&1O;6%I
M;B`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=P9&ER7U]R96UO=F5?<&1I<G-?
M;VY?9&]M)R`]/B`B5&AI<R!O<&5R871I;VX@=VEL;"!R97-U;'0@:6X@<F5M
M;W9I;F<@<')O=&5C=&EO;B!F<F]M('1H92!D:7)E8W1O<FEE<R!O9B!D;VUA
M:6X@)3(@;W=N960@8GD@8VQI96YT("4Q+"!T:&4@9&ER96-T;W)I97,@=&AE
M;7-E;'9E<R!W:6QL(&YO="!B92!E<F%S960N(BP*"2=P9&ER7U]S96QE8W1?
M<&1I<E]U<W)S7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE('!R;W1E8W1E
M9"!D:7)E8W1O<GD@=7-E<G,@=&\@8F4@<F5M;W9E9"XB+`H))W!D:7)?7W-E
M;&5C=%]P9&ER<U]T;U]R96UO=F4G(#T^(")396QE8W0@=&AE(&1I<F5C=&]R
M:65S('1O(')E;6]V92!P<F]T96-T:6]N(&9R;VTN(BP*"2=P9&ER7U]U;F%B
M;&5?9&5F:6YE7W!D:7)?=7-E<G,G(#T^(")5;F%B;&4@=&\@9&5F:6YE('1H
M92!P<F]T96-T960@9&ER96-T;W)Y('5S97)S+B(L"@DG<&1I<E]?=6YA8FQE
M7V1E9FEN95]P9&ER<U]P<F]P97)T:65S)R`]/B`B56YA8FQE('1O('-E="!T
M:&4@<')O=&5C=&5D(&1I<F5C=&]R:65S)R!P<F]P97)T:65S.B`E,2(L"@DG
M<&1I<E]?=6YA8FQE7W-E;&5C=%]D;VU?<&%R86TG(#T^(")5;F%B;&4@=&\@
M<V5L96-T(&1O;6%I;B!P87)A;65T97)S.B`E,2(L"@DG<&1I<E]E9%]?8W)E
M871E7W!D:7)?9F]R7V1O;6%I;B<@/3X@(D-R96%T92!N97<@<')O=&5C=&5D
M(&1I<F5C=&]R>2!O;B!D;VUA:6X@)3$B+`H))W!D:7)?961?7V1I<E]A;')E
M861Y7W!R;W1E8W0G(#T^(")4:&ES(&1I<F5C=&]R>2!I<R!A;')E861Y('!R
M;W1E8W1E9"XB+`H))W!D:7)?961?7VAE861?='AT)R`]/B`B2&5A9&5R(%1E
M>'0B+`H))W!D:7)?961?7VEN=F%L:61?;&]G:6XG(#T^(")5<V5R(&YA;64@
M:7,@:6YV86QI9"XB+`H))W!D:7)?961?7VQO9VEN7V5X:7-T<R<@/3X@(E-U
M8V@@=7-E<B!A;')E861Y(&5X:7-T<RX@5')Y(&%N;W1H97(@;&]G:6X@;F%M
M92XB+`H))W!D:7)?961?7VYE=U]U<W(G(#T^(").97<@=7-E<B(L"@DG<&1I
M<E]E9%]?;F]N7W-S;"<@/3X@(DYO;BU34TPB+`H))W!D:7)?961?7V-G:5]B
M:6XG(#T^(")C9VDM8FEN(BP*"2=P9&ER7V5D7U]P871H)R`]/B`B1&ER96-T
M;W)Y(&YA;64B+`H))W!D:7)?961?7W!D:7)?9F]R7V1O;6%I;B<@/3X@(E!R
M;W1E8W1E9"!D:7)E8W1O<GD@)3$@;VX@9&]M86EN("4R(BP*"2=P9&ER7V5D
M7U]P9&ER7VQO8V%T:6]N)R`]/B`B1&ER96-T;W)Y(&QO8V%T:6]N(BP*"2=P
M9&ER7V5D7U]P9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U
M<V5R<R(L"@DG<&1I<E]E9%]?<W-L)R`]/B`B4U-,(BP*"2=P9&ER7V5D7U]S
M<VQ?;F]T7W-U<'!O<G1E9%]D;VUA:6XG(#T^(")34TP@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&ES(&1O;6%I;BXB+`H))W!D:7)?961?7W-S;%]O<E]N;VYS
M<VQ?<VAO=6QD7V)E7V-H96-K960G(#T^(")!="!L96%S="!O;F4@8VAE8VMB
M;W@@<VAO=6QD(&)E('-E;&5C=&5D(&9R;VT@4U-,(&%N9"!.;VXM4U-,(&-H
M96-K8F]X97,N(BP*"2=P9&ER7V5D7U]U;F%B;&5?8W)?<&1I<E]U<W(G(#T^
M(")5;F%B;&4@=&\@8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S
M97(Z("4Q(BP*"2=P9&ER7V5D7U]U;F%B;&5?8W)E871E7W!D:7(G(#T^(")5
M;F%B;&4@=&\@8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y.B`E,2(L
M"@DG<&1I<E]E9%]?=6YA8FQE7V1E9FEN95]H<W1?='EP92<@/3X@(E5N86)L
M92!T;R!D969I;F4@=&AE(&AO<W1I;F<@='EP92XB+`H))W!D:7)?961?7W5N
M86)L95]U<&1A=&5?<&1I<B<@/3X@(E5N86)L92!T;R!U<&1A=&4@=&AE('!R
M;W1E8W1E9"!D:7)E8W1O<GDZ("4Q(BP*"2=P9&ER7V5D7U]W<F]N9U]S>6UB
M;VQ?:6Y?:&5A9&5R)R`]/B`B4&QE87-E+"!D;R!N;W0@=7-E('-Y;6)O;"`E
M,2!I;B!T:&4@9&ER96-T;W)Y(&AE861E<B(L"@DG<&1I<E]U<W)?961?7V-R
M96%T95]P9&ER7W5S<E]F;W)?<&0G(#T^(")#<F5A=&4@=7-E<B!F;W(@=&AE
M('!R;W1E8W1E9"!D:7)E8W1O<GD@)3$B+`H))W!D:7)?=7-R7V5D7U]N;W1?
M8W)E871E7W!A<W,G(#T^(")4:&ES('=I;&P@;F]T(&-R96%T92!A('!A<W-W
M;W)D(&9O<B!T:&4@;F5W('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<BY<;E=I
M=&AO=70@<&%S<W=O<F0@=&AE('5S97(@=VEL;"!N;W0@8F4@86)L92!T;R!L
M;V<@:6XN(BP*"2=P9&ER7W5S<E]E9%]?<&%S<U]F;W)?<&1I<E]U<W(G(#T^
M(")087-S=V]R9"!F;W(@=&AE('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<B`E
M,2(L"@DG<&1I<E]U<W)?961?7W5N86)L95]S96QE8W1?<&1I<E]U<W(G(#T^
M(")5;F%B;&4@=&\@<V5L96-T('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S
M97(Z("4Q(BP*"2=P9&ER7W5S<G-?;&ES=%]?=6YA8FQE7V1E9FEN95]P9&ER
M7W5S<G,G(#T^(")5;F%B;&4@=&\@9&5F:6YE('1H92!P<F]T96-T960@9&ER
M96-T;W)Y('5S97)S.B`E,2(L"@DG<&1I<E]U<W)S7VQI<W1?7W5N86)L95]R
M96UO=F5?<&1?=7-R<R<@/3X@(E5N86)L92!T;R!R96UO=F4@=&AE('!R;W1E
M8W1E9"!D:7)E8W1O<GD@=7-E<G,Z("4Q(BP*"2=P9&ER<U]L:7-T7U]N86UE
M)R`]/B`B3F%M92(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7VYO;E]S96-U
M<F5?9&ER)R`]/B`B3B(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7W-E8W5R
M95]D:7(G(#T^(")3(BP*"2=P9&ER<U]L:7-T7U]T86)?=&ET;&5?8V=I7V)I
M;E]D:7(G(#T^(")#(BP*"2=P9&ER<U]L:7-T7U]U;F%B;&5?<F5M;W9E7W!D
M:7)S)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@<')O=&5C=&5D(&1I<F5C
M=&]R:65S.B`E,2(L"@DG<&AO<W1I;F=?7V%N;VYF='!?9&ES86)L960G(#T^
M(")!;F]N>6UO=7,@1E10('-E<G9I8V4@:7,@9&ES86)L960@;VX@=&AI<R!D
M;VUA:6X@87,@=&AI<R!)4"!A9&1R97-S(&ES(&%L<F5A9'D@8F5I;F<@=7-E
M9"!F;W(@86YO;GEM;W5S($944"!S97)V:6-E(&]N(&%N;W1H97(@9&]M86EN
M+B(L"@DG<&AO<W1I;F=?7V%N;VYF='!?96YC<GEP="<)/3X@)U1H92!P87-S
M=V]R9"!O9B!&5%`@=7-E<B!I<R!E;F-R>7!T960L(&%N9"!T:&5R969O<F4@
M8V%N;F]T(&)E('5S960@9F]R('!R;W1E8W1I;F<@9&ER96-T;W)Y("]P;&5S
M:RUS=&%T+RX@4&QE87-E(')E96YT97(@>6]U<B!&5%`@<&%S<W=O<F0L(&]R
M(&1E<V5L96-T('1H92!O<'1I;VX@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D
M('!R;W1E8W1E9"!D:7)E8W1O<GD@7"<O<&QE<VLM<W1A="]<)R(G+`H))W!H
M;W-T:6YG7U]I<%]C:&%N9V5?=V%R;FEN9R<@/3X@(DE0(&%D9')E<W,@8VAA
M;F=E9"X@5&AE(&-O<G)E<W!O;F1I;F<@8VAA;F=E<R!W97)E(&%L<V\@;6%D
M92!I;B!T:&4@9&]M86EN)W,@1$Y3('IO;F4N(BP*"2=P:&]S=&EN9U]?;W1H
M97)?:&]S=&EN9U]E>&ES='-?;VY?:7`G(#T^(")5;F%B;&4@=&\@8VAA;F=E
M('1H92!C97)T:69I8V%T92!B96-A=7-E('1H:7,@:7`@861D<F5S<R!I<R!B
M96EN9R!U<V5D(&EN(&]N92!O<B!S979E<F%L(&AO<W1I;F<@86-C;W5N=',N
M(BP*"2=P:&]S=&EN9U]?=6YA8FQE7W1O7V-H86YG95]C97)T:69I8V%T92<@
M/3X@(E5N86)L92!T;R!I;G-T86QL('1H92!C97)T:69I8V%T93H@)3$B+`H)
M)W!H;W-T:6YG7U]U;F%B;&5?=&]?8VAA;F=E7VEP7V%D9')E<W,G(#T^(")5
M;F%B;&4@=&\@8VAA;F=E('1H92!I<"!A9&1R97-S.B`E,2(L"@DG<&AO<W1I
M;F=?7W5N86)L95]T;U]S971?8V5R="<@/3X@(E5N86)L92!T;R!S970@=&AE
M('-S;"!C97)T:69I8V%T93H@)3$B+`H))W!H;W-T:6YG7U]U;F%B;&5?=7!D
M871E)R`]/B`B56YA8FQE('1O('5P9&%T92!H;W-T:6YG('!R969E<F5N8V5S
M.B`E,2(L"@DG<&AO<W1I;F=?7W5N86)L95]M86YA9V4G(#T^(")5;F%B;&4@
M=&\@;6%N86=E(&AO<W1I;F<Z("4Q(BP*"@DG<&EC:V5R7V%U=&]R97-P;VYD
M97)?7W1I=&QE)R`]/B`G075T;W)E<W!O;F1E<B!S96QE8W1I;VXG+`H))W!I
M8VME<E]C;&EE;G1?7W1I=&QE)R`]/B`G0VQI96YT('-E;&5C=&EO;B<L"@DG
M<&EC:V5R7V1A=&%B87-E7U]T:71L92<@/3X@)T1A=&%B87-E('-E;&5C=&EO
M;B<L"@DG<&EC:V5R7V1O;6%I;E]?=&ET;&4G(#T^("=$;VUA:6X@<V5L96-T
M:6]N)RP*"2=P:6-K97)?;6%I;&YA;65?7W1I=&QE)R`]/B`G36%I;&YA;64@
M<V5L96-T:6]N)RP*"2=P:6-K97)?<VET95]A<'!L:6-A=&EO;E]?=&ET;&4G
M(#T^("=3:71E(&%P<&QI8V%T:6]N('-E;&5C=&EO;B<L"@DG<&EC:V5R7W-U
M8F1O;6%I;E]?=&ET;&4G(#T^("=3=6)D;VUA:6X@<V5L96-T:6]N)RP*"2=P
M:6-K97)?=V5B7W5S97)?7W1I=&QE)R`]/B`G5V5B('5S97(@<V5L96-T:6]N
M)RP*"2=P:6-K97)?8W5S=&]M7V)U='1O;E]?=&ET;&4G(#T^("=#=7-T;VT@
M8G5T=&]N('-E;&5C=&EO;B<L"@H))W!L97-K7V=U:61E)R`]/B`B4&QE<VL@
M57-E<B=S($=U:61E(BP*"2=P;&5S:U]K97E?7V%C=&EO;E]L;V=S)R`]/B`B
M06)I;&ET>2!T;R!U<V4@86-T:6]N(&QO9V=I;F<B+`H))W!L97-K7VME>5]?
M87!P7W9A=6QT)R`]/B`B06)I;&ET>2!T;R!U<V4@87!P;&EC871I;VX@=F%U
M;'0B+`H))W!L97-K7VME>5]?8F%C:W5P)R`]/B`B06)I;&ET>2!T;R!U<V4@
M=&AE(&)A8VMU<"!F=6YC=&EO;G,B+`H))W!L97-K7VME>5]?8VQI96YT7W1E
M;7!L<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E(&-L:65N="!T96UP;&%T97,B
M+`H))W!L97-K7VME>5]?8VQI96YT<R<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F
M(&-L:65N="!A8V-O=6YT<R(L"@DG<&QE<VM?:V5Y7U]C;VQD9G5S:6]N)R`]
M/B`B06)I;&ET>2!T;R!U<V4@0V]L9$9U<VEO;B(L"@DG<&QE<VM?:V5Y7U]D
M;VUA:6YS)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@9&]M86EN<R(L"@DG<&QE
M<VM?:V5Y7U]D87-H8F]A<F0G(#T^("=!8FEL:71Y('1O('5S92!$97-K=&]P
M(&EN=&5R9F%C92<L"@DG<&QE<VM?:V5Y7U]S=&1G=6DG(#T^("=!8FEL:71Y
M('1O('5S92!S=&%N9&%R9"!I;G1E<F9A8V4G+`H))W!L97-K7VME>5]?;6%N
M86=E7V1A<VAB;V%R9"<@/3X@)T%B:6QI='D@=&\@;6%N86=E($1E<VMT;W`G
M+`H))W!L97-K7VME>5]?:V5Y7VEP7W)A;F=E<R<@/3X@)UEO=2!C86X@=7-E
M(%!L97-K(&]N;'D@=VET:"!T:&4@9F]L;&]W:6YG($E0(&%D9')E<W-E<SHG
M+`H))W!L97-K7VME>5]?9')W96(G(#T^(")!8FEL:71Y('1O('5S92!$<BY7
M96(@86YT:79I<G5S(BP*"2=P;&5S:U]K97E?7V5V96YT7VUA;F%G97(G(#T^
M(")!8FEL:71Y('1O('5S92!E=F5N="!M86YA9V5R(BP*"2=P;&5S:U]K97E?
M7V5X<&ER871I;VYS)R`]/B`B06)I;&ET>2!T;R!M86YA9V4@9&]M86EN(&%N
M9"!C;&EE;G0@86-C;W5N="!E>'!I<F%T:6]N(&1A=&5S(BP*"2=P;&5S:U]K
M97E?7V=R;W5P7V]P<R<@/3X@(D%B:6QI='D@=&\@<&5R9F]R;2!G;&]B86P@
M;W!E<F%T:6]N<R!O;B!O8FIE8W1S("AG<F]U<"!O<&5R871I;VYS*2(L"@DG
M<&QE<VM?:V5Y7U]E>'!I<F%T:6]N)R`]/B`B2V5Y(&5X<&ER871I;VX@9&%T
M92(L"@DG<&QE<VM?:V5Y7U]K97E?;G5M8F5R)R`]/B`B2V5Y(&YU;6)E<B(L
M"@DG<&QE<VM?:V5Y7U]L86YG=6%G97,G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!L86YG=6%G92!P86-K<R(L"@DG<&QE<VM?:V5Y7U]M86EL;F%M97,G(#T^
M(")-87AI;75M(&YU;6)E<B!O9B!M86EL(&%C8V]U;G1S(BP*"2=P;&5S:U]K
M97E?7VUI9W)A=&EO;E]M86YA9V5R)R`]/B`B06)I;&ET>2!T;R!U<V4@36EG
M<F%T:6]N($UA;F%G97(B+`H))W!L97-K7VME>5]?;7-S<6PG(#T^(")!8FEL
M:71Y('1O('5S92!-:6-R;W-O9G0@4U%,(%-E<G9E<B(L"@DG<&QE<VM?:V5Y
M7U]M>7!L97-K7V9U;F,G(#T^(")-4$,@9G5N8W1I;VYA;&ET>2(L"@DG<&QE
M<VM?:V5Y7U]M>7!L97-K7VUA;F%G92<@/3X@(D%D;6EN:7-T<F%T;W(@8V%N
M(&UA;F%G92!-4$,@<V5R=FEC92!A8V-E<W-I8FEL:71Y(BP*"2=P;&5S:U]K
M97E?7VUY<&QE<VM?<V5R=F5R7VED)R`]/B`B35!#('-L879E('-E<G9E<B!I
M9&5N=&EF:65R(BP*"2=P;&5S:U]K97E?7VYO=&EF:6-A=&EO;G,G(#T^(")!
M8FEL:71Y('1O(&UA;F%G92!N;W1I9FEC871I;VYS(BP*"2=P;&5S:U]K97E?
M7W!O<W1G<F5S<6PG(#T^(")!8FEL:71Y('1O('5S92!0;W-T9W)E4U%,(BP*
M"2=P;&5S:U]K97E?7W%M86EL7W%U975E)R`]/B`G06)I;&ET>2!T;R!M86YA
M9V4@;6%I;"!Q=65U92<L"@DG<&QE<VM?:V5Y7U]R96UO=&5?9&(G(#T^("=!
M8FEL:71Y('1O('5S92!R96UO=&4@9&%T86)A<V4@:&]S=&EN9R<L"@DG<&QE
M<VM?:V5Y7U]S:71E8G5I;&1E<B<@/3X@(D%B:6QI='D@=&\@=7-E($UA;6)O
M($--4R(L"@DG<&QE<VM?:V5Y7U]S;&%V95]S97)V97)S)R`]/B`B4VQA=F4@
M<V5R=F5R<R!L:6UI="(L"@DG<&QE<VM?:V5Y7U]S<&%M87-S87-S:6XG(#T^
M(")!8FEL:71Y('1O('5S92!3<&%M07-S87-S:6XB+`H))W!L97-K7VME>5]?
M<W5B9&]M86EN<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E('-U8F1O;6%I;G,B
M+`H))W!L97-K7VME>5]?<WES7V%C8V5S<R<@/3X@(D%B:6QI='D@=&\@;6%N
M86=E('-H96QL(&%C8V5S<R(L"@DG<&QE<VM?:V5Y7U]T;VUC870G(#T^(")!
M8FEL:71Y('1O('5S92!4;VUC870B+`H))W!L97-K7VME>5]?=')A9F9I8U]R
M97!O<G1S)R`]/B`B06)I;&ET>2!T;R!U<V4@=')A9F9I8R!R97!O<G1I;F<B
M+`H))W!L97-K7VME>5]?='1S)R`]/B`B06)I;&ET>2!T;R!U<V4@2&5L<"!$
M97-K(BP*"2=P;&5S:U]K97E?7W9I<G1U;WIZ;R<@/3X@(E9A;&ED(&9O<B!6
M:7)T=6]Z>F\@;VYL>2(L"@DG<&QE<VM?:V5Y7U]W96)U<V5R<R<@/3X@(DUA
M>&EM=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG<&QE<VM?:V5Y7U]L:6-E
M;G-E7W5P9&%T95]D871E)R`]/B`G3F5X="!L:6-E;G-E(&ME>2!U<&1A=&4G
M+`H))W!L97-K7VME>5]?875T;VEN<W1A;&QE<E]C;VYF:6<G(#T^("=!8FEL
M:71Y('1O(&UA;F%G92!U<&1A=&5R('!R969E<F5N8V5S)RP*"2=P;&5S:U]K
M97E?=7!D871E7U]T:71L92<@/3X@)TME>2!5<&1A=&4@4W1A='5S)RP*"2=P
M;&5S:U]K97E?=7!D871E7U]L96=E;F0G(#T^("=+97D@57!D871E(%-T871U
M<R<L"@DG<&QE<VM?:V5Y7W5P9&%T95]?;F5W7V%D9&ET:6]N86Q?:V5Y)R`]
M/B`G3F5W(&%D9&ET:6]N86P@:V5Y(')E8V5I=F5D)RP*"@DG<&QE<VM?:V5Y
M7U]C:&5C:U]W<F]N9R<@"0D)"3T^("=4:&4@;&EC96YS92!K97D@:7,@;F]T
M('9A;&ED+B!4;R!U<V4@=&AE(&-O;G1R;VP@<&%N96PL(&]B=&%I;B!A;F0@
M:6YS=&%L;"!A(&YE=R!F=6QL>2!F96%T=7)E9"!L:6-E;G-E(&ME>2XG+`H)
M)W!L97-K7VME>5]?=7!L;V%D7V-H96-K7W=R;VYG)PD)"3T^("=4:&4@=7!L
M;V%D960@;&EC96YS92!K97D@:7,@;F]T('9A;&ED+B<L"@DG<&QE<VM?:V5Y
M7U]R979E<G1?8VAE8VM?=W)O;F<G"0D)/3X@)U1H92!P<F5V:6]U<VQY(&EN
M<W1A;&QE9"!L:6-E;G-E(&ME>2!I<R!N;W0@=F%L:60N)RP*"2=P;&5S:U]K
M97E?7W5P9&%T95]C:&5C:U]W<F]N9R<)"0D]/B`G5&AE('5P9&%T960@;&EC
M96YS92!K97D@:7,@;F]T('9A;&ED+B<L"@H))W!L97-K7VME>5]?:V5Y7V5X
M<&ER960G"0D)"3T^("=9;W5R(&QI8V5N<V4@:V5Y(&AA<R!E>'!I<F5D+B!4
M;R!C;VYT:6YU92!U<VEN9R!Y;W5R(&-O;G1R;VP@<&%N96PL('EO=2!M=7-T
M('!U<F-H87-E(&$@;F]N+65X<&ER:6YG(&-O;6UE<F-I86P@;&EC96YS92XG
M+`H))W!L97-K7VME>5]?=FER=6]Z>F]?;VYL>5]K97DG"0D)/3X@)U1H92!L
M:6-E;G-E(&ME>2!I<R!I;G1E;F1E9"!O;FQY(&9O<B!U<V4@=VET:"!0;&5S
M:R!I;G-I9&4@5FER='5O>GIO('9I<G1U86P@<')I=F%T92!S97)V97)S+B<L
M"@DG<&QE<VM?:V5Y7U]E87-Y7VUI<W5S960G"0D)"3T^("=4:&4@;&EC96YS
M92!K97D@9F]R(%!L97-K($5A<WD@86QL;W=S('-E<G9I;F<@;VYL>2!O;F4@
M8VQI96YT(&%C8V]U;G0N(%EO=2!H879E("4Q(&-L:65N=',N)RP*"2=P;&5S
M:U]K97E?7VEP7W)A;F=E<U]E>&-E961E9"<)"0D]/B`G66]U(&-A;B!U<V4@
M=&AI<R!L:6-E;G-E9"!0;&5S:R!C;W!Y(&]N;'D@=VET:"!T:&4@9F]L;&]W
M:6YG($E0(&%D9')E<W-E<SH@)3(N(%1H92!F;VQL;W=I;F<@25`@861D<F5S
M<V5S(&%R92!N;W0@8V]V97)E9"!B>2!Y;W5R(&QI8V5N<V4Z("4Q+B<L("\O
M)3$@=6YA;&QO=V5D(&%D9')E<W-E<R!L:7-T('-E<&%R871E9"!B>2!C;VUM
M82P@)3(@86QL;W=E9"!I<"!A9&1R97-S97,@;&ES="!S97!A<F%T960@8GD@
M8V]M;6$*"2=P;&5S:U]K97E?7VQI;6ET<U]E>&-E961E9"<)"0D]/B`G5&AE
M(&%M;W5N="!O9B!C=7)R96YT;'D@=7-E9"!R97-O=7)C97,@;W9E<G)I9&5S
M('1H92!L:6UI=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4N)RP*"2=P;&5S
M:U]K97E?7VQI;6ET<U]E>&-E961E9%]L:6U?9&]M)PD]/B`G5&AE(&YU;6)E
M<B!O9B!W96(@<VET97,@:&]S=&5D(&]N('1H92!S97)V97(@97AC965D<R!T
M:&4@;&EM:71S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!9;W4@:&%V92`E
M,B!S:71E<R!H;W-T960[('EO=7(@;&EC96YS92!A;&QO=W,@:&]S=&EN9R!O
M;FQY("4Q('-I=&5S+B<L("\O("4Q(&QI;6ET('9A;'5E+"`E,B!U<V5D('9A
M;'5E+"`E,R!D96QT82!V86QU90H))W!L97-K7VME>5]?;&EM:71S7V5X8V5E
M9&5D7VQI;5]C;"<)"3T^("=4:&4@;G5M8F5R(&]F('-E<G9E9"!C;&EE;G0@
M86-C;W5N=',@97AC965D<R!T:&4@;&EM:71S(&1E9FEN960@8GD@>6]U<B!L
M:6-E;G-E+B!9;W4@:&%V92`E,B!C;&EE;G0@86-C;W5N=',@8W5R<F5N=&QY
M('-E<G9E9#L@>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG(&]N;'D@)3$@
M8VQI96YT(&%C8V]U;G1S+B<L("\O)3$@;&EM:70@=F%L=64L("4R('5S960@
M=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?97AC
M965D961?;&EM7VUN)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D(&4M;6%I
M;"!A8V-O=6YT<R!E>&-E961S('1H92!L:6UI=',@9&5F:6YE9"!B>2!Y;W5R
M(&QI8V5N<V4N(%EO=2!H879E("4R(&4M;6%I;"!A8V-O=6YT<R!C=7)R96YT
M;'D@<V5R=F5D.R!Y;W5R(&QI8V5N<V4@86QL;W=S('-E<G9I;F<@;VYL>2`E
M,2!E+6UA:6P@86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L=64L("4R('5S
M960@=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?
M97AC965D961?;&EM7W=U)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D('=E
M8B!U<V5R(&%C8V]U;G1S(&5X8V5E9',@=&AE(&QI;6ET<R!D969I;F5D(&)Y
M('EO=7(@;&EC96YS92X@66]U(&AA=F4@)3(@=V5B('5S97(@86-C;W5N=',@
M8W5R<F5N=&QY('-E<G9E9#L@>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG
M(&]N;'D@)3$@=V5B('5S97(@86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L
M=64L("4R('5S960@=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y
M7U]L:6UI='-?97AC965D961?34Q3)PD)/3X@)U1H92!N=6UB97(@;V8@8W5R
M<F5N=&QY('5S960@;&%N9W5A9V4@<&%C:W,@97AC965D<R!T:&4@;&EM:71S
M(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!4:&5R92!A<F4@)3(@;&%N9W5A
M9V4@<&%C:W,@:6YS=&%L;&5D.R!Y;W5R(&QI8V5N<V4@86QL;W=S(&EN<W1A
M;&QI;F<@;VYL>2`E,2!L86YG=6%G92!P86-K<RXG+"`O+R`E,2!L:6UI="!V
M86QU92P@)3(@=7-E9"!V86QU92P@)3,@9&5L=&$@=F%L=64*"@DG<&QE<VM?
M:V5Y7U]K97E?9FEL95]I;G9A;&ED)R`]/B`G5&AE('5P;&]A9&5D(&ME>2!F
M:6QE(&ES(&YO="!V86QI9"!O<B!D;V5S(&YO="!C;VYT86EN(&$@;&EC96YS
M92!K97DN)RP*"2=K97E?7W1I=&QE)R`]/B`G3&EC96YS92!-86YA9V5M96YT
M)RP*"2=K97E?7W5P;&]A9%]T:71L92<@/3X@)TQI8V5N<V4@2V5Y(%5P;&]A
M9"<L"@DG:V5Y7U]U<&QO861?;&5G96YD)R`]/B`G3&EC96YS92!K97D@=7!L
M;V%D)RP*"2=K97E?7V9I;&4G(#T^("=0871H('1O('1H92!L:6-E;G-E(&ME
M>2!F:6QE(&QO8V%T:6]N)RP*"2=K97E?7VYO7VME>5]F:6QE7VEN7WII<"<@
M/3X@)U1H92!U<&QO861E9"`N>FEP(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!K
M97D@9FEL92<L"@DG:V5Y7U]K97E?=7!L;V%D)R`]/B`G3&EC96YS92!+97D@
M26YS=&%L;&%T:6]N)RP*"2=K97E?7V]V97)W<FET95]C;VYF:7)M871I;VXG
M(#T^("=297!L86-E('1H92!C=7)R96YT;'D@:6YS=&%L;&5D(&QI8V5N<V4@
M:V5Y('=I=&@@=&AE('-E;&5C=&5D(&]N92<L"@DG:V5Y7U]O=F5R=W)I=&5?
M8V]N9FER;6%T:6]N7W)E<75I<F5D)R`]/B`G4&QE87-E(&-O;F9I<FT@=&AE
M(&QI8V5N<V4@:V5Y(')E<&QA8V5M96YT+B<L"@DG:V5Y7U]L:6UI='-?97AC
M965D961?8V]N9FER;6%T:6]N)R`]/B`G1&\@;F]T(&-H96-K('1H92!L:6UI
M=',@;VX@<F5S;W5R8V4@=7-A9V4@9&5F:6YE9"!B>2!T:&4@:V5Y)RP*"2=K
M97E?7W1A8G-?<&QE<VLG(#T^("=0;&5S:R!,:6-E;G-E($ME>2<L"@DG:V5Y
M7U]T86)S7V%D9&ET:6]N86PG(#T^("=!9&1I=&EO;F%L($QI8V5N<V4@2V5Y
M<R<L"@DG:V5Y7W)E=F5R=%]?=&ET;&4G(#T^("=,:6-E;G-E($ME>2!2;VQL
M8F%C:R<L"@DG:V5Y7W)E=F5R=%]?;&5G96YD)R`]/B`G2V5Y(')O;&QB86-K
M(&-O;F9I<FUA=&EO;B<L"@DG:V5Y7W)E=F5R=%]?=&5X="<@/3X@)U1H92!L
M:6-E;G-E(&ME>2!W:71H('1H92!F;VQL;W=I;F<@<')O<&5R=&EE<R!W:6QL
M(&)E(')E<W1O<F5D.B<L"@DG861D:71I;VYA;%]K97E?7VEN9F\G(#T^("=!
M9&1I=&EO;F%L($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]?
M<')O<%]N86UE)R`]/B`G4')O<&5R='DG+`H))V%D9&ET:6]N86Q?:V5Y7U]P
M<F]P7W9A;'5E)R`]/B`G5F%L=64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C
M<E]N86UE)R`]/B`G2V5Y(&YA;64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C
M<E]K97E?;G5M8F5R)R`]/B`G2V5Y(&YU;6)E<B<L"@DG861D:71I;VYA;%]K
M97E?7V1E<V-R7VQI;5]D871E)R`]/B`G17AP:7)A=&EO;B!D871E)RP*"2=A
M9&1I=&EO;F%L7VME>5]?9&5S8W)?;&EC96YS95]U<&1A=&5?9&%T92<@/3X@
M)TYE>'0@;&EC96YS92!K97D@=7!D871E)RP*"2=A9&1I=&EO;F%L7VME>5]?
M<F5M;W9E7W1I=&QE)R`]/B`B5&AE('-I=&4@87!P;&EC871I;VX@:V5Y('=I
M=&@@=&AE(&9O;&QO=VEN9R!P<F]P97)T:65S('=I;&P@8F4@<F5M;W9E9#HB
M+`H))V%D9&ET:6]N86Q?:V5Y<U]?<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O
M;&QO=VEN9R!A9&1I=&EO;F%L(&ME>7,@=VEL;"!B92!R96UO=F5D.B(L"@DG
M861D:71I;VYA;%]K97ES7U]S96QE8W1?=&]?<F5M;W9E)R`]/B`G4V5L96-T
M('1H92!A9&1I=&EO;F%L(&ME>7,@=&\@8F4@<F5M;W9E9"XG+`H))V%D9&ET
M:6]N86Q?:V5Y7U]F:6QE7VEN=F%L:60G(#T^("=4:&4@=7!L;V%D960@:V5Y
M(&9I;&4@:7,@;F]T('9A;&ED(&]R(&1O97,@;F]T(&-O;G1A:6X@82!L:6-E
M;G-E(&ME>2XG+`H))V%D9&ET:6]N86Q?:V5Y7U]F:6QE7VEN8V]M<&%T:6)L
M92<@/3X@)U1H92!U<&QO861E9"!K97D@9FEL92!I<R!N;W0@=F%L:60@9F]R
M('1H:7,@87!P;&EC871I;VXN)RP*"2=A9&1I=&EO;F%L7VME>5]?;F]T7V5X
M:7-T<R<@/3X@)TYO(&QI8V5N<V4@:V5Y(&EN<W1A;&QE9"XG+`H))V%D9&ET
M:6]N86Q?:V5Y<U]?;&5G96YD)R`]/B`G061D:71I;VYA;"!K97ES)RP*"2=A
M9&1I=&EO;F%L7VME>7-?7VQI<W1?:&5A9&5R)R`]/B`G061D:71I;VYA;"!K
M97ES)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W1I=&QE)R`]/B`G57!D
M871I;F<@061D:71I;VYA;"!+97DN)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A
M=&5?7VQE9V5N9"<@/3X@)U-T871U<R!O9B!A9&1I=&EO;F%L(&ME>2!U<&1A
M=&4N)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7VYE=U]K97DG(#T^("=!
M9&1I=&EO;F%L($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]U
M<&1A=&5?7W)E<W5L=%]R97-P;VYS92<@/3X@)TQI8V5N<VEN9R!S97)V97(@
M<F5S<&]N<V4Z("4Q)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W)E<W5L
M=%]N971W;W)K)R`]/B`G56YA8FQE('1O(&-O;FYE8W0@=&\@=&AE(&QI8V5N
M<VEN9R!S97)V97(N(%!L96%S92!M86ME('-U<F4@=&AA="!Y;W5R(&YE='=O
M<FL@86QL;W=S(&-O;6UU;FEC871I;VX@=&\@)3$Z("4R+B<L"@DG861D:71I
M;VYA;%]K97E?=7!D871E7U]R97-U;'1?;&]C:R<@/3X@)TME>2!U<&1A=&4@
M:7,@86QR96%D>2!I;B!P<F]G<F5S<R<L"@DG861D:71I;VYA;%]K97E?=7!D
M871E7U]R97-U;'1?:6YT97)N86Q?97)R;W(G(#T^("=%<G)O<B!O8V-U<G)E
M9"!W:&EL92!U<&1A=&EN9R!T:&4@;&EC96YS92!K97DZ("4Q)RP*"@DG8G1?
M861D:71I;VYA;%]K97E?<F5V97)T)R`]/B`G4F]L;"!"86-K($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?=7!D871E)R`]/B`G4F5T<FEE=F4@061D:71I
M;VYA;"!+97DG+`H))V%D9&ET:6]N86Q?:V5Y7W)E=F5R=%]?=&ET;&4G(#T^
M("=0;&5A<V4@8V]N9FER;2!T:&4@;W!E<F%T:6]N)RP*"2=A9&1I=&EO;F%L
M7VME>5]R979E<G1?7VQE9V5N9"<@/3X@)U!R;W!E<G1I97,@;V8@=&AE('!R
M979I;W5S;'D@=7-E9"!A9&1I=&EO;F%L(&ME>2<L"@DG861D:71I;VYA;%]K
M97E?<F5V97)T7U]C;VYF:7)M7W1E>'0G(#T^("=2;VQL(&)A8VL@:V5Y)RP*
M"2=A9&1I=&EO;F%L7VME>5]R979E<G1?7V-O;F9I<FU?<F5Q=6ER960G(#T^
M("=0;&5A<V4@8V]N9FER;2!T:&4@;W!E<F%T:6]N+B<L"@H))W!R;V-E961?
M=&]?8VQ?<&]O;"<@/3X@(E!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT
M)W,@25`@<&]O;"(L"@DG<')O8V5E9%]T;U]H;W-T:6YG7W-E='5P)R`]/B`B
M4')O8V5E9"!T;R!H;W-T:6YG('-E='5P(BP*"2=R96UO=F5#97)T<U]?<F5M
M;W9E7V-E<G1I9FEC871E<U]C<"<@/3X@(E1H92!F;VQL;W=I;F<@8V5R=&EF
M:6-A=&5S('=I;&P@8F4@<F5M;W9E9#H@(BP*"2=R96UO=F5#97)T<U]?<F5M
M;W9E7V-E<G1I9FEC871E<U]D;VUA:6XG(#T^(")4:&4@9F]L;&]W:6YG(&-E
M<G1I9FEC871E<R!O=VYE9"!B>2`E,2!W:6QL(&)E(')E;6]V960Z("(L"@DG
M<F5M;W9E0VQI96YT<TE07W)E;6]V95]C;&EE;G1S7VEP)R`]/B`B5&AI<R!)
M4"!A9&1R97-S('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!P;V]L<R!O9B!T
M:&4@9F]L;&]W:6YG(&-L:65N=',Z(BP*"2=R96UO=F5#;&EE;G1S4VET94%P
M<%]R96UO=F5?8VQI96YT<R<@/3X@(E1H:7,@<VET92!A<'!L:6-A=&EO;B!W
M:6QL(&)E(')E;6]V960@9G)O;2!T:&4@<&]O;',@;V8@=&AE(&9O;&QO=VEN
M9R!C;&EE;G1S.B(L"@DG<F5M;W9E0VQI96YT<U]?<F5M;W9E7V-L:65N='-?
M9&]M86EN<R<@/3X@(E1H92!F;VQL;W=I;F<@8VQI96YT(&%C8V]U;G1S(&%N
M9"!T:&5I<B!D;VUA:6YS('=I;&P@8F4@<F5M;W9E9#HB+`H))W)E;6]V94UA
M:6Q!;&EA<V5S7U]R96UO=F5?;6%I;%]A;&EA<V5S)R`]/B`B5&AE(&9O;&QO
M=VEN9R!M86EL(&%L:6%S97,@9F]R('1H92!M86EL(&YA;64@)3$@=VEL;"!B
M92!R96UO=F5D.B(L"@DG<F5M;W9E36%I;$YA;65S7U]R96UO=F5?;6%I;&YA
M;65S)R`]/B`B5&AE(&9O;&QO=VEN9R!M86EL(&YA;65S(&%N9"!A;&EA<V5S
M('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!D;VUA:6X@)3$Z(BP*"2=R96UO
M=F5-86EL3F%M97-?7W)E;6]V95]M86EL;F%M97-?;V9?8VPG(#T^(")4:&4@
M9F]L;&]W:6YG(&UA:6P@;F%M97,@86YD(&%L:6%S97,@=VEL;"!B92!R96UO
M=F5D(&9R;VT@9&]M86EN("4R(&]W;F5D(&)Y(&-L:65N="`E,3HB+`H))W)E
M;6]V94UA:6Q.86UE<U]?=&AE<V5?;6%I;&YA;65S7W=I;&Q?;F]T7V1E;&5T
M92<@/3X@(E1H97-E(&UA:6P@;F%M97,@=VEL;"!N;W0@8F4@9&5L971E9"XB
M+`H))W)E;6]V95-E<W-I;VYS7U]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L
M;&]W:6YG('-E<W-I;VYS('=I;&P@8F4@96YD960Z(BP*"2=R96UO=F5&='!3
M97-S:6]N<U]?<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!&5%`@
M<V5S<VEO;G,@=VEL;"!B92!E;F1E9#HB+`H))W)E;6]V951E;7!L871E<U]?
M<F5M;W9E7W1E;7!L871E<R<@/3X@(E1H92!F;VQL;W=I;F<@=&5M<&QA=&5S
M('=I;&P@8F4@<F5M;W9E9#HB+`H))W)E<&]R=%]A=71O7U]L:7-T7W1I=&QE
M)R`]/B`G1"<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?875T;R<@/3X@)T9R97%U
M96YC>2<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?;&%S="<@/3X@)TQA<W0@9&5L
M:79E<GD@9&%T92<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<F5C:7!I96YT)R`]
M/B`G1&5L:79E<B!T;R<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<V5L96-T)R`]
M/B`G4F5P;W)T(&]N)RP*"2=R97!O<G1?875T;U]?=&ET;&4G(#T^("=$96QI
M=F5R>2!38VAE9'5L97,@9F]R("4Q)RP*"2=R97!O<G1?875T;U]?<F5C:7!I
M96YT7V5M86EL)R`]/B`G=&AE(&4M;6%I;"!A9&1R97-S($D@<W!E8VEF>2<L
M"@DG<F5P;W)T7V%U=&]?7W)E8VEP:65N=%]A9&UI;B<@/3X@)W1H92!S97)V
M97(@861M:6YI<W1R871O<B<L"@DG<F5P;W)T7V%U=&]?7W)E8VEP:65N=%]C
M;&EE;G0G(#T^("=T:&4@8VQI96YT)RP*"2=R97!O<G1?875T;U]?<F5C:7!I
M96YT7V1O;6%I;B<@/3X@)W1H92!D;VUA:6X@861M:6YI<W1R871O<B<L"@DG
M<F5P;W)T7V%U=&]?961I=%]?<V5L96-T)R`]/B`G4F5P;W)T(&]N)RP*"2=R
M97!O<G1?875T;U]?<V5L96-T7V-L:65N=%]R97!O<G1?86QL)R`]/B`G86QL
M(&-L:65N=',G+`H))W)E<&]R=%]A=71O7U]S96QE8W1?8VQI96YT7W)E<&]R
M=%]C=7)R96YT)R`]/B`G=&AI<R!C;&EE;G0G+`H))W)E<&]R=%]A=71O7U]S
M96QE8W1?8VQI96YT7W)E<&]R=%]O=&AE<E]C;&EE;G0G(#T^("<E,2<L"@DG
M<F5P;W)T7V%U=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V%L;"<@/3X@)V%L
M;"!D;VUA:6YS)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V1O;6%I;E]R97!O
M<G1?;W1H97)?8VQI96YT)R`]/B`G86QL(&1O;6%I;G,@;V8@)3$G+`H))W)E
M<&]R=%]A=71O7U]S96QE8W1?9&]M86EN7W)E<&]R=%]C;&EE;G0G(#T^("=A
M;&P@9&]M86EN<R!O9B!T:&ES(&-L:65N="<L"@DG<F5P;W)T7V%U=&]?7W-E
M;&5C=%]D;VUA:6Y?<F5P;W)T7V-U<G)E;G0G(#T^("=T:&ES(&1O;6%I;B<L
M"@DG<F5P;W)T7V%U=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V]T:&5R7V1O
M;6%I;B<@/3X@)R4Q)RP*"2=R97!O<G1?875T;U]?;&5G96YD)R`]/B`G1&5L
M:79E<GD@<V-H961U;&5S)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V9O<E]R
M96UO=F4G(#T^(")396QE8W0@=&AE(&1E;&EV97)Y('-C:&5D=6QE<R!T;R!B
M92!R96UO=F5D+B(L"@DG<F5P;W)T7V%U=&]?<F5M;W9E7U]T:71L92<@/3X@
M(E1H92!F;VQL;W=I;F<@<F5P;W)T(&1E;&EV97)Y('-C:&5D=6QE<R!W:6QL
M(&)E(')E;6]V960Z(BP*"2=R97!O<G1?875T;U]E9&ET7U]T:71L92<@/3X@
M)T1E;&EV97)Y(%-C:&5D=6QE(%!R;W!E<G1I97,G+`H))W)E<&]R=%]A=71O
M7V5D:71?7W)E8VEP:65N="<@/3X@)T1E;&EV97(@=&\G+`H))W)E<&]R=%]A
M=71O7V5D:71?7W1A<F=E="<@/3X@)U)E<&]R="!O;B<L"@DG<F5P;W)T7V%U
M=&]?961I=%]?875T;R<@/3X@)T1E;&EV97)Y(&9R97%U96YC>2<L"@DG<F5S
M<%]E9&ET7U]A;'=A>7-?<F5S<&]N9"<@/3X@(F%L=V%Y<R!R97-P;VYD(BP*
M"2=R97-P7V5D:71?7W)E<&QY7W-U8FIE8W0G(#T^(")297!L>2!S=6)J96-T
M(BP*"2=R97-P7V5D:71?7V%N<W=E<E]T>'0G(#T^(")297!L>2!W:71H('1E
M>'0B+`H))W)E<W!?961I=%]?871T86-H)R`]/B`B071T86-H(&9I;&5S(BP*
M"2=R97-P7V5D:71?7V1E9F%U;'1?<W5B:F5C="<@/3X@(E)E.B`E,2(L"@DG
M<F5S<%]E9&ET7U]F;W(G(#T^(")F;W(@(BP*"2=R97-P7V5D:71?7V9R=U]R
M<7-T7V5M86EL)R`]/B`B57!O;B!A=71O;6%T:6,@<F5S<&]N<V4L(&9O<G=A
M<F0@=&AE(&]R:6=I;F%L(&UE<W-A9V4@=&\@=&AE('-P96-I9FEE9"!E+6UA
M:6PB+`H))W)E<W!?961I=%]?9G=D7V5M86EL7VEN=F%L:60G(#T^(")$97-T
M:6YA=&EO;B!E+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E
M9&ET7U]I;E]B;V1Y)R`]/B`B=VAE;B!S<&5C:69I960@=V]R9',@87)E(&9O
M=6YD(&EN('1H92!M97-S86=E(&)O9'DB+`H))W)E<W!?961I=%]?:6Y?<W5B
M:F5C="<@/3X@(G=H96X@<W!E8VEF:65D('=O<F1S(&%R92!F;W5N9"!I;B!M
M97-S86=E('-U8FIE8W0B+`H))W)E<W!?961I=%]?:6YV86QI9%]R97-P7V9R
M97$G(#T^(")297-P;VYS92!F<F5Q=65N8WD@:7,@:6YV86QI9"XB+`H))W)E
M<W!?961I=%]?:6YV86QI9%]R<7-T7W1X="<@/3X@(DEN=F%L:60@<F5Q=65S
M="!T97AT+B(L"@DG<F5S<%]E9&ET7U]I;G9A;&ED7W-T;W)E7VQI;5]N=6TG
M(#T^("),:6UI="!V86QU92!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E9&ET7U]L
M:6UI='-?=&ET;&4G(#T^("),:6UI=',B+`H))W)E<W!?961I=%]?;6%X:6UU
M;5]A;&QO=V5D7W)E<W!?9G)E<5]R96%C:&5D)R`]/B`B3G5M8F5R(&]F(&UA
M>&EM=6T@<F5S<&]N<V5S('!E<B!D87D@97AC965D<R!T:&4@9&5F:6YE9"!R
M871E+B!!;&QO=V5D.B`E,2P@<F5Q=65S=&5D.B`E,B(L"@DG<F5S<%]E9&ET
M7U]N;U]F:6QE<U]S96PG(#T^(").;R!F:6QE<R!S96QE8W1E9"XB+`H))W)E
M<W!?961I=%]?;F]?='AT7W-U<'!L:65D)R`]/B`B3F\@=&5X="!S=7!P;&EE
M9"XB+`H))W)E<W!?961I=%]?<F5P;'E?=&ET;&4G(#T^(")297!L>2(L"@DG
M<F5S<%]E9&ET7U]R97!L>5]T;U]A9&1R97-S)R`]/B`B4F5T=7)N(&%D9')E
M<W,B+`H))W)E<W!?961I=%]?<F5P;'E?=&]?:6YV86QI9"<@/3X@(E)E='5R
M;B!A9&1R97-S(&ES(&EN=F%L:60N(BP*"2=R97-P7V5D:71?7W)E<&QY7W5N
M:7%?96UA:6PG(#T^(")297!L>2!T;R!T:&4@=6YI<75E(&4M;6%I;"!A9&1R
M97-S(&YO="!M;W)E('1H86XB+`H))W)E<W!?961I=%]?8V]N9&ET:6]N<U]T
M:71L92<@/3X@(D-O;F1I=&EO;G,B+`H))W)E<W!?961I=%]?<F5S<"<@/3X@
M(D%U=&]R97-P;VYD97(@("(L"@DG<F5S<%]E9&ET7U]R97-P7VYA;64G(#T^
M(")!=71O<F5S<&]N9&5R(&YA;64B+`H))W)E<W!?961I=%]?<F5S<%]N;W1?
M97AI<W0G(#T^(")!=71O<F5S<&]N9&5R(&1O97,@;F]T(&5X:7-T+B(L"@DG
M<F5S<%]E9&ET7U]R97-P7W-T871U<R<@/3X@(D%U=&]R97-P;VYD97(@<W1A
M='5S(BP*"2=R97-P7V5D:71?7W)Q<W1?='AT)R`]/B`G4W!E8VEF>2!T:&4@
M8V]N9&ET:6]N(&9O<B!T:&ES(&%U=&]M871I8R!R97!L>2<L"@DG<F5S<%]E
M9&ET7U]S96QE8W1?9FEL97-?;VY?<V5R=F5R7V9O<E]A='1A8V@G(#T^(")3
M96QE8W0@=&AE(&9I;&5S('EO=2!W86YT('1O(&%T=&%C:"(L"@DG<F5S<%]E
M9&ET7U]S=&]R95]U<%]T;R<@/3X@(E-T;W)E('5P('1O(BP*"2=R97-P7V5D
M:71?7W-U8FI?;&EN95]I;G9A;&ED)R`]/B`B4W5B:F5C="!L:6YE(&ES(&EN
M8V]R<F5C="XB+`H))W)E<W!?961I=%]?=&5X=%]T;V]?8FEG)R`]/B`B5&AE
M(')E<&QY(&UE<W-A9V4@=&5X="!I<R!T;V\@;&%R9V4N(BP*"2=R97-P7V5D
M:71?7W1I;65S7VEN7V%?9&%Y)R`]/B`B=&EM97,@82!D87DN(BP*"2=R97-P
M7V5D:71?7W5N86)L95]D969I;F5?<F5S<%]C;VYD)R`]/B`B56YA8FQE('1O
M(&1E9FEN92!T:&4@875T;W)E<W!O;F1E<B!C;VYD:71I;VXZ("4Q(BP*"2=R
M97-P7V5D:71?7W5N86)L95]D969I;F5?<F5S<%]S=&%T=7,G(#T^(")5;F%B
M;&4@=&\@9&5F:6YE(&%U=&]R97-P;VYD97(@<W1A='5S.B`E,2(L"@DG<F5S
M<%]E9&ET7U]U;F%B;&5?='5R;E]O;E]R97-P)R`]/B`B56YA8FQE('1O('1U
M<FX@;VX@=&AE(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=R97-P7V5D:71?7W5N
M:7%?96UA:6PG(#T^(")U;FEQ=64@92UM86EL(&%D9')E<W-E<R(L"@DG<F5S
M<%]E9&ET7U]C;VYT96YT7W1Y<&4G(#T^("=-86EL('-E;F1I;F<@9F]R;6%T
M)RP*"2=R97-P7V5D:71?7V-O;G1E;G1?='EP95]T97AT)R`]/B`G4&QA:6X@
M=&5X="<L"@DG<F5S<%]E9&ET7U]C;VYT96YT7W1Y<&5?:'1M;"<@/3X@)TA4
M34PG+`H))W)E<W!?961I=%]?8VAA<G-E="<@/3X@)T5N8V]D:6YG)RP*"2=R
M97-T87)T7U]C;VQD9G5S:6]N)R`]/B`B0V]L9$9U<VEO;B`H)3$I(BP*"2=R
M97-T87)T7U]C;VQD9G5S:6]N7VEN<W1A;&QA=&EO;E]T>7!E)R`]/B`B26YS
M=&%L;&%T:6]N('1Y<&4Z("4Q(BP*"2=R97-T87)T7U]D;G,G(#T^("=$3E,@
M4V5R=F5R("@E,2DG+`H))W)E<W1A<G1?7V1R=V5B)R`]/B`G1'(N5V5B(&%N
M=&EV:7)U<R<L"@DG<F5S=&%R=%]?;6%I;"<@/3X@(DE-05`O4$]0,R!397)V
M97(@*"4Q*2(L"@DG<F5S=&%R=%]?;7-S<6PG(#T^(")-:6-R;W-O9G0@4U%,
M('-E<G9E<B(L"@DG<F5S=&%R=%]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F53
M44PB+`H))W)E<W1A<G1?7W!S82<@/3X@(E-E<G9I8V5S(&UA;F%G96UE;G0B
M+`H))W)E<W1A<G1?7W-M='`G(#T^(")33510(%-E<G9E<B`H)3$I(BP*"2=R
M97-T87)T7U]S<&%M87-S87-S:6XG(#T^(")3<&%M07-S87-S:6XB+`H))W)E
M<W1A<G1?7W-T=6YN96PG(#T^(")3='5N;F5L(BP*"2=R97-T87)T7U]T;VUC
M870G(#T^(")4;VUC870B+`H))W)E<W1A<G1?7W=E8B<@/3X@(E=E8B!397)V
M97(@*"4Q*2(L"@DG<FU?9&]M86EN<U]?<V]M95]D;VUA:6YS7V%R95]N;W1?
M97AI<W0G(#T^(")3;VUE(&]F('1H92!S<&5C:69I960@9&]M86EN<R!D;R!N
M;W0@97AI<W0N(%1H97D@:&%V92!B965N('!O<W-I8FQY(')E;6]V960@8GD@
M86YO=&AE<B!U<V5R+B(L"@DG<G!T7V-L7V1O;5]D871A7V)A<V5S)R`]/B`B
M1$)A<V5S(BP*"2=R<'1?8VQ?9&]M7VUA:6Q?9W)O=7!S)R`]/B`B34=R;W5P
M<R(L"@DG<G!T7V-L7V1O;5]M86EL7VQI<W1S)R`]/B`B34QI<W1S(BP*"2=R
M<'1?8VQ?9&]M7VUA:6Q?<F5S<',G(#T^(")!4F5S<"XB+`H))W)P=%]C;%]D
M;VU?<&]S=&)O>&5S)R`]/B`B34)O>&5S(BP*"2=R<'1?8VQ?9&]M7W)E9&ER
M96-T<R<@/3X@(E)E9&ER+B(L"@DG<G!T7V-L7V1O;5]S=6)D;VUA:6YS)R`]
M/B`B4W5B9&]M(BP*"2=R<'1?8VQ?9&]M7W=E8E]U<V5R<R<@/3X@(E=5<V5R
M<R(L"@DG<G!T7V-L7V1O;5]W96)A<'!S)R`]/B`B5T%P<',B+`H))W)P=%]C
M;%]R97!O<G1?9F]R7V-L7U\G(#T^(")297!O<G0@;VX@8VQI96YT("4Q(BP*
M"2=R<'1?8VQ?<V5C=&EO;E]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T
M7V-L7W-E8W1I;VY?9G5L;%]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T
M7V-L7W-E8W1I;VY?9V5N97)A;"<@/3X@(D=E;F5R86PB+`H))W)P=%]C<F5A
M=&4G(#T^(")#<F5A=&4@<F5P;W)T(BP*"2=R<'1?96UP='DG(#T^(")4:&4@
M<F5P;W)T('-H;W5L9"!C;VYT86EN(&%T(&QE87-T(&]N92!S96-T:6]N(BP*
M"2=R<'1?9&5F875L=%]R97!O<G0G(#T^(")5<V4@87,@9&5F875L="!R97!O
M<G0B+`H))W)P=%]D;VU?<F5P;W)T7V9O<E]D;VU?7R<@/3X@(D1O;6%I;B!R
M97!O<G0@9F]R("4Q(BP*"2=R<'1?9&]M7W-E8W1I;VY?9&%T86)A<V5S)R`]
M/B`B1&%T86)A<V5S(BP*"2=R<'1?9&]M7W-E8W1I;VY?9G5L;%]D871A8F%S
M97,G(#T^(")$871A8F%S97,B+`H))W)P=%]D;VU?<V5C=&EO;E]F=6QL7VUA
M:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))W)P=%]D;VU?<V5C=&EO
M;E]F=6QL7VUA:6QN86UE<R<@/3X@(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?
M<V5C=&EO;E]F=6QL7W=E8G5S97)S)R`]/B`B5V5B('5S97)S(BP*"2=R<'1?
M9&]M7W-E8W1I;VY?9G5L;%]S:71E87!P<R<@/3X@)U-I=&4@87!P;&EC871I
M;VYS)RP*"2=R<'1?9&]M7W-E8W1I;VY?9G5L;%]T;VUC870G(#T^(")*879A
M(&%P<&QI8V%T:6]N<R(L"@DG<G!T7V1O;5]S96-T:6]N7V=E;F5R86PG(#T^
M(")'96YE<F%L(BP*"2=R<'1?9&]M7W-E8W1I;VY?:&]S=&EN9R<@/3X@(DAO
M<W1I;F<B+`H))W)P=%]D;VU?<V5C=&EO;E]L:7-T7W1O;6-A="<@/3X@(DIA
M=F$@87!P;&EC871I;VYS(BP*"2=R<'1?9&]M7W-E8W1I;VY?;6%I;&QI<W1S
M)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG<G!T7V1O;5]S96-T:6]N7VUA:6QN
M86UE<R<@/3X@(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?<V5C=&EO;E]S:71E
M87!P<R<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*"2=R<'1?9&]M7W-E8W1I
M;VY?=&]M8V%T)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H))W)P=%]D;VU?
M<V5C=&EO;E]W96)U<V5R<R<@/3X@(E=E8B!U<V5R<R(L"@DG<G!T7V1O;5]T
M:71L95]W85]S=&%T=7,G(#T^(")3(BP*"2=R<'1?961I=%]?)R`]/B`B161I
M="!R97!O<G0@)3$B+`H))W)P=%]E;G1E<E]E;6%I;%]A9&1R97-S)R`]/B`B
M16YT97(@=&AE(&4M;6%I;"!A9&1R97-S('1H92!R97!O<G0@=VEL;"!B92!D
M96QI=F5R960@=&\N(BP*"2=R<'1?;&ES="<@/3X@(D-U<W1O;2!R97!O<G0@
M;&%Y;W5T<R(L"@DG<G!T7VYA;64G(#T^(")297!O<G0@;F%M92(L"@DG<G!T
M7W)E;6]V95]R97!O<G1S)R`]/B`B5&AE(&9O;&QO=VEN9R!R97!O<G0@;&%Y
M;W5T<R!W:6QL(&)E(')E;6]V960Z(BP*"2=R<'1?<F5P;W)T<R<@/3X@(E)E
M<&]R=',B+`H))W)P=%]S96-T:6]N7V9U;&PG(#T^(")&=6QL(BP*"2=R<'1?
M<V5C=&EO;E]N;VYE)R`]/B`B3F]N92(L"@DG<G!T7W-E8W1I;VY?<W5M;6%R
M>2<@/3X@(E-U;6UA<GDB+`H))W)P=%]S96QE8W1?<F5P;W)T<U]F;W)?<F5M
M;W9E)R`]/B`B4V5L96-T('1H92!R97!O<G0@;&%Y;W5T<R!T;R!B92!R96UO
M=F5D+B(L"@DG<G!T7V1E9F%U;'1?9G5L;"<@/3X@)T9U;&P@4F5P;W)T)RP*
M"2=R<'1?9&5F875L=%]S=6UM87)Y)R`]/B`G4W5M;6%R>2!297!O<G0G+`H*
M"2\O(&5N9"!O9B!K;V]P97(@<&%R=`H*"2\O(&=R97D@<&%R="`H<G-E<W-I
M;VX@<W5P<&]R="D*"2=R<V5S<VEO;E]N;U]A<&E?<G!C7V5R<FUS9R<@/3X@
M(E!L97-K($%022!24$,@:7,@;F]T(&EN<W1A;&QE9"!O;B!T:&4@<F5M;W1E
M(&AO<W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F;W(@
M<W5P<&]R="XB+`H))W)S97-S:6]N7VYO7V%C8V]U;G1?97)R;7-G)R`]/B`B
M56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E('-E<G9I8V4@=6YD97(@>6]U
M<B!A8V-O=6YT+B!4:&4@;6]S="!C;VUM;VX@<F5A<V]N(&ES('1H870@=&AE
M('-E<G9I8V4@9F]R('EO=7(@86-C;W5N="!I<R!N;W0@86-T:79A=&5D('EE
M="X@4&QE87-E+"!W86ET(&9O<B!S979E<F%L(&UI;G5T97,L(&%N9"!T:&5N
M('1R>2!A9V%I;BX@268@>6]U(&5N8V]U;G1E<B!T:&ES(&5R<F]R(&%G86EN
M+"!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(BP*"2=R<V5S
M<VEO;E]N;U]D;VUA:6Y?97)R;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T
M:&4@<F5M;W1E('-E<G9I8V4@9F]R('1H:7,@9&]M86EN+B!4:&4@;6]S="!C
M;VUM;VX@<F5A<V]N(&ES('1H870@=&AE('-E<G9I8V4@9F]R('1H:7,@9&]M
M86EN(&ES(&YO="!A8W1I=F%T960@>65T+B!0;&5A<V4L('=A:70@9F]R('-E
M=F5R86P@;6EN=71E<RP@86YD('1H96X@=')Y(&%G86EN+B!)9B!Y;W4@96YC
M;W5N=&5R('1H:7,@97)R;W(@86=A:6XL(&-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB+`H))W)S97-S:6]N7W5N:VYO=VY?97)R;7-G)R`]
M/B`B5&AE(')E;6]T92!S97)V97(@:&%S(')E:F5C=&5D('1H92!A='1E;7!T
M('1O(&5S=&%B;&ES:"!A('-E<W-I;VXN($-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<B!F;W(@<W5P<&]R="X@5&AE(&5R<F]R('=A<SH@)3$B
M+`H))W)S97-S:6]N7W5N:VYO=VXR7V5R<FUS9R<@/3X@(E5N:VYO=VX@97)R
M;W(@=VAI;&4@97-T86)L:7-H:6YG(&$@<F5M;W1E('-E<W-I;VXN($UO<W0@
M<')O8F%B;'D@=&AE(')E;6]T92!S97)V97(@9&]E<R!N;W0@<F5S<&]N9"!P
M<F]P97)L>2!O<B!D;V5S(&YO="!A;G-W97(@870@86QL+B!!<VL@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<B!T;R!C:&5C:R!F;W(@97)R;W(@9&5T86EL
M<R!I;B!T:&4@07!A8VAE(&5R<F]R(&QO9RXB+`H))W)S97-S:6]N7VYO7V-O
M;FYE8W1?97)R;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E
M('-E<G9I8V4Z(&-O;FYE8W1I;F<@=&\@<F5M;W1E('-E<W-I;VX@9F%I;&5D
M+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@9F]R('-U<'!O
M<G0N(BP*"2\O(&5N9"!O9B!G<F5Y('!A<G0*"@DO+R!P:70@<&%R=`H*"2=R
M<'1?<V5N9%]R97!O<G1?8GE?96UA:6Q?97)R;W)?7R<@/3X@(D5R<F]R('-E
M;F1I;F<@=&AE(')E<&]R=#H@)3$B+`H))W)P=%]S96YD7W)E<&]R=%]B>5]E
M;6%I;%]O:U]?)R`]/B`B5&AE(')E<&]R="!H87,@8F5E;B!S96YT('1O("4Q
M+B(L"@DG<V%?86-T:6]N7V1E;"<@/3X@(D1E;&5T92(L"@DG<V%?86-T:6]N
M7V1E<V,G(#T^(")7:&%T('1O(&1O('=I=&@@<W!A;2!M86EL(BP*"2=S85]A
M8W1I;VY?<V%V92<@/3X@(DUA<FL@87,@<W!A;2!A;F0@<W1O<F4@:6X@;6%I
M;&)O>"(L"@DG<V%?861M:6Y?8FQA8VML:7-T)R`]/B`B061M:6YI<W1R871O
M<B=S(&)L86-K(&QI<W0B+`H))W-A7V%D;6EN7W=H:71E;&ES="<@/3X@(D%D
M;6EN:7-T<F%T;W(G<R!W:&ET92!L:7-T(BP*"2=S85]B;&%C:VQI<W0G(#T^
M(")";&%C:R!L:7-T(BP*"2=S85]B;&%C:VQI<W1?9&5S8R<@/3X@(D%L=V%Y
M<R!M87)K(&%S('-P86T@;6%I;"!F<F]M(&%D9')E<W,B+`H))W-A7V)Y7W1A
M9R<@/3X@(F)Y('1A9R(L"@DG<V%?8V9G7W5S95]P;VQI8WDG(#T^(")5<V%G
M92!P;VQI8WD@<V5T=&EN9W,B+`H))W-A7V-O;F9?;&ES=%]B;&%C:R<@/3X@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-E;&5C=&5D
M('!A='1E<FYS(&9R;VT@=&AE(&)L86-K(&QI<W0_(BP*"2=S85]C;VYF7VQI
M<W1?:6=N;W)E)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<V5L96-T960@<&%T=&5R;G,@9G)O;2!T:&4@:6=N;W)E(&QI<W0_
M(BP*"2=S85]C;VYF7VQI<W1?=VAI=&4G(#T^(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S96QE8W1E9"!P871T97)N<R!F<F]M('1H
M92!W:&ET92!L:7-T/R(L"@DG<V%?9&)?9&5L7V-O;F9I<FTG(#T^(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@8VQE87(@=&AE(%-P86U!<W-A<W-I;B=S
M(&1A=&%B87-E/R(L"@DG<V%?96UL7VEN7VEG;F]R96QI<W0G(#T^(")%+6UA
M:6P@:7,@:6X@=&AE(&EG;F]R92!L:7-T(BP*"2=S85]E;6Q?<&%T=&5R;B<@
M/3X@(D4M;6%I;"!P871T97)N(BP*"2=S85]E;7!T>5]E;6%I;"<@/3X@(D-A
M;FYO="!A9&0@96UP='D@92UM86EL('!A='1E<FXN(BP*"2=S85]E>&ES='-?
M96UA:6PG(#T^(")3=6-H(&4M;6%I;"!P871T97)N(&%L<F5A9'D@97AI<W1S
M+B(L"@DG<V%?9&ES86)L961?7VUA:6QN86UE7VYO=%]F:6QT97)I;F<G(#T^
M(")4:&4@8W5R<F5N="!S97)V97(@<V5T=&EN9W,@9&\@;F]T(&%L;&]W('1O
M('5S92!M86EL(&9I;'1E<FEN9R!F;W(@=&AI<R!M86EL(&YA;64B+`H))W-A
M7V1I<V%B;&5D7U]F:6QT97)I;F=?:7-?9&ES86)L960G(#T^("=3<&%M(&9I
M;'1E<FEN9R!W87,@9&ES86)L960@8GD@=&AE('-E<G9E<B!A9&UI;FES=')A
M=&]R)RP*"2=S85]E;F%B;&5?9FEL=&5R)R`]/B`B16YA8FQE('-P86T@9FEL
M=&5R:6YG(BP*"2=S85]H:71S7W)E<2<@/3X@(DAI=',@<F5Q=6ER960@9F]R
M('-P86TB+`H))W-A7VAI='-?;F]T7VYU;6)E<B<@/3X@)U1H92!N=6UB97(@
M>6]U('-P96-I9FEE9"!I<R!I;G9A;&ED+B!9;W4@<VAO=6QD('5S92!A('!O
M<VET:79E(&EN=&5G97(N)RP*"2=S85]I9VYO<F5L:7-T)R`]/B`B4V5R=F5R
M+7=I9&4@:6=N;W)E(&QI<W0B+`H))W-A7VEG;F]R96QI<W1?9&5S8R<@/3X@
M(D1O(&YO="!F:6QT97(@;6%I;"!F;W(@=&AE<V4@86-C;W5N=',B+`H))W-A
M7VUO9&EF>5]S=6)J)R`]/B`B36]D:69Y('-P86T@;6%I;"!S=6)J96-T(BP*
M"2=S85]P871T97)N7VEN7V)L86-K;&ES="<@/3X@(E!A='1E<FX@86QR96%D
M>2!E>&ES=',@:6X@8FQA8VL@;&ES="(L"@DG<V%?<&%T=&5R;E]I;E]I9VYO
M<F5L:7-T)R`]/B`B4&%T=&5R;B!A;')E861Y(&5X:7-T<R!I;B!I9VYO<F4@
M;&ES="(L"@DG<V%?<&%T=&5R;E]I;E]W:&ET96QI<W0G(#T^(")0871T97)N
M(&%L<F5A9'D@97AI<W1S(&EN('=H:71E(&QI<W0B+`H))W-A7W!A='1E<FY?
M:7-?:6YV86QI9"<@/3X@(E!A='1E<FX@:7,@:6YV86QI9"XB+`H))V)T7W-A
M7V-L96%R7V1B)R`]/B`G0VQE87(@4W!A;2!&:6QT97(@1&%T86)A<V4G+`H)
M)V)T7W-A7V9O<F=E="<@/3X@)T9O<F=E="!)="<L"@DG8G1?<V%?;&5A<FY?
M87-?<W!A;2<@/3X@(DET)W,@4W!A;2$B+`H))V)T7W-A7VQE87)N7V%S7VYO
M;G-P86TG(#T^("))="=S($YO="!3<&%M(BP*"2=S85]T<F%I;F5R7U]P86=E
M7W1I=&QE)R`]/B`G4W!A;2!F:6QT97(@=')A:6YI;F<G+`H))W-A7W1R86EN
M97)?7W1O;VQS7VQE9V5N9"<@/3X@)U1O;VQS)RP*"2=S85]T<F%I;F5R7U]I
M;F9O7VQE9V5N9"<@/3X@)TEN9F\G+`H))W-A7W1R86EN97)?7VUE<W-A9V5S
M7VQI<W1?;&5G96YD)R`]/B`G365S<V%G97,@:6X@>6]U<B!M86EL8F]X)RP*
M"2=S85]T<F%I;F5R7U]C)R`]/B`G5"<L"@DG<V%?=')A:6YE<E]?;"<@/3X@
M)TPG+`H))W-A7W1R86EN97)?7W-U8FIE8W0G(#T^("=3=6)J96-T)RP*"2=S
M85]T<F%I;F5R7U]F<F]M)R`]/B`G1G)O;2<L"@DG<V%?=')A:6YE<E]?9&%T
M92<@/3X@)T1A=&4G+`H))W-A7W1R86EN97)?7VEN9F]?=&5X="<@/3X@)TUE
M<W-A9V5S(&QE87)N960Z("4Q(&%S('-P86TL("4R(&%S(&YO;BUS<&%M+"`E
M,R!T;W1A;"XG+`H))W-A7W1R86EN97)?7VUE<W-A9V5S)R`]/B`G;65S<V%G
M92AS*2<L"@DG<V%?=')A:6YE<E]?<V5L96-T7U]A;&PG(#T^("=!;&PG+`H)
M)W-A7W1R86EN97)?7W-E;&5C=%]?<W!A;5]O;FQY)R`]/B`G4W!A;2<L"@DG
M<V%?=')A:6YE<E]?<V5L96-T7U]H86U?;VYL>2<@/3X@)TYO;BU3<&%M)RP*
M"2=S85]T<F%I;F5R7U]S96QE8W1?7W5N:VYO=VY?;VYL>2<@/3X@)U5N:VYO
M=VXG+`H))W-A7W1R86EN97)?7V-A;FYO=%]R96UO=F5?;65S<V%G97,G(#T^
M("=#86YN;W0@<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F<F]M('1H
M92!M86EL8F]X+B<L"@DG<V%?=')A:6YE<E]?<F5M;W9E7VUE<W-A9V5S7V-O
M;F9I<FTG(#T^("=!<F4@>6]U('-U<F4@=&AA="!Y;W4@=VES:"!T;R!R96UO
M=F4@=&AE('-E;&5C=&5D(&UE<W-A9V5S(&9R;VT@=&AE(&UA:6QB;W@_)RP*
M"2=S85]S96QE8W1?96UA:6PG(#T^(")396QE8W0@870@;&5A<W0@;VYE(&4M
M;6%I;"!P871T97)N(&9R;VT@=&AE(&QI<W0@=&\@<F5M;W9E(&ET+B(L"@DG
M<V%?<W)V7V)L86-K;&ES="<@/3X@(E-E<G9E<BUW:61E(&)L86-K(&QI<W0B
M+`H))W-A7W-R=E]C9F<G(#T^(")397)V97(@=VED92!S971T:6YG<R(L"@DG
M<V%?<W)V7W-E='1I;F=S)R`]/B`B4V5R=F5R('-E='1I;F=S(BP*"2=S85]S
M<G9?=VAI=&5L:7-T)R`]/B`B4V5R=F5R+7=I9&4@=VAI=&4@;&ES="(L"@DG
M<V%?=7-E7W-R=E]S971T:6YG<R<@/3X@(E5S92!S97)V97(@=VED92!S971T
M:6YG<R(L"@DG<V%?=7-E<E]B;&%C:VQI<W0G(#T^(")5<V5R)W,@8FQA8VL@
M;&ES="(L"@DG<V%?=7-E<E]W:&ET96QI<W0G(#T^(")5<V5R)W,@=VAI=&4@
M;&ES="(L"@DG<V%?=7-R7V1I<V%B;&5D7V)Y7W-R=B<@/3X@(D%D;6EN:7-T
M<F%T;W(@:&%S(&1I<V%B;&5D('5S97(M8V]N9FEG=7)E9"!S<&%M(&9I;'1E
M<FEN9R(L"@DG<V%?=7-R7VYO7W!O<W1B;W@G(#T^(")5<V5R(&AA<R!N;R!M
M86EL8F]X(&5N86)L960B+`H))W-A7W5S<E]S971T:6YG<R<@/3X@(E!E<G-O
M;F%L('-E='1I;F=S(BP*"2=S85]W:&ET96QI<W0G(#T^(")7:&ET92!L:7-T
M(BP*"2=S85]W:&ET96QI<W1?9&5S8R<@/3X@(DYE=F5R(&UA<FL@87,@<W!A
M;2!M86EL(&9R;VT@861D<F5S<R(L"@DG<V5R=F5R7U]A9&UI;E]I;F9O)R`]
M/B`B061M:6YI<W1R871O<B!I;F9O<FUA=&EO;B(L"@DG<V5R=F5R7U]C=')L
M7W!A;F5L)R`]/B`B0V]N=')O;"!086YE;"(L"@DG<V5R=F5R7U]E;G1E<E]B
M=6=?97-S96YC95]B96QO=R<@/3X@(D5N=&5R('1H92!B=6<@9&5S8W)I<'1I
M;VX@8F5L;W<B+`H))W-E<G9E<E]?<&]W97)?;6%N86=E;65N="<@/3X@(E!O
M=V5R(&UA;F%G96UE;G0B+`H))W-E<G9E<E]?<V5R=FEC97,G(#T^(")397)V
M:6-E<R(L"@DG<V5R=F5R7U]S>7-T96TG(#T^(")3>7-T96TB+`H))W-E<G9E
M<E]?=&ET;&4G(#T^(")397)V97(@061M:6YI<W1R871I;VXB+`H))W-E<G9E
M<E]?=V%R;FEN9U]R96)O;W0G(#T^(")787)N:6YG(2!4:&4@<WES=&5M('=I
M;&P@;F]W(&)E(')E8F]O=&5D+B!0<F]C965D/R(L"@DG<V5R=F5R7U]W87)N
M:6YG7W-H=71D;W=N)R`]/B`B5T%23DE.1SH@5&AI<R!O<&5R871I;VX@=VEL
M;"!S:'5T('1H92!S97)V97(@9&]W;BX@(%1H92!S97)V97(@8V%N;F]T7&YB
M92!R97-T87)T960@<F5M;W1E;'D@8GD@;65A;G,@;V8@=&AI<R!S;V9T=V%R
M92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O('!R;V-E960_(BP*"2=S97)V
M97)?7W=I;&Q?<F5B;V]T)R`]/B`B5&AE('-Y<W1E;2!W:6QL(&YO=R!B92!R
M96)O;W1E9"XB+`H))W-E<G9E<E]?=VEL;%]S:'5T9&]W;B<@/3X@(E1H92!S
M>7-T96T@:7,@<VAU='1I;F<@9&]W;BXB+`H))W-E<G9E<E]P<F5F97)E;F-E
M<U]?861M:6Y?;&%N9W5A9V4G(#T^(")!9&UI;FES=')A=&]R)W,@:6YT97)F
M86-E(&QA;F=U86=E(BP*"2=S97)V97)?<')E9F5R96YC97-?7V%D;6EN7W-K
M:6XG(#T^(")!9&UI;FES=')A=&]R)W,@:6YT97)F86-E('-K:6XB+`H))W-E
M<G9E<E]P<F5F97)E;F-E<U]?86QL;W=?861M:6Y?;75L=&EP;'E?;&]G:6XG
M(#T^(")!;&QO=R!M=6QT:7!L92!S97-S:6]N<R!U;F1E<B!A9&UI;FES=')A
M=&]R)W,@;&]G:6XB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?9&ES
M:U]S<&%C92<@/3X@(DEN8VQU9&4@:6X@=&AE(&1I<VL@<W!A8V4@=7-A9V4@
M8V%L8W5L871I;VXB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?=')A
M9F9I8R<@/3X@(DEN8VQU9&4@:6X@=&AE('1R869F:6,@8V%L8W5L871I;VXB
M+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?='EP92<@/3X@)U=H96X@
M8V%L8W5L871I;F<@9&ES:R!S<&%C92!U<V%G92P@8V]U;G0G+`H))W-E<G9E
M<E]P<F5F97)E;F-E<U]?8V]U;G1?='EP95]?8GET92<@/3X@)V9I;&4@<VEZ
M92<L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]C;W5N=%]T>7!E7U]B;&]C:R<@
M/3X@)V%M;W5N="!O9B!D:7-K('-P86-E('5S960G+`H))W-E<G9E<E]P<F5F
M97)E;F-E<U]?9&5F875L=%]L86YG=6%G92<@/3X@(D1E9F%U;'0@;&]C86QE
M(BP*"2=S97)V97)?<')E9F5R96YC97-?7V1E9F%U;'1?<VMI;B<@/3X@(D1E
M9F%U;'0@<VMI;B(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]D:7-P;&%Y)R`]
M/B`B1&ES<&QA>2(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7V1A
M=&%B87-E<R<@/3X@(F1A=&%B87-E<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S
M7U]I;F-L=61E7V1O;6%I;F1U;7!S)R`]/B`B9&]M86EN(&)A8VMU<"!F:6QE
M<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7VEN8V]M:6YG)R`]
M/B`B;VYL>2!I;F)O=6YD('1R869F:6,B+`H))W-E<G9E<E]P<F5F97)E;F-E
M<U]?:6YC;'5D95]I;F-O;6EN9U]A;F1?;W5T9V]I;F<G(#T^(")I;F)O=6YD
M(&%N9"!O=71B;W5N9"!T<F%F9FEC(BP*"2=S97)V97)?<')E9F5R96YC97-?
M7VEN8VQU9&5?;&]G<R<@/3X@(FQO9R!F:6QE<R(L"@DG<V5R=F5R7W!R969E
M<F5N8V5S7U]I;F-L=61E7VUA:6QB;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG
M<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7VUA:6QL:7-T<R<@/3X@(FUA
M:6QI;F<@;&ES=',B+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?:6YC;'5D95]O
M=71G;VEN9R<@/3X@(F]N;'D@;W5T8F]U;F0@=')A9F9I8R(L"@DG<V5R=F5R
M7W!R969E<F5N8V5S7U]I;F-L=61E7W=E8F%P<',G(#T^(")*879A(&%P<&QI
M8V%T:6]N<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]K965P7W-T871S)R`]
M/B`B4F5T86EN('1R869F:6,@<W1A=&ES=&EC<R!F;W(B+`H))W-E<G9E<E]P
M<F5F97)E;F-E<U]?;6%X7V)U='1O;E]L96YG=&@G(#T^(")"=71T;VX@;&%B
M96P@;&5N9W1H(BP*"2=S97)V97)?<')E9F5R96YC97-?7W)E<W1A<G1?87!A
M8VAE7VEN=&5R=F%L)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86PB+`H)
M)W-E<G9E<E]P<F5F97)E;F-E<U]?<W1A=%]W87)N:6YG)R`]/B`B5&AE(&-H
M86YG97,@;6%D92!T;R!T:&4@9&ES:R!S<&%C92!U<V%G92!C86QC=6QA=&EO
M;B!S8VAE;64@=VEL;"!T86ME(&5F9F5C="!O;FQY(&1U<FEN9R!N97AT('-T
M871I<W1I8W,@8V%L8W5L871I;VXN(BP*"2=S97)V97)?<')E9F5R96YC97-?
M7W1I=&QE)R`]/B`B4V5R=F5R('!R969E<F5N8V5S(BP*"2=S97)V97)?;6%I
M;%]?=&ET;&4G(#T^(")397)V97(M=VED92!M86EL('!R969E<F5N8V5S(BP*
M"2=M86EL7U]T86)S7W!R969E<F5N8V5S)R`]/B`B4')E9F5R96YC97,B+`H)
M)VUA:6Q?7W1A8G-?=VAI=&5?;&ES="<@/3X@(E=H:71E($QI<W0B+`H))VUA
M:6Q?7W1A8G-?8FQO8VME9%]D;VUA:6YS)R`]/B`B0FQA8VL@3&ES="(L"@DG
M;6%I;%]?=&%B<U]M86EL7W%U975E)R`]/B`B36%I;"!1=65U92(L"@DG<V5R
M=F5R7W!R969E<F5N8V5S7U]U<V5?=F]C86)U;&%R>2<@/3X@(D-H96-K('1H
M92!P87-S=V]R9',@9F]R(&UA:6QB;WAE<R!I;B!T:&4@9&EC=&EO;F%R>2(L
M"@DG<V5R=F5R<U]L:7-T7U]A8V-O=6YT7V1I<V%B;&5D)R`]/B`B26YF;W)M
M871I;VX@<75E<GD@:7,@9&ES86)L960@9F]R('1H:7,@<V5R=F5R+B(L"@DG
M<V5R=F5R<U]L:7-T7U]P;&5A<V5?=V%I="<@/3X@(E%U97)Y:6YG('-L879E
M('-E<G9E<G,N("4Q(%1H:7,@;W!E<F%T:6]N(&UI9VAT('1A:V4@<V]M92!T
M:6UE+B`E,B!0;&5A<V4@=V%I="XN+B(L"@DG<V5R=F5R<U]L:7-T7U]R96UO
M=F5?<&%G95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@<VQA=F4@<V5R=F5R
M(&%C8V]U;G1S('=I;&P@8F4@<F5M;W9E9#HB+`H))W-E<G9E<G-?;&ES=%]?
M<V5L96-T7W-L879E7W-E<G9E<G-?=&]?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!S;&%V92!S97)V97)S('1O(&)E(')E;6]V960N(BP*"2=S97)V97)S7VQI
M<W1?7W1O=&%L7V9I;&5S)R`]/B`B4VQA=F4@<V5R=F5R<R(L"@DG<V5R=F5R
M<U]L:7-T7U]U;F%B;&5?=&]?9V5T7W-L879E<U]N=6UB97(G(#T^(")5;F%B
M;&4@=&\@9&5T97)M:6YE('1H92!N=6UB97(@;V8@<VQA=F4@<V5R=F5R<R(L
M"@DG<V5R=F5R<U]L:7-T7U]U;F%B;&5?=&]?<F5M;W9E)R`]/B`B56YA8FQE
M('1O(')E;6]V92!T:&4@<VQA=F4@<V5R=F5R(&%C8V]U;G0Z("4Q(BP*"2=S
M97)V97)S7VQI<W1?7WEO=5]H879E7W1O;U]M86YY7W-L879E<R<@/3X@(EEO
M=2!H879E(&UO<F4@<VQA=F4@<V5R=F5R<R!A8V-O=6YT<R!S970@=7`@=&AA
M;B!I="!I<R!A;&QO=V5D(&)Y('EO=7(@;&EC96YS92!K97DN(BP*"2=S97)V
M97)T<F%F9FEC;&ES=%]H96%D97(G(#T^(")397)V97(@=')A9F9I8R(L"@DG
M<V5S<VEO;E]?:6YV86QI9%]I9&QE7W1I;64G(#T^(")397-S:6]N(&ED;&4@
M=&EM92!I<R!I;G9A;&ED+B(L"@DG<V5S<VEO;E]?:6YV86QI9%]L;V=I;E]A
M='1E;7!T<R<@/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',@=F%L=64@<VAO
M=6QD(&)E(&$@<&]S:71I=F4@:6YT96=E<BXB+`H))W-E<W-I;VY?7VEN=F%L
M:61?;&]G:6Y?:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN(&EN=&5R=F%L
M('9A;'5E('-H;W5L9"!B92!A('!O<VET:79E(&EN=&5G97(N(BP*"2=S97-S
M:6]N7U]I;G9A;&ED7VQO9VEN7VQO8VM?=&EM92<@/3X@(DEN=F%L:60@;&]G
M:6X@;&]C:R!T:6UE('9A;'5E('-H;W5L9"!B92!A('!O<VET:79E(&EN=&5G
M97(N(BP*"2=S97-S:6]N<U]?86=R965M96YT)R`]/B`B665S+"!)('=I<V@@
M=&\@96YD('1H97-E('-E<W-I;VYS+B(L"@DG<V5S<VEO;G-?7VEN=E]L;V=I
M;E]A='1E;7!T<R<@/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',B+`H))W-E
M<W-I;VYS7U]I;G9?;&]G:6Y?:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN
M(&EN=&5R=F%L(BP*"2=S97-S:6]N<U]?:6YV7VQO9VEN7VQO8VM?=&EM92<@
M/3X@(DEN=F%L:60@;&]G:6X@;&]C:R!T:6UE(BP*"2=S97-S:6]N<U]?;6EN
M)R`]/B`B36EN=71E<R(L"@DG<V5S<VEO;G-?7W)E<75I<F5D7V9I96QD<R<@
M/3X@(E)E<75I<F5D(&9I96QD<RXB+`H))W-E<W-I;VYS7U]S96QE8W1?<V5S
M<VEO;G-?9F]R7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@<V5S<VEO;G,@=&\@
M8F4@96YD960N(BP*"2=S97-S:6]N<U]?<V5S<VEO;E]I9&QE7W1I;64G(#T^
M(")397-S:6]N(&ED;&4@=&EM92(L"@DG<V5S<VEO;G-?7W-E<W-I;VY?<V5T
M=7`G(#T^("),;V=I;B!3971T:6YG<R(L"@DG<V5S<VEO;G-?7W-E<W-I;VYS
M7VUA;F%G96UE;G0G(#T^(")397-S:6]N<R!-86YA9V5M96YT(BP*"2=S97-S
M:6]N<U]?=6YA8FQE7W-E='5P7VEN=F%L:61?;&]G:6Y?871T96UP=',G(#T^
M(")5;F%B;&4@=&\@<V5T('5P('1H92!N=6UB97(@;V8@:6YV86QI9"!L;V=I
M;B!A='1E;7!T<SH@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?<V5T=7!?:6YV
M86QI9%]L;V=I;E]I;G1E<G9A;"<@/3X@(E5N86)L92!T;R!S970@=7`@:6YV
M86QI9"!L;V=I;B!I;G1E<G9A;#H@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?
M<V5T=7!?:6YV86QI9%]L;V=I;E]L;V-K7W1I;64G(#T^(")5;F%B;&4@=&\@
M<V5T('5P(&EN=F%L:60@;&]G:6X@;&]C:R!T:6UE.B`E,2(L"@DG<V5S<VEO
M;G-?7W5N86)L95]S971U<%]S97-S:6]N7VED;&4G(#T^(")5;F%B;&4@=&\@
M<V5T('5P('-E<W-I;VX@:61L92!T:6UE.B`E,2(L"@DG<V5S<VEO;G-?7W1A
M8G-?8W!?<V5S<VEO;G,G(#T^("=#4"!397-S:6]N<R<L"@DG<V5S<VEO;G-?
M7W1A8G-?9G1P7W-E<W-I;VYS)R`]/B`G1E10(%-E<W-I;VYS)RP*"2=S97-S
M:6]N<U]?9G1P7W-E<W-I;VYS7VQO9VEN)R`]/B`G1E10('5S97(@;&]G:6XG
M+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?9&]M86EN)R`]/B`G1&]M86EN
M(&YA;64G+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?<&%T:"<@/3X@)T-U
M<G)E;G0@;&]C871I;VXG+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?9FEL
M92<@/3X@)T9I;&4@;F%M92<L"@DG<V5S<VEO;G-?7V9T<%]S97-S:6]N<U]A
M8W1I;VXG(#T^("=3=&%T=7,G+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?
M<W!E960G(#T^("=3<&5E9"P@2T(O4R<L"@DG<V5S<VEO;G-?7V9T<%]S97-S
M:6]N<U]C;VUP)R`]/B`G4')O9W)E<W,L("4G+`H*"@DG<VET95]A<'!S7U]A
M8V-E<W-?;&5V96PG(#T^("=!8V-E<W,@;&5V96PG+`H))W-I=&5?87!P<U]?
M86-C97-S7VQE=F5L7V-O;6UE<F-I86PG(#T^("=#;VUM97)C:6%L)RP*"2=S
M:71E7V%P<'-?7V%C8V5S<U]L979E;%]F<F5E)R`]/B`G1G)E92<L"@DG<VET
M95]A<'!S7U]A8W1I;VY?:6YS=&%L;&5R)R`]/B`B4VET92!A<'!L:6-A=&EO
M;B!I;G-T86QL871I;VXB+`H))W-I=&5?87!P<U]?86-T:6]N7W)E8V]N9FEG
M=7)E)R`]/B`B4VET92!A<'!L:6-A=&EO;B!R96-O;F9I9W5R:6YG(BP*"2=S
M:71E7V%P<'-?7V5X=')A7V9I;&5S7W1I=&QE)R`]/B`G5VAA="!T;R!D;R!W
M:71H('1H92!F:6QE<S\G+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R
M;FEN9R<@/3X@)U1H92!C;VYT96YT<R!O9B!T:&4@9&ER96-T;W)Y("4Q('=I
M;&P@8F4@<F5W<FET=&5N('1O(&5N<W5R92!T:&4@8VQE86X@:6YS=&%L;&%T
M:6]N(&%N9"!P<F]P97(@=V]R:R!O9B!T:&4@87!P;&EC871I;VXN(%-O+"!I
M9B!Y;W4@:&%V92!A;GD@=F%L=6%B;&4@9&%T82!S=&]R960@=VET:&EN('1H
M92!D;VUA:6XL('EO=2!S:&]U;&0@8F%C:R!T:&5M('5P(&]R(&UO=F4@=&\@
M86YO=&AE<B!L;V-A=&EO;B!B969O<F4@>6]U('!R;V-E960@=VET:"!T:&4@
M:6YS=&%L;&%T:6]N+B!9;W4@8V%N(&)R;W=S92!T:&4@9&]M86EN(&-O;G1E
M;G0@=VET:"`E,BXG+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R;FEN
M9U]B<F]W<V4G(#T^("=B<F]W<V4@=&AE(&1O;6%I;B!C;VYT96YT('=I=&@@
M1FEL92!-86YA9V5R)RP*"2=S:71E7V%P<'-?7V5X=')A7V9I;&5S7VQE9V5N
M9"<@/3X@)U=H870@=&\@9&\@=VET:"!T:&4@9FEL97,_)RP*"2=S:71E7V%P
M<'-?7V5X=')A7V9I;&5S7V1E;&5T92<@/3X@)U)E;6]V92!A;&P@9FEL97,@
M:6X@=&AE(&1O8W5M96YT(')O;W0@9&ER96-T;W)Y+B<L"@DG<VET95]A<'!S
M7U]E>'1R85]F:6QE<U]K965P)R`]/B`G2V5E<"!E>&ES=&EN9R!F:6QE<RP@
M=VAE;B!P;W-S:6)L92X@3F]T92!T:&%T(&%P<&QI8V%T:6]N(&9I;&5S('=I
M;&P@;W9E<G=R:71E('1H92!E>&ES=&EN9R!F:6QE<R!A;GEW87DL(&%N9"!T
M:&4@97AT<F$@9FEL97,@;6%Y(&-A=7-E(&%P<&QI8V%T:6]N('1O(&)E:&%V
M92!I;F-O<G)E8W1L>2XG+`H))W-I=&5?87!P<U]?;F]?=F%C86YT7W-I=&5?
M87!P<R<@/3X@(EEO=2!H879E(&YO(&-O;6UE<F-I86P@<VET92!A<'!L:6-A
M=&EO;G,@=&\@861D+B(L"@DG<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'`G
M(#T^(")#;&EE;G1S('5S:6YG(&-O;6UE<F-I86P@<VET92!A<'!L:6-A=&EO
M;B`E,2(L"@DG<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'!?861D)R`]/B`B
M4V5L96-T('1H92!C;&EE;G1S('=H;R!S:&]U;&0@=7-E('1H:7,@87!P;&EC
M871I;VXB+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;"<@/3X@
M)U=O=6QD('EO=2!L:6ME('1O(&-R96%T92!A(&YE=R!C=7-T;VT@8G5T=&]N
M(&9O<B!A8V-E<W-I;F<@=&AI<R!A<'!L:6-A=&EO;C\G+`H))W-I=&5?87!P
M<U]?8W5S=&]M7V)U='1O;E]L979E;%]F86QS95]D;VUA:6Y?=7-E<E]O;FQY
M)R`]/B`G3F\G+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]D
M;VUA:6Y?=7-E<E]O;FQY)R`]/B`G665S)RP*"2=S:71E7V%P<'-?7V-U<W1O
M;5]B=71T;VY?;&5V96Q?9F%L<V4G(#T^("=.;R<L"@DG<VET95]A<'!S7U]C
M=7-T;VU?8G5T=&]N7VQE=F5L7V1O;6%I;B<@/3X@)UEE<RP@86YD(&UA:V4@
M:70@879A:6QA8FQE(&9O<B!T:&4@8W5R<F5N="!D;VUA:6X@;VYL>2XG+`H)
M)W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]C;&EE;G0G(#T^("=9
M97,L(&%N9"!M86ME(&ET(&%V86EL86)L92!F;W(@86QL(&1O;6%I;G,@;V8@
M=&AE(&-L:65N="XG+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E
M;%]A9&UI;B<@/3X@)UEE<RP@86YD(&UA:V4@:70@879A:6QA8FQE(&9O<B!A
M;&P@9&]M86EN<RXG+`H))W-I=&5?87!P<U]?9&5S8W)I<'1I;VXG(#T^(")$
M97-C<FEP=&EO;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]S87!P7U\G
M(#T^(")4:&4@9&ER96-T;W)Y(%PB)3%<(B!I<R!U<V5D(&)Y(&%N;W1H97(@
M<VET92!A<'!L:6-A=&EO;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]F
M<%]?)R`]/B`B5&AE(&1I<F5C=&]R>2!<(B4Q7"(@:7,@=7-E9"!B>2!T:&4@
M1G)O;G1086=E(&%P<&QI8V%T:6]N(BP*"2=S:71E7V%P<'-?7V1I<E]U<V5D
M7V)Y7W5N:VYO=VY?7R<@/3X@(E1H92!D:7)E8W1O<GD@7"(E,5PB(&%L<F5A
M9'D@97AI<W1S(BP*"2=S:71E7V%P<'-?7V9I;&5?;F%M92<@/3X@(E-I=&4@
M87!P;&EC871I;VX@<&%C:V%G92!F:6QE;F%M92(L"@DG<VET95]A<'!S7U]I
M;G-T86QL871I;VY?;G5M8F5R)R`]/B`B26YS=&%N8V5S(BP*"2=S:71E7V%P
M<'-?7VEN<W1A;&QE9%]I;E]?)R`]/B`B:6YS=&%L;&5D(&EN("4Q(BP*"2=S
M:71E7V%P<'-?7VEN=F%L:61?:6YS=&%L;%]P<F5F:7@G(#T^("));G9A;&ED
M(&EN<W1A;&QA=&EO;B!P<F5F:7@B+`H))W-I=&5?87!P<U]?:6YV86QI9%]P
M86-K86=E)R`]/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(&EN=F%L
M:60N(BP*"2=S:71E7V%P<'-?7V5R<F]R7W1E<W1?<&%C:V%G92<@/3X@(E1H
M:7,@<&%C:V%G92!F:6QE(&ES(&EN=F%L:60N7&XE,2(L"@DG<VET95]A<'!S
M7U]E<G)O<E]T97-T7W!A8VMA9V5?=F%U;'0G(#T^(")4:&ES(&9I;&4@:7,@
M;F]T(&$@=F%L:60@<VET92!A<'!L:6-A=&EO;B!P86-K86=E+EQN)3$B+`H)
M)W-I=&5?87!P<U]?97)R;W)?861D7W!A8VMA9V5?7R<@/3X@(E5N86)L92!T
M;R!I;G-T86QL('1H92!S:71E(&%P<&QI8V%T:6]N('!A8VMA9V4N7&XE,2(L
M"@DG<VET95]A<'!S7U]K97E?<W1A='5S)R`]/B`G3&EC96YS:6YG)RP*"2=S
M:71E7V%P<'-?7VME>5]S=&%T=7-?9G)E92<@/3X@)T1I<W1R:6)U=&5D(&9R
M965L>2X@3F\@;&EC96YS92!K97D@<F5Q=6ER960G+`H))W-I=&5?87!P<U]?
M:V5Y7W-T871U<U]O:R<@/3X@)U1H92!R97%U:7)E9"!L:6-E;G-E(&ME>2!I
M<R!I;G-T86QL960G+`H))W-I=&5?87!P<U]?:V5Y7W-T871U<U]P<F]B;&5M
M)R`]/B`G5&AE(')E<75I<F5D(&QI8V5N<V4@:V5Y(&ES(&YO="!I;G-T86QL
M960G+`H))W-I=&5?87!P<U]?;F%M92<@/3X@(DYA;64B+`H))W-I=&5?87!P
M<U]?;F]?9&]M86EN<R<@/3X@)U1H92!S:71E(&%P<&QI8V%T:6]N(&-A;FYO
M="!B92!I;G-T86QL960N(%1H97)E(&ES(&%L<F5A9'D@86YO=&AE<B!S:71E
M(&%P<&QI8V%T:6]N(&EN<W1A;&QE9"!I;B!T:&4@<F]O="!D:7)E8W1O<GD@
M;V8@=&AI<R!D;VUA:6XN($-O;G-I9&5R(&-R96%T:6YG(&$@<W5B9&]M86EN
M(&9O<B!T:&4@<VET92!A<'!L:6-A=&EO;BXG+`H))W-I=&5?87!P<U]?<&%C
M:V%G95]I;F9O7R<@/3X@(E-I=&4@07!P;&EC871I;VX@4&%C:V%G92!);F9O
M<FUA=&EO;B(L"@DG<VET95]A<'!S7U]P86-K86=E7VEN=&5G<F%T960G(#T^
M(")B=6EL="UI;B!P86-K86=E+"!C86YN;W0@8F4@<F5M;W9E9"(L"@DG<VET
M95]A<'!S7U]P;V]L7W1I=&QE)R`]/B`G07!P;&EC871I;VX@<&]O;"!O9B`E
M,2<L"@DG<VET95]A<'!S7U]P;V]L7W)E;6]V95]T:71L92<@/3X@(E1H92!F
M;VQL;W=I;F<@<VET92!A<'!L:6-A=&EO;B!P86-K86=E<R!W:6QL(&)E(')E
M;6]V960@9G)O;2!T:&4@<&]O;#HB+`H))W-I=&5?87!P<U]?<&]O;%]S96QE
M8W1?<&%C:V%G97-?=&]?<F5M;W9E)R`]/B`G4V5L96-T('1H92!S:71E(&%P
M<&QI8V%T:6]N('!A8VMA9V5S('1O(&)E(')E;6]V960N)RP*"2=S:71E7V%P
M<'-?7W!O;VQ?<V5L96-T7W!A8VMA9V5S7W1O7V%D9"<@/3X@)U-E;&5C="!T
M:&4@<VET92!A<'!L:6-A=&EO;B!P86-K86=E<R!T;R!A9&0@=&\@=&AE('!O
M;VPN)RP*"2=S:71E7V%P<'-?7W!O;VQ?861D7W1I=&QE)R`]/B`G061D('-I
M=&4@87!P;&EC871I;VX@<&%C:V%G97,@=&\@=&AE('!O;VPG+`H))W-I=&5?
M87!P<U]?<F5L96%S92<@/3X@(E)E;&5A<V4B+`H))W-I=&5?87!P<U]?<F5Q
M=6ER97-?879A:6)L95]T:71L92<@/3X@(D%V86EL86)L92(L"@DG<VET95]A
M<'!S7U]R97%U:7)E<U]E<G)O<B<@/3X@(E1H92!S:71E(&%P<&QI8V%T:6]N
M(')E<75I<F5S('1H92!R97-O=7)C97,L('=H:6-H(&%R92!N;W0@8W5R<F5N
M=&QY(&%V86EL86)L92(L"@DG<VET95]A<'!S7U]R97%U:7)E<U]E<G)O<E]?
M)R`]/B`B5&AE('-I=&4@87!P;&EC871I;VX@<F5Q=6ER97,@=&AE(')E<V]U
M<F-E<RP@=VAI8V@@87)E(&YO="!C=7)R96YT;'D@879A:6QA8FQE.EQN)3$B
M+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?9&5S8W)I<'1I;VY?7R<@
M/3X@(B4Q+"`E,BX@<F5Q=6ER960Z("4S+B!A=F%I;&%B;&4Z("4T+B(L"@DG
M<VET95]A<'!S7U]R97%U:7)E<U]E<G)O<E]H;W-T:6YG7U\G(#T^(")4:&4@
M<F5Q=6ER960@<F5S;W5R8V4@:7,@;F]T(&5N86)L960@:6X@9&]M86EN(&AO
M<W1I;F<@9F5A='5R97,N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S7V5R<F]R
M7VQI;6ET<U]?)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E(&ES(&YO="!A
M=F%I;&%B;&4@9'5E('1O(&1O;6%I;B!L:6UI=',@9&5F:6YE9"XB+`H))W-I
M=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?<WES=&5M7V1I<VM?<W!A8V5?7R<@
M/3X@(DYO="!E;F]U9V@@9G)E92!D:7-K('-P86-E(&]N("4Q+B!0;&5A<V4@
M9G)E92!U<"!S;VUE(&1I<VL@<W!A8V4@86YD('1R>2!I;G-T86QL:6YG('1H
M:7,@87!P;&EC871I;VX@86=A:6XN(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S
M7V5R<F]R7W9E<G-I;VY?7R<@/3X@(E1H92!C;VUP;VYE;G0@=F5R<VEO;B!O
M;B!T:&4@<V5R=F5R(&1O97,@;F]T('-A=&ES9GD@=&AE('-I=&4@87!P;&EC
M871I;VXG<R!R97%U:7)E;65N=',N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S
M7V5R<F]R7W-U8F1O;6%I;E]?)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E
M(&ES(&YO="!E;F%B;&5D(&EN('-U8F1O;6%I;B!F96%T=7)E<RXB+`H))W-I
M=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?=&ET;&4G(#T^(")$97-C<FEP=&EO
M;B(L"@DG<VET95]A<'!S7U]R97%U:7)E<U]N86UE7W1I=&QE)R`]/B`B4F5Q
M=6ER960B+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?='EP95]T:71L92<@/3X@
M(E1Y<&4B+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?=F%L=65?=&ET;&4G(#T^
M(")686QU92(L"@DG<VET95]A<'!S7U]R97-O=7)C95]U<V5D7V)Y7W-A<'`G
M(#T^(")4:&ES(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D('-I
M=&4@87!P;&EC871I;VXB+`H))W-I=&5?87!P<U]?<F]O=%]U<V5D7V)Y7W-A
M<'`G(#T^(")4:&ES(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D
M('-I=&4@87!P;&EC871I;VXB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P<%]P
M:V=?=&]?:6YS=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L:6-A=&EO
M;B!P86-K86=E('1O(&EN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P
M<%]P:V=S7W1O7W5N:6YS=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L
M:6-A=&EO;B!P86-K86=E<R!T;R!U;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?
M<V5L96-T7V%P<%]T;U]A<'!L:6-A=&EO;B<@/3X@(E-E;&5C="!T:&4@<VET
M92!A<'!L:6-A=&EO;B!T;R!O<&5N(BP*"2=S:71E7V%P<'-?7W-E;&5C=%]A
M<'!?=&]?<F5C;VYF:6=U<F4G(#T^(")396QE8W0@=&AE('-I=&4@87!P;&EC
M871I;VX@=&\@<F5C;VYF:6=U<F4B+`H))W-I=&5?87!P<U]?<V5L96-T7V%P
M<'-?=&]?=6YI;G-T86QL)R`]/B`B4V5L96-T('1H92!S:71E(&%P<&QI8V%T
M:6]N<R!T;R!U;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V-L:65N
M=',G(#T^(")396QE8W0@8VQI96YT<R(L"@DG<VET95]A<'!S7U]S:71E7V%P
M<%]P:V=S)R`]/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E<R(L"@DG<VET
M95]A<'!S7U]S:71E7V%P<%]P:V=S7V%D9"<@/3X@(D%D9"!N97<@<VET92!A
M<'!L:6-A=&EO;B!P86-K86=E(BP*"2=S:71E7V%P<'-?7W-I=&5?87!P7W!K
M9W-?;6%N86=E;65N="<@/3X@(D%P<&QI8V%T:6]N(%9A=6QT(BP*"2=S:71E
M7V%P<'-?7W-I=&5?87!P<R<@/3X@(E-I=&4@07!P;&EC871I;VYS(BP*"2=S
M:71E7V%P<'-?7W-I=&5?87!P<U]M86YA9V5M96YT)R`]/B`B26YS=&%L;&5D
M($%P<&QI8V%T:6]N<R(L"@DG<VET95]A<'!S7U]S:71E7V%P<%]P:V=S7VEN
M<W1A;&QA=&EO;B<@/3X@)TEN<W1A;&QA=&EO;CH@<V5L96-T('1H92!A<'!L
M:6-A=&EO;B!T;R!B92!I;G-T86QL960G+`H))W-I=&5?87!P<U]?<VET95]A
M<'!?<&MG<U]I;G-T86YC97,G(#T^("=);G-T86QL871I;VYS(&]F('1H92`E
M,2!!<'!L:6-A=&EO;B<L"@DG<VET95]A<'!S7U]U;FEN<W1A;&Q?<V%P<"<@
M/3X@(E5N:6YS=&%L;"!A<'!L:6-A=&EO;G,@9G)O;2!D;VUA:6X@)3$B+`H)
M)W-I=&5?87!P<U]?=6YI;G-T86QL7W-A<'!P:V<G(#T^(")5;FEN<W1A;&P@
M87!P;&EC871I;VX@<&%C:V%G97,B+`H))W-I=&5?87!P<U]?=7!L;V%D7W-I
M=&5?87!P7W!K9U]T:71L92<@/3X@(E5P;&]A9"!N97<@<VET92!A<'!L:6-A
M=&EO;B!P86-K86=E(BP*"2=S:71E7V%P<'-?7W9E<G-I;VXG(#T^(")697)S
M:6]N(BP*"2=S:71E7V)U:6QD97)?<F5Q=6ER97,G(#T^("<E,2`M("4S)RP*
M"2=S:V5L971O;E]?861M:6Y?;&%B96PG(#T^(")!9&UI;FES=')A=&]R(&1E
M9FEN960@<VME;&5T;VXB+`H))W-K96QE=&]N7U]C;&EE;G1?;&%B96PG(#T^
M("(E,2!D969I;F5D('-K96QE=&]N(BP*"2=S:V5L971O;E]?861M:6Y?<&%G
M92<@/3X@(E-K96QE=&]N(&UA;F%G96UE;G0B+`H))W-K96QE=&]N7U]F:6QE
M<U]L:7-T)R`]/B`B4VME;&5T;VX@8V]N=&5N=',B+`H))W-K96QE=&]N7U]A
M<F-H:79E<E]N;W1?:6YS=&%L;&5D)R`]/B`B56YA8FQE('1O('5N<&%C:R!T
M:&4@<VME;&5T;VXN($%R8VAI=F5R(&ES('!O<W-I8FQY(&YO="!I;G-T86QL
M960@;VX@=&AE('-E<G9E<BX@0V]N=&%C="!T:&4@)%!23T1?3D%-12!A9&UI
M;FES=')A=&]R('1O(&AA=F4@=&AE(&%R8VAI=F5R('-O9G1W87)E(&EN<W1A
M;&QE9"XB+`H))W-K96QE=&]N7U]C;&EE;G1?<&%G92<@/3X@(E9I<G1U86P@
M:&]S="!S:V5L971O;B!M86YA9V5M96YT(BP*"2=S:V5L971O;E]?87)C:&EV
M95]C;W)R=7!T960G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R960@=&AA
M="!T:&4@87)C:&EV92!F:6QE(&ES(&5I=&AE<B!C;W)R=7!T(&]R('1H:7,@
M87)C:&EV92!T>7!E(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:V5L971O;E]?
M87)C:&EV95]T;V]?;&%R9V4G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R
M960@=&AA="!T:&4@87)C:&EV92!F:6QE(&ES('1O;R!L87)G92XB+`H))W-K
M96QE=&]N7U]N;W1?<W5P<&]R=&5D7V%R8VAI=F5?='EP92<@/3X@(E1H:7,@
M='EP92!O9B!A<F-H:79E("AF:6QE("4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*
M"2=S:V5L971O;E]?=7!L;V%D7V%R8VAI=F5?9FEL92<@/3X@(E5P;&]A9"!S
M:V5L971O;B!A<F-H:79E(&9I;&4B+`H))W-K:6Y?9&]W;FQO861?7W1I=&QE
M)R`]/B`G1&]W;FQO860@4VMI;B<L"@DG<VMI;E]D;W=N;&]A9%]N;W=?7W1I
M=&QE)R`]/B`G4VMI;B!D;W=N;&]A9"!I;B!P<F]G<F5S<R<L"@DG<VMI;E]D
M;W=N;&]A9%]N;W=?7W1E>'0G(#T^("=4:&4@<VMI;B!P86-K86=E(&-R96%T
M:6]N(&ES(&EN('!R;V=R97-S+CQB<CY4:&ES('!R;V-E9'5R92!M87D@=&%K
M92!S;VUE('1I;64N/&)R/B!/;F-E('1H92!D:6%L;V<*=VEN9&]W(&%P<&5A
M<G,L('EO=2!C86X@8V]N=&EN=64@;W!E<F%T:6YG('1H92!C;VYT<F]L('!A
M;F5L+B<L"@DG<VMI;E]F:6QE7U]H96QP7V9O<E]U<VEN9U]T>7!E<R<@/3X@
M(E!L96%S92P@=7-E('1H92!S:VEN(&%R8VAI=F5S(&EN(&]N92!O9B!T:&4@
M9F]L;&]W:6YG(&9O<FUA=',B+`H))W-K:6Y?:6YF;U]?=&ET;&4G(#T^("=3
M:VEN(%!R;W!E<G1I97,G+`H))W-K:6Y?;6YG7V5R<E]?<G!M7VYO=%]S:VEN
M)PD]/B`G5&AI<R!24$T@:7,@;F]T(&$@8V]N=')O;"!P86YE;"!S:VEN('!A
M8VMA9V4G+`H))W-K:6Y?;6YG7V5R<E]?<'-A7VEN<W1A;&Q?;F]R96QO8R<@
M/3X@)T9A:6QE9"!T;R!I;G-T86QL(')P;2UB87-E9"!S:VEN(&EN('1H92!S
M<&5C:69I960@;&]C871I;VXN)RP*"2=S:VEN7VUN9U]E<G)?7V%L<F5A9'E?
M97AI<W1S)R`]/B`G5&AE('-K:6X@:6YS=&%L;&%T:6]N(&1I<F5C=&]R>2!A
M;')E861Y(&5X:7-T<RP@86YD('1H97)E(&ES(&$@<VMI;B!P86-K86=E(&1E
M<&QO>65D+B<L"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;VYR<&TG
M(#T^("=4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!24$T@<VMI
M;B!P86-K86=E+B<L"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;W-K
M:6XG(#T^("=4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!S:VEN
M('!A8VMA9V4N)RP*"2=S:VEN7VUN9U]E<G)?7W)P;5]U<&=R861E7V)A<V4G
M(#T^(")4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"`D4%)/1%].
M04U%('-K:6X@<&%C:V%G92XB+`H))W-K:6Y?;6YG7V5R<E]?<G!M7W5P9W)A
M9&5?;W1H97(G(#T^("=5;F%B;&4@=&\@:6YS=&%L;"!T:&4@<VMI;CH@:6YV
M86QI9"!S:VEN(&9O<FUA="XG+`H))W-K:6Y?;6YG7V5R<E]?;F]?85]S:VEN
M)R`]/B`B5&AE('5P;&]A9&5D(&9I;&4@:7,@;F]T(&$@=F%L:60@)%!23T1?
M3D%-12!S:VEN('!A8VMA9V4N(BP*"2=S:VEN7W5P;&]A9%]?=&ET;&4G(#T^
M("=5<&QO860@3F5W(%-K:6XG+`H))W-K:6Y?=7!L;V%D7U]A;')E861Y7V5X
M:7-T<R<@/3X@(E1H92!S:VEN("<E,2<@86QR96%D>2!E>&ES=',B+`H))W-K
M:6Y?=7!L;V%D7U]U;F%B;&5?=&]?87!P;'DG(#T^(")4:&4@=7!L;V%D960@
M9FEL92!D;V5S(&YO="!C;VYT86EN(&$@4&QE<VL@<VMI;BP@;W(@=&AE(&%R
M8VAI=F4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:VEN7W5P;&]A
M9%]?9FEL95]N86UE)R`]/B`G4&%T:"!T;R!T:&4@<VMI;B!P86-K86=E(&9I
M;&4G+`H))W-K:6YS7VQI<W1?7W1I=&QE)R`]/B`G4VMI;G,@4F5P;W-I=&]R
M>2<L"@DG<VMI;G-?<F5M;W9E7U]T:71L92<@/3X@)U-K:6X@4F5M;W9A;"<L
M"@DG<VMI;G-?<F5M;W9E7U]S96QE8W1?<VMI;G-?9F]R7W)E;6]V92<@/3X@
M)U-E;&5C="!T:&4@<VMI;G,@=&\@8F4@<F5M;W9E9"XG+`H))W-L879E7V-E
M<G1?7W!A9V5?=&ET;&4G(#T^(")3;&%V92!S97)V97(@)3$@8V5R=&EF:6-A
M=&4@<V5T=7`N(BP*"2=S;&%V95]S97)V97)?7V%D;6EN7V%P86-H95]I<U]N
M;W1?=V]R:R<@/3X@(D%D;6EN(&%P86-H92!S97)V97(@9&]E<R!N;W0@9G5N
M8W1I;VXZ('1H92!P;W)T(')E:F5C=',@8V]N;F5C=&EO;G,N(BP*"2=S;&%V
M95]S97)V97)?7V%L;%]O:R<@/3X@(D%L;"!S97)V:6-E<R!F=6YC=&EO;B!P
M<F]P97)L>2!A;F0@=&AE<F4@87)E(&YO('!R;V)L96T@9&]M86EN<R!O<B!C
M;&EE;G1S(&]N('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?
M7V)A9%]C;&EE;G1S)R`]/B`B5&AE<F4@87)E('!R;V)L96T@8VQI96YT<R!O
M;B!T:&4@<VQA=F4@<V5R=F5R+B(L"@DG<VQA=F5?<V5R=F5R7U]B861?9&]M
M86EN<R<@/3X@(E1H97)E(&%R92!P<F]B;&5M(&1O;6%I;G,@;VX@=&AE('-L
M879E('-E<G9E<BXB+`H))W-L879E7W-E<G9E<E]?8F%D7V1O;6%I;G-?86YD
M7V-L:65N=',G(#T^(")4:&5R92!A<F4@<')O8FQE;2!C;&EE;G1S(&%N9"!D
M;VUA:6YS(&]N('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?
M7V-E<G1?9FEL96YA;65?:7-?96UP='DG(#T^(")5<&QO861E9"!S;&%V92!S
M97)V97(@8V5R=&EF:6-A=&4@9FEL96YA;64@:7,@96UP='DN(BP*"2=S;&%V
M95]S97)V97)?7V-E<G1?:7-?:6YV86QI9"<@/3X@(E1H92!C97)T:69I8V%T
M92!U<V5D(&9O<B!T:&ES('-E<W-I;VX@9&ED(&YO="!P87-S('1H92!V97)I
M9FEC871I;VXN(BP*"2=S;&%V95]S97)V97)?7V-E<G1?:7-?;F]T7W-E="<@
M/3X@(E-33"!C97)T:69I8V%T92!F;W(@=&AI<R!S;&%V92!S97)V97(@=V%S
M(&YO="!I;G-T86QL960N(BP*"2=S;&%V95]S97)V97)?7V-E<G1?=&5X=&9I
M96QD7VES7V5M<'1Y)R`]/B`B57!L;V%D960@<VQA=F4@<V5R=F5R(&-E<G1I
M9FEC871E(&ES(&5M<'1Y+B(L"@DG<VQA=F5?<V5R=F5R7U]C;W5L9&YT7V-O
M;FYE8W0G(#T^(")&86EL960@=&\@8V]N;F5C="!T;R!H;W-T+B(L"@DG<VQA
M=F5?<V5R=F5R7U]D97-C<FEP=&EO;B<@/3X@(D1E<V-R:7!T:6]N(BP*"2=S
M;&%V95]S97)V97)?7V1O7VYO=%]R97%U97-T)R`]/B`B1&\@;F]T(')E<75E
M<W0@:6YF;W)M871I;VX@9G)O;2!T:&4@<V5R=F5R(BP*"2=S;&%V95]S97)V
M97)?7V5N=&5R<')I<V5?:7-?;F]T7W-U<'!O<G1E9"<@/3X@(E1H92`D4%)/
M1%].04U%('9E<G-I;VX@<G5N;FEN9R!O;B!T:&ES('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('1H92!-87-T97(@9F5A='5R92XB+`H))W-L879E7W-E<G9E
M<E]?9F]L;&]W:6YG7W-E<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B5&AE(&9O
M;&QO=VEN9R!S97)V:6-E<R!D;R!N;W0@9G5N8W1I;VX@;VX@=&AE('-L879E
M('-E<G9E<CH@)3$N(BP*"2=S;&%V95]S97)V97)?7VEN=F%L:61?;&]G:6Y?
M;W)?<&%S<W=O<F0G(#T^("));F-O<G)E8W0@;&]G:6X@86YD('!A<W-W;W)D
M+B(L"@DG<VQA=F5?<V5R=F5R7U]K97E?;&EM:71S)R`]/B`B66]U<B!K97D@
M86QL;W=S(&-R96%T:6YG("4Q('-L879E('-E<G9E<G,@86-C;W5N=',@;VYL
M>2XB+`H))W-L879E7W-E<G9E<E]?<&%G95]T:71L92<@/3X@(E-L879E('-E
M<G9E<B!A8V-O=6YT(BP*"2=S;&%V95]S97)V97)?7W)E<75E<W1?=&EM96]U
M="<@/3X@(E-E<G9E<B!D871A(')E=')I979A;"!T:6UE;W5T+B(L"@DG<VQA
M=F5?<V5R=F5R7U]S96QE8W1?<VQA=F5?<V5R=F5R<U]F;W)?<F5M;W9E)R`]
M/B`B4V5L96-T('-L879E('-E<G9E<B!A8V-O=6YT<R!T;R!B92!R96UO=F5D
M+B(L"@DG<VQA=F5?<V5R=F5R7U]S97)V97)?86-C;W5N=%]A;')E861Y7V5X
M:7-T)R`]/B`B<V5R=F5R(&%C8V]U;G0@=VET:"!S=6-H(&AO<W1N86UE(&%L
M<F5A9'D@97AI<W1S+B(L"@DG<VQA=F5?<V5R=F5R7U]S97)V97)?:6YF;U]I
M<U]N;W1?879A:6QA8FQE)R`]/B`B4VQA=F4@<V5R=F5R(&EN9F]R;6%T:6]N
M(&ES(&YO="!C=7)R96YT;'D@879A:6QA8FQE+B(L"@DG<VQA=F5?<V5R=F5R
M7U]S;VUE7W-E<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B4V]M92!S97)V:6-E
M<R!D;R!N;W0@9G5N8W1I;VX@;VX@=&AE('-L879E('-E<G9E<BXB+`H))W-L
M879E7W-E<G9E<E]?=6YA8FQE7V1E9FEN95]H;W-T;F%M92<@/3X@(E5N86)L
M92!T;R!D969I;F4@=&AE('-L879E('-E<G9E<B!H;W-T;F%M93H@)3$B+`H)
M)W-L879E7W-E<G9E<E]?=6YA8FQE7W1O7W)E<V]L=F5?:&]S=&YA;64G(#T^
M(")5;F%B;&4@=&\@<F5S;VQV92!T:&4@:&]S=&YA;64N(BP*"2=S;&%V95]S
M97)V97)?7W5N86)L95]T;U]S971?8V5R=&EF:6-A=&4G(#T^(")5;F%B;&4@
M=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@=&\@=&AE('-L879E('-E<G9E
M<CH@)3$B+`H))W-L879E7W-E<G9E<E]?=6YA8FQE7W1O7W5P9&%T92<@/3X@
M(E5N86)L92!T;R!U<&1A=&4@=&AE('-L879E('-E<G9E<B!P<F5F97)E;F-E
M<SH@)3$B+`H))W-L879E7W-E<G9E<E]?=6YK;F]W;E]E<G)O<B<@/3X@(E-E
M<G9E<B!R971U<FYE9"!U;FMN;W=N(&5R<F]R+B(L"@DG<W!A;6%S<V%S<VEN
M7U]T:71L92<@/3X@(E-P86T@9FEL=&5R(&-O;F9I9W5R871I;VXB+`H))W-P
M87=?7V5D:71?9FEL95]?)R`]/B`G5UE325=91R!E9&ET;W(Z("4Q)RP*"2=S
M<&%W;E]?=6YA8FQE7W1O7V5D:71?;F]?8F]D>2<@/3X@)U5N86)L92!T;R!E
M9&ET('1H:7,@9FEL92!B96-A=7-E(&ET(&1O97,@;F]T(&-O;G1A:6X@=&AE
M(#QB;V1Y/B!T86<N)RP*"2=S<&9?<&%R86UE=&5R<R<@/3X@)T5N86)L92!3
M4$8@<W!A;2!P<F]T96-T:6]N)RP*"2=S<&9?8F5H879I;W(G(#T^("=34$8@
M8VAE8VMI;F<@;6]D92<L"@DG<W!F7W)U;&5S)R`]/B`G4U!&(&QO8V%L(')U
M;&5S)RP*"2=S<&9?9W5E<W,G(#T^("=34$8@9W5E<W,G+`H))W-P9E]E>'`G
M(#T^("=34$8@97AP;&%N871I;VX@=&5X="<L"@DG<W!F7U]U;F%B;&5?=7!D
M871E)R`]/B`G56YA8FQE('1O('5P9&%T92!34$8@<&%R86UE=&5R<R<L"@DG
M<W!F7V)H=E]?8W)E871E7VAE861E<G-?;F]?8FQO8VLG(#T^("=/;FQY(&-R
M96%T92!296-E:79E9"U34$8@:&5A9&5R<RP@;F5V97(@8FQO8VLG+`H))W-P
M9E]B:'9?7W5S95]T;7!?97)R;W)S)R`]/B`G57-E('1E;7!O<F%R>2!E<G)O
M<B!N;W1I8V5S('=H96X@>6]U(&AA=F4@1$Y3(&QO;VMU<"!P<F]B;&5M<R<L
M"@DG<W!F7V)H=E]?<F5J96-T7VEF7V9A:6PG(#T^("=296IE8W0@;6%I;',@
M=VAE;B!34$8@<F5S;VQV97,@=&\@(F9A:6PB("AD96YY*2<L"@DG<W!F7V)H
M=E]?<F5J96-T7VEF7W-O9G1F86EL)R`]/B`G4F5J96-T(&UA:6QS('=H96X@
M4U!&(')E<V]L=F5S('1O(")S;V9T9F%I;"(G+`H))W-P9E]B:'9?7W)E:F5C
M=%]I9E]N975T<F%L)R`]/B`G4F5J96-T(&UA:6QS('=H96X@4U!&(')E<V]L
M=F5S('1O(")N975T<F%L(B<L"@DG<W!F7V)H=E]?<F5J96-T7VEF7VYO7W!A
M<W,G(#T^("=296IE8W0@;6%I;',@=VAE;B!34$8@9&]E<R!N;W0@<F5S;VQV
M92!T;R`B<&%S<R(G+`H))W-S:'1E<FU?7W1I=&QE)R`]/B`G4V5C=7)E(%-H
M96QL(%1E<FUI;F%L)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H96YT:6-A
M=&EO;E]W87)N:6YG)R`]/B`G3F]T93H@4&%S<W=O<F0@875T:&5N=&EC871I
M;VX@:7,@9&ES86)L960@:6X@=&AE(&QO8V%L(%-32"!S97)V97(@8V]N9FEG
M=7)A=&EO;BX@268@>6]U(&%R92!U;F%B;&4@=&\@8V]N;F5C="!U<VEN9R!T
M:&4@4U-((%1E<FUI;F%L+"!A<VL@=&AE(&%D;6EN:7-T<F%T;W(@=&\@<V5T
M(")087-S=V]R9$%U=&AE;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H
M+W-S:&1?8V]N9FEG(&9I;&4N)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H
M96YT:6-A=&EO;E]W87)N:6YG7V%D;6EN)R`]/B`G3F]T93H@4&%S<W=O<F0@
M875T:&5N=&EC871I;VX@:7,@9&ES86)L960@:6X@=&AE(&QO8V%L(%-32"!S
M97)V97(@8V]N9FEG=7)A=&EO;BX@268@>6]U(&%R92!U;F%B;&4@=&\@8V]N
M;F5C="!U<VEN9R!T:&4@4U-((%1E<FUI;F%L+"!P;&5A<V4@<V5T(")087-S
M=V]R9$%U=&AE;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H+W-S:&1?
M8V]N9FEG(&9I;&4N)RP*"2=S=&%T:7-T:6-S7U]A8W1I=F5?9&]M86EN<R<@
M/3X@(D%C=&EV92!D;VUA:6YS(BP*"2=S=&%T:7-T:6-S7U]C;&EE;G1S)R`]
M/B`B0VQI96YT<R(L"@DG<W1A=&ES=&EC<U]?<W5B9&]M86EN<R<@/3X@(E-U
M8F1O;6%I;G,B+`H))W-T871I<W1I8W-?7V-P=2<@/3X@(D-052(L"@DG<W1A
M=&ES=&EC<U]?9&%T86)A<V5S)R`]/B`B1&%T86)A<V5S(BP*"2=S=&%T:7-T
M:6-S7U]D8E]U<V5R<R<@/3X@(D1A=&%B87-E('5S97)S(BP*"2=S=&%T:7-T
M:6-S7U]D:7)S)R`]/B`B1&ER96-T;W)I97,B+`H))W-T871I<W1I8W-?7V1O
M;5]A8W1I=F4G(#T^(")!8W1I=F4B+`H))W-T871I<W1I8W-?7V1O;5]P87-S
M:79E)R`]/B`B4&%S<VEV92(L"@DG<W1A=&ES=&EC<U]?9&]M7W!R;V)L96TG
M(#T^(")0<F]B;&5M(BP*"2=S=&%T:7-T:6-S7U]D;VUA:6YS)R`]/B`B1&]M
M86EN<R(L"@DG<W1A=&ES=&EC<U]?9&]M86EN<U]W:71H7VAO<W0G(#T^(")$
M;VUA:6YS('=I=&@@:&]S=&EN9R(L"@DG<W1A=&ES=&EC<U]?9&]M<R<@/3X@
M(D1O;6%I;G,@(BP*"2=S=&%T:7-T:6-S7U]F:6QE<WES=&5M)R`]/B`B1FEL
M97-Y<W1E;2(L"@DG<W1A=&ES=&EC<U]?9V5N97)A;"<@/3X@(D=E;F5R86PB
M+`H))W-T871I<W1I8W-?7VAD9%]A=F%I;&%B;&4G(#T^(")!=F%I;&%B;&4B
M+`H))W-T871I<W1I8W-?7VAD9%]C87!A8VET>2<@/3X@(D-A<&%C:71Y(BP*
M"2=S=&%T:7-T:6-S7U]H9&1?=&]T86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES
M=&EC<U]?:&1D7W5S86=E)R`]/B`B2&%R9"!$:7-K(%5S86=E(BP*"2=S=&%T
M:7-T:6-S7U]H9&1?=7-E9"<@/3X@(E5S960B+`H))W-T871I<W1I8W-?7VEP
M)R`]/B`B25`@861D<F5S<R(L"@DG<W1A=&ES=&EC<U]?:V5Y7VYU;6)E<B<@
M/3X@(DME>2!N=6UB97(B+`H))W-T871I<W1I8W-?7VPQ)R`]/B`B3&%S="`Q
M(&UI;G5T92(L"@DG<W1A=&ES=&EC<U]?;#$U)R`]/B`B3&%S="`Q-2!M:6YU
M=&5S(BP*"2=S=&%T:7-T:6-S7U]L-2<@/3X@(DQA<W0@-2!M:6YU=&5S(BP*
M"2=S=&%T:7-T:6-S7U]L82<@/3X@(D-052!U<V%G92(L"@DG<W1A=&ES=&EC
M<U]?;6%I;%]A=71O<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*
M"2=S=&%T:7-T:6-S7U]M86EL7V)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=S
M=&%T:7-T:6-S7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@9W)O=7!S(BP*"2=S
M=&%T:7-T:6-S7U]M86EL7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG
M<W1A=&ES=&EC<U]?;6%I;%]R961I<F5C=',G(#T^(")-86EL(')E9&ER96-T
M<R(L"@DG<W1A=&ES=&EC<U]?;65M)R`]/B`B365M;W)Y(%5S86=E(BP*"2=S
M=&%T:7-T:6-S7U]M96U?=7-A9V4G(#T^(")5<V%G92(L"@DG<W1A=&ES=&EC
M<U]?;65M;W)Y7V)U9F9E<B<@/3X@(D)U9F9E<B(L"@DG<W1A=&ES=&EC<U]?
M;65M;W)Y7V-A8VAE9"<@/3X@(D-A8VAE9"(L"@DG<W1A=&ES=&EC<U]?;65M
M;W)Y7V9R964G(#T^(")&<F5E(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?<VAA
M<F5D)R`]/B`B4VAA<F5D(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?=&]T86PG
M(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?;65M;W)Y7W5S960G(#T^(")5
M<V5D(BP*"2=S=&%T:7-T:6-S7U]O<R<@/3X@(D]3(BP*"2=S=&%T:7-T:6-S
M7U]P<F]B;&5M7V-L:65N=',G(#T^(")0<F]B;&5M(&-L:65N=',B+`H))W-T
M871I<W1I8W-?7W!R;V)L96U?9&]M86EN<R<@/3X@(E!R;V)L96T@9&]M86EN
M<R(L"@DG<W1A=&ES=&EC<U]?<W=A<"<@/3X@(E-W87`@=7-A9V4B+`H))W-T
M871I<W1I8W-?7W-W87!?9G)E92<@/3X@(D9R964B+`H))W-T871I<W1I8W-?
M7W-W87!?=&]T86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?<W=A<%]U
M<V%G92<@/3X@(E5S86=E(BP*"2=S=&%T:7-T:6-S7U]S=V%P7W5S960G(#T^
M(")5<V5D(BP*"2=S=&%T:7-T:6-S7U]S>7-T96U?<W1A="<@/3X@(E-Y<W1E
M;2!S=&%T:7-T:6-S(BP*"2=S=&%T:7-T:6-S7U]U;F%B;&5?9&5F:6YE7V%C
M=&EV95]D;VUS)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN92!T:&4@;G5M8F5R
M(&]F(&%C=&EV92!D;VUA:6YS.B`E,2(L"@DG<W1A=&ES=&EC<U]?=6YA8FQE
M7V1E9FEN95]I;F%C=&EV95]D;VUS)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN
M92!T:&4@;G5M8F5R(&]F(&EN86-T:79E(&1O;6%I;G,Z("4Q(BP*"2=S=&%T
M:7-T:6-S7U]U<%]T:6UE)R`]/B`B4WES=&5M(%5P=&EM93H@(BP*"2=S=&%T
M:7-T:6-S7U]V97(G(#T^(")697)S:6]N(BP*"2=S=&%T:7-T:6-S7U]W96)?
M87!P<R<@/3X@(DIA=F$@87!P;&EC871I;VYS(BP*"2=S=&%T:7-T:6-S7U]W
M96)?=7-E<G,G(#T^(")796(@=7-E<G,B+`H))W-T871U<U]?8VQI96YT7VAA
M<U]R96%S;VYS7W1O7V)E7V]F9B<@/3X@(E1H92!C;&EE;G0@86-C;W5N="!I
M<R!S=&EL;"!D:7-A8FQE9"X@5&AE(')E87-O;CH@)3$B+`H))W-T871U<U]?
M9&]M86EN7VAA<U]R96%S;VYS7W1O7V)E7V]F9B<@/3X@(E1H92!D;VUA:6X@
M:7,@<W1I;&P@9&ES86)L960N(%1H92!R96%S;VXZ("4Q(BP*"2=S=6)D;VUA
M:6Y?7V-R96%T95]?)R`]/B`B0W)E871E(&$@<W5B9&]M86EN(&EN('1H92!D
M;VUA:6X@)3$B+`H))W-U8F1O;6%I;E]?961I=%]?)R`]/B`B36%N86=E('-U
M8F1O;6%I;B`E,2(L"@DG<W5B9&]M86EN7U]I;G9A;&ED7VYA;64G(#T^("))
M;G9A;&ED('-U8F1O;6%I;B!N86UE.B!U<V4@;VYL>2!A;'!H86YU;65R:6,@
M86YD(&1A<V@@<WEM8F]L<RXB+`H))W-U8F1O;6%I;G-?7V9U;&Q?;F%M95]L
M;VYG)R`]/B`B5&AE(&9U;&P@;F%M92!O9B!S=6)D;VUA:6X@:7,@=&]O(&QO
M;F<N(BP*"2=S=6)D;VUA:6YS7U]L:7-T7V]F7V1O;6%I;B<@/3X@(E-U8F1O
M;6%I;G,@:6X@=&AE(&1O;6%I;B`E,2(L"@DG<W5B9&]M86EN<U]?;6%I;&QI
M<W1S7V5N86)L961?:6Y?9&]M86EN)R`]/B`B26YC;W)R96-T('-U8F1O;6%I
M;B!N86UE(&QI<W1S+B4Q+"!O;B!D;VUA:6X@)3$@=&AE($UA:6QI;F<@;&ES
M=',@87)E(&5N86)L960N(BP*"2=S=6)D;VUA:6YS7U]D86QI87-?97AI<W1S
M)R`]/B`G5&AE(&1O;6%I;B!A;&EA<R!W:71H('-U8V@@;F%M92!A;')E9'D@
M97AI<W1S+B<L"@DG<W5B9&]M86EN<U]?;F%M95]E>&ES=',G(#T^(")4:&4@
M<W5B9&]M86EN('=I=&@@<W5C:"!N86UE(&%L<F5A9'D@97AI<W1S+B(L"@DG
M<W5B9&]M86EN<U]?<F5G=6QA<E]D;VUA:6Y?97AI<W1S)R`]/B`B5&AE(&1O
M;6%I;B!W:71H('-U8V@@;F%M92!A;')E9'D@97AI<W1S+B(L"@DG<W5B9&]M
M86EN<U]?<F5M;W9E7W-U8F1O;6%I;G-?;VY?9&]M86EN)R`]/B`B5&AE(&9O
M;&QO=VEN9R!S=6)D;VUA:6YS(&9O<B!D;VUA:6X@)3$@=VEL;"!B92!R96UO
M=F5D.B(L"@DG<W5B9&]M86EN<U]?<V5L96-T7W-U8F1O;6%I;G-?9F]R7W)E
M;6]V92<@/3X@(E-E;&5C="!T:&4@<W5B9&]M86EN<R!T;R!B92!R96UO=F5D
M+B(L"@DG<W5B9&]M86EN<U]?=&%R9V5T7V9O;&1E<E]E>&ES=',G(#T^(")4
M:&4@9&ER96-T;W)Y("4Q(&9O<B!S=6)D;VUA:6X@86QR96%D>2!E>&ES=',N
M(BP*"2=S=6)D;VUA:6YS7U]W96)M86EL7V5N86)L961?:6Y?9&]M86EN)R`]
M/B`B26YC;W)R96-T('-U8F1O;6%I;B!N86UE('=E8FUA:6PN)3$L(&]N(&1O
M;6%I;B`E,2!T:&4@5V5B;6%I;"!I<R!E;F%B;&5D+B(L"@DG<W5B9&]M86EN
M<U]?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@)U-U8V@@<F5S;W5R
M8V4@<F5C;W)D(&ES(&%L<F5A9'D@:6X@=&AE('IO;F4@)3$N)RP*"2=S=6)D
M;VUA:6YS7U]W=W=?<')E9FEX7VEN7V1O;6%I;B<@/3X@(DEN8V]R<F5C="!S
M=6)D;VUA:6X@;F%M93H@=&AE(&1O;6%I;B`E,2!A;')E861Y(&AA<R!T:&4@
M5U=7(&%L:6%S+B(L"@DG<W5B9&]M86EN<U]?8W)E871I;VY?:6Y?9&YS7W-L
M879E)R`]/B`B4&QE<VLG<R!N86UE('-E<G9E<B!I<R!A8W1I;F<@87,@82!S
M96-O;F1A<GD@*'-L879E*2!N86UE('-E<G9E<B!F;W(@=&AI<R!D;VUA:6XN
M($9O<B!Y;W5R('-U8F1O;6%I;B!T;R!R97-O;'9E('!R;W!E<FQY+"!M86ME
M('-U<F4@=&AA="!T:&4@>F]N92!F:6QE(&]N('1H92!P<FEM87)Y("AM87-T
M97(I('-E<G9E<B!C;VYT86EN<R!T:&4@<F5C;W)D("4Q(BP*"2=S>7-?=7-E
M<E]?871T<FEB=71E<U]N;W1?8VAA;F=E9"<@/3X@(EQN5&AE(&9O;&QO=VEN
M9R!S>7-T96T@=7-E<B!A='1R:6)U=&5S('=E<F4@;F]T(&-H86YG960Z("4Q
M(BP*"2=S>7-?=7-E<E]?;F]?86-C97-S7W=I=&AO=71?<&%S<W=O<F0G(#T^
M(")9;W4@9&ED(&YO="!S970@82!P87-S=V]R9"X@5&AE('-Y<W1E;2!U<V5R
M('=I;&P@8F4@8W)E871E9"P@8G5T('=I;&P@;F]T(&)E(&%B;&4@=&\@;&]G
M(&EN('1O('1H92!S>7-T96TL('5N=&EL(&AE+W-H92!I<R!G:79E;B!A('!A
M<W-W;W)D+B!7;W5L9"!Y;W4@;&EK92!T;R!P<F]C965D/R(L"@DG<WES7W5S
M97)?7VYO7VAA<F1?<75O=&$G(#T^(")N;W0@<W5P<&]R=&5D(BP*"2=S>7-U
M<V5R7U]Z97)O7W%U;W1A7VES7W5N;&EM:71E9"<@/3X@(C`@9F]R('5N;&EM
M:71E9"(L"@DG=&5M<&QA=&5?7VYU;5]E>&-L7VEP<R<@/3X@(D%L;&]C871E
M(&5X8VQU<VEV92!I<"!A9&1R97-S97,@=&\@=&AE(&-L:65N="(L"@DG=&5M
M<&QA=&5?7W-E;%]S:%]I<',G(#T^(")396QE8W0@<VAA<F5D(&EP(&%D9')E
M<W-E<R(L"@DG=&5M<&QA=&5?7V%V7W-H7VEP<R<@/3X@(D%V86EL86)L92!S
M:&%R960@:7`@861D<F5S<V5S(BP*"2=T96UP;&%T95]?=7!?=&]?97AC;%]I
M<"<@/3X@(E5P('1O("4Q(&EP(&%D9')E<W-E<R(L"@DG=&5M<&QA=&5S7U]A
M;&Q?8VQI96YT<R<@/3X@(F%L;"!C;&EE;G1S(BP*"2=T96UP;&%T97-?7V-L
M7V1O;6%I;E]T96UP;&%T97,G(#T^(")496UP;&%T97,@9F]R("4Q(BP*"2=T
M96UP;&%T97-?7V-L7W1E;7!L871E<R<@/3X@(D-L:65N="!T96UP;&%T97,B
M+`H))W1I;65?7V1A>2<@/3X@(D1A>2(L"@DG=&EM95]?9&]M7VYA;65?:7`G
M(#T^(")$;VUA:6X@;F%M92!O<B!)4"(L"@DG=&EM95]?:&]U<G,G(#T^(")(
M;W5R<R(L"@DG=&EM95]?:6YV86QI9%]I<"<@/3X@(DEN=F%L:60@25`@861D
M<F5S<R!O<B!D;VUA:6X@;F%M92XB+`H))W1I;65?7VEN=F%L:61?>65A<B<@
M/3X@(EEE87(@:7,@:6YV86QI9"X@4VAO=6QD(&)E(&)E='=E96X@,3DW,2!A
M;F0@,C`S-BXB+`H))W1I;65?7VEN=F%L:61?;6]N=&@G(#T^(")-;VYT:"!I
M<R!I;G9A;&ED+B!3:&]U;&0@8F4@8F5T=V5E;B`Q(&%N9"`Q,BXB+`H))W1I
M;65?7VEN=F%L:61?9&%Y)R`]/B`B1&%Y(&ES(&EN=F%L:60N(%-H;W5L9"!B
M92!B971W965N(#$@86YD(#,Q+B(L"@DG=&EM95]?:6YV86QI9%]H;W5R<R<@
M/3X@(DAO=7)S(&ES(&EN=F%L:60N(%-H;W5L9"!B92!B971W965N(#`@86YD
M(#(T+B(L"@DG=&EM95]?:6YV86QI9%]M:6YU=&5S)R`]/B`B36EN=71E<R!I
M<R!I;G9A;&ED+B!3:&]U;&0@8F4@8F5T=V5E;B`P(&%N9"`U.2XB+`H))W1I
M;65?7VEN=F%L:61?<V5C;VYD<R<@/3X@(E-E8V]N9',@:7,@:6YV86QI9"X@
M4VAO=6QD(&)E(&)E='=E96X@,"!A;F0@-3DN(BP*"2=T:6UE7U]M:6YU=&5S
M)R`]/B`B36EN=71E<R(L"@DG=&EM95]?;6]N=&@G(#T^(")-;VYT:"(L"@DG
M=&EM95]?<V5C)R`]/B`B4V5C;VYD<R(L"@DG=&EM95]?<WEN7W-Y<U]T:6UE
M)R`]/B`B4WEN8VAR;VYI>F4@<WES=&5M('1I;64B+`H))W1I;65?7W-Y<W1E
M;5]D871E)R`]/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H))W1I;65?7W-Y
M<W1E;5]D871E7W1I=&QE)R`]/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H)
M)W1I;65?7W1I;65Z;VYE7W1I=&QE)R`]/B`G5&EM92!Z;VYE)RP*"2=T:6UE
M7U]T:6UE>F]N92<@/3X@)UEO=7(@=&EM92!Z;VYE)RP*"2=T:6UE7U]P;&5A
M<V5?<V5L96-T7W1I;65Z;VYE)R`]/B`G4&QE87-E+"!S96QE8W0@82!T:6UE
M('IO;F4G+`H))U]?<&QE87-E7W-E;&5C=%]C;W5N=')Y)R`]/B`G4&QE87-E
M+"!S96QE8W0@>6]U<B!C;W5N=')Y)RP*"2=T:6UE7U]U;F%B;&5?<V5T7W1I
M;64G(#T^(")5;F%B;&4@=&\@<V5T('1H92!S>7-T96T@=&EM93H@)3$B+`H)
M)W1I;65?7WEE87(G(#T^(")996%R(BP*"2=T;7!L7U]C<F5A=&4G(#T^(")#
M<F5A=&4@=&5M<&QA=&4B+`H))W1M<&Q?7V5D:71?7R<@/3X@(D5D:70@=&5M
M<&QA=&4@)3$B+`H))W1M<&Q?7VQO9W)O=&%T:6]N7W=A<FXG(#T^("),;V<@
M<F]T871I;VX@;VX@=&AE(&1O;6%I;B!C<F5A=&5D(&)Y('1H:7,@=&5M<&QA
M=&4@=VEL;"!B92!P97)F;W)M960@;VYL>2!I;B!C87-E(&]F('-U8G-E<75E
M;G0@<&AY<VEC86P@:&]S=&EN9R!A8V-O=6YT(&-R96%T:6]N(&9O<B!I="XB
M+`H))W1M<&Q?7VYA;64G(#T^(")496UP;&%T92!N86UE(BP*"2=T;7!L7U]N
M86UE7VEN=F%L:60G(#T^(")496UP;&%T92!N86UE(&ES(&EN=F%L:60@;W(@
M96UP='DN(BP*"2=T;7!L7U]D;VU?97AI<W0G(#T^(")$;VUA:6X@=&5M<&QA
M=&4@=VET:"!S=6-H(&YA;64@86QR96%D>2!E>&ES=',@:6X@861M:6YI<W1R
M871O<B=S(&]R(&-L:65N="=S('1E;7!L871E<R!P;V]L+B(L"@DG=&UP;%]?
M=7-E7VYE>'1?:7!?861D<B<@/3X@(DYE>'0@=F%C86YT(&EP(&%D9')E<W,@
M=VEL;"!B92!U<V5D(BP*"2=T;V]L<V)A<E]?;&]G;W5T/R<@/3X@(D%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!L;V<@;W5T/R(L"@DG=')A9F9I8U]?;F]?
M<&5R:6]D<U]F;W5N9"<@/3X@(E5N86)L92!T;R!D:7-P;&%Y('1H92!T<F%F
M9FEC('-T871I<W1I8W,N(%1H:7,@9G5N8W1I;VX@=VEL;"!B92!A=F%I;&%B
M;&4@;VYL>2!A9G1E<B!T:&4@;F5X="!S=&%T:7-T:6-S(&-A;&-U;&%T:6]N
M+B(L"@DG='1S)R`]/B`B2&5L<"!$97-K(BP*"2=T='-?7V-A;G1?8VQO<V5?
M8VQO<V5D)R`]/B`B66]U(&-A;FYO="!C;&]S92!A;B!A;')E861Y(&-L;W-E
M9"!T:6-K970B+`H))W1T<U]?8V%N=%]D96Q?8V%T7W1I8VME=',G(#T^(")5
M;F%B;&4@=&\@9&5L971E('1H92!C871E9V]R>3H@:70@:7,@=7-E9"!B>2!C
M97)T86EN('1I8VME=',@;W(@87-S:6=N960@87,@9&5F875L="!C871E9V]R
M>2XB+`H))W1T<U]?8V%N=%]D96Q?<')I;W)I='E?=&EC:V5T<R<@/3X@(E5N
M86)L92!T;R!D96QE=&4@=&AE('!R:6]R:71Y.B!I="!I<R!U<V5D(&)Y(&-E
M<G1A:6X@=&EC:V5T<R!O<B!A<W-I9VYE9"!A<R!D969A=6QT('!R:6]R:71Y
M+B(L"@DG='1S7U]C86YT7V1E;%]Q=65U95]T:6-K971S)R`]/B`B56YA8FQE
M('1O(&1E;&5T92!T:&4@<75E=64Z(&ET(&ES('5S960@8GD@8V5R=&%I;B!T
M:6-K971S(&]R(&%S<VEG;F5D(&%S(&1E9F%U;'0@<75E=64N(BP*"2=T='-?
M7V-A;G1?;W!E;E]N;W1?8VQO<V5D)R`]/B`B66]U(&-A;FYO="!R96]P96X@
M82!N;VXM8VQO<V5D('1I8VME="(L"@DG='1S7U]C871E9V]R>2<@/3X@(D-A
M=&5G;W)Y(BP*"2=T='-?7V-A=&5G;W)Y7V%L<F5A9'E?97AI<W1S7U\G(#T^
M("=#871E9V]R>2`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?8V%T<R<@
M/3X@(D-A=&5G;W)I97,B+`H))W1T<U]?8V]N9E]C86Y?<&]S="<@/3X@(D%L
M;&]W(&-U<W1O;65R<R!T;R!S=6)M:70@=&EC:V5T<R(L"@DG='1S7U]C;VYF
M7V1E9E]C871E9V]R>2<@/3X@(D1E9F%U;'0@0V%T96=O<GDB+`H))W1T<U]?
M96YA8FQE9"<@/3X@(D5N86)L960B+`H))W1T<U]?9V5N97)A;%]C;VYF:6<G
M(#T^(")(96QP($1E<VL@4V5T=&EN9W,B+`H))W1T<U]?<')I;W)I=&EE<U]L
M:7-T)R`]/B`B4')I;W)I=&EE<R(L"@DG='1S7U]P=6)L:6-?;F%M92<@/3X@
M(DYO=&EF:6-A=&EO;B!396YD97(G<R!.86UE(BP*"2=T='-?7W!U8FQI8U]E
M;6%I;"<@/3X@(DYO=&EF:6-A=&EO;B!396YD97(G<R!2971U<FX@061D<F5S
M<R(L"@DG='1S7U]C;VYF7V1E9E]P<FEO<FET>2<@/3X@(D1E9F%U;'0@4')I
M;W)I='DB+`H))W1T<U]?8V]N9E]D969?<75E=64G(#T^(")$969A=6QT(%%U
M975E(BP*"2=T='-?7V-O;F9?96YA8FQE9"<@/3X@(D5N86)L960B+`H))W1T
M<U]?8V]N9FEG=7)A=&EO;B<@/3X@(DAE;'`@1&5S:R!3971T:6YG<R(L"@DG
M='1S7U]E9&ET7V-A="<@/3X@(D5D:70@8V%T96=O<GDB+`H))W1T<U]?961I
M=%]P<FEO<FET>2<@/3X@(D5D:70@<')I;W)I='DB+`H))W1T<U]?961I=%]Q
M=65U92<@/3X@(D5D:70@<75E=64B+`H))W1T<U]?97)R7W-E;%]Q<&,G(#T^
M(")9;W4@<VAO=6QD('-E;&5C="!T:&4@9&5F875L="!Q=65U92P@<')I;W)I
M='D@86YD(&-A=&5G;W)Y('1O(&%L;&]W('1I8VME="!S=6)M:7-S:6]N+B(L
M"@DG='1S7U]G;%]C;G1?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?7V=L
M7V-N=%]N97<G(#T^(").97<B+`H))W1T<U]?9VQ?8VYT7V]P96YE9"<@/3X@
M(D]P96XB+`H))W1T<U]?9VQ?8VYT7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B
M+`H))W1T<U]?9VQ?<V5R=F5R7VYA;64G(#T^(")397)V97(@2&]S=&YA;64B
M+`H))W1T<U]?9VQ?<V5R=F5R<R<@/3X@(E-E<G9E<G,B+`H))W1T<U]?9VQ?
M='1S7V-A;E]P;W-T)R`]/B`B5&EC:V5T(%-U8FUI<W-I;VXB+`H))W1T<U]?
M9VQ?='1S7V5N86)L960G(#T^(")(96QP($1E<VL@:7,@86-T:79A=&5D(BP*
M"2=T='-?7V=L7W5N:VYO=VXG(#T^(")5;FMN;W=N(BP*"2=T='-?7V=L7W5P
M9&%T960G(#T^(")5<&1A=&5D(BP*"2=T='-?7V=L;V)A;%]T=',G(#T^(")'
M;&]B86P@2&5L<"!$97-K(BP*"2=T='-?7VQO8U]C;VYF7W1I=&QE)R`]/B`B
M3&]C86P@2&5L<"!$97-K(%-E='1I;F=S(BP*"2=T='-?7VQO8U]I;F9O)R`]
M/B`B5&]T86P@)3$L('1O=&%L(&]P96X@)3(@*"!N97<@)3,L(')E;W!E;F5D
M("4T*2P@=&]T86P@8VQO<V5D("4U('1I8VME=',N(BP*"2=T='-?7VQO8U]T
M:6-K971S7W1I=&QE)R`]/B`B3&]C86P@5&EC:V5T<R(L"@DG='1S7U]M86EL
M9V%T95]C;VYF:6<G(#T^(")(96QP($1E<VL@36%I;"!'871E(%-E='1I;F=S
M(BP*"2=T='-?7VYE=R<@/3X@(DYE=R!4:6-K970B+`H))W1T<U]?<&]P7W-E
M<G9E<B<@/3X@(E!/4#,@4V5R=F5R(BP*"2=T='-?7W!O<%]U<V5R;F%M92<@
M/3X@(E!/4#,@3&]G:6XB+`H))W1T<U]?<')I;W)I=&EE<R<@/3X@(E!R:6]R
M:71I97,B+`H))W1T<U]?<')I;W)I='DG(#T^(")0<FEO<FET>2(L"@DG='1S
M7U]P<FEO<FET>5]A;')E861Y7V5X:7-T<U]?)R`]/B`B4')I;W)I='D@)3$@
M86QR96%D>2!E>&ES=',N(BP*"2=T='-?7W%U97)Y7W!E<FEO9"<@/3X@(E%U
M97)Y(&UA:6P@;VYC92!I;B(L"@DG='1S7U]Q=65R>5]P97)I;V1?;6EN=71E
M<R<@/3X@(FUI;B(L"@DG='1S7U]Q=65U97,G(#T^(")1=65U97,B+`H))W1T
M<U]?<75E=65S7VQI<W0G(#T^(")1=65U97,@;&ES="(L"@DG='1S7U]Q=65U
M92<@/3X@(E%U975E(BP*"2=T='-?7W%U975E7V%L<F5A9'E?97AI<W1S7U\G
M(#T^("=1=65U92`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?<F5M;W9E
M7V-A=',G(#T^(")296UO=F4@8V%T96=O<FEE<R(L"@DG='1S7U]R96UO=F5?
M<')I;W)I=&5S)R`]/B`B4F5M;W9E('!R:6]R:71I97,B+`H))W1T<U]?<F5M
M;W9E7W%U975E<R<@/3X@(E)E;6]V92!Q=65U97,B+`H))W1T<U]?<F5P;W)T
M97)?='EP95]A9&UI;B<@/3X@(D%D;6EN:7-T<F%T;W(B+`H))W1T<U]?<F5P
M;W)T97)?='EP95]C;&EE;G0G(#T^(")#;&EE;G0B+`H))W1T<U]?<F5P;W)T
M97)?='EP95]D;VUA:6XG(#T^(")$;VUA:6XB+`H))W1T<U]?<F5P;W)T97)?
M='EP95]E;6%I;"<@/3X@(D4M;6%I;"(L"@DG='1S7U]R97!O<G1E<E]T>7!E
M7VUA:6QN86UE)R`]/B`B36%I;"!N86UE(BP*"2=T='-?7W-E;&5C=%]C871S
M7W1O7W)E;6]V92<@/3X@(E-E;&5C="!C871E9V]R:65S('1O(&)E(')E;6]V
M960N(BP*"2=T='-?7W-E;&5C=%]E=F5N=%]T>7!E)R`]/B`B4V5L96-T(&5V
M96YT('1Y<&4@9F]R(&-O;6UE;G0@<W5B;6ES<VEO;B(L"@DG='1S7U]S96QE
M8W1?<')I;W)I=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!P<FEO<FET:65S
M('1O(&)E(')E;6]V960N(BP*"2=T='-?7W-E;&5C=%]Q=65U97-?=&]?<F5M
M;W9E)R`]/B`B4V5L96-T('%U975E<R!T;R!B92!R96UO=F5D+B(L"@DG='1S
M7U]S=&%R=%]T:6-K971?<W5B:B<@/3X@(E1I8VME="!S=6)J96-T(&UU<W0@
M<W1A<G0@=VET:"(L"@DG='1S7U]T979?8VQO<V5D)R`]/B`B0VQO<V5D(BP*
M"2=T='-?7W1E=E]C;VUM96YT960G(#T^(")#;VUM96YT960B+`H))W1T<U]?
M=&5V7V-R96%T960G(#T^(")#<F5A=&5D(BP*"2=T='-?7W1E=E]R96]P96YE
M9"<@/3X@(E)E;W!E;F5D(BP*"2=T='-?7W1I8VME="<@/3X@(E1I8VME="(L
M"@DG='1S7U]T:6-K971?8F]D>2<@/3X@(E1I8VME="!";V1Y(BP*"2=T='-?
M7W1I8VME=%]C871E9V]R>2<@/3X@(D-A=&5G;W)Y(BP*"2=T='-?7W1I8VME
M=%]I9"<@/3X@(DED(BP*"2=T='-?7W1I8VME=%]M86EL8VQ?;F%M92<@/3X@
M(E)E<&]R=&5R($YA;64B+`H))W1T<U]?=&EC:V5T7VUO9&EF:65D)R`]/B`B
M36]D:69I960B+`H))W1T<U]?=&EC:V5T7W%U975E)R`]/B`B475E=64B+`H)
M)W1T<U]?=&EC:V5T7W)E<&]R=&5R7W1Y<&4G(#T^(")297!O<G1E<B!4>7!E
M(BP*"2=T='-?7W1I8VME=%]S=&%T=7,G(#T^(")4:6-K970@4W1A='5S(BP*
M"2=T='-?7W1I8VME=%]S=6)J96-T)R`]/B`B5&EC:V5T(%-U8FIE8W0B+`H)
M)W1T<U]?=&EC:V5T7W1I=&QE:60G(#T^(")4:6-K970@)3$B+`H))W1T<U]?
M=&EC:V5T<R<@/3X@(E1I8VME=',B+`H))W1T<U]?=&EC:V5T<U]L:7-T)R`]
M/B`B5&EC:V5T<R(L"@DG='1S7U]T:6-K971S7W-U;6UA<GDG(#T^(")4:6-K
M971S(%-U;6UA<GDB+`H))W1T<U]?=&YE=E]C;&]S92<@/3X@(D-L;W-E('1I
M8VME="(L"@DG='1S7U]T;F5V7V-O;6UE;G0G(#T^(")#;VUM96YT('1I8VME
M="(L"@DG='1S7U]T;F5V7W)E;W!E;B<@/3X@(E)E;W!E;B(L"@DG='1S7U]T
M<U]A;&PG(#T^(")!;&PB+`H))W1T<U]?='-?86QL;W!E;F5D)R`]/B`B06QL
M(&]P96XB+`H))W1T<U]?='-?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?
M7W1S7VYE=R<@/3X@(DYE=R(L"@DG='1S7U]T<U]R96]P96YE9"<@/3X@(E)E
M;W!E;F5D(BP*"2=T='-?7W1T<R<@/3X@(DAE;'`@1&5S:R(L"@DG='1S7V-A
M;G1?<&]S="<@/3X@(E1I8VME="!S=6)M:7-S:6]N(&ES(&1I<V%B;&5D(BP*
M"2=T='-?979?7VAI<W1O<GDG(#T^(")4:6-K970@2&ES=&]R>2(L"@DG='1S
M7VYO=%]A8W1I=F%T960G(#T^(")(96QP($1E<VL@:7,@;F]T(&%C=&EV871E
M9"XB+`H))W1T<U]T:6-K971?7V1O)R`]/B`B5&EC:V5T($5V96YT(BP*"2=T
M='-?=&EC:V5T7U]N97=?8V]M;65N="<@/3X@(DYE=R!#;VUM96YT(BP*"2=T
M='-?=&EC:V5T7U]P=6)L:6,G(#T^(")6:7-I8FQE('1O(&-L:65N="(L"@DG
M='1S7W1I8VME=%]?<')I=F%T92<@/3X@(DEN=FES:6)L92!T;R!C;&EE;G0B
M+`H))W1T<U]T:6-K971?9&]?<V5C=&EO;B<@/3X@(DYE=R!%=F5N="(L"@DG
M=FA?8F%S961?7VYO7V9R965?:7!?9F]R7W9H)R`]/B`B5&AE<F4@87)E(&YO
M('9A8V%N="!)4"!A9&1R97-S97,@9F]R('1H92!)4"UB87-E9"!V:7)T=6%L
M(&AO<W1I;F<N(%!L96%S92P@861D(&%N($E0(&%D9')E<W,N(BP*"@DG=FES
M:6)I;&ET>5]?861M:6YO;FQY)R`]/B`G061M:6X@3VYL>2<L"@DG=FES:6)I
M;&ET>5]?8G5T=&]N7W-E=',G(#T^("="=71T;VX@<V5T<R<L"@DG=FES:6)I
M;&ET>5]?8V]N=')O;"<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!T:&ES(&-O
M;G1R;VPN)RP*"2=V:7-I8FEL:71Y7U]C=7)R96YT7V-U<W1O;6EZ871I;VYS
M)R`]/B`G0W5R<F5N="!C=7-T;VUI>F%T:6]N<R<L"@DG=FES:6)I;&ET>5]?
M8W5R<F5N=%]C=7-T;VUI>F%T:6]N<U]B96QO=R<@/3X@)U1H92!F;VQL;W=I
M;F<@8G5T=&]N<R!H879E(&-U<W1O;2!S971T:6YG<RX@0VQI8VL@=&AE;2!T
M;R!C:&%N9V4@=&AE<V4@<V5T=&EN9W,N)RP*"2=V:7-I8FEL:71Y7U]C=7)R
M96YT7V-U<W1O;6EZ871I;VYS7V9O<FUS)R`]/B`G4V]M92!C;VYT<F]L<R!O
M;B!F;W)M<R!H879E(&-U<W1O;2!S971T:6YG<RXG+`H))W9I<VEB:6QI='E?
M7V-U<W1O;6EZ871I;VY?9F]O=&YO=&4G(#T^("=#;&EC:R!/2R!T;R!F:6YI
M<V@@8W5S=&]M:7IA=&EO;B!O9B!T:&ES('-C<F5E;BXG+`H))W9I<VEB:6QI
M='E?7V1E9F%U;'0G(#T^("=$969A=6QT)RP*"2=V:7-I8FEL:71Y7U]E>'!O
M<G1?;F]T92<@/3X@(E1H92!C=7-T;VUI>F%T:6]N('-E='1I;F=S('EO=2!M
M861E(&%R92!A8F]U="!T;R!B92!E>'!O<G1E9"X@02!S:&5L;"!S8W)I<'0@
M=VEL;"!N;W<@8F4@9&]W;FQO861E9"!T;R!Y;W5R(&-O;7!U=&5R+B!4;R!A
M<'!L>2!T:&5S92!S971T:6YG<R!T;R!A;F]T:&5R(%!L97-K('-E<G9E<BP@
M;W9E<G=R:71I;F<@86YY(&5X:7-T:6YG(&EN=&5R9F%C92!M86YA9V5M96YT
M('-E='1I;F=S+"!P;&5A<V4@=7!L;V%D(&%N9"!E>&5C=71E('1H92!S8W)I
M<'0@=&AE<F4N7&Y<;E!L96%S92!N;W1E('1H870L(&EF('EO=2!H879E(&UA
M9&4@86YY(&-H86YG97,@;VX@=&AI<R!S8W)E96X@8G5T(&AA=F5N)W0@>65T
M(&-L:6-K960@3TLL('1H92!D871A(&5X<&]R=&5D('=I;&P@;F]T(&EN8VQU
M9&4@>6]U<B!L871E<W0@8VAA;F=E<RXB+`H))W9I<VEB:6QI='E?7V9O<FU?
M8V]N=')O;'-?<F5S970G(#T^("=!;&P@8V]N=')O;',@;VX@9F]R;7,@=VEL
M;"!B92!R97-E="!T;R!D969A=6QT('-E='1I;F=S)RP*"2=V:7-I8FEL:71Y
M7U]H:61E)R`]/B`G2&ED92<L"@DG=FES:6)I;&ET>5]?:&ED95]D:7-A8FQE
M9"<@/3X@)TAI9&4@86QL(&=R87EE9"!O=70@8G5T=&]N<R!B>2!D969A=6QT
M)RP*"2=V:7-I8FEL:71Y7U]H:61E7W5N879A:6QA8FQE7VQI;6ET<R<@/3X@
M)TAI9&4@9G)O;2!U<V5R<R!T:&4@;&EM:70@;6%N86=E;65N=`IC;VYT<F]L
M<R!T:&5Y(&%R92!N;W0@86QL;W=E9"!T;R!O<&5R871E)RP*"2=V:7-I8FEL
M:71Y7U]H:61E7W5N879A:6QA8FQE7W!E<FUI<W-I;VYS)R`]/B`G2&ED92!F
M<F]M('5S97)S('1H92!P97)M:7-S:6]N"FUA;F%G96UE;G0@8V]N=')O;',@
M=&AE>2!A<F4@;F]T(&%L;&]W960@=&\@;W!E<F%T92<L"@DG=FES:6)I;&ET
M>5]?;F]?8W5R<F5N=%]C=7-T;VUI>F%T:6]N<R<@/3X@)T%L;"!B=71T;VYS
M(&]N(%!L97-K('-C<F5E;G,@:&%V92!D969A=6QT('-E='1I;F=S+B<L"@DG
M=FES:6)I;&ET>5]?<F5S971?86QL)R`]/B`G4F5S970@86QL('1O(&1E9F%U
M;'0G+`H))W9I<VEB:6QI='E?7W)E<V5T7W-C<F5E;B<@/3X@)U)E<W1O<F4@
M;W)I9VEN86P@;&%Y;W5T(&]F('1H:7,@<V-R965N)RP*"2=V:7-I8FEL:71Y
M7U]R;V]T7V]V97)R:61E7W!A<G-E7V5R<F]R)R`]/B`G5&AE<F4@:7,@82!S
M>6YT87@@97)R;W(@:6X@9FEL92`E,2!I;B!L:6YE("4R(2<L"@DG=FES:6)I
M;&ET>5]?<V-R965N7W1I=&QE)R`]/B`G26YT97)F86-E(&UA;F%G96UE;G0G
M+`H))W9I<VEB:6QI='E?7W-E=%]C97)T7W!U8VAA<VEN9R<@/3X@)TAI9&4@
M8G5T=&]N<R!F;W(@8V5R=&EF:6-A=&4@<'5R8VAA<VEN9R<L"@DG=FES:6)I
M;&ET>5]?<V5T7V1O;6%I;E]R96=I<W1R871I;VXG(#T^("=(:61E(&)U='1O
M;G,@9F]R(&1O;6%I;B!R96=I<W1R871I;VXG+`H))W9I<VEB:6QI='E?7W-E
M=%]E>'1R87,G(#T^("=(:61E(&)U='1O;G,@9F]R(&5X=')A('-E<G9I8V5S
M)RP*"2=V:7-I8FEL:71Y7U]S971?;6%I;%]B;W5N8V4G(#T^("=(:61E(&-O
M;G1R;VQS(&9O<B!B;W5N8V4@;65S<V%G97,@9F]R(&YO;BUE>&ES=&5N="!M
M86EL(&%D9')E<W-E<R<L"@DG=FES:6)I;&ET>5]?<VAO=R<@/3X@)U-H;W<G
M+`H))W9I<VEB:6QI='E?7W-H;W=?=&]O;&)A<B<@/3X@)U-H;W<@26YT97)F
M86-E(&UA;F%G96UE;G0@=&]O;&)A<B<L"@DG=FES:6)I;&ET>5]?<W1A;F1B
M>5]F;V]T;F]T92<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!C;VYT<F]L<R!O
M;B!T:&ES('-C<F5E;BXG+`H))W9I<VEB:6QI='E?7W-T86YD8GE?9F]O=&YO
M=&5?;F]C;VYT<F]L<R<@/3X@)U1H97)E(&%R92!N;R!C=7-T;VUI>F%B;&4@
M8V]N=')O;',@;VX@=&AI<R!S8W)E96XN)RP*"2=I;G1E<F9A8V5?<')E9F5R
M96YC97,G(#T^("=);G1E<F9A8V4@<')E9F5R96YC97,G+`H))VET;7!L7U]L
M:7-T7W1I=&QE)R`]/B`G26YT97)F86-E('1E;7!L871E<R!M86YA9V5M96YT
M)RP*"2=P8E]?:6YT97)F86-E7W1E;7!L871E<R<@/3X@)TEN=&5R9F%C92!M
M86YA9V5M96YT)RP*"2=B=%]I;G1E<F9A8V5?=&5M<&QA=&5?861D)R`]/B`G
M061D($EN=&5R9F%C92!496UP;&%T92<L"@DG:71M<&Q?7VQI<W1?;&5G96YD
M)R`]/B`G26YT97)F86-E('1E;7!L871E<R<L"@DG:71M<&Q?7VQI<W1?;F%M
M92<@/3X@)TEN=&5R9F%C92!T96UP;&%T92!N86UE)RP*"2=I=&UP;%]?;&ES
M=%]U<V%G92<@/3X@)U5S86=E)RP*"2=I=&UP;%]?;&ES=%]H96%D97(G(#T^
M("=);G1E<F9A8V4@=&5M<&QA=&5S)RP*"2=I=&UP;%]?<V5L96-T7W1E;7!L
M871E<U]T;U]R96UO=F4G(#T^("=396QE8W0@=&AE(&EN=&5R9F%C92!T96UP
M;&%T97,@=&\@8F4@<F5M;W9E9"XG+`H))VET;7!L7U]S96QE8W1?=&5M<&QA
M=&5?=&]?;6%K95]D969A=6QT)R`]/B`G4V5L96-T(&%N(&EN=&5R9F%C92!T
M96UP;&%T92!T;R!M86ME(&ET(&1E9F%U;'0N)RP*"2=I=&UP;%]?;F%M92<@
M/3X@)TEN=&5R9F%C92!T96UP;&%T92!N86UE)RP*"2=B=%]S:&]W7VET;7!L
M7W1O;VQB87(G(#T^("=3:&]W(%1O;VQB87(G+`H))VET;7!L7U]U<&QO861?
M=&ET;&4G(#T^("=5<&QO860@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP
M;%]?=7!L;V%D7VQE9V5N9"<@/3X@)U5P;&]A9"!I;G1E<F9A8V4@=&5M<&QA
M=&4G+`H))VET;7!L7U]F:6QE7VYA;64G(#T^("=0871H('1O(&EN=&5R9F%C
M92!T96UP;&%T92!F:6QE)RP*"2=I=&UP;%]?:6YV86QI9%]V86QU97,G(#T^
M("=);G9A;&ED('9A;'5E<R<L"@DG:71M<&Q?7V%L<F5A9'E?97AI<W0G(#T^
M("=);G1E<F9A8V4@=&5M<&QA=&4@=VET:"!N86UE("(E,2(@86QR96%D>2!E
M>&ES=',N)RP*"2=I=&UP;%]?=7!L;V%D7VEN=F%L:61?='EP92<@/3X@)TYO
M="!S=7!P;W)T960@9FEL92!T>7!E+B<L"@DG:71M<&Q?7WAM;%]L;V%D7V9A
M:6QE9"<@/3X@)UA-3"!F:6QE(&ES(&EN('1H92!W<F]N9R!F;W)M870N)RP*
M"2=I=&UP;%]?961I=%]T:71L92<@/3X@)T5D:70@:6YT97)F86-E('1E;7!L
M871E("4Q)RP*"2=I=&UP;%]?861D7W1I=&QE)R`]/B`G061D(&YE=R!I;G1E
M<F9A8V4@=&5M<&QA=&4G+`H))VET;7!L7U]C;%]L:7-T7V9O<E\G(#T^("=#
M;&EE;G1S('5S:6YG("4Q(&EN=&5R9F%C92!T96UP;&%T92<L"@DG:71M<&Q?
M7V-L7VQI<W1?861D)R`]/B`G4V5L96-T('1H92!C;&EE;G1S('=H;R!S:&]U
M;&0@=7-E('1H:7,@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP;%]?<F5M
M;W9E7W1I=&QE)R`]/B`G5&AE(&9O;&QO=VEN9R!I;G1E<F9A8V4@=&5M<&QA
M=&5S('=I;&P@8F4@<F5M;W9E9#HG+`H))VET;7!L7U]R96UO=F5?8VQI96YT
M<R<@/3X@)U1H92!F;VQL;W=I;F<@8VQI96YT<R!W:6QL(&YO(&QO;F=E<B!U
M<V4@=&AI<R!I;G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T93HG+`H)
M)W!B7U]I;G1E<F9A8V5?8VQI96YT<R<@/3X@)T-L:65N=',@=7-I;F<@)3$G
M+`H*"2=W96)A;&EZ97)?<')E9F5R96YC97-?7W1I=&QE)R`]/B`G5V5B(%-T
M871I<W1I8W,@4')E9F5R96YC97,G+`H))W=E8F%L:7IE<E]P<F5F97)E;F-E
M<U]?=&%B7VAI9&1E;E]R969E<G)E<G,G(#T^("=(:61D96X@4F5F97)R97)S
M)RP*"2=W96)A;&EZ97)?<')E9F5R96YC97-?7W1A8E]G<F]U<%]R969E<G)E
M<G,G(#T^("='<F]U<&5D(%)E9F5R<F5R<R<L"@H))W=E8F%L:7IE<E]H:61D
M96Y?<F5F97)R97)?7V5D:71?=&ET;&4G(#T^("=(:61D96X@16YT<GD@4')O
M<&5R=&EE<R<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?961I=%]L
M96=E;F0G(#T^("=(:61D96X@16YT<FEE<R<L"@DG=V5B86QI>F5R7VAI9&1E
M;E]R969E<G)E<E]?<F5F97)R97)?='EP92<@/3X@)T5N=')Y('1Y<&4G+`H)
M)W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7W)E9F5R<F5R)R`]/B`G4F5F
M97)R97(G+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7VQI<W1?:&5A
M9&5R)R`]/B`G2&ED9&5N(%)E9F5R<F5R<R<L"@DG=V5B86QI>F5R7VAI9&1E
M;E]R969E<G)E<E]?;&ES=%]L96=E;F0G(#T^("=(:61D96X@4F5F97)R97)S
M)RP*"2=W96)A;&EZ97)?:&ED9&5N7W)E9F5R<F5R7U]R969E<G)E<E]D:7)E
M8W1?<F5Q=65S="<@/3X@)T1I<F5C="!R97%U97-T)RP*"2=W96)A;&EZ97)?
M:&ED9&5N7W)E9F5R<F5R7U]R969E<G)E<E]C=7-T;VU?<F5F97)R97(G(#T^
M("=2969E<G)E<B<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?<F5M
M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(&5N=')I97,@<V5L96-T960G
M+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7W)E;6]V95]T:71L92<@
M/3X@)U1H92!F;VQL;W=I;F<@<F5F97)R97)S('=I;&P@;F\@;&]N9V5R(&)E
M(&AI9&1E;CHG+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7V%L<F5A
M9'E?97AI<W0G(#T^("=3=6-H(&5N=')Y(&%L<F5A9'D@97AI<W1S+B<L"@H)
M)W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?;&ES=%]H96%D97(G(#T^("='
M<F]U<"!2969E<G)E<G,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M;&ES=%]L96=E;F0G(#T^("='<F]U<"!2969E<G)E<G,G+`H))W=E8F%L:7IE
M<E]G<F]U<%]R969E<G)E<E]?961I=%]T:71L92<@/3X@)U)E9F5R<F5R($=R
M;W5P(%!R;W!E<G1I97,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M961I=%]L96=E;F0G(#T^("=2969E<G)E<B!'<F]U<"!0<F]P97)T:65S)RP*
M"2=W96)A;&EZ97)?9W)O=7!?<F5F97)R97)?7V=R;W5P)R`]/B`G1W)O=7`G
M+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?<F5F97)R97(G(#T^("=2
M969E<G)E<B<L"@DG=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]A;')E861Y
M7V5X:7-T)R`]/B`G02!G<F]U<"!R969E<G)E<B!W:71H('-U8V@@;F%M92!A
M;')E861Y(&5X:7-T<RXG+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M<F5M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(')E9F5R<F5R<R!S96QE
M8W1E9"<L"@DG=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]R96UO=F5?=&ET
M;&4G(#T^("=4:&4@9F]L;&]W:6YG(')E9F5R<F5R('-I=&5S('=I;&P@8F4@
M=6YG<F]U<&5D.B<L"@H))W=E8E]A<'!S7U]D;VUA:6Y?;&EM:71?97AC965D
M960G(#T^(")5;F%B;&4@=&\@861D(&YE=R!*879A(&%P<&QI8V%T:6]N.B!D
M;VUA:6X@;&EM:70@:7,@97AC965D960B+`H))W=E8E]A<'!S7U]H879E7VYO
M7W!E<FUI<W-I;VYS)R`]/B`B56YA8FQE('1O(&UA;F%G92!*879A(&%P<&QI
M8V%T:6]N<SH@8VQI96YT(&]R(&1O;6%I;B!L979E;"!U<V5R(&1O97,@;F]T
M(&AA=F4@=&AE(&%P<')O<')I871E('!E<FUI<W-I;VX@;W(@9&]M86EN(&ES
M(&YO="!A8W1I=F4N(BP*"2=W96)?87!P<U]?;VYL>5]W87)?9FEL92<@/3X@
M(D]N;'D@+G=A<B!F:6QE<R!C86X@8F4@:6YS=&%L;&5D(&%S(&$@2F%V82!A
M<'!L:6-A=&EO;BXB+`H))W=E8E]A<'!S7U]R96UO=F5?=V5B87!P<U]O;E]D
M;VTG(#T^(")4:&4@9F]L;&]W:6YG($IA=F$@87!P;&EC871I;VYS(&9O<B!D
M;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB
M+`H))W=E8E]A<'!S7U]S96QE8W1?=V%R7V9I;&4G(#T^(")396QE8W0@2F%V
M82!A<'!L:6-A=&EO;B!F:6QE+B(L"@DG=V5B7V%P<'-?7W-E;&5C=%]W96)A
M<'!S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@2F%V82!A<'!L:6-A=&EO
M;G,@=&\@8F4@<F5M;W9E9"XB+`H))W=E8E]A<'!S7U]T:71L92<@/3X@(DIA
M=F$@87!P;&EC871I;VYS(&9O<B!D;VUA:6X@)3$B+`H))W=E8E]A<'!S7U]A
M9&1?=&ET;&4G(#T^(")!9&1I;F<@3F5W($IA=F$@07!P;&EC871I;VXB+`H)
M)W=E8E]A<'!S7U]T;VUC871?;6%Y7V)E7VYO=%]W;W)K)R`]/B`B4&]S<VEB
M;&4@<F5A<V]N("T@5&]M8V%T('-E<G9I8V4@:7,@;F]T(&-U<G)E;G1L>2!R
M=6YN:6YG(&]N('1H92!S97)V97(N(BP*"2=W96)?87!P<U]?=&]M8V%T7W-T
M871U<R<@/3X@(E1O;6-A="!S=&%T=7,B+`H))W=E8E]A<'!S7U]U;F%B;&5?
M=&]?<W1A<G1?=V5B87!P)R`]/B`B56YA8FQE('1O('-T87)T('5P($IA=F$@
M87!P;&EC871I;VXZ("4Q(BP*"2=W96)?87!P<U]?=6YA8FQE7W1O7V1O=VY?
M=V5B87!P)R`]/B`B56YA8FQE('1O('-H=70@9&]W;B!*879A(&%P<&QI8V%T
M:6]N.B`E,2(L"@DG=V5B7V%P<'-?7W5P;&]A9%]W87)?9FEL92<@/3X@(E5P
M;&]A9"!705(@9FEL92(L"@DG=V5B7V%P<'-?7W=A<E]F:6QE)R`]/B`B5T%2
M(&9I;&4B+`H))W=E8E]A<'!S7U]W96)?87!P7V-O=6QD;G1?;F%M961?;6%N
M86=E<B<@/3X@(D%N(&%P<&QI8V%T:6]N(&-A;FYO="!B92!N86UE9"!A<R!M
M86YA9V5R(BP*"2=W96)?87!P<U]?=V5B7V%P<%]F:6QE;F%M95]I;G9A;&ED
M)R`]/B`B07!P;&EC871I;VX@9FEL96YA;64@:7,@:6YV86QI9"X@57-E(&]N
M;'D@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,L(&1O="!A;F0@:'EP:&5N('-Y
M;6)O;',N(BP*"2=W96)?87!P<U]?=V5B87!P7V5X:7-T<R<@/3X@(D$@2F%V
M82!A<'!L:6-A=&EO;B!W:71H('-U8V@@;F%M92!A;')E861Y(&5X:7-T<RXB
M+`H*"2=W=5]?861D:71I;VYA;%]F96%T=7)E<R<@/3X@(D%D9&ET:6]N86P@
M9F5A='5R97,B+`H))W=U7U]A=%]D;VUA:6YS7W1E>'0G(#T^(")%;F%B;&4@
M=V5B=7-E<D`E,2!A8V-E<W,@9F]R;6%T(BP*"2=W=5]?96YT97)?=V5B7W5S
M97)?;F%M92<@/3X@(D5N=&5R(&YE=R!W96(@=7-E<B!N86UE+B(L"@DG=W5?
M7VYE=U]W=2<@/3X@(D%D9"!N97<@=V5B('5S97(@;V8@9&]M86EN(#QB/B4Q
M/"]B/B(L"@DG=W5?7W)E;6]V95]W=5]O;E]D;VTG(#T^(")4:&4@9F]L;&]W
M:6YG('=E8B!U<V5R<R!O9B!D;VUA:6X@)3$@=VEL;"!B92!R96UO=F5D.B(L
M"@DG=W5?7W)E;6]V95]W=5]O;E]D;VU?;V9?8VPG(#T^(")4:&4@9F]L;&]W
M:6YG('=E8B!U<V5R<R!O9B!D;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q
M('=I;&P@8F4@<F5M;W9E9#HB+`H))W=U7U]S96QE8W1?=W5?9F]R7W)E;6]V
M92<@/3X@(E-E;&5C="!T:&4@=V5B('5S97)S('1O(&)E(')E;6]V960N(BP*
M"2=W=5]?=6YA8FQE7V-R96%T92<@/3X@(E5N86)L92!T;R!C<F5A=&4@=V5B
M('5S97(Z("4Q(BP*"2=W=5]?=6YA8FQE7W)E;6]V95]W=2<@/3X@(E5N86)L
M92!T;R!R96UO=F4@=V5B('5S97)S.B`E,2(L"@DG=W5?7W=E8E]U<V5R<U]D
M;VUA:6XG(#T^(")796(@=7-E<G,@;V8@9&]M86EN("4Q(BP*"2=W=5]?=W5?
M:61?=6YD969I;F5D)R`]/B`B5V5B('5S97(@:60@:7,@=6YD969I;F5D+B(L
M"@DG=W5?7W=U7VYA;64G(#T^(")796(@=7-E<B!N86UE(BP*"2=W=5]E9&ET
M7U]D:7-K7W%U;W1A)R`]/B`B1&ES:R!Q=6]T82(L"@DG=W5?961I=%]?:6YV
M86QI9%]P87-S)R`]/B`B4&%S<W=O<F0@:7,@:6YV86QI9"XB+`H))W=U7V5D
M:71?7VEN=F%L:61?<75O=&$G(#T^(")4:&4@<W!E8VEF:65D(&1I<VL@<W!A
M8V4@<75O=&$@=F%L=64@:7,@:6YV86QI9"X@4&QE87-E+"!E;G1E<B!A('!O
M<VET:79E(&EN=&5G97(N(BP*"2=W=5]E9&ET7U]N;W1?8W)E871E7W!A<W,G
M(#T^(")4:&ES(&%C=&EO;B!W:6QL(&YO="!C<F5A=&4@82!P87-S=V]R9"!F
M;W(@=&AE(&YE=R!W96(@=7-E<BY<;E=I=&AO=70@<&%S<W=O<F0@=&AE('5S
M97(@=VEL;"!N;W0@8F4@86)L92!T;R!L;V<@:6XN(BP*"2=W=5]E9&ET7U]P
M87-S=V1?9F]R7W=U)R`]/B`B4')O<&5R=&EE<R!O9B!W96(@=7-E<B`@)3$B
M+`H))W=U7V5D:71?7W5N86)L95]U<&1A=&4G(#T^(")5;F%B;&4@=&\@=7!D
M871E('1H92!W96(@=7-E<B!P<F]P97)T>3H@)3$B+`H*"2=D87-H8F]A<F1?
M7V)O;VMM87)K7V)U='1O;E]T:71L95]F879O<FET95]E9&ET)PD)/3X@)T5D
M:70@1F%V;W)I=&4G+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7W1I
M=&QE7V9A=F]R:71E7V%D9"<)"0D]/B`G061D('1O(&9A=F]R:71E<R<L"@DG
M9&%S:&)O87)D7U]B;V]K;6%R:U]B=71T;VY?=&ET;&5?<VAO<G1C=71?961I
M="<)"3T^("=%9&ET(%-H;W)T8W5T)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K
M7V)U='1O;E]T:71L95]S:&]R=&-U=%]A9&0G"0D)/3X@)T-R96%T92!S:&]R
M=&-U="<L"@H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R:7!T
M:6]N7V9A=F]R:71E7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@<VAO
M<G1C=70@=&\@(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N
M7V1E<V-R:7!T:6]N7V9A=F]R:71E7V%D9"<)/3X@)T%D9"`B)3$B('1O(&9A
M=F]R:71E<RXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R
M:7!T:6]N7W-H;W)T8W5T7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@
M<VAO<G1C=70@=&\@(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T
M=&]N7V1E<V-R:7!T:6]N7W-H;W)T8W5T7V%D9"<)/3X@)T-R96%T92!S:&]R
M=&-U="!T;R`B)3$B+B<L"@H))V1A<VAB;V%R9%]?8F]O:VUA<FM?=&ET;&5?
M9F%V;W)I=&5?961I="<)/3X@)T5D:71I;F<@4')O<&5R=&EE<R!O9B!3:&]R
M=&-U="!T;R`B)3$B)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K7W1I=&QE7V9A
M=F]R:71E7V%D9"<)/3X@)T%D9&EN9R`B)3$B('1O($9A=F]R:71E<R<L"@DG
M9&%S:&)O87)D7U]B;V]K;6%R:U]T:71L95]S:&]R=&-U=%]E9&ET)PD]/B`G
M161I=&EN9R!0<F]P97)T:65S(&]F(%-H;W)T8W5T('1O("(E,2(G+`H))V1A
M<VAB;V%R9%]?8F]O:VUA<FM?=&ET;&5?<VAO<G1C=71?861D)PD]/B`G0W)E
M871I;F<@<VAO<G1C=70@=&\@(B4Q(B<L"@H))V1A<VAB;V%R9%]?<V5C=&EO
M;E]S:&]W7W1I=&QE)PD)"0D]/B`G4F5S=&]R92<L"@DG9&%S:&)O87)D7U]S
M96-T:6]N7VAI9&5?=&ET;&4G"0D)"3T^("=-:6YI;6EZ92<L"@DG9&%S:&)O
M87)D7U]S:&]R=&-U=%]P<F]P97)T:65S7W1I=&QE)PD)/3X@)U-H;W)T8W5T
M(%!R;W!E<G1I97,G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&4G"0D)
M"0D]/B`G5&ET;&4G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&5?9&5F
M875L="<)"0D]/B`G57-E(&1E9F%U;'0G+`H))V1A<VAB;V%R9%]?<VAO<G1C
M=71?9&5S8W)I<'1I;VXG"0D)/3X@)T1E<V-R:7!T:6]N)RP*"2=D87-H8F]A
M<F1?7W-H;W)T8W5T7V1E<V-R:7!T:6]N7V1E9F%U;'0G"3T^("=5<V4@9&5F
M875L="<L"@DG9&%S:&)O87)D7U]S:&]R=&-U=%]T:71L95]I;G9A;&ED7W9A
M;'5E)PD]/B`G5&AE('1I=&QE('-H;W5L9"!C;VYT86EN(&9R;VT@,2!T;R`R
M-34@8VAA<F%C=&5R<RXG+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?9&5S8W)I
M<'1I;VY?:6YV86QI9%]V86QU92<)/3X@)U1H92!D97-C<FEP=&EO;B!S:&]U
M;&0@8V]N=&%I;B!F<F]M(#$@=&\@,C4U(&-H87)A8W1E<G,N)RP*"@DG9&%S
M:&)O87)D7U]P<F5S971S7V5X<&]R=%]F86EL960G"3T^("=%<G)O<B!O8V-U
M<G)E9"!D=7)I;F<@97AP;W)T:6YG('-E;&5C=&5D($1E<VMT;W`@<')E<V5T
M<SH@)3$G+`H))V1A<VAB;V%R9%]?<')E<V5T7V5R<F]R)PD)/3X@)T5R<F]R
M(&]C8W5R<F5D(&EN($1E<VMT;W`@<')E<V5T("(E,2(G+`H))V1A<VAB;V%R
M9%]?<')E<V5T7V5R<F]R7U\G"0D]/B`G17)R;W(@;V-C=7)R960@:6X@1&5S
M:W1O<"!P<F5S970@(B4Q(CH@)3(G+`H*"2=D87-H8F]A<F1?7W!R97-E=%]U
M<&QO861?9F%I;&5D)PD]/B`G17)R;W(@;V-C=7)R960@9'5R:6YG(&EM<&]R
M=&EN9R!$97-K=&]P('!R97-E=',@9G)O;2!F:6QE.B`E,2<L"@DG9&%S:&)O
M87)D7U]P<F5S971?<F5P;&%C95]N86UE7V-O;F9L:6-T)PD]/B`G4')E<V5T
M<R!W:71H('1H92!N86UE<R!C;VYT86EN960@:6X@=&AE(&9I;&4@86QR96%D
M>2!E>&ES="!I;B!0;&5S:RX@5&\@<F5P;&%C92!E>&ES=&EN9R!P<F5S971S
M('=I=&@@=&AE('5P;&]A9&5D(&]N97,L('-E;&5C="!T:&4@;W9E<G=R:71I
M;F<@8V]N9FER;6%T:6]N(&-H96-K8F]X+B<L"@DG9&%S:&)O87)D7U]P<F5S
M971?=7!L;V%D7W)E<&QA8V5?8V]N9FER;6%T:6]N)R`]/B`G3W9E<G=R:71E
M('!R97-E=',@=VET:"!T:&4@<V%M92!N86UE(&%N9"!T>7!E+B<L"@H))V1A
M<VAB;V%R9%]?<')E<V5T7W5P;&]A9%]T:71L92<)/3X@)U5P;&]A9&EN9R!$
M97-K=&]P(%!R97-E=',G+`H))V1A<VAB;V%R9%]?<')E<V5T7W5P;&]A9%]L
M96=E;F0G"3T^("=5<&QO860@1&5S:W1O<"!P<F5S971S)RP*"2=D87-H8F]A
M<F1?7W!R97-E=%]U<&QO861?9FEL96YA;64G"3T^("=$97-K=&]P('!R97-E
M=',@9FEL92!L;V-A=&EO;B<L"@H))V1A<VAB;V%R9%]?<')E<V5T7VYA;65?
M97AI<W1S)PD)/3X@)T1E<VMT;W`@4')E<V5T("!W:71H(&YA;64@)3$@86QR
M96%D>2!E>&ES=',N)RP*"2=?7V1A<VAB;V%R9%]P<F5S970G"0D)"3T^("=$
M97-K=&]P('!R97-E="<L"@DG9&%S:&)O87)D7U]P<F5S971S7W!R:79A=&4G
M"0D]/B`G0W5S=&]M:7IE9"!$97-K=&]P)RP*"@DG9&%S:&)O87)D7U]P<F5S
M971S7VQI<W1?;&5G96YD)PD]/B`G1&5S:W1O<"!P<F5S971S)RP*"2=D87-H
M8F]A<F1?7W!R97-E='-?;&ES=%]I=&5M)PD)/3X@)T1E<VMT;W`@<')E<V5T
M<R<L"@DG9&%S:&)O87)D7U]P<F5S971S7VQI<W1?8V]P>2<)"3T^("=#;W!Y
M($1E<VMT;W`@<')E<V5T)RP*"2=D87-H8F]A<F1?7W!R97-E='-?='EP92<)
M"3T^("=4)RP*"2=D87-H8F]A<F1?7W!R97-E=%]T>7!E)PD)/3X@)U1Y<&4G
M+`H))V1A<VAB;V%R9%]?<')E<V5T7W1Y<&5?861M:6XG"0D]/B`G061M:6YI
M<W1R871O<EPG<R!D97-K=&]P('!R97-E="<L"@DG9&%S:&)O87)D7U]P<F5S
M971?='EP95]C;&EE;G0G"0D]/B`G0VQI96YT7"=S(&1E<VMT;W`@<')E<V5T
M)RP*"2=D87-H8F]A<F1?7W!R97-E=%]T>7!E7V1O;6%I;B<)"3T^("=$;VUA
M:6X@;W=N97)<)W,@9&5S:W1O<"!P<F5S970G+`H))V1A<VAB;V%R9%]?<')E
M<V5T<U]N86UE)PD)/3X@)T1E<VMT;W`@<')E<V5T(&YA;64G+`H))V1A<VAB
M;V%R9%]?<')E<V5T7VYA;64G("`)"3T^("=.86UE)RP*"2=D87-H8F]A<F1?
M7W!R97-E=%]D969A=6QT)PD)/3X@)T1E9F%U;'0G+`H))V1A<VAB;V%R9%]?
M<')E<V5T7V1I<V%B;&5D7W1A<VMS)PD]/B`G079A:6QA8FQE('1A<VMS)RP*
M"2=D87-H8F]A<F1?7W!R97-E=%]E;F%B;&5D7W1A<VMS)PD]/B`G4V5L96-T
M960@=&%S:W,G+`H*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?8W5S=&]M
M7W!R97-E="<@/3X@)T-U<W1O;2!$97-K=&]P('!R97-E="!C86YN;W0@8F4@
M<F5M;W9E9"XG+`H))V1A<VAB;V%R9%]?9&5L971E7W!R97-E=%]P<FEV871E
M7W!R97-E="<@/3X@)U!R:79A=&4@1&5S:W1O<"!P<F5S970@8V%N;F]T(&)E
M(')E;6]V960N)RP*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?9&5F875L
M=%]P<F5S970G(#T^("=$969A=6QT($1E<VMT;W`@<')E<V5T(&-A;FYO="!B
M92!R96UO=F5D+B<L"@H))V1A<VAB;V%R9%]?=W)O;F=?<')E<V5T7W1Y<&4G
M"0D]/B`G26YC;VUP871I8FQE($1E<VMT;W`@<')E<V5T('1Y<&4N)RP*"@DG
M<&)?7V1A<VAB;V%R9"<)"0D)/3X@)T1E<VMT;W`G+`H*"2=D87-H8F]A<F1?
M7W!R97-E='-?>&UL7VQO861?97)R;W(G"3T^("=5;F%B;&4@=&\@:6UP;W)T
M(&1E<VMT;W`@<')E<V5T<SH@5&AE('5P;&]A9&5D(%A-3"!F:6QE(&-O;G1A
M:6YS(&$@<WEN=&%X(&5R<F]R+B<L"@DG9&%S:&)O87)D7U]P<F5S971S7WAM
M;%]V86QI9&%T:6]N7V5R<F]R)PD]/B`G56YA8FQE('1O(&EM<&]R="!D97-K
M=&]P('!R97-E=',Z(%1H92!U<&QO861E9"!834P@9FEL92!C;VYT86EN<R!A
M('-Y;G1A>"!E<G)O<BXG+`H))V1A<VAB;V%R9%]?<')E<V5T<U]X;6Q?=F5R
M<VEO;E]E<G)O<B<)"3T^("=5;F%B;&4@=&\@:6UP;W)T(&1E<VMT;W`@<')E
M<V5T<SH@5&AE('5P;&]A9&5D(%A-3"!F:6QE('=A<R!C<F5A=&5D(&)Y(%!L
M97-K('9E<G-I;VX@)3(@=VAI8V@@:7,@96%R;&EE<B!T:&%N('1H92!C=7)R
M96YT('9E<G-I;VX@*"4Q*2XG+`H*"2=D87-H8F]A<F1?7W!R97-E=%]R96UO
M=F5?96UP='E?<V5L96-T:6]N)PD]/B`G3F\@<')E<V5T<R!S96QE8W1E9"X@
M4V5L96-T(&1E<VMT;W`@<')E<V5T<R!Y;W4@=V%N="!T;R!R96UO=F4N)RP*
M"2=D87-H8F]A<F1?7W!R97-E=%]R96UO=F5?=&ET;&4G"0D)/3X@)U1H92!F
M;VQL;W=I;F<@1&5S:W1O<"!P<F5S971S('=I;&P@8F4@<F5M;W9E9#HG+`H*
M"2=D87-H8F]A<F1?7W!R97-E=%]E9&ET7W1I=&QE)PD)"0D]/B`G161I=&EN
M9R!$97-K=&]P(%!R97-E="<L"@DG9&%S:&)O87)D7U]D87-H8F]A<F1?8W5S
M=&]M:7IE7W1I=&QE)PD)/3X@)T-U<W1O;6EZ:6YG($1E<VMT;W`G+`H*"2=S
M97)V97)?:6YT97)F86-E7U]P86=E7W1I=&QE)PD]/B`G4V5R=F5R($EN=&5R
M9F%C92!0<F5F97)E;F-E<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]L
M;V-A;&5S)R`]/B`G3&]C86QE<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B
M<U]S:VEN<R<)(#T^("=3:VEN<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B
M<U]D87-H8F]A<F1?<')E<V5T<R<@/3X@)T1E<VMT;W`@4')E<V5T<R<L"@DG
M<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]I;G1E<F9A8V5?=&5M<&QA=&5S)R`]
M/B`G26YT97)F86-E(%1E;7!L871E<R<L"@DG8G1?<V5R=F5R7VEN=&5R9F%C
M92<)/3X@)TEN=&5R9F%C92!0<F5F97)E;F-E<R<L"@DG<&)?7W-E<G9E<E]I
M;G1E<F9A8V4G"3T^("=);G1E<F9A8V4@4')E9F5R96YC97,G+`H*"2=B=%]W
M:7IA<F1?;F5X="<@/3X@)TYE>'0@/CXG+`H))V)T7W=I>F%R9%]P<F5V)R`]
M/B`G/#P@0F%C:R<L"@H))U]?;&EM:71?97AC965D961?;6%X7V1O;5]S97)V
M97(G"0D)"3T^("=397)V97(@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&1O;6%I;G,N(%!L96%S92!C;VYT86-T('1O('1H92!S97)V97(@861M
M:6YI<W1R871O<BXG+`H))U]?;&EM:71?97AC965D961?;6%X7W-U8F1O;5]S
M97)V97(G"0D)/3X@)U-E<G9E<B!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@<W5B9&]M86EN<RX@4&QE87-E(&-O;G1A8W0@=&\@=&AE('-E<G9E
M<B!A9&UI;FES=')A=&]R+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?9&]M
M86EN7V%L:6%S97-?<V5R=F5R)PD]/B`G4V5R=F5R(')E86-H960@=&AE(&QI
M;6ET(&]N(&YU;6)E<B!O9B!D;VUA:6X@86QI87-E<RX@4&QE87-E(&-O;G1A
M8W0@=&\@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R+B<L"@DG7U]L:6UI=%]E
M>&-E961E9%]M87A?=W5?<V5R=F5R)PD)"0D]/B`G4V5R=F5R(')E86-H960@
M=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!W96(@=7-E<B`@86-C;W5N=',N(%!L
M96%S92!C;VYT86-T('1O('1H92!S97)V97(@861M:6YI<W1R871O<BXG+`H)
M)U]?;&EM:71?97AC965D961?;6%X7VUN7W-E<G9E<B<)"0D)/3X@)U-E<G9E
M<B!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@92UM86EL(&YA;65S
M+B!0;&5A<V4@8V]N=&%C="!T;R!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T;W(N
M)RP*"@DG7U]L:6UI=%]E>&-E961E9%]M87A?8VQ?=7-E<F%D;6EN)PD)/3X@
M)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!C;&EE
M;G0@86-C;W5N=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO
M=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E
M>&-E961E9%]M87A?9&]M7W5S97)A9&UI;B<)"3T^("=9;W4@:&%V92!R96%C
M:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@9&]M86EN<R!D969I;F5D(&)Y
M('EO=7(@;&EC96YS92!K97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q
M=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<W5B9&]M7W5S
M97)A9&UI;B<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N
M=6UB97(@;V8@<W5B9&]M86EN<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K
M97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG
M7U]L:6UI=%]E>&-E961E9%]D:7-K7W-P86-E7W5S97)A9&UI;B<)"3T^("=9
M;W4@:&%V92!N;R!F<F5E(&1I<VL@<W!A8V4@;&5F="X@5&]T86P@86UO=6YT
M(&]F(&%V86EL86)L92!D:7-K('-P86-E.B`E,BX@57-E9#H@)3,N(%)E<75I
M<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S97)A9&UI
M;B<)"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F('=E8B!U<V5R("!A8V-O=6YT<R!D969I;F5D(&)Y('EO=7(@;&EC96YS
M92!K97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L
M"@DG7U]L:6UI=%]E>&-E961E9%]M87A?9&)?=7-E<F%D;6EN)PD)"3T^("=9
M;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@9&%T86)A
M<V5S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E(&ME>2X@06QL;W=E9#H@)3(N
M(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D
M7VUA>%]B;WA?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R96%C:&5D('1H
M92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;&)O>&5S(&1E9FEN960@8GD@>6]U
M<B!L:6-E;G-E(&ME>2X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E
M9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M;E]U<V5R861M:6XG
M"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F
M(&4M;6%I;"!N86UE<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L
M;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI
M=%]E>&-E961E9%]M87A?<F5D:7)?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E
M(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL(&9O=V%R9&5R
M<R`H<F5D:7)E8W1S*2!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L
M;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI
M=%]E>&-E961E9%]M87A?;6=?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R
M96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;"!G<F]U<',@*&4M
M;6%I;"!F;W)W87)D97)S('=I=&@@;75L=&EP;&4@<F5C:7!I96YT<RD@9&5F
M:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@
M)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W)E
M<W!?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B`@875T;W)E<W!O;F1E<G,@9&5F:6YE9"!B>2!Y;W5R
M(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D
M.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7VUA:6QL:7-T<U]U<V5R
M861M:6XG"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@;6%I;&EN9R!L:7-T<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K
M97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG
M7U]L:6UI=%]E>&-E961E9%]M87A?=V5B87!P<U]U<V5R861M:6XG"3T^("=9
M;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@2F%V82!A
M<'!L:6-A=&EO;G,@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO
M=V5D.B`E,BX@26YS=&%L;&5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@H))U]?
M;&EM:71?97AC965D961?;6%X7V1O;5]U<V5R8VQI96YT)PD)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!D;VUA:6YS+B`@
M06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI
M;6ET7V5X8V5E9&5D7VUA>%]S=6)D;VU?=7-E<F-L:65N="<)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS
M("X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?
M7VQI;6ET7V5X8V5E9&5D7V1I<VM?<W!A8V5?=7-E<F-L:65N="<)/3X@)UEO
M=2!H879E(')E86-H960@=&AE(&1I<VL@<W!A8V4@=7-A9V4@;&EM:70N("!!
M;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM
M:71?97AC965D961?;6%X7W1R869F:6-?=7-E<F-L:65N="<)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&%M;W5N="!O9B!B86YD=VED=&@N
M($%L;&]W960Z("4R+B!5<V5D.B`E,RXG+`H))U]?;&EM:71?97AC965D961?
M;6%X7W=U7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@
M;&EM:70@;VX@;G5M8F5R(&]F('=E8B!U<V5R(&%C8V]U;G1S+B!!;&QO=V5D
M.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC
M965D961?;6%X7V1B7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE
M9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1A=&%B87-E<R`N($%L;&]W960Z
M("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E
M961E9%]M87A?8F]X7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE
M9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6QB;WAE<R`N($%L;&]W960Z
M("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E
M961E9%]M87A?<F5D:7)?=7-E<F-L:65N="<)"3T^("=9;W4@:&%V92!R96%C
M:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;"!F;W)W87)D97)S("AR
M961I<F5C=',I+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E
M-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7VUG7W5S97)C;&EE;G0G"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA
M:6P@9F]R=V%R9&5R<R!W:71H(&UU;'1I<&QE(')E8VEP:65N=',@*&UA:6P@
M9W)O=7!S*2X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N
M)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]R97-P7W5S97)C;&EE;G0G"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("!A
M=71O<F5S<&]N9&5R<RX@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E
M9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M86EL;&ES='-?=7-E
M<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU
M;6)E<B!O9B!M86EL:6YG(&QI<W1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N
M(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W=E8F%P
M<'-?=7-E<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<RX@06QL;W=E9#H@)3(N
M($EN<W1A;&QE9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E
M961E9%]E>'!I<F%T:6]N7W5S97)C;&EE;G0G"3T^("=9;W5R(&%C8V]U;G0@
M97AP:7)E9"!O;B`E,BXG+`H*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]S=6)D
M;VU?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS("X@06QL;W=E9#H@)3(N(%5S960Z
M("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7V1I<VM?
M<W!A8V5?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&1I
M<VL@<W!A8V4@=7-A9V4@;&EM:70N("!!;&QO=V5D.B`E,BX@57-E9#H@)3,N
M(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W1R869F
M:6-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&%M;W5N="!O9B!B86YD=VED=&@N($%L;&]W960Z("4R+B!5<V5D.B`E
M,RXG+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S97)D;VUA:6XG"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F('=E
M8B!U<V5R(&%C8V]U;G1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I
M<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7V1B7W5S97)D;VUA
M:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&1A=&%B87-E<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER
M960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?8F]X7W5S97)D;VUA
M:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&UA:6QB;WAE<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER
M960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<F5D:7)?=7-E<F1O
M;6%I;B<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@;6%I;"!F;W)W87)D97)S("AR961I<F5C=',I+B!!;&QO=V5D.B`E
M,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D
M961?;6%X7VUG7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T
M:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6P@9F]R=V%R9&5R<R!W:71H(&UU
M;'1I<&QE(')E8VEP:65N=',@*&UA:6P@9W)O=7!S*2X@06QL;W=E9#H@)3(N
M(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D
M7VUA>%]R97-P7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T
M:&4@;&EM:70@;VX@;G5M8F5R(&]F("!A=71O<F5S<&]N9&5R<RX@06QL;W=E
M9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X
M8V5E9&5D7VUA>%]M86EL;&ES='-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E
M(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S
M+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?
M;&EM:71?97AC965D961?;6%X7W=E8F%P<'-?=7-E<F1O;6%I;B<)/3X@)UEO
M=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!*879A(&%P
M<&QI8V%T:6]N<RX@06QL;W=E9#H@)3(N($EN<W1A;&QE9#H@)3,N(%)E<75I
M<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E961E9%]E>'!I<F%T:6]N7W5S97)D
M;VUA:6XG"3T^("=9;W5R(&%C8V]U;G0@97AP:7)E9"!O;B`E,BXG+`H*"@DG
M86-T:6]N;&]G7U]D8E]S97)V97(G(#T^("=$871A8F%S92!S97)V97(G+`H)
M)V1A<VAB;V%R9%]?<')E<V5T<U]S96QE8W1?=&]?9&]W;FQO860G(#T^("=.
M;R!D97-K=&]P('!R97-E=',@<V5L96-T960N(%!L96%S92!S96QE8W0@=&AE
M('!R97-E=',@>6]U('=A;G0@=&\@9&]W;FQO860N)RP*"2=M:6=R871I;VY?
M=7!L;V%D7V9O<FU?;65S)R`]/B`G57!L;V%D:6YG(&UI9W)A=&EO;B!A9V5N
M="!T;R!H;W-T("4Q+B<L"@DG;6EG<F%T:6]N7W5P;&]A9%]A9V5N=%]F86QS
M92<@/3X@)T9A:6QE9"!T;R!U<&QO860@=&AE(&UI9W)A=&EO;B!A9V5N="<L
M"@DG;6EG<F%T:6]N7W5P;&]A9%]A9V5N="<@/3X@)TUI9W)A=&EO;B!!9V5N
M="!5<&QO860G+`H))VUI9W)A=&EO;E]U<&QO861?86=E;G1?;VXG(#T^("=5
M<&QO861I;F<@36EG<F%T:6]N($%G96YT('1O("4Q)RP*"2=M:6=R871I;VY?
M:&]S=%]I;F9O)R`]/B`G26YF;W)M871I;VX@;VX@4V]U<F-E($AO<W0@)3$G
M+`H))VUI9W)A=&EO;E]G971?86-C;W5N=%]A;F1?9&]M86EN<R<@/3X@)U-E
M;&5C="!O8FIE8W1S('1H870@>6]U('=I<V@@=&\@;6EG<F%T92!F<F]M(&AO
M<W0@)3$G+`H))VUI9W)A=&EO;E]M97-S86=E7VQE9V5N9"<@/3X@)TEN9F]R
M;6%T:6]N)RP*"2=M:6=R871I;VY?:&]S=%]D971A:6QS)R`]/B`G2&]S="!D
M971A:6QS)RP*"2=M:6=R871I;VY?:&]S=%]I;F9O7V]S)R`]/B`G3W!E<F%T
M:6YG('-Y<W1E;2<L"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]L;V%D879G)R`]
M/B`G3&]A9"!A=F5R86=E(&]N('1H92!H;W-T)RP*"2=M:6=R871I;VY?:&]S
M=%]I;F9O7VAO<W1I;F=P;&%T9F]R;2<@/3X@)TAO<W1I;F<@<&QA=&9O<FTO
M=F5R<VEO;B<L"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]C;&EE;G1S)R`]/B`G
M3G5M8F5R(&]F(&-L:65N=',G+`H))VUI9W)A=&EO;E]H;W-T7VEN9F]?9&]M
M86EN<R<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I;VY?:&]S
M=%]I;F9O7VAO<W0G(#T^("=397)V97(G+`H))VUI9W)A=&EO;E]G971?86-C
M;W5N=%]D;VUA:6Y?;65S)R`]/B`G1&]W;FQO861I;F<@82!L:7-T(&]F(&%C
M8V]U;G1S(&%N9"!D;VUA:6YS(&9R;VT@=&AE('-O=7)C92!H;W-T("4Q+B<L
M"@DG;6EG<F%T:6]N7VUA:6Y?9&]W;FQO860Q)R`]/B`B5')A;G-F97)R:6YG
M(&9I;&4Z("4Q7&Y3:7IE.B`E,EQN3&5F="!T;R!T<F%N<V9E<CH@)3,B+`H)
M)VUI9W)A=&EO;E]M86EN7V1O=VYL;V%D,B<@/3X@(DAO<W0Z("4Q7&Y4<F%N
M<V9E<G)E9#H@)3(@9FEL97,L("4S7&Y,969T.B`E-"!F:6QE<RP@)35<;E1R
M86YS9F5R('-P965D.B`E-B(L"@DG;6EG<F%T:6]N7W-E;&5C=%]A8V-O=6YT
M)R`]/B`G4V5L96-T('1H92!C;&EE;G0@86-C;W5N="<L"@DG;6EG<F%T:6]N
M7VEP7VUA<%]P86=E)R`]/B`G25`@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A
M=&$@9G)O;2`E,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?<&%G92<@
M/3X@)T1A=&%B87-E('-E<G9E<G,@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A
M=&$@9G)O;2`E,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?;&5G96YD
M)R`]/B`G1$(@<V5R=F5R<R!M87!P:6YG)RP*"2=M:6=R871I;VY?:7!?;6%P
M)R`]/B`G25`@36%P<&EN9R<L"@DG;6EG<F%T:6]N7VEP7VUA<%]A;&5R="<@
M/3X@)U!L96%S92!S<&5C:69Y(&UA<'!I;F<@9F]R(&%L;"!)4"!A9&1R97-S
M97,G+`H))VUI9W)A=&EO;E]S=&]P7W!A9V4G(#T^("=3=&]P(&UI9W)A=&EN
M9R!D871A(&9R;VT@:&]S="`E,2<L"@DG;6EG<F%T:6]N7W-T;W!?;65S<V%G
M92<@/3X@)U-T;W`@=&AE(&UI9W)A=&EO;B!P<F]C97-S)RP*"2=M:6=R871I
M;VY?9&5P;&]Y7VEN9F\Q)R`]/B`G1&5P;&]Y:6YG("4Q("4R)RP*"2=M:6=R
M871I;VY?9&5P;&]Y7VEN9F\R)R`]/B`B5&]T86P@86-C;W5N=',O;&5F="`E
M,2\E,EQN5&]T86P@9&]M86EN<R]L969T("4S+R4T7&XB+`H))VUI9W)A=&EO
M;E]N;W1I9GDG(#T^("=.;W1I9GD@=7-E<G,@=7!O;B!C<F5A=&EO;B!O9B!E
M86-H('-Y<W1E;2!O8FIE8W0G+`H))VUI9W)A=&EO;E]K965P7V%R8VAI=F5S
M)R`]/B`G2V5E<"!T:&4@=&5M<&]R87)Y(&9I;&5S)RP*"2=M:6=R871I;VY?
M<V5T=&EN9R<@/3X@)T1E<&QO>6UE;G0@4V5T=&EN9W,G+`H))VUI9W)A=&EO
M;E]S971T:6YG7VQE9R<@/3X@)T1E<&QO>6UE;G0@<V5T=&EN9W,G+`H))VUI
M9W)A=&EO;E]D97!L;WE?<')O9W)E<W,G(#T^("=$97!L;WEM96YT('!R;V=R
M97-S)RP*"2=M:6=R871I;VY?9&5P;&]Y7VEN9F\G(#T^("=$97!L;WEM96YT
M('!R;V=R97-S(&9O<B!H;W-T("4Q)RP*"2=M:6=R871I;VY?:&]S="<@/3X@
M)U-O=7)C92!H;W-T)RP*"2=M:6=R871I;VY?<&%S<W=O<F0G(#T^("=,;V=I
M;B!P87-S=V]R9"<L"@DG;6EG<F%T:6]N7W!L871F;W)M)R`]/B`G4V]U<F-E
M('!L871F;W)M)RP*"2=M:6=R871I;VY?=')A;G-L971E)R`]/B`G0V]N=F5R
M=&EN9R!D=6UP('1O(%!L97-K(&9O<FUA="<L"@DG;6EG<F%T:6]N7V%G96YT
M7W=A:70G(#T^("=786ET:6YG('1H92!R97-P;VYS92!F<F]M(&%G96YT)RP*
M"2=M:6=R871I;VY?96YD7V1E<&QO>5]I;F9O)R`]/B`G1&%T82!M:6=R871I
M;VX@9G)O;2!H;W-T("4Q(&AA<R!B965N(&-O;7!L971E9"XG+`H))VUI9W)A
M=&EO;E]D97!L;WE?9&5T86EL<R<@/3X@)T1E=&%I;',G+`H))VUI9W)A=&EO
M;E]W<F]N9U]A9V5N="<@/3X@)T%G96YT(&ES(&YO="!S=6ET86)L92!F;W(@
M=&AE(&=I=F5N(&AO<W0N)RP*"2=M:6=R871I;VY?<V5L96-T7W-O;64G(#T^
M("=396QE8W0@=&AE(&]B:F5C=',@=&\@;6EG<F%T92XG+`H))VUI9W)A=&EO
M;E]D;W=L;V%D)R`]/B`G1&]W;FQO861I;F<@8V]N=&5N="!F<F]M(&AO<W0@
M)3$G+`H))VUI9W)A=&EO;E]D;W=L;V%D7W!R;V=R97-S)R`]/B`G1&]W;FQO
M860@<')O9W)E<W,G+`H))VUI9W)A=&EO;E]D;W=L;V%D7V-U<G)E;G0G(#T^
M("=$;W=N;&]A9&EN9R!C=7)R96YT(&9I;&4G+`H))VUI9W)A=&EO;E]X;6Q?
M9&5S8R<@/3X@)T1O=VYL;V%D:6YG('1H92!D=6UP(&1E<V-R:7!T:6]N+B<L
M"@DG;6EG<F%T:6]N7VYO7V5R<F]R<R<@/3X@)U1H92!M:6=R871I;VX@:&%S
M(&)E96X@8V]M<&QE=&5D+B<L"@DG;6EG<F%T:6]N7W5N86)L95]G971?86-C
M;W5N=%]A;F1?9&]M86EN<R<@/3X@)U5N86)L92!T;R!R971R:65V92!A(&QI
M<W0@;V8@86-C;W5N=',@86YD(&1O;6%I;G,Z("<L"@DG;6EG<F%T:6]N7W5N
M86)L95]T<F%N<VQA=&4G(#T^("=5;F%B;&4@=&\@8V]N=F5R="!T:&4@9&%T
M82!T;R!0;&5S:R!F;W)M870Z("<L"@DG;6EG<F%T:6]N7W5N86)L95]D=6UP
M7W)E=')I979E)R`]/B`G1F%I;&5D('1O(')E=')I979E('1H92!D871A.B`G
M+`H))VUI9W)A=&EO;E]U;F%B;&5?87)C:&EV95]H;W-T)R`]/B`G56YA8FQE
M('1O(&-R96%T92!A(&1E<V-R:7!T:6]N(&9O<B!T:&4@;6EG<F%T960@;V)J
M96-T<SH@)RP*"2=M:6=R871I;VY?<V5L96-T7V%C8V]U;G1?<&%G92<@/3X@
M)U-E;&5C="!T:&4@8VQI96YT(&%C8V]U;G0@=&\@=VAI8V@@>6]U('=I<V@@
M=&\@;6EG<F%T92!T:&4@9&]M86EN<R<L"@DG;6EG<F%T:6]N7W5N86)L95]D
M97!L;WDG(#T^("=5;F%B;&4@=&\@9&5P;&]Y('1H92!M:6=R871E9"!O8FIE
M8W1S.B`G+`H))V)T7VUI9W)A=&EO;E]M;W)E)R`]/B`G36EG<F%T92!M;W)E
M)RP*"2=B=%]M:6=R871I;VY?8F5G:6XG(#T^("=&:6YI<V@G+`H))VUI9W)A
M=&EO;E]S96QE8W1?97AI<W1?:7`G(#T^("=396QE8W0@9&5S=&EN871I;VX@
M25`G+`H))VUI9W)A=&EO;E]S96QE8W1?97AI<W1?9&)?<V5R=F5R)R`]/B`G
M4V5L96-T(&1E<W1I;F%T:6]N($1"('-E<G9E<B<L"@DG;6EG<F%T:6]N7V1O
M;6%I;E]C;W5N="<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I
M;VY?86-C;W5N="<@/3X@)T%C8V]U;G0G+`H))VUI9W)A=&EO;E]D96UO7W=A
M<B<@/3X@(E=A<FYI;F<A(%1H:7,@:7,@=&AE($UI9W)A=&EO;B!-86YA9V5R
M(&1E;6\N($YO(&%C8V]U;G1S(&%N9"!D;VUA:6YS('=I;&P@8F4@86-T=6%L
M;'D@;6EG<F%T960N(%QN4&QE87-E('-P96-I9GD@=&AE(&1E<VER960@=F%L
M=65S+B(L"@DG;6EG<F%T:6]N7V1O=VYL;V%D7VYO=%]S<&%C92<@/3X@)TYO
M="!E;F]U9V@@9&ES:R!S<&%C92$G+`H))V)T7VUI9W)A=&EO;E]I9VYO<F4G
M(#T^("=)9VYO<F4G+`H))V)T7VUI9W)A=&EO;E]R971R>2<@/3X@)U)E=')Y
M)RP*"2=M:6=R871I;VY?9'5M<%]A;&PG(#T^("=-:6=R871E(&%L;"!C;&EE
M;G1S(&%N9"!D;VUA:6YS)RP*"2=M:6=R871I;VY?9&5T86EL<R<@/3X@)TUI
M9W)A=&EO;B!D971A:6QS)RP*"2=M:6=R871I;VY?;&EM:71?97)R;W(G(#T^
M(")4:&4@;G5M8F5R(&]F('MT>7!E?2!Y;W4@87)E('1R>6EN9R!T;R!C<F5A
M=&4@=V]U;&0@;W9E<G)I9&4@=&AE(&QI;6ET<R!D969I;F5D(&)Y('1H92!L
M:6-E;G-E(&ME>2`M("4Q+EQN66]U(&-A;B!C<F5A=&4@;VYL>2`E,B![='EP
M97T@;6]R92XB+`H))VUI9W)A=&EO;E]I9&QE)R`]/B`G4')E<&%R:6YG(&9O
M<B!E>&5C=71I;VXG+`H))VUI9W)A=&EO;E]R96UO=F5?86=E;G0G(#T^("=2
M96UO=F4@86=E;G0G+`H))VUI9W)A=&EO;E]S=&]P7VQA8FQE)R`]/B`G4W1O
M<'!I;F<G+`H))VUI9W)A=&EO;E]R96UO=F5?87)C:&EV92<@/3X@)U)E;6]V
M92!T96UP;W)A<GD@9FEL97,G+`H))VUI9W)A=&EO;E]N;U]O8FIE8W0G(#T^
M("=4:&5R92!A<F4@;F\@;V)J96-T<R!F;W(@;6EG<F%T:6]N(&]N('1H92!R
M96UO=&4@:&]S="XG+`H))VUI9W)A=&EO;E]N;U]D;VUA:6XG(#T^("=.;R!D
M;VUA:6YS('=E<F4@9F]U;F0G+`H))V)T7VUI9W)A=&5?<VEN9VQE)R`]/B`G
M4VEN9VQE+4AO<W0@36EG<F%T:6]N)RP*"2=M:6=R871I;VY?8V]M<')E<W,G
M(#T^("=$871A(&-O;7!R97-S:6]N)RP*"2=M:6=R871I;VY?;6]D92<@/3X@
M)TUI9W)A=&EO;B!M;V1E)RP*"2=M:6=R871I;VY?9'5M<%]M97-S86=E,2<@
M/3X@(D-U<G)E;G1L>2!D=6UP:6YG('1H92!A8V-O=6YT.B`E,5QN0W5R<F5N
M="!D;VUA:6XZ("4R7&Y!8V-O=6YT<R!L969T('1O(&1U;7`Z("4S7&Y$;VUA
M:6YS(&QE9G0@=&\@9'5M<#H@)30B+`H))VUI9W)A=&EO;E]D=6UP7W!R;V=R
M97-S)R`]/B`G1'5M<&EN9R!P<F]G<F5S<R<L"@DG;6EG<F%T:6]N7V1U;7!?
M8W5R<F5N="<@/3X@)T1U;7!I;F<@9&%T82<L"@DG;6EG<F%T:6]N7V%G96YT
M7W!A=&@G(#T^("=$:7)E8W1O<GD@;VX@=&AE('-O=7)C92!H;W-T('=H97)E
M($UI9W)A=&EO;B!-86YA9V5R('=I;&P@<&QA8V4@86QL(&1A=&$@8F5F;W)E
M('1R86YS9F5R<FEN9R!T:&5M)RP*"2=M:6=R871I;VY?9'5M<%]N;V5X:7-T
M)R`]/B`G1F]R('1H92!S:6YG;&4M:&]S="!M:6=R871I;VXL('EO=2!S:&]U
M;&0@<&QA8V4@=&AE(&1U;7`@=&\@(B4Q(BXG+`H))VUI9W)A=&EO;E]S=61O
M7W!A<W-W;W)D)R`]/B`G4W5D;R!P87-S=V]R9"<L"@DG;6EG<F%T:6]N7W-U
M9&]?<F]O="<@/3X@)W)O;W0G+`H))VUI9W)A=&EO;E]S=61O7V]T:&5R<R<@
M/3X@)V]T:&5R)RP*"2=M:6=R871I;VY?8F%C:V5N9%]C<F%S:%]O9F9?;65S
M<R<@/3X@)TUI9W)A=&EO;B!-86YA9V5R(&)A8VL@96YD('1E<FUI;F%T960@
M8F5C875S92!O9B!U;F5X<&5C=&5D(&5R<F]R+B!0;&5A<V4@8V]N=&%C="!S
M=7!P;W)T+B<L"@DG;6EG<F%T:6]N7W-I;F=L95]N;W1E7VUE<W,G(#T^("=5
M<V4@=&AI<R!F96%T=7)E('1O(&EM<&]R="!T:&4@9&%T82!C<F5A=&5D(&)Y
M('1H92!M:6=R871I;VX@86=E;G0N)RP*"2=M:6=R871I;VY?<VEN9VQE7VUO
M9&4G(#T^("=$871A(&EM<&]R="<L"@DG;6EG<F%T:6]N7VYO<FUA;%]M;V1E
M)R`]/B`G36EG<F%T:6]N)RP*"2=M:6=R871I;VY?<V5L96-T7V-L:65N="<@
M/3X@)U-E;&5C="!C;&EE;G0G+`H))VUI9W)A=&EO;E]F<F]M)R`]/B`G("AM
M:6=R871I;VX@9G)O;2!H;W-T("4Q*2<L"@DG;6EG<F%T:6]N7W-E;&5C=%]M
M;V1E)R`]/B`G4V5L96-T(&UI9W)A=&EO;B!M;V1E)RP*"2=M:6=R871I;VY?
M<V5L96-T7V-L:65N=%]I;E]L:7-T)R`]/B`G5&\@<V5L96-T(&$@8VQI96YT
M+"!C;&EC:R!O;B!T:&4@8VQI96YT(&YA;64G+`H))VUI9W)A=&EO;E]S:6YG
M;&5?:6YF;R<@/3X@)TEM<&]R=&EN9R!D871A(&9R;VT@)3$G+`H))VUI9W)A
M=&EO;E]D=6UP7VEN9F\G(#T^("=$=6UP(&1E=&%I;',G+`H))VUI9W)A=&EO
M;E]S96QE8W1?<VEN9VQE7VUO9&4G(#T^("=396QE8W0@:6UP;W)T(&UO9&4G
M+`H))VUI9W)A=&EO;E]S96QE8W1?<VEN9VQE7VET96TG(#T^("=396QE8W0@
M;V)J96-T<R!F;W(@:6UP;W)T)RP*"2=M:6=R871I;VY?<VEN9VQE7V%L;"<@
M/3X@)TEM<&]R="!A;&PG+`H))VUI9W)A=&EO;E]A9&1?9G)E95]I<"<@/3X@
M)SQB/DYO=&4Z/"]B/B!">2!S96QE8W1I;F<@82!V86-A;G0@25`@861D<F5S
M<R!Y;W4@=VEL;"!A9&0@:70@=&\@8VQI96YT7"=S($E0('!O;VPN)RP*"2=M
M:6=R871I;VY?:7!?=F%C86YT)R`]/B`G5F%C86YT)RP*"2=M:6=R871I;VY?
M<VEN9VQE7W1R86YS)R`]/B`G0V]N=F5R=&EN9R!D871A('1O(&YA=&EV92!0
M;&5S:R!F;W)M870G+`H))VUI9W)A=&EO;E]S96QE8W1?:7`G(#T^("=396QE
M8W0@25`G+`H))VUI9W)A=&EO;E]N;U]C:&5C:U]S<&%C92<@/3X@)T1O(&YO
M="!C:&5C:R!F;W(@86UO=6YT(&]F(&9R964@9&ES:R!S<&%C92!D=7)I;F<@
M;6EG<F%T:6]N)RP*"2=M:6=R871I;VY?9G-?:6YF;U]M;W5N='!O:6YT)R`]
M/B`G36]U;G0@<&]I;G0G+`H))VUI9W)A=&EO;E]F<U]I;F9O7W1Y<&4G(#T^
M("=4>7!E)RP*"2=M:6=R871I;VY?9G-?:6YF;U]T;W1A;"<@/3X@)U1O=&%L
M)RP*"2=M:6=R871I;VY?9G-?:6YF;U]F<F5E)R`]/B`G1G)E92<L"@DG;6EG
M<F%T:6]N7V9S7VQE9V5N="<@/3X@)U-O=7)C92!H;W-T('!A<G1I=&EO;B<L
M"@DG;6EG<F%T:6]N7V9S7W5S86=E)R`]/B`G57-A9V4G+`H))VUI9W)A=&EO
M;E]L;V-A;%]F<U]L96=E;G0G(#T^("=7;W)K:6YG(&1I<F5C=&]R>2<L"@DG
M;6EG<F%T:6]N7W-T;W)A9V5?9&ER)R`]/B`G1&ER96-T;W)Y(&]N('1H:7,@
M<V5R=F5R('1O('=H:6-H(&%L;"!D871A('=I;&P@8F4@=')A;G-F97)R960G
M+`H))VUI9W)A=&EO;E]U<&QO861?<V-O=6YT)R`]/B`G4F5T<FEE=FEN9R!I
M;F9O<FUA=&EO;B!O;B!T:&4@:&]S="`E,2!I<R!I;B!P<F]C97-S)RP*"2=M
M:6=R871I;VY?=7!L;V%D7W-C;W5N=%]O;B<@/3X@)U)E=')I979I;F<@:6YF
M;W)M871I;VX@;VX@=&AE(&AO<W0@)3$G+`H))VUI9W)A=&EO;E]S;W5R8V5?
M<&QA=&9O<FTG(#T^("=-:6=R871I;VX@<&QA=&9O<FTG+`H))VUI9W)A=&EO
M;E]P;&%T9F]R;5]D971E8U]F86EL)R`]/B`G075T;VUA=&EC(&1E=&5C=&EO
M;B!O9B!H;W-T:6YG('!L871F;W)M(&9A:6QE9"X@4&QE87-E('-E;&5C="!P
M;&%T9F]R;2!M86YU86QL>2!F<F]M('1H92!C;VUB;R!B;W@@8F5L;W<N)RP*
M"2=M:6=R871I;VY?<V5L96-T7W!L871F;W)M)R`]/B`G+2T@4V5L96-T('!L
M871F;W)M("TM)RP*"2=M:6=R871I;VY?;F]?8VQI96YT)R`]/B`G66]U(&AA
M=F4@;F\@8VQI96YT(&%C8V]U;G1S(&]N('1H92!D97-T:6YA=&EO;B!H;W-T
M('1O(&UI9W)A=&4@9&]M86EN<R!T;R<L"@DG;6EG<F%T:6]N7W1E;7!L871E
M7VQE9V5N9"<@/3X@)T-R96%T:6]N(&]F(&1O;6%I;G,@8GD@=&5M<&QA=&4G
M+`H))VUI9W)A=&EO;E]C;&EE;G1?=&5M<&QA=&4G(#T^("=5<V4@82!T96UP
M;&%T92!F;W(@8W)E871I;F<@8VQI96YT(&%C8V]U;G1S)RP*"2=M:6=R871I
M;VY?9&]M86EN7W1E;7!L871E)R`]/B`G57-E(&$@=&5M<&QA=&4@9F]R(&-R
M96%T:6YG(&1O;6%I;G,G+`H))VUI9W)A=&EO;E]R96%C:&5D7VQI;6ET)R`]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("4Q
M+B<L"@DG;6EG<F%T:6]N7W)E86-H961?;&EM:71?8VQI96YT)R`]/B`G8VQI
M96YT(&%C8V]U;G1S)RP*"2=M:6=R871I;VY?<F5A8VAE9%]L:6UI=%]D;VUA
M:6XG(#T^("=D;VUA:6YS)RP*"2=M:6=R871I;VY?<V5S<VEO;E]L:7-T)R`]
M/B`G4&QE<VL@36EG<F%T:6]N($UA;F%G97(G+`H))VUI9W)A=&EO;E]C=7)R
M96YT7VUI9W)A=&EO;G-?;&ES="<@/3X@)T-U<G)E;G0@;6EG<F%T:6]N<R<L
M"@DG;6EG<F%T:6]N7V-U<G)E;G1?;6EG<F%T:6]N)R`]/B`G0W5R<F5N="!M
M:6=R871I;VYS)RP*"2=B=%]M:6=R871I;VY?<V5S<VEO;E]A9&0G(#T^("=3
M=&%R="!A(&YE=R!M:6=R871I;VXG+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI
M<W1?7V]B:F5C=',G(#T^("=-:6=R871I;F<@;V)J96-T<R<L"@DG;6EG<F%T
M:6]N7W-E<W-I;VY?;&ES=%]?<W1A<G1?9&%T92<@/3X@)U-T87)T(&1A=&4G
M+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7V5L87!S960G(#T^("=%;&%P
M<V5D('1I;64G+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7W!R;V=R97-S
M)R`]/B`G4')O9W)E<W,G+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7VYO
M=%]S96QE8W1E9"<@/3X@)TYO="!Y970@<V5L96-T960G+`H))VUI9W)A=&EO
M;E]S=&%T95]D97-C7V9A:6QE9"<@/3X@)T9A:6QE9"!M:6=R871I;VXG+`H)
M)VUI9W)A=&EO;E]S=&%T95]D97-C7V%W86ET:6YG7W-T87)T)R`]/B`G5V%I
M=&EN9R!F;W(@82!S=&%R="<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?87=A
M:71I;F=?86=E;G1?<&%R86TG(#T^("=0;&5A<V4@<W!E8VEF>2!M:6=R871I
M;VX@<&%R86UE=&5R<R<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?<V5L96-T
M7V]B:F5C="<@/3X@)U-E;&5C="!T:&4@8G5S:6YE<W,@;V)J96-T<R!T;R!M
M:6=R871E)RP*"2=M:6=R871I;VY?<W1A=&5?9&5S8U]S96QE8W1?8VQI96YT
M)R`]/B`G4V5L96-T('1H92!C;&EE;G0@9F]R(&UI9W)A=&EO;B<L"@DG;6EG
M<F%T:6]N7W-T871E7V1E<V-?:7!?;6%P)R`]/B`G25`@;6%P<&EN9R<L"@DG
M;6EG<F%T:6]N7W-T871E7V1E<V-?9&)?<V5R=F5R7VUA<"<@/3X@)T1"('-E
M<G9E<B!M87!P:6YG)RP*"2=M:6=R871I;VY?<W1A=&5?9&5S8U]A<&E?;6EG
M<F%T:6]N)R`]/B`G36EG<F%T:6]N(&UA9&4@8GD@;65A;G,@;V8@4E!#)RP*
M"2=M:6=R871I;VY?<W1A=&5?9&5S8U]D=6UP:6YG)R`]/B`G4F5T<FEE=FEN
M9R!D871A(&9R;VT@<F5M;W1E(&AO<W0G+`H))VUI9W)A=&EO;E]S97-S:6]N
M7V9A:6QE9"<@/3X@)TUI9W)A=&EO;B!F<F]M(&AO<W0@)3$@9F%I;&5D)RP*
M"2=M:6=R871I;VY?8V]M<&QE=&5D)R`]/B`G5&AE(&UI9W)A=&EO;B!H87,@
M8F5E;B!C;VUP;&5T960N)RP*"2=M:6=R871I;VY?;F]?861M:6Y?9&]M7W1E
M;7!L871E)R`]/B`G5&AE<F4@87)E(&YO(&%D;6EN:7-T<F%T;W)<)W,@9&]M
M86EN('1E;7!L871E<R<L"@DG;6EG<F%T:6]N7V5R<F]R7V9I;&4G(#T^("=&
M:6QE)RP*"2=M:6=R871I;VY?97)R;W)?;&EN92<@/3X@)TQI;F4G+`H))VUI
M9W)A=&EO;E]E<G)O<E]C;VYT97AT)R`]/B`G0V]N=&5X="<L"@DG;6EG<F%T
M:6]N7V5R<F]R7W1E>'0G(#T^("=497AT)RP*"2=M:6=R871I;VY?97)R;W)?
M='EP92<@/3X@)U1Y<&4G+`H))VUI9W)A=&EO;E]E<G)O<E]N86UE)R`]/B`G
M3F%M92<L"@DG;6EG<F%T:6]N7VYO7VEP7V%V86EL86)L92<@/3X@)TYO($E0
M(&%D9')E<W-E<R!A=F%I;&%B;&4G+`H))VUI9W)A=&EO;E]A;FYO;E]F='!?
M;&]S="<@/3X@)T%F=&5R($E0(&UA<'!I;F<L('EO=2!W:6QL(&YO="!B92!A
M8FQE('1O('5S92!A;F]N>6UO=7,@1E10('-E<G9I8V4@(&]N("(E,2(N)RP*
M"2=P8E]M:6=R871I;VY?9G)O;2<@/3X@)TUI9W)A=&EO;B!F<F]M("4Q)RP*
M"2=M:6=R871I;VY?8VUD7VEG;F]R960G(#T^("=4:&4@8V]M;6%N9"`B)3$B
M('=A<R!I9VYO<F5D+B<L"@DG;6EG<F%T:6]N7V1B7W-E<G9E<E]N;W1?9FEN
M9"<@/3X@)U1H92!D871A8F%S92!W:6QL(&YO="!B92!R97-T;W)E9#H@=&AE
M(&%P<')O<')I871E(&1A=&%B87-E('-E<G9E<B!F;W(@=&AI<R!D871A8F%S
M92!I<R!N;W0@:6YS=&%L;&5D+B<L"@DG;6EG<F%T:6]N7VYO=%]U;F%B;&5?
M;6EG<F%T95]S;VUE)R`]/B`G36EG<F%T:6]N(&-A;FYO="!C;VYT:6YU93H@
M96ET:&5R('1H92!S96QE8W1E9"!O8FIE8W1S(&%R92!A;')E861Y(&UI9W)A
M=&5D(&]R('1H97D@8V%N;F]T(&)E(&UI9W)A=&5D(&)E8V%U<V4@9&]M86EN
M(&YA;64@;W(@=7-E<B!A8V-O=6YT(&YA;64@:7,@:6YV86QI9"XG+`HI.PHO
M+W)E<75I<F5?;VYC92@G;&]C86QE<R]E;BU54R]U:5]C87!T:6]N<RYI;F,G
M*3L*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO<V)I;B\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$T-34U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]A9&UI;B]S8FEN+V9I;&5M;F<`````````````````````````````
M```````````````````````````````````````````````````````````P
M,3`P-34P`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$U-#$R-``Q,#4Q-30S,3`U
M-@`P,38Q,C$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````?T5,1@$!`0D```````````(``P`!````R)<$"#0```"4U```````
M`#0`(``&`"@`&``7``8````T````-(`$"#2`!`C`````P`````4````$````
M`P```/0```#T@`0(](`$"!D````9````!`````$````!``````````"`!`@`
M@`0(;LX``&[.```%`````!````$```!PS@``<%X%"'!>!0@@`P``)$````8`
M````$````@```##/```P7P4(,%\%",@```#(````!@````0````$````$`$`
M`!"!!`@0@00(&````!@````$````!````"]U<W(O;&EB97AE8R]L9"UE;&8N
M<V\N,0`````(````!`````$```!&<F5E0E-$`."!!P!A````<```````````
M````40```$,`````````!`````````!K````20``````````````$````&$`
M``!5````+````&H````1````"@````````!6````7@```%<```!L````````
M```````X````10```&````!=`````````#0`````````4P```%``````````
M```````````H````6````&(```!+````7````&T```!!````&P````````!H
M````6P```%\````Z````#P```&4````K````:0```&0````R`````````$P`
M```>`````````#X```!$````#````&8````V````````````````````;P``
M`&X`````````/0`````````Q`````````"0`````````9P```%H```!4````
M(0```$H````O````)P```&,`````````````````````````3P````8`````
M`````````"H```!2````.P```$@`````````````````````````````````
M``````````````````````````````@`````````````````````````````
M````````````$@``````````````#0````````````````````L`````````
M`P```!D`````````````````````````#@``````````````'P``````````
M````%@```"``````````````````````````!P`````````N`````````!<`
M```)````````````````````````````````````&@```#``````````-P``
M````````````.0````$````3````*0```"4````````````````````%````
M````````````````1@```````````````@```#P````_`````````!P`````
M`````````#,````=````-0```"T``````````````$(`````````(@``````
M``!'````0````!0````5````)@`````````8````30```",`````````````
M`%D```````````````````!.`````````````````````````*H!``#HD00(
MA0```!(````+````^)$$"``````2````L@$``*!A!0@$````$0`4`+P!```(
MD@0(*````!(```#$`0``&)($"%`"```2````%`,``"B2!`@O````$@```"@!
M```XD@0(7P```!(```#*`0``2)($"``````2````+`$``%B2!`A;````$@``
M`-@!``!HD@0(`````!(````U`0``I&$%"`0````1`!0`X`$``'B2!`BF````
M$@```",```"(D@0(;````!(````2````,%\%"``````1`/'_YP$``)B2!`BB
M````$@```#X!``"HD@0(M0```!(```#P`0``N)($"``````2````]P$``,B2
M!`@]````$@```/\!``#8D@0(8P```!(````&`@``Z)($"``````2````#0(`
M`/B2!`@`````$@```$4!```(DP0(3`$``!(````4`@``&),$"``````2````
M&P(``"B3!`BD````$@```$L!``"H804(!````!$`%`"5`0``.),$"+D````2
M````(@(``$B3!`@`````$@```%4!``!8DP0(`````!(````G`@``:),$"($!
M```2````&P```'B3!`@:`0``$@```"(```"(DP0(?````!(````N`@``F),$
M"",````2````-0(``*B3!`@`````$@```%P!``"XDP0(`````!(````[`@``
MR),$"*(````2````+````-B3!`B(````$@```$,"``#HDP0(9@0``!(````.
M`@``^),$"``````2````\0$```B4!`@`````$@```#,```#,D00(`````!(`
M"`!,`@``&)0$"``````2````8P$``+!A!0A4#```$0`4`%$"```HE`0(````
M`!(```!V`0``.)0$"``````2````6`(``$B4!`C-````$@```#D```!8E`0(
M0@```!(```!A`@``:)0$"``````2````E@```'B4!`@`````$@```&@"``"(
MG@4(!````!$`%`!P`@``B)0$"``````2````0````)B4!`@J````$@```'8"
M``"HE`0(`````!(```!(````N)0$"``````2````3P``````````````(```
M`#P#``"4G@4(`````!``\?\5`@``R)0$"``````2````>P(``-B4!`A#````
M$@```(8"``#HE`0()@```!(```"+`@``<%X%"`0````1``T`E@(``/B4!`@`
M````$@```)P"```(E00(;0```!(```!G````&)4$"!D````2````HP(``"B5
M!`@`````$@```*D"```XE00(`````!(```!P````2)4$"``````2````VP``
M`%B5!`AF````$@```.<```!HE00(`````!(```#O````>)4$"#D````2````
ML`(``(B5!`@`````$@```'X!``"8E00(<@$``!(```#W````!&X%"`0````1
M`!0`MP(``*B5!`@`````$@```(8!``"XE00(<@```!(```"\`@``R)4$"#,`
M```2````"@$``-B5!`@Z````$@```&\```#HE00(^0```!(```!B`@``^)4$
M"``````2````=0````B6!`BG````$@```"\#``"0804(`````!``\?][````
M&)8$"``````2````@@```"B6!`@-`0``$@```,("```XE@0()0```!(````2
M`0``2)8$"``````2````R@(``%B6!`CR````$@```-,"``!HE@0(4@8``!(`
M``#:`@``>)8$".X````2````B0```+0.!0@`````$@`+`!,#``"(E@0(60``
M`!(```#C`@``F)8$"$P!```2````Z@(``*B6!`@V````$@```(\```"XE@0(
M@0```!(```!Q`@``R)8$"``````2````E0```-B6!`B7````$@```"@#``"0
M804(`````!``\?^<````#&`%"``````1`/'_.P,``)2>!0@`````$`#Q_^4"
M``#HE@0(6P```!(```#R`@``^)8$")H````2````^P(```B7!`@`````$@``
M`'8````8EP0(`````!(```"-`0``*)<$"``````2````E`$``#B7!`B)````
M$@````$#``!(EP0(`````!(````(`P``6)<$"&<````2````$0,``&B7!`BY
M````$@```)H!``!XEP0(`````!(````;`P``B)<$"``````2````(@,``)B7
M!`@`````$@```+(``````````````"````"#````J)<$"``````2````R```
M`+B7!`BV````$@````!L:6)Z+G-O+C(`<W1R8W!Y`%]$64Y!34E#`&UA;&QO
M8P!V<VYP<FEN=&8`9F9L=7-H`%]I;FET`&-A;&QO8P!F<')I;G1F`'-T<F-A
M=`!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!?7V5R<F]R`&9R96%D`&9O<&5N
M`&UE;7-E=`!F8VQO<V4`7V9I;FD`9G!U=&,`9G=R:71E`%]'3$]"04Q?3T9&
M4T547U1!0DQ%7P!?7W)E9VES=&5R7V9R86UE7VEN9F\`9G)E90!L:6)C<GEP
M="YS;RXR`%]?7W)U;F5T>7!E`'-T<FYC;7``<W1R;F-P>0!?0W5R<F5N=%)U
M;F5,;V-A;&4`<W1R;F-A=`!S=')C;7``;&EB8W)Y<'1O+G-O+C,`340U`'-T
M<F5R<F]R`%]?<W1D:6YP`&=E=&5N=@!F9V5T<P!?7W-T9&5R<G``9V5T=6ED
M`'-E;&5C=`!?1&5F875L=%)U;F5,;V-A;&4`<W1R<F-H<@!R96%L;&]C`'-S
M8V%N9@!S=')C:'(`9G!U=',`9F-N=&P`;&EB8RYS;RXT`'!U=&-H87(`7U]S
M=&1O=71P`'=A:71P:60`<&]P96X`9V5T9'1A8FQE<VEZ90!G971E=6ED`'!C
M;&]S90!G971G<F=I9`!F8VAM;V0`7U]S<F=E=`!U<VQE97``97AE8W9E`&9C
M:&]W;@!F8VAD:7(`<&5R<F]R`&1U<#(`<WES=&5M`&UK=&5M<`!R;61I<@!R
M96%D9&ER`')E86QP871H`'!I<&4`<F5N86UE`&)A<V5N86UE`')I;F1E>`!E
M;G9I<F]N`&9S=&%T`&MI;&P`:6YI=&=R;W5P<P!W86ET`%]?<')O9VYA;64`
M;'-T870`<W1R<W1R`&9L;V-K`'-E=&=I9`!U;FQI;FL`9F]R:P!E>&5C=@!O
M<&5N9&ER`&=E='!W=6ED`&=E=&-W9`!G971P=VYA;0!A=&5X:70`;6MS=&5M
M<`!G971G<FYA;0!?97AI=`!S971S:60`8VQO<V5D:7(`=F%S<')I;G1F`'-E
M='5I9`!M:V1I<@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`"@804(!0,``*1A
M!0@%"P``J&$%"`49``"P804(!2H```1N!0@%1P``&&`%"`<!```<8`4(!P(`
M`"!@!0@'!```)&`%"`<%```H8`4(!P8``"Q@!0@'!P``,&`%"`<(```T8`4(
M!PD``#A@!0@'"@``/&`%"`<,``!`8`4(!PT``$1@!0@'#P``2&`%"`<0``!,
M8`4(!Q$``%!@!0@'$@``5&`%"`<3``!88`4(!Q0``%Q@!0@'%0``8&`%"`<6
M``!D8`4(!Q<``&A@!0@'&```;&`%"`<:``!P8`4(!QL``'1@!0@''```>&`%
M"`<=``!\8`4(!QX``(!@!0@''P``A&`%"`<@``"(8`4(!R$``(Q@!0@'(@``
MD&`%"`<C``"48`4(!R0``)A@!0@')0``G&`%"`<F``"@8`4(!R<``*1@!0@'
M*0``J&`%"`<K``"L8`4(!RP``+!@!0@'+0``M&`%"`<N``"X8`4(!R\``+Q@
M!0@',```P&`%"`<R``#$8`4(!S,``,A@!0@'-```S&`%"`<U``#08`4(!S@`
M`-1@!0@'.0``V&`%"`<Z``#<8`4(!SP``.!@!0@'/0``Y&`%"`<^``#H8`4(
M!S\``.Q@!0@'0```\&`%"`=!``#T8`4(!T(``/A@!0@'0P``_&`%"`=$````
M804(!T4```1A!0@'1@``"&$%"`=(```,804(!TD``!!A!0@'2@``%&$%"`=+
M```8804(!TP``!QA!0@'30``(&$%"`=.```D804(!U```"AA!0@'40``+&$%
M"`=2```P804(!U,``#1A!0@'5```.&$%"`=5```\804(!U8``$!A!0@'6```
M1&$%"`=9``!(804(!UH``$QA!0@'6P``4&$%"`=<``!4804(!UT``%AA!0@'
M80``7&$%"`=B``!@804(!V,``&1A!0@'9```:&$%"`=E``!L804(!V8``'!A
M!0@'9P``=&$%"`=H``!X804(!VD``'QA!0@':@``@&$%"`=K``"$804(!VP`
M`(AA!0@';@``C&$%"`=O``#HVP8``.BZ?```PP#_-1!@!0C_)11@!0@`````
M_R488`4(:`````#IX/____\E'&`%"&@(````Z=#_____)2!@!0AH$````.G`
M_____R4D8`4(:!@```#IL/____\E*&`%"&@@````Z:#_____)2Q@!0AH*```
M`.F0_____R4P8`4(:#````#I@/____\E-&`%"&@X````Z7#_____)3A@!0AH
M0````.E@_____R4\8`4(:$@```#I4/____\E0&`%"&A0````Z4#_____)41@
M!0AH6````.DP_____R5(8`4(:&````#I(/____\E3&`%"&AH````Z1#_____
M)5!@!0AH<````.D`_____R548`4(:'@```#I\/[___\E6&`%"&B`````Z>#^
M____)5Q@!0AHB````.G0_O___R5@8`4(:)````#IP/[___\E9&`%"&B8````
MZ;#^____)6A@!0AHH````.F@_O___R5L8`4(:*@```#ID/[___\E<&`%"&BP
M````Z8#^____)71@!0AHN````.EP_O___R5X8`4(:,````#I8/[___\E?&`%
M"&C(````Z5#^____)8!@!0AHT````.E`_O___R6$8`4(:-@```#I,/[___\E
MB&`%"&C@````Z2#^____)8Q@!0AHZ````.D0_O___R608`4(:/````#I`/[_
M__\EE&`%"&CX````Z?#]____)9A@!0AH``$``.G@_?___R6<8`4(:`@!``#I
MT/W___\EH&`%"&@0`0``Z<#]____):1@!0AH&`$``.FP_?___R6H8`4(:"`!
M``#IH/W___\EK&`%"&@H`0``Z9#]____);!@!0AH,`$``.F`_?___R6T8`4(
M:#@!``#I</W___\EN&`%"&A``0``Z6#]____);Q@!0AH2`$``.E0_?___R7`
M8`4(:%`!``#I0/W___\EQ&`%"&A8`0``Z3#]____)<A@!0AH8`$``.D@_?__
M_R7,8`4(:&@!``#I$/W___\ET&`%"&AP`0``Z0#]____)=1@!0AH>`$``.GP
M_/___R788`4(:(`!``#IX/S___\EW&`%"&B(`0``Z=#\____)>!@!0AHD`$`
M`.G`_/___R7D8`4(:)@!``#IL/S___\EZ&`%"&B@`0``Z:#\____)>Q@!0AH
MJ`$``.F0_/___R7P8`4(:+`!``#I@/S___\E]&`%"&BX`0``Z7#\____)?A@
M!0AHP`$``.E@_/___R7\8`4(:,@!``#I4/S___\E`&$%"&C0`0``Z4#\____
M)01A!0AHV`$``.DP_/___R4(804(:.`!``#I(/S___\E#&$%"&CH`0``Z1#\
M____)1!A!0AH\`$``.D`_/___R44804(:/@!``#I\/O___\E&&$%"&@``@``
MZ>#[____)1QA!0AH"`(``.G0^____R4@804(:!`"``#IP/O___\E)&$%"&@8
M`@``Z;#[____)2AA!0AH(`(``.F@^____R4L804(:"@"``#ID/O___\E,&$%
M"&@P`@``Z8#[____)31A!0AH.`(``.EP^____R4X804(:$`"``#I8/O___\E
M/&$%"&A(`@``Z5#[____)4!A!0AH4`(``.E`^____R5$804(:%@"``#I,/O_
M__\E2&$%"&A@`@``Z2#[____)4QA!0AH:`(``.D0^____R50804(:'`"``#I
M`/O___\E5&$%"&AX`@``Z?#Z____)5AA!0AH@`(``.G@^O___R5<804(:(@"
M``#IT/K___\E8&$%"&B0`@``Z<#Z____)61A!0AHF`(``.FP^O___R5H804(
M:*`"``#IH/K___\E;&$%"&BH`@``Z9#Z____)7!A!0AHL`(``.F`^O___R5T
M804(:+@"``#I</K___\E>&$%"&C``@``Z6#Z____)7QA!0AHR`(``.E0^O__
M_R6`804(:-`"``#I0/K___\EA&$%"&C8`@``Z3#Z____)8AA!0AHX`(``.D@
M^O___R6,804(:.@"``#I$/K__U6)Y8/L#%=64XG2C74(BU[\C7R>!(D]B)X%
M"(7;?BF#?0@`=".+10BC<%X%"(`X`'06B?:`."]U"8U(`8D-<%X%"$"`.`!U
M[+@P7P4(A<!T#(/$]%+H=O[__X/$$(/$]&BT#@4(Z&;^___HE?G__X/D\(/L
M&(E<)`")="0$B7PD".BJ````B40D`.B1_O__C67H6UY?R<.058GE@^P(@#T(
M;@4(`'0/ZSB-=@"#P`2C>%X%"/_2H7A>!0B+$(72=>NX`````(7`=!"#[`QH
M+%\%".AA9_OW@\00Q@4(;@4(`<G#D%6X`````(GE@^P(A<!T%8/L"&@,;@4(
M:"Q?!0CH,V?[]X/$$*$(8`4(A<!T&[@`````A<!T$H/L#&@(8`4(Z!%G^_>#
MQ!")]LG#B?95B>575E.!["P$``"#Y/"#[!#'A=S[__\`````QX78^___````
M`&;'A=;[__\``(M5#(L"HRA?!0CHGV8``.@=^O__B<.#[`AJ`&B]#@4(Z*0P
M``"#Q!`YPW0?Z`#Z__^%P'06:+T.!0AH)!`%"&H!:@'HC7(``(/$$.CQ^/__
MA<!U&8/L#&H`Z`/^___'!"0`````Z*?[__^#Q!"#?0@"?Q3_=0AH;!`%"&H!
M:@'H47(``(/$$(M-#(M9!(M!"(F%X/O__[[$#@4(B=^Y!0```/SSI@^7P@^2
MP#C"=3B#?0@$?AR^R0X%"(N]X/O__[D*````\Z8/E\(/DL`XPG0K@^P$:-0.
M!0AJ`6H!Z/-Q``"#Q!#K%>A5^/__A<!U#(/L#%/HRQ8``(/$$(NUX/O__[_R
M#@4(N0,```#\\Z8/E\(/DL`XPG4/QX7<^___[0X%".GU`P``B[7@^___O_H.
M!0BY!````/SSI@^7P@^2P#C"=0_'A=S[___U#@4(Z<D#``"+M>#[__^_`P\%
M"+D#````_/.F#Y?"#Y+`.,)U#\>%W/O___X.!0CIG0,``(NUX/O__[\+#P4(
MN08```#\\Z8/E\(/DL`XPG4/QX7<^___!@\%".EQ`P``B[7@^___OQ8/!0BY
M`P```/SSI@^7P@^2P#C"=0_'A=S[__\1#P4(Z44#``"+M>#[__^_(@\%"+D&
M````_/.F#Y?"#Y+`.,)U#\>%W/O__QD/!0CI&0,``(NUX/O__[^2304(N0,`
M``#\\Z8/E\(/DL`XPG4/QX7<^___*`\%".GM`@``B[7@^___OS4/!0BY!@``
M`/SSI@^7P@^2P#C"=0_'A=S[__\P#P4(Z<$"``"+M>#[__^_0`\%"+D&````
M_/.F#Y?"#Y+`.,)U#\>%W/O__SL/!0CIE0(``(NUX/O__[]/#P4(N04```#\
M\Z8/E\(/DL`XPG4/QX7<^___1@\%".EI`@``B[7@^___OU0/!0BY!0```/SS
MI@^7P@^2P#C"=5B#?0@$?E*+50R+<A2_60\%"+D,````\Z8/E\(/DL`XPG4)
M9L>%UOO__P$`@^P$#[^%UOO__U"+30S_<1#_<0SH40,``,<$)`````#H.'(`
M`(/$$.GT`0``B[7@^___OV4/!0BY#````/SSI@^7P@^2P#C"=4"#?0@$=3K'
M!8R>!0@`````@^P,BT4,_W`,Z/$%``"#Q`A0:'$/!0CHC_7__\<$)`````#H
MVW$``(/$$.F7`0``B[7@^___O\D.!0BY"P```/SSI@^7P@^2P#C"=4"#?0@$
M?CJ+50R+0@R)T8M2$(-]"`9U"8M)%(F-V/O__X/L!/^UV/O__U)0Z!0'``")
M!"3H?G$``(/$$.DZ`0``B[7@^___OW4/!0BY"0```/SSI@^7P@^2P#C"=6&#
M?0@$=5N+10R+6`R#[`B-A>C[__]04^BE]O__B<:)!"3HYT0``(/$$(7`=!=3
M:*P0!0AJ`6H!Z)EN``"#Q!#IV0```(/L#%;HQ/7__\<$)`````#H`'$``(/$
M$.F\````B[7@^___OWX/!0BY!0```/SSI@^7P@^2P#C"#X6$````@WT(!75^
MBU4,BW(,OUD/!0BY#````/.F#Y?"#Y+`.,)U"6;'A=;[__\!`(M-#(M9$(/L
M"`^_A=;[__]04^@1!P``B=&)PH/$$"'(@_C_=113:(,/!0AJ`6H!Z/1M``"#
MQ!#K-X/L!%%2:*`/!0CH#/3__\<$)`````#H6'```(/$$.L7_[7@^___:-00
M!0AJ`6H!Z+MM``"#Q!"Z`@```#M5"'T0BTT,BP21B421^$([50A\\(M%"(M5
M#,=$@O@`````Z#?W__^)QH7`=4>#[`AJ`FH!Z,7T___HP//__XG#@\002X/X
M`WX4@^P,4^@,^?__@\00B=A+@_@#?^R#[`3_=1#_=0S_M=S[___H+?3__X/$
M$(/L!&H"C87D^___4%;H.//__X/$$(/X_W4-@^P,:@'HGF\``(/$$(N%Y/O_
M_X/@?W16@_A_=!^%P'0;@^P,4/^UW/O__V@`$04(:@!J`>CK;```@\0@BY7D
M^___B="#X'^#^']U1H/L#(G0P?@(4/^UW/O__V@\$04(:@!J`>B[;```@\0@
MZR2+A>3[___!^`B%P'07_[7<^___:'@1!0AJ`&H!Z)5L``"#Q!"#[`QJ"NAT
M\O__QP0D`````.@`;P``N`````"-9?1;7E_)PU6)Y5=64X/L?(M=#(M%$&:)
M18;'!8R>!0@`````QP60G@4(`````(MU"+^F#P4(N08```#\\Z8/E\(/DL`X
MPG4,QP6,G@4(`0```.MJBW4(OZP/!0BY!0```/SSI@^7P@^2P#C"=0S'!9">
M!0@!````ZT2+=0B_L0\%"+D%````_/.F#Y?"#Y+`.,)U%L<%C)X%"`$```#'
M!9">!0@!````ZQ2#[`1HG!$%"&H!:@'HNVL``(/$$(/L"(U%B%!3Z'?V__^#
MQ!"#^/]U)X/L$.BW]/__@\0$_S#H[?'__X/$$%!HM@\%"&H!:@'H?VL``(/$
M$`^W19`E`/```#T`0```=22#[`@/OT6&4%/H10```(/$$(7`=#&#[`QJ`>C1
M;0``@\00ZR*#[`@/OT6&4%/HV@$``(/$$(7`=`V#[`QJ`>BM;0``@\00N```
M``"-9?1;7E_)PU6)Y5=64X'LB````(M="(M%#&:)1893Z#GU__^)18"#Q!"%
MP'4G@^P0Z`?T__^#Q`3_,.@]\?__@\004&C'#P4(:@%J`>C/:@``@\00@^P,
M4^B/\___@\00Z0L!``"#[`B-=8A6C5\(4^AW]?__@\00@_C_=4B#[`A64^B5
M\___@\00A<!U$`^W19`E`/```#T`H```=">#[!#HEO/__X/$!/\PZ,SP__^#
MQ!!0:+8/!0AJ`6H!Z%YJ``"#Q!`/MT60)0#P```]`$````^%@P```(,]D)X%
M"``/A(H```"#[`QF@WV&`'0/BT7`BU7$#Z3""<'@">L&BT6XBU6\4E#_=:B-
M1PA0:-L/!0CH-/#__X/$%/]UF.@.*@``@\0,4(/L!/]UE.BF*0``@\0(4&CH
M#P4(Z`SP__^#Q`@/MT60)?\!``!0:.\/!0CH]>___X/$$.L4@^P(#[]%AE"-
M1PA0Z%,```"#Q!"#[`S_=8#H<?'__XG'@\00A<`/A=W^__^#[`S_=8#HZ?3_
M_[@`````C67T6UY?R<-5B>6#['"-19A0_W4(Z#KT__^#Q!"#^/\/E,`/ML#)
MPU6)Y5=64X'L@!```(M%#&:)A8;O__^_]0\%"/RY_____[``\J[WT;@!$```
M*<A0_W4(C;7H[___5NB>\O__@\0(C;V([___5U;HWO/__XG#@\00@_C_=6Z#
M[`A75NCZ\?__@\00A<!U-@^WA9#O__\E`/```#T`H```=2.#[`2_]0\%"/R)
MV;``\J[WT4E1:/4/!0A6Z*+R__^#Q!#K)X/L$.C5\?__@\0$_S#H"^___X/$
M$%!HM@\%"&H!:@'HG6@``(/$$(,]C)X%"``/A)(```"#[`QF@[V&[___`'05
MBX7`[___BY7$[___#Z3""<'@">L,BX6X[___BY6\[___4E#_M:CO__^-A>CO
M__]0:-L/!0CH<N[__X/$%/^UF.___^A)*```@\0,4(/L!/^UE.___^C>)P``
M@\0(4&CH#P4(Z$3N__^#Q`@/MX60[___)?\!``!0:.\/!0CH*N[__X/$$+@`
M````C67T6UY?R<-5B>575E.![!`0``"-O>CO__^^!A(%"/RY!P```/.E9J6-
MA0;P__]HX@\``&H`4.C6\?__@\0$BT40A<!U!;@'$`4(4/]U#&@5$`4(:``0
M``"-G>CO__]3Z!WN__^#Q!13Z#3R__^#Q!"#^/]U&(/L!&C`$04(:@%J`.AO
M9P``N/_____K7X/L#%#H"_/__X/$"(V=Z.___U/_=0CH01(``(/$$(7`=!R#
M[`Q3_W4(:.01!0AJ`6H`Z#%G``"X_____^LA@^P(:*0!``"-G>CO__]3Z"+O
M__^)'"3H2N[__[@`````C67T6UY?R<.058GE5U93@>R$````BT4,9HE%AK\`
M$```C46(4/]U".C8[___@\00NO____^Y_____X7`#XA1`0``9H-]A@!T%(M%
MP(M5Q(F%>/___XF5?/___^L2BT6XBU6\B85X____B95\____#[=%D"4`\```
M/0!```!T(XN%>/___XN5?/___V:#?88`=`</I,()P>`)B=&)PNGQ````@^P,
M5^C:[?__B<.#Q!"Z_____[G_____A<`/A-$```#K&XG>@<<`$```@^P(5U/H
MS^___XG#@\00A<!T=8/L"%=3Z(SP__^#Q!"%P'34@^P,_W4(Z-KN__^#Q!"%
MP'D5@^P,4^BZ\?__NO____^Y_____^M\@^P,#[]%AE#H>P````&%>/___Q&5
M?/___XD<).B=[O__@\00A<!Y*H/L#%/H??'__[K_____N?_____K/X/L#%;H
M:/'__[K_____N?_____K*H/L#%/H4_'__X/$$(N%>/___XN5?/___V:#?88`
M=`</I,()P>`)B=&)PHG0B<J-9?1;7E_)PU6)Y5=64X'LB````(M%"&:)18:^
M`````+\`````:#-#!0CH?^___XE%@(/$$+@`````N@````"#?8``#X2_````
MZ94```")\(GZZ;$```"-6`B`>`@N=1*`>P$`='V`>P$N=0:`>P(`='&#[`B-
M18A04^CO[?__@\00A<!X76:#?88`=`@#=<`3?<3K!@-UN!-]O`^W19`E`/``
M`#T`0```=3B#[`Q3Z(KM__^#Q!"%P'@H@^P,#[]%AE#H0/___P'&$=?'!"0&
M(@4(Z&;M__^#Q!"%P`^(:____X/L#/]U@.A0[/__@\00A<`/A5[___^#[`S_
M=8#HRN___XGPB?J-9?1;7E_)PXGV58GE5U93@>P,$```BUT(OA`G``"%VW0P
M#[X3@?K_````=A.#[`Q2Z)#M__^#Q!`E``4``.L.H01N!0B+1)`T)0`%``"%
MP'44@^P$:`DB!0AJ`6H!Z`=D``"#Q!"#[`Q&5NA6[O__@\00A<!U[X'^_/\`
M`'88@^P$:!LB!0AJ`&H`Z-IC``"X`0```.MX:"LB!0AH.B(%"/]U#%93:/@D
M!0AH`!```(V=Z.___U/H.NK__X/$%%/H$>O__XG'@\00A<!U/X/L#&A!(@4(
MZ+DB``")PX/$"&CH`0``_W4,Z!GO__^#Q`Q35O]U#.ALZ___@\0(:.@!``#_
M=0SH;.O__X/$$(GXC67T6UY?R<-5B>575E.![`P0``"+=0B+?0R%]G0P#[X6
M@?K_````=A.#[`Q2Z(7L__^#Q!`E``4``.L.H01N!0B+1)`T)0`%``"%P'44
M@^P$:$DB!0AJ`6H!Z/QB``"#Q!"#[`Q6Z&SM__^#Q!"Z`````(7`#X3%````
M:@%J`59H6R(%".BM$P``@\00A<!T%(/L!&AI(@4(:@!J`.BY8@``@\00@^P,
M5NAO`P``5FB&(@4(:``0``"-G>CO__]3Z"+I__^#Q!13Z/GI__^)-"1HI"(%
M"&BY(@4(:``0``!3Z`'I__^#Q!13Z-CI__^)PX/$$(G"A<!U1H7_=$"`/P!T
M.X/L"/\UF%X%"%?H;3<``(/$$(7`="7HJ2(``(7`=`Z#[`Q7Z%,P``"#Q!#K
M#H/L"&H!5^CP*0``@\00B=J)T(UE]%M>7\G#58GE5U93@>P@(```QX7DW___
M`0```(V]Z.___[ZH*`4(_+D&````\Z6DC84!\/__:.</``!J`%#H\.O__X/L
M"/]U#/]U".@2[/__@\0@N@````"%P`^$;@(``(-]"`!T;(M%"`^^$('Z_P``
M`'83@^P,4NCUZO__@\00)0`%``#K#J$$;@4(BT20-"4`!0``A<!T.8-]#`!T
M,XM%#`^^$('Z_P```'83@^P,4NB\ZO__@\00)0`%``#K#J$$;@4(BT20-"4`
M!0``A<!U%(/L!&C!(@4(:@%J`>@S80``@\00_W4(:-XB!0AH`!```(V=Z-__
M_U/HH^?__X/$"&AO(P4(4^@EY___B87<W___@\00A<!U%/]U"&@P)04(:@%J
M`>CK8```@\00@^P,C9WH[___4^B%Z___B87@W___@\00A<!U((/L#/^UW-__
M_^@ZY___4VA<)04(:@%J`>BO8```@\0@C9WHW___OO_____K38.]Y-___P!T
M)8"]Z-___R-U$H"]Z=___R!T,H"]ZM___PIT*<>%Y-___P````"#[`2)W_RP
M`(GQ\J[WT4E14_^UX-___^C1Z/__@\00@^P$_[7<W___:``0``!3Z$KG__^#
MQ!"%P'68_W4(:/$B!0AH`!```(VUZ-___U;HJN;__XDT).B"Y___@\0$_W4,
M_W4(:*`E!0AH`!```%;HB>;__X/$%%;H8.?__XG#@\0,:,0E!0AH`!```%;H
M:^;__XDT).A#Y___B=^#Q!"%VW4K@^P,C87H[___4/]U#&@/(P4(:``0``!6
MZ#WF__^#Q!16Z!3G__^#Q!#K+X/L#(V%Z.___U#_=0AH#R,%"&@`$```C9WH
MW___4^@,YO__@\044^CCYO__@\00@^P,_[7<W___Z.+E__^#Q`3_M>#?___H
M!.O__XV%Z.___XD$).C6Z/__B?J)T(UE]%M>7\G#58GE5E.#[!"+=0CHVNC_
M_XG"A<`/A;D```#H:^K__X/X_W49@^P,:"0C!0CH.>;__\<$)`,```#H#>K_
M_X/L"&H":#0C!0CH#NK__XG#QP0D`````.B0ZO__QP0D`0```.B$ZO__QP0D
M`@```.AXZO__@\0(:@!3Z`WF__^#Q`AJ`5/H`N;__X/$"&H"4^CWY?__B1PD
MZ$_J__^)-"3HB@,``(/$"&H/:O_H.^?__\<$)!`G``#H7^7__X/$"&H):O_H
M(^?__\<$)`````#H=^G__X/L!&H"C47T4%+H:.3__X/$$(/X_W4K@^P0Z&CG
M__^#Q`3_,.B>Y/__B00D5FCL)04(:@!J`.@P7@``N/_____K?(M%](/@?W1/
M@_A_=!Z%P'0:@^P,4%9H("8%"&H`:@#H!5X``+C_____ZU&+5?2)T(/@?X/X
M?W4_@^P,B=#!^`A05FA@)@4(:@!J`.C970``N/_____K)8M%],'X"(7`=!96
M:*`F!0AJ`&H`Z+E=``"X_____^L%N`````"-9?A;7LG#58GE5E.![`P0``"+
M70B+=0Q3Z,<S``"#Q!"Z_____X7`=4>X/B,%"(7V=06X1",%"&H`4U!H22,%
M".CK2@``B1PDZ"'^__^#Q!"%]G0.@^P,4^C@!P``@\00ZPR#[`Q3Z'('``"#
MQ!")PHG0C67X6U[)PU6)Y5=64X'L?!```(M="(7;=&D/OA.!^O\```!V$X/L
M#%+H:.;__X/$$"4`!0``ZPZA!&X%"(M$D#0E``4``(7`=#F#?0P`=#.+10P/
MOA"!^O\```!V$X/L#%+H+^;__X/$$"4`"```ZPZA!&X%"(M$D#0E``@``(7`
M=12#[`1H5",%"&H!:@'HIEP``(/$$(/L"(U%B%#_=0SH8.?__X/$$(7`#Y3`
M#[;PA?9T'(M%E(F%A.___XM%F(F%@.___XM%D&:)A7[O__^#[`S_=0Q3:,`F
M!0AH`!```(V=B.___U/HV.+__X/$%%/HK^/__XG'@\0,:,0E!0AH`!```%/H
MNN+__XD<).B2X___@\00A?9T+8/L!/^U@.____^UA.____]U#.@$Y/__@\0(
M#[>%?N___U#_=0SH`>3__X/$$(GXC67T6UY?R<-5B>564X'L`!```(M="(MU
M#(7;=&0/OA.!^O\```!V$X/L#%+H&^7__X/$$"4`!0``ZPZA!&X%"(M$D#0E
M``4``(7`=#2%]G0P#[X6@?K_````=A.#[`Q2Z.?D__^#Q!`E``@``.L.H01N
M!0B+1)`T)0`(``"%P'44@^P$:'$C!0AJ`6H!Z%Y;``"#Q!"#[`Q64VCH)@4(
M:``0``"-G?CO__]3Z,SA__^#Q!13Z*/B__^)QH/$#&C$)04(:``0``!3Z*[A
M__^)'"3HAN+__XGPC67X6U[)PU6)Y5.#[!2+70C'1?#_____QT7T_____XU%
M^%"-1?10C47P4%/H=Q@``(/$$(/X_W424VB,(P4(:@%J`>C06@``@\00@^P,
M_W7XZ([C__^#Q!"#^/]U&(/L#/]U^%-HGB,%"&H!:@'HI5H``(/$((%]\/,!
M``!W%/]U\&@,)P4(:@%J`>B(6@``@\00@^P(_W7T4^A5X___@\00@_C_=2>#
M[!#HA>/__X/$!/\PZ+O@__^)!"13:#`G!0AJ`6H!Z$U:``"#Q""#[`S_=?3H
M>^/__X/$$(7`=!3_=?1HO",%"&H!:@'H)UH``(/$$(/L#/]U\.BEY?__@\00
MA<!T%/]U\&C2(P4(:@%J`>@!6@``@\00N`````"+7?S)PU6)Y593@^QPBW4(
MQT7HZ",%",=%[/(C!0C'1?``````C5WH@^P$_S-6:/HC!0CH75D``(/$"(U5
MB%)0Z(#D__^#Q!"%P'4;#[=5D(G0)0#P```]`(```'4)]L)`=`2+`^L8Z*GB
M___'``````"#PP2#.P!UKK@`````C67X6U[)PU6)Y5=64X/L>(M]"%?HW>/_
M_XG#@\00A<!U&H/L#%=HJ#@%"&C_(P4(:@%J`>A!60``@\0@@^P,_W,<Z/_A
M__^#Q!"#^/]U%/]S'&A<)P4(:@%J`>@:60``@\00@^P(C46(4&@7)`4(Z-+C
M__^#Q!"#^/\/A$`!```/MT60)0#P```]`$````^%+`$``(/L"/]S#%?H*`$`
M`(/$$(-]#`!U+X/L#/]S'.C2_O__B44,@\00A<!U&H/L#%=HJ#@%"&A\)P4(
M:@%J`>BE6```@\0@@^P,:!LD!0CH[`$``,<$)"TD!0CHX`$``,<$)#@D!0CH
MU`$``,<$)$0D!0CHR`$``(/$"&A"(P4(:!LD!0CH:^+__XG&@\00A<!T18/L
M"&A/)`4(4.CDX/__@\00A<!X,(/L"/]U#/]S#/]S"%=H;20%"%;HQ>#__X/$
M((7`>!&#[`Q6Z$7B__^#Q!"#^/]U%(/L!&BD)P4(:@%J`>@`6```@\00@^P$
M:@!H&R0%"&@7)`4(:(,D!0AHAB0%"&B))`4(:(DD!0CHL3(``(/$((7`=!2#
M[`1HU"<%"&H!:@'HO5<``(/$$(UE]%M>7\G#58GE5E.#["C'1>BT)`4(QT7L
MG"0%",=%\*HD!0C'1?0`````C47H4(U%Y%#H32P``(/$$(7`=1G_-:AA!0AJ
M,FH!:``H!0CH0N+__^FQ````@^P,:+\D!0CHJP```(/$#&BD`0``:`$&``!H
MOR0%".A9XO__B<.#Q!"#^/]U%(/L!&@T*`4(:@%J`>@B5P``@\00@^P$_W4(
M_W4,:%@H!0CHJ%8``(G&QP0D`````&B^)`4(4&C))`4(_W7D_W7D:@)3:O_H
M6C0``(/$,(/X_W44@^P$:(@H!0AJ`6H!Z,]6``"#Q!"#[`Q6Z'_B__^)'"3H
M9^+__^C2W___QP``````C67X6U[)PU6)Y5.#[!"+70A3Z"7@__^#Q!"#^/]U
M'.BHW___@S@"=!)3:,PD!0AJ`6H!Z'A6``"#Q!"+7?S)PU6)Y8/L".@1X/__
MB<*#^/]T,H7`=1J#[`C_=0S_=0CH&.#__\<$)/_____H+.'__X/L!&H`C47\
M4%+H/=S__XM%_.L9@^P$:-XD!0AJ`6H!Z!M6``"#Q!"X_____\G#58GE@^PP
MQT78M3@%",=%W(8D!0C'1>#M)`4(BT4(B47DQT7H`````(U%V%!HM3@%".AK
M____@\00@_@!&<#WT,G#58GE@^P@QT7HQ3@%",=%[/$D!0B+10B)1?#'1?0`
M````C47H4&C%.`4(Z##___^#Q!"Z`````(7`="&)PL'Z"*A_=1&#^D-T!8/Z
M074'N`````#K!;C_____B<*)T,G#58GE@^P@QT7HTC@%",=%[.\D!0B+10B)
M1?#'1?0`````C47H4&C2.`4(Z-#^__^#Q!"Z`````(7`="&)PL'Z"*A_=1&#
M^D-T!8/Z074'N`````#K!;C_____B<*)T,G#C78`58GE5U93@>PD$```_W4,
M_W4(Z$'?__^#Q!"Z`````(7`#X12`P``@^P(:@'_=0SH!2X``(F%X.___X/$
M$(7`=!"#[`Q0Z"LM``"#Q!"%P'4I_W4,:.`X!0AJ`&H`Z*I4``"#Q`3_M>#O
M___H.2T``+H!````Z?\"``"+10B`."UU%X!X`0!U$:&D804(#[]`#HF%Y.__
M_^L6@^P(:@#_=0CH@M___X/$$(F%Y.___X.]Y.___P!Y/H/L$.AHW?__@\0$
M_S#HGMK__XD$)/]U"&C:.@4(:@!J`.@N5```@\04_[7@[___Z,TL``"Z`0``
M`.F#`@``BT4,@#@M=1&`>`$`=0NAH&$%"`^_>`[K%8/L"&@!!@``_W4,Z`G?
M__^#Q!")QX7_>7F#[!#H^-S__X/$!/\PZ"[:__^)!"3_=0QHVCH%"&H`:@#H
MOE,``(/$%/^UX.___^A=+```@\0$_[7D[___Z$[?__^Z`0```.D%`@``C;7H
M[___@^P$4U97Z`/<__^#Q!"%P'4-Z)?<___'``0```#KX3G8#X55`0``@^P$
M:``0``"-A>CO__]0_[7D[___Z)W<__^)PX/$$(7`?["#^/]U6(/L$.A7W/__
M@\0$_S#HC=G__X/$"%#_=0S_=0AH##D%"&H`:@#H&5,``(/$%/^UX.___^BX
M*P``B3PDZ*_>__^#Q`3_M>3O___HH=[__[H!````Z5@!``"AH&$%"`^_0`XY
M^'1<@^P,5^B!WO__@\00A<!T3(/L$.CBV___@\0$_S#H&-G__XD$)/]U#&CU
M.@4(:@!J`.BH4@``@\04_[7@[___Z$<K``"#Q`3_M>3O___H.-[__[H!````
MZ>\```"AI&$%"`^_0`X[A>3O__\/A*P```"#[`S_M>3O___H"][__X/$$(7`
M#X23````@^P0Z&C;__^#Q`3_,.B>V/__B00D_W4(:/4Z!0AJ`&H`Z"Y2``"#
MQ!3_M>#O___HS2H``+H!````Z8,```"#[!#H*MO__X/$!/\PZ&#8__^#Q`A0
M_W4,_W4(:#0Y!0AJ`&H`Z.Q1``"#Q!3_M>#O___HBRH``(D\).B"W?__@\0$
M_[7D[___Z'3=__^Z`0```.LN@^P,_[7@[___Z&`J``"#Q!"%P'04_W4,:%@Y
M!0AJ`&H`Z)M1``"#Q!"Z`````(G0C67T6UY?R<-5B>575E.!["00``"+11AF
MB87F[___:@#_=0CHA=S__XF%V.___X/$$(/X_W4:@^P,_W4,_W4(:(0Y!0AJ
M`6H!Z$11``"#Q""+?0S\N?____^P`/*N]]&-6?^#[`R#P0=1Z)_8__^)A>#O
M__^#Q!"%P'44@^P$:!([!0AJ`6H!Z`51``"#Q!"#[`13_W4,_[7@[___Z&S:
M__^+A>#O___'!!@N6%A8QT08!%A86`")!"3H?]O__XF%W.___X/$$(/X_W5J
M@^P,_W4,_W4(:*PY!0AJ`6H!Z*Y0``"#Q"#K3K\`````.=]S18/L!(G8*?A0
MC80]Z.___U#_M=SO___H`=G__XG&@\00@_C_=1J#[`S_=0S_=0AHV#D%"&H!
M:@'H9%```(/$("GS.=]RNX/L!&@`$```C87H[___4/^UV.___^B-V?__B<.#
MQ!"%P'6/@_C_=1J#[`S_=0S_=0AH!#H%"&H!:@'H'%```(/$((/L!/]U%/]U
M$/^UW.___^@!U___@\00@_C_=1J#[`S_=0S_=0AH+#H%"&H!:@'HYD\``(/$
M((/L"`^WA>;O__]0_[7<[___Z(G6__^#Q!"#^/]U&H/L#/]U#/]U"&A8.@4(
M:@%J`>BN3P``@\0@@^P,_[7<[___Z$G;__^#Q!"#^/]U&H/L#/]U#/]U"&B$
M.@4(:@%J`>A^3P``@\0@@^P,_[78[___Z!G;__^#Q`C_=0S_M>#O___HB-?_
M_X/$$(/X_W4:@^P,_W4,_W4(:+`Z!0AJ`6H!Z#U/``"#Q""#[`S_M>#O___H
MZ-K__XUE]%M>7\G#58GE@^P(BT4,B47XC47XQT`$`````/]U%/]U$%#_=0CH
M`@```,G#58GE5U93@>R4$```BUT0BW44QX5\[___`````&H!_W4(Z`0H``")
MA7CO__^#Q!"%P'00@^P,4.@J)P``@\00A<!U/H/L$.C.U___@\0$_S#H!-7_
M_XD$)/]U"&@D.P4(:@!J`.B43@``@\04_[5X[___Z",G``"Z`0```.F9"P``
M@^P(C86([___4/]U".@VV?__@\00A<!T1.AZU___@S@"=#"#[!#H;=?__X/$
M!/\PZ*/4__^)!"3_=0AH5#L%"&H`:@#H,TX``+H!````Z48+``#'A7SO__\!
M````@_L!#X18`P``@_L!?PF%VW03Z<0)``"#^P(/A$`&``#IM@D``(7V#X3,
M````@_X!#X6E"0``@^P(:$P\!0C_=0CHY=?__XF%A.___X/$$(7`=3Z#[!#H
MX-;__X/$!/\PZ!;4__^)!"3_=0AH3CP%"&H`:@#HIDT``(/$%/^U>.___^A%
M)@``N@$```#IJPH``(/L"/]U#/^UA.___^BD"@``@\0$_[6$[___Z)O7__^#
MQ!"%P`^$(`D``(/L$.AXUO__@\0$_S#HKM/__XD$)/]U"&CU.@4(:@!J`.@^
M30``@\04_[5X[___Z-TE``"Z`0```.E#"@``_W4(:)\\!0AH`!```(V=Z.__
M_U/HF=/__X/$"&A"(P4(4^@+U___B86`[___@\00A<!U38/L$.@&UO__@\0$
M_S#H/-/__X/$$%!3:$X\!0C_-:AA!0CH9]7__X/$!/\UJ&$%".B9U/__@\0$
M_[5X[___Z%PE``"Z`0```.G""0``@^P(_W4,_[6`[___Z+L)``"#Q`AH;R,%
M"/]U".B0UO__B86$[___@\00C9WH[___A<!U9X/L$.B%U?__@\0$_S#HN]+_
M_XD$)/]U"&A./`4(:@!J`.A+3```@\04_[6`[___Z&G6__^#Q`3_M7CO___H
MW"0``+H!````Z4()``"#[`C_M8#O__]3Z%+7__^#Q!"#^/\/A-((``"#[`3_
MM83O__]H`!```%/H`M/__X/$$(7`=<J#[`S_M83O___H#=;__X/$$(7`=$R#
M[!#H[M3__X/$!/\PZ"32__^)!"3_=0AH]3H%"&H`:@#HM$L``(/$%/^U>.__
M_^A3)```@\0$_[6`[___Z,35__^Z`0```.FK"```@^P,_[6`[___Z*S5__^#
MQ!"%P'0^@^P0Z(W4__^#Q`3_,.C#T?__B00D_W4(:/4Z!0AJ`&H`Z%-+``"#
MQ!3_M7CO___H\B,``+H!````Z5@(``#_=0AHGSP%"&@`$```C9WH[___4^BN
MT?__@\0(_W4(4^A"T___@\00A<`/A,<&``"#[!#H']3__X/$!/\PZ%71__^#
MQ!!04VAJ/`4(_S6H804(Z(#3__^#Q`3_-:AA!0CHLM+__X/$!/^U>.___^AU
M(P``N@$```#IVP<``(.]?.___P!T&(/L#/^U>.___^A4(P``N@$```#IN@<`
M`(/L"&AO(P4(_W4(Z)G4__^)A83O__^#Q!"%P'4^@^P0Z)33__^#Q`3_,.C*
MT/__B00D_W4(:$X\!0AJ`&H`Z%I*``"#Q!3_M7CO___H^2(``+H!````Z5\'
M``#_=0AHGSP%"&@`$```C9WH[___4^BUT/__@\0(:$(C!0A3Z"?4__^)A8#O
M__^#Q!"%P`^%!`$``(/L$.@>T___@\0$_S#H5-#__X/$$%!3:$X\!0C_-:AA
M!0CH?]+__X/$!/\UJ&$%".BQT?__@\0$_[5X[___Z'0B``"#Q`3_M83O___H
MY=/__[H!````Z<P&``"-O>CO___\N?____^P`/*NB<CWT(UX_\>%=.___P``
M``"`O#WG[___"G4#C7C^BUT,@SL`=#F-M>CO__^#[`175O\SZ-/2__^#Q!"%
MP'48BP.`/#@*=`:`/#@`=0K'A73O__\!````@\,$@SL`=<V#O73O__\`=3&#
M[`C_M8#O__^-A>CO__]0Z%[4__^#Q!"#^/]U%/]U"&B(/`4(:@%J`>@)20``
M@\00@^P$_[6$[___:/\/``"-E>CO__]2Z/C/__^#Q!"%P`^%,O___X/L#/^U
MA.___^C_TO__@\00A<!T3(/L$.C@T?__@\0$_S#H%L___XD$)/]U"&CU.@4(
M:@!J`.BF2```@\04_[5X[___Z$4A``"#Q`3_M8#O___HMM+__[H!````Z9T%
M``"#[`S_M8#O___HGM+__X/$$(7`=#Z#[!#H?]'__X/$!/\PZ+7.__^)!"3_
M=0AH]3H%"&H`:@#H14@``(/$%/^U>.___^CD(```N@$```#I2@4``/]U"&B?
M/`4(:``0``"-G>CO__]3Z*#.__^#Q`C_=0A3Z#30__^#Q!"%P`^$N0,``(/L
M$.@1T?__@\0$_S#H1\[__XD$)/]U"&A\.P4(:@!J`.C71P``@\04_[5X[___
MZ'8@``"Z`0```.G<!```@^P(:&\C!0C_=0CHN]'__XF%A.___X/$$(7`=3Z#
M[!#HMM#__X/$!/\PZ.S-__^)!"3_=0AH3CP%"&H`:@#H?$<``(/$%/^U>.__
M_^@;(```N@$```#I@00``/]U"&B?/`4(:``0``"-G>CO__]3Z-?-__^#Q`AH
M0B,%"%/H2='__XF%@.___X/$$(7`#X66`0``@^P0Z$#0__^#Q`3_,.AVS?__
M@\004%-H3CP%"/\UJ&$%".BAS___@\0$_S6H804(Z-/.__^#Q`3_M7CO___H
MEA\``(/$!/^UA.___^@'T?__N@$```#I[@,``(V]Z.____RY_____[``\JZ)
MR/?0C5#_B95P[___QX5L[___`````("\%>?O__\*=0F#Z`*)A7#O__^+70R#
M.P`/A/4```"-A>CO__^)A6CO__^+._RY_____[``\JZ)RO?2C4K_BP.`?`C_
M`'4#C4K^@_X!=&:#_@%_"87V=#'IBP```(/^`@^%@@```(/L"/\S_[5H[___
MZ$#/__^#Q!"%P'1KQX5L[___`0```.M?.XUP[___=U>#[`11_S/_M6CO___H
M=,___X/$$(7`=3_'A6SO__\!````ZS,[C7#O__]W*XN%:.___RG(`X5P[___
M@^P$4?\S4.@_S___@\00A<!U"L>%;.___P$```"#O6SO__\`=1>#[`C_M8#O
M____M6CO___HX=#__X/$$(/#!(,[``^%%____X/L!/^UA.___VC_#P``C87H
M[___4.B(S/__@\00A<`/A:#^__^#[`S_M83O___HC\___X/$$(7`=$R#[!#H
M<,[__X/$!/\PZ*;+__^)!"3_=0AH]3H%"&H`:@#H-D4``(/$%/^U>.___^C5
M'0``@\0$_[6`[___Z$;/__^Z`0```.DM`@``@^P,_[6`[___Z"[/__^#Q!"%
MP'0^@^P0Z`_.__^#Q`3_,.A%R___B00D_W4(:/4Z!0AJ`&H`Z-5$``"#Q!3_
MM7CO___H=!T``+H!````Z=H!``#_=0AHGSP%"&@`$```C9WH[___4^@PR___
M@\0(_W4(4^C$S/__@\00A<!T38/L$.BES?__@\0$_S#HV\K__X/$$%!3:'P[
M!0C_-:AA!0CH!LW__X/$!/\UJ&$%".@XS/__@\0$_[5X[___Z/L<``"Z`0``
M`.EA`0``@[U\[___``^%M````(/L!/^UF.____^UE.____]U".@<S/__@\00
MA<!Y/H/L$.@MS?__@\0$_S#H8\K__XD$)/]U"&B<.P4(:@!J`.CS0P``@\04
M_[5X[___Z)(<``"Z`0```.GX````@^P(#[>%D.___U#_=0CHU,O__X/$$(7`
M>3Z#[!#HU<S__X/$!/\PZ`O*__^)!"3_=0AHS#L%"&H`:@#HFT,``(/$%/^U
M>.___^@Z'```N@$```#IH````(/L#/^U>.___^@B'```@\00N@````"%P`^$
M@@```(/L$.AYS/__@\0$_S#HK\G__XD$)/]U"&C\.P4(:@!J`.@_0P``N@$`
M``#K58/L$.A,S/__@\0$_S#H@LG__XD$)/]U"&@L/`4(:@!J`.@20P``@\04
M_[5X[___Z+$;``"#Q`3_M83O___H(LW__X/$!/^U@.___^@4S?__N@$```")
MT(UE]%M>7\G#58GE5U93@^P,BW4(BUT,@SL`=$J+`XE%\(G'_+G_____L`#R
MKHG*]]*->O]65VH!_W7PZ'W-__^+`X/$$(!\./\*=!)6:@%J`6BP2P4(Z&+-
M__^#Q!"#PP2#.P!UMHUE]%M>7\G#C78`58GE5U93@^P8BW4(BUT,BWT05NC4
MS/__B<*#Q!"%P'465FBH/`4(:@!J`.A`0@``N/_____K)87;=`6+0`B)`X7_
M=`6+0@R)!X-]%`!T"(M"'(M5%(D"N`````"-9?1;7E_)PU6)Y8/L"(M5"(-]
M#`!T$VH`C47\4&H`4NA_____@\00ZQ%J`&H`C47\4%+H;/___X/$$(/X_W4'
MQT7\`````(M%_,G#58GE4XM%"(`X`'0ON[1A!0@/OA"Y`````('Z_P```'<)
M]D23,01T`K$!A<EU![@`````ZPM`@#@`==:X`0```%O)PU6)Y5.#[`2+70CH
MDLK__\<``````(/L#%/H8\S__X/$$(7`=2N#[!#H=,K__X/$!/\PZ*K'__^)
M!"13:.L\!0AJ`&H`Z#Q!``"X`````.L#BT`(BUW\R<-5B>53@^P$BUT(Z#K*
M___'``````"#[`Q3Z*O'__^#Q!")VH7`=2F#[!#H&LK__X/$!/\PZ%#'__^)
M!"13:/P\!0AJ`&H`Z.)```"Z`````(G0BUW\R<-5B>53@^P$BUT(4^C^_O__
M@\0$A<!T'X/L!(U%^%!H#3T%"%/H:<K__X/$!/]U^.AU____ZPF#[`Q3Z!+_
M__^+7?S)PU6)Y5.#[!"+70A3Z/[*__^#Q!"%P'4K@^P0Z(_)__^#Q`3_,.C%
MQO__B00D4VC(/`4(:@!J`.A70```N`````#K`XM`"(M=_,G#58GE4X/L$(M=
M"%/HE,K__X/$$(7`=1I3:!`]!0AH`!```&A`;@4(Z*C&__^#Q!#K'H/L!&C_
M#P``_S!H0&X%".A_R?__Q@4_?@4(`(/$$+A`;@4(BUW\R<-5B>53@^P0BUT(
M4^A[QO__@\00A<!U&E-H$#T%"&@`$```:$!^!0CH3\;__X/$$.L>@^P$:/\/
M``#_,&A`?@4(Z";)___&!3^.!0@`@\00N$!^!0B+7?S)PXGV58GE@^QH@SU\
M7@4(_W0'H7Q>!0CK5X/L"(U%F%!H$ST%".@YRO__@\00A<!T#,<%?%X%"```
M``#K+@^W1:`E`/```#T`@```=12+1<P+1<AU#,<%?%X%"`$```#K"L<%?%X%
M"`````"A?%X%",G#D%6)Y593BW4(BUT<4_]U$/]U#%;H&0```%/_=1C_=116
MZ&\#``"X`````(UE^%M>R<-5B>575E.![(0```"-18A0_W4(Z-?'__^#Q!"#
M^/]U,^CJQ___@S@"=2F#[!#HW<?__X/$!/\PZ!/%__^)!"3_=0AH)ST%"&H!
M:@'HHSX``(/$(`^W19`E`/```#T`H```#X3T`@``/0"```!U2X/L!/]U$/]U
M#/]U".APQO__@\00@_C_#X70`@``@^P0Z'S'__^#Q`3_,.BRQ/__B00D_W4(
M:!P^!0AJ`6H!Z$(^``"#Q"#IH@(``(/L"&H$:#-#!0CH1\G__XE%@(/$$(/X
M_W4G@^P0Z#3'__^#Q`3_,.AJQ/__@\004&A$/@4(:@%J`>C\/0``@\00@^P,
M_W4(Z"K(__^)182#Q!"%P'4I@^P0Z/C&__^#Q`3_,.@NQ/__B00D_W4(:$,]
M!0AJ`6H!Z+X]``"#Q""#[`S_=0CH?,;__X/$$(/X_P^%(P$``(/L$.BXQO__
M@\0$_S#H[L/__XD$)/]U"&A>/04(:@%J`>A^/0``@\0@Z?4```"#[`B-18A0
MC7,(5NABQO__@\00@_C_=37H=<;__X,X`@^$SP```(/L$.ADQO__@\0$_S#H
MFL/__XD$)%9H>#X%"&H!:@'H+#T``(/$(`^W19`E`/```#T`0```=4>#PPB)
MWK\S0P4(N0(```#\\Z8/E\(/DL`XPG1\B=Z_!B(%"+D#````\Z8/E\(/DL`X
MPG1D:@'_=1#_=0Q3Z.3]__^#Q!#K40^W19`E`/```#T`@```=4&#[`3_=1#_
M=0R#PPA3Z*S$__^#Q!"#^/]U)X/L$.B\Q?__@\0$_S#H\L+__XD$)%-H'#X%
M"&H!:@'HA#P``(/$((/L#/]UA.A"Q/__B<.#Q!"%P`^%\_[__X/L#/]U@.AZ
MP___@\00@_C_=!.#[`S_=8#H]\?__X/$$(/X_W4G@^P0Z%?%__^#Q`3_,.B-
MPO__@\004&B@/@4(:@%J`>@?/```@\00@^P,_W6$Z&W'__^#Q!"#^/]U*8/L
M$.@=Q?__@\0$_S#H4\+__XD$)/]U"&A[/04(:@%J`>CC.P``@\0@@WT4`'1"
M@^P$_W40_W4,_W4(Z,7#__^#Q!"#^/]U*8/L$.C5Q/__@\0$_S#H"\+__XD$
M)/]U"&B7/04(:@%J`>B;.P``@\0@C67T6UY?R<-5B>575E.![(0```"-18A0
M_W4(Z'3$__^#Q!"#^/]U,^B'Q/__@S@"=2F#[!#H>L3__X/$!/\PZ+#!__^)
M!"3_=0AH)ST%"&H!:@'H0#L``(/$(`^W19`E`/```#T`H```#X3Q`@``/0"`
M``!U2H/L"`^W10Q0_W4(Z![#__^#Q!"#^/\/A<X"``"#[!#H&L3__X/$!/\P
MZ%#!__^)!"3_=0AHLST%"&H!:@'HX#H``(/$(.F@`@``@^P(:@1H,T,%".CE
MQ?__B46`@\00@_C_=2>#[!#HTL/__X/$!/\PZ`C!__^#Q!!0:$0^!0AJ`6H!
MZ)HZ``"#Q!"#[`S_=0CHR,3__XE%A(/$$(7`=2F#[!#HEL/__X/$!/\PZ,S`
M__^)!"3_=0AH0ST%"&H!:@'H7#H``(/$((/L#/]U".@:P___@\00@_C_#X4B
M`0``@^P0Z%;#__^#Q`3_,.B,P/__B00D_W4(:%X]!0AJ`6H!Z!PZ``"#Q"#I
M]````(/L"(U%B%"-<PA6Z`##__^#Q!"#^/]U->@3P___@S@"#X3.````@^P0
MZ`+#__^#Q`3_,.@XP/__B00D5FAX/@4(:@%J`>C*.0``@\0@#[=%D"4`\```
M/0!```!U1X/#"(G>OS-#!0BY`@```/SSI@^7P@^2P#C"='N)WK\&(@4(N0,`
M``#SI@^7P@^2P#C"=&-J`?]U$/]U#%/HY?W__X/$$.M0#[=%D"4`\```/0"`
M``!U0(/L"`^W10Q0@\,(4^A;P?__@\00@_C_=2>#[!#H6\+__X/$!/\PZ)&_
M__^)!"13:,P^!0AJ`6H!Z",Y``"#Q""#[`S_=83HX<#__XG#@\00A<`/A?3^
M__^#[`S_=8#H&<#__X/$$(/X_W03@^P,_W6`Z);$__^#Q!"#^/]U)X/L$.CV
MP?__@\0$_S#H++___X/$$%!HH#X%"&H!:@'HOC@``(/$$(/L#/]UA.@,Q/__
M@\00@_C_=2F#[!#HO,'__X/$!/\PZ/*^__^)!"3_=0AH>ST%"&H!:@'H@C@`
M`(/$((-]%`!T08/L"`^W11!0_W4(Z'7`__^#Q!"#^/]U*8/L$.AUP?__@\0$
M_S#HJ[[__XD$)/]U"&C1/04(:@%J`>@[.```@\0@C67T6UY?R<-5B>575E.!
M[(0```"-18A0_W4(Z!3!__^#Q!"#^/]U#N@GP?__@S@"#X0!`P``#[=%D"4`
M\```/0"@``!T!ST`@```=5.#[`S_=0CH;,'__X/$$(/X_P^%TP(``.CKP/__
M@S@"#X3%`@``@^P0Z-K`__^#Q`3_,.@0OO__B00D_W4(:/0^!0AJ`6H!Z*`W
M``"#Q"#IEP(``(/L"&H$:#-#!0CHI<+__XE%@(/$$(/X_W4G@^P0Z)+`__^#
MQ`3_,.C(O?__@\004&A$/@4(:@%J`>A:-P``@\00@^P,_W4(Z(C!__^)182#
MQ!"%P'4I@^P0Z%;`__^#Q`3_,.B,O?__B00D_W4(:$,]!0AJ`6H!Z!PW``"#
MQ""#[`S_=0CHVK___X/$$(/X_P^%%`$``(/L$.@6P/__@\0$_S#H3+W__XD$
M)/]U"&A>/04(:@%J`>C<-@``@\0@Z>8```"#[`B-18A0C5X(4^C`O___@\00
M@_C_=37HT[___X,X`@^$P````(/L$.C"O___@\0$_S#H^+S__XD$)%-H>#X%
M"&H!:@'HBC8``(/$(`^W19`E`/```#T`0```=42-7@B)WK\S0P4(N0(```#\
M\Z8/E\(/DL`XPG1MB=Z_!B(%"+D#````\Z8/E\(/DL`XPG15@^P(:@%3Z`C^
M__^#Q!#K18/L#(U>"%/HL[___X/$$(/X_W4QZ#:___^#.`)T)X/L$.@IO___
M@\0$_S#H7[S__XD$)%-H%#\%"&H!:@'H\34``(/$((/L#/]UA.BOO?__B<:#
MQ!"%P`^%`O___X/L#/]U@.CGO/__@\00@_C_=!.#[`S_=8#H9,'__X/$$(/X
M_W4G@^P0Z,2^__^#Q`3_,.CZN___@\004&B@/@4(:@%J`>B,-0``@\00@^P,
M_W6$Z-K`__^#Q!"#^/]U*8/L$.B*OO__@\0$_S#HP+O__XD$)/]U"&A[/04(
M:@%J`>A0-0``@\0@@WT,`'1&@^P,_W4(Z.B\__^#Q!"#^/]U,^A+OO__@S@"
M="F#[!#H/K[__X/$!/\PZ'2[__^)!"3_=0AH[3T%"&H!:@'H!#4``(/$((UE
M]%M>7\G#58GE5U93@>R$````C46(4/]U".C=O?__@\00@_C_=3/H\+W__X,X
M`G4I@^P0Z..]__^#Q`3_,.@9N___B00D_W4(:"<]!0AJ`6H!Z*DT``"#Q"`/
MMT60)0#P```]`*````^$K0(``#T`@```=1;_=0AH0#\%"&H!:@#H>C0``.F0
M`@``@^P(:@1H,T,%".B"O___B46`@\00@_C_=2>#[!#H;[W__X/$!/\PZ*6Z
M__^#Q!!0:$0^!0AJ`6H!Z#<T``"#Q!"#[`S_=0CH9;[__XE%A(/$$(7`=2F#
M[!#H,[W__X/$!/\PZ&FZ__^)!"3_=0AH0ST%"&H!:@'H^3,``(/$((/L#/]U
M".BWO/__@\00@_C_#X59`0``@^P0Z/.\__^#Q`3_,.@INO__B00D_W4(:%X]
M!0AJ`6H!Z+DS``"#Q"#I*P$``(/L"(U%B%"-<PA6Z)V\__^#Q!"#^/]U->BP
MO/__@S@"#X0%`0``@^P0Z)^\__^#Q`3_,.C5N?__B00D5FAX/@4(:@%J`>AG
M,P``@\0@#[=%D"4`\```/0!```!U3X/#"(G>OS-#!0BY`@```/SSI@^7P@^2
MP#C"#X2N````B=Z_!B(%"+D#````\Z8/E\(/DL`XP@^$D@```&H!_W40_W4,
M4^@1_O__@\00ZW\/MT60)0#P```]`(```'5O@WT4`'1IBWT,_+G_____L`#R
MKO?1C4,(@^P$4?]U#%#H/+S__X/$$(7`=4.#[`C_=1#_=0SHY[K__X/$$(/X
M_W4M@^P0Z,>[__^#Q`3_,.C]N/__@\0(4/]U$/]U#&AL/P4(:@%J`>B),@``
M@\0@@^P,_W6$Z$>Z__^)PX/$$(7`#X6]_O__@^P,_W6`Z'^Y__^#Q!"#^/]T
M$X/L#/]U@.C\O?__@\00@_C_=2>#[!#H7+O__X/$!/\PZ)*X__^#Q!!0:*`^
M!0AJ`6H!Z"0R``"#Q!"#[`S_=83H<KW__X/$$(/X_W4I@^P0Z"*[__^#Q`3_
M,.A8N/__B00D_W4(:'L]!0AJ`6H!Z.@Q``"#Q""-9?1;7E_)PU6)Y593@>Q@
M$```BW4(NX1>!0B#/81>!0@`=".#[`B+`_\P5NC8!@``@\00A<!U"H/#!(,[
M`'7DZP6#.P!U$E9HG#\%"&H!:@'HCS$``(/$$(/L"(V%F.___U!6Z$B\__^#
MQ!"%P'06@^P$:.`_!0AJ`6H!Z&0Q``#IA0```(/L#/\U@%X%"(L#_S!H"CX%
M"&@`$```C9WX[___4^C(M___@\044^C/N/__@\00A<!U%(/L!&@40`4(:@%J
M`>@;,0``@\00@^P,C9WX[___4U9H5$`%"&H!:@#H_S```(/$&%-6Z"P$``"#
MQ!"%P'04@^P$:'Q`!0AJ`6H!Z-TP``"#Q!"-9?A;7LG#58GE5U93@^Q\QT6`
MA%X%"(,]A%X%"``/A"@!``"#[`R+58"+`O\PZ..Z__^)182#Q!"%P'4O@^P0
MZ+&Y__^#Q`3_,.CGMO__B00DBU6`BP+_,&A#/04(:@%J`.AS,```Z>````"#
M[`R+58"+`O\PZ"NY__^#Q!#ID0```(/L"(U%B%"-7@A3Z!.[__^#Q!"#^/]U
M%%-HK$`%"&H!:@#H,#```(/$$.ME#[=%D"4`\```/0!```!U58L5@%X%"(G7
M_+``N?_____RKO?128U>"(/L!%%24^ADN?__@\00A<!U*VH`4V@6/@4(:"@/
M!0CHC1P``(/$$(7`=!)3:-!`!0AJ`6H`Z,DO``"#Q!"#[`S_=83HA[?__XG&
M@\00A<`/A5?___^#[`QH&CX%".AMN/__@\00@T6`!(M%@(,X``^%V/[__XUE
M]%M>7\G#B?95B>53@^P,BUT(:`$&``!3Z(NZ__^#Q!"%P'DK@^P0Z'RX__^#
MQ`3_,.BRM?__B00D4V@$004(:@!J`.A$+P``N/_____K#H/L#%#HX+K__[@`
M````BUW\R<-5B>53@^P,BUT(:`$"``!3Z#&Z__^#Q!"%P'DK@^P0Z"*X__^#
MQ`3_,.A8M?__B00D4V@O0@4(:@!J`.CJ+@``N/_____K#H/L#%#HAKK__[@`
M````BUW\R<-5B>575E.#[!2+?0B+=11J+U?H);?__X/$$(G#A<!T(3GX=!W&
M``")\"7_`0``4/]U$/]U#%?HQ?___\8#+X/$$(/L"`^WQE!7Z!ZZ__^#Q!"#
M^/]U,>B1M___@S@1=&6#[!#HA+?__X/$!/\PZ+JT__^)!"17:#!!!0AJ`6H!
MZ$PN``"#Q""#[`3_=1#_=0Q7Z#:V__^#Q!"#^/]U)X/L$.A&M___@\0$_S#H
M?+3__XD$)%=H3$(%"&H!:@#H#BX``(/$((UE]%M>7\G#58GE5E,/MUT4@^P(
M_W4(:+DC!0CHABT``(G&4_]U$/]U#%#H"____X/$%%;HCKG__XUE^%M>R<-5
MB>564XMU"(M=%.C7MO__QP``````@^P(#[?#4%;H1+G__X/$$(7`=#CHN+;_
M_X,X$70N@^P0Z*NV__^#Q`3_,.CAL___B00D5FA0004(:@!J`.AS+0``N/__
M___IF0```(/L!/]U$/]U#%;H5K7__X/$$(7`=#7H:K;__X,X`G0K@^P0Z%VV
M__^#Q`3_,.B3L___B00D5FAP004(:@!J`.@E+0``N/_____K3H/L"`^WPU!6
MZ!VU__^#Q!"%P'0UZ"&V__^#.`)T*X/L$.@4MO__@\0$_S#H2K/__XD$)%9H
MD$$%"&H`:@#HW"P``+C_____ZP6X`````(UE^%M>R<-5B>575E.#['2+=0B+
M?0R-78A35NA\M___@\00A<!U98/L"%-7Z&NW__^#Q!"%P'465VBP004(:@!J
M`.B)+```N/_____K0X/L"%=6Z*2T__^#Q!"%P'0M@^P0Z(6U__^#Q`3_,.B[
MLO__@\0(4%=6:&!"!0AJ`&H`Z$LL``"X_____^L%N`````"-9?1;7E_)PU6)
MY593@^Q@BW4(BUT4Z$"U___'``````"#[`B-19A05NC=MO__@\00A<`/A8``
M``"#[`3_=1#_=0Q6Z/.S__^#Q!"%P'0K@^P0Z`2U__^#Q`3_,.@ZLO__B00D
M5FCP004(:@!J`.C,*P``N/_____K1(/L"`^WPU!6Z,2S__^#Q!"%P'0K@^P0
MZ,6T__^#Q`3_,.C[L?__B00D5F@00@4(:@!J`.B-*P``N/_____K!;@`````
MC67X6U[)PU6)Y5.#[!#_=0CHE[7__XG#@\00A<!T)X/L$.AVM/__@\0$_S#H
MK+'__X/$$%!H?D(%"&H`:@#H/BL``(/$$(G8BUW\R<-5B>564X/L8(MU",<&
M`````(M=#(,[`'0S@^P(C4684/\SZ-FU__^#Q!"%P'4+BP.)!K@!````ZQCH
M$K3__\<``````(/#!(,[`'7-N`````"-9?A;7LG#58GE5U93@>R$,```BUT(
MBWT,C46(4%/HO+/__X/$$(7`=1`/MT60)0#P```]`$```'0*N`````#ISP``
M`(/L"(U%B%!7Z(ZS__^#Q!"%P'40#[=%D"4`\```/0!```!T"K@`````Z:$`
M``"#[`AH`!```(VUB,___U;HR;3__XD<).@AL___@\0(:``0``"-A8CO__]0
MZ*VT__^)/"3H!;/__X/$"&@`$```C9V(W___4^B1M/__B30DZ.FR___\N?__
M__^P`(G?\J[WT8UQ_\>%A,___P````"#[`16C86([___4%/H7;/__X/$((7`
M=12`O#6([___+W4*QX6$S___`0```(N%A,___XUE]%M>7\G#58GEBU4(N```
M``"%TG0%@#H`=06X`0```,G#58GE5U93@>QP,```BUT(C86(W___:``0``!J
M`%#HI[/__X/$#&@`$```:@!H0(X%".B3L___@\0(:``0``"-A8C/__]0Z,^S
M__^#Q!"%P'4;@^P$:)Q"!0AJ`&H`Z$LI``"X`````.EW`0``@^P(C46(4%/H
M`+3__X/$$(7`=!E3:+Q"!0AJ`&H`Z!XI``"X`````.E*`0``@^P$:``0``!3
MC9V([___4^A[LO__#[=%D"4`\```@\00/0!```!T88/L"&HO4^@=L?__@\00
MA<!T'L8``$"#[`1H`!```%"-A8C?__]0Z#VR__^#Q!#K,8/L!&@`$```C9V(
M[___4XV%B-___U#H';+__X/$#&@`$```:#-#!0A3Z`JR__^#Q!"#[`R-A8CO
M__]0Z$BQ__^#Q!"%P'49@^P(:``0``!H0(X%".C/LO__@\00A<!U&(/L!&C<
M0@4(:@!J`.A+*```N`````#K>H"]B-___P!T78/L!+I`C@4(O@````#\N?__
M__^)UXGP\J[WT4F[`!```(G8*<A0:+E"!0A2Z.:Q__^#Q`R_0(X%"/RY____
M_XGP\J[WT4DIRU.-A8C?__]0:$".!0CHO;'__X/$$(/L#(V%B,___U#HF[#_
M_[A`C@4(C67T6UY?R<.)]E6)Y8/L$/]U"&@!0P4(Z#<"``"#Q`Q0_S607@4(
M:`)#!0CH-2<``,G#58GEBU4(N`````"%TG0)@SH`#Y_`#[;`R<-5B>6+50BX
M`0```(72=`F#.@`/E,`/ML#)PU6)Y8/L%/]U".@"````R<-5B>564XM="+X`
M````N/____^%VW1C@SL`?C^#[`S_,^C:LO__@\00A<!Y+H/L$.@[L/__@\0$
M_S#H<:W__XD$)/]S!&@X0P4(:@%J`.@!)P``OO____^#Q""#>P0`=`Z#[`S_
M<P3HI++__X/$$(/L#%/HF++__XGPC67X6U[)PU6)Y8/L"`^_10Q0:@)H`@8`
M`/]U".@>````R<-5B>6#[`@/OT4,4&H&:`(&``#_=0CH`@```,G#58GE5U93
M@^P8BWT(BW44:@CH`:[__XG#@\00N@````"%P`^$K@```,<``````,=`!```
M``!FA?9T#H/L#%?HF/[__X/$$.L1@^P(5VBY(P4(Z.$E``"#Q!")0P2#[`1H
MI`$``/]U#%#H2K'__XD#@\00A<!Y*H/L$.@YK___@\0$_S#H;ZS__XD$)/]S
M!&@70P4(:@!J`.C_)0``B=KK-H/L"/]U$/\SZ!JO__^#Q!")VH7`=""#[`S_
M,^B'L?__@\00Z.^N__^#.",/E,`/ML!(B0.)VHG0C67T6UY?R<.-=@!5B>57
M5E.#[`R+?0B^0)X%"+L`````@^P$#[8$'U!H9T,%"%;H&[#__X/&`H/$$$.#
M^P]^X;A`G@4(C67T6UY?R<-5B>574X'L#!```/]U#/]U"&CZ(P4(:``0``"-
MG?CO__]3Z-NK__^#Q`QJ`(G?_+G_____L`#RKO?125%3Z'"K__^#Q!10Z'/_
M__^-9?A;7\G#58GE5E.Y`````(U%#(U0!(,X`'0+08G0C5($@S@`=?6#[`R-
M!(T$````4.APK/__@\00B<:%P'4G@^P0Z/^M__^#Q`3_,.@UJ___@\004&AL
M0P4(:@%J`>C')```@\00N0````"-10R-4`2+`(D&A<!T#T&)T(U2!(L`B02.
MA<!U\<<$C@````"#[`1J`%;_=0CH$P```(G#B30DZ#^P__^)V(UE^%M>R<-5
MB>564X/L$(MU"/]U#%:-1?10C47P4.@6!0``B<.#Q!"%P'12@WT0`'5,@WWP
M`'04@^P(_W7P_S6H804(Z-2L__^#Q!"#??0`=!J#[`S_=?16:(!#!0AJ`6H`
MZ!HD``"#Q"#K$E9H8$0%"&H!:@#H!B0``(/$$(/L#/]U\.BTK___@\0$_W7T
MZ*FO__^)V(UE^%M>R<-5B>564[D`````C440C5`$@S@`=`M!B="-4@2#.`!U
M]8/L#(T$C00```!0Z#"K__^#Q!")QH7`=2>#[!#HOZS__X/$!/\PZ/6I__^#
MQ!!0:&Q#!0AJ`6H!Z(<C``"#Q!"Y`````(U%$(U0!(L`B0:%P'0/08G0C5($
MBP")!(Z%P'7QQP2.`````(/L!%;_=0S_=0CH<`$``(G#B30DZ/ZN__^)V(UE
M^%M>R<-5B>564[D`````C444C5`$@S@`=`M!B="-4@2#.`!U]8/L#(T$C00`
M``!0Z(6J__^#Q!")QH7`=2>#[!#H%*S__X/$!/\PZ$JI__^#Q!!0:&Q#!0AJ
M`6H!Z-PB``"#Q!"Y`````(U%%(U0!(L`B0:%P'0/08G0C5($BP")!(Z%P'7Q
MQP2.`````%;_=1#_=0S_=0CH60,``(G#B30DZ%.N__^)V(UE^%M>R<-5B>56
M4[D`````C448C5`$@S@`=`M!B="-4@2#.`!U]8/L#(T$C00```!0Z-JI__^#
MQ!")QH7`=2>#[!#H::O__X/$!/\PZ)^H__^#Q!!0:&Q#!0AJ`6H!Z#$B``"#
MQ!"Y`````(U%&(U0!(L`B0:%P'0/08G0C5($BP")!(Z%P'7QQP2.`````(/L
M#%;_=13_=1#_=0S_=0CH408``(G#@\045NBAK?__B=B-9?A;7LG#58GE5U93
M@>Q("```QX70]___`````,>%U/?__P````#'A<3W__\`````QX7`]___````
M`(M%",<``````(V%X/?__U#HKZG__X/$$(/X_W44@^P$:(!$!0AJ`6H!Z'HA
M``"#Q!"+A>#W__^->`&#[`1J!&H$4.C=K/__@\00@_C_=12#[`1HI$0%"&H!
M:@'H2"$``(/$$(/L#/]U$/]U#&H"_[7D]___:@#HC@4``(F%R/?__X/$((.]
MX/?___\/A$@!``"-M>CW__^#[`1H``@``&H`5N@=J___@\00@[W@]____W0<
MBXW@]___B<K!Z@6#X1^X`0```-/@"825Z/?__\>%V/?__P$```"-G=CW___'
M0P0`````Z-FI___'``````"#[`Q3:@!J`%97Z&2H__^#Q""%P'Y.@[W@]___
M``^.N````(N-X/?__XG(P>@%@^$?BX2%Z/?__]/HJ`$/A)D```"-A=3W__]0
MC870]___4/]U"(V%X/?__U#H-Q(``(/$$.MWZ&JI___'``````"#[`1J`8V%
MS/?__U#_M<CW___H/:;__X/$$(7`=$[H0:G__X,X`'45BX7,]___J']U"\'X
M"(F%Q/?__^L*QX7$]________X/L#/^UX/?__^B?J___QX7@]________\>%
MP/?__P$```"#Q!"#O>#W____#X6^_O__@[W`]___`'5<Z-VH___'``````"#
M[`1J`8V%S/?__U#_M<CW___HL*7__X/$$,>%Q/?_______^%P'0IZ*JH__^#
M.`!U%8N%S/?__ZA_=0O!^`B)A<3W___K"L>%Q/?_______^+10B#.`!T#(L0
MBX74]___Q@0"`(N%Q/?__XUE]%M>7\G#58GE5U93@>Q8"```QX7(]___````
M`,>%S/?__P````#'A<#W__\`````QX7$]___`````,>%M/?__P````#'A;#W
M__\`````BT4(QP``````BT4,QP``````C87@]___4.C^IO__@\00@_C_=!>#
M[`R-A=CW__]0Z.>F__^#Q!"#^/]U%(/L!&B`1`4(:@%J`>BR'@``@\00BY7@
M]___BX78]___.=!]`HG0C7@!@^P$:@1J!/^UX/?__^@$JO__@\00@_C_=!J#
M[`1J!&H$_[78]___Z.JI__^#Q!"#^/]U%(/L!&BD1`4(:@%J`>A5'@``@\00
M@^P,_W44_W40_[7<]____[7D]___:@#HEP(``(F%N/?__X/$((.]X/?___]U
M#8.]V/?___\/A-T!``"-M>CW__^#[`1H``@``&H`5N@=J/__@\00@[W@]___
M_W0<BXW@]___B<K!Z@6#X1^X`0```-/@"825Z/?__X.]V/?___]T'(N-V/?_
M_XG*P>H%@^$?N`$```#3X`F$E>CW___'A=#W__\!````C9W0]___QT,$````
M`.BTIO__QP``````@^P,4VH`:@!65^@_I?__@\0@A<`/CI4```"#O>#W__\`
M?CN+C>#W__^)R,'H!8/A'XN$A>CW___3Z*@!=""-A<SW__]0C87(]___4/]U
M"(V%X/?__U#H%@\``(/$$(.]V/?__P`/CM,```"+C=CW__^)R,'H!8/A'XN$
MA>CW___3Z*@!#X2T````C87$]___4(V%P/?__U#_=0R-A=CW__]0Z,H.``"#
MQ!#ICP```.CZI?__QP``````@^P$:@&-A;SW__]0_[6X]___Z,VB__^#Q!"%
MP'1FZ-&E__^#.`!U%8N%O/?__ZA_=0O!^`B)A;3W___K"L>%M/?_______^#
M[`S_M=CW___H+ZC__\>%V/?_______^#Q`3_M>#W___H%ZC__\>%X/?_____
M___'A;#W__\!````@\00@[W@]____P^%-O[__X.]V/?___\/A2G^__^#O;#W
M__\`=5SH2*7__\<``````(/L!&H!C86\]___4/^UN/?__^@;HO__@\00QX6T
M]________X7`="GH%:7__X,X`'45BX6\]___J']U"\'X"(F%M/?__^L*QX6T
M]________XM%"(,X`'0,BQ"+A<SW___&!`(`BT4,@S@`=`R+$(N%Q/?__\8$
M`@"+A;3W__^-9?1;7E_)PU6)Y593BW44Z#ZE__^)PX/X_W44@^P$:-1$!0AJ
M`6H!Z'H;``"#Q!"%VP^%LP```(/L"&H`_W4(Z/`,``"#Q!"#^/]T*H/L"&H!
M_W4,Z-L,``"#Q!"#^/]T%8/L"&H"_W40Z,8,``"#Q!"#^/]U,H/L$.A$I/__
M@\0$_S#H>J'__X/$#%!HF$,%"/\UJ&$%".BFH___QP0D_____^CJI?__Z)4-
M``"#[`C_=1A6Z+FD__^#[!#H`:3__X/$!/\PZ#>A__^#Q!!05FCT1`4(_S6H
M804(Z&*C__^#Q!1J_^BHI?__B=B-9?A;7LG#58GE5U93@>P<$```BUT(BWT,
MH:1A!0@/OT`..=AT#:&@804(#[]`#CGX=1N#[`1H&$4%"&H`:@#H=AH``+C_
M____Z68"``"#[`R-A>#O__]0Z'FB___H!*3__XG&@\00A<`/B!D"``"%P`^$
M(P$``(/L#/^UY.___^CAI?__@\00C9WH[___ZRC&A`7G[___`%-HN2,%"&H`
M:@#H$QH``(/$!/\UJ&$%".CAH?__@\00@^P$:/\/``!3_[7@[___Z#JC__^#
MQ!"%P'^]@^P,_[7@[___Z(6E__^#Q`QJ`HV%W.___U!6Z-.?__^#Q!"#^/]U
M+H/L$.C3HO__@\0$_S#H":#__XD$)%9H4$4%"&H`:@#HFQD``+C_____Z8L!
M``"+A=SO__^#X']T6(/X?W0AA<!T'8/L#%!6:)1%!0AJ`&H`Z&H9``"X____
M_^E:`0``BY7<[___B="#X'^#^']U(H/L#(G0P?@(4%9HR$4%"&H`:@#H.!D`
M`+C_____Z2@!``"+A=SO___!^`CI&@$``(/L#&H`Z,*D___'!"0!````Z+:D
M___'!"0"````Z*JD__^#Q`3_M>#O___HG*3__X/$"&H`4^@QH/__@\0(:@%7
MZ":@__^#Q`AJ`O^UY.___^@6H/__@\0(_W44_W40Z(BB__^)A=SO___HS:'_
M_X/$!/\PZ`.?__^#Q`Q0:/Q%!0C_-:AA!0CH+Z'__^BJH?__@\00@S@.=1G_
M-:AA!0AJ6&H!:"!&!0CH3J/__X/$$.L7_S6H804(:@)J`6BV0P4(Z#6C__^#
MQ!"#[`S_-:AA!0CH)*#__X/$!/^UY.___^CFH___BX7<[___ZRR#[!#H1J'_
M_X/$!/\PZ'R>__^#Q!!0:'Q&!0AJ`6H!Z`X8``"#Q!"X_____XUE]%M>7\G#
M58GE5U93@>PX$```QX7,[___`````(V%X.___U#H^)___^B#H?__B870[___
M@\00A<`/B)0#``"%P`^.#`,``,>%R.___P`0``"#[`S_M>3O___H4J/__[\`
M````QP0D`!```.@1G___BU4(B0*#Q`AJ`_^UX.___^C\HO__@\0,@\@$4&H$
M_[7@[___Z.BB__^-M>CW__^#Q`QH``@``&H`5NARH?__C9WH[___@\0,:``(
M``!J`%/H7*'__XN-X.___XG*P>H%@^$?N`$```#3X`F$E>CW___H.Z#__\<`
M`````,>%V.___P$```"-A=CO___'0`0`````B00D4U-6BX7@[___0%#HJY[_
M_X/$((G>Z3(!``"+E>#O__^)T,'H!8G1@^$?BX2%Z/?__]/HJ`%T;X/L!(N%
MR.___RGX2%")^(M-"`,!4%+H^9___XG#@\00@_C_=0[HNI___X,X!`^%5@$`
M`(7;#X[V`````=^+A<CO__](.?A_38&%R.___P`0``"#[`C_M<CO__^+10C_
M,.C_G___BU4(B0*#Q!#K)H/L!&H!C874[___4/^UT.___^A.G/__@\00.X70
M[___#X3H````@^P$:``(``!J`(V-Z/?__U'H.:#__X/$#&@`"```:@!6Z"F@
M__^+C>#O__^)RL'J!8/A'[@!````T^`)A)7H]___Z`B?___'``````#'A=CO
M__\!````C878[___QT`$`````(D$)%96C87H]___4(N%X.___T!0Z'*=__^#
MQ"#HRI[__X,X``^$P/[__^B\GO__@S@$#X2R_O__BU4(BP+&!#@`@[W,[___
M`'4DQX74[___`````(/L!&H`C874[___4/^UT.___^APF___@\00BX74[___
MN_____^H?W4_B</!^PCK.,>%S.___P$```#KJ(/L$.A3GO__@\0$_S#HB9O_
M_X/$$%!HN4,%"&H!:@#H&Q4``(/$$.E\____A=MT5H'[_P```'48BTT(_S%H
MUD,%"&H!:@#H]!0``(/$$.L=@^P(BT4(_S!3_W4,:)Q&!0AJ`6H`Z-44``"#
MQ""#[`R+50C_,NB!H/__BTT(QP$`````@\00B=CIK````(/L#/^UX.___^A0
MH/__QP0D`0```.A$H/__QP0D`@```.@XH/__@\0(:@&-G>#O____<P3HQ9O_
M_X/$"&H"_W,$Z+B;__^#Q`C_=1#_=0SH*I[__^AUG?__@\0$_S#HJYK__X/$
M#%#_=0QHX$,%".AJFO__QP0D_____^@>G___@^P0Z$:=__^#Q`3_,.A\FO__
M@\004&CS0P4(:@%J`>@.%```@\00N`````"-9?1;7E_)PU6)Y593BUT,N0``
M``"-11"-4`2#.`!T"T&)T(U2!(,X`'7U@^P,C02-"````%#H1YO__XG&@\00
MA<!U)X/L$.C6G/__@\0$_S#H#)K__X/$$%!H!40%"&H!:@'HGA,``(/$$(D>
MN0$```"-11"-4`2+`(7`=`^)!(Y!B="-4@2+`(7`=?''!(X`````@^P$5E/_
M=0CH9_O__XG#B30DZ!>?__^)V(UE^%M>R<-5B>564X'LL`$``(MU"(U-#(FU
M6/[__[H!````@_IC?Q.)R(U)!(L`B8256/[__T*%P'7HQT7H`````.B^G/__
MA<!U;(/L#&H`Z+">___'!"0!````Z*2>___'!"0"````Z)B>__^#Q`AJ`F@T
M(P4(Z/F=__^)PX/$"&H`4.@<FO__@\0(:@%3Z!&:__^#Q`AJ`E/H!IK__X/$
M"(V%6/[__U!6Z':<__^)!"3HCIW__X/L#(V%5/[__U#H?YO__X/$$/:%5/[_
M_W\/E<`/ML"-9?A;7LG#58GE5E.![*@1``"+70AJ+U/HDIW__X/$$(7`=!93
M:,!&!0AJ`&H`Z%`2``"X_____^M]C74,@^P,4_\UD%X%"&@@1`4(:``0``"-
MG?CO__]3Z+*8__^)G5CN__^Z`0```(/$((/Z8W\EB?"-=@2+`(F$E5CN__]"
MA<!UZ(/Z8W\-QX256.[__P````#K"L>%Z.___P````"#[`1J`(V%6.[__U"-
MA?CO__]0Z%+M__^-9?A;7LG#58GE4X'LI`$``(M="(U-#(F=6/[__[H!````
M@_IC?R6)R(U)!(L`B8256/[__T*%P'7H@_IC?PW'A)58_O__`````.L'QT7H
M`````(/L!&H`C858_O__4%/H[>S__XM=_,G#58GE4X'L#!```(M="&HO4^AY
MG/__@\00A<!T%E-HP$8%"&H`:@#H-Q$``+C_____ZRZ#[`Q3_S607@4(:"!$
M!0AH`!```(V=^.___U/HG)?__X/$'&H`_W4,4^B([/__BUW\R<-5B>6#[`QJ
M`/]U#/]U".AP[/__R<-5B>575E.#[!3'1?``````:&\C!0C_=0SHYY;__XG&
M@\00A<!U'O\UJ&$%"&I<:@%H!$<%".B*F___N/_____I^@```,=%[``0``#'
M1>@`````@^P,:`$0``#H!9C__XG'@\00A<!U/O\UJ&$%"&HF:@%H9$<%".A(
MF___N/_____IN````/\UJ&$%"&I):@%HC$<%".@JF___QT7H`````(/$$.MG
MBT7HQ@0'`.LXBT7L.47H=2:+1>@%`!```(E%[(/L"(M%Z`4!$```4%?HL)G_
M_XG'@\00A<!TJ8M%Z(@<.$")1>C_3@2#?@0`>1"#[`Q6Z+N6__^#Q!")P^L(
MBP8/MAA`B0:#^_]UHHM%Z,8$!P"#[`Q6Z$>6__^#Q!"#^/]U"<=%\/_____K
M",'X"'0#B47PBT4(B3B+1?"-9?1;7E_)PU6)Y5.#[`S'1?@`````_W4(C47X
M4.B@_O__B<.#Q!"#^/]U*8/L$.B2F/__@\0$_S#HR)7__X/$$%!HV$<%"&H!
M:@#H6@\``(/$$.LGA<!T(X/L#(M%^(`X`'4%N#!$!0A04V@$2`4(:@%J`.@Q
M#P``@\0@@^P,_W7XZ-^:__^)V(M=_,G#58GE5E.Y`````(U%#(U0!(,X`'0+
M08G0C5($@S@`=?6#[`R-!(T$````4.AHEO__@\00B<:%P'4G@^P0Z/>7__^#
MQ`3_,.@ME?__@\004&AL0P4(:@%J`>B_#@``@\00N0````"-10R-4`2+`(D&
MA<!T#T&)T(U2!(L`B02.A<!U\<<$C@````"#[`1J`%;_=0CH"^K__XG#B30D
MZ#>:__^)V(UE^%M>R<-5B>564XMU"(M=#(GP.=YT.8/^_W4>@^P(:@)H-",%
M".AIF?__B<:#Q!"X_____X/^_W06@^P(4U;H@)7__XG#B30DZ-:9__^)V(UE
M^%M>R<-5B>575E.#[`R+?0R+71"+=12-0_PY\'<QBP,%`!```(D#@^P(4/\W
MZ)"7__^)!X/$$(7`=12#[`1H/$0%"&H!:@'HV@T``(/$$(/L!(L6B=#WT`,#
M4`,74HM%"/\PZ`J7__^#Q!"%P'])@^P,BT4(_S#H5IG__XM%",<`_____^BX
MEO__@\0$_S#H[I/__X/$#%!H,$@%"/\UJ&$%".@:EO__Z)66___'``````"#
MQ!#K`@$&C67T6UY?R<-5B>564^BFD___B<:[`P```#G#?1&#[`Q3Z/*8__^#
MQ!!#.?-\[^A5EO__QP``````C67X6U[)PU6)Y5=64X/L;(M%#(7`=1V#[`QH
M4T0%".B[D___@\00N@````"%P`^$D````(G#A<`/A($```"`.`!T?(/L"&HZ
M4^CAEO__@\00B<:%P'0%*=A&ZQ&)W_RP`+G_____\J[WT8U!__]U"%-0:%A$
M!0CH4PP``(G#@\0(C46(4%/H=)?__X/$$(7`=1:#?1``=`P/MT60@^!)@_A)
M=02)VNL<@^P,4^@^F/__@\00B?.%]G0%@#X`=82Z`````(G0C67T6UY?R<.0
M58GE5E.+=0R#[`Q6Z"4)``")PX/$$(7`=`6`.`!U$E9H5$@%"&H!:@'H-@P`
M`(/$$(M%"(D8C67X6U[)PU6)Y5=64X/L#(,]D%X%"``/A9X(``"#[`QH)$L%
M".C6"```B<.#Q!"%P'0%@#@`=12#[`1HA$@%"&H!:@'HY0L``(/$$(D=D%X%
M"(/L#&@S2P4(Z*$(``")PX/$$(7`=`6`.`!U%(/L!&BH2`4(:@%J`>BP"P``
M@\00B1V87@4(@^P,:$)+!0CH;`@``(G#@\00A<!T!8`X`'44@^P$:,Q(!0AJ
M`6H!Z'L+``"#Q!")'9Q>!0B#[`QH3TL%".@W"```B<.#Q!"%P'0%@#@`=12#
M[`1H\$@%"&H!:@'H1@L``(/$$(D=H%X%"(/L#&A?2P4(Z`((``")PX/$$(7`
M=`6`.`!U%(/L!&@4204(:@%J`>@1"P``@\00B1VD7@4(@^P,:&M+!0CHS0<`
M`(G#@\00A<!T!8`X`'44@^P$:#1)!0AJ`6H!Z-P*``"#Q!")':A>!0B#[`QH
M>$L%".B8!P``B<.#Q!"%P'0%@#@`=12#[`1H6$D%"&H!:@'HIPH``(/$$(D=
MK%X%"(/L#&B*2P4(Z&,'``")PX/$$(7`=`6`.`!U%(/L!&B42P4(:@%J`>AR
M"@``@\00B1VP7@4(@^P,:+)+!0CH+@<``(G#@\00A<!T!8`X`'44@^P$:(!)
M!0AJ`6H!Z#T*``"#Q!")';1>!0B#[`AHP$L%"&BX7@4(Z+[]___'!"3+2P4(
MZ.@&``")PX/$$(7`=`6`.`!U%(/L!&BD204(:@%J`>CW"0``@\00B1V\7@4(
M@^P,:-Q+!0CHLP8``(G#@\00A<!T!8`X`'44@^P$:.5+!0AJ`6H!Z,()``"#
MQ!")'<1>!0B#[`QH`DP%".A^!@``B<.#Q!"%P'0%@#@`=12#[`1H#$P%"&H!
M:@'HC0D``(/$$(D=R%X%"(/L#&@J3`4(Z$D&``")PX/$$(7`=`6`.`!U%(/L
M!&C,204(:@%J`>A8"0``@\00B1W,7@4(@^P,:#9,!0CH%`8``(G#@\00A<!T
M!8`X`'44@^P$:.Q)!0AJ`6H!Z",)``"#Q!")'=!>!0B#[`QH0DP%".C?!0``
MB<.#Q!"%P'0%@#@`=12#[`1H#$H%"&H!:@'H[@@``(/$$(D=U%X%"(/L#&A.
M3`4(Z*H%``")PX/$$(7`=`6`.`!U%(/L!&@L2@4(:@%J`>BY"```@\00B1W8
M7@4(@^P,:%M,!0CH=04``(G#@\00A<!T!8`X`'44@^P$:%!*!0AJ`6H!Z(0(
M``"#Q!")'=Q>!0B#[`QH:DP%".A`!0``B<.#Q!"%P'0%@#@`=12#[`1H=$H%
M"&H!:@'H3P@``(/$$(D=X%X%"(/L#&AX3`4(Z`L%``")PX/$$(7`=`6`.`!U
M%(/L!&B82@4(:@%J`>@:"```@\00B1WD7@4(@^P,:(5,!0CHU@0``(G#@\00
MA<!T!8`X`'44@^P$:(Q,!0AJ`6H!Z.4'``"#Q!")'<!>!0B#[`QHITP%".BA
M!```B<.#Q!"%P'0%@#@`=12#[`1HO$H%"&H!:@'HL`<``(/$$(D=Z%X%"(/L
M#&BU3`4(Z&P$``")PX/$$(7`=`6`.`!U%(/L!&C@2@4(:@%J`>A[!P``@\00
MB1WL7@4(@^P,:,),!0CH-P0``(G#@\00A<!T!8`X`'44@^P$:`1+!0AJ`6H!
MZ$8'``"#Q!")'?!>!0B#[`QHSDP%".C(`P``H_1>!0B#Q`AH`!```&H!Z'B/
M__^)1?"C^%X%"(/$#(L5D%X%"+[_____B=>S`/R)\8C8\J[WT4E14O]U\.AJ
MD/__@\0(:.),!0C_-?A>!0CHEX___X/$"&@`$```:@'H*(___XE%\*/\7@4(
M@\0,BQ607@4(B=?\B?&(V/*N]]%)45+_=?#H(9#__X/$"&CW3`4(_S7\7@4(
MZ$Z/__^#Q`AH`!```&H!Z-^.__^)1?"C`%\%"(/$#(L5D%X%"(G7_(GQB-CR
MKO?125%2_W7PZ-B/__^#Q`AH"4T%"/\U`%\%".@%C___@\0(:``0``!J`>B6
MCO__B47PHP1?!0B#Q`R+%9!>!0B)U_R)\8C8\J[WT4E14O]U\.B/C___@\0(
M:!Q-!0C_-01?!0CHO([__X/$"&@`$```:@'H38[__XE%\*,(7P4(@\0,BQ60
M7@4(B=?\B?&(V/*N]]%)45+_=?#H1H___X/$"&@O304(_S4(7P4(Z'..__^#
MQ`AH`!```&H!Z`2.__^)1?"C#%\%"(/$#(L5D%X%"(G7_(GQB-CRKO?125%2
M_W7PZ/V.__^#Q`AH14T%"/\U#%\%".@JCO__@\0(:``0``!J`>B[C?__B47P
MHQ!?!0B#Q`R+%9!>!0B)U_R)\8C8\J[WT4E14O]U\.BTCO__@\0(:%I-!0C_
M-1!?!0CHX8W__X/$"&@`$```:@'H<HW__XE%\*,47P4(@\0,BQ607@4(B=?\
MB?&(V/*N]]%)45+_=?#H:X[__X/$"&AN304(_S447P4(Z)B-__^#Q`AH`!``
M`&H!Z"F-__^)1?"C&%\%"(/$#(L5D%X%"(G7_(GQB-CRKO?125%2_W7PZ"*.
M__^#Q`AH@TT%"/\U&%\%".A/C?__@\0(:``0``!J`>C@C/__B47PHQQ?!0B#
MQ`R+%9!>!0B)U_R)\8C8\J[WT4E14O]U\.C9C?__@\0(:)5-!0C_-1Q?!0CH
M!HW__X/$"&@`$```:@'HEXS__XE%\*,@7P4(@\0,BQ607@4(B=?\B?&(V/*N
M]]%)45+_=?#HD(W__X/$"&BJ304(_S4@7P4(Z+V,__^#Q`AH`!```&H!Z$Z,
M__^C)%\%"(/$#&@`$```_S607@4(4.A5C?__@\0,BQ4D7P4(B=?\B?&(V/*N
M]]&X`!```"G(4&B_304(4NB.C?__BSV07@4(_(GQB-CRKO?1@\$1B0PDZ!2+
M__^)PX/$"/\UD%X%"%#H@XG__X/$"&C4304(4^@UC/__B1V47@4(C67T6UY?
MR<.-=@!5B>564XMU"(/L#%;H*0```(G#@\00A<!T!8`X`'425FCF304(:@%J
M`>@Z`P``@\00B=B-9?A;7LG#58GE5U93@>R,````BWT(_+G_____L`#RKO?1
M28E-A(,]@)X%"``/A5(!``"#[`AH;R,%"&C\304(Z/R,__^)18"#Q!"X````
M`(-]@``/A&\"``"#[`B-18A0BU6`#[]"#E#H4XO__X/$$(7`=1N#[`R+1;B#
MP`)0Z"V*__^C@)X%"(/$$(7`=16#[`S_=8#HQHS__[@`````Z20"``#_=8!J
M`?]UN/\U@)X%".AIC/__@\00@_@!="V#[`S_-8">!0CH(X[__\<%@)X%"```
M``"#Q`3_=8#H?HS__[@`````Z=P!``"+5;B)%82>!0BA@)X%",8$`@#'A73_
M__\`````O@`````[-82>!0AS8:&`G@4(BY5T____@#P0"G4\B=,!P[\`0```
MZP3&`P!+#[X3@?K_````=A.#[`Q2Z$>+__^#Q!`E`$```.L+H01N!0B+1)`T
M(?B%P'7/_X5T____B[5T____.S6$G@4(<I^#[`S_=8#HWXO__X/$$,>%=/__
M_P````"X`````#L%A)X%"`^#)`$``(N==/___P,=@)X%".L!0P^V$X'Z_P``
M`'83@^P,4NC.BO__@\00)0!```#K#J$$;@4(BT20-"4`0```A<!USXM]"(M-
MA/PYR8G>\Z8/E\(/DL`XPG5VBT6$#[84`X'Z_P```'83@^P,4NB#BO__@\00
M)0!```#K#J$$;@4(BT20-"4`0```A<!T0@-=A.L!0X`[`'1_@#L*='H/MA.!
M^O\```!V$X/L#%+H0XK__X/$$"4`0```ZPZA!&X%"(M$D#0E`$```(7`=<7K
M2(N5=/___SL5A)X%"'-*BPV`G@4(BQ6$G@4(BX5T_____X5T____@#P(`'0(
M.95T____<N:+M73___\[-82>!0@/@N[^___K$(G8BY5T____.Q6$G@4(<@6X
M`````(UE]%M>7\G#58GE@^P0C44,4/]U".@"````R<-5B>6#[`S'1?P`````
M_W4,_W4(C47\4.B@B___@\00@_C_=2>#[!#H0(G__X/$!/\PZ':&__^#Q!!0
M:`Y.!0AJ`6H!Z`@```"#Q!"+1?S)PU6)Y5=64X/L'(M%"(E%\(M5#(E5[.@"
MB?__BP")1>B_`!```(/L#&@`$```Z$N'__^)PX/$$(7`=1B#[`3_=>S_=?!H
M+$X%".@=`0``Z1`!``"-1110_W405U/H+(?__XG&@\00.?A\+8/L"(U0`8E5
MY%)3Z".)__^#Q!"%P'06BWWDB<.-1110_W405U/H^8;__X/$$.B!B/__BU7H
MB1#H=XC__X,X``^$D@```,=%X``````I]W0]@^P0Z%N(__^#Q`3_,.B1A?__
MB00DZ$F(____,&A43@4(5XT$,U#HJ(7__X/$(#GX#YW`#[;`B47@A<!T2H/L
M"(M5X(U$,@%04^B5B/__@\00A<!T,HG#@^P0Z`2(__^#Q`3_,.@ZA?__B00D
MZ/*'____,&A43@4(_W7@C00S4.A/A?__@\0@@^P$_W7L_W7P4^@;````@\00
MA=MT#(/L#%/H78K__X/$$(UE]%M>7\G#58GE5U93@^P,BW4(NP````"#/2A?
M!0@`=!.#[`S_-2A?!0CHNH;__XG#@\00A=MT%X/L!%-H:4X%"/\UJ&$%".CM
MAO__@\00@^P(_S6H804(5NA[B?__B??\N?____^P`/*N]]&#Q!"`?#'^"G03
M@^P(_S6H804(:@KHTXC__X/$$(/L#/\UJ&$%".CBA?__@\00A=MT%X/L!%-H
M:4X%"/\UH&$%".B'AO__@\00@^P(_S6@804(5N@5B?__B??\N?____^P`/*N
M]]&#Q!"`?#'^"G03@^P(_S6@804(:@KH;8C__X/$$(/L#/\UH&$%".A\A?__
M@\00@WT,`'0.@^P,_W4,Z!````"#Q!"X`````(UE]%M>7\G#58GE@^P4_W4(
MZ%J(__^)]E6)Y5-2N_A?!0BA^%\%".L*C78`@^L$_]"+`X/X_W7T6%O)P^BG
MB?__PP```'!S86%D;0!R;V]T`&-P,G1E;7!N86T`3F]T(&%L;&]W960@=7-E
M<B`G<F]O="<*`"]B:6XO;',`+V)I;B]C870`+V)I;B]C<``O8FEN+V-H;6]D
M`"]B:6XO;78`+W5S<B]B:6XO=&]U8V@`+V)I;B]R;0`O8FEN+VUK9&ER`"]B
M:6XO<FUD:7(`+W5S<B]B:6XO9FEL90!L:7-T`"TM:6XM8FQO8VMS`&9I;&5?
M97AI<W1S`"5I"@!R96%L<&%T:`!S:7IE`%5N86)L92!T;R!G970@<VEZ92!F
M;W(@)R5S)PH`)6QL9`H`9FEL97,`9&ER<P!B;W1H`'-T870@9F%I;&5D.B`E
M<PH`;W!E;F1I<B!F86EL960Z("5S"@`E<PDE;'4))6QL=0D`)7,))7,)`"4P
M,V\*`"`H8G)O:V5N('-Y;6QI;FLI`'!S82UT96UP+69I;&4`)7,O)7,M6%A8
M6%A8````075T:&5N=&EC871I;VX@9F%I;&5D+"!Y;W4@87)E(&YO="`E<R!O
M<B!R;V]T("T@8V%N;F]T('-T87)T('!R;V=R86UM+@H`4WES=&5M($5R<F]R
M.B!I;G9A;&ED(&%R9W5M96YT(&YU;6)E<B`E9"P@;75S="!B92`S(&]R(&UO
M<F4*`````%5N86)L92!T;R!R96-I979E(')E86P@<&%T:"!F;W(@)R5S)PH`
M``!7<F]N9R!C;VUM86YD(&YA;64@;W(@<&%R86UE=&5R(&YU;6)E<CH@)7,*
M`%5N86)L92!T;R!E>&5C=71E("5S(&-O;6UA;F0Z(&1A96UO;B!K:6QL960@
M8GD@<VEG;F%L("5I"@```%5N86)L92!T;R!E>&5C=71E("5S(&-O;6UA;F0Z
M(&1A96UO;B!S=&]P<&5D(&)Y('-I9VYA;"`E:0H``$5R<F]R(&]C8W5R960@
M9'5R:6YG("5S(&-O;6UA;F0N"@```%=R;VYG(&-O;6UA;F0@;W!T:6]N('1O
M(&QI<W0@9FEL97,*`$5R<F]R(&1U<FEN9R!T96UP;W)A<GD@;F%M92!C<F5A
M=&4*`%5N86)L92!T;R!C;W!Y('1H92!F:6QE("5S('1O("5S"@`O=&UP+W!S
M82UA=71O<F5S<&]N9&5R+5A86%A86```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+BX`17)R
M;W(Z(&5M<'1Y(%5S97(`34%854E$(')E86-H960*`"]U<W(O8FEN+V9A;'-E
M`'!S86-L;@!P<V%S97)V`$5R<F]R.B!E;7!T>2!U<V5R`"]E=&,O9G1P=7-E
M<G,`56YA8FQE('1O(&5N86)L92!F='`@86-C97-S"@!E8VAO("=Y97,G?&-R
M;VYT86(@+7(@+74@)R5S)P`O=7-R+W-B:6XO<'<@=7-E<F1E;``E<R`G)7,G
M`$5R<F]R.B!E;7!T>2!5<V5R(&]R($YE=U5S97(`8W)O;G1A8B`M;"`M=2`G
M)7,G`&5C:&\@)WDG('P@8W)O;G1A8B`M<B`M=2`G)7,G`&-R;VYT86(@+74@
M)R5S)R`G)7,G`'-E='-I9"@I(&9A:6QE9``O9&5V+VYU;&P`86QL;W<`9&5N
M>0!C<F]N=&%B;6YG`$5R<F]R.B!E;7!T>2!5<V5R(&]R($AO;65$:7(`17)R
M;W(Z(&5M<'1Y(%5S97(@;W(@4VAE;&P`57-E<B`E<R!N;W0@9F]U;F0`0V%N
M;F]T(&-H9&ER('1O("5S(&AO;65D:7(@)7,`1F%I;&5D('1O('-E=&=I9#H@
M)60*`$9A:6QE9"!T;R!S971U:60Z("5D"@`O8FEN+V)A<V@`+V)I;B]S:``E
M<R5S`"5S*"DZ('5S97(@)7,@;F]T(&9O=6YD`&5T8P!E=&,O;6%S=&5R+G!A
M<W-W9`!E=&,O<'=D+F1B`&5T8R]S<'=D+F1B`&5T8R]P87-S=V0`<F]O=#HJ
M.C`Z,#HZ.CHF.B\Z+V)I;B]F86QS90H`)7,Z*CHE9#HE9#HZ.CHF.B\Z)7,*
M`"UD`"UP`"]U<W(O<V)I;B]P=V1?;6MD8@`O=7-R+V)I;B]G<F5P`"]U<W(O
M;&]C86PO8FEN+V=R97``+V5T8R]G<F]U<``M10!U;FQI;FLH)7,I(&9A:6QE
M9`!5;F%B;&4@=&\@9F]R:P`A`'5N;&]C:P```"]U<W(O<V)I;B]P=R!U<V5R
M861D("<E<R<@+74@)74@+60@)R5S)R`M9R`G)7,G("US("<E<R<`15)23U(Z
M(%5N86)L92!T;R!O<&5N(&-R;VYT86(@;V8@=7-E<B`G)7,G"@!%4E)/4CH@
M56YA8FQE('1O(&-R96%T92!T96UP(&9I;&4@)R5S)R!N86UE('1O('-T;W)E
M('5S97(@8W)O;G1A8@H``"]U<W(O<V)I;B]P=R!U<V5R;6]D("<E<R<@+6P@
M)R5S)P```"]U<W(O<V)I;B]P=V1?;6MD8B`O971C+VUA<W1E<BYP87-S=V0`
M``!%<G)O<B!O8V-U<F5D(&1U<FEN9R!C;&]S92!U<V5R("<E<R<@<V5S<VEO
M;CH@)7,*````56YA8FQE('1O(&-L;W-E('5S97(@)R5S)R!S97-S:6]N.B!D
M865M;VX@:VEL;&5D(&)Y('-I9VYA;"`E:0H``%5N86)L92!T;R!C;&]S92!U
M<V5R("<E<R<@<V5S<VEO;CH@9&%E;6]N('-T;W!P960@8GD@<VEG;F%L("5I
M"@!#;&]S92!U<V5R("<E<R<@<V5S<VEO;B!F86EL960*`"]U<W(O<V)I;B]P
M=R!U<V5R;6]D("<E<R<@+6T@+60@)R5S)P`````O=7-R+W-B:6XO<'<@=7-E
M<FUO9"`G)7,G("US("<E<R<```!#86YN;W0@<G5N(&%S(&9O<F)I9&1E;B!U
M:60Z("5D"@````!5;F%B;&4@=&\@:6YI="!N97<@9W)O=7!S(&9O<B!U<V5R
M("5S.B`E<P```'-E='5P7V-H<F]O=#H@8VAD:7(H)7,I(&9A:6QE9```)7,H
M*3H@3F\@8VAR;V]T960@<VAE;&P@9F]R("5S(&9O=6YD`````'-E='5P7V-H
M<F]O=#H@=W)I=&4@=&\@>W)O;W1]+V5T8R]P87-S=V0@9F%I;&5D`'-E='5P
M7V-H<F]O=#H@<&%S<W=D(&1A=&%B87-E('5P9&%T92!F86EL960`;6M?9W)O
M=7`Z(&=R97`@;F]T(&9O=6YD+"!N;W0@=W)I=&EN9R!G<F]U<',@9FEL90H`
M`&UK7V=R;W5P.B!O<&5N*"]E=&,O9W)O=7`I(&9A:6QE9````%YP<V%S97)V
M.GQ>6UXZ72HZ6UXZ72HZ*#!\)60I.GQ;+#I=)7,H+%M>.ETJ?"DD`&UK7V=R
M;W5P.B!G<F5P(&5X96-U=&EO;B!F86EL960`+W1M<"]C<F]N=&%B+71M<"U8
M6%A86%A8````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'-E='5P7V-H<F]O=``O=7-R
M+V)I;B]C:'!A<W,`+W5S<B]S8FEN+W!W`"]U<W(O<V)I;B]P=P``17)R;W(@
M;V-C=7)R960@=VAI;&4@;&]C:VEN9R!T:&4@9FEL92`E<PH```!%<G)O<B!W
M:&EL92!C;W!Y:6YG(&9I;&4@)7,@=&\@)7,Z("5S````56YA8FQE('1O(&-O
M<'D@9FEL92`E<R!T;R`E<SH@)7,*````17)R;W(@;V-C=7)R960@=VAI;&4@
M=6YL;V-K:6YG('1H92!F:6QE("5S"@!C;W!Y7V9I;&5?871O;6EC*"5S("T^
M("5S*3H@;W!E;B!F86EL960`8V]P>5]F:6QE7V%T;VUI8R@E<R`M/B`E<RDZ
M(&UK<W1E;7`@9F%I;&5D``!C;W!Y7V9I;&5?871O;6EC*"5S("T^("5S*3H@
M=W)I=&4@9F%I;&5D`````&-O<'E?9FEL95]A=&]M:6,H)7,@+3X@)7,I.B!R
M96%D(&9A:6QE9`!C;W!Y7V9I;&5?871O;6EC*"5S("T^("5S*3H@8VAO=VX@
M9F%I;&5D`````&-O<'E?9FEL95]A=&]M:6,H)7,@+3X@)7,I.B!C:&UO9"!F
M86EL960`````8V]P>5]F:6QE7V%T;VUI8R@E<R`M/B`E<RDZ(&9L=7-H(&9A
M:6QE9`````!C;W!Y7V9I;&5?871O;6EC*"5S("T^("5S*3H@<F5N86UE(&9A
M:6QE9`!5;F%B;&4@=&\@;W!E;B!F:6QE("5S.B`E<P!5;F%B;&4@=&\@8VQO
M<V4@9FEL92`E<SH@)7,*`$%L;&]C871I;VX@9F%I;&5D`$5R<F]R(&]C8W5R
M<F5D('=H:6QE(&QO8VMI;F<@=&AE(&9I;&4@)7,Z("5S"@```&9I;&5?<W1R
M.B!5;F%B;&4@=&\@<W1A="!F:6QE("5S.B`E<PH```!%<G)O<B!W:&EL92!R
M96YA;64@9FEL92`E<SH@)7,*`&9I;&5?<W1R.B!%4E)/4CH@56YA8FQE('1O
M(&-H;W=N(&9I;&4@)7,Z("5S`````&9I;&5?<W1R.B!%4E)/4CH@56YA8FQE
M('1O(&-H;6]D(&9I;&4@)7,Z("5S`````$5R<F]R(&]C8W5R<F5D('=H:6QE
M('5N;&]C:VEN9R!T:&4@9FEL92`E<SH@)7,*`%5N86)L92!T;R!F<'5T<R!T
M;R!F:6QE("5S.B`E<PH`80!5;F%B;&4@=&\@;W!E;B!F:6QE("5S.B`E<PH`
M56YA8FQE('1O(')E;F%M92!F:6QE("5S.B`E<PH`8V%N;F]T('=R:71E(&$@
M;&EN92!T;R`E<RYT;7````!5;F%B;&4@=&\@9V5T<'=N86T@9F]R('5S97(@
M)7,``%5N86)L92!T;R!F:6YD('5I9"!F;W(@=7-E<B`E<SH@)7,`9V5T9W)N
M86TH)7,I.B`E<P!G971G<F=I9"@E9"DZ("5S`"5D`"5U`"]D978O:&1V,0!?
M7V1E;&5T960`56YA8FQE('1O(&=E="!E;G1R>2`E<SH@)7,*`%5N86)L92!T
M;R!O<&5N(&1I<B`E<SH@)7,*`%5N86)L92!T;R!C:&%N9V4@9&ER("5S.B`E
M<PH`56YA8FQE('1O(&-L;W-E(&1I<B`E<SH@)7,*`%5N86)L92!T;R!C:&]W
M;B!D:7(@)7,Z("5S"@!5;F%B;&4@=&\@8VAM;V0@96YT<GD@)7,Z("5S"@!5
M;F%B;&4@=&\@8VAM;V0@9&ER("5S.B`E<PH`56YA8FQE('1O(')E;6]V92!D
M:7(@)7,Z("5S"@`E<R\E<UA86%A86``M<F8`+0!5;F%B;&4@=&\@8VAO=VX@
M9&ER96-T;W)Y(&5N=')Y("5S.B`E<PH`56YA8FQE('1O(&=E="!F:6QE(&1E
M<V-R:7!T;W(@;V8@8W5R<F5N="!D:7(Z("5S"@```%5N86)L92!T;R!C:&5C
M:R!D:7)E8W1O<GD@96YT<GD@)7,Z("5S"@!5;F%B;&4@=&\@<F5S=&]R92`F
M(&-L;W-E(&-U<G)E;G0@9&ER.B`E<PH``%5N86)L92!T;R!C:&UO9"!D:7)E
M8W1O<GD@96YT<GD@)7,Z("5S"@!5;F%B;&4@=&\@=6YL:6YK(&5N=')Y("5S
M.B`E<PH``%5N86)L92!T;R!U;FQI;FL@9&ER96-T;W)Y(&5N=')Y("5S.B`E
M<PH`````270G<R!A(')E9W5L870@96YT<GDH;F]T(&1I<F5C=&]R>2DZ("5S
M"@````!5;F%B;&4@=&\@<F5N86UE(&1I<F5C=&]R>2!E;G1R>2`E<R!T;R`E
M<SH@)7,*``!D969E<G)E9%]R96UO=F4H*3H@;F]T('-U<'!O<G1E9"!D:7)E
M8W1O<GD@9F]R(&1E9F5R<F5D(')E;6]V93H@)7,*`&1E9F5R<F5D7W)E;6]V
M92@I.B!C86XG="!S=&%T(&1I<F5C=&]R>2P@<VMI<"!I="X*``!D969E<G)E
M9%]R96UO=F4H*3H@56YA8FQE(&-R96%T92!F:6QE;F%M92!F;W(@9&5L971E
M(&1I<F5C=&]R>0H`9&5F97)R961?<F5M;W9E*"DZ(')E;F%M92!D:7(@)7,@
M=&\@)7,*`&1E9F5R<F5D7W)E;6]V92@I.B!5;F%B;&4@=&\@<F5N86UE(&1I
M<F5C=&]R>0H``%5N86)L92!T;R!S=&%T(&9I;&4@)7,L('-K:7!P960*````
M`$-A;B=T(')E;6]V92!D:7)E8W1O<GD@)7,@*'=I;&P@=')Y(&EN(&YE>'0@
M=&EM92D*``!5;F%B;&4@=&\@=')U;F-A=&4@;W(@8W)E871E(&9I;&4@)7,Z
M("5S`````$-A;FYO="!C<F5A=&4@9&ER96-T;W)Y("5S.B`E<P``15)23U(Z
M(%5N86)L92!T;R!M:V1I<B`E<SH@)7,*``!%4E)/4CH@56YA8FQE('1O(&-H
M;W=N("5S.B`E<PH``$524D]2.B!5;F%B;&4@=&\@8VAM;V0@)7,Z("5S"@``
M1&ER96-T;W)Y(')E;F%M92!E<G)O<CH@=&%R9V5T(&1I<F5C=&]R>2`E<R!A
M;')E861Y(&5X:7-T<RX*`````$524D]2.B!U;F%B;&4@=&\@8VAO=VX@)7,Z
M("5S"@``15)23U(Z('5N86)L92!T;R!C:&UO9"`E<SH@)7,*`%5N86)L92!T
M;R!C<F5A=&4@9FEL92`E<SH@)7,`0V%N;F]T(&-H;W=N("5S.B`E<P!296UA
M;6EN9R`E<R!T;R`E<R!F86EL960Z("5S"@!5;F%B;&4@=&\@8VQO<V4@=&AE
M(&9I;&4Z("5S"@!5;F%B;&4@=&\@<V%V92!C=7)R96YT('!A=&@*`"\``%-U
M8V@@<&%T:"`G)7,G(&1O97,@;F]T(&5X:7-T"@``56YA8FQE('1O(&=E="!R
M96%L('!A=&@@:6YF;W)M871I;VX*```E<R]V87(O;&]C:R]F:6QE<R\E<P!5
M;F%B;&4@=&\@;W!E;B!F:6QE("(E<R(Z("5S+@````!!;B!E<G)O<B!O8V-U
M<F5D(&1U<FEN9R!C;&]S:6YG("<E<R<@9FEL93H@)7,*`"4P,G@`;6%L;&]C
M*"D@9F%I;&5D.B`E<P`E<R!E>&5C=71I;VX@9F%I;&5D.@HE<P!F;W)K7V5X
M96-V.B!D=7`H*2!F86EL960Z("5S"@`N"@!#86YN;W0@<F5A9"!C:&EL9"!O
M=71P=70Z"B5S`&5R<F]R.@HE<P!#86YN;W0@97AE8R`E<SH*)7,`0V%N;F]T
M(&9O<FLH*3H*)7,`0V%N;F]T(&%L;&]C871E(&)U9F9E<CH*)7,`)7,O861M
M:6XO8FEN+R5S`&5R<F]R.B!N;VYE`$-A;FYO="!A;&QO8V%T92!M96UO<GD`
M4$%42``E+BIS+R5S`"5S(&5X96-U=&EO;B!F86EL960@*&YO(&]U='!U="D`
M9F]R:U]E>&5C=E]G971O=71E<G(Z('!I<&4H*2!F86EL960`9F]R:U]E>&5C
M=E]G971O=71E<G(Z(&9C;G1L*$]?3D].0DQ/0TLI(&9A:6QE9```9F]R:U]E
M>&5C=E]P:7!E<SH@9F]R:R@I(&9A:6QE9`!F;W)K7V5X96-V.B!E>&5C=B@B
M)7,B*2!F86EL960Z("5S"@!V86QU97,@,"PQ+#(@;F]T(&%L;&]W960@9F]R
M('9A<FEA8FQE<R!F9%]I;B`F(&9D7V]U=`H``$5R<F]R(&]C8W5R960@9'5R
M:6YG('=A:71I;F<@=&AE(&-H:6QD('!R;V-E<W,@=VET:"!P:60Z("5D.B`E
M<PH`````5&AE(&-H:6QD('!R;V-E<W,@=VET:"!P:60@)60@:VEL;&5D(&)Y
M('-I9VYA;"`E:0H``%1H92!C:&EL9"!P<F]C97-S('=I=&@@<&ED("5D('-T
M;W!P960@8GD@<VEG;F%L("5I"@!%<G)O<B!O8V-U<F5D(&1U<FEN9R!E>&5C
M=B@I.@HE<P`````L('!O<W-I8FQE(')E87-O;B`M($Y53$P@<&%R86UE=&5R
M(&ES(&%B<V5N="!I;B!U=&EL7V5X96,H<&%T:"P@87)G,2P@87)G,BP@3E5,
M3"D@8V%L;"X*`````$5R<F]R(&]C8W5R960@9'5R:6YG(&9O<FLH*3H*)7,`
M=71I;&ET>2`E<R!F86EL960@*')E<W5L=#TE9"DZ"B5S````571I;&ET>2!N
M86UE("<E<R<@:7,@:6YV86QI9"X@57-E(&]N;'D@=71I;&ET>2!N86UE('=I
M=&AO=70@<&%T:"X```!P;W!E;E]E>&5C.B!F86EL960@=&\@97AE8W5T92!C
M;VUM86YD.B!F;W)K(&]R('!I<&4@8V%L;',@9F%I;&5D+"!O<B!C86YN;VX@
M86QL;V-A=&4@;65M;W)Y"@````!P;W!E;E]E>&5C.B!F86EL960@=&\@86QL
M;V-A=&4@;65M;W)Y"@``<&]P96Y?97AE8SH@=V%R;FEN9SH@9F%I;&5D('1O
M(&%L;&]C871E(&UE;6]R>2!F;W(@8V]M;6%N9"!O=71P=70@8G5F9F5R"@``
M`'!O<&5N7V5X96,Z(&9A:6QE9"!T;R!E>&5C=71E(&-O;6UA;F0Z("5S"@``
M<&]P96Y?97AE8SH@8V]M;6%N9"!F86EL960@8V]D93H@)60@+"`E<PH```!F
M;W)K7V5X96,J.B!R96%D*'!I<&4I(&9A:6QE9#H@)7,*``!%<G)O<CH@)7,@
M;F]T(&1E9FEN960@:6X@<')O9'5C="!C;VYF:6<@9FEL90````!%<G)O<CH@
M4%)/1%5#5%]23T]47T0@;F]T(&1E9FEN960*``!%<G)O<CH@2%144$1?5DA/
M4U137T0@;F]T(&1E9FEN960*``!%<G)O<CH@2%144$1?0T].1E]$(&YO="!D
M969I;F5D"@````!%<G)O<CH@2%144$1?24Y#3%5$15]$(&YO="!D969I;F5D
M"@!%<G)O<CH@2%144$1?0DE.7T0@;F]T(&1E9FEN960*`$5R<F]R.B!134%)
M3%]23T]47T0@;F]T(&1E9FEN960*`````$5R<F]R.B!134%)3%]-04E,3D%-
M15-?1"!N;W0@9&5F:6YE9`H```!%<G)O<CH@1E101%]#3TY&7TE.0R!N;W0@
M9&5F:6YE9`H```!%<G)O<CH@3D%-141?4E5.7U)/3U1?1"!N;W0@9&5F:6YE
M9`H`````17)R;W(Z($U94U%,7U9!4E]$(&YO="!D969I;F5D"@!%<G)O<CH@
M35E344Q?0DE.7T0@;F]T(&1E9FEN960*`$5R<F]R.B!01U-13%]"24Y?1"!N
M;W0@9&5F:6YE9`H`17)R;W(Z(%!'4U%,7T1!5$%?1"!N;W0@9&5F:6YE9`H`
M````17)R;W(Z($U!24Q-04Y?4D]/5%]$(&YO="!D969I;F5D"@``17)R;W(Z
M($U!24Q-04Y?5D%27T0@;F]T(&1E9FEN960*````17)R;W(Z(%!23T150U1?
M4D-?1"!N;W0@9&5F:6YE9`H`````17)R;W(Z($-!5$%,24Y!7TA/344@;F]T
M(&1E9FEN960*````17)R;W(Z($125T5"7U)/3U1?1"!N;W0@9&5F:6YE9`H`
M````17)R;W(Z($125T5"7T540U]$(&YO="!D969I;F5D"@!04D]$54-47U)/
M3U1?1`!(5%101%]62$]35%-?1`!(5%101%]#3TY&7T0`2%144$1?24Y#3%5$
M15]$`$A45%!$7T))3E]$`%%-04E,7U)/3U1?1`!134%)3%]-04E,3D%-15-?
M1`!&5%!$7T-/3D8`17)R;W(Z($944$1?0T].1B!N;W0@9&5F:6YE9`H`1E10
M1%]#3TY&7TE.0P!&5%!$7T))3E]$`$Y!345$7U)53E]23T]47T0`5T5"7U-4
M050`17)R;W(Z(%=%0E]35$%4(&YO="!D969I;F5D"@!,3T=23U1!5$4`17)R
M;W(Z($Q/1U)/5$%412!N;W0@9&5F:6YE9`H`35E344Q?5D%27T0`35E344Q?
M0DE.7T0`4$=344Q?0DE.7T0`4$=344Q?1$%405]$`$U!24Q-04Y?4D]/5%]$
M`$U!24Q-04Y?5D%27T0`4%)/1%5#5%]20U]$`$1535!?1`!%<G)O<CH@1%5-
M4%]$(&YO="!D969I;F5D"@!#051!3$E.05](3TU%`$125T5"7U)/3U1?1`!$
M4E=%0E]%5$-?1`!#55),7T-!7T)53D1,15]&24Q%`"]A9&UI;B]C;VYF+W-E
M='1I;F=S`"]A9&UI;B]B:6XO9&YS;6YG`"]A9&UI;B]B:6XO;6%I;&UN9P`O
M861M:6XO8FEN+W5S97)M;F<`+V%D;6EN+V)I;B]F<%]W<F%P<&5R`"]A9&UI
M;B]B:6XO<FU?<&1?=7-R`"]A9&UI;B]B:6XO;6%K95]V<G0`+V%D;6EN+V)I
M;B]W96)S<G9M;F<`+V%D;6EN+V)I;B]R;5]F<FT`+V%D;6EN+V)I;B]I;G1E
M<F9A8V4`+V%D;6EN+V)I;B]D;VUA:6YM;F<`+V%D;6EN+V)I;B]C:&MC;VYF
M:6<`+W9A<B]C97)T:69I8V%T97,`17)R;W(Z("5S(&YO="!D969I;F5D`"]E
M=&,O<'-A+W!S82YC;VYF`$-A;FYO="!A;&QO8V%T92!M96UO<GDZ("5S````
M`$-A;B=T(&%L;&]C871E(&UE;6]R>2!F;W(@97)R;W(@;65S<V%G90`*4WES
M=&5M(&5R<F]R("5D.B`E<P`E<SH@````O`X%"``````$8`4(_____QT]!0B8
M7@4(K%X%"```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````0````$````!
M````S0````$````9`0```0```*`!```,````S)$$"`T```"T#@4(!````"B!
M!`@%````=(L$"`8```!TA`0("@```$`#```+````$````!4``````````P``
M``Q@!0@"````\`(``!0````1````%P```-R.!`@1````M(X$"!(````H````
M$P````@`````````````````````````````````````````````````````
M``````````````#_____`````/____\``````````#!?!0@``````````.Z1
M!`C^D00(#I($"!Z2!`@ND@0(/I($"$Z2!`A>D@0(;I($"'Z2!`B.D@0(GI($
M"*Z2!`B^D@0(SI($"-Z2!`CND@0(_I($"`Z3!`@>DP0(+I,$"#Z3!`A.DP0(
M7I,$"&Z3!`A^DP0(CI,$")Z3!`BNDP0(OI,$",Z3!`C>DP0([I,$"/Z3!`@.
ME`0('I0$""Z4!`@^E`0(3I0$"%Z4!`ANE`0(?I0$"(Z4!`B>E`0(KI0$"+Z4
M!`C.E`0(WI0$".Z4!`C^E`0(#I4$"!Z5!`@NE00(/I4$"$Z5!`A>E00(;I4$
M"'Z5!`B.E00(GI4$"*Z5!`B^E00(SI4$"-Z5!`CNE00(_I4$"`Z6!`@>E@0(
M+I8$"#Z6!`A.E@0(7I8$"&Z6!`A^E@0(CI8$")Z6!`BNE@0(OI8$",Z6!`C>
ME@0([I8$"/Z6!`@.EP0('I<$""Z7!`@^EP0(3I<$"%Z7!`ANEP0(?I<$"(Z7
M!`B>EP0(KI<$"+Z7!`@``````````````````````$=#0SH@*$=.52D@8R`R
M+CDU+C0@,C`P,C`S,C`@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XV(%M&
M<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N-B!;1G)E94)31%T``$=#0SH@*$=.
M52D@,RXT+C8@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XV(%M&<F5E0E-$
M70``1T-#.B`H1TY5*2`S+C0N-B!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT
M+C8@6T9R965"4T1=``!'0T,Z("A'3E4I(#,N-"XV(%M&<F5E0E-$70``1T-#
M.B`H1TY5*2`S+C0N-B!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C8@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#,N-"XV(%M&<F5E0E-$70``1T-#.B`H1TY5
M*2`S+C0N-B!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C8@6T9R965"4T1=
M``!'0T,Z("A'3E4I(#,N-"XV(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N
M-B!;1G)E94)31%T``$=#0SH@*$=.52D@,RXT+C8@6T9R965"4T1=``!'0T,Z
M("A'3E4I(#,N-"XV(%M&<F5E0E-$70``1T-#.B`H1TY5*2`S+C0N-B!;1G)E
M94)31%T``$=#0SH@*$=.52D@,RXT+C8@6T9R965"4T1=``!'0T,Z("A'3E4I
M(#,N-"XV(%M&<F5E0E-$70`(``````````$````P,2XP,0`````N<VAS=')T
M86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N<F5L+F)S<P`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"YD871A`"YE:%]F<F%M90`N9'EN86UI8P`N8W1O<G,`+F1T;W)S`"YJ8W(`
M+F=O=``N8V]M;65N=``N;F]T90``````````````````````````````````
M``````````````````````L````!`````@```/2`!`CT````&0``````````
M`````0`````````3````!P````(````0@00($`$``!@```````````````0`
M````````(0````4````"````*($$""@!``!,`P``!``````````$````!```
M`"<````+`````@```'2$!`AT!`````<```4````!````!````!`````O````
M`P````(```!TBP0(=`L``$`#``````````````$`````````-P````D````"
M````M(X$"+0.```H````!````!0````$````"````$`````)`````@```-R.
M!`C<#@``\`(```0````)````!`````@```!)`````0````8```#,D00(S!$`
M``L```````````````0`````````1`````$````&````V)$$"-@1``#P!0``
M```````````$````!````$\````!````!@```,B7!`C(%P``['8`````````
M````!`````````!5`````0````8```"T#@4(M(X```8```````````````0`
M````````6P````$````"````O`X%"+R.``"R/P`````````````$````````
M`&,````!`````P```'!>!0APS@``O```````````````!`````````!I````
M`0````(````L7P4(+,\```0```````````````0`````````<P````8````#
M````,%\%"##/``#(````!0`````````$````"````'P````!`````P```/A?
M!0CXSP``"```````````````!`````````"#`````0````,`````8`4(`-``
M``@```````````````0`````````B@````$````#````"&`%"`C0```$````
M```````````$`````````(\````!`````P````Q@!0@,T```A`$`````````
M````!`````0````[````"`````,```"@804(H-$``/0\`````````````"``
M````````E`````$``````````````*#1```\`@`````````````!````````
M`)T````'``````````````#<TP``%````````````````0`````````!````
M`P``````````````\-,``*,```````````````$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C<`,#$T-#$V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B\`````````````````````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P
M,34S-#0`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+P``
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#4V`#`Q-S$R-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4V5R=FEC97,O5V5A=&AE<B\`````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(P-3(U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]397)V:6-E<R]796%T:&5R+T5J<V4N
M<&AP````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,C4Q,@`Q,#4Q-30S
M,3`U-@`P,C(Q,C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME
M<CH@*B\*"B\J*@H@*B!014%2.CI397)V:6-E<U]796%T:&5R7T5J<V4*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O
M<'ER:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H
M=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@
M<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M
M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@
M9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R
M:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B
M;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C
M=6UE;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED
M960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA
M;64@;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R
M:6)U=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T
M92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I
M=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@
M*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@
M2$],1$524R!!3D0@0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%
M6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@
M3D]4($Q)34E4140@5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@
M34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@
M4%524$]310H@*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@
M5$A%($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!
M0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%
M0TE!3"P@15A%35!,05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@
M*$E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/
M1@H@*B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%53
M12P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!4
M24].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"
M24Q)5%DL(%=(151(15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)
M5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE3
M12D*("H@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(
M25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"
M24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A
M=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC
M97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA
M;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@
M5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`
M=F5R<VEO;B`@("`@0U93.B`D260Z($5J<V4N<&AP+'8@,2XR,R`R,#`U+S$Q
M+S$S(#(Q.C4V.C$V(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI
M;FL@("`@("`@(&AT='`Z+R]W=W<N96IS92YC;VTO<V5R=FEC97,O=V5A=&AE
M<E]X;6Q?=V5B7W-E<G9I8V5S+FAT;0H@*B!`97AA;7!L92`@("`@97AA;7!L
M97,O96IS92UB87-I8RYP:'`@("`@("`@("`@("`@96IS92UB87-I8RYP:'`*
M("H@0&9I;&5S;W5R8V4*("HO"@IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E
M871H97(O0V]M;6]N+G!H<"(["@HO+R![>WL@8VQA<W,@4V5R=FEC97-?5V5A
M=&AE<E]%:G-E"B\J*@H@*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F
M86-E('1O('1H92!S;V%P('-E<G9I8V4@;V8@14I312X@270@<F5T<FEE=F5S
M"B`J(&-U<G)E;G0@=V5A=&AE<B!D871A(&%N9"!F;W)E8V%S=',@8F%S960@
M;VX@<&]S=&%L(&-O9&5S("A:25`I+@H@*@H@*B!#=7)R96YT;'D@=&AI<R!S
M97)V:6-E(&ES(&]N;'D@879A:6QA8FQE(&9O<B!54R!T97)R:71O<GDN"B`J
M"B`J($9O<B!A('=O<FMI;F<@97AA;7!L92P@<&QE87-E('1A:V4@82!L;V]K
M(&%T"B`J("`@("!D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O96IS
M92UB87-I8RYP:'`*("H*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@
M*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@
M("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT
M='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N
M<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@4F5L96%S93H@,2XT
M+C`*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H='1P.B\O=W=W
M+F5J<V4N8V]M+W-E<G9I8V5S+W=E871H97)?>&UL7W=E8E]S97)V:6-E<RYH
M=&T*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+V5J<V4M8F%S:6,N<&AP("`@
M("`@("`@("`@(&5J<V4M8F%S:6,N<&AP"B`J+PIC;&%S<R!397)V:6-E<U]7
M96%T:&5R7T5J<V4@97AT96YD<R!397)V:6-E<U]796%T:&5R7T-O;6UO;B![
M"@H@("`@+R\@>WM[('!R;W!E<G1I97,*("`@("\J*@H@("`@("H@5U-$3"!O
M8FIE8W0L('!R;W9I9&5D(&)Y($5*4T4*("`@("`J"B`@("`@*B!`=F%R("`@
M("!O8FIE8W0@("`@("`@("`@("`@("`@("`@("`@)%]W<V1L"B`@("`@*B!`
M86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W=S9&P["@H@("`@
M+RHJ"B`@("`@*B!33T%0(&]B:F5C="!T;R!A8V-E<W,@=V5A=&AE<B!D871A
M+"!P<F]V:61E9"!B>2!%2E-%"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J
M96-T("`@("`@("`@("`@("`@("`@("`@("1?=V5A=&5R4V]A<`H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]W96%T:&5R4V]A
M<#L*("`@("\O('U]?0H*("`@("\O('M[>R!C;VYS=')U8W1O<@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J(%)E<75I<F5S(%-/
M05`@=&\@8F4@:6YS=&%L;&5D"B`@("`@*@H@("`@("H@0'!A<F%M("`@87)R
M87D@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@("`@*B!`<&%R
M86T@("!M:7AE9"`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R"B`@("`@
M*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?16IS92@D
M;W!T:6]N<RP@)B1E<G)O<BD*("`@('L*("`@("`@("`D<&5R<F]R(#T@;G5L
M;#L*("`@("`@("`D=&AI<RT^4V5R=FEC97-?5V5A=&AE<E]#;VUM;VXH)&]P
M=&EO;G,L("1P97)R;W(I.PH@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1P97)R;W(I*2!["B`@("`@("`@("`@("1E<G)O<B`]("1P
M97)R;W(["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M(%]C;VYN96-T4V5R=F5R*"D*("`@("\J*@H@("`@("H@0V]N;F5C=',@=&\@
M=&AE(%-/05`@<V5R=F5R(&%N9"!R971R:65V97,@=&AE(%=31$P@9&%T80H@
M("`@("H*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\8F]O;`H@("`@("H@
M0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]7
M4D].1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C=%-E<G9E<B@I"B`@("!["B`@("`@
M("`@:6YC;'5D95]O;F-E(")33T%0+T-L:65N="YP:'`B.PH@("`@("`@("1T
M:&ES+3Y?=W-D;"`](&YE=R!33T%07U=31$PH(FAT='`Z+R]W=W<N96IS92YC
M;VTO5V5A=&AE<E-E<G9I8V4O4V5R=FEC92YA<VUX/U=31$PB+"`D=&AI<RT^
M7VAT='!/<'1I;VYS*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]W<V1L
M+3YF875L="D@)B8@4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=&AI<RT^
M7W=S9&PM/F9A=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?
M5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@979A;"@D=&AI<RT^7W=S9&PM/F=E;F5R871E06QL4')O
M>&EE<R@I*3L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@B5V5B4V5R=FEC
M95]397)V:6-E7U-E<G9I8V53;V%P(BDI('L*("`@("`@("`@("`@<F5T=7)N
M(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]W96%T:&5R4V]A<"`]("9N
M97<@5V5B4V5R=FEC95]397)V:6-E7U-E<G9I8V53;V%P.PH*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?8VAE
M8VM,;V-A=&EO;DE$*"D*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!I9"!F
M;W(@=F%L:60@=F%L=65S(&%N9"!T:'5S('!R979E;G1S('-I;&QY(')E<75E
M<W1S('1O($5*4T4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@
M4$5!4E]%<G)O<GQB;V]L"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27TY/7TQ/0T%424]."B`@("`@*B!`=&AR
M;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TE.5D%,
M241?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-H96-K3&]C871I;VY)1"@D:60I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1I9"D@?'P@:7-?;V)J96-T*"1I9"D@?'P@(7-T
M<FQE;B@D:60I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T
M:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?3D]?3$]#
M051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E:68@
M*"%C='EP95]D:6=I="@D:60I('Q\("AS=')L96XH)&ED*2`A/2`U*2D@>PH@
M("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O
M<BA315)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TXL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A
M=&EO;B@I"B`@("`O*BH*("`@("`J($5*4T4@;V9F97)S(&YO('-E87)C:"!F
M=6YC=&EO;B!T;R!D871E+"!S;R!T:&ES(&9U;F-T:6]N(&ES(&1I<V%B;&5D
M+@H@("`@("H@36%Y8F4@=&AI<R!I<R!T:&4@<&QA8V4@=&\@:6YT97)F86-E
M('1O('-O;64@;VYL:6YE('!O<W1C;V1E('-E<G9I8V4N+BX*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&QO
M8V%T:6]N"B`@("`@*B!`<&%R86T@("!B;V]L("`@("`@("`@("`@("`@("`@
M("`@("`@)'5S949I<G-T"B`@("`@*B!`<F5T=7)N("!B;V]L"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E87)C:$QO8V%T:6]N*"1L;V-A=&EO;B`](&YU;&PL("1U
M<V5&:7)S="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N0GE#
M;W5N=')Y*"D*("`@("\J*@H@("`@("H@14I312!O9F9E<G,@;F\@<V5A<F-H
M(&9U;F-T:6]N('1O(&1A=&4L('-O('1H:7,@9G5N8W1I;VX@:7,@9&ES86)L
M960N"B`@("`@*B!-87EB92!T:&ES(&ES('1H92!P;&%C92!T;R!I;G1E<F9A
M8V4@=&\@<V]M92!O;FQI;F4@<&]S=&-O9&4@<V5R=FEC92XN+@H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M8V]U;G1R>0H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R>2@D8V]U;G1R>2`](&YU;&PI"B`@
M("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@+R\@?7U]"@H@
M("`@+R\@>WM[(&=E=$QO8V%T:6]N*"D*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@9&%T82!F;W(@=&AE(&QO8V%T:6]N(&)E;&]N9VEN9R!T;R!T:&4@
M240*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@
M("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y
M"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]C871I;VXH)&ED(#T@
M(B(I"B`@("!["B`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,;V-A
M=&EO;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1A='5S
M.PH@("`@("`@('T*"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N(#T@87)R87DH
M*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D=V5A
M=&AE<B`]("1T:&ES+3Y?8V%C:&4M/F=E="@D:60L(")W96%T:&5R(BDI*2![
M"B`@("`@("`@("`@("\O($=E="!D871A(&9R;VT@8V%C:&4*("`@("`@("`@
M("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H97(["B`@("`@("`@("`@("1L
M;V-A=&EO;E)E='5R;ELB8V%C:&4B72`](")(250B.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O($-H96-K+"!I9B!T:&4@=V5A=&AE<E-O87`M
M3V)J96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T:&4@4V5R
M=F5R(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@("`@("`@("`@(&EF
M("@A)'1H:7,M/E]W96%T:&5R4V]A<"D@>PH@("`@("`@("`@("`@("`@)'-T
M871U<R`]("1T:&ES+3Y?8V]N;F5C=%-E<G9E<B@I.PH@("`@("`@("`@("`@
M("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'=E871H97(@
M/2`D=&AI<RT^7W=E871H97)3;V%P+3YG971796%T:&5R26YF;R@D:60I.PH*
M("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'=E
M871H97(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E871H97(["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W
M96%T:&5R.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@:70*("`@("`@
M("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#15-?5T5!5$A%
M4E]%6%!)4D537U=%051(15(B*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8V%C:&4M/F5X=%-A=F4H)&ED+"`D=&AI<RT^7W=E871H97(L("(B+"`D97AP
M:7)E+"`B=V5A=&AE<B(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L
M;V-A=&EO;E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"B`@
M("`@("`@)&QO8V%T:6]N4F5T=7)N6R)N86UE(ET@/2`D=&AI<RT^7W=E871H
M97(M/DQO8V%T:6]N.PH*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N
M.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E871H97(H*0H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!W96%T:&5R+61A=&$@9F]R('1H
M92!S=7!P;&EE9"!L;V-A=&EO;@H@("`@("H*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@
M('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@
M("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@
M(%!%05)?17)R;W(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971796%T:&5R*"1I9"`]("(B+"`D=6YI='-&;W)M870@
M/2`B(BD*("`@('L*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO
M8V%T:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T
M=7,["B`@("`@("`@?0H*("`@("`@("`O+R!'970@;W1H97(@9&%T80H@("`@
M("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&
M;W)M870I.PH*("`@("`@("`D=V5A=&AE<E)E='5R;B`](&%R<F%Y*"D["B`@
M("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D=V5A=&AE<B`]
M("1T:&ES+3Y?8V%C:&4M/F=E="@D:60L(")W96%T:&5R(BDI*2!["B`@("`@
M("`@("`@("\O(%-A;64@<')O8V5D=7)E+BXN"B`@("`@("`@("`@("1T:&ES
M+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH@("`@("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB8V%C:&4B72`](")(250B.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\O($-H96-K+"!I9B!T:&4@=V5A=&AE<E-O87`M3V)J96-T(&ES
M('!R97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T:&4@4V5R=F5R(&%N9"!R
M971R:65V92!T:&4@5T133"!D871A"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]W96%T:&5R4V]A<"D@>PH@("`@("`@("`@("`@("`@)'-T871U<R`]("1T
M:&ES+3Y?8V]N;F5C=%-E<G9E<B@I.PH@("`@("`@("`@("`@("`@:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@+BXN87,@;&%S="!F=6YC
M=&EO;@H@("`@("`@("`@("`D=V5A=&AE<B`]("1T:&ES+3Y?=V5A=&AE<E-O
M87`M/F=E=%=E871H97));F9O*"1I9"D["@H@("`@("`@("`@("!I9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=V5A=&AE<BDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=V5A=&AE<CL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H97(["@H@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]C86-H945N86)L960I('L*("`@("`@("`@("`@("`@
M("\O("XN+F%N9"!C86-H92!I=`H@("`@("`@("`@("`@("`@)&5X<&ER92`]
M(&-O;G-T86YT*")315)624-%4U]714%42$527T584$E215-?5T5!5$A%4B(I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@D:60L
M("1T:&ES+3Y?=V5A=&AE<BP@(B(L("1E>'!I<F4L(")W96%T:&5R(BD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'=E871H97)2971U<FY;(F-A8VAE
M(ET@/2`B34E34R(["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C
M;VUP87-S*2D@>PH@("`@("`@("`@("`O+R!997,L($Y.12!A;F0@=&AE(&QI
M:V5S(&%R92!M=6QT:7!L97,@;V8@,C(N-2P@8G5T(&%S('1H92!O=&AE<@H@
M("`@("`@("`@("`O+R!S97)V:6-E<R!R971U<FX@:6YT96=E<G,@9F]R('1H
M:7,@=F%L=64L('1H97-E(&1I<F5C=&EO;G,@87)E"B`@("`@("`@("`@("\O
M(')O=6YD960@=7`*("`@("`@("`@("`@)&-O;7!A<W,@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@(")N;W)T:"(@("`@("`@("`@("`@/3X@87)R87DH(DXB
M+"`@("`@,"DL"B`@("`@("`@("`@("`@("`B;F]R=&@@;F]R=&AE87-T(B`@
M(#T^(&%R<F%Y*").3D4B+"`@,C,I+`H@("`@("`@("`@("`@("`@(FYO<G1H
M96%S="(@("`@("`@("`]/B!A<G)A>2@B3D4B+"`@(#0U*2P*("`@("`@("`@
M("`@("`@(")E87-T(&YO<G1H96%S="(@("`@/3X@87)R87DH(D5.12(L("`V
M."DL"B`@("`@("`@("`@("`@("`B96%S="(@("`@("`@("`@("`@(#T^(&%R
M<F%Y*")%(BP@("`@.3`I+`H@("`@("`@("`@("`@("`@(F5A<W0@<V]U=&AE
M87-T(B`@("`]/B!A<G)A>2@B15-%(BP@,3$S*2P*("`@("`@("`@("`@("`@
M(")S;W5T:&5A<W0B("`@("`@("`@/3X@87)R87DH(E-%(BP@(#$S-2DL"B`@
M("`@("`@("`@("`@("`B<V]U=&@@<V]U=&AE87-T(B`@(#T^(&%R<F%Y*")3
M4T4B+"`Q-3@I+`H@("`@("`@("`@("`@("`@(G-O=71H(B`@("`@("`@("`@
M("`]/B!A<G)A>2@B4R(L("`@,3@P*2P*("`@("`@("`@("`@("`@(")S;W5T
M:"!S;W5T:'=E<W0B("`@/3X@87)R87DH(E-35R(L(#(P,RDL"B`@("`@("`@
M("`@("`@("`B<V]U=&AW97-T(B`@("`@("`@(#T^(&%R<F%Y*")35R(L("`R
M,C4I+`H@("`@("`@("`@("`@("`@(G=E<W0@<V]U=&AW97-T(B`@("`]/B!A
M<G)A>2@B5U-7(BP@,C0X*2P*("`@("`@("`@("`@("`@(")W97-T(B`@("`@
M("`@("`@("`@/3X@87)R87DH(E<B+"`@(#(W,"DL"B`@("`@("`@("`@("`@
M("`B=V5S="!N;W)T:'=E<W0B("`@(#T^(&%R<F%Y*")73E<B+"`R.3,I+`H@
M("`@("`@("`@("`@("`@(FYO<G1H=V5S="(@("`@("`@("`]/B!A<G)A>2@B
M3E<B+"`@,S$U*2P*("`@("`@("`@("`@("`@(")N;W)T:"!N;W)T:'=E<W0B
M("`@/3X@87)R87DH(DY.5R(L(#,S."D*("`@("`@("`@("`@*3L*("`@("`@
M("!]"@H@("`@("`@("\O($EN:71I86QI>F4@<V]M92!A<G)A>7,*("`@("`@
M("`D=7!D871E("`@("`@("`@("`@(#T@87)R87DH*3L*("`@("`@("`D=&5M
M<&5R871U<F4@("`@("`@(#T@87)R87DH*3L*("`@("`@("`D9F5L=%1E;7!E
M<F%T=7)E("`@(#T@87)R87DH*3L*("`@("`@("`D=FES:6)I;&ET>2`@("`@
M("`@(#T@87)R87DH*3L*("`@("`@("`D<')E<W-U<F4@("`@("`@("`@(#T@
M87)R87DH*3L*("`@("`@("`D9&5W4&]I;G0@("`@("`@("`@(#T@87)R87DH
M*3L*("`@("`@("`D=79);F1E>"`@("`@("`@("`@(#T@87)R87DH*3L*("`@
M("`@("`D=VEN9"`@("`@("`@("`@("`@(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H(B\H7'<K*2`H7&0K*2P@*%QD*RDL(&%T("A<9"LZ
M7&0K(%QW32D@6UY<*%TK*%PH*%M>7"E=*RE<*2D_+R(L("1T:&ES+3Y?=V5A
M=&AE<BT^3&%S=%5P9&%T960L("1U<&1A=&4I*2!["B`@("`@("`@("`@(&EF
M("AI<W-E="@D=7!D871E6S5=*2D@>PH@("`@("`@("`@("`@("`@)'1I;65S
M=')I;F<@/2`D=7!D871E6S9=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1I;65S=')I;F<@/2`D=7!D871E6S)=+B(@(BXD=7!D
M871E6S%=+B(@(BXD=7!D871E6S-=+B(@(BXD=7!D871E6S1=+B(@15-4(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=7!D
M871E(ET@("`@("`@("`@("`](&=M9&%T92AT<FEM*"1T:&ES+3Y?9&%T949O
M<FUA="XB("(N)'1H:7,M/E]T:6UE1F]R;6%T*2P@<W1R=&]T:6UE*"1T:6UE
M<W1R:6YG*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(G5P9&%T92)=("`@("`@("`@("`@/2`B(CL*("`@("`@("!]
M"B`@("`@("`@)'=E871H97)2971U<FY;(G5P9&%T95)A=R)=("`@("`@("`@
M/2`D=&AI<RT^7W=E871H97(M/DQA<W15<&1A=&5D.PH@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)S=&%T:6]N(ET@("`@("`@("`@(#T@)'1H:7,M/E]W96%T
M:&5R+3Y297!O<G1E9$%T.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)C;VYD
M:71I;VY)8V]N(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R+3Y)8V]N26YD97@[
M"B`@("`@("`@<')E9U]M871C:"@B+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]W
M96%T:&5R+3Y496UP<F%T=7)E+"`D=&5M<&5R871U<F4I.PH@("`@("`@("1W
M96%T:&5R4F5T=7)N6R)T96UP97)A='5R92)=("`@("`@(#T@)'1H:7,M/F-O
M;G9E<G1496UP97)A='5R92@D=&5M<&5R871U<F5;,5TL(")F(BP@)'5N:71S
M6R)T96UP(ETI.PH@("`@("`@('!R96=?;6%T8V@H(B\H+3]<9"LI7$0K+R(L
M("1T:&ES+3Y?=V5A=&AE<BT^1F5E;'-,:6ME+"`D9F5L=%1E;7!E<F%T=7)E
M*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB9F5L=%1E;7!E<F%T=7)E(ET@
M("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)&9E;'1496UP97)A='5R
M95LQ72P@(F8B+"`D=6YI='-;(G1E;7`B72D["B`@("`@("`@)'=E871H97)2
M971U<FY;(F-O;F1I=&EO;B)=("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M
M/D9O<F5C87-T.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O*%M<9%PN72LI
M7$0K+R(L("1T:&ES+3Y?=V5A=&AE<BT^5FES:6)I;&ET>2P@)'9I<VEB:6QI
M='DI*2!["B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)V:7-I8FEL:71Y
M(ET@("`@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1V:7-I8FEL:71Y6S%=
M+"`B<VTB+"`D=6YI='-;(G9I<R)=*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=V5A=&AE<E)E='5R;ELB=FES:6)I;&ET>2)=("`@(#T@=')I
M;2@D=&AI<RT^7W=E871H97(M/E9I<VEB:6QI='DI.PH@("`@("`@('T*("`@
M("`@("!P<F5G7VUA=&-H*"(O*%M<9%PN72LI(&EN8VAE<R!A;F0@*%QW*RDO
M(BP@)'1H:7,M/E]W96%T:&5R+3Y0<F5S<W5R92P@)'!R97-S=7)E*3L*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB<')E<W-U<F4B72`@("`@("`@("`]("1T
M:&ES+3YC;VYV97)T4')E<W-U<F4H)'!R97-S=7)E6S%=+"`B:6XB+"`D=6YI
M='-;(G!R97,B72D["B`@("`@("`@)'=E871H97)2971U<FY;(G!R97-S=7)E
M5')E;F0B72`@("`@/2`D<')E<W-U<F5;,ET["B`@("`@("`@<')E9U]M871C
M:"@B+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]W96%T:&5R+3Y$97=0;VEN="P@
M)&1E=U!O:6YT*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB9&5W4&]I;G0B
M72`@("`@("`@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)&1E=U!O
M:6YT6S%=+"`B9B(L("1U;FET<ULB=&5M<")=*3L*("`@("`@("!P<F5G7VUA
M=&-H*"(O*%QD*RD@*%QW*RDO(BP@)'1H:7,M/E]W96%T:&5R+3Y55DEN9&5X
M+"`D=79);F1E>"D["B`@("`@("`@)'=E871H97)2971U<FY;(G5V26YD97@B
M72`@("`@("`@("`@/2`D=79);F1E>%LQ73L*("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB=79497AT(ET@("`@("`@("`@("`]("1U=DEN9&5X6S)=.PH@("`@
M("`@("1W96%T:&5R4F5T=7)N6R)H=6UI9&ET>2)=("`@("`@("`@(#T@<W1R
M7W)E<&QA8V4H(B4B+"`B(BP@)'1H:7,M/E]W96%T:&5R+3Y(=6UI9&ET>2D[
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]&<F]M('1H92`H6UQW7"!=*RD@
M870@*%M<9%PN72LI("AG=7-T:6YG('1O("A;7&1<+ETK*2`I/VUP:"\B+"`D
M=&AI<RT^7W=E871H97(M/E=I;F0L("1W:6YD*2D@>PH@("`@("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=VEN9")=("`@("`@("`@("`@("`]("1T:&ES+3YC
M;VYV97)T4W!E960H)'=I;F1;,ETL(")M<&@B+"`D=6YI='-;(G=I;F0B72D[
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=VEN9%LT72DI('L*("`@("`@("`@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1W5S=")=("`@("`@/2`D=&AI
M<RT^8V]N=F5R=%-P965D*"1W:6YD6S1=+"`B;7!H(BP@)'5N:71S6R)W:6YD
M(ETI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N
M6R)W:6YD1&5G<F5E<R)=("`@("`@(#T@)&-O;7!A<W-;<W1R=&]L;W=E<B@D
M=VEN9%LQ72E=6S%=.PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN
M9$1I<F5C=&EO;B)=("`@("`]("1C;VUP87-S6W-T<G1O;&]W97(H)'=I;F1;
M,5TI75LP73L*("`@("`@("!](&5L<V5I9B`H<W1R=&]L;W=E<B@D=&AI<RT^
M7W=E871H97(M/E=I;F0I(#T](")C86QM(BD@>PH@("`@("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB=VEN9")=("`@("`@("`@(#T@,#L*("`@("`@("`@("`@
M)'=E871H97)2971U<FY;(G=I;F1$96=R965S(ET@("`](#`["B`@("`@("`@
M("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1&ER96-T:6]N(ET@/2`B0T%,32([
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'=E871H97)2971U<FX["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T1F]R96-A<W0H*0H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&9O<F5C87-T(&9O<B!T:&4@;F5X="!D87ES
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1I;G0*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&%Y<R`@("`@("`@("`@5F%L=65S(&)E='=E96X@,2!A
M;F0@.0H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1U;FET<T9O<FUA=`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA
M<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9O<F5C87-T*"1I
M9"`]("(B+"`D9&%Y<R`](#(L("1U;FET<T9O<FUA="`]("(B*0H@("`@>PH@
M("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I
M.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A
M='5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]
M"B`@("`@("`@:68@*"%I;E]A<G)A>2@D9&%Y<RP@<F%N9V4H,2P@.2DI*2![
M"B`@("`@("`@("`@("1D87ES(#T@,CL*("`@("`@("!]"@H@("`@("`@("\O
M($=E="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E
M=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="D["@H@("`@("`@("1F;W)E8V%S
M=%)E='5R;B`](&%R<F%Y*"D["B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%
M;F%B;&5D("8F("@D9F]R96-A<W0@/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED
M+"`B9F]R96-A<W0B*2DI('L*("`@("`@("`@("`@+R\@4V%M92!P<F]C961U
M<F4N+BX*("`@("`@("`@("`@)'1H:7,M/E]F;W)E8V%S="`]("1F;W)E8V%S
M=#L*("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H92)=(#T@(DA)
M5"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@0VAE8VLL(&EF
M('1H92!W96%T:&5R4V]A<"U/8FIE8W0@:7,@<')E<V5N="X@268@;F]T+"!C
M;VYN96-T('1O('1H92!397)V97(@86YD(')E=')I979E('1H92!71%-,(&1A
M=&$*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W=E871H97)3;V%P*2!["B`@
M("`@("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C;VYN96-T4V5R=F5R
M*"D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<W1A='5S.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R`N+BYA<R!L87-T(&9U;F-T:6]N"B`@("`@("`@("`@("1F
M;W)E8V%S="`]("1T:&ES+3Y?=V5A=&AE<E-O87`M/D=E=$YI;F5$87E&;W)E
M8V%S=$EN9F\H)&ED*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1F;W)E8V%S="DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D9F]R96-A<W0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&ES+3Y?9F]R96-A<W0@/2`D9F]R96-A<W0["@H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]C86-H945N86)L960I('L*("`@("`@("`@("`@("`@("\O("XN
M+F%N9"!C86-H92!I=`H@("`@("`@("`@("`@("`@)&5X<&ER92`](&-O;G-T
M86YT*")315)624-%4U]714%42$527T584$E215-?1D]214-!4U0B*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H)&ED+"`D=&AI
M<RT^7V9O<F5C87-T+"`B(BP@)&5X<&ER92P@(F9O<F5C87-T(BD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H92)=
M(#T@(DU)4U,B.PH@("`@("`@('T*"B`@("`@("`@)&9O<F5C87-T4F5T=7)N
M6R)D87ES(ET@("`](&%R<F%Y*"D["@H@("`@("`@("\O($EN:71I86QI>F4@
M<V]M92!A<G)A>7,*("`@("`@("`D=&5M<&5R871U<F5(:6=H("`@(#T@87)R
M87DH*3L*("`@("`@("`D=&5M<&5R871U<F5,;W<@("`@(#T@87)R87DH*3L*
M"B`@("`@("`@9F]R("@D:2`](#$[("1I(#P]("1D87ES.R`D:2LK*2!["B`@
M("`@("`@("`@('!R96=?;6%T8V@H(B\H+3]<9"LI7$0K+R(L("1T:&ES+3Y?
M9F]R96-A<W0M/GLB1&%Y(BXD:7TM/DAI9V@L("1T96UP97)A='5R94AI9V@I
M.PH@("`@("`@("`@("!P<F5G7VUA=&-H*"(O*"T_7&0K*5Q$*R\B+"`D=&AI
M<RT^7V9O<F5C87-T+3Y[(D1A>2(N)&E]+3Y,;W<L("1T96UP97)A='5R94QO
M=RD["B`@("`@("`@("`@("1D87D@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M(")T96UP97)T=7)E2&EG:"(@/3X@)'1H:7,M/F-O;G9E<G1496UP97)A='5R
M92@D=&5M<&5R871U<F5(:6=H6S%=+"`B9B(L("1U;FET<ULB=&5M<")=*2P*
M("`@("`@("`@("`@("`@(")T96UP97)A='5R94QO=R(@/3X@)'1H:7,M/F-O
M;G9E<G1496UP97)A='5R92@D=&5M<&5R871U<F5,;W=;,5TL(")F(BP@)'5N
M:71S6R)T96UP(ETI+`H@("`@("`@("`@("`@("`@(F1A>2(@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO;B(@("`@(#T^("1T:&ES
M+3Y?9F]R96-A<W0M/GLB1&%Y(BXD:7TM/D9O<F5C87-T+`H@("`@("`@("`@
M("`@("`@("`@(")C;VYD:71I;VY)8V]N(B`]/B`D=&AI<RT^7V9O<F5C87-T
M+3Y[(D1A>2(N)&E]+3Y)8V]N26YD97@L"B`@("`@("`@("`@("`@("`@("`@
M(G!R96-I<&ET871I;VXB(#T^('1R:6TH<W1R7W)E<&QA8V4H(B4B+"`B(BP@
M)'1H:7,M/E]F;W)E8V%S="T^>R)$87DB+B1I?2T^4')E8VEP0VAA;F-E*2D*
M("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M("1F;W)E8V%S=%)E='5R;ELB9&%Y<R)=6UT@/2`D9&%Y.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1F;W)E8V%S=%)E='5R;CL*("`@('T*("`@("\O
M('U]?0I]"B\O('U]?0H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]397)V:6-E<R]796%T:&5R+T=L;V)A;'=E871H97(N<&AP````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`T-C0T,``Q,#4Q-30S,3`U-@`P,C0P,C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!014%2
M.CI397)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H
M8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V
M960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N
M9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I
M;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG
M(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@
M;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@
M:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER
M:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD
M('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO
M;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T
M:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE
M('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@
M*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T
M<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E
M8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/
M1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!
M3D0@0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2
M($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4
M140@5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!
M0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@
M*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E2
M24=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!
M3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%
M35!,05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.
M1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)3
M5$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@
M3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(
M151(15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/
M4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))
M4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!
M4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@
M4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A=&5G;W)Y("`@
M(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE
M<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@
M0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("`@0U93.B`D260Z($=L;V)A;'=E871H97(N<&AP+'8@,2XS-"`R,#`U+S$Q
M+S$S(#(Q.C4V.C$V(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI
M;FL@("`@("`@(&AT='`Z+R]W=W<N8V%P97-C:65N8V4N8V]M+W=E8G-E<G9I
M8V5S+V=L;V)A;'=E871H97(O:6YD97@N<VAT;6P*("H@0&5X86UP;&4@("`@
M(&5X86UP;&5S+V=L;V)A;'=E871H97(M8F%S:6,N<&AP("`@(&=L;V)A;'=E
M871H97(M8F%S:6,N<&AP"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O
M;F-E(")397)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'`B.PH*+R\@>WM[(&-L
M87-S(%-E<G9I8V5S7U=E871H97)?1VQO8F%L=V5A=&AE<@HO*BH*("H@5&AI
M<R!C;&%S<R!A8W1S(&%S(&%N(&EN=&5R9F%C92!T;R!T:&4@<V]A<"!S97)V
M:6-E(&]F(&-A<&5S8VEE;F-E+F-O;2X*("H@270@<V5A<F-H97,@9F]R(&=I
M=F5N(&QO8V%T:6]N<R!A;F0@<F5T<FEE=F5S(&-U<G)E;G0@=V5A=&AE<B!D
M871A+@H@*@H@*B!';&]B86Q796%T:&5R(&ES(&$@4T]!4"!F<F]N=&5N9"!F
M;W(@345405(@9&%T82P@<')O=FED960@8GD@0V%P95-C:65N8V4N"B`J($EF
M('EO=2!W86YT('1O('5S92!-151!4BP@>6]U('-H;W5L9"!T<GD@=&AI<R!C
M;&%S<R!F:7)S="P@87,@:70@:7,@;75C:`H@*B!M;W)E(&-O;69O<G1A8FQE
M("AA;F0@86QS;R!A(&)I="!F87-T97(I('1H86X@=&AE(&YA=&EV92!-151!
M4BUC;&%S<PH@*B!P<F]V:61E9"!B>2!T:&ES('!A8VMA9V4N($]N('1H92!O
M=&AE<B!H86YD+"!T:&ES('-E<G9I8V4@=V]N)W0@<W5P<&QY"B`J(%1!1G,L
M('1H92!F;W)E8V%S="!S>7-T96T@86-C;VUP86YY:6YG($U%5$%2+"!S;R!Y
M;W4@:&%V92!T;R!M86ME"B`J('1H92!C86QL(&AE<F4N+BX*("H*("H@1F]R
M(&$@=V]R:VEN9R!E>&%M<&QE+"!P;&5A<V4@=&%K92!A(&QO;VL@870*("H@
M("`@(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]G;&]B86QW96%T
M:&5R+6)A<VEC+G!H<`H@*@H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I
M8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A=71H
M;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C
M;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@
M("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC
M96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!296QE87-E
M.B`Q+C0N,`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI;FL@("`@("`@(&AT='`Z
M+R]W=W<N8V%P97-C:65N8V4N8V]M+W=E8G-E<G9I8V5S+V=L;V)A;'=E871H
M97(O:6YD97@N<VAT;6P*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+V=L;V)A
M;'=E871H97(M8F%S:6,N<&AP("`@(&=L;V)A;'=E871H97(M8F%S:6,N<&AP
M"B`J+PIC;&%S<R!397)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(@97AT
M96YD<R!397)V:6-E<U]796%T:&5R7T-O;6UO;B!["@H@("`@+R\@>WM[('!R
M;W!E<G1I97,*("`@("\J*@H@("`@("H@5U-$3"!O8FIE8W0L('!R;W9I9&5D
M(&)Y($-A<&538VEE;F-E"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J96-T
M("`@("`@("`@("`@("`@("`@("`@("1?=W-D;`H@("`@("H@0&%C8V5S<R`@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]W<V1L.PH*("`@("\J*@H@("`@
M("H@4T]!4"!O8FIE8W0@=&\@86-C97-S('-T871I;VX@9&%T82P@<')O=FED
M960@8GD@0V%P95-C:65N8V4*("`@("`J"B`@("`@*B!`=F%R("`@("!O8FIE
M8W0@("`@("`@("`@("`@("`@("`@("`@)%]S=&%T:6]N4V]A<`H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]S=&%T:6]N4V]A
M<#L*"B`@("`O*BH*("`@("`J(%-/05`@;V)J96-T('1O(&%C8V5S<R!W96%T
M:&5R(&1A=&$L('!R;W9I9&5D(&)Y($-A<&538VEE;F-E"B`@("`@*@H@("`@
M("H@0'9A<B`@("`@(&]B:F5C="`@("`@("`@("`@("`@("`@("`@("`D7W=E
M871H97)3;V%P"B`@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]W96%T:&5R4V]A<#L*("`@("\O('U]?0H*("`@("\O('M[>R!C
M;VYS=')U8W1O<@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*
M("`@("`J(%)E<75I<F5S(%-/05`@=&\@8F4@:6YS=&%L;&5D"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1O
M<'1I;VYS"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("`@("`@("`@("`@("`@
M("`@("`@)&5R<F]R"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@
M*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]2
M7U=23TY'7U-%4E9%4E]$051!"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?1VQO8F%L=V5A
M=&AE<B@D;W!T:6]N<RP@)B1E<G)O<BD*("`@('L*("`@("`@("`D<&5R<F]R
M(#T@;G5L;#L*("`@("`@("`D=&AI<RT^4V5R=FEC97-?5V5A=&AE<E]#;VUM
M;VXH)&]P=&EO;G,L("1P97)R;W(I.PH@("`@("`@(&EF("A397)V:6-E<U]7
M96%T:&5R.CII<T5R<F]R*"1P97)R;W(I*2!["B`@("`@("`@("`@("1E<G)O
M<B`]("1P97)R;W(["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@
M+R\@>WM[(%]C;VYN96-T4V5R=F5R*"D*("`@("\J*@H@("`@("H@0V]N;F5C
M=',@=&\@=&AE(%-/05`@<V5R=F5R(&%N9"!R971R:65V97,@=&AE(%=31$P@
M9&%T80H@("`@("H*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\8F]O;`H@
M("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C=%-E<G9E<B@I"B`@("![
M"B`@("`@("`@:6YC;'5D95]O;F-E(")33T%0+T-L:65N="YP:'`B.PH@("`@
M("`@("1T:&ES+3Y?=W-D;"`](&YE=R!33T%07U=31$PH(FAT='`Z+R]L:79E
M+F-A<&5S8VEE;F-E+F-O;2]W<V1L+T=L;V)A;%=E871H97(N=W-D;"(L("1T
M:&ES+3Y?:'1T<$]P=&EO;G,I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W=S9&PM/F9A=6QT*2`F)B!397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1T
M:&ES+3Y?=W-D;"T^9F%U;'0I*2!["B`@("`@("`@("`@("1E<G)O<B`](%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@979A;"@D
M=&AI<RT^7W=S9&PM/F=E;F5R871E06QL4')O>&EE<R@I*3L*("`@("`@("!I
M9B`H(6-L87-S7V5X:7-T<R@B5V5B4V5R=FEC95]';&]B86Q796%T:&5R7U-T
M871I;VY);F9O(BD@?'P@(6-L87-S7V5X:7-T<R@B5V5B4V5R=FEC95]';&]B
M86Q796%T:&5R7T=L;V)A;%=E871H97(B*2D@>PH@("`@("`@("`@("`D97)R
M;W(@/2!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%
M051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?<W1A=&EO;E-O87`@/2`F;F5W(%=E8E-E<G9I8V5?1VQO8F%L
M5V5A=&AE<E]3=&%T:6]N26YF;SL*("`@("`@("`D=&AI<RT^7W=E871H97)3
M;V%P(#T@)FYE=R!796)397)V:6-E7T=L;V)A;%=E871H97)?1VQO8F%L5V5A
M=&AE<CL*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*
M"B`@("`O+R![>WL@7V-H96-K3&]C871I;VY)1"@I"B`@("`O*BH*("`@("`J
M($-H96-K<R!T:&4@:60@9F]R('9A;&ED('9A;'5E<R!A;F0@=&AU<R!P<F5V
M96YT<R!S:6QL>2!R97%U97-T<R!T;PH@("`@("H@1VQO8F%L5V5A=&AE<B!S
M97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O
M;VP*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(
M15)?15)23U)?3D]?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3@H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8VAE8VM,;V-A=&EO;DE$*"1I9"D*("`@('L*("`@("`@("!I9B`H:7-?87)R
M87DH)&ED*2!\?"!I<U]O8FIE8W0H)&ED*2!\?"`A<W1R;&5N*"1I9"DI('L*
M("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R
M;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]S=&%T
M:6]N4V]A<"T^:7-686QI9$-O9&4H)&ED*2`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VXH
M*0H@("`@+RHJ"B`@("`@*B!396%R8VAE<R!)1',@9F]R(&=I=F5N(&QO8V%T
M:6]N+"!R971U<FYS(&%R<F%Y(&]F('!O<W-I8FQE(&QO8V%T:6]N<PH@("`@
M("H@;W(@<VEN9VQE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0'!A<F%M
M("`@8F]O;"`@("`@("`@("`@("`@("`@("`@("`@("1U<V5&:7)S="`@("`@
M("!)9B!S970L(&9I<G-T($E$(&]F(')E<W5L="UA<G)A>2!I<R!R971U<FYE
M9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*("`@
M("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M87)C:$QO8V%T:6]N*"1L;V-A=&EO;BP@)'5S949I<G-T(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@+R\@0VAE8VLL(&EF('1H92!S=&%T:6]N4V]A<"U/8FIE
M8W0@:7,@<')E<V5N="X@268@;F]T+"!C;VYN96-T('1O('1H92!397)V97(@
M86YD(')E=')I979E('1H92!71%-,(&1A=&$*("`@("`@("!I9B`H(21T:&ES
M+3Y?<W1A=&EO;E-O87`I('L*("`@("`@("`@("`@)'-T871U<R`]("1T:&ES
M+3Y?8V]N;F5C=%-E<G9E<B@I.PH@("`@("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O($=E="!S96%R8V@@9&%T82!F<F]M('-E<G9E<B!A;F0@=6YS97)I
M86QI>F4*("`@("`@("`D<V5A<F-H(#T@)'1H:7,M/E]S=&%T:6]N4V]A<"T^
M<V5A<F-H0GE.86UE*"1L;V-A=&EO;BD["@H@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S96%R8V@I*2!["B`@("`@("`@("`@(')E
M='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%
M051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<V5A<F-H*2!\?"`A<VEZ96]F*"1S96%R8V@I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA3
M15)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H(21U<V5&:7)S="`F)B`H<VEZ96]F*"1S96%R8V@I(#X@
M,2DI('L*("`@("`@("`@("`@("`@("`@("`D<V5A<F-H4F5T=7)N(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S
M:7IE;V8H)'-E87)C:"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-E87)C:%)E='5R;ELD<V5A<F-H6R1I72T^:6-A;UT@/2`D<V5A<F-H
M6R1I72T^;F%M92XB+"`B+B1S96%R8VA;)&E=+3YC;W5N=')Y.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@D=7-E
M1FER<W0@?'P@*'-I>F5O9B@D<V5A<F-H*2`]/2`Q*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1S96%R8VA2971U<FX@/2`D<V5A<F-H6S!=+3YI8V%O.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'-E87)C:%)E='5R;CL*("`@('T*("`@("\O('U]?0H*
M("`@("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R>2@I"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@241S('=I=&@@;&]C871I;VXM;F%M92!F;W(@82!G
M:79E;B!C;W5N=')Y(&]R(&%L;"!A=F%I;&%B;&4*("`@("`J(&-O=6YT<FEE
M<RP@:68@;F\@=F%L=64@=V%S(&=I=F5N"B`@("`@*@H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1C;W5N=')Y"B`@("`@
M*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!0
M14%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U=23TY'7U-%4E9%
M4E]$051!"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]7
M14%42$527T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J($!A8V-E<W,@
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96%R8VA,;V-A=&EO;D)Y
M0V]U;G1R>2@D8V]U;G1R>2`]("(B*0H@("`@>PH@("`@("`@("\O(%)E='5R
M;B!T:&4@879A:6QA8FQE(&-O=6YT<FEE<R!A<R!N;R!C;W5N=')Y('=A<R!G
M:79E;@H@("`@("`@(&EF("@A<W1R;&5N*"1C;W5N=')Y*2D@>PH@("`@("`@
M("`@("`D8V]U;G1R:65S(#T@)'1H:7,M/E]S=&%T:6]N4V]A<"T^;&ES=$-O
M=6YT<FEE<R@I.PH@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D8V]U;G1R:65S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&-O=6YT<FEE
M<SL*("`@("`@("!]"@H@("`@("`@("\O($-H96-K+"!I9B!T:&4@<W1A=&EO
M;E-O87`M3V)J96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T
M:&4@4V5R=F5R(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@("`@("`@
M:68@*"$D=&AI<RT^7W-T871I;VY3;V%P*2!["B`@("`@("`@("`@("1S=&%T
M=7,@/2`D=&AI<RT^7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@:68@
M*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!.;W<@9F]R('1H92!R96%L('-E87)C:`H@("`@
M("`@("1C;W5N=')Y3&]C<R`]("1T:&ES+3Y?<W1A=&EO;E-O87`M/G-E87)C
M:$)Y0V]U;G1R>2@D8V]U;G1R>2D["B`@("`@("`@+R\@0VAE8VL@<F5S=6QT
M(&9O<B!V86QI9&ET>0H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1C;W5N=')Y3&]C<RDI('L*("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1C;W5N=')Y3&]C<RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R
M;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@0V]N
M<W1R=6-T('1H92!R97-U;'0*("`@("`@("`D;&]C871I;VYS(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("@D8V]U;G1R>4QO8W,@87,@)&QO8V%T:6]N
M*2!["B`@("`@("`@("`@("1L;V-A=&EO;G-;)&QO8V%T:6]N+3YI8V%O72`]
M("1L;V-A=&EO;BT^;F%M92XB+"`B+B1L;V-A=&EO;BT^8V]U;G1R>3L*("`@
M("`@("!]"B`@("`@("`@87-O<G0H)&QO8V%T:6]N<RD["@H@("`@("`@(')E
M='5R;B`D;&]C871I;VYS.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M(&=E=$QO8V%T:6]N*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&%T
M82!F;W(@=&AE(&QO8V%T:6]N(&)E;&]N9VEN9R!T;R!T:&4@240*("`@("`J
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@
M)&ED"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T3&]C871I;VXH)&ED(#T@(B(I"B`@("![
M"B`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,;V-A=&EO;DE$*"1I
M9"D["@H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S
M=&%T=7,I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@
M('T*"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D;&]C871I;VX@/2`D
M=&AI<RT^7V-A8VAE+3YG970H(D=7+2(N)&ED+"`B;&]C871I;VXB*2DI('L*
M("`@("`@("`@("`@+R\@1V5T(&1A=&$@9G)O;2!C86-H90H@("`@("`@("`@
M("`D=&AI<RT^7VQO8V%T:6]N(#T@)&QO8V%T:6]N.PH@("`@("`@("`@("`D
M;&]C871I;VY2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O+R!#:&5C:RP@:68@=&AE('-T871I;VY3;V%P
M+4]B:F5C="!I<R!P<F5S96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E
M<G9E<B!A;F0@<F5T<FEE=F4@=&AE(%=$4TP@9&%T80H@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?<W1A=&EO;E-O87`I('L*("`@("`@("`@("`@("`@("1S
M=&%T=7,@/2`D=&AI<RT^7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@
M("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L;V-A=&EO
M;B`]("1T:&ES+3Y?<W1A=&EO;E-O87`M/F=E=%-T871I;VXH)&ED*3L*"B`@
M("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1L;V-A
M=&EO;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;&]C871I;VX["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?;&]C871I;VX@/2`D
M;&]C871I;VX["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L
M960I('L*("`@("`@("`@("`@("`@("\O("XN+F%N9"!C86-H92!I=`H@("`@
M("`@("`@("`@("`@)&5X<&ER92`](&-O;G-T86YT*")315)624-%4U]714%4
M2$527T584$E215-?3$]#051)3TXB*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8V%C:&4M/F5X=%-A=F4H(D=7+2(N)&ED+"`D=&AI<RT^7VQO8V%T:6]N
M+"`B(BP@)&5X<&ER92P@(FQO8V%T:6]N(BD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PH@
M("`@("`@('T*("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3Y?;&]C871I;VXM
M/G)E9VEO;BD@)B8@<W1R;&5N*"1T:&ES+3Y?;&]C871I;VXM/F-O=6YT<GDI
M*2!["B`@("`@("`@("`@("1L;V-N86UE(#T@)'1H:7,M/E]L;V-A=&EO;BT^
M;F%M92XB+"`B+B1T:&ES+3Y?;&]C871I;VXM/G)E9VEO;BXB+"`B+B1T:&ES
M+3Y?;&]C871I;VXM/F-O=6YT<GD["B`@("`@("`@?2!E;'-E:68@*'-T<FQE
M;B@D=&AI<RT^7VQO8V%T:6]N+3YC;W5N=')Y*2D@>PH@("`@("`@("`@("`D
M;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64N(BP@(BXD=&AI<RT^
M7VQO8V%T:6]N+3YC;W5N=')Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1L;V-N86UE(#T@)'1H:7,M/E]L;V-A=&EO;BT^;F%M93L*("`@("`@
M("!]"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)N86UE(ET@("`@("`]("1L
M;V-N86UE.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB;&%T:71U9&4B72`@
M/2`D=&AI<RT^7VQO8V%T:6]N+3YL871I='5D93L*("`@("`@("`D;&]C871I
M;VY2971U<FY;(FQO;F=I='5D92)=(#T@)'1H:7,M/E]L;V-A=&EO;BT^;&]N
M9VET=61E.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N<FES92)=("`@
M/2!D871E*"1T:&ES+3Y?=&EM949O<FUA="P@)'1H:7,M/F-A;&-U;&%T95-U
M;E)I<V53970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D547U1)34535$%-4"P@
M)'1H:7,M/E]L;V-A=&EO;BT^;&%T:71U9&4L("1T:&ES+3Y?;&]C871I;VXM
M/FQO;F=I='5D92P@4T525DE#15-?5T5!5$A%4E]354Y&54Y#4U]354Y225-%
M7UI%3DE42"P@,"P@=')U92DI.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB
M<W5N<V5T(ET@("`@/2!D871E*"1T:&ES+3Y?=&EM949O<FUA="P@)'1H:7,M
M/F-A;&-U;&%T95-U;E)I<V53970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D54
M7U1)34535$%-4"P@)'1H:7,M/E]L;V-A=&EO;BT^;&%T:71U9&4L("1T:&ES
M+3Y?;&]C871I;VXM/FQO;F=I='5D92P@4T525DE#15-?5T5!5$A%4E]354Y&
M54Y#4U]354Y3151?6D5.251(+"`@,"P@9F%L<V4I*3L*("`@("`@("`D;&]C
M871I;VY2971U<FY;(F5L979A=&EO;B)=(#T@)'1H:7,M/E]L;V-A=&EO;BT^
M96QE=F%T:6]N.PH*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N.PH@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E871H97(H*0H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!W96%T:&5R+61A=&$@9F]R('1H92!S
M=7!P;&EE9"!L;V-A=&EO;@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J
M($!R971U<FX@(%!%05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@(%!%
M05)?17)R;W(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971796%T:&5R*"1I9"`]("(B+"`D=6YI='-&;W)M870@/2`B
M(BD*("`@('L*("`@("`@("!S=&%T:6,@)&-L;W5D<SL*("`@("`@("!I9B`H
M(6ES<V5T*"1C;&]U9',I*2!["B`@("`@("`@("`@("1C;&]U9',@("`@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@(")S:WD@8VQE87(B+`H@("`@("`@("`@
M("`@("`@(F9E=R(L"B`@("`@("`@("`@("`@("`B<V-A='1E<F5D(BP*("`@
M("`@("`@("`@("`@(")B<F]K96XB+`H@("`@("`@("`@("`@("`@(F]V97)C
M87-T(BP*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@("1S=&%T
M=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("\O
M($=E="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E
M=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="D["@H@("`@("`@("1W96%T:&5R
M4F5T=7)N(#T@87)R87DH*3L*("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N
M86)L960@)B8@*"1W96%T:&5R(#T@)'1H:7,M/E]C86-H92T^9V5T*")'5RTB
M+B1I9"P@(G=E871H97(B*2DI('L*("`@("`@("`@("`@+R\@4V%M92!P<F]C
M961U<F4N+BX*("`@("`@("`@("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H
M97(["B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@(DA)
M5"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@0VAE8VLL(&EF
M('1H92!W96%T:&5R4V]A<"U/8FIE8W0@:7,@<')E<V5N="X@268@;F]T+"!C
M;VYN96-T('1O('1H92!397)V97(@86YD(')E=')I979E('1H92!71%-,(&1A
M=&$*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W=E871H97)3;V%P*2!["B`@
M("`@("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C;VYN96-T4V5R=F5R
M*"D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<W1A='5S.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R`N+BYA<R!L87-T(&9U;F-T:6]N"B`@("`@("`@("`@("1W
M96%T:&5R(#T@)'1H:7,M/E]W96%T:&5R4V]A<"T^9V5T5V5A=&AE<E)E<&]R
M="@D:60I.PH*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES
M17)R;W(H)'=E871H97(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E
M871H97(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?=V5A
M=&AE<B`]("1W96%T:&5R.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C
M:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@
M:70*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#
M15-?5T5!5$A%4E]%6%!)4D537U=%051(15(B*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H(D=7+2(N)&ED+"`D=&AI<RT^7W=E
M871H97(L("(B+"`D97AP:7)E+"`B=V5A=&AE<B(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B
M.PH@("`@("`@('T*"B`@("`@("`@)'5P9&%T92`]('1R:6TH<W1R7W)E<&QA
M8V4H87)R87DH(E0B+"`B6B(I+"`B("(L("1T:&ES+3Y?=V5A=&AE<BT^=&EM
M97-T86UP*2DN(B!'350B.PH*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=7!D
M871E(ET@("`@("`@("`@("`](&=M9&%T92AT<FEM*"1T:&ES+3Y?9&%T949O
M<FUA="XB("(N)'1H:7,M/E]T:6UE1F]R;6%T*2P@<W1R=&]T:6UE*"1U<&1A
M=&4I*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=7!D871E4F%W(ET@("`@
M("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=&EM97-T86UP.PH@("`@("`@(&EF
M("AS=')L96XH)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YR96=I;VXI("8F
M('-T<FQE;B@D=&AI<RT^7W=E871H97(M/G-T871I;VXM/F-O=6YT<GDI*2![
M"B`@("`@("`@("`@("1L;V-N86UE(#T@)'1H:7,M/E]W96%T:&5R+3YS=&%T
M:6]N+3YN86UE+B(L("(N)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YR96=I
M;VXN(BP@(BXD=&AI<RT^7W=E871H97(M/G-T871I;VXM/F-O=6YT<GD["B`@
M("`@("`@?2!E;'-E:68@*'-T<FQE;B@D=&AI<RT^7W=E871H97(M/G-T871I
M;VXM/F-O=6YT<GDI*2!["B`@("`@("`@("`@("1L;V-N86UE(#T@)'1H:7,M
M/E]W96%T:&5R+3YS=&%T:6]N+3YN86UE+B(L("(N)'1H:7,M/E]W96%T:&5R
M+3YS=&%T:6]N+3YC;W5N=')Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1L;V-N86UE(#T@)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YN86UE
M.PH@("`@("`@('T*("`@("`@("`D=V5A=&AE<E)E='5R;ELB<W1A=&EO;B)=
M("`@("`@("`@("`]("1L;V-N86UE.PH@("`@("`@("1W96%T:&5R4F5T=7)N
M6R)W:6YD(ET@("`@("`@("`@("`@(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D
M=&AI<RT^7W=E871H97(M/G=I;F0M/G!R979A:6QI;F=?<W!E960L(")M<',B
M+"`D=6YI='-;(G=I;F0B72D["B`@("`@("`@)'=E871H97)2971U<FY;(G=I
M;F1$96=R965S(ET@("`@("`@/2`D=&AI<RT^7W=E871H97(M/G=I;F0M/G!R
M979A:6QI;F=?9&ER96-T:6]N+3YD96=R965S.PH@("`@("`@("1W96%T:&5R
M4F5T=7)N6R)W:6YD1&ER96-T:6]N(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R
M+3YW:6YD+3YP<F5V86EL:6YG7V1I<F5C=&EO;BT^8V]M<&%S<SL*("`@("`@
M("!I9B`H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YP<F5V86EL:6YG7W-P965D
M("$]("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^9W5S=%]S<&5E9"D@>PH@("`@
M("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$=U<W0B72`@("`@(#T@)'1H
M:7,M/F-O;G9E<G13<&5E9"@D=&AI<RT^7W=E871H97(M/G=I;F0M/F=U<W1?
M<W!E960L(")M<',B+"`D=6YI='-;(G=I;F0B72D["B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&AI<RT^7W=E871H97(M/G=I;F0M/G9A<GEI;F=?9G)O;5]D
M:7)E8W1I;VX@(3T@(B(@)B8@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YV87)Y
M:6YG7W1O7V1I<F5C=&EO;B`A/2`B(BD@>PH@("`@("`@("`@("`D=V5A=&AE
M<E)E='5R;ELB=VEN9%9A<B)=("`@("`@(#T@87)R87D@*`H@("`@("`@("`@
M("`@("`@(F9R;VTB(#T^("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=F%R>6EN
M9U]F<F]M7V1I<F5C=&EO;BP*("`@("`@("`@("`@("`@(")T;R(@("`]/B`D
M=&AI<RT^7W=E871H97(M/G=I;F0M/G9A<GEI;F=?=&]?9&ER96-T:6]N"B`@
M("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB=FES:6)I;&ET>2)=("`@("`@("`]("1T:&ES+3YC;VYV97)T1&ES=&%N
M8V4H)'1H:7,M/E]W96%T:&5R+3YV:7-I8FEL:71Y+3YD:7-T86YC92`O(#$P
M,#`L(")K;2(L("1U;FET<ULB=FES(ETI.PH@("`@("`@("1W96%T:&5R4F5T
M=7)N6R)V:7-1=6%L:69I97(B72`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YV
M:7-I8FEL:71Y+3YQ=6%L:69I97(["@H@("`@("`@("1C;VYD:71I;VX@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI
M<RT^7W=E871H97(M/G!H96YO;65N82D[("1I*RLI('L*("`@("`@("`@("`@
M)&-O;F1I=&EO;EM=(#T@)'1H:7,M/E]W96%T:&5R+3YP:&5N;VUE;F%;)&E=
M+3YS=')I;F<["B`@("`@("`@?0H@("`@("`@("1W96%T:&5R4F5T=7)N6R)C
M;VYD:71I;VXB72`@("`@("`@(#T@:6UP;&]D92@B+"`B+"`D8V]N9&ET:6]N
M*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?=V5A=&AE<BT^<VMY
M+3YL87EE<G,I*2!["B`@("`@("`@("`@("1L87EE<G,@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]W
M96%T:&5R+3YS:WDM/FQA>65R<RD[("1I*RLI('L*("`@("`@("`@("`@("`@
M(&EF("AS=')T;W5P<&5R*"1T:&ES+3Y?=V5A=&AE<BT^<VMY+3YL87EE<G-;
M)&E=+3YT>7!E*2`A/2`B0TQ%05(B*2!["B`@("`@("`@("`@("`@("`@("`@
M)&QA>65R<ULD:5T@("`@("`@("`@("`@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`@("`@("`@("1L87EE<G-;)&E=6R)A;6]U;G0B72`@(#T@)&-L;W5D<ULD
M=&AI<RT^7W=E871H97(M/G-K>2T^;&%Y97)S6R1I72T^97AT96YT73L*("`@
M("`@("`@("`@("`@("`@("`D;&%Y97)S6R1I75LB:&5I9VAT(ET@("`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H)'1H:7,M/E]W96%T:&5R+3YS:WDM/FQA
M>65R<ULD:5TM/F%L=&ET=61E+"`B;2(L("1U;FET<ULB:&5I9VAT(ETI.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')T;W5P<&5R*"1T:&ES+3Y?=V5A
M=&AE<BT^<VMY+3YL87EE<G-;)&E=+3YT>7!E*2`A/2`B0TQ/540B*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1L87EE<G-;)&E=6R)T>7!E(ET@/2!U
M8W=O<F1S*'-T<E]R97!L86-E*")?(BP@(B(L("1T:&ES+3Y?=V5A=&AE<BT^
M<VMY+3YL87EE<G-;)&E=+3YT>7!E*2D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AS:7IE;V8H)&QA>65R<RDI('L*("`@("`@("`@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)C;&]U9',B72`@("`@("`@/2`D;&%Y97)S.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=&5M
M<&5R871U<F4B72`@("`@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H
M)'1H:7,M/E]W96%T:&5R+3YT96UP97)A='5R92T^86UB:65N="P@(F,B+"`D
M=6YI='-;(G1E;7`B72D["B`@("`@("`@)&9E;'1496UP97)A='5R92`]("1T
M:&ES+3YC86QC=6QA=&57:6YD0VAI;&PH)'1H:7,M/F-O;G9E<G1496UP97)A
M='5R92@D=V5A=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72P@)'5N:71S6R)T
M96UP(ETL(")F(BDL("1T:&ES+3YC;VYV97)T4W!E960H)'=E871H97)2971U
M<FY;(G=I;F0B72P@)'5N:71S6R)W:6YD(ETL(")M<&@B*2D["B`@("`@("`@
M)'=E871H97)2971U<FY;(F9E;'1496UP97)A='5R92)=("`@/2`D=&AI<RT^
M8V]N=F5R=%1E;7!E<F%T=7)E*"1F96QT5&5M<&5R871U<F4L(")F(BP@)'5N
M:71S6R)T96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)D97=0;VEN
M=")=("`@("`@("`@(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=&AI
M<RT^7W=E871H97(M/G1E;7!E<F%T=7)E+3YD97=P;VEN="P@(F,B+"`D=6YI
M='-;(G1E;7`B72D["B`@("`@("`@)'=E871H97)2971U<FY;(FAU;6ED:71Y
M(ET@("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M/G1E;7!E<F%T=7)E+3YR
M96QA=&EV95]H=6UI9&ET>3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB<')E
M<W-U<F4B72`@("`@("`@("`]("1T:&ES+3YC;VYV97)T4')E<W-U<F4H)'1H
M:7,M/E]W96%T:&5R+3YP<F5S<W5R92T^86QT:6UE=&5R+"`B:'!A(BP@)'5N
M:71S6R)P<F5S(ETI.PH*("`@("`@("!R971U<FX@)'=E871H97)2971U<FX[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T1F]R96-A<W0H*0H@
M("`@+RHJ"B`@("`@*B!';&]B86Q796%T:&5R(&AA<R!N;R!F;W)E8V%S="!P
M97(@<V4L('-O('1H:7,@9G5N8W1I;VX@:7,@:G5S="!F;W(*("`@("`J(&-O
M;7!A=&EB:6QI='D@<'5R<&]S97,N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I;G0*("`@("`J($!P87)A
M;2`@(&EN="`@("`@("`@("`@("`@("`@("`@("`@("`D9&%Y<PH@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U;FET<T9O
M<FUA=`H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971&;W)E8V%S="@D:60@/2!N=6QL+"`D9&%Y<R`](&YU;&PL("1U;FET<T9O
M<FUA="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H@("`@+R\@?7U]"GT*+R\@?7U]"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O365T87(N<&AP````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,C4R,#(T`#$P-3$U-#,Q,#4V`#`R,C,Q,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J
M(%!%05(Z.E-E<G9I8V5S7U=E871H97)?365T87(*("H*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@
M,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V960N
M"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B
M:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@
M<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N
M;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@
M8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@
M*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@
M9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O
M9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@
M(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D
M97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF
M:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E17
M05)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@
M0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2($E-
M4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@
M5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,
M2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@*B!!
M4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(
M5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@
M1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@
M0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)35$E4
M551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@
M4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%5D52
M($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(
M15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))4TE.
M1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A=&5G;W)Y("`@(%=E
M8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@
M*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI
M8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O
M8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@
M0U93.B`D260Z($UE=&%R+G!H<"QV(#$N.#<@,C`P-B\P,R\P."`Q,CHS.3HQ
M."!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H
M='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]W96%T:&5R+VUE=&%R+G-H=&UL"B`J
M($!L:6YK("`@("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]W96%T:&5R
M+W1A9BYS:'1M;`H@*B!`97AA;7!L92`@("`@97AA;7!L97,O;65T87(M8F%S
M:6,N<&AP("`@("`@("`@("`@;65T87(M8F%S:6,N<&AP"B`J($!E>&%M<&QE
M("`@("!E>&%M<&QE<R]M971A<BUE>'1E;G-I=F4N<&AP("`@("`@("!M971A
M<BUE>'1E;G-I=F4N<&AP"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O
M;F-E(")397)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'`B.PH*<F5Q=6ER95]O
M;F-E(")$0BYP:'`B.PH*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?
M365T87(*+RHJ"B`J(%1H:7,@8VQA<W,@86-T<R!A<R!A;B!I;G1E<F9A8V4@
M=&\@=&AE($U%5$%2+U1!1B!S97)V:6-E(&]F"B`J('=E871H97(N;F]A82YG
M;W8N($ET('-E87)C:&5S(&9O<B!L;V-A=&EO;G,@9VEV96X@:6X@24-!3R!N
M;W1A=&EO;B!A;F0*("H@<F5T<FEE=F5S('1H92!C=7)R96YT('=E871H97(@
M9&%T82X*("H*("H@3V8@8V]U<G-E('1H92!P87)S:6YG(&]F('1H92!-151!
M4BUD871A(&AA<R!I=',@;&EM:71A=&EO;G,L(&%S(&ET"B`J(&9O;&QO=W,@
M=&AE($9E9&5R86P@365T96]R;VQO9VEC86P@2&%N9&)O;VL@3F\N,2!W:71H
M(&UO9&EF:6-A=&EO;G,@=&\*("H@86-C;VUO9&%T92!F;W(@;F]N+553(')E
M<&]R=',L('-O(&EF('1H92!R97!O<G0@9&5V:6%T97,@9G)O;2!T:&5S90H@
M*B!S=&%N9&%R9',L('EO=2!W;VXG="!G970@:70@<&%R<V5D(&-O<G)E8W1L
M>2X*("H@06YY=&AI;F<@=&AA="!I<R!N;W0@<&%R<V5D+"!I<R!S879E9"!I
M;B!T:&4@(FYO<&%R<V4B(&%R<F%Y+65N=')Y+`H@*B!R971U<FYE9"!B>2!G
M971796%T:&5R*"DL('-O('EO=2!C86X@9&\@>6]U<B!O=VX@<&%R<VEN9R!A
M9G1E<G=A<F1S+B!4:&ES"B`J(&QI;6ET871I;VX@:7,@<W!E8VEF:6-A;&QY
M(&=I=F5N(&9O<B!R96UA<FMS+"!A<R!T:&4@8VQA<W,@:7,@;F]T"B`J('!R
M;V-E<W-I;F<@979E<GET:&EN9R!M96YT:6]N960@=&AE<F4L(&)U="!Y;W4@
M=VEL;"!G970@=&AE(&UO<W0@8V]M;6]N"B`J(&9I96QD<R!L:6ME('!R96-I
M<&ET871I;VX@86YD('1E;7!E<F%T=7)E+6-H86YG97,N($%G86EN+"!E=F5R
M>71H:6YG(&YO=`H@*B!P87)S960L(&=O97,@:6YT;R`B;F]P87)S92(N"B`J
M"B`J($EF('EO=2!T:&EN:RP@<V]M92!I;7!O<G1A;G0@9FEE;&0@:7,@;6ES
M<VEN9R!O<B!N;W0@8V]R<F5C=&QY('!A<G-E9"P*("H@<&QE87-E(&9I;&4@
M82!F96%T=7)E+7)E<75E<W0O8G5G<F5P;W)T(&%T(&AT='`Z+R]P96%R+G!H
M<"YN970O(&%N9"!B90H@*B!S=7)E('1O('!R;W9I9&4@=&AE($U%5$%2("AO
M<B!4048I(')E<&]R="!W:71H(&$@7V1E=&%I;&5D7R!E>'!L86YA=&EO;B$*
M("H*("H@1F]R('=O<FMI;F<@97AA;7!L97,L('!L96%S92!T86ME(&$@;&]O
M:R!A=`H@*B`@("`@9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+VUE
M=&%R+6)A<VEC+G!H<`H@*B`@("`@9&]C<R]397)V:6-E<U]796%T:&5R+V5X
M86UP;&5S+VUE=&%R+65X=&5N<VEV92YP:'`*("H*("H*("H@0&-A=&5G;W)Y
M("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A
M=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C
M-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*
M("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("`@4F5L96%S93H@,2XT+C`*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK
M("`@("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]W96%T:&5R+VUE=&%R
M+G-H=&UL"B`J($!L:6YK("`@("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O
M=B]W96%T:&5R+W1A9BYS:'1M;`H@*B!`97AA;7!L92`@("`@97AA;7!L97,O
M;65T87(M8F%S:6,N<&AP("`@("`@("`@("`@;65T87(M8F%S:6,N<&AP"B`J
M($!E>&%M<&QE("`@("!E>&%M<&QE<R]M971A<BUE>'1E;G-I=F4N<&AP("`@
M("`@("!M971A<BUE>'1E;G-I=F4N<&AP"B`J+PIC;&%S<R!397)V:6-E<U]7
M96%T:&5R7TUE=&%R(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX*
M>PH@("`@+R\@>WM[('!R;W!E<G1I97,*("`@("\J*@H@("`@("H@26YF;W)M
M871I;VX@=&\@86-C97-S('1H92!L;V-A=&EO;B!$0@H@("`@("H*("`@("`J
M($!V87(@("`@(&]B:F5C="`@1$(@("`@("`@("`@("`@("`@("`D7V1B"B`@
M("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1B.PH*
M("`@("\J*@H@("`@("H@5&AE('-O=7)C92!-151!4B!U<V5S"B`@("`@*@H@
M("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1?
M<V]U<F-E365T87(*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?<V]U<F-E365T87(["@H@("`@+RHJ"B`@("`@*B!4:&4@<V]U
M<F-E(%1!1B!U<V5S"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1?<V]U<F-E5&%F"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-O=7)C951A9CL*"B`@("`O
M*BH*("`@("`J(%1H:7,@<&%T:"!I<R!U<V5D('1O(&9I;F0@=&AE($U%5$%2
M(&1A=&$*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)%]S;W5R8V50871H365T87(*("`@("`J($!A8V-E<W,@
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<V]U<F-E4&%T:$UE=&%R.PH*
M("`@("\J*@H@("`@("H@5&AI<R!P871H(&ES('5S960@=&\@9FEN9"!T:&4@
M5$%&(&1A=&$*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I;F<@("`@("`@
M("`@("`@("`@("`@("`@)%]S;W5R8V50871H5&%F"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-O=7)C95!A=&A4868["B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@("!A<G)A>2`@
M("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G,*("`@("`J($!P87)A;2`@
M(&UI>&5D("`@("`@("`@("`@("`@("`@("`@("`D97)R;W(*("`@("`J($!T
M:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@4V5R=FEC97-?5V5A=&AE<E]-971A<B@D;W!T
M:6]N<RP@)B1E<G)O<BD*("`@('L*("`@("`@("`D<&5R<F]R(#T@;G5L;#L*
M("`@("`@("`D=&AI<RT^4V5R=FEC97-?5V5A=&AE<E]#;VUM;VXH)&]P=&EO
M;G,L("1P97)R;W(I.PH@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1P97)R;W(I*2!["B`@("`@("`@("`@("1E<G)O<B`]("1P97)R
M;W(["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\O
M(%-E="!O<'1I;VYS(&%C8V]R9&EN9VQY"B`@("`@("`@:68@*&ES<V5T*"1O
M<'1I;VYS6R)D<VXB72DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R)D8D]P=&EO;G,B72DI('L*("`@("`@("`@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^<V5T365T87)$0B@D;W!T:6]N<ULB9'-N(ETL("1O<'1I;VYS
M6R)D8D]P=&EO;G,B72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<W1A='5S(#T@)'1H:7,M/G-E=$UE=&%R1$(H)&]P=&EO;G-;
M(F1S;B)=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@
M("`@("`D97)R;W(@/2`D<W1A='5S.PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("`O+R!3971T:6YG('1H92!D871A('-O=7)C97,@
M9F]R($U%5$%2(&%N9"!4048@+2!H879E('1O('=A=&-H(&]U="!F;W(@;VQD
M97(@05!)('5S86=E"B`@("`@("`@:68@*"@D<V]U<F-E(#T@:7-S970H)&]P
M=&EO;G-;(G-O=7)C92)=*2D@?'P@:7-S970H)&]P=&EO;G-;(G-O=7)C94UE
M=&%R(ETI*2!["B`@("`@("`@("`@("1S;W5R8V5-971A<B`]("1S;W5R8V4@
M/R`D;W!T:6]N<ULB<V]U<F-E(ET@.B`D;W!T:6]N<ULB<V]U<F-E365T87(B
M73L*("`@("`@("`@("`@:68@*"@D<V]U<F-E4&%T:"`](&ES<V5T*"1O<'1I
M;VYS6R)S;W5R8V50871H(ETI*2!\?"!I<W-E="@D;W!T:6]N<ULB<V]U<F-E
M4&%T:$UE=&%R(ETI*2!["B`@("`@("`@("`@("`@("`D<V]U<F-E4&%T:$UE
M=&%R(#T@)'-O=7)C95!A=&@@/R`D;W!T:6]N<ULB<V]U<F-E4&%T:")=(#H@
M)&]P=&EO;G-;(G-O=7)C95!A=&A-971A<B)=.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'-O=7)C95!A=&A-971A<B`]("(B.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-O
M=7)C94UE=&%R(#T@(FAT='`B.PH@("`@("`@("`@("`D<V]U<F-E4&%T:$UE
M=&%R(#T@(B(["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULB<V]U<F-E5&%F(ETI*2!["B`@("`@("`@("`@("1S;W5R8V54868@/2`D
M;W!T:6]N<ULB<V]U<F-E5&%F(ET["B`@("`@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N6R)S;W5R8V50871H5&%F(ETI*2!["B`@("`@("`@("`@("`@("`D
M<V]U<F-E4&%T:%1A9B`]("1O<'1I;VYS6R)S;W5R8V50871H5&%F(ET["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V]U8V50871H
M5&%F(#T@(B(["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<V]U<F-E5&%F(#T@(FAT='`B.PH@("`@("`@("`@("`D<V]U
M<F-E4&%T:%1A9B`]("(B.PH@("`@("`@('T*("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/G-E=$UE=&%R4V]U<F-E*"1S;W5R8V5-971A<BP@)'-O=7)C95!A
M=&A-971A<BP@)'-O=7)C951A9BP@)'-O=7)C95!A=&A4868I.PH@("`@("`@
M(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@
M("`@("`@("`@("1E<G)O<B`]("1S=&%T=7,["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T
M365T87)$0B@I"B`@("`O*BH*("`@("`J(%-E=',@=&AE('!A<F%M971E<G,@
M;F5E9&5D(&9O<B!C;VYN96-T:6YG('1O('1H92!$0BP@=VAE<F4@=&AE"B`@
M("`@*B!L;V-A=&EO;BUS96%R8V@@:7,@9F5T8VAI;F<@:71S(&1A=&$@9G)O
M;2X@66]U(&YE960@=&\@8G5I;&0@82!$0@H@("`@("H@=VET:"!T:&4@97AT
M97)N86P@=&]O;"!B=6EL9$UE=&%R1$(@9FER<W0L(&ET(&9E=&-H97,@=&AE
M(&QO8V%T:6]N<PH@("`@("H@86YD(&%I<G!O<G1S(&9R;VT@82!.3T%!+7=E
M8G-I=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@
M("`@("`@("`@("`@("1D<VX*("`@("`J($!P87)A;2`@(&%R<F%Y("`@("`@
M("`@("`@("`@("`@("`@("`D9&)/<'1I;VYS"B`@("`@*B!`<F5T=7)N("!$
M0E]%<G)O<GQB;V]L"B`@("`@*B!`=&AR;W=S("!$0E]%<G)O<@H@("`@("H@
M0'-E92`@("`@1$(Z.G!A<G-E1%-."B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T365T87)$0B@D9'-N+"`D9&)/<'1I
M;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("`D9'-N:6YF;R`]($1".CIP
M87)S94133B@D9'-N*3L*("`@("`@("!I9B`H:7-?87)R87DH)&1S;FEN9F\I
M("8F("%I<W-E="@D9'-N:6YF;ULB;6]D92)=*2D@>PH@("`@("`@("`@("`D
M9'-N:6YF;ULB;6]D92)=/2`P-C0T.PH@("`@("`@('T*"B`@("`@("`@+R\@
M26YI=&EA;&EZ92!C;VYN96-T:6]N('1O($1"(&%N9"!S=&]R92!I;B!O8FIE
M8W0@:68@<W5C8V5S<V9U;`H@("`@("`@("1D8B`]("!$0CHZ8V]N;F5C="@D
M9'-N:6YF;RP@)&1B3W!T:6]N<RD["B`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1D8BDI('L*("`@("`@("`@("`@<F5T=7)N("1D8CL*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]D8B`]("1D8CL*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T365T87)3;W5R8V4H
M*0H@("`@+RHJ"B`@("`@*B!3971S('1H92!S;W5R8V4L('=H97)E('1H92!C
M;&%S<R!T<FEE<R!T;R!L;V-A=&4@=&AE($U%5$%2+U1!1B!D871A"B`@("`@
M*@H@("`@("H@4V]U<F-E(&-A;B!B92!H='1P+"!F='`@;W(@9FEL92X*("`@
M("`J($%L=&5R;F%T92!S;W5R8V5P871H<R!C86X@8F4@<')O=FED960N"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1S;W5R8V5-971A<@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1S;W5R8V50871H365T87(*("`@("`J($!P87)A
M;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D<V]U<F-E5&%F"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'-O
M=7)C95!A=&A4868*("`@("`J($!R971U<FX@(%!%05)?15)23U)\8F]O;`H@
M("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]-151!4E]33U520T5?24Y604Q)1`H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$UE=&%R4V]U<F-E*"1S;W5R
M8V5-971A<BP@)'-O=7)C95!A=&A-971A<B`]("(B+"`D<V]U<F-E5&%F(#T@
M(B(L("1S;W5R8V50871H5&%F(#T@(B(I"B`@("!["B`@("`@("`@:68@*&EN
M7V%R<F%Y*"1S;W5R8V5-971A<BP@87)R87DH(FAT='`B+"`B9G1P(BP@(F9I
M;&4B*2DI('L*("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V5-971A<B`]("1S
M;W5R8V5-971A<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27TU%5$%27U-/55)#15])3E9!3$E$+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&$@<')O
M<&5R($U%5$%2('-O=7)C92!I9B!P87)A;65T97(@:7,@<V5T+"!I9B!N;W0@
M<V5T('5S92!D969A=6QT<PH@("`@("`@(&-L96%R<W1A=&-A8VAE*"D["B`@
M("`@("`@:68@*'-T<FQE;B@D<V]U<F-E4&%T:$UE=&%R*2D@>PH@("`@("`@
M("`@("!I9B`H*"1T:&ES+3Y?<V]U<F-E365T87(@/3T@(F9I;&4B("8F(&ES
M7V1I<B@D<V]U<F-E4&%T:$UE=&%R*2D@?'P@*"1T:&ES+3Y?<V]U<F-E365T
M87(@(3T@(F9I;&4B("8F('!A<G-E7W5R;"@D<V]U<F-E4&%T:$UE=&%R*2DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T:$UE=&%R(#T@
M)'-O=7)C95!A=&A-971A<CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R
M*%-%4E9)0T537U=%051(15)?15)23U)?345405)?4T]54D-%7TE.5D%,240L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!S=VET8V@@*"1S;W5R8V5-971A<BD@>PH@
M("`@("`@("`@("`@("`@8V%S92`B:'1T<"(Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S;W5R8V50871H365T87(@/2`B:'1T<#HO+W=E871H97(N
M;F]A82YG;W8O<'5B+V1A=&$O;V)S97)V871I;VYS+VUE=&%R+W-T871I;VYS
M(CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&-A<V4@(F9T<"(Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R
M8V50871H365T87(@/2`B9G1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D871A+V]B
M<V5R=F%T:6]N<R]M971A<B]S=&%T:6]N<R(["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")F:6QE(CH*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C95!A=&A-971A<B`]("(N(CL*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*&EN7V%R<F%Y*"1S;W5R8V54868L(&%R<F%Y
M*")H='1P(BP@(F9T<"(L(")F:6QE(BDI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<V]U<F-E5&%F(#T@)'-O=7)C951A9CL*("`@("`@("!](&5L<V5I9B`H
M)'-O=7)C951A9B`A/2`B(BD@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]2
M7TU%5$%27U-/55)#15])3E9!3$E$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&$@<')O<&5R(%1!1B!S
M;W5R8V4@:68@<&%R86UE=&5R(&ES('-E="P@:68@;F]T('-E="!U<V4@9&5F
M875L=',*("`@("`@("!C;&5A<G-T871C86-H92@I.PH@("`@("`@(&EF("AS
M=')L96XH)'-O=7)C95!A=&A4868I*2!["B`@("`@("`@("`@(&EF("@H)'1H
M:7,M/E]S;W5R8V54868@/3T@(F9I;&4B("8F(&ES7V1I<B@D<V]U<F-E4&%T
M:%1A9BDI('Q\("@D=&AI<RT^7W-O=7)C951A9B`A/2`B9FEL92(@)B8@<&%R
M<V5?=7)L*"1S;W5R8V50871H5&%F*2DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V]U<F-E4&%T:%1A9B`]("1S;W5R8V50871H5&%F.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S
M7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]-
M151!4E]33U520T5?24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('-W:71C
M:"`H)'-O=7)C951A9BD@>PH@("`@("`@("`@("`@("`@8V%S92`B:'1T<"(Z
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V50871H5&%F(#T@
M(FAT='`Z+R]W96%T:&5R+FYO86$N9V]V+W!U8B]D871A+V9O<F5C87-T<R]T
M868O<W1A=&EO;G,B.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B9G1P(CH*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-O=7)C95!A=&A4868@/2`B9G1P.B\O=V5A=&AE<BYN;V%A+F=O
M=B]D871A+V9O<F5C87-T<R]T868O<W1A=&EO;G,B.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B9FEL92(Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V50871H5&%F(#T@(BXB
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*("`@("\O('U]
M?0H*("`@("\O('M[>R!?8VAE8VM,;V-A=&EO;DE$*"D*("`@("\J*@H@("`@
M("H@0VAE8VMS('1H92!I9"!F;W(@=F%L:60@=F%L=65S(&%N9"!T:'5S('!R
M979E;G1S('-I;&QY(')E<75E<W1S('1O"B`@("`@*B!-151!4B!S97)V97(*
M("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*("`@
M("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)2
M3U)?3D]?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%
M4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM,
M;V-A=&EO;DE$*"1I9"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&ED
M*2!\?"!I<U]O8FIE8W0H)&ED*2!\?"`A<W1R;&5N*"1I9"DI('L*("`@("`@
M("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3BP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!](&5L<V5I9B`H(6-T>7!E7V%L;G5M*"1I9"D@
M?'P@*'-T<FQE;B@D:60I(#X@-"DI('L*("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E])3E9!3$E$7TQ/0T%424].+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`O+R!]
M?7T*"B`@("`O*BH*("`@("`J($1O=VYL;V%D<R!T:&4@=V5A=&AE<BT@;W(@
M9F]R96-A<W0M9&%T82!F;W(@86X@:60@9G)O;2!T:&4@<V5R=F5R(&1E<&5N
M9&%N="!O;B!T:&4@9&%T871Y<&4@86YD(')E='5R;G,@:70*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&%4>7!E"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@
M("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27U=23TY'7U-%4E9%4E]$051!"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B\*("`@("\O('M[>R!?<F5T<FEE=F5397)V97)$871A*"D*("`@
M(&9U;F-T:6]N(%]R971R:65V95-E<G9E<D1A=&$H)&ED+"`D9&%T851Y<&4I
M('L*("`@("`@("!S=VET8V@H)'1H:7,M/GLB7W-O=7)C92(N=6-F:7)S="@D
M9&%T851Y<&4I?2D@>PH@("`@("`@("`@("!C87-E(")F:6QE(CH*("`@("`@
M("`@("`@("`@("\O($9I;&4@<V]U<F-E(&ES('5S960L(&=E="!F:6QE(&%N
M9"!R96%D(&%S+6ES(&EN=&\@82!S=')I;F<*("`@("`@("`@("`@("`@("1S
M;W5R8V4@/2!R96%L<&%T:"@D=&AI<RT^>R)?<V]U<F-E4&%T:"(N=6-F:7)S
M="@D9&%T851Y<&4I?2XB+R(N)&ED+B(N5%A4(BD["B`@("`@("`@("`@("`@
M("`D9&%T82`]($!F:6QE7V=E=%]C;VYT96YT<R@D<V]U<F-E*3L*("`@("`@
M("`@("`@("`@(&EF("@D9&%T82`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA3
M15)624-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(FAT='`B.@H@("`@("`@
M("`@("`@("`@+R\@2%144"!U<V5D+"!A8W%U:7)E(')E<75E<W0@;V)J96-T
M(&%N9"!F971C:"!D871A(&9R;VT@=V5B<V5R=F5R+B!2971U<FX@8F]D>2!O
M9B!R97!L>0H@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E(")(5%10+U)E
M<75E<W0N<&AP(CL*"B`@("`@("`@("`@("`@("`D<F5Q=65S="`]("9N97<@
M2%144%]297%U97-T*"1T:&ES+3Y[(E]S;W5R8V50871H(BYU8V9I<G-T*"1D
M871A5'EP92E]+B(O(BXD:60N(BY46%0B+"`D=&AI<RT^7VAT='!/<'1I;VYS
M*3L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D<F5Q=65S="T^<V5N9%)E
M<75E<W0H*3L*("`@("`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1S=&%T=7,I('Q\("AI;G0I("1R97%U97-T+3YG971297-P
M;VYS94-O9&4H*2`\/B`R,#`I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1D871A
M(#T@)')E<75E<W0M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(F9T<"(Z"B`@("`@("`@("`@
M("`@("`O+R!&5%`@87,@<V]U<F-E+"!A8W%U:7)E(&YE8V-E<W-A<GD@;V)J
M96-T(&9I<G-T"B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@(DYE="]&
M5%`N<&AP(CL*"B`@("`@("`@("`@("`@("`O+R!087)S92!S;W5R8V4@=&\@
M9V5T('1H92!S97)V97(@9&%T80H@("`@("`@("`@("`@("`@)'-E<G9E<B`]
M('!A<G-E7W5R;"@D=&AI<RT^>R)?<V]U<F-E4&%T:"(N=6-F:7)S="@D9&%T
M851Y<&4I?2XB+R(N)&ED+B(N5%A4(BD["@H@("`@("`@("`@("`@("`@+R\@
M268@;F5C8V5S<V%R>2!O<'1I;VYS(&%R92!N;W0@<V5T+"!U<V4@9&5F875L
M=',*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'-E<G9E<ELB<&]R=")=
M*2!\?"`D<V5R=F5R6R)P;W)T(ET@/3T@(B(@?'P@)'-E<G9E<ELB<&]R=")=
M(#T](#`I('L*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R6R)P;W)T(ET@
M/2`R,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'-E<G9E<ELB=7-E<B)=*2!\?"`D<V5R=F5R6R)U<V5R(ET@/3T@
M(B(I('L*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R6R)U<V5R(ET@/2`B
M9G1P(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'-E<G9E<ELB<&%S<R)=*2!\?"`D<V5R=F5R6R)P87-S(ET@/3T@
M(B(I('L*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R6R)P87-S(ET@/2`B
M9G1P0"(["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@
M26YS=&%N=&EA=&4@;V)J96-T(&%N9"!C;VYN96-T('1O('-E<G9E<@H@("`@
M("`@("`@("`@("`@)&9T<"`]("9N97<@3F5T7T944"@D<V5R=F5R6R)H;W-T
M(ETL("1S97)V97);(G!O<G0B72P@)'1H:7,M/E]H='1P3W!T:6]N<ULB=&EM
M96]U=")=*3L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D9G1P+3YC;VYN
M96-T*"D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(
M15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@3&]G
M:6X@=&\@<V5R=F5R+BXN"B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)&9T
M<"T^;&]G:6XH)'-E<G9E<ELB=7-E<B)=+"`D<V5R=F5R6R)P87-S(ETI.PH@
M("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]2
M7U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O("XN+F%N9"!R971R
M:65V92!T:&4@9&%T82!I;G1O(&$@=&5M<&]R87)Y(&9I;&4*("`@("`@("`@
M("`@("`@("1T96UP9FEL92`]('1E;7!N86TH(BXO(BP@(E-E<G9I8V5S7U=E
M871H97)?365T87(B*3L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D9G1P
M+3YG970H)'-E<G9E<ELB<&%T:")=+"`D=&5M<&9I;&4L('1R=64L($944%]!
M4T-)22D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@('5N;&EN
M:R@D=&5M<&9I;&4I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!397)V
M:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@1&ES8V]N;F5C
M="!&5%`@<V5R=F5R+"!A;F0@<F5A9"!D871A(&9R;VT@=&5M<&]R87)Y(&9I
M;&4*("`@("`@("`@("`@("`@("1F='`M/F1I<V-O;FYE8W0H*3L*("`@("`@
M("`@("`@("`@("1D871A(#T@0&9I;&5?9V5T7V-O;G1E;G1S*"1T96UP9FEL
M92D["B`@("`@("`@("`@("`@("!U;FQI;FLH)'1E;7!F:6QE*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@4W!L:70@
M9&%T82!I;G1O(&%N(&%R<F%Y(&%N9"!R971U<FX*("`@("`@("!R971U<FX@
M<')E9U]S<&QI="@B+UQN?%QR7&Y\7&Y<<B\B+"`D9&%T82D["B`@("!]"B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@7W!A<G-E5V5A=&AE<D1A=&$H*0H@("`@
M+RHJ"B`@("`@*B!087)S97,@=&AE(&1A=&$@86YD(&-A8VAE<R!I=`H@("`@
M("H*("`@("`J($U%5$%2($M0250@,#DQ.34U6B!#3U(@,C(P,35',C5+5"`S
M+S1332!2,CA,+S(V,#!&5"!44U)!($]60S`Q,$-""B`@("`@*B`Q."\Q-B!!
M,CDY,B!234L@4TQ0,#0U(%0P,3@R,#$U.0H@("`@("H*("`@("`J($!P87)A
M;2`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D9&%T80H@("`@("H@
M0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!
M4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?
M1$%400H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424]."B`@("`@*B!`86-C97-S("!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95=E871H97)$871A
M*"1D871A*0H@("`@>PH@("`@("`@('-T871I8R`D8V]M<&%S<SL*("`@("`@
M("!S=&%T:6,@)&-L;W5D<SL*("`@("`@("!S=&%T:6,@)&-O;F1I=&EO;G,[
M"B`@("`@("`@<W1A=&EC("1S96YS;W)S.PH@("`@("`@(&EF("@A:7-S970H
M)&-O;7!A<W,I*2!["B`@("`@("`@("`@("1C;VUP87-S(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`B3B(L(").3D4B+"`B3D4B+"`B14Y%(BP*("`@("`@
M("`@("`@("`@(")%(BP@(D5312(L(")312(L(")34T4B+`H@("`@("`@("`@
M("`@("`@(E,B+"`B4U-7(BP@(E-7(BP@(E=35R(L"B`@("`@("`@("`@("`@
M("`B5R(L(")73E<B+"`B3E<B+"`B3DY7(@H@("`@("`@("`@("`I.PH@("`@
M("`@("`@("`D8VQO=61S("`@(#T@87)R87DH"B`@("`@("`@("`@("`@("`B
M<VMC(B`@("`@("`@(#T^(")S:WD@8VQE87(B+`H@("`@("`@("`@("`@("`@
M(FYS8R(@("`@("`@("`]/B`B;F\@<VEG;FEF:6-A;G0@8VQO=60B+`H@("`@
M("`@("`@("`@("`@(F9E=R(@("`@("`@("`]/B`B9F5W(BP*("`@("`@("`@
M("`@("`@(")S8W0B("`@("`@("`@/3X@(G-C871T97)E9"(L"B`@("`@("`@
M("`@("`@("`B8FMN(B`@("`@("`@(#T^(")B<F]K96XB+`H@("`@("`@("`@
M("`@("`@(F]V8R(@("`@("`@("`]/B`B;W9E<F-A<W0B+`H@("`@("`@("`@
M("`@("`@(G9V(B`@("`@("`@("`]/B`B=F5R=&EC86P@=FES:6)I;&ET>2(L
M"B`@("`@("`@("`@("`@("`B=&-U(B`@("`@("`@(#T^(")4;W=E<FEN9R!#
M=6UU;'5S(BP*("`@("`@("`@("`@("`@(")C8B(@("`@("`@("`@/3X@(D-U
M;75L;VYI;6)U<R(L"B`@("`@("`@("`@("`@("`B8VQR(B`@("`@("`@(#T^
M(")C;&5A<B!B96QO=R`Q,BPP,#`@9G0B"B`@("`@("`@("`@("D["B`@("`@
M("`@("`@("1C;VYD:71I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`B
M*R(@("`@("`@("`@(#T^(")H96%V>2(L("`@("`@("`B+2(@("`@("`@("`@
M(#T^(")L:6=H="(L"@H@("`@("`@("`@("`@("`@(G9C(B`@("`@("`@("`]
M/B`B=FEC:6YI='DB+"`@("`@(G)E(B`@("`@("`@("`]/B`B<F5C96YT(BP*
M("`@("`@("`@("`@("`@(")N<W<B("`@("`@("`@/3X@(FYO('-I9VYI9FEC
M86YT('=E871H97(B+`H*("`@("`@("`@("`@("`@(")M:2(@("`@("`@("`@
M/3X@(G-H86QL;W<B+"`@("`@(")B8R(@("`@("`@("`@/3X@(G!A=&-H97,B
M+`H@("`@("`@("`@("`@("`@(G!R(B`@("`@("`@("`]/B`B<&%R=&EA;"(L
M("`@("`@(G1S(B`@("`@("`@("`]/B`B=&AU;F1E<G-T;W)M(BP*("`@("`@
M("`@("`@("`@(")B;"(@("`@("`@("`@/3X@(F)L;W=I;F<B+"`@("`@(")S
M:"(@("`@("`@("`@/3X@(G-H;W=E<G,B+`H@("`@("`@("`@("`@("`@(F1R
M(B`@("`@("`@("`]/B`B;&]W(&1R:69T:6YG(BP@(F9Z(B`@("`@("`@("`]
M/B`B9G)E97II;F<B+`H*("`@("`@("`@("`@("`@(")D>B(@("`@("`@("`@
M/3X@(F1R:7IZ;&4B+"`@("`@(")R82(@("`@("`@("`@/3X@(G)A:6XB+`H@
M("`@("`@("`@("`@("`@(G-N(B`@("`@("`@("`]/B`B<VYO=R(L("`@("`@
M("`@(G-G(B`@("`@("`@("`]/B`B<VYO=R!G<F%I;G,B+`H@("`@("`@("`@
M("`@("`@(FEC(B`@("`@("`@("`]/B`B:6-E(&-R>7-T86QS(BP@(G!E(B`@
M("`@("`@("`]/B`B:6-E('!E;&QE=',B+`H@("`@("`@("`@("`@("`@(F=R
M(B`@("`@("`@("`]/B`B:&%I;"(L("`@("`@("`@(F=S(B`@("`@("`@("`]
M/B`B<VUA;&P@:&%I;"]S;F]W('!E;&QE=',B+`H@("`@("`@("`@("`@("`@
M(G5P(B`@("`@("`@("`]/B`B=6YK;F]W;B!P<F5C:7!I=&%T:6]N(BP*"B`@
M("`@("`@("`@("`@("`B8G(B("`@("`@("`@(#T^(")M:7-T(BP@("`@("`@
M("`B9F<B("`@("`@("`@(#T^(")F;V<B+`H@("`@("`@("`@("`@("`@(F9U
M(B`@("`@("`@("`]/B`B<VUO:V4B+"`@("`@("`@(G9A(B`@("`@("`@("`]
M/B`B=F]L8V%N:6,@87-H(BP*("`@("`@("`@("`@("`@(")S82(@("`@("`@
M("`@/3X@(G-A;F0B+"`@("`@("`@(")H>B(@("`@("`@("`@/3X@(FAA>F4B
M+`H@("`@("`@("`@("`@("`@(G!Y(B`@("`@("`@("`]/B`B<W!R87DB+"`@
M("`@("`@(F1U(B`@("`@("`@("`]/B`B=VED97-P<F5A9"!D=7-T(BP*"B`@
M("`@("`@("`@("`@("`B<W$B("`@("`@("`@(#T^(")S<75A;&PB+"`@("`@
M("`B<W,B("`@("`@("`@(#T^(")S86YD<W1O<FTB+`H@("`@("`@("`@("`@
M("`@(F1S(B`@("`@("`@("`]/B`B9'5S='-T;W)M(BP@("`@(G!O(B`@("`@
M("`@("`]/B`B=V5L;"!D979E;&]P960@9'5S="]S86YD('=H:7)L<R(L"B`@
M("`@("`@("`@("`@("`B9F,B("`@("`@("`@(#T^(")F=6YN96P@8VQO=60B
M+`H*("`@("`@("`@("`@("`@("(K9F,B("`@("`@("`@/3X@(G1O<FYA9&\O
M=V%T97)S<&]U="(*("`@("`@("`@("`@*3L*("`@("`@("`@("`@)'-E;G-O
M<G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@(")R=G)N;R(@(#T^(")2=6YW
M87D@5FES=6%L(%)A;F=E($1E=&5C=&]R(&]F9FQI;F4B+`H@("`@("`@("`@
M("`@("`@(G!W:6YO(B`@/3X@(E!R97-E;G0@5V5A=&AE<B!)9&5N=&EF:65R
M(&]F9FQI;F4B+`H@("`@("`@("`@("`@("`@(G!N;R(@("`@/3X@(E1I<'!I
M;F<@0G5C:V5T(%)A:6X@1V%U9V4@;V9F;&EN92(L"B`@("`@("`@("`@("`@
M("`B9GIR86YO(B`]/B`B1G)E97II;F<@4F%I;B!396YS;W(@;V9F;&EN92(L
M"B`@("`@("`@("`@("`@("`B='-N;R(@("`]/B`B3&EG:'1N:6YG($1E=&5C
M=&EO;B!3>7-T96T@;V9F;&EN92(L"B`@("`@("`@("`@("`@("`B=FES;F\B
M("`]/B`B,FYD(%9I<VEB:6QI='D@4V5N<V]R(&]F9FQI;F4B+`H@("`@("`@
M("`@("`@("`@(F-H:6YO(B`@/3X@(C)N9"!#96EL:6YG($AE:6=H="!);F1I
M8V%T;W(@;V9F;&EN92(*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@
M("`@("1M971A<D-O9&4@/2!A<G)A>2@*("`@("`@("`@("`@(G)E<&]R="(@
M("`@("`]/B`B345405)\4U!%0TDB+`H@("`@("`@("`@("`B<W1A=&EO;B(@
M("`@(#T^(")<=WLT?2(L"B`@("`@("`@("`@(")U<&1A=&4B("`@("`@/3X@
M(BA<9'LR?2D_*%QD>S1]*5HB+`H@("`@("`@("`@("`B='EP92(@("`@("`@
M(#T^(")!551/?$-/4B(L"B`@("`@("`@("`@(")W:6YD(B`@("`@("`@/3X@
M(BA<9'LS?7Q605)\5E)"*2A<9'LR+#-]*2A'*%QD>S)]*2D_*%QW>S(L,WTI
M(BP*("`@("`@("`@("`@(G=I;F1687(B("`@("`]/B`B*%QD>S-]*58H7&1[
M,WTI(BP*("`@("`@("`@("`@(G9I<T9R86,B("`@("`]/B`B*%QD>S%]*2(L
M"B`@("`@("`@("`@(")V:7-I8FEL:71Y(B`@/3X@(BA<9'LT?2E\*"A-?%`I
M/R@H7&1[,2PR?7PH*%QD*2`I/RA<9"E<+RA<9"DI*%--?$M-*2DI?"A#059/
M2RDB+`H@("`@("`@("`@("`B<G5N=V%Y(B`@("`@(#T^(")2*%QD>S)]*2A<
M=RD_7"\H4'Q-*3\H7&1[-'TI*$94*3\H5BA0?$TI/RA<9'LT?2DH1E0I/RD_
M*%QW*3\B+`H@("`@("`@("`@("`B8V]N9&ET:6]N(B`@(#T^("(H+7Q<*WQ6
M0WQ217Q.4U<I/RA-27Q"0WQ04GQ44WQ"3'Q32'Q$4GQ&6BD_*"A$6BE\*%)!
M*7PH4TXI?"A31RE\*$E#*7PH4$PI?"A'4BE\*$=3*7PH55`I*2HH0E)\1D=\
M1E5\5D%\1%5\4T%\2%I\4%DI/RA03WQ347Q&0WQ34WQ$4RD_(BP*("`@("`@
M("`@("`@(F-L;W5D<R(@("`@("`]/B`B*%-+0WQ#3%)\3E-#?"@H1D57?%-#
M5'Q"2TY\3U9#?%96*2A<9'LS?2DH5$-5?$-"*3\I*2(L"B`@("`@("`@("`@
M(")T96UP97)A='5R92(@/3X@(BA-*3\H7&1[,GTI7"\H*$TI/RA<9'LR?2E\
M6%A\7"]<+RD_(BP*("`@("`@("`@("`@(G!R97-S=7)E(B`@("`]/B`B*$$I
M*%QD>S1]*7PH42DH7&1[-'TI(BP*("`@("`@("`@("`@(G1R96YD(B`@("`@
M("`]/B`B3D]324=\5$5-4$]\0D5#34<B+`H@("`@("`@("`@("`B<F5M87)K
M(B`@("`@(#T^(")234LB"B`@("`@("`@*3L*"B`@("`@("`@)')E;6%R:W,@
M/2!A<G)A>2@*("`@("`@("`@("`@(FYO<W!E8VDB("`@("`]/B`B3D]34$5#
M22(L"B`@("`@("`@("`@(")A=71O<W1A=&EO;B(@/3X@(D%/*#%\,BDB+`H@
M("`@("`@("`@("`B<')E<W-C:&<B("`@(#T^(")04D53*%)\1BE2(BP*("`@
M("`@("`@("`@(G-E87!R97-S=7)E(B`]/B`B4TQ0*%QD>S-]?$Y/*2(L"B`@
M("`@("`@("`@(")P<F5C:7`B("`@("`@/3X@(BA0?#9\-RDH7&1[-'U\7"][
M-'TI(BP*("`@("`@("`@("`@(G-N;W=D97!T:"(@("`]/B`B-%PO*%QD>S-]
M*2(L"B`@("`@("`@("`@(")S;F]W97%U:78B("`@/3X@(CDS,RA<9'LS?2DB
M+`H@("`@("`@("`@("`B8VQO=61T>7!E<R(@(#T^("(X7"\H7&1\7"\I*%QD
M?%PO*2A<9'Q<+RDB+`H@("`@("`@("`@("`B<W5N9'5R871I;VXB(#T^("(Y
M."A<9'LS?2DB+`H@("`@("`@("`@("`B,6AT96UP9&5W(B`@(#T^(")4*#!\
M,2DH7&1[,WTI*"@P?#$I*%QD>S-]*2D_(BP*("`@("`@("`@("`@(C9H;6%X
M=&5M<"(@("`]/B`B,2@P?#$I*%QD>S-]*2(L"B`@("`@("`@("`@("(V:&UI
M;G1E;7`B("`@/3X@(C(H,'PQ*2A<9'LS?2DB+`H@("`@("`@("`@("`B,C1H
M=&5M<"(@("`@(#T^("(T*#!\,2DH7&1[,WTI*#!\,2DH7&1[,WTI(BP*("`@
M("`@("`@("`@(C-H<')E<W-T96YD(B`]/B`B-2A;,"TX72DH7&1[,WTI(BP*
M("`@("`@("`@("`@(G-E;G-O<G,B("`@("`]/B`B4E923D]\4%=)3D]\4$Y/
M?$9:4D%.3WQ44TY/?%9)4TY/?$-(24Y/(BP*("`@("`@("`@("`@(FUA:6YT
M86EN(B`@("`]/B`B6UPD72(*("`@("`@("`I.PH*("`@("`@("!I9B`H4T52
M5DE#15-?5T5!5$A%4E]$14)51RD@>PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!S:7IE;V8H)&1A=&$I.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("!E8VAO("1D871A6R1I73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("`O+R!3=&%R="!W:71H('!A<G-I;F<@=&AE(&9I<G-T(&QI;F4@9F]R
M('1H92!L87-T('5P9&%T90H@("`@("`@("1W96%T:&5R1&%T82`](&%R<F%Y
M*"D["B`@("`@("`@)'=E871H97)$871A6R)S=&%T:6]N(ET@("`]("(B.PH@
M("`@("`@("1W96%T:&5R1&%T85LB9&%T85)A=R)=("`@/2!I;7!L;V1E*"(@
M(BP@)&1A=&$I.PH@("`@("`@("1W96%T:&5R1&%T85LB=7!D871E(ET@("`@
M/2!S=')T;W1I;64H=')I;2@D9&%T85LP72DN(B!'350B*3L*("`@("`@("`D
M=V5A=&AE<D1A=&%;(G5P9&%T95)A=R)=(#T@=')I;2@D9&%T85LP72D["B`@
M("`@("`@+R\@86YD('!R97!A<F4@=&AE(')E<W0@9F]R('-T97!P:6YG('1H
M<F]U9V@*("`@("`@("!A<G)A>5]S:&EF="@D9&%T82D["B`@("`@("`@)&UE
M=&%R(#T@97AP;&]D92@B("(L('!R96=?<F5P;&%C92@B+UQS>S(L?2\B+"`B
M("(L(&EM<&QO9&4H(B`B+"`D9&%T82DI*3L*"B`@("`@("`@+R\@061D(&$@
M9F5W(&QO8V%L('9A<FEA8FQE<R!F;W(@9&%T82!P<F]C97-S:6YG"B`@("`@
M("`@)'1R96YD0V]U;G0@/2`P.R`@("`@("`@("`@("`O+R!)9B!W92!H879E
M('1R96YD<RP@=V4@;F5E9"!T:&ES"B`@("`@("`@)'!O:6YT97(@("`@/28@
M)'=E871H97)$871A.R`O+R!0;VEN=&5R('1O('1H92!A<G)A>2!W92!A9&0@
M=&AE(&1A=&$@=&\*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)&UE=&%R*3L@)&DK*RD@>PH@("`@("`@("`@("`O+R!#:&5C:R!F;W(@=VAI
M=&5S<&%C92!A;F0@<W1E<"!L;V]P+"!I9B!N;W1H:6YG)W,@=&AE<F4*("`@
M("`@("`@("`@)&UE=&%R6R1I72`]('1R:6TH)&UE=&%R6R1I72D["B`@("`@
M("`@("`@(&EF("@A<W1R;&5N*"1M971A<ELD:5TI*2!["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*%-%4E9)0T537U=%051(15)?1$5"54<I('L*("`@("`@("`@("`@("`@("1T
M86(@/2!S=')?<F5P96%T*")<="(L(#(@+2!F;&]O<B@H<W1R;&5N*"1M971A
M<ELD:5TI("L@,BD@+R`X*2D["B`@("`@("`@("`@("`@("!E8VAO(")<(B(N
M)&UE=&%R6R1I72XB7"(B+B1T86(N(BT^("(["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\O($EN:71I86QI>F4@<V]M92!A<G)A>7,*("`@("`@("`@
M("`@)')E<W5L="`@(#T@87)R87DH*3L*("`@("`@("`@("`@)')E<W5L=%9&
M(#T@87)R87DH*3L*("`@("`@("`@("`@)&QR97-U;'0@(#T@87)R87DH*3L*
M"B`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("`@("!F;W)E
M86-H("@D;65T87)#;V1E(&%S("1K97D@/3X@)')E9V5X<"D@>PH@("`@("`@
M("`@("`@("`@+R\@0VAE8VL@:68@8W5R<F5N="!C;V1E(&UA=&-H97,@8W5R
M<F5N="!M971A<B!S;FEP<&5T"B`@("`@("`@("`@("`@("!I9B`H*"1F;W5N
M9"`]('!R96=?;6%T8V@H(B]>(BXD<F5G97AP+B(D+VDB+"`D;65T87);)&E=
M+"`D<F5S=6QT*2D@/3T@=')U92D@>PH@("`@("`@("`@("`@("`@("`@('-W
M:71C:"`H)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")S
M=&%T:6]N(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)S=&%T:6]N(ET@/2`D<F5S=6QT6S!=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB<W1A=&EO;B)=*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E(")W:6YD(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(%!A<G-E('=I;F0@9&%T82P@9FER<W0@=&AE('-P965D+"!C;VYV
M97)T(&9R;VT@:W0@=&\@8VAO<V5N('5N:70*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)W:6YD(ET@/2`D=&AI<RT^8V]N=F5R=%-P
M965D*"1R97-U;'1;,ETL('-T<G1O;&]W97(H)')E<W5L=%LU72DL(")M<&@B
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=
M(#T](")605(B('Q\("1R97-U;'1;,5T@/3T@(E920B(I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!687)I86)L92!W:6YD<PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&5G
M<F5E<R)=("`@/2`B5F%R:6%B;&4B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&ER96-T:6]N(ET@/2`B5F%R:6%B
M;&4B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!3879E('=I;F0@9&5G
M<F5E(&%N9"!C86QC(&1I<F5C=&EO;@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&5G<F5E<R)=("`@/2!I;G1V86PH
M)')E<W5L=%LQ72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(G=I;F1$:7)E8W1I;VXB72`]("1C;VUP87-S6W)O=6YD*"1R
M97-U;'1;,5T@+R`R,BXU*2`E(#$V73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N
M=6UE<FEC*"1R97-U;'1;-%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@5VEN9"!W:71H(&=U<W1S+BXN"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1'=7-T(ET@/2`D=&AI
M<RT^8V]N=F5R=%-P965D*"1R97-U;'1;-%TL('-T<G1O;&]W97(H)')E<W5L
M=%LU72DL(")M<&@B*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E(")W:6YD5F%R(CH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O($]N8V4@;6]R92!W:6YD+"!N;W<@=F%R:6%B:6QI
M='D@87)O=6YD('1H92!C=7)R96YT('=I;F0M9&ER96-T:6]N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=VEN9%9A<FEA8FEL:71Y
M(ET@/2!A<G)A>2@B9G)O;2(@/3X@:6YT=F%L*"1R97-U;'1;,5TI+"`B=&\B
M(#T^(&EN='9A;"@D<F5S=6QT6S)=*2D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M=FES1G)A8R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0;W-S
M:6)L92!F<F%C=&EO;F%L('9I<VEB:6QI='D@:&5R92X@0VAE8VL@:68@:70@
M;6%T8VAE<R!W:71H('1H92!N97AT($U%5$%2('!I96-E(&9O<B!V:7-I8FEL
M:71Y"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1M
M971A<ELD:2`K(#%=*2!\?"`A<')E9U]M871C:"@B+UXB+B1M971A<D-O9&5;
M(G9I<VEB:6QI='DB72XB)"]I(BP@)')E<W5L=%LQ72XB("(N)&UE=&%R6R1I
M("L@,5TL("1R97-U;'161BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!.;R!N97AT($U%5$%2('!I96-E(&%V86EL86)L92!O<B!N
M;W0@;6%T8VAI;F<N($UA=&-H(&%G86EN<W0@;F5X="!-151!4B!C;V1E"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($UA=&-H+B!(86YD(&]V97(@<F5S=6QT
M(&%N9"!A9'9A;F-E($U%5$%2"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*%-%4E9)0T537U=%051(15)?1$5"54<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`D:V5Y+B)<;B(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@(EPB(BXD
M<F5S=6QT6S%=+B(@(BXD;65T87);)&D@*R`Q72XB7"(B+G-T<E]R97!E870H
M(EQT(BP@,B`M(&9L;V]R*"AS=')L96XH)')E<W5L=%LQ72XB("(N)&UE=&%R
M6R1I("L@,5TI("L@,BD@+R`X*2DN(BT^("(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1K97D@/2`B=FES:6)I;&ET>2(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1R97-U;'161CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V:7-I
M8FEL:71Y(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)V:7-1=6%L:69I97(B72`](")!5"(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S%=*2`F)B`H)')E<W5L
M=%LQ72`]/2`Y.3DY*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(%5P<&5R(&QI;6ET(&]F('9I<VEB:6QI='D@<F%N9V4*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H,3`L(")K;2(L(")S;2(I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B
M72`](")"15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*&ES7VYU;65R:6,H)')E<W5L=%LQ72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R`T+61I9VET('9I<VEB:6QI='D@:6X@
M;0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@H)')E<W5L=%LQ72\Q,#`P*2P@
M(FMM(BP@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H(6ES<V5T*"1R97-U;'1;,3%=*2!\?"`D<F5S=6QT6S$Q72`A/2`B
M0T%63TLB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1R97-U;'1;,UT@/3T@(DTB*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"14Q/
M5R(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1R97-U;'1;,UT@/3T@(E`B*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"15E/
M3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<F5S
M=6QT6S5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!V:7-I8FEL:71Y(&%S(&]N92]T=V\M9&EG:70@;G5M8F5R"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y(#T@
M)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6S5=+"`D<F5S=6QT6S$P
M72P@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M=&AE('DO>B!P87)T+"!A9&0@:68@=V4@:&%D(&$@>"!P87)T("AS964@=FES
M:6)I;&ET>3$I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;-UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LW72`K("1R97-U;'1;.%T@+R`D
M<F5S=6QT6SE=+"`D<F5S=6QT6S$P72P@(G-M(BD["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LX72`O("1R97-U;'1;.5TL("1R
M97-U;'1;,3!=+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI9FEE
M<B)=(#T@(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*#$P+"`B
M:VTB+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&]I;G1E<ELB8VQO=61S(ET@/2!A<G)A>2AA<G)A>2@B86UO=6YT(B`]/B`B
M0VQE87(@8F5L;W<B+"`B:&5I9VAT(B`]/B`U,#`P*2D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=(#T@
M(FYO('-I9VYI9FEC86YT('=E871H97(B.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G9I<VEB:6QI='DB72`]("1V:7-I8FEL:71Y.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@(F-O;F1I=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!&:7)S="!S;VUE(&)A<VEC('-E='5P<PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);
M(F-O;F1I=&EO;B)=(#T@(B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H<W1R;&5N*"1P;VEN=&5R6R)C;VYD:71I;VXB72D@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);
M(F-O;F1I=&EO;B)=("X]("(L(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?87)R
M87DH<W1R=&]L;W=E<B@D<F5S=6QT6S!=*2P@)&-O;F1I=&EO;G,I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1FER<W0@=')Y(&UA
M=&-H:6YG('1H92!C;VUP;&5T92!S=')I;F<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@+CT@(B`B+B1C
M;VYD:71I;VYS6W-T<G1O;&]W97(H)')E<W5L=%LP72E=.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!.;R!L=6-K+"!M871C:"!P87)T(&)Y('!A<G0*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]S:&EF="@D
M<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@87)R87E?=6YI<75E*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@87,@)&-O;F1I=&EO
M;BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M<W1R;&5N*"1C;VYD:71I;VXI(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=("X]
M("(@(BXD8V]N9&ET:6]N<UMS=')T;VQO=V5R*"1C;VYD:71I;VXI73L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)C;VYD:71I;VXB72`]('1R:6TH)'!O:6YT97);(F-O;F1I=&EO;B)=*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E(")C;&]U9',B.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D<&]I;G1E<ELB8VQO=61S(ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-L
M;W5D<R)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1R
M97-U;'0I(#T](#4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!/;FQY(&%M;W5N="!A;F0@:&5I9VAT"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-L;W5D(#T@87)R87DH(F%M;W5N="(@/3X@)&-L
M;W5D<UMS=')T;VQO=V5R*"1R97-U;'1;,UTI72P@(FAE:6=H="(@/3X@*"1R
M97-U;'1;-%TJ,3`P*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;'-E:68@*'-I>F5O9B@D
M<F5S=6QT*2`]/2`V*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@06UO=6YT+"!H96EG:'0@86YD('1Y<&4*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8VQO=60@/2!A<G)A>2@B86UO=6YT(B`]/B`D
M8VQO=61S6W-T<G1O;&]W97(H)')E<W5L=%LS72E=+"`B:&5I9VAT(B`]/B`H
M)')E<W5L=%LT72HQ,#`I+"`B='EP92(@/3X@)&-L;W5D<UMS=')T;VQO=V5R
M*"1R97-U;'1;-5TI72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!32T,@;W(@0TQ2(&]R($Y30PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`](&%R<F%Y
M*")A;6]U;G0B(#T^("1C;&]U9'-;<W1R=&]L;W=E<B@D<F5S=6QT6S!=*5TI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O:6YT97);(F-L;W5D<R)=6UT@/2`D8VQO=60[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`B=&5M<&5R871U<F4B.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@;F]R;6%L('1E;7!E<F%T=7)E(&EN(&9I
M<G-T('!A<G0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&YE9V%T
M:79E('9A;'5E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E
M<W5L=%LQ72`]/2`B32(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT6S)=("H]("TQ.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);
M(G1E;7!E<F%T=7)E(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R
M97-U;'1;,ETL(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AS:7IE;V8H)')E<W5L="D@/B`T*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@<V%M92!F;W(@9&5W<&]I;G0*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LT72`]/2`B
M32(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E
M<W5L=%LU72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);
M(F1E=U!O:6YT(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U
M;'1;-5TL(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB:'5M:61I='DB72`]("1T:&ES+3YC86QC=6QA=&5(
M=6UI9&ET>2@D<F5S=6QT6S)=+"`D<F5S=6QT6S5=*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&]I;G1E<ELB=VEN9")=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($YO=R!C86QC=6QA=&4@=VEN9&-H:6QL
M(&9R;VT@=&5M<&5R871U<F4@86YD('=I;F1S<&5E9`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)F96QT5&5M<&5R871U<F4B
M72`]("1T:&ES+3YC86QC=6QA=&57:6YD0VAI;&PH)'!O:6YT97);(G1E;7!E
M<F%T=7)E(ETL("1P;VEN=&5R6R)W:6YD(ETI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G!R97-S=7)E(CH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T]
M(")!(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%!R
M97-S=7)E('!R;W9I9&5D(&EN(&EN8VAE<PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)P<F5S<W5R92)=(#T@)')E<W5L=%LR
M72`O(#$P,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("@D<F5S=6QT6S-=(#T](")1(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O("XN+B!I;B!H96-T;W!A<V-A;`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)P<F5S<W5R92)=(#T@)'1H
M:7,M/F-O;G9E<G10<F5S<W5R92@D<F5S=6QT6S1=+"`B:'!A(BP@(FEN(BD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B=')E;F0B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M5V4@;6%Y(&AA=F4@82!T<F5N9"!H97)E+BXN(&5X=')A8W0@='EP92!A;F0@
M<V5T('!O:6YT97(@;VX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&-R96%T960@;F5W(&%R<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1W96%T:&5R1&%T85LB=')E;F0B72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G1R96YD
M(ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1W96%T:&5R1&%T85LB=')E;F0B75LD=')E;F1#;W5N=%T@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O:6YT97(@/28@)'=E871H97)$871A6R)T<F5N
M9")=6R1T<F5N9$-O=6YT73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T<F5N9$-O=6YT*RL["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&]I;G1E<ELB='EP92)=(#T@)')E<W5L=%LP73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('=H:6QE("AI<W-E="@D;65T87);)&D@*R`Q72D@)B8@
M<')E9U]M871C:"@B+UXH1DU\5$Q\050I*%QD>S)]*2A<9'LR?2DD+VDB+"`D
M;65T87);)&D@*R`Q72P@)&QR97-U;'0I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1L<F5S=6QT6S%=(#T](")&32(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F9R
M;VTB72`]("1L<F5S=6QT6S)=+B(Z(BXD;')E<W5L=%LS73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QR97-U;'1;,5T@
M/3T@(E1,(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB=&\B72`]("1L<F5S=6QT6S)=+B(Z(BXD;')E<W5L=%LS
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB
M870B72`]("1L<F5S=6QT6S)=+B(Z(BXD;')E<W5L=%LS73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@07,@=V4@:&%V92!J=7-T(&5X=')A8W1E9"!T:&4@
M=&EM92!F;W(@=&AI<R!T<F5N9`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O(&9R;VT@;W5R($U%5$%2+"!I;F-R96%S92!F:65L9"UC;W5N
M=&5R"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M(")R96UA<FLB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4F5M
M87)K('!A<G0@8F5G:6YS"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;65T87)#;V1E(#T@)')E;6%R:W,["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E(")A=71O<W1A=&EO;B(Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!7:&EC:"!A=71O<W1A=&EO;B!D;R!W92!H879E(&AE
M<F4_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ
M72`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E
M871H97)$871A6R)R96UA<FLB75LB875T;W-T871I;VXB72`](")!=71O;6%T
M:6,@=V5A=&AE<G-T871I;VX@=R]O('!R96-I<&ET871I;VX@9&ES8W)I;6EN
M871O<B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB
M<F5M87)K(EU;(F%U=&]S=&%T:6]N(ET@/2`B075T;VUA=&EC('=E871H97)S
M=&%T:6]N('<O('!R96-I<&ET871I;VX@9&ES8W)I;6EN871O<B(["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D;65T87)#;V1E6R)A=71O<W1A=&EO;B)=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E(")P<F5S<V-H9R(Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!$96-O9&EN9R!F;W(@<F%P:60@<')E<W-U<F4@8VAA
M;F=E<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W
M97(H)')E<W5L=%LQ72D@/3T@(G(B*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB75LB<')E<W-C:&<B
M72`](")0<F5S<W5R92!R:7-I;F<@<F%P:61L>2(["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G!R97-S8VAG(ET@
M/2`B4')E<W-U<F4@9F%L;&EN9R!R87!I9&QY(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1M971A<D-O9&5;(G!R97-S8VAG(ETI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(G-E87!R97-S=7)E(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%!R97-S=7)E(&%T('-E82!L979E;"`H9&5L:79E<F5D(&EN(&AP82D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($1E8V]D:6YG(&ES(&$@
M8FET(&]B<V-U<F4@87,@.3@R(&=E=',@.3DX+C(*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O('=H97)E87,@,3$S(&)E8V]M97,@,3$Q,R`M/B!N
M;R!R96%L(')U;&4@:&5R90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*'-T<G1O;&]W97(H)')E<W5L=%LQ72D@(3T@(FYO(BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#X@-3`P
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5S
M<R`](#DP,"`K(')O=6YD*"1R97-U;'1;,5T@+R`Q,#`L(#$I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5S<R`](#$P,#`@*R`D<F5S
M=6QT6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E
M;6%R:R)=6R)S96%P<F5S<W5R92)=(#T@)'1H:7,M/F-O;G9E<G10<F5S<W5R
M92@D<')E<W,L(")H<&$B+"`B:6XB*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M
M971A<D-O9&5;(G-E87!R97-S=7)E(ETI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G!R96-I<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0<F5C
M:7!I=&%T:6]N(&EN(&EN8VAE<PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1A=&EC("1H;W5R<SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'=E871H97)$871A6R)P<F5C:7!I=&%T:6]N(ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A
M6R)P<F5C:7!I=&%T:6]N(ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1H;W5R<R`](&%R<F%Y*")0(B`]/B`B,2(L("(V
M(B`]/B`B,R\V(BP@(C<B(#T^("(R-"(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<U]N=6UE<FEC*"1R97-U;'1;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R96-I<"`](")I;F1E=&5R;6EN86)L92(["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E<W5L=%LR72`]
M/2`B,#`P,"(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')E8VEP(#T@(G1R86-E86)L92(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!R96-I<"`]("1R97-U;'1;,ET@+R`Q,#`["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A
M=&AE<D1A=&%;(G!R96-I<&ET871I;VXB75M=(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(F%M;W5N="(@/3X@)'!R96-I<"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B:&]U<G,B("`]/B`D
M:&]U<G-;)')E<W5L=%LQ75T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B<VYO=V1E<'1H(CH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%-N;W<@9&5P=&@@:6X@:6YC:&5S"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R
M:R)=6R)S;F]W9&5P=&@B72`]("1R97-U;'1;,5T["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R)S;F]W9&5P=&@B72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`B<VYO=V5Q=6EV(CH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%-A;64@9F]R(&5Q=6EV86QE;G0@:6X@5V%T
M97(N+BX@*&EN8VAE<RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M96%T:&5R1&%T85LB<F5M87)K(EU;(G-N;W=E<75I=B)=(#T@)')E<W5L=%LQ
M72`O(#$P.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE
M=&%R0V]D95LB<VYO=V5Q=6EV(ETI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(F-L
M;W5D='EP97,B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@0VQO
M=60@='EP97,L(&AA=F5N)W0@9F]U;F0@82!W87D@9F]R(&1E8V5N="!D96-O
M9&EN9R`H>65T*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H
M)&UE=&%R0V]D95LB8VQO=61T>7!E<R)=*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M(")S=6YD=7)A=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!$=7)A=&EO;B!O9B!S=6YS:&EN92`H:6X@;6EN=71E<RD*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G-U
M;F1U<F%T:6]N(ET@/2`B5&]T86P@;6EN=71E<R!O9B!S=6YS:&EN93H@(BXD
M<F5S=6QT6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H
M)&UE=&%R0V]D95LB<W5N9'5R871I;VXB72D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`B,6AT96UP9&5W(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(%1E;7!E<F%T=7)E<R!I;B!T:&4@;&%S="!H;W5R(&EN($,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T]("(Q(BD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;,ET@*CT@
M+3$["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R(Q:'1E
M;7`B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L=%LR72`O
M(#$P+"`B8R(L(")F(BD["@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*'-I>F5O9B@D<F5S=6QT*2`^(#,I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!S86UE(&9O<B!D97=P;VEN=`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S1=(#T]("(Q(BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT
M6S5=("H]("TQ.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;
M(G)E;6%R:R)=6R(Q:&1E=R)=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R
M92@D<F5S=6QT6S5=("\@,3`L(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1M971A<D-O9&5;(C%H=&5M<&1E=R)=*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("(V:&UA>'1E;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@36%X('1E;7!E<F%T=7)E(&EN('1H92!L87-T(#8@:&]U<G,@:6X@0PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@
M(C$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L
M=%LR72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K
M(EU;(C9H;6%X=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D
M<F5S=6QT6S)=("\@,3`L(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C9H;6%X=&5M<")=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("(V:&UI;G1E;7`B.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@36EN('1E;7!E<F%T=7)E(&EN('1H92!L87-T(#8@
M:&]U<G,@:6X@0PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R
M97-U;'1;,5T@/3T@(C$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<W5L=%LR72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R
M1&%T85LB<F5M87)K(EU;(C9H;6EN=&5M<")=(#T@)'1H:7,M/F-O;G9E<G14
M96UP97)A='5R92@D<F5S=6QT6S)=("\@,3`L(")C(BP@(F8B*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C9H;6EN
M=&5M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E("(R-&AT96UP(CH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O($UA>"]-:6X@=&5M<&5R871U<F5S
M(&EN('1H92!L87-T(#(T(&AO=7)S(&EN($,*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T]("(Q(BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;,ET@*CT@+3$["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R(R-&AM87AT96UP(ET@
M/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;,ET@+R`Q,"P@
M(F,B+"`B9B(I.PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M<F5S=6QT6S-=(#T]("(Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R97-U;'1;-%T@*CT@+3$["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<D1A=&%;(G)E;6%R:R)=6R(R-&AM:6YT96UP(ET@/2`D=&AI<RT^8V]N=F5R
M=%1E;7!E<F%T=7)E*"1R97-U;'1;-%T@+R`Q,"P@(F,B+"`B9B(I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB,C1H
M=&5M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E("(S:'!R97-S=&5N9"(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!792!D;VXG="!S879E('1H
M92!P<F5S<W5R92!D=7)I;F<@=&AE(&1A>2P@<V\@;F\@9&5C;V1I;F<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O('!O<W-I8FQE+"!S;W)R>0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB
M,VAP<F5S<W1E;F0B72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B;F]S<&5C:2(Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!.;R!C:&%N9V4@9'5R
M:6YG('1H92!L87-T(&AO=7(*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1W96%T:&5R1&%T85LB<F5M87)K(EU;(FYO<W!E8VDB72`](").;R!C:&%N
M9V5S(&EN('=E871H97(@8V]N9&ET:6]N<R(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R)N;W-P96-I(ETI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@(G-E;G-O<G,B.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@5V4@;6%Y(&AA=F4@;75L=&EP;&4@8G)O:V5N('-E;G-O
M<G,L('-O(&1O(&YO="!U;G-E=`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S96YS;W)S
M(ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H
M97)$871A6R)R96UA<FLB75LB<V5N<V]R<R)=(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G-E;G-O<G,B75MS=')T
M;VQO=V5R*"1R97-U;'1;,%TI72`]("1S96YS;W)S6W-T<G1O;&]W97(H)')E
M<W5L=%LP72E=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FUA:6YT86EN(CH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K
M(EU;(FUA:6YT86EN(ET@/2`B36%I;G1A:6YA;F-E(&YE961E9"(["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R)M86EN
M=&%I;B)=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@1&\@;F]T:&EN9RP@:G5S="!P<F5V96YT(&9U
M<G1H97(@;6%T8VAI;F<*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1M971A<D-O9&5;)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D9F]U;F0@)B8@(5-%4E9)0T537U=%051(15)?1$5"
M54<I('L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1F;W5N9"`F)B!315)624-%4U]714%4
M2$527T1%0E5'*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&ME
M>2XB7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@
M(&EF("A315)624-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@("`@
M("`@("`@96-H;R`B;B]A7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=V5A=&AE<D1A=&%;(FYO<&%R<V4B72DI
M('L*("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(FYO<&%R<V4B
M72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=V5A=&AE<D1A=&%;(FYO<&%R<V4B75M=(#T@)&UE=&%R6R1I73L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1W96%T
M:&5R1&%T85LB;F]P87)S92)=*2D@>PH@("`@("`@("`@("`D=V5A=&AE<D1A
M=&%;(FYO<&%R<V4B72`](&EM<&QO9&4H(B`B+"`@)'=E871H97)$871A6R)N
M;W!A<G-E(ETI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1W96%T:&5R
M1&%T83L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?<&%R<V5&;W)E
M8V%S=$1A=&$H*0H@("`@+RHJ"B`@("`@*B!087)S97,@=&AE(&1A=&$@86YD
M(&-A8VAE<R!I=`H@("`@("H*("`@("`J(%1!1B!+3$=!(#(W,3<S-%H@,C<Q
M.#$X(#$Q,#`W2U0@4#9332`M4D$@4T-4,#(P($)+3C(P,`H@("`@("H@("`@
M($9-,C,P,"`Q-#`P-TM4(%`V4TT@4T-4,#,P($)+3C$U,`H@("`@("H@("`@
M($9-,#0P,"!64D(P,TM4(%`V4TT@4T-4,#,U($]60S`X,"!04D]",S`@,#4P
M.2!0-E--("U202!"2TXP,S4*("`@("`J("`@("!&33`Y,#`@5E)",#-+5"`V
M4TT@+5)!($)2(%-#5#`Q-2!/5D,P,S4*("`@("`J("`@("`@("`@5$5-4$\@
M,3(Q-2`U4TT@+5)!($)2(%-#5#`P.2!"2TXP,34*("`@("`J("`@("`@("`@
M0D5#34<@,34Q-R`Q-C`P-TM4(%`V4TT@3E-7(%-#5#`Q-2!"2TXP-S`*("`@
M("`J"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&$*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87D*("`@
M("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<&%R<V5&;W)E8V%S=$1A=&$H)&1A=&$I"B`@("!["B`@("`@("`@<W1A=&EC
M("1C;VUP87-S.PH@("`@("`@('-T871I8R`D8VQO=61S.PH@("`@("`@('-T
M871I8R`D8V]N9&ET:6]N<SL*("`@("`@("!S=&%T:6,@)'-E;G-O<G,["B`@
M("`@("`@:68@*"%I<W-E="@D8V]M<&%S<RDI('L*("`@("`@("`@("`@)&-O
M;7!A<W,@/2!A<G)A>2@*("`@("`@("`@("`@("`@(").(BP@(DY.12(L(").
M12(L(")%3D4B+`H@("`@("`@("`@("`@("`@(D4B+"`B15-%(BP@(E-%(BP@
M(E-312(L"B`@("`@("`@("`@("`@("`B4R(L(")34U<B+"`B4U<B+"`B5U-7
M(BP*("`@("`@("`@("`@("`@(")7(BP@(E=.5R(L(").5R(L(").3E<B"B`@
M("`@("`@("`@("D["B`@("`@("`@("`@("1C;&]U9',@("`@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@(")S:V,B("`@("`@("`@/3X@(G-K>2!C;&5A<B(L
M"B`@("`@("`@("`@("`@("`B;G-C(B`@("`@("`@(#T^(")N;R!S:6=N:69I
M8V%N="!C;&]U9"(L"B`@("`@("`@("`@("`@("`B9F5W(B`@("`@("`@(#T^
M(")F97<B+`H@("`@("`@("`@("`@("`@(G-C="(@("`@("`@("`]/B`B<V-A
M='1E<F5D(BP*("`@("`@("`@("`@("`@(")B:VXB("`@("`@("`@/3X@(F)R
M;VME;B(L"B`@("`@("`@("`@("`@("`B;W9C(B`@("`@("`@(#T^(")O=F5R
M8V%S="(L"B`@("`@("`@("`@("`@("`B=G8B("`@("`@("`@(#T^(")V97)T
M:6-A;"!V:7-I8FEL:71Y(BP*("`@("`@("`@("`@("`@(")T8W4B("`@("`@
M("`@/3X@(E1O=V5R:6YG($-U;75L=7,B+`H@("`@("`@("`@("`@("`@(F-B
M(B`@("`@("`@("`]/B`B0W5M=6QO;FEM8G5S(BP*("`@("`@("`@("`@("`@
M(")C;'(B("`@("`@("`@/3X@(F-L96%R(&)E;&]W(#$R+#`P,"!F="(*("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@)&-O;F1I=&EO;G,@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("(K(B`@("`@("`@("`@/3X@(FAE879Y(BP@("`@
M("`@("(M(B`@("`@("`@("`@/3X@(FQI9VAT(BP*"B`@("`@("`@("`@("`@
M("`B=F,B("`@("`@("`@(#T^(")V:6-I;FET>2(L("`@("`B<F4B("`@("`@
M("`@(#T^(")R96-E;G0B+`H@("`@("`@("`@("`@("`@(FYS=R(@("`@("`@
M("`]/B`B;F\@<VEG;FEF:6-A;G0@=V5A=&AE<B(L"@H@("`@("`@("`@("`@
M("`@(FUI(B`@("`@("`@("`]/B`B<VAA;&QO=R(L("`@("`@(F)C(B`@("`@
M("`@("`]/B`B<&%T8VAE<R(L"B`@("`@("`@("`@("`@("`B<'(B("`@("`@
M("`@(#T^(")P87)T:6%L(BP@("`@("`B=',B("`@("`@("`@(#T^(")T:'5N
M9&5R<W1O<FTB+`H@("`@("`@("`@("`@("`@(F)L(B`@("`@("`@("`]/B`B
M8FQO=VEN9R(L("`@("`@(G-H(B`@("`@("`@("`]/B`B<VAO=V5R<R(L"B`@
M("`@("`@("`@("`@("`B9'(B("`@("`@("`@(#T^(")L;W<@9')I9G1I;F<B
M+"`B9GHB("`@("`@("`@(#T^(")F<F5E>FEN9R(L"@H@("`@("`@("`@("`@
M("`@(F1Z(B`@("`@("`@("`]/B`B9')I>GIL92(L("`@("`@(G)A(B`@("`@
M("`@("`]/B`B<F%I;B(L"B`@("`@("`@("`@("`@("`B<VXB("`@("`@("`@
M(#T^(")S;F]W(BP@("`@("`@("`B<V<B("`@("`@("`@(#T^(")S;F]W(&=R
M86EN<R(L"B`@("`@("`@("`@("`@("`B:6,B("`@("`@("`@(#T^(")I8V4@
M8W)Y<W1A;',B+"`B<&4B("`@("`@("`@(#T^(")I8V4@<&5L;&5T<R(L"B`@
M("`@("`@("`@("`@("`B9W(B("`@("`@("`@(#T^(")H86EL(BP@("`@("`@
M("`B9W,B("`@("`@("`@(#T^(")S;6%L;"!H86EL+W-N;W<@<&5L;&5T<R(L
M"B`@("`@("`@("`@("`@("`B=7`B("`@("`@("`@(#T^(")U;FMN;W=N('!R
M96-I<&ET871I;VXB+`H*("`@("`@("`@("`@("`@(")B<B(@("`@("`@("`@
M/3X@(FUI<W0B+"`@("`@("`@(")F9R(@("`@("`@("`@/3X@(F9O9R(L"B`@
M("`@("`@("`@("`@("`B9G4B("`@("`@("`@(#T^(")S;6]K92(L("`@("`@
M("`B=F$B("`@("`@("`@(#T^(")V;VQC86YI8R!A<V@B+`H@("`@("`@("`@
M("`@("`@(G-A(B`@("`@("`@("`]/B`B<V%N9"(L("`@("`@("`@(FAZ(B`@
M("`@("`@("`]/B`B:&%Z92(L"B`@("`@("`@("`@("`@("`B<'DB("`@("`@
M("`@(#T^(")S<')A>2(L("`@("`@("`B9'4B("`@("`@("`@(#T^(")W:61E
M<W!R96%D(&1U<W0B+`H*("`@("`@("`@("`@("`@(")S<2(@("`@("`@("`@
M/3X@(G-Q=6%L;"(L("`@("`@(")S<R(@("`@("`@("`@/3X@(G-A;F1S=&]R
M;2(L"B`@("`@("`@("`@("`@("`B9',B("`@("`@("`@(#T^(")D=7-T<W1O
M<FTB+"`@("`B<&\B("`@("`@("`@(#T^(")W96QL(&1E=F5L;W!E9"!D=7-T
M+W-A;F0@=VAI<FQS(BP*("`@("`@("`@("`@("`@(")F8R(@("`@("`@("`@
M/3X@(F9U;FYE;"!C;&]U9"(L"@H@("`@("`@("`@("`@("`@(BMF8R(@("`@
M("`@("`]/B`B=&]R;F%D;R]W871E<G-P;W5T(@H@("`@("`@("`@("`I.PH@
M("`@("`@('T*"B`@("`@("`@)'1A9D-O9&4@/2!A<G)A>2@*("`@("`@("`@
M("`@(G)E<&]R="(@("`@("`]/B`B5$%&?$%-1"(L"B`@("`@("`@("`@(")S
M=&%T:6]N(B`@("`@/3X@(EQW>S1](BP*("`@("`@("`@("`@(G5P9&%T92(@
M("`@("`]/B`B*%QD>S)]*3\H7&1[-'TI6B(L"B`@("`@("`@("`@(")V86QI
M9"(@("`@("`@/3X@(BA<9'LR?2DH7&1[,GTI*%QD>S)]*2(L"B`@("`@("`@
M("`@(")W:6YD(B`@("`@("`@/3X@(BA<9'LS?7Q605)\5E)"*2A<9'LR+#-]
M*2A'*%QD>S)]*2D_*%QW>S(L,WTI(BP*("`@("`@("`@("`@(G9I<T9R86,B
M("`@("`]/B`B*%QD>S%]*2(L"B`@("`@("`@("`@(")V:7-I8FEL:71Y(B`@
M/3X@(BA<9'LT?2E\*"A-?%`I/R@H7&1[,2PR?7PH*%QD*2`I/RA<9"E<+RA<
M9"DI*%--?$M-*2DI?"A#059/2RDB+`H@("`@("`@("`@("`B8V]N9&ET:6]N
M(B`@(#T^("(H+7Q<*WQ60WQ217Q.4U<I/RA-27Q"0WQ04GQ44WQ"3'Q32'Q$
M4GQ&6BD_*"A$6BE\*%)!*7PH4TXI?"A31RE\*$E#*7PH4$PI?"A'4BE\*$=3
M*7PH55`I*2HH0E)\1D=\1E5\5D%\1%5\4T%\2%I\4%DI/RA03WQ347Q&0WQ3
M4WQ$4RD_(BP*("`@("`@("`@("`@(F-L;W5D<R(@("`@("`]/B`B*%-+0WQ#
M3%)\3E-#?"@H1D57?%-#5'Q"2TY\3U9#?%96*2A<9'LS?2DH5$-5?$-"*3\I
M*2(L"B`@("`@("`@("`@(")W:6YD<VAE87(B("`@/3X@(E=3*%QD>S-]*5PO
M*%QD>S-]*2A<9'LR+#-]*2A<=WLR+#-]*2(L"B`@("`@("`@("`@(")T96UP
M;6%X(B`@("`@/3X@(E18*%QD>S)]*5PO*%QD>S)]*2A<=RDB+`H@("`@("`@
M("`@("`B=&5M<&UI;B(@("`@(#T^(")43BA<9'LR?2E<+RA<9'LR?2DH7'<I
M(BP*("`@("`@("`@("`@(G1E;7!M87AM:6XB("`]/B`B5%@H7&1[,GTI7"\H
M7&1[,GTI*%QW*51.*%QD>S)]*5PO*%QD>S)]*2A<=RDB+`H@("`@("`@("`@
M("`B9G)O;2(@("`@("`@(#T^(")&32A<9'LR?2DH7&1[,GTI/R(L"B`@("`@
M("`@("`@(")F;6,B("`@("`@("`@/3X@(BA04D]"?$)%0TU'?%1%35!/*2A<
M9'LR?2D_(@H@("`@("`@("D["@H@("`@("`@(&EF("A315)624-%4U]714%4
M2$527T1%0E5'*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I
M>F5O9B@D9&%T82D[("1I*RLI('L*("`@("`@("`@("`@("`@(&5C:&\@)&1A
M=&%;)&E=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O($]K
M+"!W92!H879E(&-O<G)E8W0@9&%T82P@<W1A<G0@=VET:"!P87)S:6YG('1H
M92!F:7)S="!L:6YE(&9O<B!T:&4@;&%S="!U<&1A=&4*("`@("`@("`D9F]R
M96-A<W1$871A(#T@87)R87DH*3L*("`@("`@("`D9F]R96-A<W1$871A6R)S
M=&%T:6]N(ET@("`]("(B.PH@("`@("`@("1F;W)E8V%S=$1A=&%;(F1A=&%2
M87<B72`@(#T@:6UP;&]D92@B("(L("1D871A*3L*("`@("`@("`D9F]R96-A
M<W1$871A6R)U<&1A=&4B72`@("`]('-T<G1O=&EM92AT<FEM*"1D871A6S!=
M*2XB($=-5"(I.PH@("`@("`@("1F;W)E8V%S=$1A=&%;(G5P9&%T95)A=R)=
M(#T@=')I;2@D9&%T85LP72D["B`@("`@("`@+R\@86YD('!R97!A<F4@=&AE
M(')E<W0@9F]R('-T97!P:6YG('1H<F]U9V@*("`@("`@("!A<G)A>5]S:&EF
M="@D9&%T82D["B`@("`@("`@)'1A9B`](&5X<&QO9&4H(B`B+"!P<F5G7W)E
M<&QA8V4H(B]<<WLR+'TO(BP@(B`B+"!I;7!L;V1E*"(@(BP@)&1A=&$I*2D[
M"@H@("`@("`@("\O($%D9"!A(&9E=R!L;V-A;"!V87)I86)L97,@9F]R(&1A
M=&$@<')O8V5S<VEN9PH@("`@("`@("1F<F]M5&EM92`]("`B(CL@("`@("`@
M("`@("`O+R!4:&4@=&EM97!E<FEO9"!T:&4@9&%T82!G971S(&%D9&5D('1O
M"B`@("`@("`@)&9M8T-O=6YT(#T@(#`[("`@("`@("`@("`@("\O($EF('=E
M(&AA=F4@1DU#<R`H1F]R96-A<W0@365T96]R;VQO9VEC86P@0V]N9&ET:6]N
M<RDL('=E(&YE960@=&AI<PH@("`@("`@("1P;VEN=&5R("`])B`D9F]R96-A
M<W1$871A.R`O+R!0;VEN=&5R('1O('1H92!A<G)A>2!W92!A9&0@=&AE(&1A
M=&$@=&\*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1A9BD[
M("1I*RLI('L*("`@("`@("`@("`@+R\@0VAE8VL@9F]R('=H:71E<W!A8V4@
M86YD('-T97`@;&]O<"P@:68@;F]T:&EN9R=S('1H97)E"B`@("`@("`@("`@
M("1T869;)&E=(#T@=')I;2@D=&%F6R1I72D["B`@("`@("`@("`@(&EF("@A
M<W1R;&5N*"1T869;)&E=*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("A315)624-%4U]714%4
M2$527T1%0E5'*2!["B`@("`@("`@("`@("`@("`D=&%B(#T@<W1R7W)E<&5A
M="@B7'0B+"`R("T@9FQO;W(H*'-T<FQE;B@D=&%F6R1I72D@*R`R*2`O(#@I
M*3L*("`@("`@("`@("`@("`@(&5C:&\@(EPB(BXD=&%F6R1I72XB7"(B+B1T
M86(N(BT^("(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($EN:71I
M86QI>F4@<V]M92!A<G)A>7,*("`@("`@("`@("`@)')E<W5L="`@(#T@87)R
M87DH*3L*("`@("`@("`@("`@)')E<W5L=%9&(#T@87)R87DH*3L*("`@("`@
M("`@("`@)&QR97-U;'0@(#T@87)R87DH*3L*"B`@("`@("`@("`@("1F;W5N
M9"`](&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H("@D=&%F0V]D92!A<R`D
M:V5Y(#T^("1R96=E>'`I('L*("`@("`@("`@("`@("`@("\O($-H96-K(&EF
M(&-U<G)E;G0@8V]D92!M871C:&5S(&-U<G)E;G0@=&%F('-N:7!P970*("`@
M("`@("`@("`@("`@(&EF("@H)&9O=6YD(#T@<')E9U]M871C:"@B+UXB+B1R
M96=E>'`N(B0O:2(L("1T869;)&E=+"`D<F5S=6QT*2D@/3T@=')U92D@>PH@
M("`@("`@("`@("`@("`@("`@("1I;G-E<G0@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E(")S=&%T:6]N(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)S=&%T:6]N(ET@/2`D<F5S=6QT6S!=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1A9D-O9&5;(G-T871I
M;VXB72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`B=F%L:60B.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9A;&ED4F%W(ET@/2`D<F5S
M=6QT6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1V5N97)A
M=&5S('1H92!T:6UE<&5R:6]D('1H92!R97!O<G0@:7,@=F%L:60@9F]R"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1Y96%R+"`D;6]N=&@L
M("1D87DI(#T@97AP;&]D92@B+2(L(&1A=&4H(EDM;2UD(BP@)&9O<F5C87-T
M1&%T85LB=7!D871E(ETI*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O($1A=&4@:7,@:6X@;F5X="!M;VYT:`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1R97-U;'1;,5T@/"`D9&%Y*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UO;G1H*RL["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&]I;G1E<ELB=F%L:61&<F]M(ET@/2!G;6UK=&EM92@D<F5S=6QT6S)=+"`P
M+"`P+"`D;6]N=&@L("1R97-U;'1;,5TL("1Y96%R*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%9A;&ED('1I;64@96YD<R!N97AT(&1A>0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,ET@/CT@
M)')E<W5L=%LS72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R97-U;'1;,5TK*SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V86QI9%1O
M(ET@("`](&=M;6MT:6UE*"1R97-U;'1;,UTL(#`L(#`L("1M;VYT:"P@)')E
M<W5L=%LQ72P@)'EE87(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=6YS970H)'1A9D-O9&5;(G9A;&ED(ETI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@3F]W('1H92!G<F]U<',@=VEL;"!S=&%R="P@<V\@:6YI
M=&EA;&EZ92!T:&4@=&EM92!G<F]U<',*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)T:6UE(ET@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9R;VU4:6UE(#T@)')E<W5L=%LR72XB.C`P
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)T:6UE
M(EU;)&9R;VU4:6UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!3970@<&]I;G1E<B!T;R!T:&4@9FER<W0@=&EM97!E<FEO
M9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97(@/28@)'!O
M:6YT97);(G1I;64B75LD9G)O;51I;65=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G=I;F0B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4&%R<V4@
M=VEN9"!D871A+"!F:7)S="!T:&4@<W!E960L(&-O;G9E<G0@9G)O;2!K="!T
M;R!C:&]S96X@=6YI=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G=I;F0B72`]("1T:&ES+3YC;VYV97)T4W!E960H)')E<W5L=%LR
M72P@<W1R=&]L;W=E<B@D<F5S=6QT6S5=*2P@(FUP:"(I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@(E9!4B(@?'P@
M)')E<W5L=%LQ72`]/2`B5E)"(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%9A<FEA8FQE('=I;F1S"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1$96=R965S(ET@("`](")6
M87)I86)L92(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G=I;F1$:7)E8W1I;VXB72`](")687)I86)L92(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%-A=F4@=VEN9"!D96=R964@86YD(&-A;&,@
M9&ER96-T:6]N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G=I;F1$96=R965S(ET@("`]("1R97-U;'1;,5T["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1$:7)E8W1I
M;VXB72`]("1C;VUP87-S6W)O=6YD*"1R97-U;'1;,5T@+R`R,BXU*2`E(#$V
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;-%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5VEN9"!W:71H
M(&=U<W1S+BXN"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G=I;F1'=7-T(ET@/2`D=&AI<RT^8V]N=F5R=%-P965D*"1R97-U
M;'1;-%TL('-T<G1O;&]W97(H)')E<W5L=%LU72DL(")M<&@B*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<')O8F%B:6QI='DI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F10<F]B(ET@/2`D
M<')O8F%B:6QI='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=6YS970H)'!R;V)A8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E(")V:7-&<F%C(CH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%!O<W-I8FQE(&9R86-T:6]N86P@=FES
M:6)I;&ET>2!H97)E+B!#:&5C:R!I9B!I="!M871C:&5S('=I=&@@=&AE(&YE
M>'0@5$%&('!I96-E(&9O<B!V:7-I8FEL:71Y"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T869;)&D@*R`Q72D@?'P@(7!R96=?
M;6%T8V@H(B]>(BXD=&%F0V]D95LB=FES:6)I;&ET>2)=+B(D+VDB+"`D<F5S
M=6QT6S%=+B(@(BXD=&%F6R1I("L@,5TL("1R97-U;'161BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!.;R!N97AT(%1!1B!P:65C
M92!A=F%I;&%B;&4@;W(@;F]T(&UA=&-H:6YG+B!-871C:"!A9V%I;G-T(&YE
M>'0@5$%&(&-O9&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]U;F0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@36%T8V@N($AA
M;F0@;W9E<B!R97-U;'0@86YD(&%D=F%N8V4@5$%&"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*%-%4E9)0T537U=%051(15)?1$5"54<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`D
M:V5Y+B)<;B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&5C:&\@(EPB(BXD<F5S=6QT6S%=+B(@(BXD=&%F6R1I("L@,5TN(EPB(BYS
M=')?<F5P96%T*")<="(L(#(@+2!F;&]O<B@H<W1R;&5N*"1R97-U;'1;,5TN
M(B`B+B1T869;)&D@*R`Q72D@*R`R*2`O(#@I*2XB+3X@(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&ME>2`](")V:7-I8FEL:71Y(CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)')E<W5L=%9&.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(G9I<VEB:6QI='DB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(G9I<U%U86QI9FEE<B)=(#T@(D%4(CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;,5TI("8F
M("@D<F5S=6QT6S%=(#T](#DY.3DI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@57!P97(@;&EM:70@;V8@=FES:6)I;&ET>2!R86YG
M90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@Q,"P@(FMM(BP@(G-M(BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U
M86QI9FEE<B)=(#T@(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S%=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(#0M9&EG:70@=FES:6)I
M;&ET>2!I;B!M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9I
M<VEB:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"@D<F5S=6QT6S%=
M+S$P,#`I+"`B:VTB+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@A:7-S970H)')E<W5L=%LQ,5TI('Q\("1R97-U;'1;
M,3%=("$](")#059/2R(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)')E<W5L=%LS72`]/2`B32(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI9FEE<B)=
M(#T@(D)%3$]7(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)')E<W5L=%LS72`]/2`B4"(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI9FEE<B)=
M(#T@(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE
M<FEC*"1R97-U;'1;-5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O('9I<VEB:6QI='D@87,@;VYE+W1W;RUD:6=I="!N=6UB
M97(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9I<VEB
M:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1R97-U;'1;-5TL("1R
M97-U;'1;,3!=+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!T:&4@>2]Z('!A<G0L(&%D9"!I9B!W92!H860@82!X('!A<G0@
M*'-E92!V:7-I8FEL:71Y,2D*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7VYU;65R:6,H)')E<W5L=%LW72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6S==("L@)')E<W5L
M=%LX72`O("1R97-U;'1;.5TL("1R97-U;'1;,3!=+"`B<VTB*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6SA=("\@)')E<W5L
M=%LY72P@)')E<W5L=%LQ,%TL(")S;2(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES
M475A;&EF:65R(ET@/2`B0D593TY$(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES+3YC;VYV97)T1&ES=&%N
M8V4H,3`L(")K;2(L(")S;2(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)C;&]U9',B72`](&%R<F%Y*&%R<F%Y*")A;6]U
M;G0B(#T^(")#;&5A<B!B96QO=R(L(")H96EG:'0B(#T^(#4P,#`I*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET
M:6]N(ET@/2`B;F\@<VEG;FEF:6-A;G0@=V5A=&AE<B(["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-0<F]B(ET@/2`D<')O8F%B
M:6QI='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H
M)'!R;V)A8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-I8FEL
M:71Y(ET@/2`D=FES:6)I;&ET>3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")C;VYD
M:71I;VXB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1FER<W0@
M<V]M92!B87-I8R!S971U<',*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'!O:6YT97);(F-O;F1I=&EO;B)=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB
M72`]("(B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*'-T<FQE;B@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI(#X@,"D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB
M72`N/2`B+"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*'-T<G1O;&]W
M97(H)')E<W5L=%LP72DL("1C;VYD:71I;VYS*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($9I<G-T('1R>2!M871C:&EN9R!T:&4@
M8V]M<&QE=&4@<W1R:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!O:6YT97);(F-O;F1I=&EO;B)=("X]("(@(BXD8V]N9&ET:6]N<UMS
M=')T;VQO=V5R*"1R97-U;'1;,%TI73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@3F\@;'5C:RP@;6%T8V@@<&%R="!B>2!P87)T"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)')E<W5L="D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="`](&%R<F%Y
M7W5N:7%U92@D<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1C;VYD:71I;VXI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D8V]N
M9&ET:6]N*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`N/2`B("(N)&-O;F1I
M=&EO;G-;<W1R=&]L;W=E<B@D8V]N9&ET:6]N*5T["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N
M(ET@/2!T<FEM*"1P;VEN=&5R6R)C;VYD:71I;VXB72D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD
M:71I;VXB72`N/2`B("@B+B1P<F]B86)I;&ET>2XB)2!P<F]B+BDB.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B86)I;&ET
M>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B8VQO=61S(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'!O:6YT97);(F-L;W5D<R)=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B72`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*'-I>F5O9B@D<F5S=6QT*2`]/2`U
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@3VYL>2!A
M;6]U;G0@86YD(&AE:6=H=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;&]U9"`](&%R<F%Y*")A;6]U;G0B(#T^("1C;&]U9'-;<W1R=&]L
M;W=E<B@D<F5S=6QT6S-=*5TL(")H96EG:'0B(#T^("@D<F5S=6QT6S1=("H@
M,3`P*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!E;'-E:68@*'-I>F5O9B@D<F5S=6QT*2`]
M/2`V*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@06UO
M=6YT+"!H96EG:'0@86YD('1Y<&4*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8VQO=60@/2!A<G)A>2@B86UO=6YT(B`]/B`D8VQO=61S6W-T
M<G1O;&]W97(H)')E<W5L=%LS72E=+"`B:&5I9VAT(B`]/B`H)')E<W5L=%LT
M72`J(#$P,"DL(")T>7!E(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H)')E<W5L
M=%LU72E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%-+0R!O<B!#3%(@;W(@3E-#"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-L;W5D(#T@87)R87DH(F%M;W5N
M="(@/3X@)&-L;W5D<UMS=')T;VQO=V5R*"1R97-U;'1;,%TI72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9BAI<W-E="@D<')O8F%B:6QI='DI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-L;W5D6R)P<F]B(ET@/2`D<')O8F%B
M:6QI='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H
M)'!R;V)A8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B
M75M=(#T@)&-L;W5D.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1S:&5A<B(Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!087)S92!W:6YD<VAE
M87(L(&EF(&%V86EL86)L90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(G=I;F1S:&5A<B)=("`@("`@("`@(#T@)'1H:7,M/F-O;G9E
M<G13<&5E9"@D<F5S=6QT6S-=+"!S=')T;VQO=V5R*"1R97-U;'1;-%TI+"`B
M;7!H(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB
M=VEN9'-H96%R2&5I9VAT(ET@("`@/2`D<F5S=6QT6S%=("H@,3`P.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1S:&5A<D1E
M9W)E97,B72`@(#T@)')E<W5L=%LR73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)W:6YD<VAE87)$:7)E8W1I;VXB72`]("1C;VUP
M87-S6W)O=6YD*"1R97-U;'1;,ET@+R`R,BXU*2`E(#$V73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")T96UP;6%X(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S=$1A=&%;(G1E;7!E<F%T=7)E2&EG:")=(#T@)'1H:7,M
M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT6S%=+"`B8R(L(")F(BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`B=&5M<&UI;B(Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!087)S92!M87@O;6EN('1E;7!E<F%T=7)E"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A6R)T96UP97)A
M='5R94QO=R)=("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L
M=%LQ72P@(F,B+"`B9B(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!M87AM
M:6XB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T
M85LB=&5M<&5R871U<F5(:6=H(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T
M=7)E*"1R97-U;'1;,5TL(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F;W)E8V%S=$1A=&%;(G1E;7!E<F%T=7)E3&]W(ET@(#T@
M)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT6S1=+"`B8R(L(")F
M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B9G)O;2(Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!.97AT('1I;65P97)I;V0@:7,@8V]M:6YG('5P
M+"!P<F5P87)E(&%R<F%Y(&%N9`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@<V5T('!O:6YT97(@86-C;W)D:6YG;'D*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AS:7IE;V8H)')E<W5L="D@/B`R*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5&AE($E#04\@=V%Y"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9R;VU4:6UE(#T@)')E
M<W5L=%LQ72XB.B(N)')E<W5L=%LR73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@5&AE($%U<W1R86QI86X@=V%Y("A(97D@;6%T97,A*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F<F]M5&EM92`]("1R97-U;'1;
M,5TN(CHP,"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A6R)T:6UE(EU;
M)&9R;VU4:6UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9FUC0V]U;G0@/2`P.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!O:6YT97(@/28@)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M5&EM
M95T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B9FUC(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%1E<W0L(&EF('1H:7,@:7,@82!P<F]B86)I;&ET
M>2!F;W(@=&AE(&YE>'0@1DU#"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@B+UY"14--1WQ414U03R0O:2(L("1T869;)&D@
M*R`Q72P@)&QR97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@4V5T('1Y<&4@=&\@0D5#34<@;W(@5$5-4$\*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("1L<F5S=6QT6S!=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%-E="!P<F]B86)I
M;&ET>0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F]B86)I
M;&ET>2`]("1R97-U;'1;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@3F]W(&5X=')A8W0@=&EM92!F;W(@=&AI<R!G<F]U<`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('!R96=?;6%T8V@H(B]>*%QD
M>S)]*2A<9'LR?2DD+VDB+"`D=&%F6R1I("L@,ETL("1L<F5S=6QT*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9G)O;2`]("1L<F5S=6QT
M6S%=+B(Z,#`B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M;R`@(#T@)&QR97-U;'1;,ETN(CHP,"(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1O("`@/2`H)'1O(#T]("(R-#HP,"(I(#\@(C`P.C`P
M(B`Z("1T;SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!!
M<R!W92!N;W<@:&%V92!T>7!E+"!P<F]B86)I;&ET>2!A;F0@=&EM92!F;W(@
M=&AI<R!&34,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!F
M<F]M(&]U<B!4048L(&EN8W)E87-E(&9I96QD+6-O=6YT97(*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2`K/2`R.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H(B]>*%QD>S)]
M*2A<9'LR?2DD+VDB+"`D=&%F6R1I("L@,5TL("1L<F5S=6QT*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($YO<FUA;"!G<F]U<"P@
M<V5T('1Y<&4@86YD('5S92!E>'1R86-T960@=&EM90H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)')E<W5L=%LQ73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!#:&5C:R!F;W(@4%)/0F1D
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R
M97-U;'1;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P<F]B86)I;&ET>2`]("1R97-U;'1;,ET["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F<F]M(#T@)&QR97-U;'1;,5TN(CHP,"(["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1O("`@/2`D;')E<W5L=%LR72XB.C`P
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&\@("`]("@D
M=&\@/3T@(C(T.C`P(BD@/R`B,#`Z,#`B(#H@)'1O.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%-A;64@87,@86)O=F4L('=E(&AA=F4@
M82!T:6UE(&9O<B!T:&ES($9-0R!F<F]M(&]U<B!4048L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@:6YC<F5A<V4@9FEE;&0M8V]U;G1E
M<@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I("L](#$["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%1H:7,@:7,@96ET:&5R(&$@4%)/
M0F1D(&]R(&$@;6%L9F]R;65D(%1!1@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<F5S=6QT6S)=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O8F%B:6QI='D@/2`D<F5S
M=6QT6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!(86YD;&4@=&AE($9-0RP@9V5N97)A=&4@;F5C8V5S
M<V%R>2!A<G)A>2!I9B!I="=S('1H92!F:7)S="XN+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T>7!E*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&9O<F5C87-T1&%T
M85LB=&EM92)=6R1F<F]M5&EM95U;(F9M8R)=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A6R)T:6UE(EU;
M)&9R;VU4:6UE75LB9FUC(ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W1$871A6R)T:6UE(EU;)&9R;VU4:6UE75LB9FUC(EU;
M)&9M8T-O=6YT72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@+BXN86YD('-E="!P;VEN=&5R+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R(#TF("1F;W)E8V%S=$1A=&%;
M(G1I;64B75LD9G)O;51I;65=6R)F;6,B75LD9FUC0V]U;G1=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;6-#;W5N="LK.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O($EN<V5R="!D871A"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G1Y<&4B72`]
M("1T>7!E.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN
M=&5R6R)F<F]M(ET@/2`D9G)O;3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&]I;G1E<ELB=&\B72`@(#T@)'1O.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1T>7!E+"`D9G)O;2P@)'1O*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!R
M;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB<')O8F%B:6QI='DB72`]("1P<F]B86)I;&ET>3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!R
M;V)A8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($1O(&YO
M=&AI;F<*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&9O
M=6YD("8F("%315)624-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("@D9F]U;F0@)B8@4T525DE#15-?5T5!5$A%4E]$14)51RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!E8VAO("1K97DN(EQN(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("!I9B`H4T525DE#15-?5T5!
M5$A%4E]$14)51RD@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(FXO85QN
M(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&9O<F5C87-T1&%T85LB;F]P87)S92)=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1F;W)E8V%S=$1A=&%;(FYO<&%R<V4B72`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A
M6R)N;W!A<G-E(EU;72`]("1T869;)&E=.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)&9O<F5C87-T1&%T85LB;F]P87)S
M92)=*2D@>PH@("`@("`@("`@("`D9F]R96-A<W1$871A6R)N;W!A<G-E(ET@
M/2!I;7!L;V1E*"(@(BP@("1F;W)E8V%S=$1A=&%;(FYO<&%R<V4B72D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&9O<F5C87-T1&%T83L*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!?8V]N=F5R=%)E='5R;B@I"B`@("`O
M*BH*("`@("`J($-O;G9E<G1S('1H92!D871A(&EN('1H92!R971U<FX@87)R
M87D@=&\@=&AE(&1E<VER960@=6YI=',@86YD+V]R"B`@("`@*B!O=71P=70@
M9F]R;6%T+@H@("`@("H*("`@("`J($!P87)A;2`@(&%R<F%Y("`@("`@("`@
M("`@("`@("`@("`@("`D=&%R9V5T"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)'5N:71S"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&QO8V%T:6]N"B`@("`@*B!`
M86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T
M4F5T=7)N*"8D=&%R9V5T+"`D=6YI=',L("1L;V-A=&EO;BD*("`@('L*("`@
M("`@("!I9B`H:7-?87)R87DH)'1A<F=E="DI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)'1A<F=E="!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@
M("\O($%N;W1H97(@87)R87D@9&5T96-T960L('-O(')E8W5R<V4@:6YT;R!I
M="!T;R!C;VYV97)T('1H92!U;FET<PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8V]N=F5R=%)E='5R;B@D=&%R9V5T6R1K97E=+"`D=6YI=',L("1L
M;V-A=&EO;BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")S=&%T:6]N(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N97=686P@/2`D;&]C871I;VY;(FYA;64B73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(")U<&1A=&4B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M(")V86QI9$9R;VTB.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V
M86QI9%1O(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=686P@
M/2!G;61A=&4H=')I;2@D=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?
M=&EM949O<FUA="DL("1V86PI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F0B
M.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD1W5S="(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1S:&5A<B(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)'1H:7,M/F-O;G9E
M<G13<&5E9"@D=F%L+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@(G9I<VEB:6QI='DB.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T1&ES=&%N8V4H)'9A
M;"P@(G-M(BP@)'5N:71S6R)V:7,B72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M:&5I9VAT(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=VEN9'-H
M96%R2&5I9VAT(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=6
M86P@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1V86PL(")F="(L("1U;FET
M<ULB:&5I9VAT(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=&5M<&5R871U<F5(
M:6=H(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=&5M<&5R871U
M<F5,;W<B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")D97=0;VEN
M="(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(F9E;'1496UP97)A
M='5R92(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@
M)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=F%L+"`B9B(L("1U;FET<ULB
M=&5M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")P<F5S<W5R92(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)'1H:7,M/F-O;G9E
M<G10<F5S<W5R92@D=F%L+"`B:6XB+"`D=6YI='-;(G!R97,B72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B86UO=6YT(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B<VYO=V1E<'1H(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B<VYO=V5Q=6EV(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]N=6UE<FEC*"1V86PI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T4')E<W-U<F4H
M)'9A;"P@(FEN(BP@)'5N:71S6R)R86EN(ETI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F5W5F%L(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")S96%P<F5S<W5R92(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)'1H:7,M/F-O
M;G9E<G10<F5S<W5R92@D=F%L+"`B:6XB+"`D=6YI='-;(G!R97,B72D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`B,6AT96UP(CH*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B,6AD97<B.@H@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("(V:&UA>'1E;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("(V:&UI;G1E;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("(R
M-&AM87AT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B,C1H
M;6EN=&5M<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L
M(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=F%L+"`B9B(L("1U;FET
M<ULB=&5M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1A<F=E=%LD:V5Y72`]("1N
M97=686P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I
M;VXH*0H@("`@+RHJ"B`@("`@*B!396%R8VAE<R!)1',@9F]R(&=I=F5N(&QO
M8V%T:6]N+"!R971U<FYS(&%R<F%Y(&]F('!O<W-I8FQE(&QO8V%T:6]N<PH@
M("`@("H@;W(@<VEN9VQE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG?&%R<F%Y("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0'!A
M<F%M("`@8F]O;"`@("`@("`@("`@("`@("`@("`@("`@("1U<V5&:7)S="`@
M("`@("!)9B!S970L(&9I<G-T($E$(&]F(')E<W5L="UA<G)A>2!I<R!R971U
M<FYE9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?
M15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$
M"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$52
M7T524D]27TE.5D%,241?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96%R8VA,;V-A=&EO;B@D;&]C871I
M;VXL("1U<V5&:7)S="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]D8BD@?'P@(41".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D
M8BDI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A
M:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#
M5$5$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&ES7W-T<FEN9R@D;&]C871I;VXI*2!["B`@("`@("`@("`@("\O(%1R
M>2!T;R!P87)T('-E87)C:"!S=')I;F<@:6X@;F%M92P@<W1A=&4@86YD(&-O
M=6YT<GD@<&%R=`H@("`@("`@("`@("`O+R!A;F0@8G5I;&0@=VAE<F4@8VQA
M=7-E(&9R;VT@:70@9F]R('1H92!S96QE8W0*("`@("`@("`@("`@)&QO8V%T
M:6]N(#T@97AP;&]D92@B+"(L("1L;V-A=&EO;BD["@H@("`@("`@("`@("`O
M+R!4<FEM+"!C87!S+6QO=R!A;F0@<75O=&4@=&AE('-T<FEN9W,*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1L;V-A=&EO;BD[("1I
M*RLI('L*("`@("`@("`@("`@("`@("1L;V-A=&EO;ELD:5T@/2`D=&AI<RT^
M7V1B+3YQ=6]T92@B)2(N<W1R=&]L;W=E<BAT<FEM*"1L;V-A=&EO;ELD:5TI
M*2XB)2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<VEZ96]F
M*"1L;V-A=&EO;BD@/3T@,2D@>PH@("`@("`@("`@("`@("`@)'=H97)E("`]
M("),3U=%4BAN86UE*2!,24M%("(N)&QO8V%T:6]N6S!=.PH@("`@("`@("`@
M("!](&5L<V5I9B`H<VEZ96]F*"1L;V-A=&EO;BD@/3T@,BD@>PH@("`@("`@
M("`@("`@("`@)'=H97)E("`]("),3U=%4BAN86UE*2!,24M%("(N)&QO8V%T
M:6]N6S!=.PH@("`@("`@("`@("`@("`@)'=H97)E("X]("(@04Y$($Q/5T52
M*&-O=6YT<GDI($Q)2T4@(BXD;&]C871I;VY;,5T["B`@("`@("`@("`@('T@
M96QS96EF("AS:7IE;V8H)&QO8V%T:6]N*2`]/2`S*2!["B`@("`@("`@("`@
M("`@("`D=VAE<F4@(#T@(DQ/5T52*&YA;64I($Q)2T4@(BXD;&]C871I;VY;
M,%T["B`@("`@("`@("`@("`@("`D=VAE<F4@+CT@(B!!3D0@3$]715(H<W1A
M=&4I($Q)2T4@(BXD;&]C871I;VY;,5T["B`@("`@("`@("`@("`@("`D=VAE
M<F4@+CT@(B!!3D0@3$]715(H8V]U;G1R>2D@3$E+12`B+B1L;V-A=&EO;ELR
M73L*("`@("`@("`@("`@?2!E;'-E:68@*'-I>F5O9B@D;&]C871I;VXI(#T]
M(#0I('L*("`@("`@("`@("`@("`@("1W:&5R92`@/2`B3$]715(H;F%M92D@
M3$E+12`B+G-U8G-T<B@D;&]C871I;VY;,%TL(#`L("TR*2XB+"`B+G-U8G-T
M<B@D;&]C871I;VY;,5TL(#(I.PH@("`@("`@("`@("`@("`@)'=H97)E("X]
M("(@04Y$($Q/5T52*'-T871E*2!,24M%("(N)&QO8V%T:6]N6S)=.PH@("`@
M("`@("`@("`@("`@)'=H97)E("X]("(@04Y$($Q/5T52*&-O=6YT<GDI($Q)
M2T4@(BXD;&]C871I;VY;,UT["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O($-R96%T92!S96QE8W0L(&QO8V%T:6]N<R!W:71H($E#04\@9FER<W0*
M("`@("`@("`@("`@)'-E;&5C="`](")314Q%0U0@:6-A;RP@;F%M92P@<W1A
M=&4L(&-O=6YT<GDL(&QA=&ET=61E+"!L;VYG:71U9&4@(BX*("`@("`@("`@
M("`@("`@("`@("`@(")&4D]-(&UE=&%R3&]C871I;VYS("(N"B`@("`@("`@
M("`@("`@("`@("`@("`B5TA%4D4@(BXD=VAE<F4N(B`B+@H@("`@("`@("`@
M("`@("`@("`@("`@(D]21$52($)9(&EC86\@1$530R(["B`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<V5L96-T*3L*("`@("`@
M("`@("`@+R\@0VAE8VL@<F5S=6QT(&9O<B!V86QI9&ET>0H@("`@("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R=&]L
M;W=E<BAG971?8VQA<W,H)')E<W5L="DI("$](")D8E]R97-U;'0B('Q\("1R
M97-U;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%)E<W5L="!I<R!V
M86QI9"P@<W1A<G0@<')E<&%R:6YG('1H92!R971U<FX*("`@("`@("`@("`@
M)&EC86\@/2!A<G)A>2@I.PH@("`@("`@("`@("!W:&EL92`H*"1R;W<@/2`D
M<F5S=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2`A/2!N=6QL
M*2!["B`@("`@("`@("`@("`@("`D;&]C:6-A;R`]("1R;W=;(FEC86\B73L*
M("`@("`@("`@("`@("`@("\O($9I<G-T('1H92!N86UE(&]F('1H92!L;V-A
M=&EO;@H@("`@("`@("`@("`@("`@:68@*"%S=')L96XH)')O=ULB<W1A=&4B
M72DI('L*("`@("`@("`@("`@("`@("`@("`D;&]C;F%M92`]("1R;W=;(FYA
M;64B72XB+"`B+B1R;W=;(F-O=6YT<GDB73L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N
M86UE(ETN(BP@(BXD<F]W6R)S=&%T92)=+B(L("(N)')O=ULB8V]U;G1R>2)=
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1L;V-I
M8V%O("$]("(M+2TM(BD@>PH@("`@("`@("`@("`@("`@("`@("\O(%=E(&AA
M=F4@82!L;V-A=&EO;B!W:71H($E#04\*("`@("`@("`@("`@("`@("`@("`D
M:6-A;ULD;&]C:6-A;UT@/2`D;&]C;F%M93L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@3F\@24-!3RP@=')Y(&9I
M;F1I;F<@=&AE(&YE87)E<W0@86ER<&]R=`H@("`@("`@("`@("`@("`@("`@
M("1L;V-I8V%O(#T@)'1H:7,M/G-E87)C:$%I<G!O<G0H)')O=ULB;&%T:71U
M9&4B72P@)')O=ULB;&]N9VET=61E(ETI.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&EC86];)&QO8VEC86]=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:6-A;ULD;&]C:6-A;UT@/2`D;&]C;F%M93L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@+R\@3VYL>2!O;F4@<F5S=6QT/R!2971U<FX@87,@
M<W1R:6YG"B`@("`@("`@("`@(&EF("AS:7IE;V8H)&EC86\I(#T](#$@?'P@
M)'5S949I<G-T*2!["B`@("`@("`@("`@("`@("`D:6-A;R`](&ME>2@D:6-A
M;RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH
M)&QO8V%T:6]N*2D@>PH@("`@("`@("`@("`O+R!,;V-A=&EO;B!W87,@<')O
M=FED960@87,@8V]O<F1I;F%T97,L('-E87)C:"!N96%R97-T(&%I<G!O<G0*
M("`@("`@("`@("`@)&EC86\@/2`D=&AI<RT^<V5A<F-H06ER<&]R="@D;&]C
M871I;VY;,%TL("1L;V-A=&EO;ELQ72D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I
M8V%O.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T
M:6]N0GE#;W5N=')Y*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!)1',@=VET
M:"!L;V-A=&EO;BUN86UE(&9O<B!A(&=I=F5N(&-O=6YT<GD@;W(@86QL(&%V
M86EL86)L90H@("`@("H@8V]U;G1R:65S+"!I9B!N;R!V86QU92!W87,@9VEV
M96X*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@
M("`@("`@("`@)&-O=6YT<GD*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\
M87)R87D*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%
M051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@
M4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].
M3D5#5$5$"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]7
M14%42$527T524D]27U=23TY'7U-%4E9%4E]$051!"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VY"
M>4-O=6YT<GDH)&-O=6YT<GD@/2`B(BD*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?9&(I('Q\("%$0CHZ:7-#;VYN96-T:6]N*"1T:&ES+3Y?
M9&(I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR
M86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%
M0U1%1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%)E='5R;B!T:&4@879A:6QA8FQE(&-O=6YT<FEE<R!A<R!N;R!C;W5N
M=')Y('=A<R!G:79E;@H@("`@("`@(&EF("@A<W1R;&5N*"1C;W5N=')Y*2D@
M>PH@("`@("`@("`@("`D<V5L96-T(#T@(E-%3$5#5"!$25-424Y#5"AC;W5N
M=')Y*2`B+@H@("`@("`@("`@("`@("`@("`@("`@(D923TT@;65T87)!:7)P
M;W)T<R`B+@H@("`@("`@("`@("`@("`@("`@("`@(D]21$52($)9(&-O=6YT
M<GD@05-#(CL*("`@("`@("`@("`@)&-O=6YT<FEE<R`]("1T:&ES+3Y?9&(M
M/F=E=$-O;"@D<V5L96-T*3L*"B`@("`@("`@("`@("\O($%S("1C;W5N=')I
M97,@:7,@96ET:&5R(&%N(&5R<F]R(&]R('1H92!T<G5E(')E<W5L="P*("`@
M("`@("`@("`@+R\@=V4@8V%N(&IU<W0@<F5T=7)N(&ET"B`@("`@("`@("`@
M(')E='5R;B`D8V]U;G1R:65S.PH@("`@("`@('T*"B`@("`@("`@+R\@3F]W
M(&9O<B!T:&4@<F5A;"!S96%R8V@*("`@("`@("`D<V5L96-T(#T@(E-%3$5#
M5"!I8V%O+"!N86UE+"!S=&%T92P@8V]U;G1R>2`B+@H@("`@("`@("`@("`@
M("`@("`B1E)/32!M971A<D%I<G!O<G1S("(N"B`@("`@("`@("`@("`@("`@
M(")72$5212!,3U=%4BAC;W5N=')Y*2!,24M%("<E(BYS=')T;VQO=V5R*'1R
M:6TH)&-O=6YT<GDI*2XB)2<@(BX*("`@("`@("`@("`@("`@("`@(D]21$52
M($)9(&YA;64@05-#(CL*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M<75E<GDH)'-E;&5C="D["B`@("`@("`@+R\@0VAE8VL@<F5S=6QT(&9O<B!V
M86QI9&ET>0H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V5I9B`H
M<W1R=&]L;W=E<BAG971?8VQA<W,H)')E<W5L="DI("$](")D8E]R97-U;'0B
M('Q\("1R97-U;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E
M='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%
M051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@("\O($-O;G-T<G5C="!T:&4@<F5S
M=6QT"B`@("`@("`@)&QO8V%T:6]N<R`](&%R<F%Y*"D["B`@("`@("`@=VAI
M;&4@*"@D<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%3
M4T]#*2D@(3T@;G5L;"D@>PH@("`@("`@("`@("`D;&]C:6-A;R`]("1R;W=;
M(FEC86\B73L*("`@("`@("`@("`@:68@*"1L;V-I8V%O("$]("(M+2TM(BD@
M>PH@("`@("`@("`@("`@("`@+R\@1FER<W0@=&AE(&YA;64@;V8@=&AE(&QO
M8V%T:6]N"B`@("`@("`@("`@("`@("!I9B`H(7-T<FQE;B@D<F]W6R)S=&%T
M92)=*2D@>PH@("`@("`@("`@("`@("`@("`@("1L;V-N86UE(#T@)')O=ULB
M;F%M92)=+B(L("(N)')O=ULB8V]U;G1R>2)=.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;&]C;F%M92`]("1R;W=;
M(FYA;64B72XB+"`B+B1R;W=;(G-T871E(ETN(BP@(BXD<F]W6R)C;W5N=')Y
M(ET["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;&]C871I
M;VYS6R1L;V-I8V%O72`]("1L;V-N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&QO8V%T:6]N<SL*("`@('T*("`@("\O
M('U]?0H*("`@("\O('M[>R!S96%R8VA!:7)P;W)T*"D*("`@("\J*@H@("`@
M("H@4V5A<F-H97,@=&AE(&YE87)E<W0@86ER<&]R="AS*2!F;W(@9VEV96X@
M8V]O<F1I;F%T97,L(')E='5R;G,@87)R87D*("`@("`J(&]F($E$<R!O<B!S
M:6YG;&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@
M("`@("`@("`@("`@("`@)&QA=&ET=61E"B`@("`@*B!`<&%R86T@("!F;&]A
M="`@("`@("`@("`@("`@("`@("`@("`@)&QO;F=I='5D90H@("`@("H@0'!A
M<F%M("`@:6YT("`@("`@("`@("`@("`@("`@("`@("`@("1N=6U297-U;'1S
M"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y?'-T<FEN9PH@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]53DM.3U=.7TQ/0T%424]."B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R
M.CI315)624-%4U]714%42$527T524D]27T1"7TY/5%]#3TY.14-4140*("`@
M("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)2
M3U)?24Y604Q)1%],3T-!5$E/3@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E87)C:$%I<G!O<G0H)&QA=&ET=61E+"`D
M;&]N9VET=61E+"`D;G5M4F5S=6QT<R`](#$I"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V1B*2!\?"`A1$(Z.FES0V]N;F5C=&EO;B@D=&AI
M<RT^7V1B*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE
M<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27T1"7TY/5%]#
M3TY.14-4140L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-?;G5M97)I8R@D;&%T:71U9&4I('Q\("%I<U]N=6UE<FEC
M*"1L;VYG:71U9&4I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]7
M96%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?24Y6
M04Q)1%],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@("\O($=E="!A;&P@86ER<&]R=',*("`@("`@("`D<V5L96-T
M(#T@(E-%3$5#5"!I8V%O+"!X+"!Y+"!Z($923TT@;65T87)!:7)P;W)T<R([
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S96QE8W0I
M.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V5I9B`H<W1R=&]L
M;W=E<BAG971?8VQA<W,H)')E<W5L="DI("$](")D8E]R97-U;'0B('Q\("1R
M97-U;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!3
M97)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?
M15)23U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("\O(%)E<W5L="!I<R!V86QI9"P@<W1A<G0@
M<V5A<F-H"B`@("`@("`@+R\@26YI=&EA;&EZ92!V86QU97,*("`@("`@("`D
M;6EN7V1I<W0@/2!N=6QL.PH@("`@("`@("1Q=65R>2`@("`]("1T:&ES+3YP
M;VQA<C)C87)T97-I86XH)&QA=&ET=61E+"`D;&]N9VET=61E*3L*("`@("`@
M("`D<V5A<F-H("`@/2!A<G)A>2@B9&ES="(@/3X@87)R87DH*2P@(FEC86\B
M(#T^(&%R<F%Y*"DI.PH@("`@("`@('=H:6QE("@H)')O=R`]("1R97-U;'0M
M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI("$](&YU;&PI('L*("`@
M("`@("`@("`@)&EC86\@/2`D<F]W6R)I8V%O(ET["B`@("`@("`@("`@("1A
M:7(@(#T@87)R87DH)')O=ULB>")=+"`D<F]W6R)Y(ETL("1R;W=;(GHB72D[
M"@H@("`@("`@("`@("`D9&ES="`](#`["B`@("`@("`@("`@("1D(#T@,#L*
M("`@("`@("`@("`@+R\@0V%L8W5L871E(&1I<W1A;F-E(&]F('%U97)Y(&%N
M9"!C=7)R96YT(&%I<G!O<G0*("`@("`@("`@("`@+R\@8G)E86L@;V9F+"!I
M9B!D:7-T86YC92!I<R!L87)G97(@=&AA;B!C=7)R96YT("1M:6Y?9&ES=`H@
M("`@("`@("`@("!F;W(H)&0[("1D(#P@<VEZ96]F*"1A:7(I.R`D9"LK*2![
M"B`@("`@("`@("`@("`@("`D="`]("1A:7);)&1=("T@)'%U97)Y6R1D73L*
M("`@("`@("`@("`@("`@("1D:7-T("L]('!O=R@D="P@,BD["B`@("`@("`@
M("`@("`@("!I9B`H)&UI;E]D:7-T("$](&YU;&P@)B8@)&1I<W0@/B`D;6EN
M7V1I<W0I('L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1D(#X]
M('-I>F5O9B@D86ER*2D@>PH@("`@("`@("`@("`@("`@+R\@3VLL(&-U<G)E
M;G0@86ER<&]R="!I<R!O;F4@;V8@=&AE(&YE87)E<B!L;V-A=&EO;G,*("`@
M("`@("`@("`@("`@("\O(&%D9"!T;R!R97-U;'0M87)R87D*("`@("`@("`@
M("`@("`@("1S96%R8VA;(F1I<W0B75M=(#T@)&1I<W0["B`@("`@("`@("`@
M("`@("`D<V5A<F-H6R)I8V%O(EU;72`]("1I8V%O.PH@("`@("`@("`@("`@
M("`@+R\@4V]R="!A<G)A>2!F;W(@9&ES=&%N8V4*("`@("`@("`@("`@("`@
M(&%R<F%Y7VUU;'1I<V]R="@D<V5A<F-H6R)D:7-T(ETL(%-/4E1?3E5-15))
M0RP@4T]25%]!4T,L("1S96%R8VA;(FEC86\B72P@4T]25%]35%))3D<L(%-/
M4E1?05-#*3L*("`@("`@("`@("`@("`@("\O($EF(&%R<F%Y(&ES(&QA<F=E
M<B!T:&5N(&1E<VER960@<F5S=6QT<RP@8VAO<"!O9F8@;&%S="!O;F4*("`@
M("`@("`@("`@("`@(&EF("AS:7IE;V8H)'-E87)C:%LB9&ES=")=*2`^("1N
M=6U297-U;'1S*2!["B`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P*"1S
M96%R8VA;(F1I<W0B72D["B`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P
M*"1S96%R8VA;(FEC86\B72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D;6EN7V1I<W0@/2!M87@H)'-E87)C:%LB9&ES=")=*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&YU;5)E<W5L=',@
M/3T@,2D@>PH@("`@("`@("`@("`O+R!/;FQY(&]N92!R97-U;'0@=V%N=&5D
M+"!R971U<FX@87,@<W1R:6YG"B`@("`@("`@("`@(')E='5R;B`D<V5A<F-H
M6R)I8V%O(EU;,%T["B`@("`@("`@?2!E;'-E:68@*"1N=6U297-U;'1S(#X@
M,2D@>PH@("`@("`@("`@("`O+R!2971U<FX@9F]U;F0@;&]C871I;VYS"B`@
M("`@("`@("`@(')E='5R;B`D<V5A<F-H6R)I8V%O(ET["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A
M:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%4
M24].+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*("`@
M("\O('U]?0H*("`@("\O('M[>R!G971,;V-A=&EO;B@I"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&1A=&$@9F]R('1H92!L;V-A=&EO;B!B96QO;F=I
M;F<@=&\@=&AE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%
M<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%T
M:6]N*"1I9"`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^
M7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R
M;B`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE
M9"`F)B`H)&QO8V%T:6]N(#T@)'1H:7,M/E]C86-H92T^9V5T*")-151!4BTB
M+B1I9"P@(FQO8V%T:6]N(BDI*2!["B`@("`@("`@("`@("\O($=R86(@<W1U
M9F8@9G)O;2!C86-H90H@("`@("`@("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@
M)&QO8V%T:6]N.PH@("`@("`@("`@("`D;&]C871I;VY2971U<FY;(F-A8VAE
M(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]D
M8BD@)B8@1$(Z.FES0V]N;F5C=&EO;B@D=&AI<RT^7V1B*2D@>PH@("`@("`@
M("`@("`O+R!'970@9&%T82!F<F]M($1""B`@("`@("`@("`@("1S96QE8W0@
M/2`B4T5,14-4(&EC86\L(&YA;64L('-T871E+"!C;W5N=')Y+"!L871I='5D
M92P@;&]N9VET=61E+"!E;&5V871I;VX@(BX*("`@("`@("`@("`@("`@("`@
M("`@(")&4D]-(&UE=&%R06ER<&]R=',@5TA%4D4@:6-A;STG(BXD:60N(B<B
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-E
M;&5C="D["@H@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!](&5L<V5I9B`H<W1R=&]L;W=E<BAG971?8VQA<W,H)')E<W5L="DI("$]
M(")D8E]R97-U;'0B('Q\("1R97-U;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%
M<G)O<BA315)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TXL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@+R\@4F5S=6QT(&ES(&]K+"!P=70@=&AI;F=S(&EN=&\@;V)J96-T"B`@
M("`@("`@("`@("1T:&ES+3Y?;&]C871I;VX@/2`D<F5S=6QT+3YF971C:%)O
M=RA$0E]&151#2$U/1$5?05-33T,I.PH*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@
M8V%C:&4@:70*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B
M4T525DE#15-?5T5!5$A%4E]%6%!)4D537TQ/0T%424].(BD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-A8VAE+3YE>'13879E*")-151!4BTB+B1I9"P@
M)'1H:7,M/E]L;V-A=&EO;BP@(B(L("1E>'!I<F4L(")L;V-A=&EO;B(I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&]C871I;VY2971U<FY;(F-A
M8VAE(ET@/2`B34E34R(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]L;V-A=&EO;B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(FYA
M;64B("`@("`@/3X@)&ED+`H@("`@("`@("`@("`@("`@(G-T871E(B`@("`@
M/3X@(B(L"B`@("`@("`@("`@("`@("`B8V]U;G1R>2(@("`]/B`B(BP*("`@
M("`@("`@("`@("`@(")L871I='5D92(@(#T^("(B+`H@("`@("`@("`@("`@
M("`@(FQO;F=I='5D92(@/3X@(B(L"B`@("`@("`@("`@("`@("`B96QE=F%T
M:6]N(B`]/B`B(@H@("`@("`@("`@("`I.PH@("`@("`@('T*("`@("`@("`O
M+R!3='5F9B!N86UE+7-T<FEN9R!T;V=E=&AE<@H@("`@("`@(&EF("AS=')L
M96XH)'1H:7,M/E]L;V-A=&EO;ELB<W1A=&4B72D@)B8@<W1R;&5N*"1T:&ES
M+3Y?;&]C871I;VY;(F-O=6YT<GDB72DI('L*("`@("`@("`@("`@)&QO8VYA
M;64@/2`D=&AI<RT^7VQO8V%T:6]N6R)N86UE(ETN(BP@(BXD=&AI<RT^7VQO
M8V%T:6]N6R)S=&%T92)=+B(L("(N)'1H:7,M/E]L;V-A=&EO;ELB8V]U;G1R
M>2)=.PH@("`@("`@('T@96QS96EF("AS=')L96XH)'1H:7,M/E]L;V-A=&EO
M;ELB8V]U;G1R>2)=*2D@>PH@("`@("`@("`@("`D;&]C;F%M92`]("1T:&ES
M+3Y?;&]C871I;VY;(FYA;64B72XB+"`B+B1T:&ES+3Y?;&]C871I;VY;(F-O
M=6YT<GDB73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&]C;F%M
M92`]("1T:&ES+3Y?;&]C871I;VY;(FYA;64B73L*("`@("`@("!]"B`@("`@
M("`@)&QO8V%T:6]N4F5T=7)N6R)N86UE(ET@("`@("`]("1L;V-N86UE.PH@
M("`@("`@("1L;V-A=&EO;E)E='5R;ELB;&%T:71U9&4B72`@/2`D=&AI<RT^
M7VQO8V%T:6]N6R)L871I='5D92)=.PH@("`@("`@("1L;V-A=&EO;E)E='5R
M;ELB;&]N9VET=61E(ET@/2`D=&AI<RT^7VQO8V%T:6]N6R)L;VYG:71U9&4B
M73L*("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G)I<V4B72`@(#T@9&%T
M92@D=&AI<RT^7W1I;65&;W)M870L("1T:&ES+3YC86QC=6QA=&53=6Y2:7-E
M4V5T*&=M;6MT:6UE*"DL(%-53D953D-37U)%5%]424U%4U1!35`L("1T:&ES
M+3Y?;&]C871I;VY;(FQA=&ET=61E(ETL("1T:&ES+3Y?;&]C871I;VY;(FQO
M;F=I='5D92)=+"!315)624-%4U]714%42$527U-53D953D-37U-53E))4T5?
M6D5.251(+"`P+"!T<G5E*2D["B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)S
M=6YS970B72`@("`](&1A=&4H)'1H:7,M/E]T:6UE1F]R;6%T+"`D=&AI<RT^
M8V%L8W5L871E4W5N4FES95-E="AG;6UK=&EM92@I+"!354Y&54Y#4U]2151?
M5$E-15-404U0+"`D=&AI<RT^7VQO8V%T:6]N6R)L871I='5D92)=+"`D=&AI
M<RT^7VQO8V%T:6]N6R)L;VYG:71U9&4B72P@4T525DE#15-?5T5!5$A%4E]3
M54Y&54Y#4U]354Y3151?6D5.251(+"`@,"P@9F%L<V4I*3L*("`@("`@("`D
M;&]C871I;VY2971U<FY;(F5L979A=&EO;B)=(#T@)'1H:7,M/E]L;V-A=&EO
M;ELB96QE=F%T:6]N(ET["@H@("`@("`@(')E='5R;B`D;&]C871I;VY2971U
M<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T5V5A=&AE<B@I
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('=E871H97(M9&%T82!F;W(@
M=&AE('-U<'!L:65D(&QO8V%T:6]N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U;FET<T9O<FUA=`H@
M("`@("H@0')E='5R;B`@4$A07T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S
M("!02%!?17)R;W(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971796%T:&5R*"1I9"`]("(B+"`D=6YI='-&;W)M870@
M/2`B(BD*("`@('L*("`@("`@("`D:60@("`@(#T@<W1R=&]U<'!E<B@D:60I
M.PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D
M:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D
M<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@
M("!]"@H@("`@("`@("\O($=E="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S
M("`@(#T@)'1H:7,M/F=E=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="D["B`@
M("`@("`@)&QO8V%T:6]N(#T@)'1H:7,M/F=E=$QO8V%T:6]N*"1I9"D["@H@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1L;V-A=&EO
M;BDI('L*("`@("`@("`@("`@<F5T=7)N("1L;V-A=&EO;CL*("`@("`@("!]
M"@H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H
M97(@/2`D=&AI<RT^7V-A8VAE+3YG970H(DU%5$%2+2(N)&ED+"`B=V5A=&AE
M<B(I*2D@>PH@("`@("`@("`@("`O+R!7964N+BX@:70@=V%S(&-A8VAE9"P@
M;&5T)W,@:&%V92!I="XN+@H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;B`@
M/2`D=V5A=&AE<CL*("`@("`@("`@("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E
M871H97)2971U<FX["B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H
M92)=(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M1&]W;FQO860@=V5A=&AE<@H@("`@("`@("`@("`D=V5A=&AE<D1A=&$@/2`D
M=&AI<RT^7W)E=')I979E4V5R=F5R1&%T82@D:60L(")M971A<B(I.PH@("`@
M("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=V5A=&AE
M<D1A=&$I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E871H97)$871A
M.PH@("`@("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1W96%T:&5R1&%T
M82D@?'P@<VEZ96]F*"1W96%T:&5R1&%T82D@/"`R*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)6
M24-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!0
M87)S92!W96%T:&5R"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N("`]("1T
M:&ES+3Y?<&%R<V5796%T:&5R1&%T82@D=V5A=&AE<D1A=&$I.PH*("`@("`@
M("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'=E871H97)2
M971U<FXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E871H97)2971U
M<FX["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($%D9"!A;B!I8V]N
M(&9O<B!T:&4@8W5R<F5N="!C;VYD:71I;VYS"B`@("`@("`@("`@("\O($1E
M=&5R;6EN92!I9B!C97)T86EN('9A;'5E<R!A<F4@<V5T+"!I9B!N;W0@=7-E
M(&1E9F%U;'1S"B`@("`@("`@("`@("1C;VYD:71I;VX@("`](&ES<V5T*"1W
M96%T:&5R4F5T=7)N6R)C;VYD:71I;VXB72D@("`_("1W96%T:&5R4F5T=7)N
M6R)C;VYD:71I;VXB72`@(#H@(DYO(%-I9VYI9FEC86YT(%=E871H97(B.PH@
M("`@("`@("`@("`D8VQO=61S("`@("`@/2!I<W-E="@D=V5A=&AE<E)E='5R
M;ELB8VQO=61S(ETI("`@("`@/R`D=V5A=&AE<E)E='5R;ELB8VQO=61S(ET@
M("`@("`Z("`@("`@("`@("`@("`@("`@87)R87DH*3L*("`@("`@("`@("`@
M)'=I;F0@("`@("`@(#T@:7-S970H)'=E871H97)2971U<FY;(G=I;F0B72D@
M("`@("`@(#\@)'=E871H97)2971U<FY;(G=I;F0B72`@("`@("`@.B`@("`@
M("`@("`@("`@("`@("`@("`@(#4[(`H@("`@("`@("`@("`D=&5M<&5R871U
M<F4@/2!I<W-E="@D=V5A=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72D@/R`D
M=V5A=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72`Z("`@("`@("`@("`@("`@
M("`@("`@("`W,#L@"B`@("`@("`@("`@("1L871I='5D92`@("`](&ES<V5T
M*"1L;V-A=&EO;ELB;&%T:71U9&4B72D@("`@("`@("`_("1L;V-A=&EO;ELB
M;&%T:71U9&4B72`@("`@("`@(#H@("`@("`@("`@("`@("`@("`@("`M,S8P
M.PH@("`@("`@("`@("`D;&]N9VET=61E("`@/2!I<W-E="@D;&]C871I;VY;
M(FQO;F=I='5D92)=*2`@("`@("`@/R`D;&]C871I;VY;(FQO;F=I='5D92)=
M("`@("`@("`Z("`@("`@("`@("`@("`@("`@("`@+3,V,#L*("`@("`@("`@
M("`@"B`@("`@("`@("`@("\O($=E="!T:&4@:6-O;@H@("`@("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N26-O;B)=(#T@)'1H:7,M/F=E=%=E
M871H97))8V]N*"1C;VYD:71I;VXL("1C;&]U9',L("1W:6YD+"`D=&5M<&5R
M871U<F4L("1L871I='5D92P@)&QO;F=I='5D92D["@H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]C86-H945N86)L960I('L*("`@("`@("`@("`@("`@("\O
M($-A8VAE('=E871H97(*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS
M=&%N="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U=%051(15(B*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H(DU%5$%2+2(N
M)&ED+"`D=V5A=&AE<E)E='5R;BP@)'5N:71S1F]R;6%T+"`D97AP:7)E+"`B
M=V5A=&AE<B(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M=V5A=&AE<B`]("1W96%T:&5R4F5T=7)N.PH@("`@("`@("`@("`D=V5A=&AE
M<E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?8V]N=F5R=%)E='5R;B@D=V5A=&AE<E)E='5R;BP@)'5N:71S
M+"`D;&]C871I;VXI.PH*("`@("`@("!R971U<FX@)'=E871H97)2971U<FX[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T1F]R96-A<W0H*0H@
M("`@+RHJ"B`@("`@*B!-151!4B!P<F]V:61E<R!N;R!F;W)E8V%S="!P97(@
M<V4L('=E('5S92!T:&4@5$%&(')E<&]R=',@=&\@9V5N97)A=&4*("`@("`J
M(&$@9F]R96-A<W0@9F]R('1H92!A;FYO=6YC960@=&EM97!E<FEO9`H@("`@
M("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D:60*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%Y<R`@("`@("`@("`@26=N;W)E9"P@;F]T(&%P<&QI8V%B;&4*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M=6YI='-&;W)M870*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87D*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971&;W)E8V%S="@D:60@/2`B
M(BP@)&1A>7,@/2!N=6QL+"`D=6YI='-&;W)M870@/2`B(BD*("`@('L*("`@
M("`@("`D:60@("`@(#T@<W1R=&]U<'!E<B@D:60I.PH@("`@("`@("1S=&%T
M=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("\O
M($=E="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E
M=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="D["B`@("`@("`@)&QO8V%T:6]N
M(#T@)'1H:7,M/F=E=$QO8V%T:6]N*"1I9"D["@H@("`@("`@(&EF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1L;V-A=&EO;BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1L;V-A=&EO;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)&9O<F5C87-T(#T@)'1H:7,M/E]C
M86-H92T^9V5T*")-151!4BTB+B1I9"P@(F9O<F5C87-T(BDI*2!["B`@("`@
M("`@("`@("\O(%=E92XN+B!I="!W87,@8V%C:&5D+"!L970G<R!H879E(&ET
M+BXN"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;B`@/2`D9F]R96-A<W0[
M"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D9F]R96-A<W12971U
M<FX["B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`](")(
M250B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($1O=VYL;V%D
M(&9O<F5C87-T"B`@("`@("`@("`@("1F;W)E8V%S=$1A=&$@/2`D=&AI<RT^
M7W)E=')I979E4V5R=F5R1&%T82@D:60L(")T868B*3L*("`@("`@("`@("`@
M:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&9O<F5C87-T1&%T82DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D9F]R96-A<W1$871A.PH@("`@
M("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1F;W)E8V%S=$1A=&$I('Q\
M('-I>F5O9B@D9F]R96-A<W1$871A*2`\(#(I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T53
M7U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%!A<G-E
M(&9O<F5C87-T"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;B`@/2`D=&AI
M<RT^7W!A<G-E1F]R96-A<W1$871A*"1F;W)E8V%S=$1A=&$I.PH*("`@("`@
M("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&9O<F5C87-T
M4F5T=7)N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1F;W)E8V%S=%)E
M='5R;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C
M86-H945N86)L960I('L*("`@("`@("`@("`@("`@("\O($-A8VAE('=E871H
M97(*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#
M15-?5T5!5$A%4E]%6%!)4D537T9/4D5#05-4(BD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-A8VAE+3YE>'13879E*")-151!4BTB+B1I9"P@)&9O<F5C
M87-T4F5T=7)N+"`D=6YI='-&;W)M870L("1E>'!I<F4L(")F;W)E8V%S="(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@
M/2`D9F]R96-A<W12971U<FX["B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R
M;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?8V]N=F5R=%)E='5R;B@D9F]R96-A<W12971U<FXL("1U;FET<RP@)&QO
M8V%T:6]N*3L*"B`@("`@("`@<F5T=7)N("1F;W)E8V%S=%)E='5R;CL*("`@
M('T*("`@("\O('U]?0I]"B\O('U]?0H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<B]796%T:&5R9&]T8V]M+G!H<```
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-C,P,3``,3`U,34T,S$P-38`,#(T,#0P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT
M('-O9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@
M4$5!4CHZ4V5R=FEC97-?5V5A=&AE<E]796%T:&5R9&]T8V]M"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG
M:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E
M<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I
M8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO
M=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y
M<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT
M871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I
M=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F
M('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O
M<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O
M9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T
M('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)
M4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%
M4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D53
M4R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,
M24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(
M04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/
M4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#
M3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&
M3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL
M($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@
M4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@
M2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/
M4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J
M($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/
M1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R
M>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E
M871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P
M8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z
M"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I
M;VX@("`@($-64SH@)$ED.B!796%T:&5R9&]T8V]M+G!H<"QV(#$N-3@@,C`P
M-2\Q,2\Q-R`P.#HQ.3HT,B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J
M($!L:6YK("`@("`@("!H='1P.B\O=W=W+G=E871H97(N8V]M+W-E<G9I8V5S
M+WAM;&]A<"YH=&UL"B`J($!E>&%M<&QE("`@("!E>&%M<&QE<R]W96%T:&5R
M+F-O;2UB87-I8RYP:'`@("`@("!W96%T:&5R+F-O;2UB87-I8RYP:'`*("H@
M0&5X86UP;&4@("`@(&5X86UP;&5S+W=E871H97(N8V]M+65X=&5N<VEV92YP
M:'`@('=E871H97(N8V]M+65X=&5N<VEV92YP:'`*("H@0&9I;&5S;W5R8V4*
M("HO"@IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E871H97(O0V]M;6]N+G!H
M<"(["@HO+R![>WL@8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]796%T:&5R9&]T
M8V]M"B\J*@H@*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E('1O
M('1H92!X;6P@<V5R=FEC92!O9B!W96%T:&5R+F-O;2X@270*("H@<V5A<F-H
M97,@9F]R(&=I=F5N(&QO8V%T:6]N<R!A;F0@<F5T<FEE=F5S(&-U<G)E;G0@
M=V5A=&AE<B!D871A(&%S('=E;&P*("H@87,@9F]R96-A<W0@9F]R('5P('1O
M(#$P(&1A>7,N"B`J"B`J($9O<B!U<VEN9R!T:&4@=V5A=&AE<BYC;VT@>&UL
M+7-E<G9I8V4@<&QE87-E('9I<VET"B`J("`@("!H='1P.B\O=W=W+G=E871H
M97(N8V]M+W-E<G9I8V5S+WAM;&]A<"YH=&UL"B`J(&%N9"!F;VQL;W<@=&AE
M(&QI;FL@=&\@<VEG;B!U<"P@:70G<R!F<F5E(2!9;W4@=VEL;"!R96-E:79E
M(&%N(&5M86EL"B`J('=H97)E('1O(&1O=VYL;V%D('1H92!31$L@=VET:"!T
M:&4@;F5E9&5D(&EM86=E<R!A;F0@9W5I9&5L:6YE<R!H;W<@=&\*("H@<'5B
M;&ES:"!L:79E(&1A=&$@9G)O;2!W96%T:&5R+F-O;2X@56YF;W)T=6YA=&5L
M>2!T:&4@9W5I9&5L:6YE<R!A<F4@80H@*B!B:70@:&%R<V@L('1H870G<R!W
M:'D@=&AE<F4G<R!N;R!A8W1U86P@9&%T82UR97!R97-E;G1A=&EO;B!I;B!T
M:&ES"B`J(&-L87-S+"!J=7-T('1H92!R87<@9&%T82X@06QS;R!W96%T:&5R
M+F-O;2!D96UA;F1S(&%C=&EV92!C86-H:6YG+"!S;R!))V0*("H@<W1R;VYG
M;'D@<F5C;VUM96YD(&5N86)L:6YG('1H92!C86-H:6YG(&EM<&QE;65N=&5D
M(&EN('1H:7,@8VQA<W,N($ET"B`J(&]B97ES('1O('1H92!T:6UE<R!A<R!W
M<FET=&5N(&1O=VX@:6X@=&AE(&=U:61E;&EN97,N"B`J"B`J($9O<B!W;W)K
M:6YG(&5X86UP;&5S+"!P;&5A<V4@=&%K92!A(&QO;VL@870*("H@("`@(&1O
M8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]W96%T:&5R+F-O;2UB87-I
M8RYP:'`*("H@("`@(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]W
M96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP"B`J"B`J($!C871E9V]R>2`@("!7
M96(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*
M("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE
M=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L
M:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M(%)E;&5A<V4Z(#$N-"XP"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@
M("`@:'1T<#HO+W=W=RYW96%T:&5R+F-O;2]S97)V:6-E<R]X;6QO87`N:'1M
M;`H@*B!`97AA;7!L92`@("`@97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N
M<&AP("`@("`@=V5A=&AE<BYC;VTM8F%S:6,N<&AP"B`J($!E>&%M<&QE("`@
M("!E>&%M<&QE<R]W96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP("!W96%T:&5R
M+F-O;2UE>'1E;G-I=F4N<&AP"B`J+PIC;&%S<R!397)V:6-E<U]796%T:&5R
M7U=E871H97)D;W1C;VT@97AT96YD<R!397)V:6-E<U]796%T:&5R7T-O;6UO
M;B!["@H@("`@+R\@>WM[('!R;W!E<G1I97,*("`@("\J*@H@("`@("H@4&%R
M=&YE<BU)1"!A="!W96%T:&5R+F-O;0H@("`@("H*("`@("`J($!V87(@("`@
M('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D7W!A<G1N97))1`H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]P87)T;F5R
M240@/2`B(CL*"B`@("`O*BH*("`@("`J($QI8V5N<V4@:V5Y(&%T('=E871H
M97(N8V]M"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@
M("`@("`@("`@("`@("1?;&EC96YS94ME>0H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]L:6-E;G-E2V5Y(#T@(B(["@H@("`@
M+RHJ"B`@("`@*B!3=VET8V@@=&\@=&]G9VQE('!R92UF971C:&EN9R!O9B!D
M871A(&EN(&]N92!S:6YG;&4@<F5Q=65S=`H@("`@("H*("`@("`J($!V87(@
M("`@(&)O;VP@("`@("`@("`@("`@("`@("`@("`@("`D7W!R949E=&-H"B`@
M("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@("!V87(@)%]P<F5&
M971C:"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@3V)J96-T(&-O;G1A:6YI
M;F<@=&AE('!R;VUO=&EO;F%L(&QI;FMS+61A=&$*("`@("`J"B`@("`@*B!`
M=F%R("`@("!O8FIE8W0@<W1D0VQA<W,@("`@("`@("`@("`@)%]L:6YK<PH@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L:6YK
M<SL*"B`@("`O*BH*("`@("`J(%A-3%]5;G-E<FEA;&EZ97(L('5S960@9F]R
M('!R;V-E<W-I;F<@=&AE('AM;`H@("`@("H*("`@("`J($!V87(@("`@(&]B
M:F5C="!834Q?56YS97)I86QI>F5R("`@("`D7W5N<V5R:6%L:7IE<@H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]U;G-E<FEA
M;&EZ97(["B`@("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!297%U:7)E
M<R!834Q?4V5R:6%L:7IE<B!T;R!B92!I;G-T86QL960*("`@("`J"B`@("`@
M*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO
M;G,*("`@("`J($!P87)A;2`@(&UI>&5D("`@("`@("`@("`@("`@("`@("`@
M("`D97)R;W(*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@4V5R=FEC97-?
M5V5A=&AE<E]796%T:&5R9&]T8V]M*"1O<'1I;VYS+"`F)&5R<F]R*0H@("`@
M>PH@("`@("`@("1P97)R;W(@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y397)V
M:6-E<U]796%T:&5R7T-O;6UO;B@D;W!T:6]N<RP@)'!E<G)O<BD["B`@("`@
M("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'!E<G)O<BDI('L*
M("`@("`@("`@("`@)&5R<F]R(#T@)'!E<G)O<CL*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T(&]P=&EO;G,@86-C;W)D
M:6YG;'D*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G!A<G1N97))1")=
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T06-C;W5N=$1A=&$H)&]P=&EO
M;G-;(G!A<G1N97))1")=*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R)L:6-E;G-E2V5Y(ETI*2!["B`@("`@("`@("`@("1T:&ES
M+3YS971!8V-O=6YT1&%T82@B(BP@)&]P=&EO;G-;(FQI8V5N<V5+97DB72D[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB<')E1F5T
M8V@B72DI('L*("`@("`@("`@("`@)'1H:7,M/F5N86)L95!R949E=&-H*"1O
M<'1I;VYS6R)P<F5&971C:")=*3L*("`@("`@("!]"@H@("`@("`@(&EN8VQU
M9&5?;VYC92`B6$U,+U5N<V5R:6%L:7IE<BYP:'`B.PH@("`@("`@("1U;G-E
M<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H87)R87DH(F-O;7!L
M97A4>7!E(B`]/B`B;V)J96-T(BP@(FME>4%T=')I8G5T92(@/3X@(G1Y<&4B
M*2D["B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'5N
M<V5R:6%L:7IE<BDI('L*("`@("`@("`@("`@)&5R<F]R(#T@)'5N<V5R:6%L
M:7IE<CL*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?=6YS97)I86QI>F5R(#T@)'5N<V5R:6%L:7IE
M<CL*("`@("`@("!]"@H@("`@("`@("\O($-A;B=T(&%C<75I<F4@86X@;V)J
M96-T(&AE<F4L(&AA<R!T;R!B92!C;&5A;B!O;B!E=F5R>2!R97%U97-T"B`@
M("`@("`@:6YC;'5D95]O;F-E(")(5%10+U)E<75E<W0N<&AP(CL*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!S971!8V-O=6YT1&%T82@I"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE(&YE8V-E<W-A<GD@86-C;W5N="UI;F9O<FUA
M=&EO;B!F;W(@=V5A=&AE<BYC;VTL('EO=2=L;`H@("`@("H@<F5C96EV92!T
M:&5M(&%F=&5R(')E9VES=&5R:6YG(&9O<B!T:&4@6$U,+7-T<F5A;0H@("`@
M("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D<&%R=&YE<DE$"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)&QI8V5N<V5+97D*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971!8V-O=6YT1&%T82@D<&%R=&YE
M<DE$+"`D;&EC96YS94ME>2D*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1P
M87)T;F5R240I("8F(&-T>7!E7V1I9VET*"1P87)T;F5R240I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R=&YE<DE$("`]("1P87)T;F5R240["B`@("`@
M("`@?0H@("`@("`@(&EF("AS=')L96XH)&QI8V5N<V5+97DI("8F(&-T>7!E
M7V%L;G5M*"1L:6-E;G-E2V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI
M8V5N<V5+97D@/2`D;&EC96YS94ME>3L*("`@("`@("!]"B`@("!]"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@96YA8FQE4')E1F5T8V@H*0H@("`@+RHJ"B`@
M("`@*B!%;F%B;&5S('!R92UF971C:&EN9R!O9B!D871A(&EN(&]N92!S:6YG
M;&4@<F5Q=65S=`H@("`@("H*("`@("`J($!P87)A;2`@(&)O;VP@("`@("`@
M("`@("`@("`@("`@("`@("`D<')E1F5T8V@*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!E;F%B;&50<F5&971C:"@D<')E
M1F5T8V@I"B`@("!["B`@("`@("`@:68@*"1P<F5&971C:"`]/2!T<G5E*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<')E1F5T8V@@/2!T<G5E.PH@("`@("`@
M('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?8VAE8VM,;V-A=&EO
M;DE$*"D*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!I9"!F;W(@=F%L:60@
M=F%L=65S(&%N9"!T:'5S('!R979E;G1S('-I;&QY(')E<75E<W1S('1O"B`@
M("`@*B!W96%T:&5R+F-O;2!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<F5T
M=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J($!T:')O=W,@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?3D]?3$]#051)3TX*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M24Y604Q)1%],3T-!5$E/3@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8VAE8VM,;V-A=&EO;DE$*"1I9"D*("`@('L*
M("`@("`@("!I9B`H:7-?87)R87DH)&ED*2!\?"!I<U]O8FIE8W0H)&ED*2!\
M?"`A<W1R;&5N*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S
M7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E].
M3U],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!](&5L
M<V5I9B`H(6-T>7!E7V%L;G5M*"1I9"D@?'P@*'-T<FQE;B@D:60I(#X@."DI
M('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E
M17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7W!A<G-E
M5V5A=&AE<D1A=&$H*0H@("`@+RHJ"B`@("`@*B!&971C:&5S('1H92!D871A
M(&)A<V5D(&]N('1H92!R97%U97-T960@='EP92!A;F0@8V%C:&5S(&ET"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1I9`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1R97%4>7!E"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O
M;VP*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(
M15)?15)23U)?5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%
M05)?17)R;W(*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W!A<G-E5V5A=&AE<D1A=&$H)&ED+"`D<F5Q5'EP92D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/E]P<F5&971C:"D@>PH@("`@("`@("`@
M("`D<F5Q5'EP92`](")A;&PB.PH@("`@("`@('T*"B`@("`@("`@)'5R;"`]
M(")H='1P.B\O>&]A<"YW96%T:&5R+F-O;2]W96%T:&5R+VQO8V%L+R(N)&ED
M+B(_<')O9#UX;V%P)G!A<CTB+B1T:&ES+3Y?<&%R=&YE<DE$+B(F:V5Y/2(N
M)'1H:7,M/E]L:6-E;G-E2V5Y.PH*("`@("`@("!S=VET8V@@*"1R97%4>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@(FQI;FMS(CH*("`@("`@("`@("`@("`@
M("1U<FP@+CT@(B9L:6YK/7AO87`B.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@(G=E871H97(B.@H@("`@("`@("`@("`@("`@
M)'5R;"`N/2`B)F-C/2HF=6YI=#US(CL*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E(")F;W)E8V%S="(Z"B`@("`@("`@("`@("`@
M("`D=7)L("X]("(F9&%Y9CTQ,"9U;FET/7,B.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@(F%L;"(Z"B`@("`@("`@("`@("`@
M("`D=7)L("X]("(F;&EN:SUX;V%P)F-C/2HF9&%Y9CTQ,"9U;FET/7,B.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O+R!'
M970@9&%T82!F<F]M(%523"XN+@H@("`@("`@("1R97%U97-T(#T@)FYE=R!(
M5%107U)E<75E<W0H)'5R;"P@)'1H:7,M/E]H='1P3W!T:6]N<RD["B`@("`@
M("`@)'-T871U<R`]("1R97%U97-T+3YS96YD4F5Q=65S="@I.PH@("`@("`@
M(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I('Q\("AI
M;G0I("1R97%U97-T+3YG971297-P;VYS94-O9&4H*2`\/B`R,#`I('L*("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@)&1A=&$@/2`D
M<F5Q=65S="T^9V5T4F5S<&]N<V5";V1Y*"D["@H@("`@("`@("\O("XN+F%N
M9"!U;G-E<FEA;&EZ90H@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7W5N<V5R
M:6%L:7IE<BT^=6YS97)I86QI>F4H)&1A=&$I.PH*("`@("`@("!I9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@
M("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%
M4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R;V]T
M(#T@)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E=%)O;W1.86UE*"D["B`@("`@
M("`@("`@("1D871A(#T@)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E=%5N<V5R
M:6%L:7IE9$1A=&$H*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1R;V]T*2!\?"`D<F]O="`]/2`B2%1-3"(I('L*("`@
M("`@("`@("`@("`@("\O(%-O;65T:&EN9R!W<F]N9R!H97)E+"!M87EB92!N
M;W0@6$U,(')E=')I979E9"XN+@H@("`@("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1R;V]T(#T](")E<G)O<B(I('L*("`@
M("`@("`@("`@("`@("\O(%=E(&=O="!A;B!E<G)O<B!B86-K(&9R;VT@=V5A
M=&AE<BYC;VT*("`@("`@("`@("`@("`@("1E<G)N;R`@/2!K97DH9V5T7V]B
M:F5C=%]V87)S*"1D871A*2D["B`@("`@("`@("`@("`@("!R971U<FX@4V5R
M=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<B@D97)R;F\L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`O+R!686QI9"!D871A+"!L971S(&=E="!S=&%R=&5D"B`@("`@("`@("`@
M("`@("`O+R!,;V]P('1H<F]U9V@@=&AE(&1I9F9E<F5N="!S=6(M<&%R=',@
M;V8@=&AE(&1A=&$@9G)O('!R;V-E<W-I;F<*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*&=E=%]O8FIE8W1?=F%R<R@D9&%T82D@87,@)&ME>2`]/B`D=F%L
M*2!["B`@("`@("`@("`@("`@("`@("`@<W=I=&-H("@D:V5Y*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@(FAE860B.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B<')M;R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92`@/2`B;&EN:W,B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FQO
M8R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`@/2`B
M;&]C871I;VXB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(F-C(CH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V87)N86UE("`](")W96%T:&5R(CL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E(")D87EF(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE("`](")F;W)E8V%S="(["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@+R\@4V%V92!D871A(&EN(&]B:F5C=`H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y[(E\B+B1V87)N86UE?2`]("1V86P[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O("XN+F%N9"!C86-H92!I
M9B!P;W-S:6)L90H@("`@("`@("`@("`@("`@("`@("`@("`D97AP:7)E(#T@
M8V]N<W1A;G0H(E-%4E9)0T537U=%051(15)?15A025)%4U\B+G-T<G1O=7!P
M97(H)'9A<FYA;64I*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C86-H92T^97AT4V%V92@D:60L("1V86PL("(B+"`D97AP:7)E+"`D=F%R
M;F%M92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A=&EO
M;B@I"B`@("`O*BH*("`@("`J(%-E87)C:&5S($E$<R!F;W(@9VEV96X@;&]C
M871I;VXL(')E='5R;G,@87)R87D@;V8@<&]S<VEB;&4@;&]C871I;VYS"B`@
M("`@*B!O<B!S:6YG;&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)&QO8V%T:6]N"B`@("`@*B!`<&%R
M86T@("!B;V]L("`@("`@("`@("`@("`@("`@("`@("`@)'5S949I<G-T("`@
M("`@($EF('-E="P@9FER<W0@240@;V8@<F5S=6QT+6%R<F%Y(&ES(')E='5R
M;F5D"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y?'-T<FEN9PH@
M("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%400H@("`@("H@0'1H<F]W<R`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].
M"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5A<F-H3&]C871I;VXH)&QO8V%T:6]N+"`D=7-E1FER<W0@/2!F86QS92D*
M("`@('L*("`@("`@("`D;&]C871I;VX@/2!T<FEM*"1L;V-A=&EO;BD["B`@
M("`@("`@)&QO8TQO=R`@(#T@<W1R=&]L;W=E<B@D;&]C871I;VXI.PH@("`@
M("`@(`H@("`@("`@("\O($-H96-K(&]N(&-A8VAE9"!D871A.B!-1#4M:&%S
M:"!O9B!L;V-A=&EO;B!H87,@=&\@8F4@8V]R<F5C="!A;F0@=&AE('5S97)D
M871A(&AA<R!T;R!B92!T:&4@<V%M92!A<R!T:&4@9VEV96X@;&]C871I;VX@
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("1L;V-,;W<@
M/3T@)'1H:7,M/E]C86-H92T^9V5T57-E<D1A=&$H;60U*"1L;V-,;W<I+"`B
M<V5A<F-H(BDI('L*("`@("`@("`@("`@)'-E87)C:"`]("1T:&ES+3Y?8V%C
M:&4M/F=E="AM9#4H)&QO8TQO=RDL(")S96%R8V@B*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O+R!'970@<V5A<F-H(&1A=&$@9G)O;2!S97)V
M97(@86YD('5N<V5R:6%L:7IE"B`@("`@("`@("`@("1R97%U97-T(#T@)FYE
M=R!(5%107U)E<75E<W0H(FAT='`Z+R]X;V%P+G=E871H97(N8V]M+W-E87)C
M:"]S96%R8V@_=VAE<F4](BYU<FQE;F-O9&4H)&QO8V%T:6]N*2P@)'1H:7,M
M/E]H='1P3W!T:6]N<RD["B`@("`@("`@("`@("1S=&%T=7,@/2`D<F5Q=65S
M="T^<V5N9%)E<75E<W0H*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E
M871H97(Z.FES17)R;W(H)'-T871U<RD@?'P@*&EN="D@)')E<75E<W0M/F=E
M=%)E<W!O;G-E0V]D92@I(#P^(#(P,"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&%T82`]("1R97%U
M97-T+3YG971297-P;VYS94)O9'DH*3L*("`@(`H@("`@("`@("`@("`O+R`N
M+BYA;F0@=6YS97)I86QI>F4*("`@("`@("`@("`@)'-T871U<R`]("1T:&ES
M+3Y?=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D9&%T82P@9F%L<V4L(&%R
M<F%Y*")O=F5R<FED94]P=&EO;G,B(#T^('1R=64L(")C;VUP;&5X5'EP92(@
M/3X@(F%R<F%Y(BP@(FME>4%T=')I8G5T92(@/3X@(FED(BDI.PH@("`@"B`@
M("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T
M=7,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE
M<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=23TY'7U-%
M4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]
M"B`@("`*("`@("`@("`@("`@)')O;W0@/2`D=&AI<RT^7W5N<V5R:6%L:7IE
M<BT^9V5T4F]O=$YA;64H*3L*("`@("`@("`@("`@)'-E87)C:"`]("1T:&ES
M+3Y?=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("`*
M("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-E
M87)C:"D@?'P@)')O;W0@/3T@(DA434PB*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]7
M14%42$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1S96%R
M8V@I('Q\("%S:7IE;V8H)'-E87)C:"DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%
M051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C
M:&4@:68@<&]S<VEB;&4*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS
M=&%N="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U-%05)#2"(I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT4V%V92AM9#4H)&QO8TQO
M=RDL("1S96%R8V@L("1L;V-,;W<L("1E>'!I<F4L(")S96%R8V@B*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D=7-E1FER<W0@
M)B8@*'-I>F5O9B@D<V5A<F-H*2`^(#$I*2!["B`@("`@("`@("`@("1S96%R
M8VA2971U<FX@/2`D<V5A<F-H.PH@("`@("`@('T@96QS96EF("@D=7-E1FER
M<W0@?'P@*'-I>F5O9B@D<V5A<F-H*2`]/2`Q*2D@>PH@("`@("`@("`@("`D
M<V5A<F-H4F5T=7)N(#T@:V5Y*"1S96%R8V@I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1S96%R8VA2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@
M("`O+R![>WL@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH*0H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&]N;'D@9F%L<V4L(&%S('=E871H97(N8V]M(&]F9F5R
M<R!N;R!C;W5N=')Y(&QI<W1I;F<@=FEA"B`@("`@*B!I=',@6$U,('-E<G9I
M8V5S"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1C;W5N=')Y"B`@("`@*B!`<F5T=7)N("!B;V]L"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E87)C:$QO8V%T:6]N0GE#;W5N=')Y*"1C;W5N=')Y
M(#T@(B(I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@
M+R\@?7U]"@H@("`@+R\@>WM[(&=E=$QI;FMS*"D*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@9&%T82!F;W(@=&AE('!R;VUO=&EO;F%L(&QI;FMS(&)E
M;&]N9VEN9R!T;R!T:&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!0
M14%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3&EN:W,H)&ED(#T@(B(I"B`@("!["B`@("`@("`@)'-T871U<R`]("1T:&ES
M+3Y?8VAE8VM,;V-A=&EO;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<W1A='5S.PH@("`@("`@('T*"B`@("`@("`@)&QI;FMS4F5T=7)N
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M("8F("@D;&EN:W,@/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED+"`B;&EN:W,B
M*2DI('L*("`@("`@("`@("`@+R\@1V5T(&1A=&$@9G)O;2!C86-H90H@("`@
M("`@("`@("`D=&AI<RT^7VQI;FMS(#T@)&QI;FMS.PH@("`@("`@("`@("`D
M;&EN:W-2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!386UE(&%S(&EN('1H92!F=6YC=&EO;B!A8F]V
M92XN+@H@("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]P87)S95=E871H
M97)$871A*"1I9"P@(FQI;FMS(BD["@H@("`@("`@("`@("!I9B`H4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&QI;FMS4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PH@("`@("`@('T*"B`@
M("`@("`@)&QI;FMS4F5T=7)N6R)P<F]M;R)=(#T@87)R87DH*3L*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]L:6YK<RT^;&EN
M:RD[("1I*RLI('L*("`@("`@("`@("`@)&QI;FMS4F5T=7)N6R)P<F]M;R)=
M6R1I72`](&%R<F%Y*"D["B`@("`@("`@("`@("1L:6YK<U)E='5R;ELB<')O
M;6\B75LD:5U;(G1I=&QE(ET@/2`D=&AI<RT^7VQI;FMS+3YL:6YK6R1I72T^
M=#L*("`@("`@("`@("`@+R\@0C!R:V5D(')E<W!O;G-E("AR971U<FYE9"!I
M<R`F<&%R/7AO87`L('-H;W5L9"!B92`F<')O9#UX;V%P*2P@9FEX(&ET"B`@
M("`@("`@("`@("1L:6YK<U)E='5R;ELB<')O;6\B75LD:5U;(FQI;FLB72`@
M/2!S=')?<F5P;&%C92@B<&%R/2(L(")P<F]D/2(L("1T:&ES+3Y?;&EN:W,M
M/FQI;FM;)&E=+3YL*3L*("`@("`@("`@("`@)&QI;FMS4F5T=7)N6R)P<F]M
M;R)=6R1I75LB;&EN:R)=("X]("(F<&%R/2(N)'1H:7,M/E]P87)T;F5R240[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QI;FMS4F5T=7)N.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$QO8V%T:6]N*"D*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@9&%T82!F;W(@=&AE(&QO8V%T:6]N(&)E
M;&]N9VEN9R!T;R!T:&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!0
M14%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3&]C871I;VXH)&ED(#T@(B(I"B`@("!["B`@("`@("`@)'-T871U<R`]("1T
M:&ES+3Y?8VAE8VM,;V-A=&EO;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<W1A='5S.PH@("`@("`@('T*"B`@("`@("`@)&QO8V%T:6]N
M4F5T=7)N(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%
M;F%B;&5D("8F("@D;&]C871I;VX@/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED
M+"`B;&]C871I;VXB*2DI('L*("`@("`@("`@("`@+R\@1V5T(&1A=&$@9G)O
M;2!C86-H90H@("`@("`@("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)&QO8V%T
M:6]N.PH@("`@("`@("`@("`D;&]C871I;VY2971U<FY;(F-A8VAE(ET@/2`B
M2$E4(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!386UE(&%S
M(&EN('1H92!F=6YC=&EO;B!A8F]V92XN+@H@("`@("`@("`@("`D<W1A='5S
M(#T@)'1H:7,M/E]P87)S95=E871H97)$871A*"1I9"P@(FQO8V%T:6]N(BD[
M"@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D
M<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H
M92)=(#T@(DU)4U,B.PH@("`@("`@('T*"B`@("`@("`@)&QO8V%T:6]N4F5T
M=7)N6R)N86UE(ET@("`@("`]("1T:&ES+3Y?;&]C871I;VXM/F1N86T["B`@
M("`@("`@)&QO8V%T:6]N4F5T=7)N6R)T:6UE(ET@("`@("`](&1A=&4H)'1H
M:7,M/E]T:6UE1F]R;6%T+"!S=')T;W1I;64H)'1H:7,M/E]L;V-A=&EO;BT^
M=&TI*3L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQA=&ET=61E(ET@(#T@
M)'1H:7,M/E]L;V-A=&EO;BT^;&%T.PH@("`@("`@("1L;V-A=&EO;E)E='5R
M;ELB;&]N9VET=61E(ET@/2`D=&AI<RT^7VQO8V%T:6]N+3YL;VX["B`@("`@
M("`@)&QO8V%T:6]N4F5T=7)N6R)S=6YR:7-E(ET@("`](&1A=&4H)'1H:7,M
M/E]T:6UE1F]R;6%T+"!S=')T;W1I;64H)'1H:7,M/E]L;V-A=&EO;BT^<W5N
M<BDI.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N<V5T(ET@("`@/2!D
M871E*"1T:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C
M871I;VXM/G-U;G,I*3L*("`@("`@("`D;&]C871I;VY2971U<FY;(G1I;65Z
M;VYE(ET@(#T@)'1H:7,M/E]L;V-A=&EO;BT^>F]N93L*"B`@("`@("`@<F5T
M=7)N("1L;V-A=&EO;E)E='5R;CL*("`@('T*("`@("\O('U]?0H*("`@("\O
M('M[>R!G971796%T:&5R*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M=V5A=&AE<BUD871A(&9O<B!T:&4@<W5P<&QI960@;&]C871I;VX*("`@("`J
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@
M)&ED"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@
M("`@)'5N:71S1F]R;6%T"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R
M<F%Y"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5V5A=&AE<B@D:60@
M/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I"B`@("!["B`@("`@("`@)'-T871U
M<R`]("1T:&ES+3Y?8VAE8VM,;V-A=&EO;DE$*"1I9"D["@H@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@('T*"B`@("`@("`@+R\@
M1V5T(&]T:&5R(&1A=&$*("`@("`@("`D=6YI=',@("`@/2`D=&AI<RT^9V5T
M56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L*"B`@("`@("`@)'=E871H97)2
M971U<FX@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N
M86)L960@)B8@*"1W96%T:&5R(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@
M(G=E871H97(B*2DI('L*("`@("`@("`@("`@+R\@4V%M92!P<F]C961U<F4N
M+BX*("`@("`@("`@("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H97(["B`@
M("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@(DA)5"(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@+BXN87,@;&%S="!F=6YC
M=&EO;@H@("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]P87)S95=E871H
M97)$871A*"1I9"P@(G=E871H97(B*3L*"B`@("`@("`@("`@(&EF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]
M"@H@("`@("`@("\O(%-O;64@97AP;&%N871I;VX@9F]R('1H92!N97AT('1W
M;R!L:6YE<SH*("`@("`@("`O+R!W96%T:&5R+F-O;2!I<VXG="!A;'=A>7,@
M<W5P<&QY:6YG('1H92!T:6UE>F]N92!I;B!T:&4@=7!D871E('-T<FEN9RP@
M8G5T"B`@("`@("`@+R\@=7-E<R`B3&]C86P@5&EM92(@87,@<F5F97)E;F-E
M+"!W:&EC:"!I<R!I;6AO('5T=&5R;'D@<W1U<&ED+"!B96-A=7-E(&ET)W,*
M("`@("`@("`O+R!I;F-O;G-I<W1E;G0N(%=E;&PL('=H870@22!D;R!H97)E
M(&ES(&-H96-K(&9O<B!T:&ES('-T<FEN9R!A;F0@:68@22!C86X*("`@("`@
M("`O+R!F:6YD(&ET+"!)(&-A;&-U;&%T92!T:&4@9&EF9F5R96YC92!B971W
M965N('1H92!T:6UE>F]N92!A="!T:&4@;&]C871I;VX*("`@("`@("`O+R!A
M;F0@=&AI<R!C;VUP=71E<G,@=&EM97IO;F4N(%1H:7,@86UO=6YT(&]F('-E
M8V]N9',@:7,@=&AE;B!S=6)T<F%C=&5D(&9R;VT*("`@("`@("`O+R!T:&4@
M=&EM92!T:&4@=7!D871E+7-T<FEN9R!H87,@9&5L:79E<F5D+@H@("`@("`@
M("1U<&1A=&4@("`]('-T<E]R97!L86-E*"),;V-A;"!4:6UE(BP@(B(L("1T
M:&ES+3Y?=V5A=&AE<BT^;'-U<"D["B`@("`@("`@)&%D:G5S=%1:(#T@*"1U
M<&1A=&4@/3T@)'1H:7,M/E]W96%T:&5R+3YL<W5P*2`_(#`@.B`D=&AI<RT^
M7VQO8V%T:6]N+3YZ;VYE("H@,S8P,"`M(&1A=&4H(EHB*3L*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=7!D871E(ET@("`@("`@("`@("`](&=M9&%T92AT
M<FEM*"1T:&ES+3Y?9&%T949O<FUA="XB("(N)'1H:7,M/E]T:6UE1F]R;6%T
M*2P@<W1R=&]T:6UE*"1U<&1A=&4I("T@)&%D:G5S=%1:*3L*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=7!D871E4F%W(ET@("`@("`@("`]("1T:&ES+3Y?
M=V5A=&AE<BT^;'-U<#L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB<W1A=&EO
M;B)=("`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^;V)S=#L*("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72`@("`@("`]("1T:&ES
M+3YC;VYV97)T5&5M<&5R871U<F4H)'1H:7,M/E]W96%T:&5R+3YT;7`L(")F
M(BP@)'5N:71S6R)T96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)F
M96QT5&5M<&5R871U<F4B72`@(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R
M92@D=&AI<RT^7W=E871H97(M/F9L:6LL(")F(BP@)'5N:71S6R)T96UP(ETI
M.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)C;VYD:71I;VXB72`@("`@("`@
M(#T@)'1H:7,M/E]W96%T:&5R+3YT.PH@("`@("`@("1W96%T:&5R4F5T=7)N
M6R)C;VYD:71I;VY)8V]N(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YI8V]N
M.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)P<F5S<W5R92)=("`@("`@("`@
M(#T@)'1H:7,M/F-O;G9E<G10<F5S<W5R92@D=&AI<RT^7W=E871H97(M/F)A
M<BT^<BP@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PH@("`@("`@("1W96%T:&5R
M4F5T=7)N6R)P<F5S<W5R951R96YD(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R
M+3YB87(M/F0["B`@("`@("`@)'=E871H97)2971U<FY;(G=I;F0B72`@("`@
M("`@("`@("`@/2`D=&AI<RT^8V]N=F5R=%-P965D*"1T:&ES+3Y?=V5A=&AE
M<BT^=VEN9"T^<RP@(FUP:"(L("1U;FET<ULB=VEN9")=*3L*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=VEN9$=U<W0B72`@("`@("`@("`]("1T:&ES+3YC
M;VYV97)T4W!E960H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YG=7-T+"`B;7!H
M(BP@)'5N:71S6R)W:6YD(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W
M:6YD1&5G<F5E<R)=("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YD
M.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1&ER96-T:6]N(ET@("`@
M(#T@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YT.PH@("`@("`@("1W96%T:&5R
M4F5T=7)N6R)H=6UI9&ET>2)=("`@("`@("`@(#T@)'1H:7,M/E]W96%T:&5R
M+3YH;6ED.PH@("`@("`@(&EF("AI<U]N=6UE<FEC*"1T:&ES+3Y?=V5A=&AE
M<BT^=FES*2D@>PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=FES:6)I
M;&ET>2)=("`@(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D=&AI<RT^7W=E
M871H97(M/G9I<RP@(G-M(BP@)'5N:71S6R)V:7,B72D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G9I<VEB:6QI='DB
M72`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=FES.PH@("`@("`@('T*("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB=79);F1E>")=("`@("`@("`@("`]("1T:&ES
M+3Y?=V5A=&AE<BT^=78M/FD["B`@("`@("`@)'=E871H97)2971U<FY;(G5V
M5&5X=")=("`@("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M/G5V+3YT.PH@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)D97=0;VEN=")=("`@("`@("`@(#T@
M)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=&AI<RT^7W=E871H97(M/F1E
M=W`L(")F(BP@)'5N:71S6R)T96UP(ETI.PH*("`@("`@("!R971U<FX@)'=E
M871H97)2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T
M1F]R96-A<W0H*0H@("`@+RHJ"B`@("`@*B!'970@=&AE(&9O<F5C87-T(&9O
M<B!T:&4@;F5X="!D87ES"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0'!A<F%M("`@:6YT
M("`@("`@("`@("`@("`@("`@("`@("`@("1D87ES("`@("`@("`@("!686QU
M97,@8F5T=V5E;B`Q(&%N9"`Q,`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1U;FET<T9O<FUA=`H@("`@("H@0')E='5R
M;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O
M<@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$9O<F5C87-T*"1I9"`]("(B+"`D9&%Y<R`](#(L("1U;FET<T9O<FUA
M="`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K
M3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE
M<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T
M871U<SL*("`@("`@("!]"B`@("`@("`@:68@*"%I;E]A<G)A>2@D9&%Y<RP@
M<F%N9V4H,2P@,3`I*2D@>PH@("`@("`@("`@("`D9&%Y<R`](#(["B`@("`@
M("`@?0H*("`@("`@("`O+R!'970@;W1H97(@9&%T80H@("`@("`@("1U;FET
M<R`@("`]("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&;W)M870I.PH*
M("`@("`@("`D9F]R96-A<W12971U<FX@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H)'1H:7,M/E]C86-H945N86)L960@)B8@*"1F;W)E8V%S="`]("1T:&ES
M+3Y?8V%C:&4M/F=E="@D:60L(")F;W)E8V%S="(I*2D@>PH@("`@("`@("`@
M("`O+R!%;F-O<F4N+BX*("`@("`@("`@("`@)'1H:7,M/E]F;W)E8V%S="`]
M("1F;W)E8V%S=#L*("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H
M92)=(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M+BXN"B`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7W!A<G-E5V5A=&AE
M<D1A=&$H)&ED+"`B9F]R96-A<W0B*3L*"B`@("`@("`@("`@(&EF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D9F]R96-A<W12971U<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@
M?0H*("`@("`@("`O+R!3;VUE(&5X<&QA;F%T:6]N(&9O<B!T:&4@;F5X="!T
M=V\@;&EN97,Z("AS86UE(&%S(&%B;W9E*0H@("`@("`@("\O('=E871H97(N
M8V]M(&ES;B=T(&%L=V%Y<R!S=7!P;'EI;F<@=&AE('1I;65Z;VYE(&EN('1H
M92!U<&1A=&4@<W1R:6YG+"!B=70*("`@("`@("`O+R!U<V5S("),;V-A;"!4
M:6UE(B!A<R!R969E<F5N8V4L('=H:6-H(&ES(&EM:&\@=71T97)L>2!S='5P
M:60L(&)E8V%U<V4@:70G<PH@("`@("`@("\O(&EN8V]N<VES=&5N="X@5V5L
M;"P@=VAA="!)(&1O(&AE<F4@:7,@8VAE8VL@9F]R('1H:7,@<W1R:6YG(&%N
M9"!I9B!)(&-A;@H@("`@("`@("\O(&9I;F0@:70L($D@8V%L8W5L871E('1H
M92!D:69F97)E;F-E(&)E='=E96X@=&AE('1I;65Z;VYE(&%T('1H92!L;V-A
M=&EO;@H@("`@("`@("\O(&%N9"!T:&ES(&-O;7!U=&5R<R!T:6UE>F]N92X@
M5&AI<R!A;6]U;G0@;V8@<V5C;VYD<R!I<R!T:&5N('-U8G1R86-T960@9G)O
M;0H@("`@("`@("\O('1H92!T:6UE('1H92!U<&1A=&4M<W1R:6YG(&AA<R!D
M96QI=F5R960N"B`@("`@("`@)'5P9&%T92`@(#T@<W1R7W)E<&QA8V4H(DQO
M8V%L(%1I;64B+"`B(BP@)'1H:7,M/E]F;W)E8V%S="T^;'-U<"D["B`@("`@
M("`@)&%D:G5S=%1:(#T@*"1U<&1A=&4@/3T@)'1H:7,M/E]F;W)E8V%S="T^
M;'-U<"D@/R`P(#H@)'1H:7,M/E]L;V-A=&EO;BT^>F]N92`J(#,V,#`@+2!D
M871E*"):(BD["B`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)U<&1A=&4B72`@
M("`](&=M9&%T92@D=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?=&EM
M949O<FUA="P@<W1R=&]T:6UE*"1U<&1A=&4I("T@)&%D:G5S=%1:*3L*("`@
M("`@("`D9F]R96-A<W12971U<FY;(G5P9&%T95)A=R)=(#T@)'1H:7,M/E]F
M;W)E8V%S="T^;'-U<#L*("`@("`@("`D9F]R96-A<W12971U<FY;(F1A>7,B
M72`@("`@(#T@87)R87DH*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&1A>7,[("1I*RLI('L*("`@("`@("`@("`@)&1A>2`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@(G1E;7!E<F%T=7)E2&EG:"(@/3X@)'1H:7,M/F-O;G9E
M<G1496UP97)A='5R92@D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YH:2P@
M(F8B+"`D=6YI='-;(G1E;7`B72DL"B`@("`@("`@("`@("`@("`B=&5M<&5R
M871U<F5,;W<B("`]/B`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1T:&ES
M+3Y?9F]R96-A<W0M/F1A>5LD:5TM/FQO=RP@(F8B+"`D=6YI='-;(G1E;7`B
M72DL"B`@("`@("`@("`@("`@("`B<W5N<FES92(@("`@("`@("`]/B!D871E
M*"1T:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?9F]R96-A
M<W0M/F1A>5LD:5TM/G-U;G(I*2P*("`@("`@("`@("`@("`@(")S=6YS970B
M("`@("`@("`@(#T^(&1A=&4H)'1H:7,M/E]T:6UE1F]R;6%T+"!S=')T;W1I
M;64H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<W5N<RDI+`H@("`@("`@
M("`@("`@("`@(F1A>2(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M(F-O;F1I=&EO;B(@("`@(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM
M/G!A<G1;,%TM/G0L"B`@("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO;DEC
M;VXB(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,%TM/FEC
M;VXL"B`@("`@("`@("`@("`@("`@("`@(G=I;F0B("`@("`@("`@(#T^("1T
M:&ES+3YC;VYV97)T4W!E960H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^
M<&%R=%LP72T^=VEN9"T^<RP@(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@
M("`@("`@("`@("`@("`@("`B=VEN9$=U<W0B("`@("`@/3X@)'1H:7,M/F-O
M;G9E<G13<&5E9"@D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=
M+3YW:6YD+3YG=7-T+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI+`H@("`@("`@
M("`@("`@("`@("`@(")W:6YD1&5G<F5E<R(@("`]/B`D=&AI<RT^7V9O<F5C
M87-T+3YD87E;)&E=+3YP87)T6S!=+3YW:6YD+3YD+`H@("`@("`@("`@("`@
M("`@("`@(")W:6YD1&ER96-T:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD
M87E;)&E=+3YP87)T6S!=+3YW:6YD+3YT+`H@("`@("`@("`@("`@("`@("`@
M(")P<F5C:7!I=&%T:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=
M+3YP87)T6S!=+3YP<&-P+`H@("`@("`@("`@("`@("`@("`@(")H=6UI9&ET
M>2(@("`@("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=
M+3YH;6ED"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@(FYI
M9VAT(B`]/B!A<G)A>2`H"B`@("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO
M;B(@("`@(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM
M/G0L"B`@("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO;DEC;VXB(#T^("1T
M:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/FEC;VXL"B`@("`@
M("`@("`@("`@("`@("`@(G=I;F0B("`@("`@("`@(#T^("1T:&ES+3YC;VYV
M97)T4W!E960H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^
M=VEN9"T^<RP@(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@("`@("`@("`@
M("`@("`@("`B=VEN9$=U<W0B("`@("`@/3X@)'1H:7,M/F-O;G9E<G13<&5E
M9"@D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YW:6YD+3YG
M=7-T+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI+`H@("`@("`@("`@("`@("`@
M("`@(")W:6YD1&5G<F5E<R(@("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;
M)&E=+3YP87)T6S%=+3YW:6YD+3YD+`H@("`@("`@("`@("`@("`@("`@(")W
M:6YD1&ER96-T:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP
M87)T6S%=+3YW:6YD+3YT+`H@("`@("`@("`@("`@("`@("`@(")P<F5C:7!I
M=&%T:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=
M+3YP<&-P+`H@("`@("`@("`@("`@("`@("`@(")H=6UI9&ET>2(@("`@("`]
M/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YH;6ED"B`@
M("`@("`@("`@("`@("`I"B`@("`@("`@("`@("D["@H@("`@("`@("`@("`D
M9F]R96-A<W12971U<FY;(F1A>7,B75M=(#T@)&1A>3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D9F]R96-A<W12971U<FX["B`@("!]"B`@("`O+R!]
M?7T*?0HO+R!]?7T*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O0V]M;6]N+G!H<```````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,3$S,#`P`#$P-3$U-#,Q,#4V`#`R,C0U-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J
M(%!%05(Z.E-E<G9I8V5S7U=E871H97)?0V]M;6]N"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I
M(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D
M+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@
M8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N
M+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C
M;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F
M('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@
M;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN
M(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG
M:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*
M("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE
M(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S
M;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@
M("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@
M9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I
M9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T94
M5T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$
M($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)
M35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$
M(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))
M3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@
M05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'
M2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9
M($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U0
M3$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L
M($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)
M5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%
M4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4
M("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)
M3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%
M+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!7
M96(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*
M("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE
M=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L
M:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M($-64SH@)$ED.B!#;VUM;VXN<&AP+'8@,2XU,2`R,#`U+S$Q+S$S(#(R.C(W
M.C,R(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&9I;&5S;W5R8V4*
M("HO"@IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E871H97(N<&AP(CL*"B\O
M('M[>R!C;VYS=&%N=',*+R\@>WM[(&YA='5R86P@8V]N<W1A;G1S(&%N9"!M
M96%S=7)E<PID969I;F4H(E-%4E9)0T537U=%051(15)?4D%$25537T5!4E1(
M(BP@-C,W."XQ-2D["B\O('U]?0H*+R\@>WM[(&1E9F%U;'0@=F%L=65S(&9O
M<B!T:&4@<W5N+69U;F-T:6]N<PID969I;F4H(E-%4E9)0T537U=%051(15)?
M4U5.1E5.0U-?1$5&055,5%],051)5%5$12(L("`S,2XW-C8W*3L*9&5F:6YE
M*")315)624-%4U]714%42$527U-53D953D-37T1%1D%53%1?3$].1TE4541%
M(BP@,S4N,C,S,RD["F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]354Y&54Y#
M4U]354Y225-%7UI%3DE42"(L("`@(#DP+C@S*3L*9&5F:6YE*")315)624-%
M4U]714%42$527U-53D953D-37U-53E-%5%]:14Y)5$@B+"`@("`@.3`N.#,I
M.PHO+R!]?7T*+R\@?7U]"@HO+R![>WL@8VQA<W,@4V5R=FEC97-?5V5A=&AE
M<E]#;VUM;VX*+RHJ"B`J(%!A<F5N="!C;&%S<R!F;W(@=V5A=&AE<BUS97)V
M:6-E<RX@1&5F:6YE<R!C;VUM;VX@9G5N8W1I;VYS(&9O<B!U;FET"B`J(&-O
M;G9E<G-I;VYS+"!C:&5C:W,@9F]R(&-A8VAE(&5N86)L:6YG(&%N9"!D;V5S
M(&]T:&5R(&UI<V-E;&QA;F5O=7,*("H@=&AI;F=S+@H@*@H@*B!`8V%T96=O
M<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]7
M96%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`
M<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T
M>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S
M:6]N("`@("!296QE87-E.B`Q+C0N,`H@*B!`;&EN:R`@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("HO"F-L
M87-S(%-E<G9I8V5S7U=E871H97)?0V]M;6]N('L*"B`@("`O+R![>WL@<')O
M<&5R=&EE<PH@("`@+RHJ"B`@("`@*B!&;W)M870@;V8@=&AE('5N:71S('!R
M;W9I9&5D("AS=&%N9&%R9"]M971R:6,O8W5S=&]M*0H@("`@("H*("`@("`J
M($!V87(@("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D7W5N:71S
M1F]R;6%T"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W5N:71S1F]R;6%T(#T@(G,B.PH*("`@("\J*@H@("`@("H@0W5S=&]M
M(&9O<FUA="!O9B!T:&4@=6YI=',*("`@("`J"B`@("`@*B!`=F%R("`@("!A
M<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)%]C=7-T;VU5;FET<T9O<FUA
M=`H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C
M=7-T;VU5;FET<T9O<FUA="`](&%R<F%Y*`H@("`@("`@(")T96UP(B`@(#T^
M(")F(BP*("`@("`@("`B=FES(B`@("`]/B`B<VTB+`H@("`@("`@(")H96EG
M:'0B(#T^(")F="(L"B`@("`@("`@(G=I;F0B("`@/3X@(FUP:"(L"B`@("`@
M("`@(G!R97,B("`@/3X@(FEN(BP*("`@("`@("`B<F%I;B(@("`]/B`B:6XB
M"B`@("`I.PH*("`@("\J*@H@("`@("H@3W!T:6]N<R!F;W(@2%144"!R97%U
M97-T<PH@("`@("H*("`@("`J($!V87(@("`@(&%R<F%Y("`@("`@("`@("`@
M("`@("`@("`@("`D7VAT='!/<'1I;VYS"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7VAT='!/<'1I;VYS(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($9O<FUA="!O9B!T:&4@=7-E9"!D871E<PH@("`@
M("H*("`@("`J($!V87(@("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D7V1A=&5&;W)M870*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1?9&%T949O<FUA="`](")M+V0O>2(["@H@("`@+RHJ"B`@
M("`@*B!&;W)M870@;V8@=&AE('5S960@=&EM97,*("`@("`J"B`@("`@*B!`
M=F%R("`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)%]T:6UE1F]R
M;6%T"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7W1I;65&;W)M870@/2`B1SII($$B.PH*("`@("\J*@H@("`@("H@3V)J96-T
M(&-O;G1A:6YI;F<@=&AE(&QO8V%T:6]N+61A=&$*("`@("`J"B`@("`@*B!`
M=F%R("`@("!O8FIE8W0@<W1D0VQA<W,@("`@("`@("`@("`@)%]L;V-A=&EO
M;@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L
M;V-A=&EO;CL*"B`@("`O*BH*("`@("`J($]B:F5C="!C;VYT86EN:6YG('1H
M92!W96%T:&5R+61A=&$*("`@("`J"B`@("`@*B!`=F%R("`@("!O8FIE8W0@
M<W1D0VQA<W,@("`@("`@("`@("`@)%]W96%T:&5R"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W=E871H97(["@H@("`@+RHJ
M"B`@("`@*B!/8FIE8W0@8V]N=&%I;FEN9R!T:&4@9F]R96-A<W0M9&%T80H@
M("`@("H*("`@("`J($!V87(@("`@(&]B:F5C="!S=&1#;&%S<R`@("`@("`@
M("`@("`D7V9O<F5C87-T"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7V9O<F5C87-T.PH*("`@("\J*@H@("`@("H@0V%C:&4L
M(&-O;G1A:6YI;F<@=&AE(&1A=&$M;V)J96-T<PH@("`@("H*("`@("`J($!V
M87(@("`@(&]B:F5C="!#86-H92`@("`@("`@("`@("`@("`D7V-A8VAE"B`@
M("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V-A8VAE
M.PH*("`@("\J*@H@("`@("H@4')O=FED97,@8VAE8VL@9F]R($-A8VAE"B`@
M("`@*@H@("`@("H@0'9A<B`@("`@8F]O;"`@("`@("`@("`@("`@("`@("`@
M("`@("1?8V%C:&5%;F%B;&5D"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V-A8VAE16YA8FQE9"`](&9A;'-E.PH@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@87)R87D@("`@("`@
M("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@("`@*B!`<&%R86T@("!M:7AE
M9"`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R"B`@("`@*B!`=&AR;W=S
M("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I;VYS
M+"`F)&5R<F]R*0H@("`@>PH@("`@("`@("\O(%-E="!S;VUE(&-O;G-T86YT
M<R!F;W(@=&AE(&-A<V4@=VAE;B!02%`T(&ES('5S960L(&%S('1H90H@("`@
M("`@("\O(&1A=&5?<W5N<V5T+W-U;G)I<V4@9G5N8W1I;VYS(&%R92!N;W0@
M:6UP;&5M96YT960@=&AE<F4*("`@("`@("!I9B`H(61E9FEN960H(E-53D95
M3D-37U)%5%]424U%4U1!35`B*2D@>PH@("`@("`@("`@("!D969I;F4H(E-5
M3D953D-37U)%5%]424U%4U1!35`B+"`P*3L*("`@("`@("`@("`@9&5F:6YE
M*")354Y&54Y#4U]2151?4U1224Y'(BP@("`@,2D["B`@("`@("`@("`@(&1E
M9FEN92@B4U5.1E5.0U-?4D547T1/54),12(L("`@(#(I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@4V5T(&]P=&EO;G,@86-C;W)D:6YG;'D*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;(F-A8VAE5'EP92)=*2D@>PH@("`@("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;(F-A8VAE3W!T:6]N<R)=*2D@>PH@("`@
M("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3YS971#86-H92@D;W!T:6]N
M<ULB8V%C:&54>7!E(ETL("1O<'1I;VYS6R)C86-H94]P=&EO;G,B72D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/G-E=$-A8VAE*"1O<'1I;VYS6R)C86-H951Y<&4B72D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES
M17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("1E<G)O<B`]("1S
M=&%T=7,["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB=6YI='-&
M;W)M870B72DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)C
M=7-T;VU5;FET<T9O<FUA=")=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=%5N:71S1F]R;6%T*"1O<'1I;VYS6R)U;FET<T9O<FUA=")=+"`D;W!T
M:6]N<ULB8W5S=&]M56YI='-&;W)M870B72D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T56YI='-&;W)M870H)&]P
M=&EO;G-;(G5N:71S1F]R;6%T(ETI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(FAT='!4:6UE;W5T(ETI
M*2!["B`@("`@("`@("`@("1T:&ES+3YS971(='1P5&EM96]U="@D;W!T:6]N
M<ULB:'1T<%1I;65O=70B72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/G-E=$AT='!4:6UE;W5T*#8P*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R)H='1P4')O>'DB72DI('L*("`@("`@
M("`@("`@)'-T871U<R`]("1T:&ES+3YS971(='1P4')O>'DH)&]P=&EO;G-;
M(FAT='!0<F]X>2)=*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("1E<G)O
M<B`]("1S=&%T=7,["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB
M9&%T949O<FUA=")=*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T1&%T951I
M;65&;W)M870H)&]P=&EO;G-;(F1A=&5&;W)M870B72P@(B(I.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G1I;65&;W)M870B72DI
M('L*("`@("`@("`@("`@)'1H:7,M/G-E=$1A=&54:6UE1F]R;6%T*"(B+"`D
M;W!T:6]N<ULB=&EM949O<FUA=")=*3L*("`@("`@("!]"B`@("!]"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@<V5T0V%C:&4H*0H@("`@+RHJ"B`@("`@*B!%
M;F%B;&5S(&-A8VAI;F<@=&AE(&1A=&$L('5S86=E('-T<F]N9VQY(')E8V]M
M;65N9&5D"B`@("`@*@H@("`@("H@4F5Q=6ER97,@0V%C:&4@=&\@8F4@:6YS
M=&%L;&5D"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@
M("`@("`@("`@("`@("1C86-H951Y<&4*("`@("`J($!P87)A;2`@(&%R<F%Y
M("`@("`@("`@("`@("`@("`@("`@("`D8V%C:&5/<'1I;VYS"B`@("`@*B!`
M<F5T=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J($!T:')O=W,@(%!%05)?
M17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?0T%#2$5?24Y)5%]&04E,
M140*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!S971#86-H92@D8V%C:&54>7!E(#T@(F9I;&4B+"`D8V%C:&5/<'1I;VYS
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`O+R!4:&4@97)R;W(@:&%N9&QI
M;F<@:6X@0V%C:&4@:7,@82!B:70@8W)U;6UY("AR96%D.B!N;W0@97AI<W1E
M;G0I"B`@("`@("`@+R\@<V\@=V4@:&%V92!T;R!D;R!T:&%T(&]N(&]U<B!O
M=VXN+BX*("`@("`@("!`:6YC;'5D95]O;F-E(")#86-H92YP:'`B.PH@("`@
M("`@($`D8V%C:&4@/2!N97<@0V%C:&4H)&-A8VAE5'EP92P@)&-A8VAE3W!T
M:6]N<RD["B`@("`@("`@:68@*&ES7V]B:F5C="@D8V%C:&4I("8F("AS=')T
M;VQO=V5R*&=E=%]C;&%S<R@D8V%C:&4I*2`]/2`B8V%C:&4B('Q\(&ES7W-U
M8F-L87-S7V]F*"1C86-H92P@(F-A8VAE(BDI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V%C:&4@("`@("`@(#T@)&-A8VAE.PH@("`@("`@("`@("`D=&AI
M<RT^7V-A8VAE16YA8FQE9"`]('1R=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/E]C86-H92`@("`@("`@/2!N=6QL.PH@("`@("`@
M("`@("`D=&AI<RT^7V-A8VAE16YA8FQE9"`](&9A;'-E.PH@("`@("`@("`@
M("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%
M4U]714%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T56YI='-&;W)M870H*0H@
M("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!R97!R97-E;G1A=&EO;B!O9B!T
M:&4@=6YI=',@*'-T86YD87)D+VUE=')I8RD*("`@("`J"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T
M"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@
M)&-U<W1O;55N:71S1F]R;6%T"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T
M+"`D8W5S=&]M56YI='-&;W)M870@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M('-T871I8R`D86-C97!T961&;W)M871S.PH@("`@("`@(&EF("@A:7-S970H
M)&%C8V5P=&5D1F]R;6%T<RDI('L*("`@("`@("`@("`@)&%C8V5P=&5D1F]R
M;6%T<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(G1E;7`B("`@/3X@87)R
M87DH(F,B+"`B9B(I+`H@("`@("`@("`@("`@("`@(G9I<R(@("`@/3X@87)R
M87DH(FTB+"`B:VTB+"`B9G0B+"`B<VTB*2P*("`@("`@("`@("`@("`@(")H
M96EG:'0B(#T^(&%R<F%Y*")M(BP@(F9T(BDL"B`@("`@("`@("`@("`@("`B
M=VEN9"(@("`]/B!A<G)A>2@B;7!H(BP@(FMM:"(L(")K="(L(")M<',B+"`B
M9G!S(BP@(F)F="(I+`H@("`@("`@("`@("`@("`@(G!R97,B("`@/3X@87)R
M87DH(FEN(BP@(FAP82(L(")M8B(L(")M;2(L(")A=&TB*2P*("`@("`@("`@
M("`@("`@(")R86EN(B`@(#T^(&%R<F%Y*")I;B(L(")M;2(I"B`@("`@("`@
M("`@("D["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R;&5N*"1U;FET<T9O
M<FUA="D@)B8@:6Y?87)R87DH<W1R=&]L;W=E<B@D=6YI='-&;W)M871[,'TI
M+"!A<G)A>2@B8R(L(")M(BP@(G,B*2DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]U;FET<T9O<FUA="`]('-T<G1O;&]W97(H)'5N:71S1F]R;6%T>S!]*3L*
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?=6YI='-&;W)M870@/3T@(F,B("8F
M(&ES7V%R<F%Y*"1C=7-T;VU5;FET<T9O<FUA="DI('L*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1C=7-T;VU5;FET<T9O<FUA="!A<R`D:V5Y(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI
M<W1S*"1K97DL("1A8V-E<'1E9$9O<FUA=',I("8F(&EN7V%R<F%Y*"1V86QU
M92P@)&%C8V5P=&5D1F]R;6%T<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C=7-T;VU5;FET<T9O<FUA=%LD:V5Y72`]("1V
M86QU93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7W5N:71S1F]R;6%T(#T]
M(")C(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]U;FET<T9O<FUA="`]
M(")S(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@("\O('U]
M?0H*("`@("\O('M[>R!S971(='1P3W!T:6]N*"D*("`@("\J*@H@("`@("H@
M4V5T<R!A;B!O<'1I;VX@9F]R('5S86=E(&EN($A45%!?4F5Q=65S="!O8FIE
M8W1S"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1V87).86UE"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<E9A;'5E"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2'1T<$]P=&EO;B@D=F%R
M3F%M92P@)'9A<E9A;'5E*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H
M)'9A<DYA;64I("8F("1V87).86UE("$]("(B("8F("%E;7!T>2@D=F%R5F%L
M=64I*2!["B`@("`@("`@("`@("1T:&ES+3Y?:'1T<$]P=&EO;G-;)'9A<DYA
M;65=(#T@)'9A<E9A;'5E.PH@("`@("`@('T*("`@('T*("`@("\O('U]?0H*
M("`@("\O('M[>R!S971(='1P5&EM96]U="@I"B`@("`O*BH*("`@("`J(%-E
M=',@=&AE('1I;65O=70@:6X@<V5C;VYD<R!F;W(@2%144"!R97%U97-T<PH@
M("`@("H*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@("`@("`@("`@
M("`@("`D:'1T<%1I;65O=70*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!S971(='1P5&EM96]U="@D:'1T<%1I;65O=70I
M"B`@("!["B`@("`@("`@:68@*&ES7VEN="@D:'1T<%1I;65O=70I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?:'1T<$]P=&EO;G-;(G1I;65O=70B72`]("1H
M='1P5&EM96]U=#L*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O
M+R![>WL@<V5T2'1T<%!R;WAY*"D*("`@("\J*@H@("`@("H@4V5T<R!T:&4@
M<')O>'D@9F]R($A45%`@<F5Q=65S=',*("`@("`J"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&AT='!0<F]X>0H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$AT
M='!0<F]X>2@D:'1T<%!R;WAY*0H@("`@>PH@("`@("`@(&EF("@H)'!R;WAY
M(#T@<&%R<V5?=7)L*"1H='1P4')O>'DI*2`A/3T@9F%L<V4@)B8@)'!R;WAY
M6R)S8VAE;64B72`]/2`B:'1T<"(I('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1P<F]X>5LB=7-E<B)=*2`F)B`D<')O>'E;(G5S97(B72`A/2`B(BD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]H='1P3W!T:6]N<ULB<')O>'E?=7-E
M<B)=(#T@)'!R;WAY6R)U<V5R(ET["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1P<F]X>5LB<&%S<R)=*2`F)B`D<')O>'E;(G!A<W,B
M72`A/2`B(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]H='1P3W!T:6]N
M<ULB<')O>'E?<&%S<R)=(#T@)'!R;WAY6R)P87-S(ET["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LB:&]S=")=*2`F)B`D
M<')O>'E;(FAO<W0B72`A/2`B(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]H='1P3W!T:6]N<ULB<')O>'E?:&]S=")=(#T@)'!R;WAY6R)H;W-T(ET[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LB
M<&]R=")=*2`F)B`D<')O>'E;(G!O<G0B72`A/2`B(BD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]H='1P3W!T:6]N<ULB<')O>'E?<&]R=")=(#T@)'!R
M;WAY6R)P;W)T(ET["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!3
M97)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?
M15)23U)?2%144%]04D]865])3E9!3$E$+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!G9715
M;FET<T9O<FUA="@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-E;&5C
M=&5D('5N:71S(&9O<FUA=`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J($!R
M971U<FX@(&%R<F%Y"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T(#T@(B(I
M"B`@("!["B`@("`@("`@+R\@5&AI<R!I<R!C:&5A<"=O('-T=69F"B`@("`@
M("`@:68@*'-T<FQE;B@D=6YI='-&;W)M870I("8F(&EN7V%R<F%Y*'-T<G1O
M;&]W97(H)'5N:71S1F]R;6%T>S!]*2P@87)R87DH(F,B+"`B;2(L(")S(BDI
M*2!["B`@("`@("`@("`@("1U;FET<T9O<FUA="`]('-T<G1O;&]W97(H)'5N
M:71S1F]R;6%T>S!]*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=6YI='-&;W)M870@/2`D=&AI<RT^7W5N:71S1F]R;6%T.PH@("`@("`@('T*
M"B`@("`@("`@)&,@/2`D=&AI<RT^7V-U<W1O;55N:71S1F]R;6%T.PH@("`@
M("`@("1M(#T@87)R87DH"B`@("`@("`@("`@(")T96UP(B`@(#T^(")C(BP*
M("`@("`@("`@("`@(G9I<R(@("`@/3X@(FMM(BP*("`@("`@("`@("`@(FAE
M:6=H="(@/3X@(FTB+`H@("`@("`@("`@("`B=VEN9"(@("`]/B`B:VUH(BP*
M("`@("`@("`@("`@(G!R97,B("`@/3X@(FUB(BP*("`@("`@("`@("`@(G)A
M:6XB("`@/3X@(FUM(@H@("`@("`@("D["B`@("`@("`@)',@/2!A<G)A>2@*
M("`@("`@("`@("`@(G1E;7`B("`@/3X@(F8B+`H@("`@("`@("`@("`B=FES
M(B`@("`]/B`B<VTB+`H@("`@("`@("`@("`B:&5I9VAT(B`]/B`B9G0B+`H@
M("`@("`@("`@("`B=VEN9"(@("`]/B`B;7!H(BP*("`@("`@("`@("`@(G!R
M97,B("`@/3X@(FEN(BP*("`@("`@("`@("`@(G)A:6XB("`@/3X@(FEN(@H@
M("`@("`@("D["@H@("`@("`@(')E='5R;B`D>R1U;FET<T9O<FUA='T["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T1&%T951I;65&;W)M870H
M*0H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!R97!R97-E;G1A=&EO;B!O
M9B!T:6UE(&%N9"!D871E<R`H<V5E(&AT='`Z+R]W=W<N<&AP+FYE="]D871E
M*0H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("`D9&%T949O<FUA=`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1T:6UE1F]R;6%T"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&%T951I;65&;W)M
M870H)&1A=&5&;W)M870@/2`B(BP@)'1I;65&;W)M870@/2`B(BD*("`@('L*
M("`@("`@("!I9B`H<W1R;&5N*"1D871E1F]R;6%T*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V1A=&5&;W)M870@/2`D9&%T949O<FUA=#L*("`@("`@("!]
M"B`@("`@("`@:68@*'-T<FQE;B@D=&EM949O<FUA="DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]T:6UE1F]R;6%T(#T@)'1I;65&;W)M870["B`@("`@("`@
M?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G9E<G1496UP97)A
M='5R92@I"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&5M<&5R871U<F4@8F5T
M=V5E;B!F(&%N9"!C"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@
M("`@("`@("`@("`@("`@("`@("1T96UP97)A='5R90H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1F<F]M"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'1O"B`@("`@
M*B!`<F5T=7)N("!F;&]A=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1496UP97)A='5R92@D=&5M<&5R871U
M<F4L("1F<F]M+"`D=&\I"B`@("!["B`@("`@("`@)&9R;VT@/2!S=')T;VQO
M=V5R*"1F<F]M>S!]*3L*("`@("`@("`D=&\@("`]('-T<G1O;&]W97(H)'1O
M>S!]*3L*"B`@("`@("`@)')E<W5L="`](&%R<F%Y*`H@("`@("`@("`@("`B
M9B(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`B9B(@/3X@)'1E;7!E<F%T
M=7)E+"`@("`@("`@("`@(")C(B`]/B`H)'1E;7!E<F%T=7)E("T@,S(I("\@
M,2XX"B`@("`@("`@("`@("DL"B`@("`@("`@("`@(")C(B`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@(")F(B`]/B`Q+C@@*B`D=&5M<&5R871U<F4@*R`S
M,BP@(F,B(#T^("1T96UP97)A='5R90H@("`@("`@("`@("`I"B`@("`@("`@
M*3L*"B`@("`@("`@<F5T=7)N(')O=6YD*"1R97-U;'1;)&9R;VU=6R1T;UTL
M(#(I.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G9E<G13<&5E
M9"@I"B`@("`O*BH*("`@("`J($-O;G9E<G0@<W!E960@8F5T=V5E;B!M<&@L
M(&MM:"P@:W0L(&UP<RP@9G!S(&%N9"!B9G0*("`@("`J"B`@("`@*B!&=6YC
M=&EO;B!W:6QL(')E='5R;B`B9F%L<V4B('=H96X@=')Y:6YG('1O(&-O;G9E
M<G0@9G)O;0H@("`@("H@0F5A=69O<G0L(&%S(&ET(&ES(&$@<V-A;&4@86YD
M(&YO="!A('1R=64@;65A<W5R96UE;G0*("`@("`J"B`@("`@*B!`<&%R86T@
M("!F;&]A="`@("`@("`@("`@("`@("`@("`@("`@)'-P965D"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&9R;VT*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=&\*
M("`@("`J($!R971U<FX@(&9L;V%T?&EN='QB;V]L"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J($!L:6YK("`@(&AT='`Z+R]W=W<N<W!C+FYO86$N
M9V]V+V9A<2]T;W)N861O+V)E875F;W)T+FAT;6P*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N=F5R=%-P965D*"1S<&5E9"P@)&9R;VTL("1T;RD*("`@('L*
M("`@("`@("`D9G)O;2`]('-T<G1O;&]W97(H)&9R;VTI.PH@("`@("`@("1T
M;R`@(#T@<W1R=&]L;W=E<B@D=&\I.PH*("`@("`@("!S=&%T:6,@)&9A8W1O
M<CL*("`@("`@("!S=&%T:6,@)&)E875F;W)T.PH@("`@("`@(&EF("@A:7-S
M970H)&9A8W1O<BDI('L*("`@("`@("`@("`@)&9A8W1O<B`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@(FUP:"(@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@(FUP:"(@/3X@,2P@("`@("`@("`B:VUH(B`]/B`Q+C8P.3,T-"P@
M(FMT(B`]/B`P+C@V.#DW-C(L(")M<',B(#T^(#`N-#0W,#0L("`@(F9P<R(@
M/3X@,2XT-C8V-C8W"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@
M("`@(FMM:"(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FUP:"(@
M/3X@,"XV,C$S-S$R+"`B:VUH(B`]/B`Q+"`@("`@("`@(FMT(B`]/B`P+C4S
M.3DU-C@L(")M<',B(#T^(#`N,C<W-S<W."P@(F9P<R(@/3X@,"XY,3$S-#0T
M"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@(FMT(B`@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FUP:"(@/3X@,2XQ-3`W-SDT
M+"`B:VUH(B`]/B`Q+C@U,BP@("`@(FMT(B`]/B`Q+"`@("`@("`@(")M<',B
M(#T^(#`N-3$T-#0T-"P@(F9P<R(@/3X@,2XV.#<X,#DY"B`@("`@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`@("`@(FUP<R(@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@(FUP:"(@/3X@,BXR,S8Y,S8S+"`B:VUH(B`]/B`S
M+C8L("`@("`@(FMT(B`]/B`Q+CDT,S@T-#4L(")M<',B(#T^(#$L("`@("`@
M("`@(F9P<R(@/3X@,RXR.#`X,SDY"B`@("`@("`@("`@("`@("`I+`H@("`@
M("`@("`@("`@("`@(F9P<R(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@(FUP:"(@/3X@,"XV.#$X,3@R+"`B:VUH(B`]/B`Q+C`Y-S(X+"`@(FMT
M(B`]/B`P+C4Y,C0X,S@L(")M<',B(#T^(#`N,S`T."P@("`@(F9P<R(@/3X@
M,0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH*("`@("`@("`@
M("`@+R\@0F5A=69O<G0@<V-A;&4L(&UE87-U<F5M96YT<R!A<F4@:6X@:VYO
M=',*("`@("`@("`@("`@)&)E875F;W)T(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@(#$L("`@,RP@("`V+"`@,3`L"B`@("`@("`@("`@("`@("`@,38L
M("`R,2P@(#(W+"`@,S,L"B`@("`@("`@("`@("`@("`@-#`L("`T-RP@(#4U
M+"`@-C,*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M9G)O;2`]/2`B8F9T(BD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?2!E;'-E:68@*"1T;R`]/2`B8F9T(BD@>PH@("`@("`@("`@("`D
M<W!E960@/2!R;W5N9"@D<W!E960@*B`D9F%C=&]R6R1F<F]M75LB:W0B72P@
M,"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D8F5A
M=69O<G0I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)'-P965D(#P]
M("1B96%U9F]R=%LD:5TI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5T=7)N('-I>F5O9B@D8F5A=69O<G0I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!R;W5N9"@D<W!E960@*B`D9F%C=&]R6R1F
M<F]M75LD=&]=+"`R*3L*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@
M("`O+R![>WL@8V]N=F5R=%!R97-S=7)E*"D*("`@("\J*@H@("`@("H@0V]N
M=F5R="!P<F5S<W5R92!B971W965N(&EN+"!H<&$L(&UB+"!M;2!A;F0@871M
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5S<W5R90H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1F<F]M"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)'1O"B`@("`@*B!`<F5T=7)N("!F;&]A
M=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;G9E<G10<F5S<W5R92@D<')E<W-U<F4L("1F<F]M+"`D=&\I"B`@("![
M"B`@("`@("`@)&9R;VT@/2!S=')T;VQO=V5R*"1F<F]M*3L*("`@("`@("`D
M=&\@("`]('-T<G1O;&]W97(H)'1O*3L*"B`@("`@("`@<W1A=&EC("1F86-T
M;W(["B`@("`@("`@:68@*"%I<W-E="@D9F%C=&]R*2D@>PH@("`@("`@("`@
M("`D9F%C=&]R(#T@87)R87DH"B`@("`@("`@("`@("`@("`B:6XB("`@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`Q+"`@("`@("`@
M(")H<&$B(#T^(#,S+C@V,S@X-RP@(FUB(B`]/B`S,RXX-C,X.#<L(")M;2(@
M/3X@,C4N-"P@("`@("`B871M(B`]/B`P+C`S,S0R,3,*("`@("`@("`@("`@
M("`@("DL"B`@("`@("`@("`@("`@("`B:'!A(B`@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@(FEN(B`]/B`P+C`R.34S+"`@(")H<&$B(#T^(#$L
M("`@("`@("`@(FUB(B`]/B`Q+"`@("`@("`@(")M;2(@/3X@,"XW-3`P-C$V
M+"`B871M(B`]/B`P+C`P,#DX-CD*("`@("`@("`@("`@("`@("DL"B`@("`@
M("`@("`@("`@("`B;6(B("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@(FEN(B`]/B`P+C`R.34S+"`@(")H<&$B(#T^(#$L("`@("`@("`@(FUB
M(B`]/B`Q+"`@("`@("`@(")M;2(@/3X@,"XW-3`P-C$V+"`B871M(B`]/B`P
M+C`P,#DX-CD*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B
M;6TB("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`P
M+C`S.3,W,#$L(")H<&$B(#T^(#$N,S,S,C(S.2P@(FUB(B`]/B`Q+C,S,S(R
M,SDL(")M;2(@/3X@,2P@("`@("`@("`B871M(B`]/B`P+C`P,3,Q-3@*("`@
M("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B871M(B`@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`R.2PY,C$R-3@L(")H
M<&$B(#T^(#$P,3,N,C4P,2P@(FUB(B`]/B`Q,#$S+C(U,#$L(")M;2(@/3X@
M-S4Y+CDY.3DU,BP@(F%T;2(@/3X@,0H@("`@("`@("`@("`@("`@*0H@("`@
M("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(')O=6YD*"1P
M<F5S<W5R92`J("1F86-T;W);)&9R;VU=6R1T;UTL(#(I.PH@("`@?0H@("`@
M+R\@?7U]"@H@("`@+R\@>WM[(&-O;G9E<G1$:7-T86YC92@I"B`@("`O*BH*
M("`@("`J($-O;G9E<G0@9&ES=&%N8V4@8F5T=V5E;B!K;2P@9G0@86YD('-M
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@
M("`@("`@("1D:7-T86YC90H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1F<F]M"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)'1O"B`@("`@*B!`<F5T=7)N("!F;&]A
M=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;G9E<G1$:7-T86YC92@D9&ES=&%N8V4L("1F<F]M+"`D=&\I"B`@("![
M"B`@("`@("`@)'1O("`@/2!S=')T;VQO=V5R*"1T;RD["B`@("`@("`@)&9R
M;VT@/2!S=')T;VQO=V5R*"1F<F]M*3L*"B`@("`@("`@<W1A=&EC("1F86-T
M;W(["B`@("`@("`@:68@*"%I<W-E="@D9F%C=&]R*2D@>PH@("`@("`@("`@
M("`D9F%C=&]R(#T@87)R87DH"B`@("`@("`@("`@("`@("`B;2(@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@(FTB(#T^(#$L("`@("`@("`@("`@
M(FMM(B`]/B`Q,#`P+"`@("`@(")F="(@/3X@,RXR.#`X,SDX.34L(")S;2(@
M/3X@,"XP,#`V,C$S-CDY"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@
M("`@("`@(FMM(B`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`B;2(@
M/3X@,"XP,#$L("`@("`@("`B:VTB(#T^(#$L("`@("`@("`@(F9T(B`]/B`S
M,C@P+C@S.3@Y-2P@(G-M(B`]/B`P+C8R,3,V.3D*("`@("`@("`@("`@("`@
M("DL"B`@("`@("`@("`@("`@("`B9G0B(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@(")M(B`]/B`P+C,P-#@L("`@("`@(")K;2(@/3X@,"XP,#`S
M,#0X+"`B9G0B(#T^(#$L("`@("`@("`@("`B<VTB(#T^(#`N,#`P,3@Y-`H@
M("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@(")S;2(@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@(FTB(#T^(#`N,#`Q-C`Y,S0W,BP@
M(FMM(B`]/B`Q+C8P.3,T-S(L(")F="(@/3X@-3(X,"XP,3`V+"`@(")S;2(@
M/3X@,0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(')O=6YD*"1D:7-T86YC92`J("1F86-T;W);
M)&9R;VU=6R1T;UTL(#(I.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M(&-A;&-U;&%T95=I;F1#:&EL;"@I"B`@("`O*BH*("`@("`J($-A;&-U;&%T
M92!W:6YD8VAI;&P@9G)O;2!T96UP97)A='5R92!A;F0@=VEN9'-P965D("AE
M;FAA;F-E9"!F;W)M=6QA*0H@("`@("H*("`@("`J(%1E;7!E<F%T=7)E(&AA
M<R!T;R!B92!E;G1E<F5D(&EN(&1E9R!&+"!S<&5E9"!I;B!M<&@A"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@
M("1T96UP97)A='5R90H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@
M("`@("`@("`@("`@("1S<&5E9`H@("`@("H@0')E='5R;B`@9FQO870*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0&QI;FL@("`@:'1T<#HO+W=W
M=RYN=W,N;F]A82YG;W8O;VTO=VEN9&-H:6QL+PH@("`@("HO"B`@("!F=6YC
M=&EO;B!C86QC=6QA=&57:6YD0VAI;&PH)'1E;7!E<F%T=7)E+"`D<W!E960I
M"B`@("!["B`@("`@("`@<F5T=7)N(')O=6YD*#,U+C<T("L@,"XV,C$U("H@
M)'1E;7!E<F%T=7)E("T@,S4N-S4@*B!P;W<H)'-P965D+"`P+C$V*2`K(#`N
M-#(W-2`J("1T96UP97)A='5R92`J('!O=R@D<W!E960L(#`N,38I*3L*("`@
M('T*("`@("\O('U]?0H*("`@("\O('M[>R!C86QC=6QA=&5(=6UI9&ET>2@I
M"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!H=6UI9&ET>2!F<F]M('1E;7!E
M<F%T=7)E(&%N9"!D97=P;VEN=`H@("`@("H@5&AI<R!I<R!O;FQY(&%N(&%P
M<')O>&EM871I;VXL('1H97)E(&ES(&YO(&5X86-T(&9O<FUU;&$L('1H:7,*
M("`@("`J(&]N92!H97)E(&ES(&-A;&QE9"!-86=N=7,M1F]R;75L80H@("`@
M("H*("`@("`J(%1E;7!E<F%T=7)E(&%N9"!D97=P;VEN="!H879E('1O(&)E
M(&5N=&5R960@:6X@9&5G($,A"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO
M870@("`@("`@("`@("`@("`@("`@("`@("1T96UP97)A='5R90H@("`@("H@
M0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1D97=0;VEN
M=`H@("`@("H@0')E='5R;B`@9FQO870*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0&QI;FL@("`@:'1T<#HO+W=W=RYF87%S+F]R9R]F87%S+VUE
M=&5O<F]L;V=Y+W1E;7`M9&5W<&]I;G0O"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-A;&-U;&%T94AU;6ED:71Y*"1T96UP97)A='5R92P@)&1E=U!O:6YT*0H@
M("`@>PH@("`@("`@("\O($9I<G-T(&-A;&-U;&%T92!S871U<F%T:6]N('-T
M96%M('!R97-S=7)E(&9O<B!B;W1H('1E;7!E<F%T=7)E<PH@("`@("`@(&EF
M("@D=&5M<&5R871U<F4@/CT@,"D@>PH@("`@("`@("`@("`D82`](#<N-3L*
M("`@("`@("`@("`@)&(@/2`R,S<N,SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D82`](#<N-CL*("`@("`@("`@("`@)&(@/2`R-#`N-SL*("`@
M("`@("!]"B`@("`@("`@)'1E;7!34U`@/2`V+C$P-S@@*B!P;W<H,3`L("@D
M82`J("1T96UP97)A='5R92D@+R`H)&(@*R`D=&5M<&5R871U<F4I*3L*"B`@
M("`@("`@:68@*"1D97=0;VEN="`^/2`P*2!["B`@("`@("`@("`@("1A(#T@
M-RXU.PH@("`@("`@("`@("`D8B`](#(S-RXS.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1A(#T@-RXV.PH@("`@("`@("`@("`D8B`](#(T,"XW
M.PH@("`@("`@('T*("`@("`@("`D9&5W4U-0("`](#8N,3`W."`J('!O=R@Q
M,"P@*"1A("H@)&1E=U!O:6YT*2`O("@D8B`K("1D97=0;VEN="DI.PH*("`@
M("`@("!R971U<FX@<F]U;F0H,3`P("H@)&1E=U-34"`O("1T96UP4U-0+"`Q
M*3L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!C86QC=6QA=&5$97=0
M;VEN="@I"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!D97=P;VEN="!F<F]M
M('1E;7!E<F%T=7)E(&%N9"!H=6UI9&ET>0H@("`@("H@5&AI<R!I<R!O;FQY
M(&%N(&%P<')O>&EM871I;VXL('1H97)E(&ES(&YO(&5X86-T(&9O<FUU;&$L
M('1H:7,*("`@("`J(&]N92!H97)E(&ES(&-A;&QE9"!-86=N=7,M1F]R;75L
M80H@("`@("H*("`@("`J(%1E;7!E<F%T=7)E(&AA<R!T;R!B92!E;G1E<F5D
M(&EN(&1E9R!#(0H@("`@("H*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@
M("`@("`@("`@("`@("`@("`D=&5M<&5R871U<F4*("`@("`J($!P87)A;2`@
M(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D:'5M:61I='D*("`@("`J
M($!R971U<FX@(&9L;V%T"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!L:6YK("`@(&AT='`Z+R]W=W<N9F%Q<RYO<F<O9F%Q<R]M971E;W)O;&]G
M>2]T96UP+61E=W!O:6YT+PH@("`@("HO"B`@("!F=6YC=&EO;B!C86QC=6QA
M=&5$97=0;VEN="@D=&5M<&5R871U<F4L("1H=6UI9&ET>2D*("`@('L*("`@
M("`@("!I9B`H)'1E;7!E<F%T=7)E(#X](#`I('L*("`@("`@("`@("`@)&$@
M/2`W+C4["B`@("`@("`@("`@("1B(#T@,C,W+C,["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&$@/2`W+C8["B`@("`@("`@("`@("1B(#T@,C0P
M+C<["B`@("`@("`@?0H*("`@("`@("`O+R!&:7)S="!C86QC=6QA=&4@<V%T
M=7)A=&EO;B!S=&5A;2!P<F5S<W5R92!F;W(@=&5M<&5R871U<F4*("`@("`@
M("`D4U-0(#T@-BXQ,#<X("H@<&]W*#$P+"`H)&$@*B`D=&5M<&5R871U<F4I
M("\@*"1B("L@)'1E;7!E<F%T=7)E*2D["@H@("`@("`@("\O(%-T96%M('!R
M97-S=7)E"B`@("`@("`@)%-0("`]("1H=6UI9&ET>2`O(#$P,"`J("134U`[
M"@H@("`@("`@("1V("`@/2!L;V<H)%-0("\@-BXQ,#<X+"`Q,"D["@H@("`@
M("`@(')E='5R;B!R;W5N9"@D8B`J("1V("\@*"1A("T@)'8I+"`Q*3L*("`@
M('T*("`@("\O('U]?0H*("`@("\O('M[>R!P;VQA<C)C87)T97-I86XH*0H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T('!O;&%R(&-O;W)D:6YA=&5S('1O(&-A
M<G1E<VEA;B!C;V]R9&EN871E<PH@("`@("H*("`@("`J($!P87)A;2`@(&9L
M;V%T("`@("`@("`@("`@("`@("`@("`@("`D;&%T:71U9&4*("`@("`J($!P
M87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D;&]N9VET=61E
M"B`@("`@*B!`<F5T=7)N("!A<G)A>0H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;&%R,F-A<G1E<VEA;B@D;&%T:71U
M9&4L("1L;VYG:71U9&4I"B`@("!["B`@("`@("`@)'1H971A(#T@9&5G,G)A
M9"@D;&%T:71U9&4I.PH@("`@("`@("1P:&D@("`](&1E9S)R860H)&QO;F=I
M='5D92D["@H@("`@("`@("1X(#T@4T525DE#15-?5T5!5$A%4E]2041)55-?
M14%25$@@*B!C;W,H)'!H:2D@*B!C;W,H)'1H971A*3L*("`@("`@("`D>2`]
M(%-%4E9)0T537U=%051(15)?4D%$25537T5!4E1(("H@<VEN*"1P:&DI("H@
M8V]S*"1T:&5T82D["B`@("`@("`@)'H@/2!315)624-%4U]714%42$527U)!
M1$E54U]%05)42"`@("`@("`@("`@("`J('-I;B@D=&AE=&$I.PH*("`@("`@
M("!R971U<FX@87)R87DH)'@L("1Y+"`D>BD["B`@("!]"B`@("`O+R!]?7T*
M"@H@("`@+R\@>WM[(&-A;&-U;&%T95-U;E)I<V53970H*0H@("`@+RHJ"B`@
M("`@*B!#86QC=6QA=&5S('-U;G)I<V4@86YD('-U;G-E="!F;W(@82!L;V-A
M=&EO;@H@("`@("H*("`@("`J(%1H92!S=6X@<&]S:71I;VX@86QG;W)I=&AM
M('1A:V5N(&9R;VT@=&AE("=54R!.879A;"!/8G-E<G9A=&]R>2=S"B`@("`@
M*B!!;&UA;F%C(&9O<B!#;VUP=71E<G,G+"!I;7!L96UE;G1E9"!B>2!+96X@
M0FQO;VT@/&ME:V%B;&]O;5MA=%UU8V1A=FES6V1O=%UE9'4^"B`@("`@*B!F
M;W(@=&AE('IM86YI;2!P<F]J96-T+"!C;VYV97)T960@=&\@0R!B>2!-;W-H
M92!$;W)O;B`\;6]S9&]R;VY;871=;F5T=FES:6]N6V1O=%UN971;9&]T76EL
M/@H@("`@("H@86YD(&9I;F%L;'D@=&%K96X@9G)O;2!T:&4@4$A0-2!S;W5R
M8V5S(&%N9"!C;VYV97)T960@=&\@;F%T:79E(%!(4"!A<R!A('=R87!P97(N
M"B`@("`@*@H@("`@("H@5&AE(&1A=&4@:&%S('1O(&)E(&5N=&5R960@87,@
M82!T:6UE<W1A;7`A"B`@("`@*@H@("`@("H@0'!A<F%M("`@:6YT("`@("`@
M("`@("`@("`@("`@("`@("`@("1D871E"B`@("`@*B!`<&%R86T@("!I;G0@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E=&9O<FUA=`H@("`@("H@0'!A
M<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1L871I='5D90H@
M("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1L
M;VYG:71U9&4*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@
M("`@("`@("`D>F5N:71H"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@
M("`@("`@("`@("`@("`@)&=M=%]O9F9S970*("`@("`J($!P87)A;2`@(&)O
M;VP@("`@("`@("`@("`@("`@("`@("`@("`D<W5N<FES90H@("`@("H@0')E
M='5R;B`@4$5!4E]%<G)O<GQM:7AE9`H@("`@("H@0'1H<F]W<R`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]354Y&54Y#4U]$051%7TE.
M5D%,240*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%
M051(15)?15)23U)?4U5.1E5.0U-?4D541D]235])3E9!3$E$"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U5.
M2TY/5TY?15)23U(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!C86QC=6QA=&53=6Y2:7-E4V5T*"1D871E+"`D<F5T9F]R
M;6%T(#T@;G5L;"P@)&QA=&ET=61E(#T@;G5L;"P@)&QO;F=I='5D92`](&YU
M;&PL("1Z96YI=&@@/2!N=6QL+"`D9VUT7V]F9G-E="`](&YU;&PL("1S=6YR
M:7-E(#T@=')U92D*("`@('L*("`@("`@("`O+R!$871E(&UU<W0@8F4@=&EM
M97-T86UP(&9O<B!N;W<*("`@("`@("!I9B`H(6ES7VEN="@D9&%T92DI('L*
M("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R
M;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]354Y&54Y#4U]$051%7TE.5D%,
M240L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O
M+R!#:&5C:R!F;W(@<')O<&5R(')E='5R;B!F;W)M870*("`@("`@("!I9B`H
M)')E=&9O<FUA="`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<F5T9F]R;6%T
M("`](%-53D953D-37U)%5%]35%))3D<["B`@("`@("`@?2!E;'-E:68@*"%I
M;E]A<G)A>2@D<F5T9F]R;6%T+"!A<G)A>2A354Y&54Y#4U]2151?5$E-15-4
M04U0+"!354Y&54Y#4U]2151?4U1224Y'+"!354Y&54Y#4U]2151?1$]50DQ%
M*2D@*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR
M86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?4U5.1E5.0U-?4D54
M1D]235])3E9!3$E$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@4V5T(&1E9F%U;'0@=F%L=65S(&9O<B!C;V]R9&EN871E
M<PH@("`@("`@(&EF("@D;&%T:71U9&4@/3T](&YU;&PI('L*("`@("`@("`@
M("`@)&QA=&ET=61E("`@/2!354Y&54Y#4U]$149!54Q47TQ!5$E4541%.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L871I='5D92`@(#T@*&9L
M;V%T*2`D;&%T:71U9&4["B`@("`@("`@?0H@("`@("`@(&EF("@D;&]N9VET
M=61E(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1L;VYG:71U9&4@(#T@4U5.
M1E5.0U-?1$5&055,5%],3TY'25151$4["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&QO;F=I='5D92`@/2`H9FQO870I("1L;VYG:71U9&4["B`@
M("`@("`@?0H@("`@("`@(&EF("@D>F5N:71H(#T]/2!N=6QL*2!["B`@("`@
M("`@("`@(&EF*"1S=6YR:7-E*2!["B`@("`@("`@("`@("`@("`D>F5N:71H
M(#T@4U5.1E5.0U-?4U5.4DE315]:14Y)5$@["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D>F5N:71H(#T@4U5.1E5.0U-?4U5.4T54
M7UI%3DE42#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1Z96YI=&@@("`@(#T@*&9L;V%T*2`D>F5N:71H.PH@("`@("`@
M('T*"B`@("`@("`@+R\@1&5F875L="!V86QU92!F;W(@1TU4(&]F9G-E=`H@
M("`@("`@(&EF("@D9VUT7V]F9G-E="`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("`D9VUT7V]F9G-E="`](&1A=&4H(EHB+"`D9&%T92D@+R`S-C`P.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1G;71?;V9F<V5T(#T@*&9L;V%T
M*2`D9VUT7V]F9G-E=#L*("`@("`@("!]"@H@("`@("`@("\O($EF('=E(&AA
M=F4@4$A0-2P@=&AE;B!A8W0@87,@=W)A<'!E<B!F;W(@=&AE(&%P<')O<')I
M871E(&9U;F-T:6]N<PH@("`@("`@(&EF("@D<W5N<FES92`F)B!F=6YC=&EO
M;E]E>&ES=',H(F1A=&5?<W5N<FES92(I*2!["B`@("`@("`@("`@(')E='5R
M;B!D871E7W-U;G)I<V4H)&1A=&4L("1R971F;W)M870L("1L871I='5D92P@
M)&QO;F=I='5D92P@)'IE;FET:"P@)&=M=%]O9F9S970I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21S=6YR:7-E("8F(&9U;F-T:6]N7V5X:7-T<R@B9&%T
M95]S=6YS970B*2D@>PH@("`@("`@("`@("!R971U<FX@9&%T95]S=6YS970H
M)&1A=&4L("1R971F;W)M870L("1L871I='5D92P@)&QO;F=I='5D92P@)'IE
M;FET:"P@)&=M=%]O9F9S970I.PH@("`@("`@('T*"B`@("`@("`@+R\@07!P
M87)E;G1L>2!W92!H879E(%!(4#0L('-O(&-A;&-U;&%T92!T:&4@;F5C8V5S
M<V%R>2!S=&5P<R!I;B!N871I=F4@4$A0"B`@("`@("`@+R\@4W1E<"`Q.B!&
M:7)S="!C86QC=6QA=&4@=&AE(&1A>2!O9B!T:&4@>65A<@H@("`@("`@("1.
M(#T@9&%T92@B>B(L("1D871E*2`K(#$["@H@("`@("`@("\O(%-T97`@,CH@
M0V]N=F5R="!T:&4@;&]N9VET=61E('1O(&AO=7(@=F%L=64@86YD(&-A;&-U
M;&%T92!A;B!A<'!R;WAI;6%T92!T:6UE"B`@("`@("`@)&QN9TAO=7(@/2`D
M;&]N9VET=61E("\@,34["@H@("`@("`@("\O(%5S92`Q."!F;W(@<W5N<V5T
M(&EN<W1E860@;V8@-@H@("`@("`@(&EF("@D<W5N<FES92D@>PH@("`@("`@
M("`@("`O+R!3=6YR:7-E"B`@("`@("`@("`@("1T(#T@)$X@*R`H*#8@+2`D
M;&YG2&]U<BD@+R`R-"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+R\@4W5N<V5T"B`@("`@("`@("`@("1T(#T@)$X@*R`H*#$X("T@)&QN9TAO
M=7(I("\@,C0I.PH@("`@("`@('T*"B`@("`@("`@+R\@4W1E<"`S.B!#86QC
M=6QA=&4@=&AE('-U;B=S(&UE86X@86YO;6%L>0H@("`@("`@("1-(#T@*#`N
M.3@U-B`J("1T*2`M(#,N,C@Y.PH*("`@("`@("`O+R!3=&5P(#0Z($-A;&-U
M;&%T92!T:&4@<W5N)W,@=')U92!L;VYG:71U9&4*("`@("`@("`D3"`]("1-
M("L@*#$N.3$V("H@<VEN*&1E9S)R860H)$TI*2D@*R`H,"XP,C`@*B!S:6XH
M9&5G,G)A9"@R("H@)$TI*2D@*R`R.#(N-C,T.PH*("`@("`@("!W:&EL92`H
M)$P@/"`P*2!["B`@("`@("`@("`@("1,>"`]("1,("L@,S8P.PH@("`@("`@
M("`@("!A<W-E<G0H)$QX("$]("1,*3L@+R\@87-K:6YG=&AE9W5R=3H@<F5A
M;&QY(&YE961E9#\*("`@("`@("`@("`@)$P@/2`D3'@["B`@("`@("`@?0H*
M("`@("`@("!W:&EL92`H)$P@/CT@,S8P*2!["B`@("`@("`@("`@("1,>"`]
M("1,("T@,S8P.PH@("`@("`@("`@("!A<W-E<G0H)$QX("$]("1,*3L@+R\@
M87-K:6YG=&AE9W5R=3H@<F5A;&QY(&YE961E9#\*("`@("`@("`@("`@)$P@
M/2`D3'@["B`@("`@("`@?0H*("`@("`@("`O+R!3=&5P(#5A.B!#86QC=6QA
M=&4@=&AE('-U;B=S(')I9VAT(&%S8V5N<VEO;@H@("`@("`@("1202`](')A
M9#)D96<H871A;B@P+CDQ-S8T("H@=&%N*&1E9S)R860H)$PI*2DI.PH*("`@
M("`@("!W:&EL92`H)%)!(#P@,"D@>PH@("`@("`@("`@("`D4D%X(#T@)%)!
M("L@,S8P.PH@("`@("`@("`@("!A<W-E<G0H)%)!>"`A/2`D4D$I.R`O+R!A
M<VMI;F=T:&5G=7)U.B!R96%L;'D@;F5E9&5D/PH@("`@("`@("`@("`D4D$@
M/2`D4D%X.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*"1202`^/2`S-C`I
M('L*("`@("`@("`@("`@)%)!>"`]("1202`M(#,V,#L*("`@("`@("`@("`@
M87-S97)T*"1207@@(3T@)%)!*3L@+R\@87-K:6YG=&AE9W5R=3H@<F5A;&QY
M(&YE961E9#\*("`@("`@("`@("`@)%)!(#T@)%)!>#L*("`@("`@("!]"@H@
M("`@("`@("\O(%-T97`@-6(Z(%)I9VAT(&%S8V5N<VEO;B!V86QU92!N965D
M<R!T;R!B92!I;B!T:&4@<V%M92!Q=6%D<F%N="!A<R!,"B`@("`@("`@)$QQ
M=6%D<F%N="`@/2!F;&]O<B@D3"`O(#DP*2`J(#DP.PH@("`@("`@("1207%U
M861R86YT(#T@9FQO;W(H)%)!("\@.3`I("H@.3`["@H@("`@("`@("1202`]
M("1202`K("@D3'%U861R86YT("T@)%)!<75A9')A;G0I.PH*("`@("`@("`O
M+R!3=&5P(#5C.B!2:6=H="!A<V-E;G-I;VX@=F%L=64@;F5E9',@=&\@8F4@
M8V]N=F5R=&5D(&EN=&\@:&]U<G,*("`@("`@("`D4D$@+ST@,34["@H@("`@
M("`@("\O(%-T97`@-CH@0V%L8W5L871E('1H92!S=6XG<R!D96-L:6YA=&EO
M;@H@("`@("`@("1S:6Y$96,@/2`P+C,Y-S@R("H@<VEN*&1E9S)R860H)$PI
M*3L*("`@("`@("`D8V]S1&5C(#T@8V]S*&%S:6XH)'-I;D1E8RDI.PH*("`@
M("`@("`O+R!3=&5P(#=A.B!#86QC=6QA=&4@=&AE('-U;B=S(&QO8V%L(&AO
M=7(@86YG;&4*("`@("`@("`D8V]S2"`]("AC;W,H9&5G,G)A9"@D>F5N:71H
M*2D@+2`H)'-I;D1E8R`J('-I;BAD96<R<F%D*"1L871I='5D92DI*2D@+R`H
M)&-O<T1E8R`J(&-O<RAD96<R<F%D*"1L871I='5D92DI*3L*"B`@("`@("`@
M+R\@6%A8.B!7:&%T)W,@=&AE('5S92!O9B!T:&ES(&)L;V-K+BX@/PH@("`@
M("`@("\O(&EF("AS=6YR:7-E("8F(&-O<T@@/B`Q('Q\("%S=6YR:7-E("8F
M(&-O<T@@/"`M,2D@>PH@("`@("`@("\O("`@("!T:')O=R!D;V5S;G1H87!P
M96XH*3L*("`@("`@("`O+R!]"@H@("`@("`@("\O(%-T97`@-V(Z($9I;FES
M:"!C86QC=6QA=&EN9R!((&%N9"!C;VYV97)T(&EN=&\@:&]U<G,*("`@("`@
M("!I9B`H)'-U;G)I<V4I('L*("`@("`@("`@("`@+R\@4W5N<FES90H@("`@
M("`@("`@("`D2"`](#,V,"`M(')A9#)D96<H86-O<R@D8V]S2"DI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\O(%-U;G-E=`H@("`@("`@("`@
M("`D2"`](')A9#)D96<H86-O<R@D8V]S2"DI.PH@("`@("`@('T*("`@("`@
M("`D2"`]("1(("\@,34["@H@("`@("`@("\O(%-T97`@.#H@0V%L8W5L871E
M(&QO8V%L(&UE86X@=&EM90H@("`@("`@("14(#T@)$@@*R`D4D$@+2`H,"XP
M-C4W,2`J("1T*2`M(#8N-C(R.PH*("`@("`@("`O+R!3=&5P(#DZ($-O;G9E
M<G0@=&\@551#"B`@("`@("`@)%54(#T@)%0@+2`D;&YG2&]U<CL*"B`@("`@
M("`@=VAI;&4@*"155"`\(#`I('L*("`@("`@("`@("`@)%54>"`]("155"`K
M(#(T.PH@("`@("`@("`@("!A<W-E<G0H)%54>"`A/2`D550I.R`O+R!A<VMI
M;F=T:&5G=7)U.B!R96%L;'D@;F5E9&5D/PH@("`@("`@("`@("`D550@/2`D
M551X.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*"155"`^/2`R-"D@>PH@
M("`@("`@("`@("`D551X(#T@)%54("T@,C0["B`@("`@("`@("`@(&%S<V5R
M="@D551X("$]("155"D[("\O(&%S:VEN9W1H96=U<G4Z(')E86QL>2!N965D
M960_"B`@("`@("`@("`@("155"`]("155'@["B`@("`@("`@?0H*("`@("`@
M("`D550@/2`D550@*R`D9VUT7V]F9G-E=#L*"B`@("`@("`@+R\@3F]W(&)R
M:6YG('1H92!R97-U;'0@:6YT;R!T:&4@8VAO<V5N(&9O<FUA="!A;F0@<F5T
M=7)N"B`@("`@("`@<W=I=&-H("@D<F5T9F]R;6%T*2!["B`@("`@("`@("`@
M(&-A<V4@4U5.1E5.0U-?4D547U1)34535$%-4#H*("`@("`@("`@("`@("`@
M(')E='5R;B!F;&]O<B@D9&%T92`M("@D9&%T92`E("@R-"`J(#,V,#`I*2D@
M*R!F;&]O<B@V,"`J("155"D["B`@("`@("`@("`@(&-A<V4@4U5.1E5.0U-?
M4D547U-44DE.1SH*("`@("`@("`@("`@("`@("1.(#T@9FQO;W(H)%54*3L*
M("`@("`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"(E,#)D.B4P,F0B+"`D
M3BP@9FQO;W(H-C`@*B`H)%54("T@)$XI*2D["B`@("`@("`@("`@(&-A<V4@
M4U5.1E5.0U-?4D547T1/54),13H*("`@("`@("`@("`@("`@(')E='5R;B`D
M550["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27U5.2TY/5TY?15)23U(L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E
M871H97))8V]N*"D*("`@("\J*@H@("`@("H@1V5T<R!A(&YU;6)E<B!C;W)R
M97-P;VYD:6YG('1O(&$@=V5A=&AE<B!I8V]N+@H@("`@("H*("`@("`J(%1H
M97-E(&YU;6)E<G,@:G5S="!H87!P96X@=&\@8V]R<F5S<&]N9"!W:71H('1H
M92!I8V]N<R!T:&%T('EO=2!G970@=VET:`H@("`@("H@=&AE('=E871H97(N
M8V]M(%-$2RP@8G5T(&]P96X@=F5R<VEO;G,@;V8@=&AE;2!H879E(&)E96X@
M8W)E871E9"X@26YP=70*("`@("`J(&UU<W0@8F4@:6X@<W1A;F1A<F0@=6YI
M=',N($9O<B!T:&4@:6-O;G,@=&AA="!I;F-L=61E(&1A>2]N:6=H="P@=V4@
M=7-E"B`@("`@*B!T:&4@<')E<V5N="!T:6UE(&%N9"!T:&4@<')O=FED960@
M;&%T+VQO;B!T;R!D971E<FUI;F4@:68@=&AE('-U;B!I<R!U<"X*("`@("`J
M($$@8V]M<&QE=&4@<V5T(&]F(&EC;VX@9&5S8W)I<'1I;VYS(&-A;B!B92!F
M;W5N9"!H97)E.@H@("`@("H@:'1T<#HO+W-R86YS:&%F="YW:6YC=7-T;VUI
M>F4N8V]M+T%R=&EC;&5S+F%S<'@_04E$/38P,38U)G4],`H@("`@("H*("`@
M("`J(%1H97)E(&%R92!A(&YU;6)E<B!O9B!I8V]N('-E=',@:&5R93H*("`@
M("`J(&AT='`Z+R]W=W<N9&5S:W1O<'-I9&5B87(N8V]M+V9O<G5M<R]I;F1E
M>"YP:'`_<VAO=W1O<&EC/3(T-#$F<W0],`H@("`@("H@:'1T<#HO+W=W=RYD
M97-K=&]P<VED96)A<BYC;VTO9F]R=6US+VEN9&5X+G!H<#]S:&]W=&]P:6,]
M.#$Y"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1C;VYD:71I;VX@("`@("!4:&4@8V]N9&ET:6]N+@H@("`@
M("H@0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1C;&]U
M9',@("`@("`@("!4:&4@8VQO=61S(&%T('9A<FEO=7,@;&5V96QS+@H@("`@
M("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1W:6YD
M("`@("`@("`@("!7:6YD('-P965D(&EN(&UP:"X*("`@("`J($!P87)A;2`@
M(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D=&5M<&5R871U<F4@("`@
M5&5M<&5R871U<F4@:6X@9&5G($8N"B`@("`@*B!`<&%R86T@("!F;&]A="`@
M("`@("`@("`@("`@("`@("`@("`@)&QA=&ET=61E("`@("`@(%!O:6YT(&QA
M=&ET=61E+@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@
M("`@("`@("1L;VYG:71U9&4@("`@("!0;VEN="!L;VYG:71U9&4N"B`@("`@
M*B!`875T:&]R("!3971H(%!R:6-E("`\<V5T:$!P<FEC97!A9V5S+F]R9SX*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M971796%T:&5R26-O;B@D8V]N9&ET:6]N+"`D8VQO=61S(#T@87)R87DH*2P@
M)'=I;F0@/2`U+"`D=&5M<&5R871U<F4@/2`W,"P@)&QA=&ET=61E(#T@+3,V
M,"P@)&QO;F=I='5D92`]("TS-C`I"B`@("!["B`@("`@("`@+R\@4V5A<F-H
M(&9O<B!M871C:&5S('1H870@9&]N)W0@=7-E('1H92!T:6UE(&]F(&1A>0H@
M("`@("`@("1H86EL("`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL
M(")H86EL(BD["B`@("`@("`@)&1U<W0@("`@(#T@*&)O;VPI('-T<FES='(H
M)&-O;F1I=&EO;BP@(F1U<W0B*2`@("`@?'P@*&)O;VPI('-T<FES='(H)&-O
M;F1I=&EO;BP@(G-A;F0B*3L*("`@("`@("`D<VUO:V4@("`@/2`H8F]O;"D@
M<W1R:7-T<B@D8V]N9&ET:6]N+"`B<VUO:V4B*2`@("!\?"`H8F]O;"D@<W1R
M:7-T<B@D8V]N9&ET:6]N+"`B=F]L8V%N:6,@87-H(BD["@H@("`@("`@("\O
M(%-L:6=H=&QY(&UO<F4@8V]M<&QE>"!M871C:&5S('1H870@;6EG:'0@;W(@
M;6EG:'0@;F]T('5S92!T:&4@=&EM92!O9B!D87D*("`@("`@("`D;F5A<B`@
M("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B=FEC:6YI='DB*2!\
M?"`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B<F5C96YT(BD["B`@("`@
M("`@)&QI9VAT("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(FQI
M9VAT(BD["B`@("`@("`@)&AE879Y("`@(#T@*&)O;VPI('-T<FES='(H)&-O
M;F1I=&EO;BP@(FAE879Y(BD["B`@("`@("`@)&EC92`@("`@(#T@*&)O;VPI
M('-T<FES='(H)&-O;F1I=&EO;BP@(FEC92(I("`@("`@?'P@*&)O;VPI('-T
M<FES='(H)&-O;F1I=&EO;BP@(G!E;&QE=',B*3L*("`@("`@("`D<F%I;B`@
M("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B<F%I;B(I.PH@("`@
M("`@("1S;F]W("`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL(")S
M;F]W(BD["B`@("`@("`@)&9O9R`@("`@(#T@*&)O;VPI('-T<FES='(H)&-O
M;F1I=&EO;BP@(F9O9R(I("`@("`@?'P@*&)O;VPI('-T<FES='(H)&-O;F1I
M=&EO;BP@(G-P<F%Y(BD@("`@("`@('Q\("AB;V]L*2!S=')I<W1R*"1C;VYD
M:71I;VXL(")M:7-T(BD["B`@("`@("`@)&AA>F4@("`@(#T@*&)O;VPI('-T
M<FES='(H)&-O;F1I=&EO;BP@(FAA>F4B*3L*("`@("`@("`D=',@("`@("`@
M/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B=&AU;F1E<G-T;W)M(BD[
M"B`@("`@("`@)&9R965Z:6YG(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO
M;BP@(F9R965Z:6YG(BD["B`@("`@("`@)'=I;F0@("`@(#T@*&)O;VPI('-T
M<FES='(H)&-O;F1I=&EO;BP@(G-Q=6%L;"(I("`@?'P@)'=I;F0@/B`R-3L*
M("`@("`@("`D;G-W("`@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N
M+"`B;F\@<VEG;FEF:6-A;G0@=V5A=&AE<B(I.PH@("`@("`@("1H;W0@("`@
M("`]("1T96UP97)A='5R92`^(#DU.PH@("`@("`@("1F<FEG:60@("`]("1T
M96UP97)A='5R92`\(#4["@H*("`@("`@("!I9B`H)&AA:6PI('L*("`@("`@
M("`@("`@<F5T=7)N(#8[("`O+R!(86EL"B`@("`@("`@?0H@("`@("`@(&EF
M("@D9'5S="D@>PH@("`@("`@("`@("!R971U<FX@,3D[("\O($1U<W0*("`@
M("`@("!]"B`@("`@("`@:68@*"1S;6]K92D@>PH@("`@("`@("`@("!R971U
M<FX@,C([("\O(%-M;VME"B`@("`@("`@?0H*("`@("`@("`O+R!'970@<V]M
M92!O9B!T:&4@9&%N9V5R;W5S(&-O;F1I=&EO;G,@9FES=`H@("`@("`@(&EF
M("@D<F%I;B`F)B`D<VYO=R`F)B`H)&EC92!\?"`D9G)E97II;F<I*2!["B`@
M("`@("`@("`@(')E='5R;B`W.R`@+R\@26-Y+T-L;W5D<R!286EN+5-N;W<*
M("`@("`@("!]"B`@("`@("`@:68@*"@D=',@?'P@)')A:6XI("8F("@D:6-E
M('Q\("1F<F5E>FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N(#$P.R`O+R!)
M8WDO4F%I;@H@("`@("`@('T*("`@("`@("!I9B`H*"1F;V<@?'P@)&AA>F4I
M("8F("@D:6-E('Q\("1F<F5E>FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N
M(#@[("`O+R!)8WDO2&%Z92!286EN"B`@("`@("`@?0H@("`@("`@(&EF("@D
M<F%I;B`F)B`D<VYO=RD@>PH@("`@("`@("`@("!R971U<FX@-3L@("\O($-L
M;W5D>2]3;F]W+5)A:6X@36EX"B`@("`@("`@?0H@("`@("`@(&EF("@D9F]G
M("8F("1R86EN*2!["B`@("`@("`@("`@(')E='5R;B`Y.R`@+R\@2&%Z92]2
M86EN"B`@("`@("`@?0H@("`@("`@(&EF("@D=VEN9"`F)B`D<F%I;BD@>PH@
M("`@("`@("`@("!R971U<FX@,3L@("\O(%=I;F0O4F%I;@H@("`@("`@('T*
M("`@("`@("!I9B`H)'=I;F0@)B8@)'-N;W<I('L*("`@("`@("`@("`@<F5T
M=7)N(#0S.R`O+R!7:6YD>2]3;F]W"B`@("`@("`@?0H@("`@("`@(&EF("@D
M<VYO=R`F)B`D;&EG:'0I('L*("`@("`@("`@("`@<F5T=7)N(#$S.R`O+R!&
M;'5R<FEE<PH@("`@("`@('T*("`@("`@("!I9B`H)&QI9VAT("8F("1R86EN
M*2!["B`@("`@("`@("`@(')E='5R;B`Q,3L@+R\@3&EG:'0@4F%I;@H@("`@
M("`@('T*"B`@("`@("`@+R\@1V5T('1H92!M87AI;75M(&-O=F5R86=E(&]F
M('1H92!C;&]U9',@870@86YY(&AE:6=H="X@1F]R(&UO<W0*("`@("`@("`O
M+R!P96]P;&4L(&]V97)C87-T(&%T(#$P,#!F="!I<R!T:&4@<V%M92!A<R!O
M=F5R8V%S="!A="`Q,#`P,&9T+@H@("`@("`@("\O"B`@("`@("`@+R\@,"`]
M/2!C;&5A<BP@,2`]/2!H87IE>2P@,B`]/2!P87)T;'D@8VQO=61Y+"`S(#T]
M(&UO<W1L>2!C;&]U9'DL(#0@/3T@;W9E<F-A<W0*("`@("`@("`D8V]V97)A
M9V4@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1C;&]U9',@87,@)&QA>65R*2![
M"B`@("`@("`@("`@(&EF("@D8V]V97)A9V4@/"`Q("8F('-T<FES='(H)&QA
M>65R6R)A;6]U;G0B72P@(F9E=R(I*2!["B`@("`@("`@("`@("`@("`D8V]V
M97)A9V4@/2`Q.PH@("`@("`@("`@("!](&5L<V5I9B`H)&-O=F5R86=E(#P@
M,B`F)B!S=')I<W1R*"1L87EE<ELB86UO=6YT(ETL(")S8V%T=&5R960B*2D@
M>PH@("`@("`@("`@("`@("`@)&-O=F5R86=E(#T@,CL*("`@("`@("`@("`@
M?2!E;'-E:68@*"1C;W9E<F%G92`\(#,@)B8@*'-T<FES='(H)&QA>65R6R)A
M;6]U;G0B72P@(F)R;VME;B(I('Q\('-T<FES='(H)&QA>65R6R)A;6]U;G0B
M72P@(F-U;75L=7,B*2DI('L*("`@("`@("`@("`@("`@("1C;W9E<F%G92`]
M(#,["B`@("`@("`@("`@('T@96QS96EF("@D8V]V97)A9V4@/"`T("8F('-T
M<FES='(H)&QA>65R6R)A;6]U;G0B72P@(F]V97)C87-T(BDI('L*("`@("`@
M("`@("`@("`@("1C;W9E<F%G92`](#0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O($-H96-K(&EF(&ET(&ES(&1A>2!O<B!N;W0N(#`@
M:7,@;FEG:'0L(#(@:7,@9&%Y+"!A;F0@,2!I<R!U;FMN;W=N"B`@("`@("`@
M+R\@;W(@='=I;&EG:'0@*'XH*WPM*3$@:&]U<B!O9B!S=6YR:7-E+W-U;G-E
M="DN($YO=&4@=&AA="!T=VEL:6=H="!I<VXG=`H@("`@("`@("\O(&%L=V%Y
M<R!A8V-U<F%T92!B96-A=7-E(&]F(&ES<W5E<R!W<F%P<&EN9R!A<F]U;F0@
M=&AE(#(T:'(@8VQO8VLN($]H('=E;&PN+BX*("`@("`@("!I9B`H)&QA=&ET
M=61E(#P@.3`@)B8@)&QA=&ET=61E(#X@+3DP("8F("1L;VYG:71U9&4@/"`Q
M.#`@)B8@)&QO;F=I='5D92`^("TQ.#`I('L*("`@("`@("`@("`@+R\@0V%L
M8W5L871E('-U;G)I<V4O<W5N<V5T(&%N9"!C=7)R96YT('1I;64@:6X@1TU4
M"B`@("`@("`@("`@("1S=6YR:7-E("`@/2`D=&AI<RT^8V%L8W5L871E4W5N
M4FES95-E="AG;6UK=&EM92@I+"!354Y&54Y#4U]2151?5$E-15-404U0+"`D
M;&%T:71U9&4L("1L;VYG:71U9&4L(%-%4E9)0T537U=%051(15)?4U5.1E5.
M0U-?4U5.4DE315]:14Y)5$@L(#`L('1R=64I.PH@("`@("`@("`@("`D<W5N
M<V5T("`@(#T@)'1H:7,M/F-A;&-U;&%T95-U;E)I<V53970H9VUM:W1I;64H
M*2P@4U5.1E5.0U-?4D547U1)34535$%-4"P@)&QA=&ET=61E+"`D;&]N9VET
M=61E+"!315)624-%4U]714%42$527U-53D953D-37U-53E))4T5?6D5.251(
M+"`P+"!F86QS92D["B`@("`@("`@("`@("1T:6UE3V9$87D@/2!G;6UK=&EM
M92@I.PH*("`@("`@("`@("`@+R\@3F]W('1H870@=V4@:&%V92!T:&4@<W5N
M<FES92]S=6YS970@=&EM97,@86YD('1H92!C=7)R96YT('1I;64L"B`@("`@
M("`@("`@("\O('=E(&YE960@=&\@9FEG=7)E(&]U="!I9B!I="!I<R!D87DL
M(&YI9VAT+"!O<B!T=VEL:6=H="X@5W)A<'!I;F<*("`@("`@("`@("`@+R\@
M=&AE<V4@=&EM97,@87)O=6YD('1H92`R-&AR(&-L;V-K(&ES(&$@<&%I;BX*
M("`@("`@("`@("`@:68@*"1S=6YR:7-E(#P@)'-U;G-E="D@>PH@("`@("`@
M("`@("`@("`@:68@*"1T:6UE3V9$87D@/B`H)'-U;G)I<V4@*R`S-C`P*2`F
M)B`D=&EM94]F1&%Y(#P@*"1S=6YS970@+2`S-C`P*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1I<T1A>2`](#(["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)'1I;65/9D1A>2`^("@D<W5N<FES92`M(#,V,#`I("8F("1T:6UE3V9$
M87D@/"`H)'-U;G-E="`K(#,V,#`I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&ES1&%Y(#T@,3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&ES1&%Y(#T@,#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D=&EM94]F
M1&%Y(#P@*"1S=6YR:7-E("T@,S8P,"D@)B8@)'1I;65/9D1A>2`^("@D<W5N
M<V5T("L@,S8P,"DI('L*("`@("`@("`@("`@("`@("`@("`D:7-$87D@/2`P
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:6UE3V9$87D@/"`H)'-U
M;G)I<V4@*R`S-C`P*2`F)B`D=&EM94]F1&%Y(#X@*"1S=6YS970@+2`S-C`P
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1I<T1A>2`](#$["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1I<T1A>2`]
M(#(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!$969A=6QT('1O('1W:6QI9VAT(&)E
M8V%U<V4@:70@=&5N9',@=&\@:&%V92!N975T<F%L(&EC;VYS+@H@("`@("`@
M("`@("`D:7-$87D@/2`Q.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5N97)A
M;"!P<F5C:7!I=&%T:6]N"B`@("`@("`@:68@*"1T<R`F)B`D;F5A<BD@>PH@
M("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@
M8V%S92`P.@H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`S.#L@+R\@3&EG:'1N:6YG"B`@("`@("`@("`@("`@
M("!C87-E(#(Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#,W.R`O+R!,
M:6=H=&YI;F<O1&%Y"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M:68@*"1T<RD@>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@
M("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`T-SL@+R\@5&AU;F1E<G-T;W)M+TYI9VAT"B`@("`@("`@("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(#`[("`O+R!286EN+TQI9VAT;FEN9PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D<VYO=RD@>PH@("`@("`@("`@
M("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S92`P.@H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`T-CL@+R\@4VYO=R].:6=H=`H@
M("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@8V%S92`R
M.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`T,3L@+R\@4VYO=PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D<F%I;BD@>PH@("`@
M("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S
M92`P.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`T-3L@+R\@4F%I;B].
M:6=H=`H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`T,#L@+R\@4F%I;@H@("`@("`@("`@("`@("`@8V%S92`R
M.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`S.3L@+R\@4F%I;B]$87D*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@0VQO=60@8V]N
M9&ET:6]N<R!N96%R('1H92!G<F]U;F0*("`@("`@("!I9B`H)&9O9RD@>PH@
M("`@("`@("`@("!R971U<FX@,C`[("\O($9O9PH@("`@("`@('T*("`@("`@
M("!I9B`H)&AA>F4I('L*("`@("`@("`@("`@<F5T=7)N(#(Q.R`O+R!(87IE
M"B`@("`@("`@?0H*("`@("`@("`O+R!#;&]U9"!C;VYD:71I;VYS"B`@("`@
M("`@:68@*"1C;W9E<F%G92`]/2`T*2!["B`@("`@("`@("`@(')E='5R;B`R
M-CL@+R\@36]S=&QY($-L;W5D>0H@("`@("`@('T*("`@("`@("!I9B`H)&-O
M=F5R86=E(#T](#,I('L*("`@("`@("`@("`@<W=I=&-H("@D:7-$87DI('L*
M("`@("`@("`@("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@,C<[("\O($UO<W1L>2!#;&]U9'DO3FEG:'0*("`@("`@("`@("`@
M("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@("`@("!R971U<FX@,C8[("\O
M($UO<W1L>2!#;&]U9'D*("`@("`@("`@("`@("`@(&-A<V4@,CH*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@,C@[("\O($UO<W1L>2!#;&]U9'DO1&%Y
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1C;W9E<F%G
M92`]/2`R*2!["B`@("`@("`@("`@('-W:71C:"`H)&ES1&%Y*2!["B`@("`@
M("`@("`@("`@("!C87-E(#`Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(#(Y.R`O+R!087)T;'D@0VQO=61Y+TYI9VAT"B`@("`@("`@("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#(V.R`O+R!-;W-T
M;'D@0VQO=61Y"B`@("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(#,P.R`O+R!087)T;'D@0VQO=61Y+T1A>0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D8V]V97)A9V4@/3T@
M,2D@>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@
M("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`S,SL@+R\@2&%Z>2].:6=H=`H@("`@("`@
M("`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`S
M-#L@+R\@2&%Z>2]$87D*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+R\@0V%T8V@M86QL<PH@("`@("`@(&EF("@D=VEN9"D@>PH@("`@("`@
M("`@("!R971U<FX@,C,[("\O(%=I;F0*("`@("`@("!]"B`@("`@("`@:68@
M*"1H;W0I('L*("`@("`@("`@("`@<F5T=7)N(#,V.R`O+R!(;W0A"B`@("`@
M("`@?0H@("`@("`@(&EF("@D9G)I9VED*2!["B`@("`@("`@("`@(')E='5R
M;B`R-3L@+R\@1G)I9VED"B`@("`@("`@?0H*("`@("`@("!I9B`H)&YS=RD@
M>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@
M("`@8V%S92`P.@H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@
M("`@("`@("`@("\O(%5S92!N:6=H="!F;W(@='=I;&EG:'0@8F5C875S92!T
M:&4@;6]O;B!I<R!G96YE<F%L;'D*("`@("`@("`@("`@("`@("`@("`O+R!O
M=70@=&AE;BP@<V\@:70@=VEL;"!M871C:"!W:71H(&UO<W0@:6-O;B!S971S
M+@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`S,3L@+R\@0VQE87(@3FEG
M:'0*("`@("`@("`@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@,S([("\O($-L96%R($1A>0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@(FYA(CL*("`@('T*("`@("\O('U]?0I]
M"B\O('U]?0H_/@HN+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4V5R
M=FEC97,O5V5A=&AE<BYP:'``````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C8P-C(`,3`U,34T,S$P-38`,#(Q,C0Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T
M(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P
M/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@4$5!4CHZ4V5R=FEC
M97-?5V5A=&AE<@H@*@H@*B!397)V:6-E<U]796%T:&5R('-E87)C:&5S(&9O
M<B!G:79E;B!L;V-A=&EO;G,@86YD(')E=')I979E<R!C=7)R96YT"B`J('=E
M871H97(@9&%T82!A;F0L(&1E<&5N9&%N="!O;B!T:&4@=7-E9"!S97)V:6-E
M+"!A;'-O(&9O<F5C87-T<RX@57`@=&\*("H@;F]W+"!33T%0('-E<G9I8V5S
M(&9R;VT@0V%P95-C:65N8V4@86YD($5*4T4L(%A-3"!F<F]M('=E871H97(N
M8V]M(&%N9`H@*B!-151!4B]4048@9G)O;2!N;V%A+F=O=B!A<F4@<W5P<&]R
M=&5D+"!F=7)T:&5R('-E<G9I8V5S('=I;&P@9V5T"B`J(&EN8VQU9&5D+"!I
M9B!T:&5Y(&)E8V]M92!A=F%I;&%B;&4@86YD(&%R92!P<F]P97)L>2!D;V-U
M;65N=&5D+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#
M14Y313X*("H@0V]P>7)I9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER='H*
M("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@
M86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W
M:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E
M9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@
M*B!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I
M;B!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@
M*B!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O
M9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M(&EN('1H92!D;V-U;65N=&%T:6]N"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R
M:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I
M=&AE<B!T:&4@;F%M92!O9B!T:&4@<V]F='=A<F4@;F]R('1H92!N86UE<R!O
M9B!I=',@8V]N=')I8G5T;W)S"B`J("`@;6%Y(&)E('5S960@=&\@96YD;W)S
M92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W
M87)E"B`J("`@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI
M<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%
M($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@
M*B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%2
M4D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@
M4$%25$E#54Q!4B!055)03U-%"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%
M5D5.5"!32$%,3"!42$4@0T]065))1TA4($]73D52($]2($-/3E1224)55$]2
M4R!"10H@*B!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)
M1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)
M04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!2
M3T-54D5-14Y4($]&"B`J(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[
M($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@
M*B!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%
M3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U12
M24-4($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@
M3U(@3U1(15)725-%*0H@*B!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(
M12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(
M10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H@/"],24-%3E-%
M/@H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E
M("`@("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD
M97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U
M($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO
M<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,
M:6-E;G-E"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@5V5A=&AE<BYP:'`L
M=B`Q+C0S(#(P,#4O,3$O,38@,3(Z-#@Z,S0@97)U($5X<"`D"B`J($!L:6YK
M("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?
M5V5A=&AE<@H@*B!`9FEL97-O=7)C90H@*B\*"B\O('M[>R!C;VYS=&%N=',*
M+R\@>WM[(&-A8VAE('1I;65S"F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%
M6%!)4D537U5.2513(BP@("`@("`@(#DP,"D[("\O(#$U30ID969I;F4H(E-%
M4E9)0T537U=%051(15)?15A025)%4U],3T-!5$E/3B(L("`@-#,R,#`I.R`O
M+R`Q,D@*9&5F:6YE*")315)624-%4U]714%42$527T584$E215-?5T5!5$A%
M4B(L("`@("`Q.#`P*3L@+R\@,S!-"F1E9FEN92@B4T525DE#15-?5T5!5$A%
M4E]%6%!)4D537T9/4D5#05-4(BP@("`@-S(P,"D[("\O("`R2`ID969I;F4H
M(E-%4E9)0T537U=%051(15)?15A025)%4U],24Y+4R(L("`@("`@-#,R,#`I
M.R`O+R`Q,D@*9&5F:6YE*")315)624-%4U]714%42$527T584$E215-?4T5!
M4D-((BP@("`R-#$Y,C`P*3L@+R\@,CA$"B\O('U]?0H*+R\@>WM[(&5R<F]R
M(&-O9&5S"F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%4E)/4E]315)624-%
M7TY/5%]&3U5.1"(L("`@("`@("`Q,"D["F1E9FEN92@B4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].(BP@("`@("`@("`Q,2D["F1E
M9FEN92@B4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%4
M02(L("`@("`@("`Q,BD["F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]#04-(15])3DE47T9!24Q%1"(L("`@("`@("`Q,RD["F1E9FEN92@B4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$(BP@("`@("`@
M("`Q-"D["F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%4E)/4E](5%107U!2
M3UA97TE.5D%,240B+"`@("`@("`Q-2D["F1E9FEN92@B4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]354Y&54Y#4U]$051%7TE.5D%,240B+"`@("`Q-BD["F1E
M9FEN92@B4T525DE#15-?5T5!5$A%4E]%4E)/4E]354Y&54Y#4U]2151&3U)-
M7TE.5D%,240B+"`Q-RD["F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]-151!4E]33U520T5?24Y604Q)1"(L("`@("`Q."D["B\O('U]?0H*+R\@
M>WM[(&5R<F]R(&-O9&5S(&1E9FEN960@8GD@=V5A=&AE<BYC;VT*9&5F:6YE
M*")315)624-%4U]714%42$527T524D]27U5.2TY/5TY?15)23U(B+"`@("`@
M("`@("`@(#`I.PID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?3D]?
M3$]#051)3TXB+"`@("`@("`@("`@("`@,2D["F1E9FEN92@B4T525DE#15-?
M5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].(BP@("`@("`@("`R*3L*
M9&5F:6YE*")315)624-%4U]714%42$527T524D]27TE.5D%,241?4$%25$Y%
M4E])1"(L("`@("`Q,#`I.PID969I;F4H(E-%4E9)0T537U=%051(15)?15)2
M3U)?24Y604Q)1%]04D]$54-47T-/1$4B+"`@(#$P,2D["F1E9FEN92@B4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ)0T5.4T5?2T59(BP@("`@
M,3`R*3L*+R\@?7U]"B\O('U]?0H*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E
M871H97(*+RHJ"B`J(%1H:7,@8VQA<W,@86-T<R!A<R!A;B!I;G1E<F9A8V4@
M=&\@=F%R:6]U<R!O;FQI;F4@=V5A=&AE<BUS97)V:6-E<RX*("H*("H@0&-A
M=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC
M97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA
M;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@
M5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`
M=F5R<VEO;B`@("`@4F5L96%S93H@,2XT+C`*("H@0&QI;FL@("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J
M+PIC;&%S<R!397)V:6-E<U]796%T:&5R('L*"B`@("`O+R![>WL@)G-E<G9I
M8V4H*0H@("`@+RHJ"B`@("`@*B!&86-T;W)Y(&9O<B!C<F5A=&EN9R!T:&4@
M<V5R=FEC97,M;V)J96-T<PH@("`@("H*("`@("`J(%5S86)L92!K97ES(&9O
M<B!T:&4@;W!T:6]N<R!A<G)A>2!A<F4Z"B`@("`@*B!O(&1E8G5G("`@("`@
M("`@("`@("!E;F%B;&5S(&1E8G5G9VEN9R!O=71P=70*("`@("`J("TM+2!#
M;VUM;VX@3W!T:6]N<PH@("`@("H@;R!C86-H951Y<&4@("`@("`@("`@9&5F
M:6YE<R!W:&%T('1Y<&4@;V8@8V%C:&4@=&\@=7-E"B`@("`@*B!O(&-A8VAE
M3W!T:6]N<R`@("`@("!P87-S97,@8V%C:&4@;W!T:6]N<PH@("`@("H@;R!U
M;FET<T9O<FUA="`@("`@("`@=7-E("A54RDM<W1A;F1A<F0L(&UE=')I8R!O
M<B!C=7-T;VT@=6YI=',*("`@("`J(&\@8W5S=&]M56YI='-&;W)M870@(&1E
M9FEN97,@=&AE(&-U<W1O;6EZ960@=6YI=',@9F]R;6%T"B`@("`@*B!O(&AT
M='!4:6UE;W5T("`@("`@("!S971S('1I;65O=70@9F]R($A45%`@<F5Q=65S
M=',*("`@("`J(&\@:'1T<%!R;WAY("`@("`@("`@('-E=',@<')O>'D@9F]R
M($A45%`@<F5Q=65S=',L('!L96%S92!U<V4@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!N;W1A=&EO;B!H='1P.B\O6W5S97);.G!A<W-=0%UH
M;W-T6SIP;W)T70H@("`@("H@;R!D871E1F]R;6%T("`@("`@("`@<W1R:6YG
M('1O('5S92!F;W(@9&%T92!O=71P=70*("`@("`J(&\@=&EM949O<FUA="`@
M("`@("`@('-T<FEN9R!T;R!U<V4@9F]R('1I;64@;W5T<'5T"B`@("`@*B`M
M+2T@14I312!/<'1I;VYS"B`@("`@*B!O(&YO;F4*("`@("`J("TM+2!';&]B
M86Q796%T:&5R($]P=&EO;G,*("`@("`J(&\@;F]N90H@("`@("H@+2TM($U%
M5$%2+U1!1B!/<'1I;VYS"B`@("`@*B!O(&1S;B`@("`@("`@("`@("`@("!3
M=')I;F<@9F]R(&1E9FEN:6YG('1H92!$0B!C;VYN96-T:6]N"B`@("`@*B!O
M(&1B3W!T:6]N<R`@("`@("`@("!P87-S97,@1$(@;W!T:6]N<PH@("`@("H@
M;R!S;W5R8V5-971A<B`@("`@("`@:'1T<"P@9G1P(&]R(&9I;&4@+2!T>7!E
M(&]F(&1A=&$M<V]U<F-E(&9O<B!-151!4@H@("`@("H@;R!S;W5R8V50871H
M365T87(@("`@=VAE<F4@=&\@;&]O:R!F;W(@=&AE('-O=7)C92P@55))(&]R
M(&9I;&5P871H+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;V8@3454
M05(@:6YF;W)M871I;VX*("`@("`J(&\@<V]U<F-E5&%F("`@("`@("`@(&AT
M='`L(&9T<"!O<B!F:6QE("T@='EP92!O9B!D871A+7-O=7)C92!F;W(@5$%&
M"B`@("`@*B!O('-O=7)C95!A=&A4868@("`@("!W:&5R92!T;R!L;V]K(&9O
M<B!T:&4@<V]U<F-E+"!54DD@;W(@9FEL97!A=&@L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!O9B!4048@:6YF;W)M871I;VX*("`@("`J("TM+2!W
M96%T:&5R+F-O;2!/<'1I;VYS"B`@("`@*B!O('!A<G1N97))1"`@("`@("`@
M("!9;W4G;&P@<F5C96EV92!T:&5S92!K97ES(&%F=&5R(')E9VES=&5R:6YG
M"B`@("`@*B!O(&QI8V5N<V5+97D@("`@("`@("!W:71H('1H92!W96%T:&5R
M+F-O;2!834PM<V5R=FEC90H@("`@("H@;R!P<F5&971C:"`@("`@("`@("`@
M16YA8FQE<R!P<F4M9F5T8VAI;F<@;V8@9&%T82!I;B!O;F4@<VEN9VQE(')E
M<75E<W0*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`@
M("`@("`@("`@("`@)'-E<G9I8V4*("`@("`J($!P87)A;2`@("!A<G)A>2`@
M("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<PH@("`@("H@0')E='5R;B`@
M(%!%05)?17)R;W)\;V)J96-T"B`@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O
M<@H@("`@("H@0'1H<F]W<R`@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(
M15)?15)23U)?4T525DE#15].3U1?1D]53D0*("`@("`J($!A8V-E<W,@("!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)G-E<G9I8V4H)'-E<G9I8V4L
M("1O<'1I;VYS(#T@;G5L;"D*("`@('L*("`@("`@("`D<V5R=FEC92`]('5C
M9FER<W0H<W1R=&]L;W=E<B@D<V5R=FEC92DI.PH@("`@("`@("1C;&%S<VYA
M;64@/2`B4V5R=FEC97-?5V5A=&AE<E\B+B1S97)V:6-E.PH*("`@("`@("`O
M+R!#:&5C:R!F;W(@9&5B=6=G:6YG+6UO9&4@86YD('-E="!S='5F9B!A8V-O
M<F1I;F=L>0H@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RD@)B8@:7-S
M970H)&]P=&EO;G-;(F1E8G5G(ETI("8F("1O<'1I;VYS6R)D96)U9R)=(#X]
M(#(I('L*("`@("`@("`@("`@:68@*"%D969I;F5D*")315)624-%4U]714%4
M2$527T1%0E5'(BDI('L*("`@("`@("`@("`@("`@(&1E9FEN92@B4T525DE#
M15-?5T5!5$A%4E]$14)51R(L('1R=64I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EN8VQU9&5?;VYC92@B4V5R=FEC97,O5V5A=&AE<B\B+B1S97)V
M:6-E+B(N<&AP(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*"%D969I;F5D*")315)624-%4U]714%42$527T1%0E5'(BDI('L*("`@("`@
M("`@("`@("`@(&1E9FEN92@B4T525DE#15-?5T5!5$A%4E]$14)51R(L(&9A
M;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!`:6YC;'5D95]O;F-E
M*")397)V:6-E<R]796%T:&5R+R(N)'-E<G9I8V4N(BYP:'`B*3L*("`@("`@
M("!]"@H@("`@("`@("\O($YO('-U8V@@<V5R=FEC92XN+B!B86EL(&]U=`H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<VYA;64I*2!["B`@("`@
M("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?4T525DE#15].3U1?1D]53D0L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@
M<V5R=FEC92!A;F0@<F5T=7)N"B`@("`@("`@)&5R<F]R(#T@;G5L;#L*("`@
M("`@("!`)&]B:B`]("9N97<@)&-L87-S;F%M92@D;W!T:6]N<RP@)&5R<F]R
M*3L*"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&5R
M<F]R*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D;V)J.PH@("`@("`@('T*("`@
M('T*("`@("\O('U]?0H*("`@("\O('M[>R!A<&E697)S:6]N*"D*("`@("\J
M*@H@("`@("H@1F]R('EO=7(@8V]N=F5N:65N8V4L('=H96X@22!C;VUE('5P
M('=I=&@@8VAA;F=E<R!I;B!T:&4@05!)+BXN"B`@("`@*@H@("`@("H@0')E
M='5R;B`@<W1R:6YG"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N
M("(Q+C0B.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(%]E<G)O<DUE
M<W-A9V4H*0H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!M97-S86=E(&9O
M<B!A(&-E<G1A:6X@97)R;W(@8V]D90H@("`@("H*("`@("`J($!P87)A;2`@
M(%!%05)?17)R;W)\:6YT("`@("`@("`@("`@("`D=F%L=64*("`@("`J($!R
M971U<FX@('-T<FEN9PH@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?97)R;W)-97-S86=E*"1V86QU92D*("`@('L*("`@
M("`@("!S=&%T:6,@)&5R<F]R365S<V%G97,["B`@("`@("`@:68@*"%I<W-E
M="@D97)R;W)-97-S86=E<RDI('L*("`@("`@("`@("`@)&5R<F]R365S<V%G
M97,@/2!A<G)A>2@*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?
M15)23U)?4T525DE#15].3U1?1D]53D0@("`@("`@("`]/B`B4F5Q=65S=&5D
M('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(L"B`@("`@("`@("`@("`@
M("!315)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TX@("`@
M("`@("`@/3X@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(BP*("`@("`@
M("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D52
M7T1!5$$@("`@("`@("`]/B`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92XB+`H@("`@("`@("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]#04-(15])3DE47T9!24Q%1"`@("`@("`@(#T^(")#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+B(L"B`@("`@("`@("`@("`@("!315)624-%
M4U]714%42$527T524D]27T1"7TY/5%]#3TY.14-4140@("`@("`@("`@/3X@
M(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB+`H@("`@("`@("`@("`@("`@
M4T525DE#15-?5T5!5$A%4E]%4E)/4E](5%107U!23UA97TE.5D%,240@("`@
M("`@(#T^(")4:&4@9VEV96X@<')O>'D@:7,@;F]T('9A;&ED+"!P;&5A<V4@
M=7-E('1H92!N;W1A=&EO;B!H='1P.B\O6W5S97);.G!A<W-=0%UH;W-T6SIP
M;W)T72XB+`H@("`@("`@("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]354Y&54Y#4U]$051%7TE.5D%,240@("`@(#T^(")4:&4@9&%T92!Y;W4G
M=F4@<')O=FED960@9F]R(&-A;&-U;&%T:6]N(&]F('-U;G)I<V4O<W5N<V5T
M(&ES(&YO="!A('1I;65S=&%M<"XB+`H@("`@("`@("`@("`@("`@4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]354Y&54Y#4U]2151&3U)-7TE.5D%,240@(#T^
M(")4:&4@<F5T=7)N(&9O<FUA="!Y;W4G=F4@<')O=FED960@9F]R(&-A;&-U
M;&%T:6]N(&]F('-U;G)I<V4O<W5N<V5T(&ES(&YO="!V86QI9"XB+`H@("`@
M("`@("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E]-151!4E]33U52
M0T5?24Y604Q)1"`@("`@(#T^(")4:&4@345405(O5$%&('-O=7)C92!Y;W4G
M=F4@<')O=FED960@:&%S(&%N(&EN=F%L:60@='EP92!O<B!P871H+B(L"B`@
M("`@("`@("`@("`@("!315)624-%4U]714%42$527T524D]27U5.2TY/5TY?
M15)23U(@("`@("`@("`@("`@/3X@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)2
M3U)?3D]?3$]#051)3TX@("`@("`@("`@("`@("`]/B`B3F\@;&]C871I;VX@
M<')O=FED960N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?
M15)23U)?24Y604Q)1%],3T-!5$E/3B`@("`@("`@("`]/B`B26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"XB+`H@("`@("`@("`@("`@("`@4T525DE#15-?
M5T5!5$A%4E]%4E)/4E])3E9!3$E$7U!!4E1.15)?240@("`@("`@(#T^("))
M;G9A;&ED('!A<G1N97(@:60N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T53
M7U=%051(15)?15)23U)?24Y604Q)1%]04D]$54-47T-/1$4@("`@("`]/B`B
M26YV86QI9"!P<F]D=6-T(&-O9&4N(BP*("`@("`@("`@("`@("`@(%-%4E9)
M0T537U=%051(15)?15)23U)?24Y604Q)1%],24-%3E-%7TM%62`@("`@("`]
M/B`B26YV86QI9"!L:6-E;G-E(&ME>2XB"B`@("`@("`@("`@("D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D
M=F%L=64I*2!["B`@("`@("`@("`@("1V86QU92`]("1V86QU92T^9V5T0V]D
M92@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1E<G)O<DUE
M<W-A9V5S6R1V86QU95TI(#\@)&5R<F]R365S<V%G97-;)'9A;'5E72`Z("1E
M<G)O<DUE<W-A9V5S6U-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E]%
M4E)/4ET["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@:7-%<G)O<B@I
M"B`@("`O*BH*("`@("`J($-H96-K<R!F;W(@86X@97)R;W(@;V)J96-T+"!S
M86UE(&%S(&EN(%!%05(*("`@("`J"B`@("`@*B!`<&%R86T@("!014%27T5R
M<F]R?&UI>&5D("`@("`@("`@("`@)'9A;'5E"B`@("`@*B!`<F5T=7)N("!B
M;V]L"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-%<G)O<B@D=F%L=64I"B`@("!["B`@("`@("`@<F5T=7)N("AI<U]O
M8FIE8W0H)'9A;'5E*2`F)B`H<W1R=&]L;W=E<BAG971?8VQA<W,H)'9A;'5E
M*2D@/3T@(G!E87)?97)R;W(B('Q\(&ES7W-U8F-L87-S7V]F*"1V86QU92P@
M(G!E87)?97)R;W(B*2DI.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M("9R86ES945R<F]R*"D*("`@("\J*@H@("`@("H@0W)E871E<R!E<G)O<BP@
M<V%M92!A<R!I;B!014%2('=I=&@@82!C=7-T;VUI>F5D(&9L879O<@H@("`@
M("H*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]D90H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1F:6QE"B`@("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@
M("`@("`@("`@("`@)&QI;F4*("`@("`J($!R971U<FX@(%!%05)?17)R;W(*
M("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G)A:7-E17)R;W(H)&-O9&4@/2!315)624-%4U]714%42$527T524D]27U5.
M2TY/5TY?15)23U(L("1F:6QE(#T@(B(L("1L:6YE(#T@,"D*("`@('L*("`@
M("`@("`O+R!4:&ES('-H;W5L9"!I;7!R;W9E('1H92!P97)F;W)M86YC92!O
M9B!T:&4@<V-R:7!T+"!A<R!014%2(&ES(&]N;'D@:6YC;'5D960L('=H96X*
M("`@("`@("`O+R!R96%L;'D@;F5E9&5D+@H@("`@("`@(&EN8VQU9&5?;VYC
M92`B4$5!4BYP:'`B.PH*("`@("`@("`D;65S<V%G92`](")397)V:6-E<U]7
M96%T:&5R(CL*("`@("`@("!I9B`H)&9I;&4@(3T@(B(@)B8@)&QI;F4@/B`P
M*2!["B`@("`@("`@("`@("1M97-S86=E("X]("(@*"(N8F%S96YA;64H)&9I
M;&4I+B(Z(BXD;&EN92XB*2(["B`@("`@("`@?0H@("`@("`@("1M97-S86=E
M("X]("(Z("(N4V5R=FEC97-?5V5A=&AE<CHZ7V5R<F]R365S<V%G92@D8V]D
M92D["@H@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)&UE<W-A
M9V4L("1C;V1E+"!014%27T524D]27U)%5%523BP@15]54T527TY/5$E#12P@
M(E-E<G9I8V5S7U=E871H97)?17)R;W(B+"!N=6QL+"!F86QS92D["B`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@('T*("`@("\O('U]?0I]"B\O('U]?0H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M07)C:&EV92\`````````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$V-S(T`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]!<F-H:79E+U1A<BYP:'``````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V-C<W-P`Q,#4Q-30S,3`U-@`P
M,C`R,3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\J('9I;3H@<V5T('1S/30@<W<]-#H@*B\-"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R<VEO;B`T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!U<FPZ("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@
M?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S
M92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PT*+R\@?"!!=71H;W(Z(%9I;F-E;G0@0FQA=F5T(#QV:6YC96YT0'!H<&-O
M;F-E<'0N;F5T/B`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z(%1A<BYP:'`L=B`Q
M+C(Y(#(P,#4O,#,O,3<@,C$Z,#(Z,S$@=F)L879E="!%>'`@)`T*#0IR97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL-"@T*#0ID969I;F4@*"=!4D-(259%7U1!
M4E]!5%1?4T5005)!5$]2)RP@.3`P,#$I.PT*#0HO*BH-"BH@0W)E871E<R!A
M("AC;VUP<F5S<V5D*2!487(@87)C:&EV90T**@T**B!`875T:&]R("`@5FEN
M8V5N="!";&%V970@/'9I;F-E;G1`<&AP8V]N8V5P="YN970^#0HJ($!V97)S
M:6]N("`D4F5V:7-I;VXZ(#$N,CD@)`T**B!`<&%C:V%G92`@07)C:&EV90T*
M*B\-"F-L87-S($%R8VAI=F5?5&%R(&5X=&5N9',@4$5!4@T*>PT*("`@("\J
M*@T*("`@("H@0'9A<B!S=')I;F<@3F%M92!O9B!T:&4@5&%R#0H@("`@*B\-
M"B`@("!V87(@)%]T87)N86UE/2<G.PT*#0H@("`@+RHJ#0H@("`@*B!`=F%R
M(&)O;VQE86X@:68@=')U92P@=&AE(%1A<B!F:6QE('=I;&P@8F4@9WII<'!E
M9`T*("`@("HO#0H@("`@=F%R("1?8V]M<')E<W,]9F%L<V4[#0H-"B`@("`O
M*BH-"B`@("`J($!V87(@<W1R:6YG(%1Y<&4@;V8@8V]M<')E<W-I;VX@.B`G
M;F]N92<L("=G>B<@;W(@)V)Z,B<-"B`@("`J+PT*("`@('9A<B`D7V-O;7!R
M97-S7W1Y<&4])VYO;F4G.PT*#0H@("`@+RHJ#0H@("`@*B!`=F%R('-T<FEN
M9R!%>'!L;V1E('-E<&%R871O<@T*("`@("HO#0H@("`@=F%R("1?<V5P87)A
M=&]R/2<@)SL-"@T*("`@("\J*@T*("`@("H@0'9A<B!F:6QE(&1E<V-R:7!T
M;W(-"B`@("`J+PT*("`@('9A<B`D7V9I;&4],#L-"@T*("`@("\J*@T*("`@
M("H@0'9A<B!S=')I;F<@3&]C86P@5&%R(&YA;64@;V8@82!R96UO=&4@5&%R
M("AH='1P.B\O(&]R(&9T<#HO+RD-"B`@("`J+PT*("`@('9A<B`D7W1E;7!?
M=&%R;F%M93TG)SL-"@T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*("`@("\J
M*@T*("`@("H@07)C:&EV95]487(@0VQA<W,@8V]N<W1R=6-T;W(N(%1H:7,@
M9FQA=F]U<B!O9B!T:&4@8V]N<W1R=6-T;W(@;VYL>0T*("`@("H@9&5C;&%R
M92!A(&YE=R!!<F-H:79E7U1A<B!O8FIE8W0L(&ED96YT:69Y:6YG(&ET(&)Y
M('1H92!N86UE(&]F('1H90T*("`@("H@=&%R(&9I;&4N#0H@("`@*B!)9B!T
M:&4@8V]M<')E<W,@87)G=6UE;G0@:7,@<V5T('1H92!T87(@=VEL;"!B92!R
M96%D(&]R(&-R96%T960@87,@80T*("`@("H@9WII<"!O<B!B>C(@8V]M<')E
M<W-E9"!405(@9FEL92X-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`D<%]T87)N86UE("!4:&4@;F%M92!O9B!T:&4@=&%R(&%R8VAI=F4@=&\@
M8W)E871E#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<%]C;VUP<F5S<R!C
M86X@8F4@;G5L;"P@)V=Z)R!O<B`G8GHR)RX@5&AI<PT*("`@("H@("`@("`@
M("`@("`@("`@("`@<&%R86UE=&5R(&EN9&EC871E<R!I9B!G>FEP(&]R(&)Z
M,B!C;VUP<F5S<VEO;@T*("`@("H@("`@("`@("`@("`@("`@("`@:7,@<F5Q
M=6ER960N("!&;W(@8V]M<&%T:6)I;&ET>2!R96%S;VX@=&AE#0H@("`@*B`@
M("`@("`@("`@("`@("`@("!B;V]L96%N('9A;'5E("=T<G5E)R!M96%N<R`G
M9WHG+@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T
M:6]N($%R8VAI=F5?5&%R*"1P7W1A<FYA;64L("1P7V-O;7!R97-S(#T@;G5L
M;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y014%2*"D[#0H@("`@("`@("1T
M:&ES+3Y?8V]M<')E<W,@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/E]C;VUP
M<F5S<U]T>7!E(#T@)VYO;F4G.PT*("`@("`@("!I9B`H*"1P7V-O;7!R97-S
M(#T]/2!N=6QL*2!\?"`H)'!?8V]M<')E<W,@/3T@)R<I*2![#0H@("`@("`@
M("`@("!I9B`H0&9I;&5?97AI<W1S*"1P7W1A<FYA;64I*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1F<"`]($!F;W!E;B@D<%]T87)N86UE+"`B<F(B*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`O+R!L;V]K(&9O<B!G>FEP(&UA9VEC
M(&-O;VMI90T*("`@("`@("`@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F
M<"P@,BD[#0H@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&1A=&$@/3T@(EPS-UPR,3,B*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W-?
M='EP92`]("=G>B<[#0H@("`@("`@("`@("`@("`@("`@("\O($YO('-U<F4@
M:70G<R!E;F]U9VAT(&9O<B!A(&UA9VEC(&-O9&4@+BXN+@T*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)&1A=&$@/3T@(D):(BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]('1R=64[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S7W1Y<&4@
M/2`G8GHR)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M+R\@<')O8F%B;'D@82!R96UO=&4@9FEL92!O<B!S;VUE(&9I;&4@86-C97-S
M:6)L90T*("`@("`@("`@("`@("`@("\O('1H<F]U9V@@82!S=')E86T@:6YT
M97)F86-E#0H@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D<%]T87)N86UE
M+"`M,BD@/3T@)V=Z)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-O;7!R97-S(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C;VUP<F5S<U]T>7!E(#T@)V=Z)SL-"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H*'-U8G-T<B@D<%]T87)N86UE+"`M,RD@/3T@)V)Z,B<I('Q\#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("AS=6)S='(H)'!?=&%R;F%M92P@
M+3(I(#T]("=B>B<I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8V]M<')E<W,@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-O;7!R97-S7W1Y<&4@/2`G8GHR)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I
M9B`H*"1P7V-O;7!R97-S(#T]/2!T<G5E*2!\?"`H)'!?8V]M<')E<W,@/3T@
M)V=Z)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S7W1Y<&4@
M/2`G9WHG.PT*("`@("`@("`@("`@?2!E;'-E(&EF("@D<%]C;VUP<F5S<R`]
M/2`G8GHR)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W,@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W-?='EP
M92`]("=B>C(G.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!D:64H(E5N<W5P<&]R=&5D(&-O;7!R97-S:6]N('1Y<&4@)R1P7V-O
M;7!R97-S)UQN(BX-"B`@("`@("`@("`@("`@("`@("`@(E-U<'!O<G1E9"!T
M>7!E<R!A<F4@)V=Z)R!A;F0@)V)Z,B<N7&XB*3L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]T87)N86UE(#T@)'!?=&%R;F%M93L-"B`@("`@("`@
M:68@*"1T:&ES+3Y?8V]M<')E<W,I('L@+R\@87-S97)T('IL:6(@;W(@8GHR
M(&5X=&5N<VEO;B!S=7!P;W)T#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@("`@("`@("`@)&5X=&YA
M;64@/2`G>FQI8B<[#0H@("`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O
M;7!R97-S7W1Y<&4@/3T@)V)Z,B<I#0H@("`@("`@("`@("`@("`@)&5X=&YA
M;64@/2`G8GHR)SL-"@T*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A
M9&5D*"1E>'1N86UE*2D@>PT*("`@("`@("`@("`@("`@(%!%05(Z.FQO861%
M>'1E;G-I;VXH)&5X=&YA;64I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"1E>'1N86UE*2D@>PT*("`@("`@
M("`@("`@("`@(&1I92@B5&AE(&5X=&5N<VEO;B`G)&5X=&YA;64G(&-O=6QD
M;B=T(&)E(&9O=6YD+EQN(BX-"B`@("`@("`@("`@("`@("`@("`@(E!L96%S
M92!M86ME('-U<F4@>6]U<B!V97)S:6]N(&]F(%!(4"!W87,@8G5I;'0@(BX-
M"B`@("`@("`@("`@("`@("`@("`@(G=I=&@@)R1E>'1N86UE)R!S=7!P;W)T
M+EQN(BD[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@
M+R\@>WM[(&1E<W1R=6-T;W(-"B`@("!F=6YC=&EO;B!?07)C:&EV95]487(H
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]C;&]S92@I.PT*("`@("`@("`O
M+R`M+2TM+2!,;V]K(&9O<B!A(&QO8V%L(&-O<'D@=&\@9&5L971E#0H@("`@
M("`@(&EF("@D=&AI<RT^7W1E;7!?=&%R;F%M92`A/2`G)RD-"B`@("`@("`@
M("`@($!U;FQI;FLH)'1H:7,M/E]T96UP7W1A<FYA;64I.PT*("`@("`@("`D
M=&AI<RT^7U!%05(H*3L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![
M>WL@8W)E871E*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&-R96%T
M97,@=&AE(&%R8VAI=F4@9FEL92!A;F0@861D('1H92!F:6QE<R`O(&1I<F5C
M=&]R:65S#0H@("`@*B!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N
M#0H@("`@*B!)9B!A(&9I;&4@=VET:"!T:&4@<V%M92!N86UE(&5X:7-T(&%N
M9"!I<R!W<FET86)L92P@:70@:7,@<F5P;&%C960-"B`@("`J(&)Y('1H92!N
M97<@=&%R+@T*("`@("H@5&AE(&UE=&AO9"!R971U<FX@9F%L<V4@86YD(&$@
M4$5!4B!E<G)O<B!T97AT+@T*("`@("H@5&AE("1P7V9I;&5L:7-T('!A<F%M
M971E<B!C86X@8F4@86X@87)R87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*
M("`@("H@<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@
M;F%M92!W:71H('1H96ER('!A=&@@:68-"B`@("`J(&YE961E9"X@270@8V%N
M(&%L<V\@8F4@82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D
M(&)Y(&$-"B`@("`J('-I;F=L92!B;&%N:RX-"B`@("`J($9O<B!E86-H(&1I
M<F5C=&]R>2!A9&1E9"!I;B!T:&4@87)C:&EV92P@=&AE(&9I;&5S(&%N9`T*
M("`@("H@<W5B+61I<F5C=&]R:65S(&%R92!A;'-O(&%D9&5D+@T*("`@("H@
M4V5E(&%L<V\@8W)E871E36]D:69Y*"D@;65T:&]D(&9O<B!M;W)E(&1E=&%I
M;',N#0H@("`@*@T*("`@("H@0'!A<F%M(&%R<F%Y("`D<%]F:6QE;&ES="!!
M;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@
M80T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("!S:6YG;&4@<W1R:6YG
M('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE#0H)*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)L86YK('-P86-E+@T*("`@("H@0')E='5R
M;B`@("`@("`@("`@("`@("`@("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&5R<F]R+@T*("`@("H@0'-E92!C<F5A=&5-;V1I9GDH*0T*("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T92@D<%]F
M:6QE;&ES="D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^8W)E871E
M36]D:69Y*"1P7V9I;&5L:7-T+"`G)RP@)R<I.PT*("`@('T-"B`@("`O+R!]
M?7T-"@T*("`@("\O('M[>R!A9&0H*0T*("`@("\J*@T*("`@("H@5&AI<R!M
M971H;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S('1H870@87)E(&QI
M<W1E9"!I;B`D<%]F:6QE;&ES="!I;@T*("`@("H@=&AE(&%R8VAI=F4N($EF
M('1H92!A<F-H:79E(&1O97,@;F]T(&5X:7-T(&ET(&ES(&-R96%T960N#0H@
M("`@*B!4:&4@;65T:&]D(')E='5R;B!F86QS92!A;F0@82!014%2(&5R<F]R
M('1E>'0N#0H@("`@*B!4:&4@9FEL97,@86YD(&1I<F5C=&]R:65S(&QI<W1E
M9"!A<F4@;VYL>2!A9&1E9"!A="!T:&4@96YD(&]F('1H92!A<F-H:79E+`T*
M("`@("H@979E;B!I9B!A(&9I;&4@=VET:"!T:&4@<V%M92!N86UE(&ES(&%L
M<F5A9'D@87)C:&EV960N#0H@("`@*B!3964@86QS;R!C<F5A=&5-;V1I9GDH
M*2!M971H;V0@9F]R(&UO<F4@9&5T86EL<RX-"B`@("`J#0H@("`@*B!`<&%R
M86T@87)R87D@("1P7V9I;&5L:7-T($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A
M;F0@9&ER96-T;W)Y(&YA;65S+"!O<B!A#0H)*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@
M8GD@82!S:6YG;&4-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@8FQA
M;FL@<W!A8V4N#0H@("`@*B!`<F5T=7)N("`@("`@("`@("`@("`@("`@('1R
M=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@*B!`<V5E(&-R
M96%T94UO9&EF>2@I#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@861D*"1P7V9I;&5L:7-T*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YA9&1-;V1I9GDH)'!?9FEL96QI<W0L("<G+"`G)RD[
M#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&5X=')A8W0H*0T*
M("`@(&9U;F-T:6]N(&5X=')A8W0H)'!?<&%T:#TG)RD-"B`@("![#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^97AT<F%C=$UO9&EF>2@D<%]P871H+"`G)RD[
M#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&QI<W1#;VYT96YT
M*"D-"B`@("!F=6YC=&EO;B!L:7-T0V]N=&5N="@I#0H@("`@>PT*("`@("`@
M("`D=E]L:7-T7V1E=&%I;"`](&%R<F%Y*"D[#0H-"B`@("`@("`@:68@*"1T
M:&ES+3Y?;W!E;E)E860H*2D@>PT*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M7V5X=')A8W1,:7-T*"<G+"`D=E]L:7-T7V1E=&%I;"P@(FQI<W0B+"`G)RP@
M)R<I*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'9?;&ES=%]D971A:6PI
M.PT*("`@("`@("`@("`@("`@("1V7VQI<W1?9&5T86EL(#T@,#L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@
M("`@?0T*#0H@("`@("`@(')E='5R;B`D=E]L:7-T7V1E=&%I;#L-"B`@("!]
M#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8W)E871E36]D:69Y*"D-"B`@
M("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&-R96%T97,@=&AE(&%R8VAI=F4@
M9FEL92!A;F0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S#0H@("`@*B!T
M:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N#0H@("`@*B!)9B!T:&4@
M9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&%B;&4L(&ET(&ES(')E
M<&QA8V5D(&)Y('1H90T*("`@("H@;F5W('1A<BX@270@:7,@82!C<F5A=&4@
M86YD(&YO="!A;B!A9&0N($EF('1H92!F:6QE(&5X:7-T<R!A;F0@:7,-"B`@
M("`J(')E860M;VYL>2!O<B!I<R!A(&1I<F5C=&]R>2!I="!I<R!N;W0@<F5P
M;&%C960N(%1H92!M971H;V0@<F5T=7)N#0H@("`@*B!F86QS92!A;F0@82!0
M14%2(&5R<F]R('1E>'0N#0H@("`@*B!4:&4@)'!?9FEL96QI<W0@<&%R86UE
M=&5R(&-A;B!B92!A;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG#0H@
M("`@*B!R97!R97-E;G1I;F<@82!F:6QE;F%M92!O<B!A(&1I<F5C=&]R>2!N
M86UE('=I=&@@=&AE:7(@<&%T:"!I9@T*("`@("H@;F5E9&5D+B!)="!C86X@
M86QS;R!B92!A('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@
M8GD@80T*("`@("H@<VEN9VQE(&)L86YK+@T*("`@("H@5&AE('!A=&@@:6YD
M:6-A=&5D(&EN("1P7W)E;6]V95]D:7(@=VEL;"!B92!R96UO=F5D(&9R;VT@
M=&AE#0H@("`@*B!M96UO<FEZ960@<&%T:"!O9B!E86-H(&9I;&4@+R!D:7)E
M8W1O<GD@;&ES=&5D('=H96X@=&AI<R!P871H#0H@("`@*B!E>&ES=',N($)Y
M(&1E9F%U;'0@;F]T:&EN9R!I<R!R96UO=F5D("AE;7!T>2!P871H("<G*0T*
M("`@("H@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7V%D9%]D:7(@=VEL;"!B
M92!A9&1E9"!A="!T:&4@8F5G:6YN:6YG(&]F#0H@("`@*B!T:&4@;65M;W)I
M>F5D('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"X@2&]W
M979E<B!I="!C86X-"B`@("`J(&)E('-E="!T;R!E;7!T>2`G)RX@5&AE(&%D
M9&EN9R!O9B!A('!A=&@@:7,@9&]N92!A9G1E<B!T:&4@<F5M;W9I;F<-"B`@
M("`J(&]F('!A=&@N#0H@("`@*B!4:&4@<&%T:"!A9&0O<F5M;W9E(&%B:6QI
M='D@96YA8FQE<R!T:&4@=7-E<B!T;R!P<F5P87)E(&%N(&%R8VAI=F4-"B`@
M("`J(&9O<B!E>'1R86-T:6]N(&EN(&$@9&EF9F5R96YT('!A=&@@=&AA;B!T
M:&4@;W)I9VEN(&9I;&5S(&%R92X-"B`@("`J(%-E92!A;'-O(&%D9$UO9&EF
M>2@I(&UE=&AO9"!F;W(@9FEL92!A9&1I;F<@<')O<&5R=&EE<RX-"B`@("`J
M#0H@("`@*B!`<&%R86T@87)R87D@("1P7V9I;&5L:7-T("`@("!!;B!A<G)A
M>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP-"@DJ("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&$@<VEN9VQE('-T<FEN9R!W
M:71H(&YA;65S('-E<&%R871E9"!B>0T*"2H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@82!S:6YG;&4@8FQA;FL@<W!A8V4N#0H@("`@*B!`<&%R
M86T@<W1R:6YG("1P7V%D9%]D:7(@("`@("!!('-T<FEN9R!W:&EC:"!C;VYT
M86EN<R!A('!A=&@@=&\@8F4@861D960-"@DJ("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1O('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L
M96UE;G0@:6X-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!L:7-T+@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]R96UO=F5?9&ER("`@
M02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@82!P871H('1O(&)E#0H)*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F5D(&9R;VT@=&AE(&UE
M;6]R:7IE9"!P871H(&]F(&5A8V@-"@DJ("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&5L96UE;G0@:6X@=&AE(&QI<W0L('=H96X@<F5L979A;G0N
M#0H@("`@*B!`<F5T=7)N(&)O;VQE86X@("`@("`@("`@("`@("!T<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`J($!S964@861D36]D:69Y*"D-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(&-R96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP@)'!?
M<F5M;W9E7V1I<CTG)RD-"B`@("![#0H@("`@("`@("1V7W)E<W5L="`]('1R
M=64[#0H-"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y7<FET92@I*0T*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`@(&EF("@D<%]F:6QE
M;&ES="`A/2`G)RD@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P7V9I
M;&5L:7-T*2D-"B`@("`@("`@("`@("`@("`D=E]L:7-T(#T@)'!?9FEL96QI
M<W0[#0H@("`@("`@("`@("!E;'-E:68@*&ES7W-T<FEN9R@D<%]F:6QE;&ES
M="DI#0H@("`@("`@("`@("`@("`@)'9?;&ES="`](&5X<&QO9&4H)'1H:7,M
M/E]S97!A<F%T;W(L("1P7V9I;&5L:7-T*3L-"B`@("`@("`@("`@(&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VQE86Y&:6QE*"D[#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!F:6QE(&QI<W0G
M*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?861D3&ES
M="@D=E]L:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*3L-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EF("@D=E]R97-U;'0I('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?=W)I=&5&;V]T97(H*3L-"B`@("`@("`@("`@("1T:&ES+3Y?
M8VQO<V4H*3L-"B`@("`@("`@?2!E;'-E#0H@("`@("`@("`@("`D=&AI<RT^
M7V-L96%N1FEL92@I.PT*#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&%D9$UO9&EF>2@I#0H@
M("`@+RHJ#0H@("`@*B!4:&ES(&UE=&AO9"!A9&0@=&AE(&9I;&5S("\@9&ER
M96-T;W)I97,@;&ES=&5D(&EN("1P7V9I;&5L:7-T(&%T('1H90T*("`@("H@
M96YD(&]F('1H92!E>&ES=&EN9R!A<F-H:79E+B!)9B!T:&4@87)C:&EV92!D
M;V5S(&YO="!Y970@97AI<W1S(&ET#0H@("`@*B!I<R!C<F5A=&5D+@T*("`@
M("H@5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C86X@8F4@86X@87)R87D@
M;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("`@("H@<F5P<F5S96YT:6YG(&$@
M9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M92!W:71H('1H96ER('!A=&@@
M:68-"B`@("`J(&YE961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG;&4@<W1R
M:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@("`J('-I;F=L92!B
M;&%N:RX-"B`@("`J(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]R96UO=F5?
M9&ER('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H90T*("`@("H@;65M;W)I>F5D
M('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"!W:&5N('1H
M:7,@<&%T:`T*("`@("H@97AI<W1S+B!">2!D969A=6QT(&YO=&AI;F<@:7,@
M<F5M;W9E9"`H96UP='D@<&%T:"`G)RD-"B`@("`J(%1H92!P871H(&EN9&EC
M871E9"!I;B`D<%]A9&1?9&ER('=I;&P@8F4@861D960@870@=&AE(&)E9VEN
M;FEN9R!O9@T*("`@("H@=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@9FEL
M92`O(&1I<F5C=&]R>2!L:7-T960N($AO=V5V97(@:70@8V%N#0H@("`@*B!B
M92!S970@=&\@96UP='D@)R<N(%1H92!A9&1I;F<@;V8@82!P871H(&ES(&1O
M;F4@869T97(@=&AE(')E;6]V:6YG#0H@("`@*B!O9B!P871H+@T*("`@("H@
M5&AE('!A=&@@861D+W)E;6]V92!A8FEL:71Y(&5N86)L97,@=&AE('5S97(@
M=&\@<')E<&%R92!A;B!A<F-H:79E#0H@("`@*B!F;W(@97AT<F%C=&EO;B!I
M;B!A(&1I9F9E<F5N="!P871H('1H86X@=&AE(&]R:6=I;B!F:6QE<R!A<F4N
M#0H@("`@*B!)9B!A(&9I;&4O9&ER(&ES(&%L<F5A9'D@:6X@=&AE(&%R8VAI
M=F4@:70@=VEL;"!O;FQY(&)E(&%D9&5D(&%T('1H90T*("`@("H@96YD(&]F
M('1H92!A<F-H:79E+B!4:&5R92!I<R!N;R!U<&1A=&4@;V8@=&AE(&5X:7-T
M:6YG(&%R8VAI=F5D#0H@("`@*B!F:6QE+V1I<BX@2&]W979E<B!W:&EL92!E
M>'1R86-T:6YG('1H92!A<F-H:79E+"!T:&4@;&%S="!F:6QE('=I;&P-"B`@
M("`J(')E<&QA8V4@=&AE(&9I<G-T(&]N92X@5&AI<R!R97-U;'1S(&EN(&$@
M;F]N92!O<'1I;6EZ871I;VX@;V8@=&AE#0H@("`@*B!A<F-H:79E('-I>F4N
M#0H@("`@*B!)9B!A(&9I;&4O9&ER(&1O97,@;F]T(&5X:7-T('1H92!F:6QE
M+V1I<B!I<R!I9VYO<F5D+B!(;W=E=F5R(&%N#0H@("`@*B!E<G)O<B!T97AT
M(&ES('-E;F0@=&\@4$5!4B!E<G)O<BX-"B`@("`J($EF(&$@9FEL92]D:7(@
M:7,@;F]T(')E861A8FQE('1H92!F:6QE+V1I<B!I<R!I9VYO<F5D+B!(;W=E
M=F5R(&%N#0H@("`@*B!E<G)O<B!T97AT(&ES('-E;F0@=&\@4$5!4B!E<G)O
M<BX-"B`@("`J#0H@("`@*B!`<&%R86T@87)R87D@("`@("`D<%]F:6QE;&ES
M="`@("`@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O<GD-"@DJ
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE<RP@;W(@
M82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,-"@DJ("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S97!A<F%T960@8GD@82!S:6YG;&4@8FQA
M;FL@<W!A8V4N#0H@("`@*B!`<&%R86T@<W1R:6YG("`@("`D<%]A9&1?9&ER
M("`@("`@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@82!P871H('1O(&)E#0H)
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D960@=&\@
M=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@-"@DJ("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!E;&5M96YT(&EN('1H92!L:7-T+@T*("`@
M("H@0'!A<F%M('-T<FEN9R`@("`@)'!?<F5M;W9E7V1I<B`@($$@<W1R:6YG
M('=H:6-H(&-O;G1A:6YS(&$@<&%T:"!T;R!B90T*"2H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E;6]V960@9G)O;2!T:&4@;65M;W)I
M>F5D('!A=&@@;V8-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!E86-H(&5L96UE;G0@:6X@=&AE(&QI<W0L('=H96X-"B`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96QE=F%N="X-"B`@
M("`J($!R971U<FX@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$UO9&EF>2@D<%]F:6QE;&ES
M="P@)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<CTG)RD-"B`@("![#0H@("`@
M("`@("1V7W)E<W5L="`]('1R=64[#0H-"B`@("`@("`@:68@*"$D=&AI<RT^
M7VES07)C:&EV92@I*0T*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M
M/F-R96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP-"@D)"2`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!?<F5M;W9E7V1I<BD[
M#0H@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P
M7V9I;&5L:7-T*2D-"B`@("`@("`@("`@("`@("`D=E]L:7-T(#T@)'!?9FEL
M96QI<W0[#0H@("`@("`@("`@("!E;'-E:68@*&ES7W-T<FEN9R@D<%]F:6QE
M;&ES="DI#0H@("`@("`@("`@("`@("`@)'9?;&ES="`](&5X<&QO9&4H)'1H
M:7,M/E]S97!A<F%T;W(L("1P7V9I;&5L:7-T*3L-"B`@("`@("`@("`@(&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@
M9FEL92!L:7-T)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI
M<RT^7V%P<&5N9"@D=E]L:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&%D9%-T<FEN9R@I#0H@
M("`@+RHJ#0H@("`@*B!4:&ES(&UE=&AO9"!A9&0@82!S:6YG;&4@<W1R:6YG
M(&%S(&$@9FEL92!A="!T:&4-"B`@("`J(&5N9"!O9B!T:&4@97AI<W1I;F<@
M87)C:&EV92X@268@=&AE(&%R8VAI=F4@9&]E<R!N;W0@>65T(&5X:7-T<R!I
M=`T*("`@("H@:7,@8W)E871E9"X-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R
M:6YG("`@("`D<%]F:6QE;F%M92`@("`@02!S=')I;F<@=VAI8V@@8V]N=&%I
M;G,@=&AE(&9U;&P-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F:6QE;F%M92!P871H('1H870@=VEL;"!B92!A<W-O8VEA=&5D#0H)
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VET:"!T:&4@
M<W1R:6YG+@T*("`@("H@0'!A<F%M('-T<FEN9R`@("`@)'!?<W1R:6YG("`@
M("`@(%1H92!C;VYT96YT(&]F('1H92!F:6QE(&%D9&5D(&EN#0H)*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&%R8VAI=F4N#0H@
M("`@*B!`<F5T=7)N("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92!O
M;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A9&13=')I;F<H)'!?9FEL96YA
M;64L("1P7W-T<FEN9RD-"B`@("![#0H@("`@("`@("1V7W)E<W5L="`]('1R
M=64[#0H@("`@("`@(`T*("`@("`@("!I9B`H(21T:&ES+3Y?:7-!<F-H:79E
M*"DI('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N5W)I=&4H*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@?0T*
M("`@("`@("`-"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y!<'!E;F0H*2D-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("`O+R!.965D
M('1O(&-H96-K('1H92!G970@8F%C:R!T;R!T:&4@=&5M<&]R87)Y(&9I;&4@
M/R`N+BXN#0H@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?861D4W1R:6YG
M*"1P7V9I;&5N86UE+"`D<%]S=')I;F<I.PT*#0H@("`@("`@("1T:&ES+3Y?
M=W)I=&5&;V]T97(H*3L-"@T*("`@("`@("`D=&AI<RT^7V-L;W-E*"D[#0H-
M"B`@("`@("`@<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]#0H@("`@+R\@?7U]
M#0H-"B`@("`O+R![>WL@97AT<F%C=$UO9&EF>2@I#0H@("`@+RHJ#0H@("`@
M*B!4:&ES(&UE=&AO9"!E>'1R86-T(&%L;"!T:&4@8V]N=&5N="!O9B!T:&4@
M87)C:&EV92!I;B!T:&4@9&ER96-T;W)Y#0H@("`@*B!I;F1I8V%T960@8GD@
M)'!?<&%T:"X@5VAE;B!R96QE=F%N="!T:&4@;65M;W)I>F5D('!A=&@@;V8@
M=&AE#0H@("`@*B!F:6QE<R]D:7(@8V%N(&)E(&UO9&EF:65D(&)Y(')E;6]V
M:6YG('1H92`D<%]R96UO=F5?<&%T:"!P871H(&%T('1H90T*("`@("H@8F5G
M:6YN:6YG(&]F('1H92!F:6QE+V1I<B!P871H+@T*("`@("H@5VAI;&4@97AT
M<F%C=&EN9R!A(&9I;&4L(&EF('1H92!D:7)E8W1O<GD@<&%T:"!D;V5S(&YO
M="!E>&ES=',@:70@:7,-"B`@("`J(&-R96%T960N#0H@("`@*B!7:&EL92!E
M>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&9I;&4@86QR96%D>2!E>&ES=',@
M:70@:7,@<F5P;&%C960-"B`@("`J('=I=&AO=70@;&]O:VEN9R!F;W(@;&%S
M="!M;V1I9FEC871I;VX@9&%T92X-"B`@("`J(%=H:6QE(&5X=')A8W1I;F<@
M82!F:6QE+"!I9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I
M=&4-"B`@("`J('!R;W1E8W1E9"P@=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E
M9"X-"B`@("`J(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!A(&1I<F5C
M=&]R>2!W:71H('1H92!S86UE(&YA;64@86QR96%D>0T*("`@("H@97AI<W1S
M+"!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+@T*("`@("H@5VAI;&4@97AT
M<F%C=&EN9R!A(&1I<F5C=&]R>2P@:68@82!F:6QE('=I=&@@=&AE('-A;64@
M;F%M92!A;')E861Y#0H@("`@*B!E>&ES=',L('1H92!E>'1R86-T:6]N(&ES
M(&%B;W)T960N#0H@("`@*B!7:&EL92!E>'1R86-T:6YG(&$@9FEL92]D:7)E
M8W1O<GD@:68@=&AE(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2!E>&ES=`T*("`@
M("H@86YD(&ES('=R:71E('!R;W1E8W1E9"P@;W(@9&]E<R!N;W0@97AI<W0@
M8G5T(&-A;B!N;W0@8F4@8W)E871E9"P-"B`@("`J('1H92!E>'1R86-T:6]N
M(&ES(&%B;W)T960N#0H@("`@*B!)9B!A9G1E<B!E>'1R86-T:6]N(&%N(&5X
M=')A8W1E9"!F:6QE(&1O97,@;F]T('-H;W<@=&AE(&-O<G)E8W0-"B`@("`J
M('-T;W)E9"!F:6QE('-I>F4L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N
M#0H@("`@*B!7:&5N('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960L(&$@4$5!
M4B!E<G)O<B!T97AT(&ES('-E="!A;F0@9F%L<V4-"B`@("`J(&ES(')E='5R
M;F5D+B!(;W=E=F5R('1H92!R97-U;'0@8V%N(&)E(&$@<&%R=&EA;"!E>'1R
M86-T:6]N('1H870@;6%Y#0H@("`@*B!N965D('1O(&)E(&UA;G5A;&QY(&-L
M96%N960N#0H@("`@*@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]P871H("`@
M("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2!W:&5R92!T:&4-"@DJ
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I;&5S+V1I<B!N965D
M('1O(&)Y(&5X=')A8W1E9"X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?<F5M
M;W9E7W!A=&@@(%!A<G0@;V8@=&AE(&UE;6]R:7IE9"!P871H('1H870@8V%N
M(&)E#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F5D
M(&EF('!R97-E;G0@870@=&AE(&)E9VEN;FEN9R!O9@T*"2H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&9I;&4O9&ER('!A=&@N#0H@("`@
M*B!`<F5T=7)N(&)O;VQE86X@("`@("`@("`@("`@("!T<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`J($!S964@97AT<F%C=$QI<W0H*0T*("`@("HO#0H@("`@9G5N8W1I;VX@
M97AT<F%C=$UO9&EF>2@D<%]P871H+"`D<%]R96UO=F5?<&%T:"D-"B`@("![
M#0H@("`@("`@("1V7W)E<W5L="`]('1R=64[#0H@("`@("`@("1V7VQI<W1?
M9&5T86EL(#T@87)R87DH*3L-"@T*("`@("`@("!I9B`H)'9?<F5S=6QT(#T@
M)'1H:7,M/E]O<&5N4F5A9"@I*2![#0H@("`@("`@("`@("`D=E]R97-U;'0@
M/2`D=&AI<RT^7V5X=')A8W1,:7-T*"1P7W!A=&@L("1V7VQI<W1?9&5T86EL
M+`T*"0D)("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B8V]M<&QE
M=&4B+"`P+"`D<%]R96UO=F5?<&%T:"D[#0H@("`@("`@("`@("`D=&AI<RT^
M7V-L;W-E*"D[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'9?<F5S
M=6QT.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!E>'1R86-T
M26Y3=')I;F<H*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@97AT<F%C
M="!F<F]M('1H92!A<F-H:79E(&]N92!F:6QE(&ED96YT:69I960@8GD@)'!?
M9FEL96YA;64N#0H@("`@*B!4:&4@<F5T=7)N('9A;'5E(&ES(&$@<W1R:6YG
M('=I=&@@=&AE(&9I;&4@8V]N=&5N="P@;W(@3E5,3"!O;B!E<G)O<BX-"B`@
M("`J($!P87)A;2!S=')I;F<@)'!?9FEL96YA;64@("`@(%1H92!P871H(&]F
M('1H92!F:6QE('1O(&5X=')A8W0@:6X@82!S=')I;F<N#0H@("`@*B!`<F5T
M=7)N("`@("`@("`@("`@("`@("`@("`@("!A('-T<FEN9R!W:71H('1H92!F
M:6QE(&-O;G1E;G0@;W(@3E5,3"X-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!E>'1R86-T26Y3=')I;F<H)'!?9FEL96YA
M;64I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N4F5A9"@I*2![
M#0H@("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^7V5X=')A8W1);E-T
M<FEN9R@D<%]F:6QE;F%M92D[#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E
M*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=E]R97-U;'0@
M/2!.54Q,.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1V7W)E<W5L
M=#L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@97AT<F%C=$QI
M<W0H*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@97AT<F%C="!F<F]M
M('1H92!A<F-H:79E(&]N;'D@=&AE(&9I;&5S(&EN9&EC871E9"!I;B!T:&4-
M"B`@("`J("1P7V9I;&5L:7-T+B!4:&5S92!F:6QE<R!A<F4@97AT<F%C=&5D
M(&EN('1H92!C=7)R96YT(&1I<F5C=&]R>2!O<@T*("`@("H@:6X@=&AE(&1I
M<F5C=&]R>2!I;F1I8V%T960@8GD@=&AE(&]P=&EO;F%L("1P7W!A=&@@<&%R
M86UE=&5R+@T*("`@("H@268@:6YD:6-A=&5D('1H92`D<%]R96UO=F5?<&%T
M:"!C86X@8F4@=7-E9"!I;B!T:&4@<V%M92!W87D@87,@:70@:7,-"B`@("`J
M('5S960@:6X@97AT<F%C=$UO9&EF>2@I(&UE=&AO9"X-"B`@("`J($!P87)A
M;2!A<G)A>2`@)'!?9FEL96QI<W0@("`@($%N(&%R<F%Y(&]F(&9I;&5N86UE
M<R!A;F0@9&ER96-T;W)Y(&YA;65S+`T*"2H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;W(@82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P
M87)A=&5D#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B>2!A
M('-I;F=L92!B;&%N:R!S<&%C92X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?
M<&%T:"`@("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=VAE<F4@
M=&AE#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE<R]D
M:7(@;F5E9"!T;R!B>2!E>'1R86-T960N#0H@("`@*B!`<&%R86T@<W1R:6YG
M("1P7W)E;6]V95]P871H("!087)T(&]F('1H92!M96UO<FEZ960@<&%T:"!T
M:&%T(&-A;B!B90T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5M;W9E9"!I9B!P<F5S96YT(&%T('1H92!B96=I;FYI;F<@;V8-"@DJ("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F:6QE+V1I<B!P871H
M+@T*("`@("H@0')E='5R;B`@("`@("`@("`@("`@("`@("`@("`@=')U92!O
M;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@*B!`<V5E(&5X=')A8W1-;V1I9GDH*0T*("`@("HO#0H@("`@
M9G5N8W1I;VX@97AT<F%C=$QI<W0H)'!?9FEL96QI<W0L("1P7W!A=&@])R<L
M("1P7W)E;6]V95]P871H/2<G*0T*("`@('L-"B`@("`@("`@)'9?<F5S=6QT
M(#T@=')U93L-"B`@("`@("`@)'9?;&ES=%]D971A:6P@/2!A<G)A>2@I.PT*
M#0H@("`@("`@(&EF("AI<U]A<G)A>2@D<%]F:6QE;&ES="DI#0H@("`@("`@
M("`@("`D=E]L:7-T(#T@)'!?9FEL96QI<W0[#0H@("`@("`@(&5L<V5I9B`H
M:7-?<W1R:6YG*"1P7V9I;&5L:7-T*2D-"B`@("`@("`@("`@("1V7VQI<W0@
M/2!E>'!L;V1E*"1T:&ES+3Y?<V5P87)A=&]R+"`D<%]F:6QE;&ES="D[#0H@
M("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV
M86QI9"!S=')I;F<@;&ES="<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1V7W)E<W5L="`]("1T:&ES
M+3Y?;W!E;E)E860H*2D@>PT*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H
M:7,M/E]E>'1R86-T3&ES="@D<%]P871H+"`D=E]L:7-T7V1E=&%I;"P@(G!A
M<G1I86PB+`T*"0D)("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=E]L:7-T+"`D<%]R96UO=F5?<&%T:"D[#0H@("`@("`@("`@("`D=&AI<RT^
M7V-L;W-E*"D[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'9?<F5S
M=6QT.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!S971!='1R
M:6)U=&4H*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@<V5T('-P96-I
M9FEC(&%T=')I8G5T97,@;V8@=&AE(&%R8VAI=F4N($ET('5S97,@82!V87)I
M86)L90T*("`@("H@;&ES="!O9B!P87)A;65T97)S+"!I;B!T:&4@9F]R;6%T
M(&%T=')I8G5T92!C;V1E("L@871T<FEB=71E('9A;'5E<R`Z#0H@("`@*B`D
M87)C:"T^<V5T071T<FEB=71E*$%20TA)5D5?5$%27T%45%]315!!4D%43U(L
M("<L)RD[#0H@("`@*B!`<&%R86T@;6EX960@)&%R9W8@("`@("`@("`@("!V
M87)I86)L92!L:7-T(&]F(&%T=')I8G5T97,@86YD('9A;'5E<PT*("`@("H@
M0')E='5R;B`@("`@("`@("`@("`@("`@("`@("`@=')U92!O;B!S=6-C97-S
M+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971!='1R:6)U=&4H*0T*("`@('L-"B`@("`@
M("`@)'9?<F5S=6QT(#T@=')U93L-"B`@("`@("`@#0H@("`@("`@("\O("TM
M+2TM($=E="!T:&4@;G5M8F5R(&]F('9A<FEA8FQE(&QI<W0@;V8@87)G=6UE
M;G1S#0H@("`@("`@(&EF("@H)'9?<VEZ92`](&9U;F-?;G5M7V%R9W,H*2D@
M/3T@,"D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@#0H@("`@("`@("\O("TM+2TM($=E="!T:&4@87)G=6UE;G1S
M#0H@("`@("`@("1V7V%T=%]L:7-T(#T@)F9U;F-?9V5T7V%R9W,H*3L-"@T*
M("`@("`@("`O+R`M+2TM+2!296%D('1H92!A='1R:6)U=&5S#0H@("`@("`@
M("1I/3`[#0H@("`@("`@('=H:6QE("@D:3PD=E]S:7IE*2![#0H-"B`@("`@
M("`@("`@("\O("TM+2TM($QO;VL@9F]R(&YE>'0@;W!T:6]N#0H@("`@("`@
M("`@("!S=VET8V@@*"1V7V%T=%]L:7-T6R1I72D@>PT*("`@("`@("`@("`@
M("`@("\O("TM+2TM($QO;VL@9F]R(&]P=&EO;G,@=&AA="!R97%U97-T(&$@
M<W1R:6YG('9A;'5E#0H@("`@("`@("`@("`@("`@8V%S92!!4D-(259%7U1!
M4E]!5%1?4T5005)!5$]2(#H-"B`@("`@("`@("`@("`@("`@("`@+R\@+2TM
M+2T@0VAE8VL@=&AE(&YU;6)E<B!O9B!P87)A;65T97)S#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@H)&DK,2D@/CT@)'9?<VEZ92D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!N=6UB97(@
M;V8@<&%R86UE=&5R<R!F;W(@)PT*"0D)"0D)("`@("`@("`@("`@("`N)V%T
M=')I8G5T92!!4D-(259%7U1!4E]!5%1?4T5005)!5$]2)RD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("`O+R`M+2TM+2!'970@
M=&AE('9A;'5E#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5P87)A
M=&]R(#T@)'9?871T7VQI<W1;)&DK,5T[#0H@("`@("`@("`@("`@("`@("`@
M("1I*RL[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@
M("`@("!D969A=6QT(#H-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E
M<G)O<B@G56YK;F]W(&%T=')I8G5T92!C;V1E("<N)'9?871T7VQI<W1;)&E=
M+B<G*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@?0T*#0H@("`@("`@("`@("`O+R`M+2TM+2!.97AT(&%T=')I
M8G5T90T*("`@("`@("`@("`@)&DK*SL-"B`@("`@("`@?0T*#0H@("`@("`@
M(')E='5R;B`D=E]R97-U;'0[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@
M+R\@>WM[(%]E<G)O<B@I#0H@("`@9G5N8W1I;VX@7V5R<F]R*"1P7VUE<W-A
M9V4I#0H@("`@>PT*("`@("`@("`O+R`M+2TM+2!4;R!B92!C;VUP;&5T960-
M"B`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)'!?;65S<V%G92D[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]W87)N:6YG*"D-"B`@("!F
M=6YC=&EO;B!?=V%R;FEN9R@D<%]M97-S86=E*0T*("`@('L-"B`@("`@("`@
M+R\@+2TM+2T@5&\@8F4@8V]M<&QE=&5D#0H@("`@("`@("1T:&ES+3YR86ES
M945R<F]R*"1P7VUE<W-A9V4I.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@
M("\O('M[>R!?:7-!<F-H:79E*"D-"B`@("!F=6YC=&EO;B!?:7-!<F-H:79E
M*"1P7V9I;&5N86UE/4Y53$PI#0H@("`@>PT*("`@("`@("!I9B`H)'!?9FEL
M96YA;64@/3T@3E5,3"D@>PT*("`@("`@("`@("`@)'!?9FEL96YA;64@/2`D
M=&AI<RT^7W1A<FYA;64[#0H@("`@("`@('T-"B`@("`@("`@8VQE87)S=&%T
M8V%C:&4H*3L-"B`@("`@("`@<F5T=7)N($!I<U]F:6QE*"1P7V9I;&5N86UE
M*3L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V]P96Y7<FET
M92@I#0H@("`@9G5N8W1I;VX@7V]P96Y7<FET92@I#0H@("`@>PT*("`@("`@
M("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@
M("`@("`D=&AI<RT^7V9I;&4@/2!`9WIO<&5N*"1T:&ES+3Y?=&%R;F%M92P@
M(G=B.2(I.PT*("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y
M<&4@/3T@)V)Z,B<I#0H@("`@("`@("`@("`D=&AI<RT^7V9I;&4@/2!`8GIO
M<&5N*"1T:&ES+3Y?=&%R;F%M92P@(G=B(BD[#0H@("`@("`@(&5L<V4@:68@
M*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G;F]N92<I#0H@("`@("`@("`@
M("`D=&AI<RT^7V9I;&4@/2!`9F]P96XH)'1H:7,M/E]T87)N86UE+"`B=V(B
M*3L-"B`@("`@("`@96QS90T*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G
M56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<-"@D)"2`@
M("`@("`@("`@("`@+B1T:&ES+3Y?8V]M<')E<W-?='EP92XG*2<I.PT*#0H@
M("`@("`@(&EF("@D=&AI<RT^7V9I;&4@/3T@,"D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&]P96X@:6X@=W)I=&4@;6]D92!<
M)R<-"@D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?=&%R;F%M92XG7"<G*3L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?;W!E;E)E860H*0T*("`@(&9U;F-T:6]N(%]O<&5N4F5A9"@I#0H@
M("`@>PT*("`@("`@("!I9B`H<W1R=&]L;W=E<BAS=6)S='(H)'1H:7,M/E]T
M87)N86UE+"`P+"`W*2D@/3T@)VAT='`Z+R\G*2![#0H-"B`@("`@("`@("`O
M+R`M+2TM+2!,;V]K(&EF(&$@;&]C86P@8V]P>2!N965D('1O(&)E(&1O;F4-
M"B`@("`@("`@("!I9B`H)'1H:7,M/E]T96UP7W1A<FYA;64@/3T@)R<I('L-
M"B`@("`@("`@("`@("`@)'1H:7,M/E]T96UP7W1A<FYA;64@/2!U;FEQ:60H
M)W1A<B<I+B<N=&UP)SL-"B`@("`@("`@("`@("`@:68@*"$D=E]F:6QE7V9R
M;VT@/2!`9F]P96XH)'1H:7,M/E]T87)N86UE+"`G<F(G*2D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&EN(')E
M860@;6]D92!<)R<-"@D)"0D@("`@("`@("`@("`@("XD=&AI<RT^7W1A<FYA
M;64N)UPG)RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]T96UP7W1A<FYA
M;64@/2`G)SL-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@:68@*"$D=E]F:6QE7W1O(#T@
M0&9O<&5N*"1T:&ES+3Y?=&5M<%]T87)N86UE+"`G=V(G*2D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&EN('=R
M:71E(&UO9&4@7"<G#0H)"0D)("`@("`@("`@("`@("`N)'1H:7,M/E]T96UP
M7W1A<FYA;64N)UPG)RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]T96UP
M7W1A<FYA;64@/2`G)SL-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@=VAI;&4@*"1V7V1A
M=&$@/2!`9G)E860H)'9?9FEL95]F<F]M+"`Q,#(T*2D-"B`@("`@("`@("`@
M("`@("`@($!F=W)I=&4H)'9?9FEL95]T;RP@)'9?9&%T82D[#0H@("`@("`@
M("`@("`@($!F8VQO<V4H)'9?9FEL95]F<F]M*3L-"B`@("`@("`@("`@("`@
M0&9C;&]S92@D=E]F:6QE7W1O*3L-"B`@("`@("`@("!]#0H-"B`@("`@("`@
M("`O+R`M+2TM+2!&:6QE('1O(&]P96X@:68@=&AE(&QO8V%L(&-O<'D-"B`@
M("`@("`@("`D=E]F:6QE;F%M92`]("1T:&ES+3Y?=&5M<%]T87)N86UE.PT*
M#0H@("`@("`@('T@96QS90T*("`@("`@("`@("\O("TM+2TM($9I;&4@=&\@
M;W!E;B!I9B!T:&4@;F]R;6%L(%1A<B!F:6QE#0H@("`@("`@("`@)'9?9FEL
M96YA;64@/2`D=&AI<RT^7W1A<FYA;64[#0H-"B`@("`@("`@:68@*"1T:&ES
M+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@)'1H:7,M
M/E]F:6QE(#T@0&=Z;W!E;B@D=E]F:6QE;F%M92P@(G)B(BD[#0H@("`@("`@
M(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@
M("`@("`@("`@("1T:&ES+3Y?9FEL92`]($!B>F]P96XH)'9?9FEL96YA;64L
M(")R8B(I.PT*("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y
M<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&9O
M<&5N*"1V7V9I;&5N86UE+"`B<F(B*3L-"B`@("`@("`@96QS90T*("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R
M97-S:6]N('1Y<&4@*"<-"@D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?8V]M
M<')E<W-?='EP92XG*2<I.PT*#0H@("`@("`@(&EF("@D=&AI<RT^7V9I;&4@
M/3T@,"D@>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O
M(&]P96X@:6X@<F5A9"!M;V1E(%PG)RXD=E]F:6QE;F%M92XG7"<G*3L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!?;W!E;E)E8617<FET92@I#0H@("`@9G5N8W1I;VX@7V]P96Y296%D5W)I
M=&4H*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP
M92`]/2`G9WHG*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&=Z;W!E
M;B@D=&AI<RT^7W1A<FYA;64L(")R*V(B*3L-"B`@("`@("`@96QS92!I9B`H
M)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@
M)'1H:7,M/E]F:6QE(#T@0&)Z;W!E;B@D=&AI<RT^7W1A<FYA;64L(")R*V(B
M*3L-"B`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]
M("=N;VYE)RD-"B`@("`@("`@("`@("1T:&ES+3Y?9FEL92`]($!F;W!E;B@D
M=&AI<RT^7W1A<FYA;64L(")R*V(B*3L-"B`@("`@("`@96QS90T*("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R
M97-S:6]N('1Y<&4@*"<-"@D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?8V]M
M<')E<W-?='EP92XG*2<I.PT*#0H@("`@("`@(&EF("@D=&AI<RT^7V9I;&4@
M/3T@,"D@>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O
M(&]P96X@:6X@<F5A9"]W<FET92!M;V1E(%PG)PT*"0D)("`@("`@("`@("`@
M("`N)'1H:7,M/E]T87)N86UE+B=<)R<I.PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]C;&]S92@I#0H@("`@
M9G5N8W1I;VX@7V-L;W-E*"D-"B`@("![#0H@("`@("`@("\O:68@*&ES<V5T
M*"1T:&ES+3Y?9FEL92DI('L-"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T
M:&ES+3Y?9FEL92DI('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R
M97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@("!`9WIC;&]S92@D
M=&AI<RT^7V9I;&4I.PT*("`@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@("`@($!B>F-L
M;W-E*"1T:&ES+3Y?9FEL92D[#0H@("`@("`@("`@("!E;'-E(&EF("@D=&AI
M<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@("`@
M($!F8VQO<V4H)'1H:7,M/E]F:6QE*3L-"B`@("`@("`@("`@(&5L<V4-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;FMN;W=N(&]R(&UI<W-I
M;F<@8V]M<')E<W-I;VX@='EP92`H)PT*"0D)"2`@("`@("`@("`@("`@+B1T
M:&ES+3Y?8V]M<')E<W-?='EP92XG*2<I.PT*#0H@("`@("`@("`@("`D=&AI
M<RT^7V9I;&4@/2`P.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@
M3&]O:R!I9B!A(&QO8V%L(&-O<'D@;F5E9"!T;R!B92!E<F%S90T*("`@("`@
M("`O+R!.;W1E('1H870@:70@;6EG:'0@8F4@:6YT97)E<W1I;F<@=&\@:V5E
M<"!T:&4@=7)L(&9O<B!A('1I;64@.B!4;T1O#0H@("`@("`@(&EF("@D=&AI
M<RT^7W1E;7!?=&%R;F%M92`A/2`G)RD@>PT*("`@("`@("`@("`@0'5N;&EN
M:R@D=&AI<RT^7W1E;7!?=&%R;F%M92D[#0H@("`@("`@("`@("`D=&AI<RT^
M7W1E;7!?=&%R;F%M92`]("<G.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]C
M;&5A;D9I;&4H*0T*("`@(&9U;F-T:6]N(%]C;&5A;D9I;&4H*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]C;&]S92@I.PT*#0H@("`@("`@("\O("TM+2TM
M($QO;VL@9F]R(&$@;&]C86P@8V]P>0T*("`@("`@("!I9B`H)'1H:7,M/E]T
M96UP7W1A<FYA;64@(3T@)R<I('L-"B`@("`@("`@("`@("\O("TM+2TM(%)E
M;6]V92!T:&4@;&]C86P@8V]P>2!B=70@;F]T('1H92!R96UO=&4@=&%R;F%M
M90T*("`@("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7W1E;7!?=&%R;F%M92D[
M#0H@("`@("`@("`@("`D=&AI<RT^7W1E;7!?=&%R;F%M92`]("<G.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@+R\@+2TM+2T@4F5M;W9E('1H
M92!L;V-A;"!T87)N86UE(&9I;&4-"B`@("`@("`@("`@($!U;FQI;FLH)'1H
M:7,M/E]T87)N86UE*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W1A
M<FYA;64@/2`G)SL-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7W=R:71E0FQO8VLH*0T*("`@(&9U
M;F-T:6]N(%]W<FET94)L;V-K*"1P7V)I;F%R>5]D871A+"`D<%]L96X];G5L
M;"D-"B`@("![#0H@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]F:6QE
M*2D@>PT*("`@("`@("`@(&EF("@D<%]L96X@/3T](&YU;&PI('L-"B`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*
M("`@("`@("`@("`@("`@("`@0&=Z<'5T<R@D=&AI<RT^7V9I;&4L("1P7V)I
M;F%R>5]D871A*3L-"B`@("`@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@("`@("`@0&)Z
M=W)I=&4H)'1H:7,M/E]F:6QE+"`D<%]B:6YA<GE?9&%T82D[#0H@("`@("`@
M("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G;F]N
M92<I#0H@("`@("`@("`@("`@("`@("!`9G!U=',H)'1H:7,M/E]F:6QE+"`D
M<%]B:6YA<GE?9&%T82D[#0H@("`@("`@("`@("`@(&5L<V4-"B`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C
M;VUP<F5S<VEO;B!T>7!E("@G#0H)"0D)("`@("`@("`@("`@("`@("XD=&AI
M<RT^7V-O;7!R97-S7W1Y<&4N)RDG*3L-"B`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G
M>B<I#0H@("`@("`@("`@("`@("`@("!`9WIP=71S*"1T:&ES+3Y?9FEL92P@
M)'!?8FEN87)Y7V1A=&$L("1P7VQE;BD[#0H@("`@("`@("`@("`@(&5L<V4@
M:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@
M("`@("`@("`@($!B>G=R:71E*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A
M=&$L("1P7VQE;BD[#0H@("`@("`@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?
M8V]M<')E<W-?='EP92`]/2`G;F]N92<I#0H@("`@("`@("`@("`@("`@("!`
M9G!U=',H)'1H:7,M/E]F:6QE+"`D<%]B:6YA<GE?9&%T82P@)'!?;&5N*3L-
M"B`@("`@("`@("`@("`@96QS90T*("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@
M*"<-"@D)"0D@("`@("`@("`@("`@("`@+B1T:&ES+3Y?8V]M<')E<W-?='EP
M92XG*2<I.PT*#0H@("`@("`@("`@?0T*("`@("`@?0T*("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]R96%D
M0FQO8VLH*0T*("`@(&9U;F-T:6]N(%]R96%D0FQO8VLH*0T*("`@('L-"B`@
M("`@("1V7V)L;V-K(#T@;G5L;#L-"B`@("`@(&EF("AI<U]R97-O=7)C92@D
M=&AI<RT^7V9I;&4I*2![#0H@("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E
M<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@("`D=E]B;&]C:R`]($!G
M>G)E860H)'1H:7,M/E]F:6QE+"`U,3(I.PT*("`@("`@("`@(&5L<V4@:68@
M*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@
M("`@)'9?8FQO8VL@/2!`8GIR96%D*"1T:&ES+3Y?9FEL92P@-3$R*3L-"B`@
M("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO
M;F4G*0T*("`@("`@("`@("`@("`D=E]B;&]C:R`]($!F<F5A9"@D=&AI<RT^
M7V9I;&4L(#4Q,BD[#0H@("`@("`@("`@96QS90T*("`@("`@("`@("`@("`D
M=&AI<RT^7V5R<F]R*"=5;FMN;W=N(&]R(&UI<W-I;F<@8V]M<')E<W-I;VX@
M='EP92`H)PT*"0D)("`@("`@("`@("`@("`@("XD=&AI<RT^7V-O;7!R97-S
M7W1Y<&4N)RDG*3L-"B`@("`@('T-"B`@("`@(')E='5R;B`D=E]B;&]C:SL-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7VIU;7!";&]C:R@I
M#0H@("`@9G5N8W1I;VX@7VIU;7!";&]C:R@D<%]L96X];G5L;"D-"B`@("![
M#0H@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]F:6QE*2D@>PT*("`@
M("`@("`@(&EF("@D<%]L96X@/3T](&YU;&PI#0H@("`@("`@("`@("`@("1P
M7VQE;B`](#$[#0H-"B`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T
M>7!E(#T]("=G>B<I('L-"B`@("`@("`@("`@("`@0&=Z<V5E:R@D=&AI<RT^
M7V9I;&4L($!G>G1E;&PH)'1H:7,M/E]F:6QE*2LH)'!?;&5N*C4Q,BDI.PT*
M("`@("`@("`@('T-"B`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R
M97-S7W1Y<&4@/3T@)V)Z,B<I('L-"B`@("`@("`@("`@("`@+R\@+2TM+2T@
M4F5P;&%C92!M:7-S:6YG(&)Z=&5L;"@I(&%N9"!B>G-E96LH*0T*("`@("`@
M("`@("`@("!F;W(@*"1I/3`[("1I/"1P7VQE;CL@)&DK*RD-"B`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F5A9$)L;V-K*"D[#0H@("`@("`@("`@?2!E
M;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@
M("`@("`@("`@("!`9G-E96LH)'1H:7,M/E]F:6QE+"!`9G1E;&PH)'1H:7,M
M/E]F:6QE*2LH)'!?;&5N*C4Q,BDI.PT*("`@("`@("`@(&5L<V4-"B`@("`@
M("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O
M;7!R97-S:6]N('1Y<&4@*"<-"@D)"2`@("`@("`@("`@("`@("`N)'1H:7,M
M/E]C;VUP<F5S<U]T>7!E+B<I)RD[#0H-"B`@("`@('T-"B`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?=W)I
M=&5&;V]T97(H*0T*("`@(&9U;F-T:6]N(%]W<FET949O;W1E<B@I#0H@("`@
M>PT*("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?9FEL92DI('L-"B`@
M("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@;&%S="`P(&9I;&QE9"!B;&]C
M:R!F;W(@96YD(&]F(&%R8VAI=F4-"B`@("`@("`@("`D=E]B:6YA<GE?9&%T
M82`]('!A8VLH(F$U,3(B+"`G)RD[#0H@("`@("`@("`@)'1H:7,M/E]W<FET
M94)L;V-K*"1V7V)I;F%R>5]D871A*3L-"B`@("`@('T-"B`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?861D
M3&ES="@I#0H@("`@9G5N8W1I;VX@7V%D9$QI<W0H)'!?;&ES="P@)'!?861D
M7V1I<BP@)'!?<F5M;W9E7V1I<BD-"B`@("![#0H@("`@("`D=E]R97-U;'0]
M=')U93L-"B`@("`@("1V7VAE861E<B`](&%R<F%Y*"D[#0H-"B`@("`@("\O
M("TM+2TM(%)E;6]V92!P;W1E;G1I86P@=VEN9&]W<R!D:7)E8W1O<GD@<V5P
M87)A=&]R#0H@("`@("`D<%]A9&1?9&ER(#T@)'1H:7,M/E]T<F%N<VQA=&57
M:6Y0871H*"1P7V%D9%]D:7(I.PT*("`@("`@)'!?<F5M;W9E7V1I<B`]("1T
M:&ES+3Y?=')A;G-L871E5VEN4&%T:"@D<%]R96UO=F5?9&ER+"!F86QS92D[
M#0H-"B`@("`@(&EF("@A)'1H:7,M/E]F:6QE*2![#0H@("`@("`@("`@)'1H
M:7,M/E]E<G)O<B@G26YV86QI9"!F:6QE(&1E<V-R:7!T;W(G*3L-"B`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("!]#0H-"B`@("`@(&EF("AS:7IE
M;V8H)'!?;&ES="D@/3T@,"D-"B`@("`@("`@("!R971U<FX@=')U93L-"@T*
M("`@("`@9F]R96%C:"`H)'!?;&ES="!A<R`D=E]F:6QE;F%M92D@>PT*("`@
M("`@("`@(&EF("@A)'9?<F5S=6QT*2![#0H@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@('T-"@T*("`@("`@("`O+R`M+2TM+2!3:VEP('1H92!C
M=7)R96YT('1A<B!N86UE#0H@("`@("`@(&EF("@D=E]F:6QE;F%M92`]/2`D
M=&AI<RT^7W1A<FYA;64I#0H@("`@("`@("`@("!C;VYT:6YU93L-"@T*("`@
M("`@("!I9B`H)'9?9FEL96YA;64@/3T@)R<I#0H@("`@("`@("`@("!C;VYT
M:6YU93L-"@T*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1V7V9I;&5N86UE
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG*")&:6QE("<D=E]F
M:6QE;F%M92<@9&]E<R!N;W0@97AI<W0B*3L-"B`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@061D('1H92!F
M:6QE(&]R(&1I<F5C=&]R>2!H96%D97(-"B`@("`@("`@:68@*"$D=&AI<RT^
M7V%D9$9I;&4H)'9?9FEL96YA;64L("1V7VAE861E<BP@)'!?861D7V1I<BP@
M)'!?<F5M;W9E7V1I<BDI#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H-
M"B`@("`@("`@:68@*$!I<U]D:7(H)'9?9FEL96YA;64I*2![#0H@("`@("`@
M("`@("!I9B`H(2@D<%]H9&ER(#T@;W!E;F1I<B@D=E]F:6QE;F%M92DI*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG*")$:7)E8W1O<GD@
M)R1V7V9I;&5N86UE)R!C86X@;F]T(&)E(')E860B*3L-"B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('=H
M:6QE("AF86QS92`A/3T@*"1P7VAI=&5M(#T@<F5A9&1I<B@D<%]H9&ER*2DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H*"1P7VAI=&5M("$]("<N)RD@)B8@
M*"1P7VAI=&5M("$]("<N+B<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D=E]F:6QE;F%M92`A/2`B+B(I#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<%]T96UP7VQI<W1;,%T@/2`D=E]F:6QE;F%M92XG+R<N)'!?:&ET96T[
M#0H@("`@("`@("`@("`@("`@("`@(&5L<V4-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P7W1E;7!?;&ES=%LP72`]("1P7VAI=&5M.PT*#0H@("`@("`@
M("`@("`@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?861D3&ES="@D<%]T
M96UP7VQI<W0L#0H)"0D)"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<%]A9&1?9&ER+`T*"0D)"0D)"0D)"0D))'!?<F5M;W9E7V1I<BD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!U
M;G-E="@D<%]T96UP7VQI<W0I.PT*("`@("`@("`@("`@=6YS970H)'!?:&1I
M<BD[#0H@("`@("`@("`@("!U;G-E="@D<%]H:71E;2D[#0H@("`@("`@('T-
M"B`@("`@('T-"@T*("`@("`@<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V%D9$9I;&4H*0T*("`@(&9U;F-T
M:6]N(%]A9&1&:6QE*"1P7V9I;&5N86UE+"`F)'!?:&5A9&5R+"`D<%]A9&1?
M9&ER+"`D<%]R96UO=F5?9&ER*0T*("`@('L-"B`@("`@(&EF("@A)'1H:7,M
M/E]F:6QE*2![#0H@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!F
M:6QE(&1E<V-R:7!T;W(G*3L-"B`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("!]#0H-"B`@("`@(&EF("@D<%]F:6QE;F%M92`]/2`G)RD@>PT*("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL92!N86UE)RD[#0H@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@?0T*#0H@("`@("`O+R`M
M+2TM+2!#86QC=6QA=&4@=&AE('-T;W)E9"!F:6QE;F%M90T*("`@("`@)'!?
M9FEL96YA;64@/2`D=&AI<RT^7W1R86YS;&%T95=I;E!A=&@H)'!?9FEL96YA
M;64L(&9A;'-E*3L[#0H@("`@("`D=E]S=&]R961?9FEL96YA;64@/2`D<%]F
M:6QE;F%M93L-"B`@("`@(&EF("AS=')C;7`H)'!?9FEL96YA;64L("1P7W)E
M;6]V95]D:7(I(#T](#`I('L-"B`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@('T-"B`@("`@(&EF("@D<%]R96UO=F5?9&ER("$]("<G*2![#0H@("`@
M("`@("`@:68@*'-U8G-T<B@D<%]R96UO=F5?9&ER+"`M,2D@(3T@)R\G*0T*
M("`@("`@("`@("`@("`D<%]R96UO=F5?9&ER("X]("<O)SL-"@T*("`@("`@
M("`@(&EF("AS=6)S='(H)'!?9FEL96YA;64L(#`L('-T<FQE;B@D<%]R96UO
M=F5?9&ER*2D@/3T@)'!?<F5M;W9E7V1I<BD-"B`@("`@("`@("`@("`@)'9?
M<W1O<F5D7V9I;&5N86UE(#T@<W5B<W1R*"1P7V9I;&5N86UE+"!S=')L96XH
M)'!?<F5M;W9E7V1I<BDI.PT*("`@("`@?0T*("`@("`@)'9?<W1O<F5D7V9I
M;&5N86UE(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0871H*"1V7W-T;W)E9%]F
M:6QE;F%M92D[#0H@("`@("!I9B`H)'!?861D7V1I<B`A/2`G)RD@>PT*("`@
M("`@("`@(&EF("AS=6)S='(H)'!?861D7V1I<BP@+3$I(#T]("<O)RD-"B`@
M("`@("`@("`@("`@)'9?<W1O<F5D7V9I;&5N86UE(#T@)'!?861D7V1I<BXD
M=E]S=&]R961?9FEL96YA;64[#0H@("`@("`@("`@96QS90T*("`@("`@("`@
M("`@("`D=E]S=&]R961?9FEL96YA;64@/2`D<%]A9&1?9&ER+B<O)RXD=E]S
M=&]R961?9FEL96YA;64[#0H@("`@("!]#0H-"B`@("`@("1V7W-T;W)E9%]F
M:6QE;F%M92`]("1T:&ES+3Y?<&%T:%)E9'5C=&EO;B@D=E]S=&]R961?9FEL
M96YA;64I.PT*#0H@("`@("!I9B`H)'1H:7,M/E]I<T%R8VAI=F4H)'!?9FEL
M96YA;64I*2![#0H@("`@("`@("`@:68@*"@D=E]F:6QE(#T@0&9O<&5N*"1P
M7V9I;&5N86UE+"`B<F(B*2D@/3T@,"D@>PT*("`@("`@("`@("`@("`D=&AI
M<RT^7W=A<FYI;F<H(E5N86)L92!T;R!O<&5N(&9I;&4@)R(N)'!?9FEL96YA
M;64-"@D)"2`@("`@("`@("`@("`@("`@("XB)R!I;B!B:6YA<GD@<F5A9"!M
M;V1E(BD[#0H@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M('T-"@T*("`@("`@("`@(&EF("@A)'1H:7,M/E]W<FET94AE861E<B@D<%]F
M:6QE;F%M92P@)'9?<W1O<F5D7V9I;&5N86UE*2D-"B`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*#0H@("`@("`@("`@=VAI;&4@*"@D=E]B=69F97(@
M/2!F<F5A9"@D=E]F:6QE+"`U,3(I*2`A/2`G)RD@>PT*("`@("`@("`@("`@
M("`D=E]B:6YA<GE?9&%T82`]('!A8VLH(F$U,3(B+"`B)'9?8G5F9F5R(BD[
M#0H@("`@("`@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?
M9&%T82D[#0H@("`@("`@("`@?0T*#0H@("`@("`@("`@9F-L;W-E*"1V7V9I
M;&4I.PT*#0H@("`@("!](&5L<V4@>PT*("`@("`@("`@("\O("TM+2TM($]N
M;'D@:&5A9&5R(&9O<B!D:7(-"B`@("`@("`@("!I9B`H(21T:&ES+3Y?=W)I
M=&5(96%D97(H)'!?9FEL96YA;64L("1V7W-T;W)E9%]F:6QE;F%M92DI#0H@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(%]A9&13=')I;F<H*0T*("`@(&9U;F-T:6]N(%]A9&13=')I;F<H)'!?9FEL
M96YA;64L("1P7W-T<FEN9RD-"B`@("![#0H@("`@("!I9B`H(21T:&ES+3Y?
M9FEL92D@>PT*("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL
M92!D97-C<FEP=&]R)RD[#0H@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@?0T*#0H@("`@("!I9B`H)'!?9FEL96YA;64@/3T@)R<I('L-"B`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@;F%M92<I.PT*("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@+R\@+2TM
M+2T@0V%L8W5L871E('1H92!S=&]R960@9FEL96YA;64-"B`@("`@("1P7V9I
M;&5N86UE(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0871H*"1P7V9I;&5N86UE
M+"!F86QS92D[.PT*#0H@("`@("!I9B`H(21T:&ES+3Y?=W)I=&5(96%D97)"
M;&]C:R@D<%]F:6QE;F%M92P@<W1R;&5N*"1P7W-T<FEN9RDL#0H)("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`P+"`P+"`B(BP@,"P@,"DI#0H@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`D:3TP.PT*("`@("`@
M=VAI;&4@*"@D=E]B=69F97(@/2!S=6)S='(H)'!?<W1R:6YG+"`H*"1I*RLI
M*C4Q,BDL(#4Q,BDI("$]("<G*2![#0H@("`@("`@("`@)'9?8FEN87)Y7V1A
M=&$@/2!P86-K*")A-3$R(BP@)'9?8G5F9F5R*3L-"B`@("`@("`@("`D=&AI
M<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&$I.PT*("`@("`@?0T*#0H@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O
M+R![>WL@7W=R:71E2&5A9&5R*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5(96%D
M97(H)'!?9FEL96YA;64L("1P7W-T;W)E9%]F:6QE;F%M92D-"B`@("![#0H@
M("`@("`@(&EF("@D<%]S=&]R961?9FEL96YA;64@/3T@)R<I#0H@("`@("`@
M("`@("`D<%]S=&]R961?9FEL96YA;64@/2`D<%]F:6QE;F%M93L-"B`@("`@
M("`@)'9?<F5D=6-E7V9I;&5N86UE(#T@)'1H:7,M/E]P871H4F5D=6-T:6]N
M*"1P7W-T;W)E9%]F:6QE;F%M92D[#0H-"B`@("`@("`@:68@*'-T<FQE;B@D
M=E]R961U8V5?9FEL96YA;64I(#X@.3DI('L-"B`@("`@("`@("!I9B`H(21T
M:&ES+3Y?=W)I=&5,;VYG2&5A9&5R*"1V7W)E9'5C95]F:6QE;F%M92DI#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@
M("`D=E]I;F9O(#T@<W1A="@D<%]F:6QE;F%M92D[#0H@("`@("`@("1V7W5I
M9"`]('-P<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?:6YF;ULT72DI.PT*("`@
M("`@("`D=E]G:60@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V7VEN9F];
M-5TI*3L-"B`@("`@("`@)'9?<&5R;7,@/2!S<')I;G1F*"(E-G,@(BP@1&5C
M3V-T*&9I;&5P97)M<R@D<%]F:6QE;F%M92DI*3L-"@T*("`@("`@("`D=E]M
M=&EM92`]('-P<FEN=&8H(B4Q,7,B+"!$96-/8W0H9FEL96UT:6UE*"1P7V9I
M;&5N86UE*2DI.PT*#0H@("`@("`@(&EF("A`:7-?9&ER*"1P7V9I;&5N86UE
M*2D@>PT*("`@("`@("`@("1V7W1Y<&5F;&%G(#T@(C4B.PT*("`@("`@("`@
M("1V7W-I>F4@/2!S<')I;G1F*"(E,3%S("(L($1E8T]C="@P*2D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@)'9?='EP969L86<@/2`G)SL-"B`@
M("`@("`@("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("`@("1V7W-I>F4@
M/2!S<')I;G1F*"(E,3%S("(L($1E8T]C="AF:6QE<VEZ92@D<%]F:6QE;F%M
M92DI*3L-"B`@("`@("`@?0T*#0H@("`@("`@("1V7VQI;FMN86UE(#T@)R<[
M#0H-"B`@("`@("`@)'9?;6%G:6,@/2`G)SL-"@T*("`@("`@("`D=E]V97)S
M:6]N(#T@)R<[#0H-"B`@("`@("`@)'9?=6YA;64@/2`G)SL-"@T*("`@("`@
M("`D=E]G;F%M92`]("<G.PT*#0H@("`@("`@("1V7V1E=FUA:F]R(#T@)R<[
M#0H-"B`@("`@("`@)'9?9&5V;6EN;W(@/2`G)SL-"@T*("`@("`@("`D=E]P
M<F5F:7@@/2`G)SL-"@T*("`@("`@("`D=E]B:6YA<GE?9&%T85]F:7)S="`]
M('!A8VLH(F$Q,#!A.&$X83AA,3)!,3(B+`T*"0D@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9?<F5D=6-E7V9I;&5N86UE+"`D=E]P97)M<RP@)'9?
M=6ED+`T*"0D)"0D)"0D))'9?9VED+"`D=E]S:7IE+"`D=E]M=&EM92D[#0H@
M("`@("`@("1V7V)I;F%R>5]D871A7VQA<W0@/2!P86-K*")A,6$Q,#!A-F$R
M83,R83,R83AA.&$Q-35A,3(B+`T*"0D@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=E]T>7!E9FQA9RP@)'9?;&EN:VYA;64L("1V7VUA9VEC+`T*"0D)
M"0D)"0D@("`D=E]V97)S:6]N+"`D=E]U;F%M92P@)'9?9VYA;64L#0H)"0D)
M"0D)"2`@("1V7V1E=FUA:F]R+"`D=E]D979M:6YO<BP@)'9?<')E9FEX+"`G
M)RD[#0H-"B`@("`@("`@+R\@+2TM+2T@0V%L8W5L871E('1H92!C:&5C:W-U
M;0T*("`@("`@("`D=E]C:&5C:W-U;2`](#`[#0H@("`@("`@("\O("XN+BXN
M($9I<G-T('!A<G0@;V8@=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I/3`[
M("1I/#$T.#L@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R
M9"AS=6)S='(H)'9?8FEN87)Y7V1A=&%?9FER<W0L)&DL,2DI.PT*("`@("`@
M("`O+R`N+BXN+B!)9VYO<F4@=&AE(&-H96-K<W5M('9A;'5E(&%N9"!R97!L
M86-E(&ET(&)Y("<@)R`H<W!A8V4I#0H@("`@("`@(&9O<B`H)&D],30X.R`D
M:3PQ-38[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H
M)R`G*3L-"B`@("`@("`@+R\@+BXN+BX@3&%S="!P87)T(&]F('1H92!H96%D
M97(-"B`@("`@("`@9F]R("@D:3TQ-38L("1J/3`[("1I/#4Q,CL@)&DK*RP@
M)&HK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R9"AS=6)S='(H
M)'9?8FEN87)Y7V1A=&%?;&%S="PD:BPQ*2D[#0H-"B`@("`@("`@+R\@+2TM
M+2T@5W)I=&4@=&AE(&9I<G-T(#$T."!B>71E<R!O9B!T:&4@:&5A9&5R(&EN
M('1H92!A<F-H:79E#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B
M:6YA<GE?9&%T85]F:7)S="P@,30X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7
M<FET92!T:&4@8V%L8W5L871E9"!C:&5C:W-U;0T*("`@("`@("`D=E]C:&5C
M:W-U;2`]('-P<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?8VAE8VMS=6TI*3L-
M"B`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A."(L("1V7V-H96-K
M<W5M*3L-"B`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D
M871A+"`X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@;&%S="`S
M-38@8GET97,@;V8@=&AE(&AE861E<B!I;B!T:&4@87)C:&EV90T*("`@("`@
M("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?;&%S="P@,S4V
M*3L-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]
M#0H-"B`@("`O+R![>WL@7W=R:71E2&5A9&5R0FQO8VLH*0T*("`@(&9U;F-T
M:6]N(%]W<FET94AE861E<D)L;V-K*"1P7V9I;&5N86UE+"`D<%]S:7IE+"`D
M<%]M=&EM93TP+"`D<%]P97)M<STP+`T*"2`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P7W1Y<&4])R<L("1P7W5I9#TP+"`D<%]G:60],"D-"B`@("![
M#0H@("`@("`@("1P7V9I;&5N86UE(#T@)'1H:7,M/E]P871H4F5D=6-T:6]N
M*"1P7V9I;&5N86UE*3L-"@T*("`@("`@("!I9B`H<W1R;&5N*"1P7V9I;&5N
M86UE*2`^(#DY*2![#0H@("`@("`@("`@:68@*"$D=&AI<RT^7W=R:71E3&]N
M9TAE861E<B@D<%]F:6QE;F%M92DI#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)'!?='EP92`]/2`B-2(I
M('L-"B`@("`@("`@("`D=E]S:7IE(#T@<W!R:6YT9B@B)3$Q<R`B+"!$96-/
M8W0H,"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("1V7W-I>F4@
M/2!S<')I;G1F*"(E,3%S("(L($1E8T]C="@D<%]S:7IE*2D[#0H@("`@("`@
M('T-"@T*("`@("`@("`D=E]U:60@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T
M*"1P7W5I9"DI.PT*("`@("`@("`D=E]G:60@/2!S<')I;G1F*"(E-G,@(BP@
M1&5C3V-T*"1P7V=I9"DI.PT*("`@("`@("`D=E]P97)M<R`]('-P<FEN=&8H
M(B4V<R`B+"!$96-/8W0H)'!?<&5R;7,I*3L-"@T*("`@("`@("`D=E]M=&EM
M92`]('-P<FEN=&8H(B4Q,7,B+"!$96-/8W0H)'!?;71I;64I*3L-"@T*("`@
M("`@("`D=E]L:6YK;F%M92`]("<G.PT*#0H@("`@("`@("1V7VUA9VEC(#T@
M)R<[#0H-"B`@("`@("`@)'9?=F5R<VEO;B`]("<G.PT*#0H@("`@("`@("1V
M7W5N86UE(#T@)R<[#0H-"B`@("`@("`@)'9?9VYA;64@/2`G)SL-"@T*("`@
M("`@("`D=E]D979M86IO<B`]("<G.PT*#0H@("`@("`@("1V7V1E=FUI;F]R
M(#T@)R<[#0H-"B`@("`@("`@)'9?<')E9FEX(#T@)R<[#0H-"B`@("`@("`@
M)'9?8FEN87)Y7V1A=&%?9FER<W0@/2!P86-K*")A,3`P83AA.&$X83$R03$R
M(BP-"@D)("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P7V9I;&5N86UE
M+"`D=E]P97)M<RP@)'9?=6ED+"`D=E]G:60L#0H)"0D)"0D)"0DD=E]S:7IE
M+"`D=E]M=&EM92D[#0H@("`@("`@("1V7V)I;F%R>5]D871A7VQA<W0@/2!P
M86-K*")A,6$Q,#!A-F$R83,R83,R83AA.&$Q-35A,3(B+`T*"0D@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<%]T>7!E+"`D=E]L:6YK;F%M92P@)'9?
M;6%G:6,L#0H)"0D)"0D)"2`@("1V7W9E<G-I;VXL("1V7W5N86UE+"`D=E]G
M;F%M92P-"@D)"0D)"0D)("`@)'9?9&5V;6%J;W(L("1V7V1E=FUI;F]R+"`D
M=E]P<F5F:7@L("<G*3L-"@T*("`@("`@("`O+R`M+2TM+2!#86QC=6QA=&4@
M=&AE(&-H96-K<W5M#0H@("`@("`@("1V7V-H96-K<W5M(#T@,#L-"B`@("`@
M("`@+R\@+BXN+BX@1FER<W0@<&%R="!O9B!T:&4@:&5A9&5R#0H@("`@("`@
M(&9O<B`H)&D],#L@)&D\,30X.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE
M8VMS=6T@*ST@;W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]F:7)S="PD:2PQ
M*2D[#0H@("`@("`@("\O("XN+BXN($EG;F]R92!T:&4@8VAE8VMS=6T@=F%L
M=64@86YD(')E<&QA8V4@:70@8GD@)R`G("AS<&%C92D-"B`@("`@("`@9F]R
M("@D:3TQ-#@[("1I/#$U-CL@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K
M<W5M("L](&]R9"@G("<I.PT*("`@("`@("`O+R`N+BXN+B!,87-T('!A<G0@
M;V8@=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I/3$U-BP@)&H],#L@)&D\
M-3$R.R`D:2LK+"`D:BLK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@*ST@
M;W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]L87-T+"1J+#$I*3L-"@T*("`@
M("`@("`O+R`M+2TM+2!7<FET92!T:&4@9FER<W0@,30X(&)Y=&5S(&]F('1H
M92!H96%D97(@:6X@=&AE(&%R8VAI=F4-"B`@("`@("`@)'1H:7,M/E]W<FET
M94)L;V-K*"1V7V)I;F%R>5]D871A7V9I<G-T+"`Q-#@I.PT*#0H@("`@("`@
M("\O("TM+2TM(%=R:71E('1H92!C86QC=6QA=&5D(&-H96-K<W5M#0H@("`@
M("`@("1V7V-H96-K<W5M(#T@<W!R:6YT9B@B)39S("(L($1E8T]C="@D=E]C
M:&5C:W-U;2DI.PT*("`@("`@("`D=E]B:6YA<GE?9&%T82`]('!A8VLH(F$X
M(BP@)'9?8VAE8VMS=6TI.PT*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH
M)'9?8FEN87)Y7V1A=&$L(#@I.PT*#0H@("`@("`@("\O("TM+2TM(%=R:71E
M('1H92!L87-T(#,U-B!B>71E<R!O9B!T:&4@:&5A9&5R(&EN('1H92!A<F-H
M:79E#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T
M85]L87-T+"`S-38I.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?=W)I=&5,;VYG2&5A9&5R*"D-
M"B`@("!F=6YC=&EO;B!?=W)I=&5,;VYG2&5A9&5R*"1P7V9I;&5N86UE*0T*
M("`@('L-"B`@("`@("`@)'9?<VEZ92`]('-P<FEN=&8H(B4Q,7,@(BP@1&5C
M3V-T*'-T<FQE;B@D<%]F:6QE;F%M92DI*3L-"@T*("`@("`@("`D=E]T>7!E
M9FQA9R`]("=,)SL-"@T*("`@("`@("`D=E]L:6YK;F%M92`]("<G.PT*#0H@
M("`@("`@("1V7VUA9VEC(#T@)R<[#0H-"B`@("`@("`@)'9?=F5R<VEO;B`]
M("<G.PT*#0H@("`@("`@("1V7W5N86UE(#T@)R<[#0H-"B`@("`@("`@)'9?
M9VYA;64@/2`G)SL-"@T*("`@("`@("`D=E]D979M86IO<B`]("<G.PT*#0H@
M("`@("`@("1V7V1E=FUI;F]R(#T@)R<[#0H-"B`@("`@("`@)'9?<')E9FEX
M(#T@)R<[#0H-"B`@("`@("`@)'9?8FEN87)Y7V1A=&%?9FER<W0@/2!P86-K
M*")A,3`P83AA.&$X83$R03$R(BP-"@D)("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<N+RXO0$QO;F=,:6YK)RP@,"P@,"P@,"P@)'9?<VEZ92P@,"D[
M#0H@("`@("`@("1V7V)I;F%R>5]D871A7VQA<W0@/2!P86-K*")A,6$Q,#!A
M-F$R83,R83,R83AA.&$Q-35A,3(B+`T*"0D@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=E]T>7!E9FQA9RP@)'9?;&EN:VYA;64L("1V7VUA9VEC+`T*
M"0D)"0D)"0D@("`D=E]V97)S:6]N+"`D=E]U;F%M92P@)'9?9VYA;64L#0H)
M"0D)"0D)"2`@("1V7V1E=FUA:F]R+"`D=E]D979M:6YO<BP@)'9?<')E9FEX
M+"`G)RD[#0H-"B`@("`@("`@+R\@+2TM+2T@0V%L8W5L871E('1H92!C:&5C
M:W-U;0T*("`@("`@("`D=E]C:&5C:W-U;2`](#`[#0H@("`@("`@("\O("XN
M+BXN($9I<G-T('!A<G0@;V8@=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I
M/3`[("1I/#$T.#L@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L]
M(&]R9"AS=6)S='(H)'9?8FEN87)Y7V1A=&%?9FER<W0L)&DL,2DI.PT*("`@
M("`@("`O+R`N+BXN+B!)9VYO<F4@=&AE(&-H96-K<W5M('9A;'5E(&%N9"!R
M97!L86-E(&ET(&)Y("<@)R`H<W!A8V4I#0H@("`@("`@(&9O<B`H)&D],30X
M.R`D:3PQ-38[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O
M<F0H)R`G*3L-"B`@("`@("`@+R\@+BXN+BX@3&%S="!P87)T(&]F('1H92!H
M96%D97(-"B`@("`@("`@9F]R("@D:3TQ-38L("1J/3`[("1I/#4Q,CL@)&DK
M*RP@)&HK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R9"AS=6)S
M='(H)'9?8FEN87)Y7V1A=&%?;&%S="PD:BPQ*2D[#0H-"B`@("`@("`@+R\@
M+2TM+2T@5W)I=&4@=&AE(&9I<G-T(#$T."!B>71E<R!O9B!T:&4@:&5A9&5R
M(&EN('1H92!A<F-H:79E#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D
M=E]B:6YA<GE?9&%T85]F:7)S="P@,30X*3L-"@T*("`@("`@("`O+R`M+2TM
M+2!7<FET92!T:&4@8V%L8W5L871E9"!C:&5C:W-U;0T*("`@("`@("`D=E]C
M:&5C:W-U;2`]('-P<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?8VAE8VMS=6TI
M*3L-"B`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A."(L("1V7V-H
M96-K<W5M*3L-"B`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R
M>5]D871A+"`X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@;&%S
M="`S-38@8GET97,@;V8@=&AE(&AE861E<B!I;B!T:&4@87)C:&EV90T*("`@
M("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?;&%S="P@
M,S4V*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@9FEL96YA;64@
M87,@8V]N=&5N="!O9B!T:&4@8FQO8VL-"B`@("`@("`@)&D],#L-"B`@("`@
M("`@=VAI;&4@*"@D=E]B=69F97(@/2!S=6)S='(H)'!?9FEL96YA;64L("@H
M)&DK*RDJ-3$R*2P@-3$R*2D@(3T@)R<I('L-"B`@("`@("`@("`@("1V7V)I
M;F%R>5]D871A(#T@<&%C:R@B834Q,B(L("(D=E]B=69F97(B*3L-"B`@("`@
M("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T82D[#0H@
M("`@("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@7W)E861(96%D97(H*0T*("`@(&9U;F-T
M:6]N(%]R96%D2&5A9&5R*"1V7V)I;F%R>5]D871A+"`F)'9?:&5A9&5R*0T*
M("`@('L-"B`@("`@("`@:68@*'-T<FQE;B@D=E]B:6YA<GE?9&%T82D]/3`I
M('L-"B`@("`@("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]("<G.PT*
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"@T*("`@("`@
M("!I9B`H<W1R;&5N*"1V7V)I;F%R>5]D871A*2`A/2`U,3(I('L-"B`@("`@
M("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]("<G.PT*("`@("`@("`@
M("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!B;&]C:R!S:7IE(#H@)RYS=')L
M96XH)'9?8FEN87)Y7V1A=&$I*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*#0H@("`@("`@("\O("TM+2TM($-A;&-U;&%T92!T
M:&4@8VAE8VMS=6T-"B`@("`@("`@)'9?8VAE8VMS=6T@/2`P.PT*("`@("`@
M("`O+R`N+BXN+B!&:7)S="!P87)T(&]F('1H92!H96%D97(-"B`@("`@("`@
M9F]R("@D:3TP.R`D:3PQ-#@[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C
M:W-U;2L];W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T82PD:2PQ*2D[#0H@("`@
M("`@("\O("XN+BXN($EG;F]R92!T:&4@8VAE8VMS=6T@=F%L=64@86YD(')E
M<&QA8V4@:70@8GD@)R`G("AS<&%C92D-"B`@("`@("`@9F]R("@D:3TQ-#@[
M("1I/#$U-CL@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R
M9"@G("<I.PT*("`@("`@("`O+R`N+BXN+B!,87-T('!A<G0@;V8@=&AE(&AE
M861E<@T*("`@("`@("!F;W(@*"1I/3$U-CL@)&D\-3$R.R`D:2LK*0T*("`@
M("`@("`@("`D=E]C:&5C:W-U;2L];W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T
M82PD:2PQ*2D[#0H-"B`@("`@("`@)'9?9&%T82`]('5N<&%C:R@B83$P,&9I
M;&5N86UE+V$X;6]D92]A.'5I9"]A.&=I9"]A,3)S:7IE+V$Q,FUT:6UE+R(-
M"@D)("`@("`@("`@("`@("`@("`N(F$X8VAE8VMS=6TO83%T>7!E9FQA9R]A
M,3`P;&EN:R]A-FUA9VEC+V$R=F5R<VEO;B\B#0H)"0D)"0D@+B)A,S)U;F%M
M92]A,S)G;F%M92]A.&1E=FUA:F]R+V$X9&5V;6EN;W(B+`T*"0D)"0D)("1V
M7V)I;F%R>5]D871A*3L-"@T*("`@("`@("`O+R`M+2TM+2!%>'1R86-T('1H
M92!C:&5C:W-U;0T*("`@("`@("`D=E]H96%D97);)V-H96-K<W5M)UT@/2!/
M8W1$96,H=')I;2@D=E]D871A6R=C:&5C:W-U;2==*2D[#0H@("`@("`@(&EF
M("@D=E]H96%D97);)V-H96-K<W5M)UT@(3T@)'9?8VAE8VMS=6TI('L-"B`@
M("`@("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]("<G.PT*#0H@("`@
M("`@("`@("`O+R`M+2TM+2!,;V]K(&9O<B!L87-T(&)L;V-K("AE;7!T>2!B
M;&]C:RD-"B`@("`@("`@("`@(&EF("@H)'9?8VAE8VMS=6T@/3T@,C4V*2`F
M)B`H)'9?:&5A9&5R6R=C:&5C:W-U;2==(#T](#`I*0T*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R
M*"=);G9A;&ED(&-H96-K<W5M(&9O<B!F:6QE("(G+B1V7V1A=&%;)V9I;&5N
M86UE)UT-"@D)"2`@("`@("`@("`@("`@+B<B(#H@)RXD=E]C:&5C:W-U;2XG
M(&-A;&-U;&%T960L("<-"@D)"0D)"2`@+B1V7VAE861E<ELG8VAE8VMS=6TG
M72XG(&5X<&5C=&5D)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"@T*("`@("`@("`O+R`M+2TM+2!%>'1R86-T('1H92!P<F]P
M97)T:65S#0H@("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]('1R:6TH
M)'9?9&%T85LG9FEL96YA;64G72D[#0H@("`@("`@("1V7VAE861E<ELG;6]D
M92==(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG;6]D92==*2D[#0H@("`@("`@
M("1V7VAE861E<ELG=6ED)UT@/2!/8W1$96,H=')I;2@D=E]D871A6R=U:60G
M72DI.PT*("`@("`@("`D=E]H96%D97);)V=I9"==(#T@3V-T1&5C*'1R:6TH
M)'9?9&%T85LG9VED)UTI*3L-"B`@("`@("`@)'9?:&5A9&5R6R=S:7IE)UT@
M/2!/8W1$96,H=')I;2@D=E]D871A6R=S:7IE)UTI*3L-"B`@("`@("`@)'9?
M:&5A9&5R6R=M=&EM92==(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG;71I;64G
M72DI.PT*("`@("`@("!I9B`H*"1V7VAE861E<ELG='EP969L86<G72`]("1V
M7V1A=&%;)W1Y<&5F;&%G)UTI(#T]("(U(BD@>PT*("`@("`@("`@("1V7VAE
M861E<ELG<VEZ92==(#T@,#L-"B`@("`@("`@?0T*("`@("`@("`O*B`M+2TM
M+2!!;&P@=&AE<V4@9FEE;&1S(&%R92!R96UO=F5D(&9O<FT@=&AE(&AE861E
M<B!B96-A=7-E#0H)"71H97D@9&\@;F]T(&-A<G)Y(&EN=&5R97-T:6YG(&EN
M9F\-"B`@("`@("`@)'9?:&5A9&5R6VQI;FM=(#T@=')I;2@D=E]D871A6VQI
M;FM=*3L-"B`@("`@("`@)'9?:&5A9&5R6VUA9VEC72`]('1R:6TH)'9?9&%T
M85MM86=I8UTI.PT*("`@("`@("`D=E]H96%D97);=F5R<VEO;ET@/2!T<FEM
M*"1V7V1A=&%;=F5R<VEO;ETI.PT*("`@("`@("`D=E]H96%D97);=6YA;65=
M(#T@=')I;2@D=E]D871A6W5N86UE72D[#0H@("`@("`@("1V7VAE861E<EMG
M;F%M95T@/2!T<FEM*"1V7V1A=&%;9VYA;65=*3L-"B`@("`@("`@)'9?:&5A
M9&5R6V1E=FUA:F]R72`]('1R:6TH)'9?9&%T85MD979M86IO<ETI.PT*("`@
M("`@("`D=E]H96%D97);9&5V;6EN;W)=(#T@=')I;2@D=E]D871A6V1E=FUI
M;F]R72D[#0H@("`@("`@("HO#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]R96%D3&]N9TAE861E
M<B@I#0H@("`@9G5N8W1I;VX@7W)E861,;VYG2&5A9&5R*"8D=E]H96%D97(I
M#0H@("`@>PT*("`@("`@)'9?9FEL96YA;64@/2`G)SL-"B`@("`@("1N(#T@
M9FQO;W(H)'9?:&5A9&5R6R=S:7IE)UTO-3$R*3L-"B`@("`@(&9O<B`H)&D]
M,#L@)&D\)&X[("1I*RLI('L-"B`@("`@("`@)'9?8V]N=&5N="`]("1T:&ES
M+3Y?<F5A9$)L;V-K*"D[#0H@("`@("`@("1V7V9I;&5N86UE("X]("1V7V-O
M;G1E;G0[#0H@("`@("!]#0H@("`@("!I9B`H*"1V7VAE861E<ELG<VEZ92==
M("4@-3$R*2`A/2`P*2![#0H@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^
M7W)E861";&]C:R@I.PT*("`@("`@("`D=E]F:6QE;F%M92`N/2`D=E]C;VYT
M96YT.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM+2!296%D('1H92!N97AT
M(&AE861E<@T*("`@("`@)'9?8FEN87)Y7V1A=&$@/2`D=&AI<RT^7W)E861"
M;&]C:R@I.PT*#0H@("`@("!I9B`H(21T:&ES+3Y?<F5A9$AE861E<B@D=E]B
M:6YA<GE?9&%T82P@)'9?:&5A9&5R*2D-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*#0H@("`@("`D=E]H96%D97);)V9I;&5N86UE)UT@/2`D=E]F:6QE;F%M
M93L-"@T*("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(%]E>'1R86-T26Y3=')I;F<H*0T*("`@("\J*@T*("`@
M("H@5&AI<R!M971H;V0@97AT<F%C="!F<F]M('1H92!A<F-H:79E(&]N92!F
M:6QE(&ED96YT:69I960@8GD@)'!?9FEL96YA;64N#0H@("`@*B!4:&4@<F5T
M=7)N('9A;'5E(&ES(&$@<W1R:6YG('=I=&@@=&AE(&9I;&4@8V]N=&5N="P@
M;W(@3E5,3"!O;B!E<G)O<BX-"B`@("`J($!P87)A;2!S=')I;F<@)'!?9FEL
M96YA;64@("`@(%1H92!P871H(&]F('1H92!F:6QE('1O(&5X=')A8W0@:6X@
M82!S=')I;F<N#0H@("`@*B!`<F5T=7)N("`@("`@("`@("`@("`@("`@("`@
M("!A('-T<FEN9R!W:71H('1H92!F:6QE(&-O;G1E;G0@;W(@3E5,3"X-"B`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@7V5X
M=')A8W1);E-T<FEN9R@D<%]F:6QE;F%M92D-"B`@("![#0H@("`@("`@("1V
M7W)E<W5L=%]S='(@/2`B(CL-"@T*("`@("`@("!7:&EL92`H<W1R;&5N*"1V
M7V)I;F%R>5]D871A(#T@)'1H:7,M/E]R96%D0FQO8VLH*2D@(3T@,"D-"B`@
M("`@("`@>PT*("`@("`@("`@(&EF("@A)'1H:7,M/E]R96%D2&5A9&5R*"1V
M7V)I;F%R>5]D871A+"`D=E]H96%D97(I*0T*("`@("`@("`@("`@<F5T=7)N
M($Y53$P[#0H-"B`@("`@("`@("!I9B`H)'9?:&5A9&5R6R=F:6QE;F%M92==
M(#T]("<G*0T*("`@("`@("`@("`@8V]N=&EN=64[#0H-"B`@("`@("`@("`O
M+R`M+2TM+2!,;V]K(&9O<B!L;VYG(&9I;&5N86UE#0H@("`@("`@("`@:68@
M*"1V7VAE861E<ELG='EP969L86<G72`]/2`G3"<I('L-"B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]R96%D3&]N9TAE861E<B@D=E]H96%D97(I*0T*("`@
M("`@("`@("`@("!R971U<FX@3E5,3#L-"B`@("`@("`@("!]#0H-"B`@("`@
M("`@("!I9B`H)'9?:&5A9&5R6R=F:6QE;F%M92==(#T]("1P7V9I;&5N86UE
M*2![#0H@("`@("`@("`@("`@(&EF("@D=E]H96%D97);)W1Y<&5F;&%G)UT@
M/3T@(C4B*2![#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5
M;F%B;&4@=&\@97AT<F%C="!I;B!S=')I;F<@82!D:7)E8W1O<GD@)PT*"0D)
M"2`@("`@("`@("`@("`@("`N)V5N=')Y('LG+B1V7VAE861E<ELG9FEL96YA
M;64G72XG?2<I.PT*("`@("`@("`@("`@("`@("`@<F5T=7)N($Y53$P[#0H@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`D;B`]
M(&9L;V]R*"1V7VAE861E<ELG<VEZ92==+S4Q,BD[#0H@("`@("`@("`@("`@
M("`@("!F;W(@*"1I/3`[("1I/"1N.R`D:2LK*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@)'9?<F5S=6QT7W-T<B`N/2`D=&AI<RT^7W)E861";&]C:R@I
M.PT*("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@:68@
M*"@D=E]H96%D97);)W-I>F4G72`E(#4Q,BD@(3T@,"D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("1V7W)E<W5L=%]S='(@+CT@<W5B
M<W1R*"1V7V-O;G1E;G0L(#`L#0H)"0D)"2`@("`@("`@("`@("`@("`@("`@
M("`@("`@*"1V7VAE861E<ELG<VEZ92==("4@-3$R*2D[#0H@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("!R971U<FX@)'9?<F5S=6QT
M7W-T<CL-"B`@("`@("`@("`@("`@?0T*("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("1T:&ES+3Y?:G5M<$)L;V-K*&-E:6PH*"1V7VAE861E
M<ELG<VEZ92==+S4Q,BDI*3L-"B`@("`@("`@("!]#0H@("`@("`@('T-"@T*
M("`@("`@("!R971U<FX@3E5,3#L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@7V5X=')A8W1,:7-T*"D-"B`@("!F=6YC=&EO;B!?97AT<F%C
M=$QI<W0H)'!?<&%T:"P@)B1P7VQI<W1?9&5T86EL+"`D<%]M;V1E+`T*"2`@
M("`@("`@("`@("`@("`@("`@("`D<%]F:6QE7VQI<W0L("1P7W)E;6]V95]P
M871H*0T*("`@('L-"B`@("`D=E]R97-U;'0]=')U93L-"B`@("`D=E]N8B`]
M(#`[#0H@("`@)'9?97AT<F%C=%]A;&P@/2!T<G5E.PT*("`@("1V7VQI<W1I
M;F<@/2!F86QS93L-"@T*("`@("1P7W!A=&@@/2`D=&AI<RT^7W1R86YS;&%T
M95=I;E!A=&@H)'!?<&%T:"P@9F%L<V4I.PT*("`@(&EF("@D<%]P871H(#T]
M("<G('Q\("AS=6)S='(H)'!?<&%T:"P@,"P@,2D@(3T@)R\G#0H)("`@("8F
M('-U8G-T<B@D<%]P871H+"`P+"`S*2`A/2`B+BXO(B`F)B`A<W1R<&]S*"1P
M7W!A=&@L("<Z)RDI*2![#0H@("`@("`D<%]P871H(#T@(BXO(BXD<%]P871H
M.PT*("`@('T-"B`@("`D<%]R96UO=F5?<&%T:"`]("1T:&ES+3Y?=')A;G-L
M871E5VEN4&%T:"@D<%]R96UO=F5?<&%T:"D[#0H-"B`@("`O+R`M+2TM+2!,
M;V]K(&9O<B!P871H('1O(')E;6]V92!F;W)M870@*'-H;W5L9"!E;F0@8GD@
M+RD-"B`@("!I9B`H*"1P7W)E;6]V95]P871H("$]("<G*2`F)B`H<W5B<W1R
M*"1P7W)E;6]V95]P871H+"`M,2D@(3T@)R\G*2D-"B`@("`@("1P7W)E;6]V
M95]P871H("X]("<O)SL-"B`@("`D<%]R96UO=F5?<&%T:%]S:7IE(#T@<W1R
M;&5N*"1P7W)E;6]V95]P871H*3L-"@T*("`@('-W:71C:"`H)'!?;6]D92D@
M>PT*("`@("`@8V%S92`B8V]M<&QE=&4B(#H-"B`@("`@("`@)'9?97AT<F%C
M=%]A;&P@/2!44E5%.PT*("`@("`@("`D=E]L:7-T:6YG(#T@1D%,4T4[#0H@
M("`@("!B<F5A:SL-"B`@("`@(&-A<V4@(G!A<G1I86PB(#H-"B`@("`@("`@
M("`D=E]E>'1R86-T7V%L;"`]($9!3%-%.PT*("`@("`@("`@("1V7VQI<W1I
M;F<@/2!&04Q313L-"B`@("`@(&)R96%K.PT*("`@("`@8V%S92`B;&ES="(@
M.@T*("`@("`@("`@("1V7V5X=')A8W1?86QL(#T@1D%,4T4[#0H@("`@("`@
M("`@)'9?;&ES=&EN9R`](%12544[#0H@("`@("!B<F5A:SL-"B`@("`@(&1E
M9F%U;'0@.@T*("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&5X=')A
M8W0@;6]D92`H)RXD<%]M;V1E+B<I)RD[#0H@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("!]#0H-"B`@("!C;&5A<G-T871C86-H92@I.PT*#0H@("`@=VAI
M;&4@*'-T<FQE;B@D=E]B:6YA<GE?9&%T82`]("1T:&ES+3Y?<F5A9$)L;V-K
M*"DI("$](#`I#0H@("`@>PT*("`@("`@)'9?97AT<F%C=%]F:6QE(#T@1D%,
M4T4[#0H@("`@("`D=E]E>'1R86-T:6]N7W-T;W!P960@/2`P.PT*#0H@("`@
M("!I9B`H(21T:&ES+3Y?<F5A9$AE861E<B@D=E]B:6YA<GE?9&%T82P@)'9?
M:&5A9&5R*2D-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("!I9B`H
M)'9?:&5A9&5R6R=F:6QE;F%M92==(#T]("<G*2![#0H@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM+2!,;V]K(&9O<B!L;VYG
M(&9I;&5N86UE#0H@("`@("!I9B`H)'9?:&5A9&5R6R=T>7!E9FQA9R==(#T]
M("=,)RD@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?<F5A9$QO;F=(96%D97(H
M)'9?:&5A9&5R*2D-"B`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("!]
M#0H-"B`@("`@(&EF("@H(21V7V5X=')A8W1?86QL*2`F)B`H:7-?87)R87DH
M)'!?9FEL95]L:7-T*2DI('L-"B`@("`@("`@+R\@+2TM+2T@0GD@9&5F875L
M="!N;R!U;GII<"!I9B!T:&4@9FEL92!I<R!N;W0@9F]U;F0-"B`@("`@("`@
M)'9?97AT<F%C=%]F:6QE(#T@9F%L<V4[#0H-"B`@("`@("`@9F]R("@D:3TP
M.R`D:3QS:7IE;V8H)'!?9FEL95]L:7-T*3L@)&DK*RD@>PT*("`@("`@("`@
M("\O("TM+2TM($QO;VL@:68@:70@:7,@82!D:7)E8W1O<GD-"B`@("`@("`@
M("!I9B`H<W5B<W1R*"1P7V9I;&5?;&ES=%LD:5TL("TQ*2`]/2`G+R<I('L-
M"B`@("`@("`@("`@("\O("TM+2TM($QO;VL@:68@=&AE(&1I<F5C=&]R>2!I
M<R!I;B!T:&4@9FEL96YA;64@<&%T:`T*("`@("`@("`@("`@:68@*"AS=')L
M96XH)'9?:&5A9&5R6R=F:6QE;F%M92==*2`^('-T<FQE;B@D<%]F:6QE7VQI
M<W1;)&E=*2D-"@D)"2`@("`F)B`H<W5B<W1R*"1V7VAE861E<ELG9FEL96YA
M;64G72P@,"P@<W1R;&5N*"1P7V9I;&5?;&ES=%LD:5TI*0T*"0D)"2`@("`]
M/2`D<%]F:6QE7VQI<W1;)&E=*2D@>PT*("`@("`@("`@("`@("`D=E]E>'1R
M86-T7V9I;&4@/2!44E5%.PT*("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("!]#0H-"B`@("`@("`@("`O+R`M+2TM+2!)
M="!I<R!A(&9I;&4L('-O(&-O;7!A<F4@=&AE(&9I;&4@;F%M97,-"B`@("`@
M("`@("!E;'-E:68@*"1P7V9I;&5?;&ES=%LD:5T@/3T@)'9?:&5A9&5R6R=F
M:6QE;F%M92==*2![#0H@("`@("`@("`@("`D=E]E>'1R86-T7V9I;&4@/2!4
M4E5%.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("!](&5L<V4@>PT*("`@("`@("`D=E]E>'1R86-T7V9I;&4@
M/2!44E5%.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM+2!,;V]K(&EF('1H
M:7,@9FEL92!N965D('1O(&)E(&5X=')A8W1E9`T*("`@("`@:68@*"@D=E]E
M>'1R86-T7V9I;&4I("8F("@A)'9?;&ES=&EN9RDI#0H@("`@("![#0H@("`@
M("`@(&EF("@H)'!?<F5M;W9E7W!A=&@@(3T@)R<I#0H@("`@("`@("`@("`F
M)B`H<W5B<W1R*"1V7VAE861E<ELG9FEL96YA;64G72P@,"P@)'!?<F5M;W9E
M7W!A=&A?<VEZ92D-"@D)"2`@("`]/2`D<%]R96UO=F5?<&%T:"DI#0H@("`@
M("`@("`@)'9?:&5A9&5R6R=F:6QE;F%M92==(#T@<W5B<W1R*"1V7VAE861E
M<ELG9FEL96YA;64G72P-"@D)("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!?<F5M;W9E7W!A=&A?<VEZ92D[#0H@("`@("`@(&EF("@H)'!?
M<&%T:"`A/2`G+B\G*2`F)B`H)'!?<&%T:"`A/2`G+R<I*2![#0H@("`@("`@
M("`@=VAI;&4@*'-U8G-T<B@D<%]P871H+"`M,2D@/3T@)R\G*0T*("`@("`@
M("`@("`@)'!?<&%T:"`]('-U8G-T<B@D<%]P871H+"`P+"!S=')L96XH)'!?
M<&%T:"DM,2D[#0H-"B`@("`@("`@("!I9B`H<W5B<W1R*"1V7VAE861E<ELG
M9FEL96YA;64G72P@,"P@,2D@/3T@)R\G*0T*("`@("`@("`@("`@("`D=E]H
M96%D97);)V9I;&5N86UE)UT@/2`D<%]P871H+B1V7VAE861E<ELG9FEL96YA
M;64G73L-"B`@("`@("`@("!E;'-E#0H@("`@("`@("`@("`D=E]H96%D97);
M)V9I;&5N86UE)UT@/2`D<%]P871H+B<O)RXD=E]H96%D97);)V9I;&5N86UE
M)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1V7VAE
M861E<ELG9FEL96YA;64G72DI('L-"B`@("`@("`@("!I9B`H("`@*$!I<U]D
M:7(H)'9?:&5A9&5R6R=F:6QE;F%M92==*2D-"@D)("`@("`@)B8@*"1V7VAE
M861E<ELG='EP969L86<G72`]/2`G)RDI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?97)R;W(H)T9I;&4@)RXD=E]H96%D97);)V9I;&5N86UE)UT-"@D)"2`@
M("`@("`@("`@("`@+B<@86QR96%D>2!E>&ES=',@87,@82!D:7)E8W1O<GDG
M*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("!]#0H@
M("`@("`@("`@:68@*"`@("@D=&AI<RT^7VES07)C:&EV92@D=E]H96%D97);
M)V9I;&5N86UE)UTI*0T*"0D@("`@("`F)B`H)'9?:&5A9&5R6R=T>7!E9FQA
M9R==(#T]("(U(BDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T1I
M<F5C=&]R>2`G+B1V7VAE861E<ELG9FEL96YA;64G70T*"0D)("`@("`@("`@
M("`@("`N)R!A;')E861Y(&5X:7-T<R!A<R!A(&9I;&4G*3L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("!]#0H@("`@("`@("`@:68@
M*"%I<U]W<FET96%B;&4H)'9?:&5A9&5R6R=F:6QE;F%M92==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]E<G)O<B@G1FEL92`G+B1V7VAE861E<ELG9FEL
M96YA;64G70T*"0D)("`@("`@("`@("`@("`N)R!A;')E861Y(&5X:7-T<R!A
M;F0@:7,@=W)I=&4@<')O=&5C=&5D)RD[#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@("`@?0T*("`@("`@("`@(&EF("AF:6QE;71I;64H
M)'9?:&5A9&5R6R=F:6QE;F%M92==*2`^("1V7VAE861E<ELG;71I;64G72D@
M>PT*("`@("`@("`@("`@+R\@5&\@8F4@8V]M<&QE=&5D(#H@06X@97)R;W(@
M;W(@<VEL96YT(&YO(')E<&QA8V4@/PT*("`@("`@("`@('T-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O("TM+2TM($-H96-K('1H92!D:7)E8W1O<GD@879A
M:6QA8FEL:71Y(&%N9"!C<F5A=&4@:70@:68@;F5C97-S87)Y#0H@("`@("`@
M(&5L<V5I9B`H*"1V7W)E<W5L=`T*"0D@("`@("`@("`]("1T:&ES+3Y?9&ER
M0VAE8VLH*"1V7VAE861E<ELG='EP969L86<G72`]/2`B-2(-"@D)"0D@("`@
M("`@("`@("`@("`@("`@(#\D=E]H96%D97);)V9I;&5N86UE)UT-"@D)"0D)
M"0D)"3ID:7)N86UE*"1V7VAE861E<ELG9FEL96YA;64G72DI*2D@(3T@,2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&-R96%T
M92!P871H(&9O<B`G+B1V7VAE861E<ELG9FEL96YA;64G72D[#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H
M)'9?97AT<F%C=%]F:6QE*2![#0H@("`@("`@("`@:68@*"1V7VAE861E<ELG
M='EP969L86<G72`]/2`B-2(I('L-"B`@("`@("`@("`@(&EF("@A0&9I;&5?
M97AI<W1S*"1V7VAE861E<ELG9FEL96YA;64G72DI('L-"B`@("`@("`@("`@
M("`@("!I9B`H(4!M:V1I<B@D=E]H96%D97);)V9I;&5N86UE)UTL(#`W-S<I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L
M92!T;R!C<F5A=&4@9&ER96-T;W)Y('LG#0H)"0D)"2`@("`@("`@("`@("`@
M+B1V7VAE861E<ELG9FEL96YA;64G72XG?2<I.PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@(&EF
M("@H)'9?9&5S=%]F:6QE(#T@0&9O<&5N*"1V7VAE861E<ELG9FEL96YA;64G
M72P@(G=B(BDI(#T](#`I('L-"B`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M97)R;W(H)T5R<F]R('=H:6QE(&]P96YI;F<@>R<N)'9?:&5A9&5R6R=F:6QE
M;F%M92==#0H)"0D)("`@("`@("`@("`@("`@("XG?2!I;B!W<FET92!B:6YA
M<GD@;6]D92<I.PT*("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@)&X@
M/2!F;&]O<B@D=E]H96%D97);)W-I>F4G72\U,3(I.PT*("`@("`@("`@("`@
M("`@("`@9F]R("@D:3TP.R`D:3PD;CL@)&DK*RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I.PT*
M("`@("`@("`@("`@("`@("`@("`@(&9W<FET92@D=E]D97-T7V9I;&4L("1V
M7V-O;G1E;G0L(#4Q,BD[#0H@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H*"1V7VAE861E<ELG<VEZ92==("4@-3$R*2`A/2`P*2![#0H@
M("`@("`@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I
M.PT*("`@("`@("`@("`@("!F=W)I=&4H)'9?9&5S=%]F:6QE+"`D=E]C;VYT
M96YT+"`H)'9?:&5A9&5R6R=S:7IE)UT@)2`U,3(I*3L-"B`@("`@("`@("`@
M('T-"@T*("`@("`@("`@("`@0&9C;&]S92@D=E]D97-T7V9I;&4I.PT*#0H@
M("`@("`@("`@("`O+R`M+2TM+2!#:&%N9V4@=&AE(&9I;&4@;6]D92P@;71I
M;64-"B`@("`@("`@("`@($!T;W5C:"@D=E]H96%D97);)V9I;&5N86UE)UTL
M("1V7VAE861E<ELG;71I;64G72D[#0H@("`@("`@("`@("`O+R!4;R!B92!C
M;VUP;&5T960-"B`@("`@("`@("`@("\O8VAM;V0H)'9?:&5A9&5R6V9I;&5N
M86UE72P@1&5C3V-T*"1V7VAE861E<EMM;V1E72DI.PT*("`@("`@("`@('T-
M"@T*("`@("`@("`@("\O("TM+2TM($-H96-K('1H92!F:6QE('-I>F4-"B`@
M("`@("`@("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("`@(&EF("AF:6QE
M<VEZ92@D=E]H96%D97);)V9I;&5N86UE)UTI("$]("1V7VAE861E<ELG<VEZ
M92==*2![#0H@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T5X=')A8W1E
M9"!F:6QE("<N)'9?:&5A9&5R6R=F:6QE;F%M92==#0H)"0D@("`@("`@("`@
M("`@("`@+B<@9&]E<R!N;W0@:&%V92!T:&4@8V]R<F5C="!F:6QE('-I>F4@
M7"<G#0H)"0D)"0D)+F9I;&5S:7IE*"1V7VAE861E<ELG9FEL96YA;64G72D-
M"@D)"0D)"0DN)UPG("@G+B1V7VAE861E<ELG<VEZ92==#0H)"0D)"0D)+B<@
M97AP96-T960I+B!!<F-H:79E(&UA>2!B92!C;W)R=7!T960N)RD[#0H@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("!]#0H@("`@("`@
M("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("1T:&ES+3Y?:G5M
M<$)L;V-K*&-E:6PH*"1V7VAE861E<ELG<VEZ92==+S4Q,BDI*3L-"B`@("`@
M("`@?0T*("`@("`@?2!E;'-E('L-"B`@("`@("`@("`D=&AI<RT^7VIU;7!"
M;&]C:RAC96EL*"@D=E]H96%D97);)W-I>F4G72\U,3(I*2D[#0H@("`@("!]
M#0H-"B`@("`@("\J(%1"0R`Z(%-E96US('1O(&)E('5N=7-E9"`N+BX-"B`@
M("`@(&EF("@D=&AI<RT^7V-O;7!R97-S*0T*("`@("`@("`D=E]E;F1?;V9?
M9FEL92`]($!G>F5O9B@D=&AI<RT^7V9I;&4I.PT*("`@("`@96QS90T*("`@
M("`@("`D=E]E;F1?;V9?9FEL92`]($!F96]F*"1T:&ES+3Y?9FEL92D[#0H@
M("`@("`@("HO#0H-"B`@("`@(&EF("@D=E]L:7-T:6YG('Q\("1V7V5X=')A
M8W1?9FEL92!\?"`D=E]E>'1R86-T:6]N7W-T;W!P960I('L-"B`@("`@("`@
M+R\@+2TM+2T@3&]G(&5X=')A8W1E9"!F:6QE<PT*("`@("`@("!I9B`H*"1V
M7V9I;&5?9&ER(#T@9&ER;F%M92@D=E]H96%D97);)V9I;&5N86UE)UTI*0T*
M"0D@("`@/3T@)'9?:&5A9&5R6R=F:6QE;F%M92==*0T*("`@("`@("`@("1V
M7V9I;&5?9&ER(#T@)R<[#0H@("`@("`@(&EF("@H<W5B<W1R*"1V7VAE861E
M<ELG9FEL96YA;64G72P@,"P@,2D@/3T@)R\G*2`F)B`H)'9?9FEL95]D:7(@
M/3T@)R<I*0T*("`@("`@("`@("1V7V9I;&5?9&ER(#T@)R\G.PT*#0H@("`@
M("`@("1P7VQI<W1?9&5T86EL6R1V7VYB*RM=(#T@)'9?:&5A9&5R.PT*("`@
M("`@?0T*("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V]P96Y!<'!E;F0H*0T*("`@(&9U
M;F-T:6]N(%]O<&5N07!P96YD*"D-"B`@("![#0H@("`@("`@(&EF("AF:6QE
M<VEZ92@D=&AI<RT^7W1A<FYA;64I(#T](#`I#0H@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?;W!E;E=R:71E*"D[#0H@("`@("`@("`@#0H@("`@("`@(&EF
M("@D=&AI<RT^7V-O;7!R97-S*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-L
M;W-E*"D[#0H-"B`@("`@("`@("`@(&EF("@A0')E;F%M92@D=&AI<RT^7W1A
M<FYA;64L("1T:&ES+3Y?=&%R;F%M92XB+G1M<"(I*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B@G17)R;W(@=VAI;&4@<F5N86UI;F<@7"<G
M+B1T:&ES+3Y?=&%R;F%M90T*"0D)"2`@("`@("`@("`@("`@+B=<)R!T;R!T
M96UP;W)A<GD@9FEL92!<)R<N)'1H:7,M/E]T87)N86UE#0H)"0D)"0D)("`N
M)RYT;7!<)R<I.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@('T-"@T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E
M<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@("`@("1V7W1E;7!?=&%R
M(#T@0&=Z;W!E;B@D=&AI<RT^7W1A<FYA;64N(BYT;7`B+"`B<F(B*3L-"B`@
M("`@("`@("`@(&5L<V5I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=B
M>C(G*0T*("`@("`@("`@("`@("`@("1V7W1E;7!?=&%R(#T@0&)Z;W!E;B@D
M=&AI<RT^7W1A<FYA;64N(BYT;7`B+"`B<F(B*3L-"B`@("`@("`@("`@("`@
M("`-"B`@("`@("`@("`@(&EF("@D=E]T96UP7W1A<B`]/2`P*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&]P96X@9FEL
M92!<)R<N)'1H:7,M/E]T87)N86UE#0H)"0D)("`@("`@("`@("`@("`N)RYT
M;7!<)R!I;B!B:6YA<GD@<F5A9"!M;V1E)RD[#0H@("`@("`@("`@("`@("`@
M0')E;F%M92@D=&AI<RT^7W1A<FYA;64N(BYT;7`B+"`D=&AI<RT^7W1A<FYA
M;64I.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y7<FET92@I
M*2![#0H@("`@("`@("`@("`@("`@0')E;F%M92@D=&AI<RT^7W1A<FYA;64N
M(BYT;7`B+"`D=&AI<RT^7W1A<FYA;64I.PT*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*2![#0H@("`@("`@("`@
M("`@("`@)'9?8G5F9F5R(#T@0&=Z<F5A9"@D=E]T96UP7W1A<BP@-3$R*3L-
M"@T*("`@("`@("`@("`@("`@("\O("TM+2TM(%)E860@=&AE(&9O;&QO=VEN
M9R!B;&]C:W,@8G5T(&YO="!T:&4@;&%S="!O;F4-"B`@("`@("`@("`@("`@
M("!I9B`H(4!G>F5O9B@D=E]T96UP7W1A<BDI('L-"B`@("`@("`@("`@("`@
M("`@("`@9&][#0H@("`@("`@("`@("`@("`@("`@("`@("`D=E]B:6YA<GE?
M9&%T82`]('!A8VLH(F$U,3(B+"`D=E]B=69F97(I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V7V)U9F9E<B`]($!G>G)E
M860H)'9?=&5M<%]T87(L(#4Q,BD[#0H-"B`@("`@("`@("`@("`@("`@("`@
M?2!W:&EL92`H(4!G>F5O9B@D=E]T96UP7W1A<BDI.PT*("`@("`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@("`@($!G>F-L;W-E*"1V7W1E;7!?=&%R
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&5L<V5I9B`H)'1H:7,M
M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G*2![#0H@("`@("`@("`@("`@("`@
M)'9?8G5F9F5R961?;&EN97,@("`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@
M("`@)'9?8G5F9F5R961?;&EN97-;72`]($!B>G)E860H)'9?=&5M<%]T87(L
M(#4Q,BD[#0H-"B`@("`@("`@("`@("`@("`O+R`M+2TM+2!296%D('1H92!F
M;VQL;W=I;F<@8FQO8VMS(&)U="!N;W0@=&AE(&QA<W0@;VYE#0H@("`@("`@
M("`@("`@("`@=VAI;&4@*'-T<FQE;B@D=E]B=69F97)E9%]L:6YE<UM=#0H)
M"0D)("`@("`@("`@("`@("`]($!B>G)E860H)'9?=&5M<%]T87(L(#4Q,BDI
M(#X@,"D@>PT*("`@("`@("`@("`@("`@("`@("`D=E]B:6YA<GE?9&%T82`]
M('!A8VLH(F$U,3(B+`T*"0D)"0D@("`@("`@("`@("`@("`@("`@("`@87)R
M87E?<VAI9G0H)'9?8G5F9F5R961?;&EN97,I*3L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A*3L-"B`@
M("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("!`8GIC;&]S92@D
M=E]T96UP7W1A<BD[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF
M("@A0'5N;&EN:R@D=&AI<RT^7W1A<FYA;64N(BYT;7`B*2D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T5R<F]R('=H:6QE(&1E;&5T:6YG
M('1E;7!O<F%R>2!F:6QE(%PG)PT*"0D)"2`@("`@("`@("`@("`@+B1T:&ES
M+3Y?=&%R;F%M92XG+G1M<%PG)RD[#0H@("`@("`@("`@("!]#0H-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O("TM+2TM($9O<B!N;W0@8V]M
M<')E<W-E9"!T87(L(&IU<W0@861D(&9I;&5S(&)E9F]R92!T:&4@;&%S=`T*
M"0D)+R\@("`@("`@-3$R(&)Y=&5S(&)L;V-K#0H@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?;W!E;E)E8617<FET92@I*0T*("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*#0H@("`@("`@("`@("!C;&5A<G-T871C86-H92@I.PT*
M("`@("`@("`@("`@)'9?<VEZ92`](&9I;&5S:7IE*"1T:&ES+3Y?=&%R;F%M
M92D[#0H@("`@("`@("`@("!F<V5E:R@D=&AI<RT^7V9I;&4L("1V7W-I>F4M
M-3$R*3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?87!P96YD*"D-"B`@("!F
M=6YC=&EO;B!?87!P96YD*"1P7V9I;&5L:7-T+"`D<%]A9&1?9&ER/2<G+"`D
M<%]R96UO=F5?9&ER/2<G*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^
M7V]P96Y!<'!E;F0H*2D-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@(`T*("`@("`@("!I9B`H)'1H:7,M/E]A9&1,:7-T*"1P7V9I
M;&5L:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*2D-"B`@("`@("`@
M("`@)'1H:7,M/E]W<FET949O;W1E<B@I.PT*#0H@("`@("`@("1T:&ES+3Y?
M8VQO<V4H*3L-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@7V1I<D-H96-K*"D-"@T*("`@("\J*@T*
M("`@("`J($-H96-K(&EF(&$@9&ER96-T;W)Y(&5X:7-T<R!A;F0@8W)E871E
M(&ET("AI;F-L=61I;F<@<&%R96YT#0H@("`@("H@9&ER<RD@:68@;F]T+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<%]D:7(@9&ER96-T;W)Y
M('1O(&-H96-K#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!I
M9B!T:&4@9&ER96-T;W)Y(&5X:7-T<R!O<B!W87,@8W)E871E9`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]D:7)#:&5C:R@D<%]D:7(I#0H@("`@>PT*("`@
M("`@("!I9B`H*$!I<U]D:7(H)'!?9&ER*2D@?'P@*"1P7V1I<B`]/2`G)RDI
M#0H@("`@("`@("`@("!R971U<FX@=')U93L-"@T*("`@("`@("`D<%]P87)E
M;G1?9&ER(#T@9&ER;F%M92@D<%]D:7(I.PT*#0H@("`@("`@(&EF("@H)'!?
M<&%R96YT7V1I<B`A/2`D<%]D:7(I("8F#0H@("`@("`@("`@("`H)'!?<&%R
M96YT7V1I<B`A/2`G)RD@)B8-"B`@("`@("`@("`@("@A)'1H:7,M/E]D:7)#
M:&5C:R@D<%]P87)E;G1?9&ER*2DI#0H@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*#0H@("`@("`@(&EF("@A0&UK9&ER*"1P7V1I<BP@,#<W-RDI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H(E5N86)L92!T;R!C<F5A=&4@
M9&ER96-T;W)Y("<D<%]D:7(G(BD[#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?<&%T:%)E9'5C=&EO;B@I
M#0H-"B`@("`O*BH-"B`@("`@*B!#;VUP<F5S<R!P871H(&)Y(&-H86YG:6YG
M(&9O<B!E>&%M<&QE("(O9&ER+V9O;R\N+B]B87(B('1O("(O9&ER+V)A<B(L
M(`T*("`@("`J(')A;F0@96UO=F4@9&]U8FQE('-L87-H97,N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P7V1I<B!P871H('1O(')E9'5C90T*
M("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@<F5D=6-E9"!P871H#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]P871H4F5D=6-T:6]N*"1P7V1I<BD-"B`@("![
M#0H@("`@("`@("1V7W)E<W5L="`]("<G.PT*#0H@("`@("`@("\O("TM+2TM
M($QO;VL@9F]R(&YO="!E;7!T>2!P871H#0H@("`@("`@(&EF("@D<%]D:7(@
M(3T@)R<I('L-"B`@("`@("`@("`@("\O("TM+2TM($5X<&QO9&4@<&%T:"!B
M>2!D:7)E8W1O<GD@;F%M97,-"B`@("`@("`@("`@("1V7VQI<W0@/2!E>'!L
M;V1E*"<O)RP@)'!?9&ER*3L-"@T*("`@("`@("`@("`@+R\@+2TM+2T@4W1U
M9'D@9&ER96-T;W)I97,@9G)O;2!L87-T('1O(&9I<G-T#0H@("`@("`@("`@
M("!F;W(@*"1I/7-I>F5O9B@D=E]L:7-T*2TQ.R`D:3X],#L@)&DM+2D@>PT*
M("`@("`@("`@("`@("`@("\O("TM+2TM($QO;VL@9F]R(&-U<G)E;G0@<&%T
M:`T*("`@("`@("`@("`@("`@(&EF("@D=E]L:7-T6R1I72`]/2`B+B(I('L-
M"B`@("`@("`@("`@("`@("`@("`@+R\@+2TM+2T@26=N;W)E('1H:7,@9&ER
M96-T;W)Y#0H@("`@("`@("`@("`@("`@("`@("\O(%-H;W5L9"!B92!T:&4@
M9FER<W0@)&D],"P@8G5T(&YO(&-H96-K(&ES(&1O;F4-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@96QS92!I9B`H)'9?;&ES=%LD:5T@
M/3T@(BXN(BD@>PT*("`@("`@("`@("`@("`@("`@("`O+R`M+2TM+2!)9VYO
M<F4@:70@86YD(&EG;F]R92!T:&4@)&DM,0T*("`@("`@("`@("`@("`@("`@
M("`D:2TM.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!E
M;'-E(&EF("@@("`H)'9?;&ES=%LD:5T@/3T@)R<I#0H)"0D)("`@("`@("`@
M)B8@*"1I(3TH<VEZ96]F*"1V7VQI<W0I+3$I*0T*"0D)"0D)("8F("@D:2$]
M,"DI('L-"B`@("`@("`@("`@("`@("`@("`@+R\@+2TM+2T@26=N;W)E(&]N
M;'D@=&AE(&1O=6)L92`G+R\G(&EN('!A=&@L#0H@("`@("`@("`@("`@("`@
M("`@("\O(&)U="!N;W0@=&AE(&9I<G-T(&%N9"!L87-T("\-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=E]R97-U
M;'0@/2`D=E]L:7-T6R1I72XH)&DA/2AS:7IE;V8H)'9?;&ES="DM,2D_)R\G
M#0H)"0D)"2`@("`@("`@("`@("XD=E]R97-U;'0Z)R<I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D
M=E]R97-U;'0@/2!S=')T<B@D=E]R97-U;'0L("=<7"<L("<O)RD[#0H@("`@
M("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-
M"B`@("`O+R![>WL@7W1R86YS;&%T95=I;E!A=&@H*0T*("`@(&9U;F-T:6]N
M(%]T<F%N<VQA=&57:6Y0871H*"1P7W!A=&@L("1P7W)E;6]V95]D:7-K7VQE
M='1E<CUT<G5E*0T*("`@('L-"B`@("`@(&EF("A/4U]724Y$3U=3*2![#0H@
M("`@("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@<&]T96YT:6%L(&1I<VL@;&5T
M=&5R#0H@("`@("`@("`@:68@*"`@("@D<%]R96UO=F5?9&ES:U]L971T97(I
M#0H)"2`@("`@("8F("@H)'9?<&]S:71I;VX@/2!S=')P;W,H)'!?<&%T:"P@
M)SHG*2D@(3T@9F%L<V4I*2![#0H@("`@("`@("`@("`@("1P7W!A=&@@/2!S
M=6)S='(H)'!?<&%T:"P@)'9?<&]S:71I;VXK,2D[#0H@("`@("`@("`@?0T*
M("`@("`@("`@("\O("TM+2TM($-H86YG92!P;W1E;G1I86P@=VEN9&]W<R!D
M:7)E8W1O<GD@<V5P87)A=&]R#0H@("`@("`@("`@:68@*"AS=')P;W,H)'!?
M<&%T:"P@)UQ<)RD@/B`P*2!\?"`H<W5B<W1R*"1P7W!A=&@L(#`L,2D@/3T@
M)UQ<)RDI('L-"B`@("`@("`@("`@("`@)'!?<&%T:"`]('-T<G1R*"1P7W!A
M=&@L("=<7"<L("<O)RD[#0H@("`@("`@("`@?0T*("`@("`@?0T*("`@("`@
M<F5T=7)N("1P7W!A=&@[#0H@("`@?0T*("`@("\O('U]?0T*#0I]#0H_/@T*
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+P``````````
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`U-@`P,38R-#0`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T%U=&@O4T%33"\`````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`Q-S`P-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O075T:"]305-,+T-O;6UO;BYP:'``````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U-#``,3`U,34T,S$P
M-38`,#(P-S4Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@
M"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R9"!(97EE<R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@06QL(')I
M9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R
M8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P@"B\O
M('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@"B\O('P@87)E(&UE=#H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@
M;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@"B\O('P@
M("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@('P@"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE
M('P@"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA
M;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@"B\O('P@;R!4
M:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N
M9&]R<V4@;W(@<')O;6]T92`@("`@('P@"B\O('P@("!P<F]D=6-T<R!D97)I
M=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R
M('=R:71T96X@('P@"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@5$A)4R!3
M3T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@
M04Y$($-/3E1224)55$]24R`@('P@"B\O('P@(D%3($E3(B!!3D0@04Y9($58
M4%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.
M3U0@("`@('P@"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.
M5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P@"B\O
M('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/
M($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@"B\O('P@3U=.15(@3U(@
M0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%
M0U0L($E.0TE$14Y404PL('P@"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/
M4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@
M("`@('P@"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)
M5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L('P@"B\O('P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@"B\O('P@5$A%3U)9($]&($Q)
M04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E4
M62P@3U(@5$]25"`@('P@"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2
M($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%
M('P@"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&
M(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P@"B\O('P@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L@"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H
M87)D0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@"B\O(`HO+R`D260Z
M($-O;6UO;BYP:'`L=B`Q+C8@,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@
M)`H*+RHJ"BH@0V]M;6]N(&9U;F-T:6]N86QI='D@=&\@4T%33"!M96-H86YI
M<VUS"BH**B!`875T:&]R("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN
M970^"BH@0&%C8V5S<R`@<'5B;&EC"BH@0'9E<G-I;VX@,2XP"BH@0'!A8VMA
M9V4@075T:%]305-,"BHO"@IC;&%S<R!!=71H7U-!4TQ?0V]M;6]N"GL*("`@
M("\J*@H@("`@*B!&=6YC=&EO;B!W:&EC:"!I;7!L96UE;G1S($A-04,@340U
M(&1I9V5S=`H@("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R`D:V5Y("!4:&4@
M<V5C<F5T(&ME>0H@("`@*B!`<&%R86T@('-T<FEN9R`D9&%T82!4:&4@9&%T
M82!T;R!P<F]T96-T"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@(%1H92!(
M34%#($U$-2!D:6=E<W0*("`@("HO"B`@("!F=6YC=&EO;B!?2$U!0U]-1#4H
M)&ME>2P@)&1A=&$I"B`@("!["B`@("`@("`@:68@*'-T<FQE;B@D:V5Y*2`^
M(#8T*2!["B`@("`@("`@("`@("1K97D@/2!P86-K*"=(,S(G+"!M9#4H)&ME
M>2DI.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T<FQE;B@D:V5Y*2`\(#8T
M*2!["B`@("`@("`@("`@("1K97D@/2!S=')?<&%D*"1K97DL(#8T+"!C:'(H
M,"DI.PH@("`@("`@('T*"B`@("`@("`@)&M?:7!A9"`]('-U8G-T<B@D:V5Y
M+"`P+"`V-"D@7B!S=')?<F5P96%T*&-H<B@P>#,V*2P@-C0I.PH@("`@("`@
M("1K7V]P860@/2!S=6)S='(H)&ME>2P@,"P@-C0I(%X@<W1R7W)E<&5A="AC
M:'(H,'@U0RDL(#8T*3L*"B`@("`@("`@)&EN;F5R("`]('!A8VLH)T@S,B<L
M(&UD-2@D:U]I<&%D("X@)&1A=&$I*3L*("`@("`@("`D9&EG97-T(#T@;60U
M*"1K7V]P860@+B`D:6YN97(I.PH*("`@("`@("!R971U<FX@)&1I9V5S=#L*
M("`@('T*?0H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]#<F%M340U+G!H<```
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-S`V`#$P-3$U-#,Q
M,#4V`#`R,#<Q-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*R`-"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R9"!(97EE
M<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\($%L
M;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?"`-"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@
M('P@#0HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E
M9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`T*+R\@?"!A
M<F4@;65T.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O
M=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@
M("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?"`-"B\O('P@
M;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U
M8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P@#0HO+R!\("`@;F]T:6-E+"!T
M:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C
M;&%I;65R(&EN('1H92!\(`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R
M(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I
M;VXN?"`-"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO
M="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P@#0HO+R!\
M("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U
M="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\(`T*+R\@?"`@('!E<FUI<W-I
M;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@#0HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%
M($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\(`T*+R\@
M?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)
M15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?"`-"B\O('P@3$E-251%1"!4
M3RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@
M04Y$($9)5$Y%4U,@1D]2('P@#0HO+R!\($$@4$%25$E#54Q!4B!055)03U-%
M($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))
M1TA4("!\(`T*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%
M($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?"`-"B\O
M('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'
M15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P@#0HO+R!\($Q)34E4140@
M5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#
M15,[($Q/4U,@3T8@55-%+"!\(`T*+R\@?"!$051!+"!/4B!04D]&2513.R!/
M4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/
M3B!!3ED@?"`-"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)
M3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P@#0HO
M+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)
M3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\(`T*+R\@?"!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+B`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*
M+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R`-"B\O("1)9#H@0W)A;4U$-2YP
M:'`L=B`Q+C0@,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@)`T*#0HO*BH-
M"BH@26UP;&UE;G1A=&EO;B!O9B!#4D%-+4U$-2!305-,(&UE8VAA;FES;0T*
M*@T**B!`875T:&]R("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^
M#0HJ($!A8V-E<W,@('!U8FQI8PT**B!`=F5R<VEO;B`Q+C`-"BH@0'!A8VMA
M9V4@075T:%]305-,#0HJ+PT*#0IR97%U:7)E7V]N8V4H)T%U=&@O4T%33"]#
M;VUM;VXN<&AP)RD[#0H-"F-L87-S($%U=&A?4T%33%]#<F%M340U(&5X=&5N
M9',@075T:%]305-,7T-O;6UO;@T*>PT*("`@("\J*@T*("`@("H@26UP;&5M
M96YT<R!T:&4@0U)!32U-1#4@4T%33"!M96-H86YI<VT-"B`@("`J(%1H:7,@
M1$]%4R!.3U0@8F%S938T(&5N8V]D92!T:&4@<F5T=7)N('9A;'5E+`T*("`@
M("H@>6]U('=I;&P@;F5E9"!T;R!D;R!T:&%T('EO=7)S96QF+@T*("`@("H-
M"B`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!5<V5R;F%M90T*("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%S<R`@("`@(%!A<W-W;W)D#0H@("`@*B!`
M<&%R86T@<W1R:6YG("1C:&%L;&5N9V4@5&AE(&-H86QL96YG92!S=7!P;&EE
M9"!B>2!T:&4@<V5R=F5R+@T*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H:7,@<VAO=6QD(&)E(&%L<F5A9'D@8F%S938T7V1E8V]D960N#0H@
M("`@*@T*("`@("H@0')E='5R;B!S=')I;F<@5&AE('-T<FEN9R!T;R!P87-S
M(&)A8VL@=&\@=&AE('-E<G9E<BP@;V8@=&AE(&9O<FT-"B`@("`J("`@("`@
M("`@("`@("`@("(\=7-E<CX@/&1I9V5S=#XB+B!4:&ES(&ES($Y/5"!B87-E
M-C1?96YC;V1E9"X-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E
M*"1U<V5R+"`D<&%S<RP@)&-H86QL96YG92D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=7-E<B`N("<@)R`N("1T:&ES+3Y?2$U!0U]-1#4H)'!A<W,L("1C
M:&%L;&5N9V4I.PT*("`@('T-"GT-"C\^````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO1&EG97-T340U+G!H
M<```````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#(V,``Q,#4Q-30S
M,3`U-@`P,C$R-#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*R`*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!2:6-H87)D($AE>65S
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`*+R\@?"!!;&P@
M<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"`*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?"`*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?"`*
M+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA
M="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`*+R\@?"!A<F4@;65T
M.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?"`*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?"`*+R\@
M?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?"`*+R\@?"!O(%)E9&ES=')I
M8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O
M=F4@8V]P>7)I9VAT("`@?"`*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T
M:&4@?"`*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R
M:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?"`*+R\@?"!O
M(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@
M96YD;W)S92!O<B!P<F]M;W1E("`@("`@?"`*+R\@?"`@('!R;V1U8W1S(&1E
M<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B`@?"`*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`*+R\@?"!42$E3
M(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$52
M4R!!3D0@0T].5%))0E543U)3("`@?"`*+R\@?"`B05,@25,B($%.1"!!3ED@
M15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54
M($Y/5"`@("`@?"`*+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)2
M04Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@?"`*
M+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@
M3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?"`*+R\@?"!/5TY%4B!/
M4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)
M4D5#5"P@24Y#241%3E1!3"P@?"`*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL
M($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4
M("`@("`@?"`*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)3
M5$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?"`*+R\@
M?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?"`*+R\@?"!42$5/4ED@3T8@
M3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,
M2519+"!/4B!43U)4("`@?"`*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@
M3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!5
M4T4@?"`*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@
M3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?"`*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"`*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*R`*+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I
M8VAA<F1`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`*+R\@"B\O("1)
M9#H@1&EG97-T340U+G!H<"QV(#$N-B`R,#`S+S`R+S(Q(#$V.C`W.C$W(&UJ
M($5X<"`D"@HO*BH**B!);7!L;65N=&%T:6]N(&]F($1)1T535"U-1#4@4T%3
M3"!M96-H86YI<VT**@HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA
M<F1`<&AP+FYE=#X**B!`86-C97-S("!P=6)L:6,**B!`=F5R<VEO;B`Q+C`*
M*B!`<&%C:V%G92!!=71H7U-!4TP**B\*"G)E<75I<F5?;VYC92@G075T:"]3
M05-,+T-O;6UO;BYP:'`G*3L*"F-L87-S($%U=&A?4T%33%]$:6=E<W1-1#4@
M97AT96YD<R!!=71H7U-!4TQ?0V]M;6]N"GL*("`@("\J*@H@("`@*B!0<F]V
M:61E<R!T:&4@*&UA:6XI(&-L:65N="!R97-P;VYS92!F;W(@1$E'15-4+4U$
M-0H@("`@*B!R97%U:7)E<R!A(&9E=R!E>'1R82!P87)A;65T97)S('1H86X@
M=&AE(&]T:&5R"B`@("`J(&UE8VAA;FES;7,L('=H:6-H(&%R92!U;F%V;VED
M86)L92X*("`@("H@"B`@("`J($!P87)A;2`@<W1R:6YG("1A=71H8VED("`@
M075T:&5N=&EC871I;VX@:60@*'5S97)N86UE*0H@("`@*B!`<&%R86T@('-T
M<FEN9R`D<&%S<R`@("`@(%!A<W-W;W)D"B`@("`J($!P87)A;2`@<W1R:6YG
M("1C:&%L;&5N9V4@5&AE(&1I9V5S="!C:&%L;&5N9V4@<V5N="!B>2!T:&4@
M<V5R=F5R"B`@("`J($!P87)A;2`@<W1R:6YG("1H;W-T;F%M92`@5&AE(&AO
M<W1N86UE(&]F('1H92!M86-H:6YE('EO=2=R92!C;VYN96-T:6YG('1O"B`@
M("`J($!P87)A;2`@<W1R:6YG("1S97)V:6-E("`@5&AE('-E<G9I8V5N86UE
M("AE9RX@:6UA<"P@<&]P+"!A8V%P(&5T8RD*("`@("H@0'!A<F%M("!S=')I
M;F<@)&%U=&AZ:60@("!!=71H;W)I>F%T:6]N(&ED("AU<V5R;F%M92!T;R!P
M<F]X>2!A<RD*("`@("H@0')E='5R;B!S=')I;F<@("`@("`@("`@("!4:&4@
M9&EG97-T(')E<W!O;G-E("A.3U0@8F%S938T(&5N8V]D960I"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H
M)&%U=&AC:60L("1P87-S+"`D8VAA;&QE;F=E+"`D:&]S=&YA;64L("1S97)V
M:6-E+"`D875T:'II9"`]("<G*0H@("`@>PH@("`@("`@("1C:&%L;&5N9V4@
M/2`D=&AI<RT^7W!A<G-E0VAA;&QE;F=E*"1C:&%L;&5N9V4I.PH@("`@("`@
M("1A=71H>FED7W-T<FEN9R`]("<G.PH@("`@("`@(&EF("@D875T:'II9"`A
M/2`G)RD@>PH@("`@("`@("`@("`D875T:'II9%]S=')I;F<@/2`G+&%U=&AZ
M:60](B<@+B`D875T:'II9"`N("<B)SL@"B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1C:&%L;&5N9V4I*2!["B`@("`@("`@("`@("1C;F]N8V4@
M("`@("`@("`]("1T:&ES+3Y?9V5T0VYO;F-E*"D["B`@("`@("`@("`@("1D
M:6=E<W1?=7)I("`@("`]('-P<FEN=&8H)R5S+R5S)RP@)'-E<G9I8V4L("1H
M;W-T;F%M92D["B`@("`@("`@("`@("1R97-P;VYS95]V86QU92`]("1T:&ES
M+3Y?9V5T4F5S<&]N<V5686QU92@D875T:&-I9"P@)'!A<W,L("1C:&%L;&5N
M9V5;)W)E86QM)UTL("1C:&%L;&5N9V5;)VYO;F-E)UTL("1C;F]N8V4L("1D
M:6=E<W1?=7)I+"`D875T:'II9"D["@H@("`@("`@("`@("!R971U<FX@<W!R
M:6YT9B@G=7-E<FYA;64](B5S(BQR96%L;3TB)7,B)R`N("1A=71H>FED7W-T
M<FEN9R`@+B`G+&YO;F-E/2(E<R(L8VYO;F-E/2(E<R(L;F,](C`P,#`P,#`Q
M(BQQ;W`]875T:"QD:6=E<W0M=7)I/2(E<R(L<F5S<&]N<V4])7,L)60G+"`D
M875T:&-I9"P@)&-H86QL96YG95LG<F5A;&TG72P@)&-H86QL96YG95LG;F]N
M8V4G72P@)&-N;VYC92P@)&1I9V5S=%]U<FDL("1R97-P;VYS95]V86QU92P@
M)&-H86QL96YG95LG;6%X8G5F)UTI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=);G9A;&ED(&1I9V5S
M="!C:&%L;&5N9V4G*3L*("`@("`@("!]"B`@("!]"B`@("`*("`@("\J*@H@
M("`@*B!087)S97,@86YD('9E<FEF:65S('1H92!D:6=E<W0@8VAA;&QE;F=E
M*@H@("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R`D8VAA;&QE;F=E(%1H92!D
M:6=E<W0@8VAA;&QE;F=E"B`@("`J($!R971U<FX@87)R87D@("`@("`@("`@
M("`@5&AE('!A<G-E9"!C:&%L;&5N9V4@87,@86X@87-S;V,*("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2!I;B!T:&4@9F]R;2`B9&ER
M96-T:79E(#T^('9A;'5E(BX*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J
M+PH@("`@9G5N8W1I;VX@7W!A<G-E0VAA;&QE;F=E*"1C:&%L;&5N9V4I"B`@
M("!["B`@("`@("`@)'1O:V5N<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@
M*'!R96=?;6%T8V@H)R]>*%MA+7HM72LI/2@B6UXB72LH/SPA7%Q<*2)\6UXL
M72LI+VDG+"`D8VAA;&QE;F=E+"`D;6%T8VAE<RDI('L*"B`@("`@("`@("`@
M("\O($EG;F]R92!T:&5S92!A<R!P97(@<F9C,C@S,0H@("`@("`@("`@("!I
M9B`H)&UA=&-H97-;,5T@/3T@)V]P87%U92<@3U(@)&UA=&-H97-;,5T@/3T@
M)V1O;6%I;B<I('L*("`@("`@("`@("`@("`@("1C:&%L;&5N9V4@/2!S=6)S
M='(H)&-H86QL96YG92P@<W1R;&5N*"1M871C:&5S6S!=*2`K(#$I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O($%L;&]W960@;75L=&EP;&4@(G)E86QM(B!A;F0@(F%U=&@M<&%R
M86TB"B`@("`@("`@("`@(&EF("@A96UP='DH)'1O:V5N<ULD;6%T8VAE<ULQ
M75TI($%.1"`H)&UA=&-H97-;,5T@/3T@)W)E86QM)R!/4B`D;6%T8VAE<ULQ
M72`]/2`G875T:"UP87)A;2<I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'1O:V5N<ULD;6%T8VAE<ULQ75TI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1O:V5N<ULD;6%T8VAE<ULQ75U;72`]('!R96=?<F5P;&%C92@G
M+UXB*"XJ*2(D+R<L("=<7#$G+"`D;6%T8VAE<ULR72D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T;VME;G-;)&UA
M=&-H97-;,5U=(#T@87)R87DH)'1O:V5N<ULD;6%T8VAE<ULQ75TL('!R96=?
M<F5P;&%C92@G+UXB*"XJ*2(D+R<L("=<7#$G+"`D;6%T8VAE<ULR72DI.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@06YY(&]T:&5R(&UU
M;'1I<&QE(&EN<W1A;F-E(#T@9F%I;'5R90H@("`@("`@("`@("!](&5L<V5I
M9B`H(65M<'1Y*"1T;VME;G-;)&UA=&-H97-;,5U=*2D@>PH@("`@("`@("`@
M("`@("`@)'1O:V5N<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&]K
M96YS6R1M871C:&5S6S%=72`]('!R96=?<F5P;&%C92@G+UXB*"XJ*2(D+R<L
M("=<7#$G+"`D;6%T8VAE<ULR72D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O(%)E;6]V92!T:&4@:G5S="!P87)S960@9&ER96-T:79E(&9R;VT@
M=&AE(&-H86QL96YG90H@("`@("`@("`@("`D8VAA;&QE;F=E(#T@<W5B<W1R
M*"1C:&%L;&5N9V4L('-T<FQE;B@D;6%T8VAE<ULP72D@*R`Q*3L*("`@("`@
M("!]"@H@("`@("`@("\J*@H@("`@("`@("H@1&5F875L=',@86YD(')E<75I
M<F5D(&1I<F5C=&EV97,*("`@("`@("`J+PH@("`@("`@("\O(%)E86QM"B`@
M("`@("`@:68@*&5M<'1Y*"1T;VME;G-;)W)E86QM)UTI*2!["B`@("`@("`@
M("`@("1U;F%M92`]('!O<VEX7W5N86UE*"D["B`@("`@("`@("`@("1T;VME
M;G-;)W)E86QM)UT@/2`D=6YA;65;)VYO9&5N86UE)UT["B`@("`@("`@?0H@
M("`@("`@(`H@("`@("`@("\O($UA>&)U9@H@("`@("`@(&EF("AE;7!T>2@D
M=&]K96YS6R=M87AB=68G72DI('L*("`@("`@("`@("`@)'1O:V5N<ULG;6%X
M8G5F)UT@/2`V-34S-CL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@
M4F5Q=6ER960Z(&YO;F-E+"!A;&=O<FET:&T*("`@("`@("!I9B`H96UP='DH
M)'1O:V5N<ULG;F]N8V4G72D@3U(@96UP='DH)'1O:V5N<ULG86QG;W)I=&AM
M)UTI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*
M("`@("`@("`*("`@("`@("!R971U<FX@)'1O:V5N<SL*("`@('T*"B`@("`O
M*BH*("`@("H@0W)E871E<R!T:&4@<F5S<&]N<V4]('!A<G0@;V8@=&AE(&1I
M9V5S="!R97-P;VYS90H@("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R`D875T
M:&-I9"`@("!!=71H96YT:6-A=&EO;B!I9"`H=7-E<FYA;64I"B`@("`J($!P
M87)A;2`@<W1R:6YG("1P87-S("`@("`@(%!A<W-W;W)D"B`@("`J($!P87)A
M;2`@<W1R:6YG("1R96%L;2`@("`@(%)E86QM(&%S('!R;W9I9&5D(&)Y('1H
M92!S97)V97(*("`@("H@0'!A<F%M("!S=')I;F<@)&YO;F-E("`@("`@3F]N
M8V4@87,@<')O=FED960@8GD@=&AE('-E<G9E<@H@("`@*B!`<&%R86T@('-T
M<FEN9R`D8VYO;F-E("`@("!#;&EE;G0@;F]N8V4*("`@("H@0'!A<F%M("!S
M=')I;F<@)&1I9V5S=%]U<FD@5&AE(&1I9V5S="UU<FD]('9A;'5E('!A<G0@
M;V8@=&AE(')E<W!O;G-E"B`@("`J($!P87)A;2`@<W1R:6YG("1A=71H>FED
M("`@($%U=&AO<FEZ871I;VX@:60*("`@("H@0')E='5R;B!S=')I;F<@("`@
M("`@("`@("`@5&AE(')E<W!O;G-E/2!P87)T(&]F('1H92!D:6=E<W0@<F5S
M<&]N<V4*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+R`@("`*("`@(&9U
M;F-T:6]N(%]G971297-P;VYS959A;'5E*"1A=71H8VED+"`D<&%S<RP@)')E
M86QM+"`D;F]N8V4L("1C;F]N8V4L("1D:6=E<W1?=7)I+"`D875T:'II9"`]
M("<G*0H@("`@>PH@("`@("`@(&EF("@D875T:'II9"`]/2`G)RD@>PH@("`@
M("`@("`@("`D03$@/2!S<')I;G1F*"<E<SHE<SHE<R<L('!A8VLH)T@S,B<L
M(&UD-2AS<')I;G1F*"<E<SHE<SHE<R<L("1A=71H8VED+"`D<F5A;&TL("1P
M87-S*2DI+"`D;F]N8V4L("1C;F]N8V4I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1!,2`]('-P<FEN=&8H)R5S.B5S.B5S.B5S)RP@<&%C:R@G
M2#,R)RP@;60U*'-P<FEN=&8H)R5S.B5S.B5S)RP@)&%U=&AC:60L("1R96%L
M;2P@)'!A<W,I*2DL("1N;VYC92P@)&-N;VYC92P@)&%U=&AZ:60I.PH@("`@
M("`@('T*("`@("`@("`D03(@/2`G05542$5.5$E#051%.B<@+B`D9&EG97-T
M7W5R:3L*("`@("`@("!R971U<FX@;60U*'-P<FEN=&8H)R5S.B5S.C`P,#`P
M,#`Q.B5S.F%U=&@Z)7,G+"!M9#4H)$$Q*2P@)&YO;F-E+"`D8VYO;F-E+"!M
M9#4H)$$R*2DI.PH@("`@?0H*("`@("\J*@H@("`@*B!#<F5A=&5S('1H92!C
M;&EE;G0@;F]N8V4@9F]R('1H92!R97-P;VYS90H@("`@*@H@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&-N;VYC92!V86QU90H@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("HO"B`@("!F=6YC=&EO;B!?9V5T0VYO;F-E*"D*("`@('L*
M("`@("`@("!I9B`H9FEL95]E>&ES=',H)R]D978O=7)A;F1O;2<I*2!["B`@
M("`@("`@("`@(')E='5R;B!B87-E-C1?96YC;V1E*&9R96%D*&9O<&5N*"<O
M9&5V+W5R86YD;VTG+"`G<B<I+"`S,BDI.PH*("`@("`@("!](&5L<V5I9B`H
M9FEL95]E>&ES=',H)R]D978O<F%N9&]M)RDI('L*("`@("`@("`@("`@<F5T
M=7)N(&)A<V4V-%]E;F-O9&4H9G)E860H9F]P96XH)R]D978O<F%N9&]M)RP@
M)W(G*2P@,S(I*3L*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T
M<B`]("<G.PH@("`@("`@("`@("!M=%]S<F%N9"@H9&]U8FQE*6UI8W)O=&EM
M92@I*C$P,#`P,#`P*3L*("`@("`@("`@("`@9F]R("@D:3TP.R`D:3PS,CL@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@)'-T<B`N/2!C:'(H;71?<F%N9"@P
M+"`R-34I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("`@
M("`@<F5T=7)N(&)A<V4V-%]E;F-O9&4H)'-T<BD["B`@("`@("`@?0H@("`@
M?0I]"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO3&]G:6XN<&AP````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(W-``Q,#4Q-30S,3`U-@`P,C`U
M-S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\
M($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!!;&P@<FEG:'1S
M(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E
M(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`T*+R\@
M?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T
M:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`-"B\O('P@87)E(&UE=#H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?"`-"B\O
M('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@#0HO+R!\(&\@4F5D:7-T
M<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A
M8F]V92!C;W!Y<FEG:'0@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T
M(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I
M;B!T:&4@?"`-"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@#0HO
M+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E
M9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`T*+R\@?"`@('!R;V1U
M8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF
M:6,@<')I;W(@=W)I='1E;B`@?"`-"B\O('P@("!P97)M:7-S:6]N+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*
M+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'
M2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?"`-"B\O('P@(D%3($E3
M(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3($9/4B!\(`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E3
M0TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?"`-
M"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9
M($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@#0HO+R!\(%-014-)
M04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!04D]#
M55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3
M($]&(%5312P@?"`-"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%
M4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@
M#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!
M0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`T*+R\@?"`H24Y#
M3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.
M62!705D@3U54($]&(%1(12!54T4@?"`-"B\O('P@3T8@5$A)4R!33T945T%2
M12P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(
M($1!34%'12X@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@075T
M:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK(`T*+R\@#0HO+R`D260Z($QO9VEN+G!H<"QV(#$N-"`R
M,#`S+S`R+S(Q(#$V.C`W.C$W(&UJ($5X<"`D#0H-"B\J*@T**B!4:&ES(&ES
M('1E8VAN:6-A;&QY(&YO="!A(%-!4TP@;65C:&%N:7-M+"!H;W=E=F5R#0HJ
M(&ET)W,@=7-E9"!B>2!.971?4VEE=F4L($YE=%]#>7)U<R!A;F0@<&]T96YT
M:6%L;'D-"BH@;W1H97(@<')O=&]C;VQS("P@<V\@:&5R92!I<R!A(&=O;V0@
M<&QA8V4@=&\@86)S=')A8W0-"BH@:70N#0HJ#0HJ($!A=71H;W(@(%)I8VAA
M<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X-"BH@0&%C8V5S<R`@<'5B;&EC
M#0HJ($!V97)S:6]N(#$N,`T**B!`<&%C:V%G92!!=71H7U-!4TP-"BHO#0H-
M"G)E<75I<F5?;VYC92@G075T:"]305-,+T-O;6UO;BYP:'`G*3L-"@T*8VQA
M<W,@075T:%]305-,7TQO9VEN(&5X=&5N9',@075T:%]305-,7T-O;6UO;@T*
M>PT*("`@("\J*@T*("`@("H@4'-E=61O(%-!4TP@3$]'24X@;65C:&%N:7-M
M#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@)'5S97(@57-E<FYA;64-
M"B`@("`J($!P87)A;2`@<W1R:6YG("1P87-S(%!A<W-W;W)D#0H@("`@*B!`
M<F5T=7)N('-T<FEN9R`@("`@("!,3T=)3B!S=')I;F<-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1U<V5R+"`D<&%S<RD-"B`@("![#0H@
M("`@("`@(')E='5R;B!S<')I;G1F*"=,3T=)3B`E<R`E<R<L("1U<V5R+"`D
M<&%S<RD[#0H@("`@?0T*?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O075T:"]305-,+U!L86EN+G!H<```````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R-3$`,3`U,34T,S$P-38`,#(P
M-38S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!2:6-H87)D($AE>65S("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@06QL(')I9VAT
M<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?"`-"B\O
M('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@#0HO+R!\(&%R92!M970Z
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?"`-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O
M9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@#0HO
M+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`T*+R\@?"!O(%)E9&ES
M=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@
M86)O=F4@8V]P>7)I9VAT("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES
M="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@
M:6X@=&AE('P@#0HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@
M;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`T*
M+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S
M960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?"`-"B\O('P@("!P<F]D
M=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I
M9FEC('!R:6]R('=R:71T96X@('P@#0HO+R!\("`@<&5R;6ES<VEO;BX@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-
M"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))
M1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@#0HO+R!\(")!4R!)
M4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#
M3%5$24Y'+"!"550@3D]4("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!42$4@
M24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534R!&3U(@?"`-"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)
M4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@
M#0HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.
M62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\(`T*+R\@?"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+"!"550@3D]4("`@("`@?"`-"B\O('P@3$E-251%1"!43RP@4%)/
M0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]3
M4R!/1B!54T4L('P@#0HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.
M15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\
M(`T*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E12
M04-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?"`-"B\O('P@*$E.
M0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!
M3ED@5T%9($]55"!/1B!42$4@55-%('P@#0HO+R!\($]&(%1(25,@4T]&5%=!
M4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($%U
M=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*R`-"B\O(`T*+R\@)$ED.B!0;&%I;BYP:'`L=B`Q+C4@
M,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@)`T*#0HO*BH-"BH@26UP;&UE
M;G1A=&EO;B!O9B!03$%)3B!305-,(&UE8VAA;FES;0T**@T**B!`875T:&]R
M("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^#0HJ($!A8V-E<W,@
M('!U8FQI8PT**B!`=F5R<VEO;B`Q+C`-"BH@0'!A8VMA9V4@075T:%]305-,
M#0HJ+PT*#0IR97%U:7)E7V]N8V4H)T%U=&@O4T%33"]#;VUM;VXN<&AP)RD[
M#0H-"F-L87-S($%U=&A?4T%33%]0;&%I;B!E>'1E;F1S($%U=&A?4T%33%]#
M;VUM;VX-"GL-"B`@("`O*BH-"B`@("`J(%)E='5R;G,@4$Q!24X@<F5S<&]N
M<V4-"B`@("`J#0H@("`@*B!`<&%R86T@('-T<FEN9R`D875T:&-I9"`@($%U
M=&AE;G1I8V%T:6]N(&ED("AU<V5R;F%M92D-"B`@("`J($!P87)A;2`@<W1R
M:6YG("1P87-S("`@("`@4&%S<W=O<F0-"B`@("`J($!P87)A;2`@<W1R:6YG
M("1A=71H>FED("`@075T;W)I>F%T:6]N(&ED#0H@("`@*B!`<F5T=7)N('-T
M<FEN9R`@("`@("`@("`@(%!,04E.(%)E<W!O;G-E#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971297-P;VYS92@D875T:&-I9"P@)'!A<W,L("1A=71H>FED
M(#T@)R<I#0H@("`@>PT*("`@("`@("!R971U<FX@)&%U=&AZ:60@+B!C:'(H
M,"D@+B`D875T:&-I9"`N(&-H<B@P*2`N("1P87-S.PT*("`@('T-"GT-"C\^
M#0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]!;F]N>6UO=7,N<&AP````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-S8T`#$P-3$U-#,Q,#4V`#`R
M,34R,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O
M('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R9"!(97EE<R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\($%L;"!R:6=H
M=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?"`-"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R
M8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P@#0HO
M+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T
M('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`T*+R\@?"!A<F4@;65T
M.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C
M;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\(`T*
M+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?"`-"B\O('P@;R!2961I
M<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE
M(&%B;W9E(&-O<'ER:6=H="`@('P@#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M(&EN('1H92!\(`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R
M(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?"`-
M"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U
M<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P@#0HO+R!\("`@<')O
M9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C
M:69I8R!P<FEO<B!W<FET=&5N("!\(`T*+R\@?"`@('!E<FUI<W-I;VXN("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M#0HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E2
M24=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\(`T*+R\@?"`B05,@
M25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.
M0TQ51$E.1RP@0E54($Y/5"`@("`@?"`-"B\O('P@3$E-251%1"!43RP@5$A%
M($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)
M5$Y%4U,@1D]2('P@#0HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$
M25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\
M(`T*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!
M3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?"`-"B\O('P@4U!%
M0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.
M0TQ51$E.1RP@0E54($Y/5"`@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%!2
M3T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/
M4U,@3T8@55-%+"!\(`T*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)
M3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@
M?"`-"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY4
M4D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P@#0HO+R!\("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@
M04Y9(%=!62!/550@3T8@5$A%(%5312!\(`T*+R\@?"!/1B!42$E3(%-/1E17
M05)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+B`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@?"!!
M=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L@#0HO+R`-"B\O("1)9#H@06YO;GEM;W5S+G!H<"QV
M(#$N-"`R,#`S+S`R+S(Q(#$V.C`W.C$W(&UJ($5X<"`D#0H-"B\J*@T**B!)
M;7!L;65N=&%T:6]N(&]F($%.3TY934]54R!305-,(&UE8VAA;FES;0T**@T*
M*B!`875T:&]R("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^#0HJ
M($!A8V-E<W,@('!U8FQI8PT**B!`=F5R<VEO;B`Q+C`-"BH@0'!A8VMA9V4@
M075T:%]305-,#0HJ+PT*#0IR97%U:7)E7V]N8V4H)T%U=&@O4T%33"]#;VUM
M;VXN<&AP)RD[#0H-"F-L87-S($%U=&A?4T%33%]!;F]N>6UO=7,@97AT96YD
M<R!!=71H7U-!4TQ?0V]M;6]N#0I[#0H@("`@+RHJ#0H@("`@*B!.;W0@;75C
M:"!T;R!D;R!H97)E(&5X8V5P="!R971U<FX@=&AE('1O:V5N('-U<'!L:65D
M+@T*("`@("H@3F\@96YC;V1I;F<L(&AA<VAI;F<@;W(@96YC<GEP=&EO;B!T
M86ME<R!P;&%C92!F;W(@=&AI<PT*("`@("H@;65C:&%N:7-M+"!S:6UP;'D@
M;VYE(&]F.@T*("`@("H@(&\@06X@96UA:6P@861D<F5S<PT*("`@("H@(&\@
M06X@;W!A<75E('-T<FEN9R!N;W0@8V]N=&%I;FEN9R`B0"(@=&AA="!C86X@
M8F4@:6YT97)P<F5T960-"B`@("`J("`@(&)Y('1H92!S>7-A9&UI;@T*("`@
M("H@(&\@3F]T:&EN9PT*("`@("H-"B`@("`J(%=E(&-O=6QD(&AA=F4@<V]M
M92!L;V=I8R!H97)E(&9O<B!T:&4@<V5C;VYD(&]P=&EO;BP@8G5T('1H:7,-
M"B`@("`J('=O=6QD(&)Y(&YO(&UE86YS(&-R96%T92!S;VUE=&AI;F<@:6YT
M97)P<F5T86)L92X-"B`@("`J#0H@("`@*B!`<&%R86T@('-T<FEN9R`D=&]K
M96X@3W!T:6]N86P@96UA:6P@861D<F5S<R!O<B!S=')I;F<@=&\@<')O=FED
M90T*("`@("H@("`@("`@("`@("`@("`@("`@("`@(&%S('1R86-E(&EN9F]R
M;6%T:6]N+@T*("`@("H@0')E='5R;B!S=')I;F<@("`@("`@(%1H92!U;F%L
M=&5R960@:6YP=70@=&]K96X-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%)E
M<W!O;G-E*"1T;VME;B`]("<G*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T
M;VME;CL-"B`@("!]#0I]#0H_/@```````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPN<&AP````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#(P-``Q,#4Q-30S,3`U-@`P
M,3<U,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO
M+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!!;&P@<FEG
M:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`T*
M+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA
M="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`-"B\O('P@87)E(&UE
M=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@
M8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?"`-
M"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@#0HO+R!\(&\@4F5D
M:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H
M92!A8F]V92!C;W!Y<FEG:'0@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<B!I;B!T:&4@?"`-"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE
M<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@
M#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@
M=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`T*+R\@?"`@('!R
M;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E
M8VEF:6,@<')I;W(@=W)I='1E;B`@?"`-"B\O('P@("!P97)M:7-S:6]N+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`T*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!9
M4DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?"`-"B\O('P@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%1(
M12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&
M251.15-3($9/4B!\(`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@
M?"`-"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@#0HO+R!\(%-0
M14-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)
M3D-,541)3D<L($)55"!.3U0@("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!0
M4D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,
M3U-3($]&(%5312P@?"`-"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E53
M24Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9
M('P@#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].
M5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`T*+R\@?"`H
M24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.
M($%.62!705D@3U54($]&(%1(12!54T4@?"`-"B\O('P@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!3
M54-(($1!34%'12X@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@
M075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK(`T*+R\@#0HO+R`D260Z(%-!4TPN<&AP+'8@,2XT
M(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*+RHJ#0HJ($-L:65N
M="!I;7!L96UE;G1A=&EO;B!O9B!V87)I;W5S(%-!4TP@;65C:&%N:7-M<R`-
M"BH-"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T
M/@T**B!`86-C97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K
M86=E($%U=&A?4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E*"=014%2+G!H<"<I
M.PT*#0IC;&%S<R!!=71H7U-!4TP-"GL-"B`@("`O*BH-"B`@("`J($9A8W1O
M<GD@8VQA<W,N(%)E='5R;G,@86X@;V)J96-T(&]F('1H92!R97%U97-T#0H@
M("`@*B!T>7!E+@T*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M3VYE(&]F.B!!;F]N>6UO=7,-"B`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!0;&%I;@T*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($-R86U-1#4-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!$:6=E<W1-1#4-"B`@("`J("`@("`@("`@("`@("`@("`@("`@5'EP97,@
M87)E(&YO="!C87-E('-E;G-I=&EV90T*("`@("HO#0H@("`@9G5N8W1I;VX@
M)F9A8W1O<GDH)'1Y<&4I#0H@("`@>PT*("`@("`@("!S=VET8V@@*'-T<G1O
M;&]W97(H)'1Y<&4I*2![#0H@("`@("`@("`@("!C87-E("=A;F]N>6UO=7,G
M.@T*("`@("`@("`@("`@("`@("1F:6QE;F%M92`@/2`G075T:"]305-,+T%N
M;VYY;6]U<RYP:'`G.PT*("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G
M075T:%]305-,7T%N;VYY;6]U<R<[#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H-"B`@("`@("`@("`@(&-A<V4@)VQO9VEN)SH-"B`@("`@("`@("`@("`@
M("`D9FEL96YA;64@(#T@)T%U=&@O4T%33"],;V=I;BYP:'`G.PT*("`@("`@
M("`@("`@("`@("1C;&%S<VYA;64@/2`G075T:%]305-,7TQO9VEN)SL-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S92`G<&QA
M:6XG.@T*("`@("`@("`@("`@("`@("1F:6QE;F%M92`@/2`G075T:"]305-,
M+U!L86EN+G!H<"<[#0H@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("=!
M=71H7U-!4TQ?4&QA:6XG.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@
M("`@("`@("`@("!C87-E("=C<F%M;60U)SH-"B`@("`@("`@("`@("`@("`D
M9FEL96YA;64@(#T@)T%U=&@O4T%33"]#<F%M340U+G!H<"<[#0H@("`@("`@
M("`@("`@("`@)&-L87-S;F%M92`]("=!=71H7U-!4TQ?0W)A;4U$-2<[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@)V1I
M9V5S=&UD-2<Z#0H@("`@("`@("`@("`@("`@)&9I;&5N86UE("`]("=!=71H
M+U-!4TPO1&EG97-T340U+G!H<"<[#0H@("`@("`@("`@("`@("`@)&-L87-S
M;F%M92`]("=!=71H7U-!4TQ?1&EG97-T340U)SL-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"@T*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI9"!305-,(&UE
M8VAA;FES;2!T>7!E)RD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@('T-"@T*("`@("`@("!R97%U:7)E7V]N8V4H)&9I;&5N86UE*3L-"B`@
M("`@("`@<F5T=7)N(&YE=R`D8VQA<W-N86UE*"D[#0H@("`@?0T*?0T*#0H_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T-A8VAE+P``````````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`Q-C,T-@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+P``````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-38`,#(P,C<P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H
M92]#;VYT86EN97(O9&(N<&AP````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R,C,S,``Q,#4Q-30S,3`U-@`P,C$S-C,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@
M56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/B`@("`@("`@("`@("`@
M('P*+R\@?"`@("`@("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&1B+G!H<"QV(#$N-2`R
M,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)T1"
M+G!H<"<["G)E<75I<F5?;VYC92`G0V%C:&4O0V]N=&%I;F5R+G!H<"<["@HO
M*BH**B!014%2+T1"($-A8VAE($-O;G1A:6YE<BX**@HJ(%=!4DY)3D<Z($]T
M:&5R('-Y<W1E;7,@;6EG:'0@;W(@;6EG:'0@;F]T('-U<'!O<G0@8V5R=&%I
M;B!D871A='EP97,@;V8**B!T:&4@=&%B;&5S('-H;W=N+B!!<R!F87(@87,@
M22!K;F]W('1H97)E)W,@;F\@;&%R9V4@8FEN87)Y"BH@='EP92!I;B!344PM
M.3(@;W(@4U%,+3DY+B!0;W-T9W)E<R!S965M<R!T;R!L86-K(&%N>0HJ($),
M3T(@;W(@5$585"!T>7!E+"!F;W(@35,M4U%,('EO=2!C;W5L9"!U<V4@24U!
M1T4L(&1O;B=T(&MN;W<**B!A8F]U="!O=&AE<B!D871A8F%S97,N(%!L96%S
M92!A9&0@<W5G97-T:6]N<R!F;W(@;W1H97(@9&%T86)A<V5S('1O"BH@=&AE
M(&EN;&EN92!D;V-S+@HJ"BH@5&AE(&9I96QD("=C:&%N9V5D)R!H87,@;F\@
M;65A;FEN9R!F;W(@=&AE($-A8VAE(&ET<V5L9BX@270G<R!J=7-T('1H97)E
M"BH@8F5C875S92!I="=S(&$@9V]O9"!I9&5A('1O(&AA=F4@86X@875T;VUA
M=&EC86QL>2!U<&1A=&5D('1I;65S=&%M<`HJ(&9I96QD(&9O<B!D96)U9V=I
M;F<@:6X@86QL(&]F('EO=7(@=&%B;&5S+@HJ"BH@1F]R(%]->5-13%\@>6]U
M(&YE960@=&AI<R!$0B!T86)L93H**@HJ($-214%412!404),12!C86-H92`H
M"BH@("!I9"`@("`@("`@("!#2$%2*#,R*2!.3U0@3E5,3"!$149!54Q4("<G
M+`HJ("`@8V%C:&5G<F]U<"`@5D%20TA!4B@Q,C<I($Y/5"!.54Q,($1%1D%5
M3%0@)R<L"BH@("!C86-H961A=&$@("!"3$]"($Y/5"!.54Q,($1%1D%53%0@
M)R<L"BH@("!U<V5R9&%T82`@("!605)#2$%2*#(U-2D@3D]4($Y53$P@1$5&
M055,("<G+`HJ("`@97AP:7)E<R`@("`@24Y4*#DI($Y/5"!.54Q,($1%1D%5
M3%0@,"P**@HJ("`@8VAA;F=E9"`@("`@5$E-15-404U0*#$T*2!.3U0@3E5,
M3"P**@HJ("`@24Y$15@@*&5X<&ER97,I+`HJ("`@4%))34%262!+15D@*&ED
M+"!C86-H96=R;W5P*0HJ("D**@HJ($!A=71H;W(@("!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X**B!`=F5R<VEO;B`@
M)$ED.B!D8BYP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@
M)`HJ($!P86-K86=E("!#86-H90HJ+PIC;&%S<R!#86-H95]#;VYT86EN97)?
M9&(@97AT96YD<R!#86-H95]#;VYT86EN97(@>PH*("`@("\J*@H@("`@*B!.
M86UE(&]F('1H92!$0B!T86)L92!T;R!S=&]R92!C86-H:6YG(&1A=&$*("`@
M("H*("`@("H@0'-E92`@0V%C:&5?0V]N=&%I;F5R7V9I;&4Z.B1F:6QE;F%M
M95]P<F5F:7@*("`@("HO"B`@("!V87(@)&-A8VAE7W1A8FQE(#T@)R<["@H@
M("`@+RHJ"B`@("`J(%!%05(@1$(@9'-N('1O('5S92X*("`@("H*("`@("H@
M0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1D<VX@/2`G)SL*"B`@("`O
M*BH*("`@("H@4$5!4B!$0B!O8FIE8W0*("`@("H*("`@("H@0'9A<B`@;V)J
M96-T(%!%05)?1$(*("`@("HO"B`@("!V87(@)&1B.PH*("`@(&9U;F-T:6]N
M($-A8VAE7T-O;G1A:6YE<E]D8B@D;W!T:6]N<RD*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1O<'1I;VYS*2!\?"`A:7-S970H)&]P=&EO;G-;)V1S
M;B==*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=.
M;R!D<VX@<W!E8VEF:65D(2<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@(&%R
M<F%Y7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P=&EO;G,L(&%R<F%Y*"=D<VXG
M+"`G8V%C:&5?=&%B;&4G*2DI.PH*("`@("`@("!I9B`H(21T:&ES+3YD<VXI
M"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TYO(&1S;B!S
M<&5C:69I960A)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@)'1H
M:7,M/F1B(#T@1$(Z.F-O;FYE8W0H)'1H:7,M/F1S;BP@=')U92D["B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1T:&ES+3YD8BDI('L*("`@("`@("`@("`@
M<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.F-O;FYE8W0@9F%I;&5D.B`G
M("X@1$(Z.F5R<F]R365S<V%G92@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YD
M8BT^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*0H@("`@
M>PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(E-%3$5#5"!C86-H961A=&$L
M('5S97)D871A+"!E>'!I<F5S($923TT@)7,@5TA%4D4@:60@/2`G)7,G($%.
M1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A
M9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@("`@("`@("D[
M"@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1"
M.CIE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@
M("`@("`@("1R;W<@/2`D<F5S+3YF971C:%)O=R@I.PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D<F]W*2D*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@D<F]W
M6R=E>'!I<F5S)UTL("1T:&ES+3YD96-O9&4H)')O=ULG8V%C:&5D871A)UTI
M+"`D<F]W6R=U<V5R9&%T82==*3L*("`@("`@("!E;'-E"B`@("`@("`@("`@
M("1D871A(#T@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["@H@("`@("`@("\O
M(&QA<W0@=7-E9"!R97%U:7)E9"!B>2!T:&4@9V%R8F%G92!C;VQL96-T:6]N
M"B`@("`@("`@+R\@5T%23DE.1SH@;6EG:'0@8F4@37E344P@<W!E8VEF:6,*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*")54$1!5$4@)7,@4T54(&-H86YG
M960@/2`H3D]7*"D@*R`P*2!72$5212!I9"`]("<E<R<@04Y$(&-A8VAE9W)O
M=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D
M9'-L87-H97,H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D
M9'-L87-H97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@("`@("`@("`@("D[
M"@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1"
M.CIE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@
M("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("H@4W1O
M<F5S(&$@9&%T87-E="X*("`@("H*("`@("H@5T%23DE.1SH@=V4@=7-E('1H
M92!344P@8V]M;6%N9"!215!,04-%($E.5$\@=&AI<R!M:6=H="!B90H@("`@
M*B!->5-13"!S<&5C:69I8RX@07,@37E344P@:7,@=F5R>2!P;W!U;&%R('1H
M92!M971H;V0@<VAO=6QD"B`@("`J('=O<FL@9FEN92!F;W(@.34E(&]F('EO
M=2X*("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I
M<F5S+"`D9W)O=7`L("1U<V5R9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^
M9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@B4D503$%#12!)3E1/("5S("AU<V5R9&%T82P@8V%C:&5D871A
M+"!E>'!I<F5S+"!I9"P@8V%C:&5G<F]U<"D@5D%,5453("@G)7,G+"`G)7,G
M+"`E9"P@)R5S)RP@)R5S)RDB+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M861D<VQA<VAE<R@D=7-E<F1A=&$I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@861D<VQA<VAE<R@D=&AI<RT^96YC;V1E*"1D871A*2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$5X<&ER97-!8G-O;'5T92@D
M97AP:7)E<RD@+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE
M<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D
M9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("1R
M97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A
M8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D.B`G("X@1$(Z.F5R<F]R365S
M<V%G92@D<F5S*2`L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(')E;6]V92@D:60L("1G<F]U<"D*("`@('L*
M("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($923TT@)7,@5TA%4D4@
M:60@/2`G)7,G(&%N9"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH
M)'%U97)Y*3L*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*0H@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I
M;&5D.B`G("X@1$(Z.F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@('T*"B`@("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`@/2`G
M)RD*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@("`@
M("`@("!I9B`H)&=R;W5P*2!["B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H(D1%3$5412!&4D]-("5S(%=(15)%(&-A8VAE9W)O=7`@/2`G)7,G(BP@
M)'1H:7,M/F-A8VAE7W1A8FQE+"!A9&1S;&%S:&5S*"1G<F]U<"DI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(D1%
M3$5412!&4D]-("5S(BP@)'1H:7,M/F-A8VAE7W1A8FQE*3L*("`@("`@("!]
M"@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1"
M.CIE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@:61%>&ES=',H)&ED+"`D9W)O=7`I"B`@("![
M"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4T5,14-4(&ED($923TT@)7,@
M5TA%4D4@240@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@
M("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^
M<75E<GDH)'%U97)Y*3L*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I
M*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ<75E
M<GD@9F%I;&5D.B`G("X@1$(Z.F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*"B`@("`@("`@)')O=R`]("1R97,M/F9E=&-H4F]W
M*"D["@H@("`@("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=A
M<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92D*("`@('L*("`@("`@("`D
M=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H)T1%3$5412!&4D]-("5S(%=(15)%("AE>'!I<F5S(#P]("5D($%.1"!E
M>'!I<F5S(#X@,"D@3U(@8VAA;F=E9"`\/2`E9"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("!T:6UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("!T
M:6UE*"D@+2`D;6%X;&EF971I;64*("`@("`@("`@("`@("`@("`@("`@("`I
M.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=S96QE8W0@<W5M*&QE;F=T:"AC
M86-H961A=&$I*2!A<R!#86-H95-I>F4@9G)O;2`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@("1C86-H97-I>F4@/2`D=&AI<RT^9&(M
M/D=E=$]N92@D<75E<GDI.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D8V%C
M:&5S:7IE*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=$0CHZ<75E<GD@9F%I;&5D.B`G("X@1$(Z.F5R<F]R365S<V%G92@D8V%C
M:&5S:7IE*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@("\O:68@8V%C:&4@:7,@=&\@8FEG+@H@("`@("`@(&EF("@D8V%C:&5S
M:7IE(#X@)'1H:7,M/FAI9VAW871E<BD*("`@("`@("!["B`@("`@("`@("`@
M("\O9FEN9"!T:&4@;&]W=V%T97(@;6%R:RX*("`@("`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G<V5L96-T(&QE;F=T:"AC86-H961A=&$I(&%S('-I>F4L
M(&-H86YG960@9G)O;2`E<R!O<F1E<B!B>2!C:&%N9V5D($1%4T,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D.B`G("X@1$(Z
M.F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&YU;7)O=W,@/2`D=&AI<RT^9&(M
M/FYU;5)O=W,H)')E<RD["B`@("`@("`@("`@("1K965P7W-I>F4@/2`P.PH@
M("`@("`@("`@("!W:&EL92`H)&ME97!?<VEZ92`\("1T:&ES+3YL;W=W871E
M<B`F)B`D;G5M<F]W<RTM*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2`D
M<F5S+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@("`@
M("`@("`@)&ME97!?<VEZ92`K/2`D96YT<GE;)W-I>F4G73L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R]D96QE=&4@86QL(&5N=')I97,L('=H:6-H
M('=E<F4@8VAA;F=E9"!B969O<F4@=&AE(")L;W=W=V%T97(@;6%R:R(*("`@
M("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G9&5L971E(&9R;VT@)7,@=VAE
M<F4@8VAA;F=E9"`\/2`G+B@D96YT<GE;)V-H86YG960G72`_("1E;G1R>5LG
M8VAA;F=E9"==(#H@,"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M
M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@('T*"B`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C
M:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S
M86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M('T*"GT*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+VUD8BYP:'``
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S,R,30`,3`U,34T,S$P
M-38`,#(Q-30S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%!%05(@.CH@0V%C:&4@.CH@341"($-O;G1A:6YE<B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@
M5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@
M("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($YO=&4Z(%1H:7,@:7,@82!-1$(M;W)I96YT960@
M<F5W<FET92!O9B!#86-H92]#;VYT86EN97(O9&(N<&AP+B`@("`@('P*+R\@
M?"!4:&%N:W,@=&\@3'5K87,@4VUI=&@@9F]R(&AI<R!P871I96YC92!I;B!A
M;G-W97)I;F<@;7D@<75E<W1I;VYS("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@3&]R96YZ;R!!;&)E<G1O;B`\
M;"YA;&)E<G1O;B!A="!Q=6EP;RYI=#X@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@;61B
M+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"@IR97%U
M:7)E7V]N8V4@)TU$0BYP:'`G.PIR97%U:7)E7V]N8V4@)T-A8VAE+T-O;G1A
M:6YE<BYP:'`G.PH*+RHJ"BH@4$5!4B]-1$(@0V%C:&4@0V]N=&%I;F5R+@HJ
M"BH@3D(Z(%1H92!F:65L9"`G8VAA;F=E9"<@:&%S(&YO(&UE86YI;F<@9F]R
M('1H92!#86-H92!I='-E;&8N($ET)W,@:G5S="!T:&5R90HJ(&)E8V%U<V4@
M:70G<R!A(&=O;V0@:61E82!T;R!H879E(&%N(&%U=&]M871I8V%L;'D@=7!D
M871E9"!T:6UE<W1A;7`**B!F:65L9"!F;W(@9&5B=6=G:6YG(&EN(&%L;"!O
M9B!Y;W5R('1A8FQE<RX**@HJ($$@6$U,($U$0BUC;VUP;&EA;G0@<V-H96UA
M(&5X86UP;&4@9F]R('1H92!T86)L92!N965D960@:7,@<')O=FED960N"BH@
M3&]O:R!A="!T:&4@9FEL92`B;61B7V-A8VAE7W-C:&5M82YX;6PB(&9O<B!T
M:&%T+@HJ"BH@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM"BH@02!B87-I8R!U<V%G92!E>&%M<&QE.@HJ("TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HJ"BH@)&1B:6YF;R`]
M(&%R<F%Y*`HJ("`@)V1A=&%B87-E)R`@("`]/B`G9&)N86UE)RP**B`@("=P
M:'!T>7!E)R`@("`@/3X@)VUY<W%L)RP**B`@("=U<V5R;F%M92<@("`@/3X@
M)W)O;W0G+`HJ("`@)W!A<W-W;W)D)R`@("`]/B`G)RP**B`@("=C86-H95]T
M86)L92<@/3X@)V-A8VAE)PHJ("D["BH**@HJ("1C86-H92`](&YE=R!#86-H
M92@G;61B)RP@)&1B:6YF;RD["BH@)&ED(#T@)&-A8VAE+3YG96YE<F%T94E$
M*"=T97-T96YT<GDG*3L**@HJ(&EF("@D9&%T82`]("1C86-H92T^9V5T*"1I
M9"DI('L**B`@("!E8VAO("=#86-H92!H:70N/&)R("\^1&%T83H@)RXD9&%T
M83L**@HJ('T@96QS92!["BH@("`D9&%T82`]("=D871A(&]F(&%N>2!K:6YD
M)SL**B`@("1C86-H92T^<V%V92@D:60L("1D871A*3L**B`@(&5C:&\@)T-A
M8VAE(&UI<W,N/&)R("\^)SL**B!]"BH**B`M+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T**@HJ($!A=71H;W(@("!,;W)E;GIO
M($%L8F5R=&]N(#QL+F%L8F5R=&]N(&%T('%U:7!O+FET/@HJ($!V97)S:6]N
M("`D260Z(&UD8BYP:'`L=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%
M>'`@)`HJ($!P86-K86=E("!#86-H90HJ+PIC;&%S<R!#86-H95]#;VYT86EN
M97)?;61B(&5X=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*"B`@("`O*BH*("`@
M("`J($YA;64@;V8@=&AE($U$0B!T86)L92!T;R!S=&]R92!C86-H:6YG(&1A
M=&$*("`@("`J"B`@("`@*B!`<V5E("!#86-H95]#;VYT86EN97)?9FEL93HZ
M)&9I;&5N86UE7W!R969I>`H@("`@("HO"B`@("!V87(@)&-A8VAE7W1A8FQE
M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!014%2($U$0B!O8FIE8W0*("`@("`J
M"B`@("`@*B!`=F%R("!O8FIE8W0@4$5!4E]-1$(*("`@("`J+PH@("`@=F%R
M("1D8CL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D($%R<F%Y('=I=&@@8V]N;F5C=&EO;B!I;F9O(&]R
M(&1S;B!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I
M;F5R7VUD8B@D;W!T:6]N<RD*("`@('L*("`@("`@("`D=&AI<RT^9&(@/2`F
M341".CI#;VYN96-T*"1O<'1I;VYS*3L*("`@("`@("!I9BA-1$(Z.FES17)R
M;W(H)'1H:7,M/F1B*2D@>PH@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?
M17)R;W(H)TU$0CHZ8V]N;F5C="!F86EL960Z("<*("`@("`@("`@("`@("`@
M("`@("`N("1T:&ES+3YD8BT^9V5T365S<V%G92@I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YD
M8BT^<V5T1F5T8VA-;V1E*$U$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@87)R87E?
M;65R9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9'-N)RP@)V-A8VAE
M7W1A8FQE)RDI*3L*("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H(&EN('1H
M92!D8B!T:&4@9&%T82!T:&%T(&UA=&-H97,@:6YP=70@<&%R86UE=&5R<PH@
M("`@("H*("`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@
M("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`@*B!`<F5T
M=7)N("`@;6EX960@("!D871A<V5T('9A;'5E(&]R($Y53$PO0V%C:&5?17)R
M;W(@;VX@9F%I;'5R90H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D*("`@('L*("`@("`@
M("`D<75E<GD@/2`G4T5,14-4(&-A8VAE9&%T82!&4D]-("<@+B`D=&AI<RT^
M8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("XG(%=(15)%(&ED/2<@("`@
M("`@+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D:60I"B`@("`@("`@("`@
M("`@("`N)R!!3D0@8V%C:&5G<F]U<#TG("X@)'1H:7,M/F1B+3YG971497AT
M5F%L=64H)&=R;W5P*3L*("`@("`@("!I9B@D<F5S(#T@)'1H:7,M/F1B+3YQ
M=65R>2@D<75E<GDI*2!["B`@("`@("`@("`@(&EF*"1T:&ES+3YD8BT^96YD
M3V9297-U;'0H)')E<RDI('L*("`@("`@("`@("`@("`@("\O;F\@<F]W<R!R
M971U<FYE9`H@("`@("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,+"!.
M54Q,+"!.54Q,*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1C;&]B(#T@)'1H:7,M/F1B+3YF971C:$-L;V(H)')E<RPP+"=C86-H
M961A=&$G*3L*("`@("`@("`@("`@("`@(&EF*"%-1$(Z.FES17)R;W(H)&-L
M;V(I*2!["B`@("`@("`@("`@("`@("`@("`@)&-A8VAE9%]D871A(#T@)R<[
M"B`@("`@("`@("`@("`@("`@("`@=VAI;&4H(21T:&ES+3YD8BT^96YD3V9,
M3T(H)&-L;V(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF*$U$0CHZ
M:7-%<G)O<B@D97)R;W(@/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^9&(M/G)E861,;V(H)&-L;V(L)&1A=&$L.#`P,"D\
M,"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!N97<@
M0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)&5R<F]R+3YG971-97-S86=E
M*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&-A8VAE9%]D871A("X]
M("1D871A.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D9&%T82D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F1B+3YD97-T<F]Y3&]B*"1C;&]B*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^9&(M/F9R965297-U;'0H)')E<RD["@H@("`@("`@("`@("`@("`@
M("`@("\O9FEN:7-H960@9F5T8VAI;F<@3$]"+"!N;W<@9F5T8V@@;W1H97(@
M9FEE;&1S+BXN"B`@("`@("`@("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#
M5"!U<V5R9&%T82P@97AP:7)E<R!&4D]-("<@+B`D=&AI<RT^8V%C:&5?=&%B
M;&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("XG(%=(15)%(&ED/2<@
M("`@("`@+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D:60I"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N)R!!3D0@8V%C:&5G<F]U<#TG("X@)'1H
M:7,M/F1B+3YG971497AT5F%L=64H)&=R;W5P*3L*("`@("`@("`@("`@("`@
M("`@("!I9B@D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R;W<@/2`D=&AI<RT^9&(M/F9E=&-H
M26YT;R@D<F5S*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1R;W<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')O=ULG97AP:7)E<R==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F1E8V]D92@D8V%C:&5D7V1A=&$I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O
M=ULG=7-E<F1A=&$G70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,+"!.
M54Q,+"!.54Q,*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A(#T@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y
M(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)&-L
M;V(M/F=E=$UE<W-A9V4H*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M9&(M/F9R965297-U;'0H)')E<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R]R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A
M:6QE9#H@)PH@("`@("`@("`@("`O+R`@("`@("`@("`N("1R97-U;'0M/F=E
M=$UE<W-A9V4H*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@
M)&1A=&$@/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@("!]"@H@
M("`@("`@("\O(&QA<W0@=7-E9"!R97%U:7)E9"!B>2!T:&4@9V%R8F%G92!C
M;VQL96-T:6]N"B`@("`@("`@)'%U97)Y(#T@)U501$%412`G("`@("`@("`@
M("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`N)R!3150@
M8VAA;F=E9#TG("`@("X@=&EM92@I"B`@("`@("`@("`@("`@("`N)R!72$52
M12!I9#TG("`@("`@("X@)'1H:7,M/F1B+3YG971497AT5F%L=64H)&ED*0H@
M("`@("`@("`@("`@("`@+B<@04Y$(&-A8VAE9W)O=7`])R`N("1T:&ES+3YD
M8BT^9V5T5&5X=%9A;'5E*"1G<F]U<"D["@H@("`@("`@("1R97,@/2`D=&AI
M<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$U$0CHZ:7-%<G)O
M<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@+B`D=&AI
M<RT^9&(M/F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@
M+RHJ"B`@("`@*B!3=&]R97,@82!D871A<V5T(&EN('1H92!D871A8F%S90H@
M("`@("H*("`@("`J($EF(&1A=&%S971?240@86QR96%D>2!E>&ES=',L(&]V
M97)W<FET92!I="!W:71H(&YE=R!D871A+`H@("`@("H@96QS92!I;G-E<G0@
M9&%T82!I;B!A(&YE=R!R96-O<F0N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@9&%T87-E="!)1`H@("`@("H@0'!A<F%M("`@(&UI>&5D("`@
M9&%T82!T;R!B92!C86-H960*("`@("`J($!P87)A;2`@("!I;G1E9V5R(&5X
M<&ER871I;VX@=&EM90H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@
M9W)O=7`*("`@("`J($!P87)A;2`@("!S=')I;F<@('5S97)D871A"B`@("`@
M*B!`86-C97-S("`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H
M)&ED+"`D9&%T82P@)&5X<&ER97,L("1G<F]U<"P@)'5S97)D871A*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D9&(["B`@("`@("`@)'1H:7,M/F9L=7-H4')E
M;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("1F:65L9',@/2!A<G)A>2@*
M("`@("`@("`@("`@)VED)R`@("`@("`@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G5'EP92<@("`]/B`G=&5X="<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G5F%L=64G("`]/B`D:60L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G2V5Y)R`@("`]/B!T<G5E"B`@("`@("`@
M("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("=U<V5R9&%T82<@(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U1Y<&4G("`@
M/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U9A
M;'5E)R`@/3X@)'5S97)D871A+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)TYU;&PG("`@/3X@*"1U<V5R9&%T82`_(&9A;'-E(#H@=')U92D*("`@
M("`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@)V5X<&ER97,G
M("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5'EP
M92<@("`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G5F%L=64G("`]/B`D=&AI<RT^9V5T17AP:7)E<T%B<V]L=71E*"1E>'!I
M<F5S*0H@("`@("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`G
M8V%C:&5G<F]U<"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G5'EP92<@("`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G5F%L=64G("`]/B`D9W)O=7`*("`@("`@("`@("`@("`@("`@
M("`@("`@*0H@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/F1B+3YR97!L86-E*"1T:&ES+3YC86-H95]T86)L92P@)&9I96QD<RD[
M"@H@("`@("`@(&EF*$U$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`O+U9A<E]$=6UP.CID:7-P;&%Y*"1R97-U;'0I.PH@("`@("`@("`@
M("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@
M)PH@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A
M9V4H)')E<W5L="DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@
M("`@("`@('5N<V5T*"1F:65L9',I.R`O+V5N9"!F:7)S="!P87)T(&]F('%U
M97)Y"B`@("`@("`@)'%U97)Y,B`]("=54$1!5$4@)R`@("X@)'1H:7,M/F-A
M8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@+B<@4T54(&-A8VAE9&%T83T_
M)PH@("`@("`@("`@("`@("`@("XG(%=(15)%(&ED/2<N("1T:&ES+3YD8BT^
M9V5T5&5X=%9A;'5E*"1I9"D["@H@("`@("`@(&EF*"@D<')E<&%R961?<75E
M<GD@/2`D=&AI<RT^9&(M/G!R97!A<F51=65R>2@D<75E<GDR*2DI('L*("`@
M("`@("`@("`@)&-H87)?;&]B(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G17)R;W(G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)U1Y<&4G(#T^("=D871A)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=$871A)R`]/B`D=&AI<RT^96YC;V1E*"1D871A*0H@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("!I9B@A341".CII
M<T5R<F]R*"1C;&]B(#T@)'1H:7,M/F1B+3YC<F5A=&5,;V(H)&-H87)?;&]B
M*2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YD8BT^<V5T4&%R86U#;&]B
M*"1P<F5P87)E9%]Q=65R>2PQ+"1C;&]B+"=C86-H961A=&$G*3L*("`@("`@
M("`@("`@("`@(&EF*$U$0CHZ:7-%<G)O<B@D97)R;W(])'1H:7,M/F1B+3YE
M>&5C=71E475E<GDH)'!R97!A<F5D7W%U97)Y*2DI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A
M:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D97)R;W(M
M/F=E=$UE<W-A9V4H*2`L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^9&(M/F1E<W1R;WE,
M;V(H)&-L;V(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@8W)E871I;VX@;V8@=&AE(&AA;F1L97(@;V)J96-T(&9A:6QE9`H@
M("`@("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ
M=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("`@("`@+B`D8VQO
M8BT^9V5T365S<V%G92@I("P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^9&(M/F9R9650<F5P87)E9%%U
M97)Y*"1P<F5P87)E9%]Q=65R>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R]P<F5P87)E9"!Q=65R>2!F86EL960*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@
M("`@("`@("`@("`@("`@("`N("1P<F5P87)E9%]Q=65R>2T^9V5T365S<V%G
M92@I("P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F5S(&$@9&%T87-E="!F<F]M('1H92!D871A
M8F%S90H@("`@("H*("`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@
M240*("`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V92@D:60L("1G<F]U<"D*("`@('L*("`@
M("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@
M("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@("`@("X@)'1H:7,M/F-A8VAE
M7W1A8FQE"B`@("`@("`@("`@("`@("`N)R!72$5212!I9#TG("`@("`@("X@
M)'1H:7,M/F1B+3YG971497AT5F%L=64H)&ED*0H@("`@("`@("`@("`@("`@
M+B<@04Y$(&-A8VAE9W)O=7`])R`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E
M*"1G<F]U<"D["@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q
M=65R>2D["B`@("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A
M:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O
M<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E(&%L;"!C86-H960@9&%T
M82!F;W(@82!C97)T86EN(&=R;W5P+"!O<B!E;7!T>0H@("`@("H@=&AE(&-A
M8VAE('1A8FQE(&EF(&YO(&=R;W5P(&ES('-P96-I9FEE9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@("HO"B`@
M("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`@/2`G)RD*("`@('L*("`@("`@("`D
M=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@("`@("`@(&EF("@D9W)O=7`I('L*
M("`@("`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@("`@("`@+B`D
M=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@("`N)R!72$52
M12!C86-H96=R;W5P/2<@+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D9W)O
M=7`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Q=65R>2`]("=$
M14Q%5$4@1E)/32`G("X@)'1H:7,M/F-A8VAE7W1A8FQE.PH@("`@("`@('T*
M"B`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@
M("`@("!I9B`H341".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E
M='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@9F%I;&5D.B`G"B`@
M("`@("`@("`@("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1R97,I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K(&EF(&$@9&%T87-E="!)1"]G<F]U<"!E>&ES=',N
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("`J($!R
M971U<FX@("!B;V]L96%N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ED17AI<W1S
M*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@("`@("1Q=65R>2`]("=314Q%0U0@
M:60@1E)/32`G("`N("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@
M("`@+B<@5TA%4D4@:60])R`@("`@("`N("1T:&ES+3YD8BT^9V5T5&5X=%9A
M;'5E*"1I9"D*("`@("`@("`@("`@("`@("XG($%.1"!C86-H96=R;W5P/2<@
M+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D9W)O=7`I.PH@("`@("`@(&5C
M:&\@)'%U97)Y.PH@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q
M=65R>2D["B`@("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A
M:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O
M<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H@("`@("`@("1R;W<@/2`D=&AI<RT^9&(M/F9E=&-H26YT;R@D<F5S*3L*
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'87)B
M86=E(&-O;&QE8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@("`@:6YT(&UA
M>&QI9F5T:6UE"B`@("`@*B\*("`@(&9U;F-T:6]N(&=A<F)A9V5#;VQL96-T
M:6]N*"1M87AL:69E=&EM92D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0
M<F5L;V%D*"D["B`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@("`@
M("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`N)R!7
M2$5212`H97AP:7)E<R`\/2`G("X@=&EM92@I"B`@("`@("`@("`@("`@("`N
M)R!!3D0@97AP:7)E<R`^(#`I($]2(&-H86YG960@/#T@)RX@=&EM92@I("T@
M)&UA>&QI9F5T:6UE.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R
M>2@D<75E<GDI.PH*("`@("`@("`D<75E<GD@/2`G4T5,14-4('-U;2AL96YG
M=&@H8V%C:&5D871A*2D@87,@0V%C:&53:7IE($923TT@)PH@("`@("`@("`@
M("`@("`@+B`D=&AI<RT^8V%C:&5?=&%B;&4["@H@("`@("`@("1C86-H97-I
M>F4@/2`D=&AI<RT^9&(M/F=E=$]N92@D<75E<GDI.PH@("`@("`@(&EF("A-
M1$(Z.FES17)R;W(H)&-A8VAE<VEZ92DI('L*("`@("`@("`@("`@<F5T=7)N
M(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@
M("`@("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)&-A8VAE
M<VEZ92DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@
M("\O:68@8V%C:&4@:7,@=&\@8FEG+@H@("`@("`@(&EF("@D8V%C:&5S:7IE
M(#X@)'1H:7,M/FAI9VAW871E<BD*("`@("`@("!["B`@("`@("`@("`@("\O
M9FEN9"!T:&4@;&]W=V%T97(@;6%R:RX*("`@("`@("`@("`@)'%U97)Y(#T@
M)U-%3$5#5"!L96YG=&@H8V%C:&5D871A*2!A<R!S:7IE+"!C:&%N9V5D($92
M3TT@)PH@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE
M("XG($]21$52($)9(&-H86YG960@1$530R<["@H@("`@("`@("`@("`D<F5S
M(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@("`@("!I9B`H
M341".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@
M("`@("`@("`@("`@+B`D=&AI<RT^9&(M/F5R<F]R365S<V%G92@D<F5S*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;G5M<F]W<R`]("1T:&ES+3YD8BT^;G5M4F]W<R@D<F5S*3L*("`@("`@
M("`@("`@)&ME97!?<VEZ92`](#`["B`@("`@("`@("`@('=H:6QE("@D:V5E
M<%]S:7IE(#P@)'1H:7,M/FQO=W=A=&5R("8F("1N=6UR;W=S+2TI('L*("`@
M("`@("`@("`@("`@("1E;G1R>2`]("1T:&ES+3YD8BT^9F5T8VA);G1O*"1R
M97,L341"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@("`@("`@("`D:V5E
M<%]S:7IE("L]("1E;G1R>5LG<VEZ92==.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+V1E;&5T92!A;&P@96YT<FEE<RP@=VAI8V@@=V5R92!C:&%N
M9V5D(&)E9F]R92!T:&4@(FQO=W=A=&5R(&UA<FLB"B`@("`@("`@("`@("1Q
M=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@
M("`@("`@("`@("`@("`@("`@+B<@5TA%4D4@8VAA;F=E9#P])RXH)&5N=')Y
M6R=C:&%N9V5D)UT@/R`D96YT<GE;)V-H86YG960G72`Z(#`I.PH*("`@("`@
M("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@
M("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@
M("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@
M)PH@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A
M9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@I]"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]F:6QE+G!H<```
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,Q-#`U`#$P-3$U-#,Q,#4V
M`#`R,3<R,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@
M;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L
M0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!F:6QE+G!H<"QV(#$N,3,@,C`P,R\P
M,R\R-R`Q,#HT.#HT,B!C:')E9W4@17AP("0*"G)E<75I<F5?;VYC92`G0V%C
M:&4O0V]N=&%I;F5R+G!H<"<["@HO*BH**B!3=&]R97,@8V%C:&4@8V]N=&5N
M=',@:6X@82!F:6QE+@HJ"BH@0&%U=&AO<B`@(%5L9B!796YD96P@(#QU;&8N
M=V5N9&5L0'!H<&1O8RYD93X**B!`=F5R<VEO;B`@)$ED.B!F:6QE+G!H<"QV
M(#$N,3,@,C`P,R\P,R\R-R`Q,#HT.#HT,B!C:')E9W4@17AP("0**B\*8VQA
M<W,@0V%C:&5?0V]N=&%I;F5R7V9I;&4@97AT96YD<R!#86-H95]#;VYT86EN
M97(@>PH*("`@("\J*@H@("`@*B!&:6QE(&QO8VMI;F<*("`@("H*("`@("H@
M5VET:"!F:6QE(&-O;G1A:6YE<BP@:70G<R!P;W-S:6)L92P@=&AA="!Y;W4@
M9V5T(&-O<G)U<'1E9`H@("`@*B!D871A+65N=')I97,@=6YD97(@8F%D(&-I
M<F-U;7-T86YC97,N(%1H92!F:6QE(&QO8VMI;F<@;75S=`H@("`@*B!I;7!R
M;W9E('1H:7,@<')O8FQE;2!B=70@:70G<R!E>'!E<FEM96YT86P@<W1U9F8N
M(%-O('1H90H@("`@*B!D969A=6QT('9A;'5E(&ES(&9A;'-E+B!"=70@:70@
M<V5E;7,@=&\@9VEV92!G;V]D(')E<W5L=',*("`@("H*("`@("H@0'9A<B!B
M;V]L96%N"B`@("`J+PH@("`@=F%R("1F:6QE3&]C:VEN9R`](&9A;'-E.PH*
M("`@("\J*@H@("`@*B!$:7)E8W1O<GD@=VAE<F4@=&\@<'5T('1H92!C86-H
M92!F:6QE<RX*("`@("H*("`@("H@0'9A<B`@<W1R:6YG("!-86ME('-U<F4@
M=&\@861D(&$@=')A:6QI;F<@<VQA<V@*("`@("HO"B`@("!V87(@)&-A8VAE
M7V1I<B`]("<G.PH*("`@("\J*@H@("`@*B!&:6QE;F%M92!P<F5F:7@@9F]R
M(&-A8VAE(&9I;&5S+@H@("`@*@H@("`@*B!9;W4@8V%N('5S92!T:&4@9FEL
M96YA;64@<')E9FEX('1O(&EM<&QE;65N="!A(")D;VUA:6XB(&)A<V5D(&-A
M8VAE(&]R(&IU<W0*("`@("H@=&\@9VEV92!T:&4@9FEL97,@82!M;W)E(&1E
M<V-R:7!T:79E(&YA;64N(%1H92!W;W)D(")D;VUA:6XB(&ES(&)O<G)O960@
M9G)O;0H@("`@*B!A('5S97(@875T:&5N=&EF:6-A=&EO;B!S>7-T96TN($]N
M92!U<V5R(&ED("AC86-H960@9&%T87-E="!W:71H('1H92!)1"!X*0H@("`@
M*B!M87D@97AI<W1S(&EN(&1I9F9E<F5N="!D;VUA:6YS("AD:69F97)E;G0@
M9FEL96YA;64@<')E9FEX*2X@66]U(&UI9VAT('=A;G0*("`@("H@=&\@=7-E
M('1H:7,@=&\@:&%V92!D:69F97)E;G0@8V%C:&4@=F%L=65S(&9O<B!A('!R
M;V1U8W1I;VXL(&1E=F5L;W!M96YT(&%N9`H@("`@*B!Q=6%L:71Y(&%S<W5R
M86YC92!S>7-T96TN($EF('EO=2!W86YT('1H92!P<F]D=6-T:6]N(&-A8VAE
M(&YO="!T;R!B92!I;F9L=65N8V5D"B`@("`J(&)Y('1H92!Q=6%L:71Y(&%S
M<W5R86YC92!A8W1I=FET:65S+"!U<V4@9&EF9F5R96YT(&9I;&5N86UE('!R
M969I>&5S(&9O<B!T:&5M+@H@("`@*@H@("`@*B!)('!E<G-O;F%L;'D@9&]N
M)W0@=&AI;FL@=&AA="!Y;W4G;&P@;F5V97(@;F5E9"!T:&ES+"!B=70@-C0P
M:V(@:&%P<&5N9"!T;R!B90H@("`@*B!N;W0@96YO=6=H+"!S;RXN+B!Y;W4@
M:VYO=R!W:&%T($D@;65A;BX@268@>6]U(&9I;F0@82!U<V5F=6P@87!P;&EC
M871I;VX@;V8@=&AE"B`@("`J(&9E871U<F4@<&QE87-E('5P9&%T92!T:&ES
M(&EN;&EN92!D;V,N"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*
M("`@('9A<B`D9FEL96YA;65?<')E9FEX(#T@)R<["B`@("`*("`@(`H@("`@
M+RHJ"B`@("`J($QI<W0@;V8@8V%C:&4@96YT<FEE<RP@=7-E9"!W:71H:6X@
M82!G8R!R=6X*("`@("H@"B`@("`J($!V87(@87)R87D*("`@("HO"B`@("!V
M87(@)&5N=')I97,["B`@("`*("`@("\J*@H@("`@*B!4;W1A;"!N=6UB97(@
M;V8@8GET97,@<F5Q=6ER960@8GD@86QL(&-A8VAE(&5N=')I97,L('5S960@
M=VET:&EN(&$@9V,@<G5N+@H@("`@*B`*("`@("H@0'9A<B`@:6YT"B`@("`J
M+PH@("`@=F%R("1T;W1A;%]S:7IE(#T@,#L*"@H@("`@+RHJ"B`@("`J($UA
M>"!,:6YE($QE;F=T:"!O9B!U<V5R9&%T80H@("`@*@H@("`@*B!)9B!S970@
M=&\@,"P@:70@=VEL;"!T86ME('1H92!D969A=6QT(`H@("`@*B`H(#$P,C0@
M:6X@<&AP(#0N,BP@=6YL:6UI=&5D(&EN('!H<"`T+C,I"B`@("`J('-E92!H
M='1P.B\O8V@N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN9F=E=',N<&AP
M"B`@("`J(&9O<B!D971A:6QS"B`@("`J"B`@("`J($!V87(@:6YT"B`@("`J
M+PH@("`@=F%R("1M87A?=7-E<F1A=&%?;&EN96QE;F=T:"`](#(U-SL*"B`@
M("`O*BH*("`@("H@0W)E871E<R!T:&4@8V%C:&4@9&ER96-T;W)Y(&EF(&YE
M8V-E<W-A<GD*("`@("H*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@0V]N9FEG
M(&]P=&EO;G,Z(%LB8V%C:&5?9&ER(B`]/B`N+BXL(")F:6QE;F%M95]P<F5F
M:7@B(#T^("XN+ET*("`@("HO"B`@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I
M;F5R7V9I;&4H)&]P=&EO;G,@/2`G)RD@>PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D;W!T:6]N<RDI"B`@("`@("`@("`@("1T:&ES+3YS971/<'1I;VYS*"1O
M<'1I;VYS+"!A<G)A>5]M97)G92@D=&AI<RT^86QL;W=E9%]O<'1I;VYS+"!A
M<G)A>2@G8V%C:&5?9&ER)RP@)V9I;&5N86UE7W!R969I>"<L("=M87A?=7-E
M<F1A=&%?;&EN96QE;F=T:"<I*2D["B`@("`@("`@"B`@("`@("`@8VQE87)S
M=&%T8V%C:&4H*3L*("`@("`@("!I9B`H)'1H:7,M/F-A8VAE7V1I<BD*("`@
M("`@("!["B`@("`@("`@("`@("\O(&UA:V4@<F5L871I=F4@<&%T:',@86)S
M;VQU=&4@9F]R('5S92!I;B!D96-O;G-T<G5C=&]R+@H@("`@("`@("`@("`O
M+R!I="!L;V]K<R!L:6ME('1H92!D96-O;G-T<G5C=&]R(&AA<R!P<F]B;&5M
M<R!W:71H(')E;&%T:79E('!A=&AS"B`@("`@("`@("`@(&EF("A/4U]53DE8
M("8F("<O)R`A/2`D=&AI<RT^8V%C:&5?9&ER>S!]("`I"B`@("`@("`@("`@
M("`@("`D=&AI<RT^8V%C:&5?9&ER(#T@<F5A;'!A=&@H(&=E=&-W9"@I("X@
M)R\G("X@)'1H:7,M/F-A8VAE7V1I<BD@+B`G+R<["@H@("`@("`@("`@("`O
M+R!C:&5C:R!I9B!A('1R86EL:6YG('-L87-H(&ES(&EN(&-A8VAE7V1I<@H@
M("`@("`@("`@("!I9B`H)'1H:7,M/F-A8VAE7V1I<GMS=')L96XH)'1H:7,M
M/F-A8VAE7V1I<BDM,7T@(3T@1$E214-43U)97U-%4$%2051/4BD*("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V%C:&5?9&ER("X]("<O)SL*"B`@("`@("`@
M("`@(&EF("`H(69I;&5?97AI<W1S*"1T:&ES+3YC86-H95]D:7(I('Q\("%I
M<U]D:7(H)'1H:7,M/F-A8VAE7V1I<BDI"B`@("`@("`@("`@("`@("!M:V1I
M<B@D=&AI<RT^8V%C:&5?9&ER+"`P-S4U*3L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/F5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YG<F]U
M<%]D:7)S(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`*("`@('T@
M+R\@96YD(&9U;F,@8V]N=')U8W1O<@H*("`@(&9U;F-T:6]N(&9E=&-H*"1I
M9"P@)&=R;W5P*2!["B`@("`@("`@)&9I;&4@/2`D=&AI<RT^9V5T1FEL96YA
M;64H)&ED+"`D9W)O=7`I.PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I
M;&4I*0H@("`@("`@("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,3"P@3E5,
M3"D["@H@("`@("`@("\O(')E=')I=F4@=&AE(&-O;G1E;G0*("`@("`@("!I
M9B`H(2@D9F@@/2!`9F]P96XH)&9I;&4L("=R8B<I*2D*("`@("`@("`@("`@
M<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@86-C97-S(&-A8VAE(&9I
M;&4@)R1F:6QE)RX@0VAE8VL@86-C97-S(')I9VAT<R!A;F0@<&%T:"XB+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`O+R!&:6QE(&QO8VMI;F<@
M*'-H87)E9"!L;V-K*0H@("`@("`@(&EF("@D=&AI<RT^9FEL94QO8VMI;F<I
M"B`@("`@("`@("`@(&9L;V-K*"1F:"P@3$]#2U]32"D["@H@("`@("`@("\O
M(&9I;&4@9F]R;6%T.@H@("`@("`@("\O(#%S="!L:6YE.B!E>'!I<F%T:6]N
M(&1A=&4*("`@("`@("`O+R`R;F0@;&EN93H@=7-E<B!D871A"B`@("`@("`@
M+R\@,W)D*R!L:6YE<SH@8V%C:&4@9&%T80H@("`@("`@("1E>'!I<F4@/2!T
M<FEM*&9G971S*"1F:"P@,3(I*3L*("`@("`@("!I9B`H)'1H:7,M/FUA>%]U
M<V5R9&%T85]L:6YE;&5N9W1H(#T](#`@*2!["B`@("`@("`@("`@("1U<V5R
M9&%T82`]('1R:6TH9F=E=',H)&9H*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'5S97)D871A(#T@=')I;2AF9V5T<R@D9F@L("1T:&ES+3YM
M87A?=7-E<F1A=&%?;&EN96QE;F=T:"DI.PH@("`@("`@('T*("`@("`@("`D
M8V%C:&5D871A(#T@)'1H:7,M/F1E8V]D92AF<F5A9"@D9F@L(&9I;&5S:7IE
M*"1F:6QE*2DI.PH*("`@("`@("`O+R!5;FQO8VMI;F<*("`@("`@("!I9B`H
M)'1H:7,M/F9I;&5,;V-K:6YG*0H@("`@("`@("`@("!F;&]C:R@D9F@L($Q/
M0TM?54XI.PH*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@+R\@;&%S
M="!U<V%G92!D871E('5S960@8GD@=&AE(&=C("T@;6%X;&EF971I;64*("`@
M("`@("`O+R!T;W5C:"!W:71H;W5T('-E8V]N9"!P87)A;2!P<F]D=6-E9"!S
M='5P:60@96YT<FEE<RXN+@H@("`@("`@('1O=6-H*"1F:6QE+'1I;64H*2D[
M"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1E>'!I<F4L("1C86-H961A=&$L("1U<V5R9&%T82D["B`@("!]("\O
M(&5N9"!F=6YC(&9E=&-H"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!A(&1A=&%S
M970N"B`@("`J"B`@("`J(%=!4DY)3D<Z($EF('EO=2!S=7!P;'D@=7-E<F1A
M=&$@:70@;75S="!N;W0@8V]N=&%I;B!A;GD@;&EN96)R96%K<RP*("`@("H@
M;W1H97)W:7-E(&ET('=I;&P@8G)E86L@=&AE(&9I;&5S=')U8W1U<F4N"B`@
M("`J+PH@("`@9G5N8W1I;VX@<V%V92@D:60L("1C86-H961A=&$L("1E>'!I
M<F5S+"`D9W)O=7`L("1U<V5R9&%T82D@>PH@("`@("`@("1T:&ES+3YF;'5S
M:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D9FEL92`]("1T:&ES
M+3YG971&:6QE;F%M92@D:60L("1G<F]U<"D["B`@("`@("`@:68@*"$H)&9H
M(#T@0&9O<&5N*"1F:6QE+"`G=V(G*2DI"B`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H(D-A;B=T(&%C8V5S<R`G)&9I;&4G('1O('-T;W)E
M(&-A8VAE(&1A=&$N($-H96-K(&%C8V5S<R!R:6=H=',@86YD('!A=&@N(BP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@+R\@1FEL92!L;V-K:6YG
M("AE>&-L=7-I=F4@;&]C:RD*("`@("`@("!I9B`H)'1H:7,M/F9I;&5,;V-K
M:6YG*0H@("`@("`@("`@("!F;&]C:R@D9F@L($Q/0TM?15@I.PH*("`@("`@
M("`O+R!F:6QE(&9O<FUA=#H*("`@("`@("`O+R`Q<W0@;&EN93H@97AP:7)A
M=&EO;B!D871E"B`@("`@("`@+R\@,FYD(&QI;F4Z('5S97(@9&%T80H@("`@
M("`@("\O(#-R9"L@;&EN97,Z(&-A8VAE(&1A=&$*("`@("`@("`D97AP:7)E
M<R`]("1T:&ES+3YG971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I.PH@("`@
M("`@(&9W<FET92@D9F@L("1E>'!I<F5S("X@(EQN(BD["B`@("`@("`@9G=R
M:71E*"1F:"P@)'5S97)D871A("X@(EQN(BD["B`@("`@("`@9G=R:71E*"1F
M:"P@)'1H:7,M/F5N8V]D92@D8V%C:&5D871A*2D["@H@("`@("`@("\O($9I
M;&4@=6YL;V-K:6YG"B`@("`@("`@:68@*"1T:&ES+3YF:6QE3&]C:VEN9RD*
M("`@("`@("`@("`@9FQO8VLH)&9H+"!,3T-+7U5.*3L*"B`@("`@("`@9F-L
M;W-E*"1F:"D["@H@("`@("`@("\O($DG;2!N;W0@<W5R92!I9B!W92!N965D
M('1H:7,*"2\O(&D@9&]N)W0@=&AI;FL@=V4@;F5E9"!T:&ES("AC:')E9W4I
M"B`@("`@("`@+R\@=&]U8V@H)&9I;&4I.PH*("`@("`@("!R971U<FX@=')U
M93L*("`@('T@+R\@96YD(&9U;F,@<V%V90H*("`@(&9U;F-T:6]N(')E;6]V
M92@D:60L("1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H
M)&ED+"`D9W)O=7`I.PH*("`@("`@("`D9FEL92`]("1T:&ES+3YG971&:6QE
M;F%M92@D:60L("1G<F]U<"D["B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F
M:6QE*2D@>PH*("`@("`@("`@("`@)&]K(#T@=6YL:6YK*"1F:6QE*3L*("`@
M("`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*"B`@("`@("`@("`@(')E='5R
M;B`D;VL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M("\O(&5N9"!F=6YC(')E;6]V90H*("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U
M<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*("`@("`@("`D
M9&ER(#T@*"1G<F]U<"D@/R`D=&AI<RT^8V%C:&5?9&ER("X@)&=R;W5P("X@
M)R\G(#H@)'1H:7,M/F-A8VAE7V1I<CL*"B`@("`@("`@)&YU;5]R96UO=F5D
M(#T@)'1H:7,M/F1E;&5T941I<B@D9&ER*3L*("`@("`@("!U;G-E="@D=&AI
M<RT^9W)O=7!?9&ER<ULD9W)O=7!=*3L*("`@("`@("!C;&5A<G-T871C86-H
M92@I.PH*("`@("`@("!R971U<FX@)&YU;5]R96UO=F5D.PH@("`@?2`O+R!E
M;F0@9G5N8R!F;'5S:`H*("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@)&=R
M;W5P*2!["@H@("`@("`@(')E='5R;B!F:6QE7V5X:7-T<R@D=&AI<RT^9V5T
M1FEL96YA;64H)&ED+"`D9W)O=7`I*3L*("`@('T@+R\@96YD(&9U;F,@:61%
M>&ES=',*"B`@("`O*BH*("`@("H@1&5L971E<R!A;&P@97AP:7)E9"!F:6QE
M<RX*("`@("H*("`@("H@1V%R8F%G92!C;VQL96-T:6]N(&9O<B!F:6QE<R!I
M<R!A(')A=&AE<B`B97AP96YS:79E(BP@(FQO;F<@=&EM92(*("`@("H@;W!E
M<F%T:6]N+B!!;&P@9FEL97,@:6X@=&AE(&-A8VAE(&1I<F5C=&]R>2!H879E
M('1O(&)E(&5X86UI;F5D('=H:6-H"B`@("`J(&UE86YS('1H870@=&AE>2!M
M=7-T(&)E(&]P96YE9"!F;W(@<F5A9&EN9RP@=&AE(&5X<&ER871I;VX@9&%T
M92!H87,@=&\@8F4*("`@("H@<F5A9"!F<F]M('1H96T@86YD(&EF(&YE8V-E
M<W-A<GD@=&AE>2!H879E('1O(&)E('5N;&EN:V5D("AR96UO=F5D*2X*("`@
M("H@268@>6]U(&AA=F4@82!U<V5R(&-O;6UE;G0@9F]R(&$@9V]O9"!D969A
M=6QT(&=C('!R;V)A8FEL:71Y('!L96%S92!A9&0@:70@=&\*("`@("H@=&\@
M=&AE(&EN;&EN92!D;V-S+@H@("`@*@H@("`@*B!`<&%R86T@("`@:6YT96=E
M<B!-87AI;75M(&QI9F5T:6UE(&EN('-E8V]N9',@;V8@86X@;F\@;&]N9V5R
M('5S960O=&]U8VAE9"!E;G1R>0H@("`@*B!`=&AR;W=S("`@0V%C:&5?17)R
M;W(*("`@("HO"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO;B@D;6%X
M;&EF971I;64I('L*"B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@
M("`@("`@(&-L96%R<W1A=&-A8VAE*"D["@H@("`@("`@("1O:R`]("1T:&ES
M+3YD;T=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92P@)'1H:7,M/F-A
M8VAE7V1I<BD["@H@("`@("`@("\O(&-H96-K('1H92!S<&%C92!U<V5D(&)Y
M('1H92!C86-H92!E;G1R:65S("`@("`@("`*("`@("`@("!I9B`H)'1H:7,M
M/G1O=&%L7W-I>F4@/B`D=&AI<RT^:&EG:'=A=&5R*2!["B`@("`@("`@"B`@
M("`@("`@("`@(&MR<V]R="@D=&AI<RT^96YT<FEE<RD["B`@("`@("`@("`@
M(')E<V5T*"1T:&ES+3YE;G1R:65S*3L*("`@("`@("`@("`@"B`@("`@("`@
M("`@('=H:6QE("@D=&AI<RT^=&]T86Q?<VEZ92`^("1T:&ES+3YL;W=W871E
M<B`F)B!L:7-T*"1L87-T;6]D+"`D96YT<GDI(#T@96%C:"@D=&AI<RT^96YT
M<FEE<RDI('L*("`@("`@("`@("`@("`@(&EF("A`=6YL:6YK*"1E;G1R>5LG
M9FEL92==*2D*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=&]T86Q?<VEZ
M92`M/2`D96YT<GE;)W-I>F4G73L*("`@("`@("`@("`@("`@(&5L<V4*("`@
M("`@("`@("`@("`@("`@("!N97<@0V%C:&5%<G)O<B@B0V%N)W0@9&5L971E
M('LD96YT<GE;(F9I;&4B77TN($-H96-K('1H92!P97)M:7-S:6]N<RXB*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("!]"B`@("`@("`@
M"B`@("`@("`@)'1H:7,M/F5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3YT;W1A;%]S:7IE(#T@,#L*("`@("`@("`*("`@("`@("!R971U<FX@
M)&]K.PH@("`@?2`O+R!E;F0@9G5N8R!G87)B86=E0V]L;&5C=&EO;@H@("`@
M"B`@("`O*BH*("`@("H@1&]E<R!T:&4@<F5C=7)S:79E(&=C('!R;V-E9'5R
M92P@<')O=&5C=&5D+@H@("`@*@H@("`@*B!`<&%R86T@("`@:6YT96=E<B!-
M87AI;75M(&QI9F5T:6UE(&EN('-E8V]N9',@;V8@86X@;F\@;&]N9V5R('5S
M960O=&]U8VAE9"!E;G1R>0H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D:7)E
M8W1O<GD@=&\@97AA;6EN92`M(&1O;B=T('-E=',@=&AI<R!P87)A;65T97(L
M(&ET)W,@=7-E9"!F;W(@80H@("`@*B`@("`@("`@("`@("`@("`@("!R96-U
M<G-I=F4@9G5N8W1I;VX@8V%L;"$*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R
M<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@9&]'87)B86=E0V]L;&5C=&EO;B@D
M;6%X;&EF971I;64L("1D:7(I('L*("`@("`@("`@("`*("`@("`@("!I9B`H
M(2@D9&@@/2!O<&5N9&ER*"1D:7(I*2D*("`@("`@("`@("`@<F5T=7)N(&YE
M=R!#86-H95]%<G)O<B@B0V%N)W0@86-C97-S(&-A8VAE(&1I<F5C=&]R>2`G
M)&1I<B<N($-H96-K('!E<FUI<W-I;VYS(&%N9"!P871H+B(L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@('=H:6QE("@D9FEL92`](')E861D:7(H
M)&1H*2D@>PH@("`@("`@("`@("!I9B`H)RXG(#T]("1F:6QE('Q\("<N+B<@
M/3T@)&9I;&4I"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*"B`@("`@("`@
M("`@("1F:6QE(#T@)&1I<B`N("1F:6QE.PH@("`@("`@("`@("!I9B`H:7-?
M9&ER*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1O1V%R8F%G
M94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE+"1F:6QE("X@)R\G*3L*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!S:VEP('1R;W5B;&4@;6%K97)S(&)U="!I;F9O<FT@=&AE('5S97(*
M("`@("`@("`@("`@:68@*"$H)&9H(#T@0&9O<&5N*"1F:6QE+"`G<F(G*2DI
M('L*("`@("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@86-C
M97-S(&-A8VAE(&9I;&4@)R1F:6QE)RP@<VMI<'!I;F<@:70N($-H96-K('!E
M<FUI<W-I;VYS(&%N9"!P871H+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&5X<&ER92`](&9G971S*"1F:"P@,3$I.PH@("`@("`@("`@("!F
M8VQO<V4H)&9H*3L*("`@("`@("`@("`@)&QA<W1U<V5D(#T@9FEL96UT:6UE
M*"1F:6QE*3L*("`@("`@("`@("`@"B`@("`@("`@("`@("1T:&ES+3YE;G1R
M:65S6R1L87-T=7-E9%T@/2!A<G)A>2@G9FEL92<@/3X@)&9I;&4L("=S:7IE
M)R`]/B!F:6QE<VEZ92@D9FEL92DI.PH@("`@("`@("`@("`D=&AI<RT^=&]T
M86Q?<VEZ92`K/2!F:6QE<VEZ92@D9FEL92D["B`@("`@("`@("`@(`H@("`@
M("`@("`@("`O+R!R96UO=F4@:68@97AP:7)E9`H@("`@("`@("`@("!I9B`H
M*"`H)&5X<&ER92`F)B`D97AP:7)E(#P]('1I;64H*2D@?'P@*"1L87-T=7-E
M9"`\/2`H=&EM92@I("T@)&UA>&QI9F5T:6UE*2D@*2`F)B`A=6YL:6YK*"1F
M:6QE*2D*("`@("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@
M=6YL:6YK(&-A8VAE(&9I;&4@)R1F:6QE)RP@<VMI<'!I;F<N($-H96-K('!E
M<FUI<W-I;VYS(&%N9"!P871H+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H*("`@("`@("!C;&]S961I<B@D9&@I.PH*("`@("`@("`O+R!F
M;'5S:"!T:&4@9&ES:R!S=&%T92!C86-H90H@("`@("`@(&-L96%R<W1A=&-A
M8VAE*"D["@H@("`@?2`O+R!E;F0@9G5N8R!D;T=A<F)A9V5#;VQL96-T:6]N
M"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(&9I;&5N86UE(&9O<B!T:&4@
M<W!E8VEF:65D(&ED+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D
M871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P
M"B`@("`J($!R971U<FX@("!S=')I;F<@(&9U;&P@9FEL96YA;64@=VET:"!T
M:&4@<&%T:`H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1FEL96YA;64H)&ED+"`D9W)O=7`I('L*"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YG<F]U<%]D:7)S6R1G<F]U<%TI*0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F=R;W5P7V1I<G-;)&=R;W5P72`N("1T:&ES+3YF
M:6QE;F%M95]P<F5F:7@@+B`D:60["@H@("`@("`@("1D:7(@/2`D=&AI<RT^
M8V%C:&5?9&ER("X@)&=R;W5P("X@)R\G.PH@("`@("`@(&EF("@A9FEL95]E
M>&ES=',H)&1I<BDI('L*("`@("`@("`@("`@;6MD:7(H)&1I<BP@,#<U-2D[
M"B`@("`@("`@("`@(&-L96%R<W1A=&-A8VAE*"D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^9W)O=7!?9&ER<ULD9W)O=7!=(#T@)&1I<CL*"B`@("`@
M("`@<F5T=7)N("1D:7(@+B`D=&AI<RT^9FEL96YA;65?<')E9FEX("X@)&ED
M.PH@("`@?2`O+R!E;F0@9G5N8R!G971&:6QE;F%M90H*("`@("\J*@H@("`@
M*B!$96QE=&5S(&$@9&ER96-T;W)Y(&%N9"!A;&P@9FEL97,@:6X@:70N"B`@
M("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1I<F5C=&]R>0H@("`@*B!`
M<F5T=7)N("`@:6YT96=E<B!N=6UB97(@;V8@<F5M;W9E9"!F:6QE<PH@("`@
M*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*("`@("HO"B`@("!F=6YC=&EO;B!D
M96QE=&5$:7(H)&1I<BD@>PH@("`@("`@(&EF("@A*"1D:"`](&]P96YD:7(H
M)&1I<BDI*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#
M86XG="!R96UO=F4@9&ER96-T;W)Y("<D9&ER)RX@0VAE8VL@<&5R;6ES<VEO
M;G,@86YD('!A=&@N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M)&YU;5]R96UO=F5D(#T@,#L*"B`@("`@("`@=VAI;&4@*&9A;'-E("$]/2`D
M9FEL92`](')E861D:7(H)&1H*2D@>PH@("`@("`@("`@("!I9B`H)RXG(#T]
M("1F:6QE('Q\("<N+B<@/3T@)&9I;&4I"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*"B`@("`@("`@("`@("1F:6QE(#T@)&1I<B`N("1F:6QE.PH@("`@
M("`@("`@("!I9B`H:7-?9&ER*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@
M)&9I;&4@+CT@)R\G.PH@("`@("`@("`@("`@("`@)&YU;2`]("1T:&ES+3YD
M96QE=&5$:7(H)&9I;&4@+B`G+R<I.PH@("`@("`@("`@("`@("`@:68@*&ES
M7VEN="@D;G5M*2D*("`@("`@("`@("`@("`@("`@("`D;G5M7W)E;6]V960@
M*ST@)&YU;3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&EF("AU;FQI;FLH)&9I;&4I*0H@("`@("`@("`@("`@("`@("`@("1N=6U?
M<F5M;W9E9"LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O
M(&%C8V]R9&EN9R!T;R!P:'`M;6%N=6%L('1H92!F;VQL;W=I;F<@:7,@;F5E
M9&5D(&9O<B!W:6YD;W=S(&EN<W1A;&QA=&EO;G,N"B`@("`@("`@8VQO<V5D
M:7(H)&1H*3L*("`@("`@("!U;G-E="@@)&1H*3L*("`@("`@("!I9B`H)&1I
M<B`A/2`D=&AI<RT^8V%C:&5?9&ER*2![("`O+V1E;&5T92!T:&4@<W5B+61I
M<B!E;G1R:65S("!I='-E;&8@86QS;RP@8G5T(&YO="!T:&4@8V%C:&4M9&ER
M+@H@("`@("`@("`@("!R;41I<B@D9&ER*3L*("`@("`@("`@("`@)&YU;5]R
M96UO=F5D*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&YU;5]R96UO
M=F5D.PH@("`@?2`O+R!E;F0@9G5N8R!D96QE=&5$:7(*("`@(`I]("\O(&5N
M9"!C;&%S<R!F:6QE"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]M
M<V5S<VEO;BYP:'``````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V-C,Q`#$P
M-3$U-#,Q,#4V`#`R,C8T-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F
M('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU
M;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M(&US97-S:6]N+G!H<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X
M<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ
M"BH@4W1O<F5S(&-A8VAE(&-O;G1E;G1S(&EN(&US97-S:6]N<RX**@HJ(%=!
M4DY)3D<Z(&5X<&5R:6UE;G1A;"P@=6YT97-T960**@HJ($!A=71H;W(@("!5
M;&8@5V5N9&5L("`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^"BH@0'9E<G-I;VX@
M("1)9#H@;7-E<W-I;VXN<&AP+'8@,2XT(#(P,#,O,#$O,#0@,3$Z-30Z-#8@
M;6H@17AP("0**B\*8VQA<W,@0V%C:&5?0V]N=&%I;F5R7VUS97-S:6]N(&5X
M=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*"@H@("`@+RHJ"B`@("`J($QE;F=T
M:"!O9B!T:&4@0V%C:&4M261E;G1I9FEE<@H@("`@*@H@("`@*B!.;W1E('1H
M870@=&AE(%!%05(M0V%C:&4@<')E9FEX97,@=&AE($E$('=I=&@@86X@;60U
M*"D@=F%L=64*("`@("H@;V8@=&AE(&-A8VAE+6=R;W5P+B!!(&=O;V0@=F%L
M=64@9F]R('1H92!I9%]L96YG=&@*("`@("H@9&5P96YD<R!O;B!T:&4@;6%X
M:6UU;2!N=6UB97(@;V8@96YT<FEE<R!P97(@8V%C:&4@9W)O=7`N"B`@("`J
M"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@('9A<B`D:61?;&5N9W1H(#T@
M,S(["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(%5S92!M<V5S<VEO;E]U;FEQ
M('1O(&-R96%T92!A('5N:7%U92!3240N"B`@("`J(`H@("`@*B!`=F%R("!B
M;V]L96%N"B`@("`J+PH@("`@=F%R("1U;FEQ(#T@=')U93L*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@17-T86)L:7-H(&$@8V]N;F5C=&EO;B!T;R!A(&US
M97-S:6]N('-E<G9E<C\*("`@("H*("`@("H@0'9A<B`@8F]O;&5A;@H@("`@
M*B\*("`@('9A<B`D8V]N;F5C="`]('1R=64["B`@(`H@("`*("`@("\J*@H@
M("`@*B!M<V5S<VEO;B!H;W-T"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@
M("`@*B\@(`H@("`@=F%R("1H;W-T(#T@3E5,3#L*("`@(`H@("`*("`@("\J
M*@H@("`@*B!M<V5S<VEO;B!P;W)T"B`@("`J"B`@("`J($!V87(@('-T<FEN
M9PH@("`@*B\*("`@('9A<B`D<&]R="`]($Y53$P["B`@("`*("`@(`H@("`@
M+RHJ"B`@("`J(&UE<V5S<VEO;B!S97)V97(@8V]N;F5C=&EO;@H@("`@*@H@
M("`@*B!`=F%R("!R97-O=7)C92!M<V5S<VEO;@H@("`@*B\*("`@('9A<B`D
M;7,@/2!.54Q,.PH*("`@(`H@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R
M7VUS97-S:6]N*"1O<'1I;VYS(#T@)R<I('L*("`@("`@("!I9B`H:7-?87)R
M87DH)&]P=&EO;G,I*0H@("`@("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D
M;W!T:6]N<RP@87)R87E?;65R9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@
M87)R87DH)VED7VQE;F=H="<L("=U;FEQ)RP@)VAO<W0G+"`G<&]R="<L("=C
M;VYN96-T)RDI*3L*"B`@("`@("`@:68@*"1C;VYN96-T*2![("`@("`@("`@
M("`@"B`@("`@("`@("`@(&EF("A.54Q,(#T]("1T:&ES+3YH;W-T*0H@("`@
M("`@("`@("`@("`@;F5W($-A8VAE7T5R<F]R*"=.;R!H;W-T('-P96-I9FEE
M9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!I9B`H3E5,
M3"`]/2`D=&AI<RT^<&]R="D*("`@("`@("`@("`@("`@(&YE=R!#86-H95]%
M<G)O<B@G3F\@<&]R="!S<&5C:69I960N)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`*("`@("`@("`@("`@:68@*"$H)'1H:7,M/FUS(#T@;7-E
M<W-I;VY?8V]N;F5C="@D=&AI<RT^:&]S="P@)'1H:7,M/G!O<G0I*2D*("`@
M("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@G0V%N(&YO="!C;VYN96-T
M('1O('1H92!S979E<B!U<VEN9R!H;W-T("(G("X@)'1H:7,M/FAO<W0@+B`G
M(B!O;B!P;W)T("(G("X@)'1H:7,M/G!O<G0@+B`G(B<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@(`H@("`@?2`O+R!E;F0@9G5N
M8R!C;VYT<G5C=&]R"@H@("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O=7`I
M('L*("`@(`H@("`@("`@("1I9"`]('-T<G1O=7!P97(H;60U*"1G<F]U<"DI
M("X@)&ED.PH@("`@("`@("1G<F]U<"`](&US97-S:6]N7V=E="@D:60L("=?
M<&5A<E]C86-H95]D871A)RP@3E5,3"D["B`@("`@("`@"B`@("`@("`@:68@
M*$Y53$P@/3T@)&1A=&$I"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A.54Q,
M+"!.54Q,+"!.54Q,*3L*("`@("`@("`*("`@("`@("!R971U<FX@87)R87DH
M)&1A=&%;)V5X<&ER97,G72P@)&1A=&%;)V-A8VAE9&%T82==+"`D9&%T85LG
M=7-E<F1A=&$G72D["B`@("!]("\O(&5N9"!F=6YC(&9E=&-H"@H@("`@+RHJ
M"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@("`J"B`@("`J(%=!4DY)3D<Z
M($EF('EO=2!S=7!P;'D@=7-E<F1A=&$@:70@;75S="!N;W0@8V]N=&%I;B!A
M;GD@;&EN96)R96%K<RP*("`@("H@;W1H97)W:7-E(&ET('=I;&P@8G)E86L@
M=&AE(&9I;&5S=')U8W1U<F4N"B`@("`J+PH@("`@9G5N8W1I;VX@<V%V92@D
M:60L("1C86-H961A=&$L("1E>'!I<F5S+"`D9W)O=7`L("1U<V5R9&%T82D@
M>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH@
M("`@("`@(`H@("`@("`@("1C86-H961A=&$@("`@("`]("1T:&ES+3YE;F-O
M9&4H)&-A8VAE9&%T82D["B`@("`@("`@)&5X<&ER97-?86)S("`@(#T@)'1H
M:7,M/F=E=$5X<&ER97-!8G-O;'5T92@D97AP:7)E<RD["@H@("`@("`@("1S
M:7IE(#T@,2`K('-T<FQE;B@D8V%C:&5D871A*2`K('-T<FQE;B@D97AP:7)E
M<U]A8G,I("L@<W1R;&5N*"1U<V5R9&%T82D@*R!S=')L96XH)&=R;W5P*3L*
M("`@("`@("`D<VEZ92`K/2!S=')L96XH)'-I>F4I.PH@("`@("`@(`H@("`@
M("`@("1D871A(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V-A8VAE
M9&%T82<@/3X@)&-A8VAE9&%T82P@"B`@("`@("`@("`@("`@("`@("`@)V5X
M<&ER97,G("`@/3X@)&5X<&ER97-?86)S+`H@("`@("`@("`@("`@("`@("`@
M("=U<V5R9&%T82<@(#T^("1U<V5R9&%T80H@("`@("`@("`@("`@("`@("`I
M.PH@("`@("`@("1I9"`]('-T<G1O=7!P97(H;60U*"1G<F]U<"DI("X@)&ED
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@;7-E<W-I
M;VY?;&]C:R@D:60I.PH@("`@("`@(`H@("`@("`@(&EF("@A;7-E<W-I;VY?
M<V5T*"1I9"P@)U]P96%R7V-A8VAE)RP@=')U92DI('L*("`@("`@("`@("`@
M;7-E<W-I;VY?=6YL;V-K*"1I9"D["B`@("`@("`@("`@(')E='5R;B!N97<@
M0V%C:&5?17)R;W(H(D-A;B=T('=R:71E(&-A8VAE(&1A=&$N(BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@
M*"%M<V5S<VEO;E]S970H)&ED+"`G7W!E87)?8V%C:&5?9&%T82<L("1D871A
M*2D@>PH@("`@("`@("`@("!M<V5S<VEO;E]U;FQO8VLH)&ED*3L*("`@("`@
M("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@=W)I=&4@8V%C
M:&4@9&%T82XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M("`@("`*("`@("`@("!I9B`H(6US97-S:6]N7W-E="@D:60L("=?<&5A<E]C
M86-H95]G<F]U<"<L("1G<F]U<"DI('L*("`@("`@("`@("`@;7-E<W-I;VY?
M=6YL;V-K*"1I9"D["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R
M;W(H(D-A;B=T('=R:71E(&-A8VAE(&1A=&$N(BP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"%M<V5S<VEO
M;E]S970H)&ED+"`G7W!E87)?8V%C:&5?<VEZ92<L("1S:7IE*2D@>PH@("`@
M("`@("`@("!M<V5S<VEO;E]U;FQO8VLH)&ED*3L*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@=W)I=&4@8V%C:&4@9&%T82XB
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("`O+R!L970@;7-E<W-I;VX@9&\@<V]M92!'0R!A<R!W96QL"B`@("`@
M("`@+R\@;F]T92!T:&%T(&US97-S:6]N('=O<FMS(&1I9F9E<F5N="!F<F]M
M('1H92!014%2($-A8VAE+@H@("`@("`@("\O(&US97-S:6]N(&1E;&5T97,@
M86X@96YT<GD@:68@:70@:&%S(&YO="!B965N('5S960@9F]R(&XM<V5C;VYD
M<RX*("`@("`@("`O+R!014%2($-A8VAE(&1E;&5T97,@869T97(@;BUS96-O
M;F1S+@H@("`@("`@(&EF("@P("$]("1E>'!I<F5S*0H@("`@("`@("`@("!M
M<V5S<VEO;E]T:6UE;W5T*"1I9"P@)&5X<&ER97,I.PH@("`@("`@("`@("`*
M("`@("`@("!M<V5S<VEO;E]U;FQO8VLH)&ED*3L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]("\O(&5N9"!F=6YC('-A=F4*"B`@("!F=6YC=&EO;B!R
M96UO=F4H)&ED+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L
M;V%D*"1I9"P@)&=R;W5P*3L*("`@(`H@("`@("`@(')E='5R;B!M<V5S<VEO
M;E]D97-T<F]Y*'-T<G1O=7!P97(H;60U*"1G<F]U<"DI("X@)&ED*3L*("`@
M('T@+R\@96YD(&9U;F,@<F5M;W9E"@H@("`@9G5N8W1I;VX@9FQU<V@H)&=R
M;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@("`@("`*
M("`@("`@("`D<V5S<VEO;G,@/2!M<V5S<VEO;E]F:6YD*"=?<&5A<E]C86-H
M95]G<F]U<"<L("1G<F]U<"D["B`@("`@("`@:68@*&5M<'1Y*"1S97-S:6]N
M<RDI"B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@(`H@("`@("`@(&9O
M<F5A8V@@*"1S97-S:6]N<R!A<R`D:R`]/B`D:60I"B`@("`@("`@("`@(&UE
M<W-S:6]N7V1E<W1R;WDH)&ED*3L*"B`@("`@("`@<F5T=7)N(&-O=6YT*"1S
M97-S:6]N<RD["B`@("!]("\O(&5N9"!F=6YC(&9L=7-H"@H@("`@9G5N8W1I
M;VX@:61%>&ES=',H)&ED+"`D9W)O=7`I('L*("`@("`@("`*("`@("`@("!R
M971U<FX@*$Y53$P@/3T@;7-E<W-I;VY?9V5T*'-T<G1O=7!P97(H;60U*"1G
M<F]U<"DI("X@)&ED+"`G7W!E87)?8V%C:&5?9W)O=7`G+"!.54Q,*2D@/R!F
M86QS92`Z('1R=64["B`@("!]("\O(&5N9"!F=6YC(&ED17AI<W1S"@H@("`@
M+RHJ"B`@("`J($1E;&5T97,@86QL(&5X<&ER960@9FEL97,N"B`@("`J"B`@
M("`J($YO=&4Z(&=A<F)A9V4@8V]L;&5C=&EO;B!S:&]U;&0@8V%U<V4@;&]T
M)W,@;V8@;F5T=V]R:R!T<F%F9FEC+@H@("`@*@H@("`@*B!`<&%R86T@("`@
M:6YT96=E<B!-87AI;75M(&QI9F5T:6UE(&EN('-E8V]N9',@;V8@86X@;F\@
M;&]N9V5R('5S960O=&]U8VAE9"!E;G1R>0H@("`@*B!`=&AR;W=S("`@0V%C
M:&5?17)R;W(*("`@("HO"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO
M;B@D;6%X;&EF971I;64I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D
M*"D["B`@("`@("`@"B`@("`@("`@)'-E<W-I;VYS(#T@;7-E<W-I;VY?9FEN
M9"@G7W!E87)?8V%C:&4G+"!T<G5E*3L*("`@("`@("!I9B`H96UP='DH)'-E
M<W-I;VYS*2D*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@"B`@
M("`@("`@)'1O=&%L(#T@,#L*("`@("`@("`D96YT<FEE<R`](&%R<F%Y*"D[
M"B`@("`@("`@"B`@("`@("`@9F]R96%C:"`H)'-E<W-I;VYS(&%S("1K(#T^
M("1I9"D@>PH@("`@("`@("`@("`D9&%T82`](&US97-S:6]N7V=E="@D:60L
M("=?<&5A<E]C86-H95]D871A)RP@3E5,3"D["B`@("`@("`@("`@(&EF("A.
M54Q,(#T]("1D871A*0H@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@("`@("`*("`@("`@("`@("`@:68@*"1D871A6R=E>'!I<F5S)UT@
M/#T@=&EM92@I*2!["B`@("`@("`@("`@("`@("!M<V5S<VEO;E]D97-T<F]Y
M*"1I9"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`*("`@("`@("`@("`@)'-I>F4@/2!M<V5S<VEO;E]G
M970H)&ED+"`G7W!E87)?8V%C:&5?<VEZ92<L($Y53$PI.PH@("`@("`@("`@
M("`D=&]T86P@*ST@)'-I>F4["B`@("`@("`@("`@("1E;G1R:65S6R1D871A
M6R=E>'!I<F5S)UU=(#T@87)R87DH)&ED+"`D<VEZ92D["B`@("`@("`@?0H@
M("`@("`@(`H@("`@("`@(&EF("@D=&]T86P@/B`D=&AI<RT^:&EG:'=A=&5R
M*2!["B`@("`@("`@("`@(`H@("`@("`@("`@("!K<G-O<G0H)&5N=')I97,I
M.PH@("`@("`@("`@("!R97-E="@D96YT<FEE<RD["B`@("`@("`@("`@(`H@
M("`@("`@("`@("!W:&EL92`H)'1O=&%L(#X@)'1H:7,M/FQO=W=A=&5R("8F
M(&QI<W0H)&5X<&ER97,L("1E;G1R>2D@/2!E86-H*"1E;G1R:65S*2D@>PH@
M("`@("`@("`@("`@("`@;7-E<W-I;VY?9&5S=')O>2@D96YT<GE;,%TI.PH@
M("`@("`@("`@("`@("`@)'1O=&%L("T]("1E;G1R>5LQ73L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]("\O(&5N9"!F=6YC(&=A<F)A9V5#;VQL96-T
M:6]N"B`@("`*?2`O+R!E;F0@8VQA<W,@9FEL90H_/@``````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R
M+W!H<&QI8BYP:'``````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(T-C(`
M,3`U,34T,S$P-38`,#(R,C8R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!796YD96P@
M/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('!H<&QI8BYP:'`L
M=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`H*<F5Q=6ER95]O
M;F-E("=#86-H92]#;VYT86EN97(N<&AP)SL*"B\J*@HJ(%-T;W)E<R!C86-H
M92!D871A(&EN=&\@82!D871A8F%S92!T86)L92!U<VEN9R!02%!,:6)S($1"
M(&%B<W1R86-T:6]N+@HJ"BH@5T%23DE.1SH@3W1H97(@<WES=&5M<R!M:6=H
M="!O<B!M:6=H="!N;W0@<W5P<&]R="!C97)T86EN(&1A=&%T>7!E<R!O9B`*
M*B!T:&4@=&%B;&5S('-H;W=N+B!!<R!F87(@87,@22!K;F]W('1H97)E)W,@
M;F\@;&%R9V4@8FEN87)Y(`HJ('1Y<&4@:6X@4U%,+3DR(&]R(%-13"TY.2X@
M4&]S=&=R97,@<V5E;7,@=&\@;&%C:R!A;GD@"BH@0DQ/0B!O<B!415A4('1Y
M<&4L(&9O<B!-4RU344P@>6]U(&-O=6QD('5S92!)34%'12P@9&]N)W0@:VYO
M=R`**B!A8F]U="!O=&AE<B!D871A8F%S97,N(%!L96%S92!A9&0@<W5G97-T
M:6]N<R!F;W(@;W1H97(@9&%T86)A<V5S('1O(`HJ('1H92!I;FQI;F4@9&]C
M<RX**@HJ(%1H92!F:65L9"`G8VAA;F=E9"<@:7,@=7-E9"!B>2!T:&4@9V%R
M8F%G92!C;VQL96-T:6]N+B!$97!E;F1I;F<@;VX@"BH@>6]U<B!D871A8F%S
M97-Y<W1E;2!Y;W4@;6EG:'0@:&%V92!T;R!S=6)C;&%S<R!F971C:"@I(&%N
M9"!G87)B86=E0V]L;&5C=&EO;B@I+@HJ"BH@1F]R(%]->5-13%\@>6]U(&YE
M960@=&AI<R!$0B!T86)L93H**@HJ($-214%412!404),12!C86-H92`H"BH@
M("!I9"`@("`@("`@("!#2$%2*#,R*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ
M("`@8V%C:&5G<F]U<"`@5D%20TA!4B@Q,C<I($Y/5"!.54Q,($1%1D%53%0@
M)R<L"BH@("!C86-H961A=&$@("!"3$]"($Y/5"!.54Q,($1%1D%53%0@)R<L
M"BH@("!U<V5R9&%T82`@("!605)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,
M("<G+`HJ("`@97AP:7)E<R`@("`@24Y4*#DI($Y/5"!.54Q,($1%1D%53%0@
M,"P**B`@"BH@("!C:&%N9V5D("`@("!424U%4U1!35`H,30I($Y/5"!.54Q,
M+`HJ("`**B`@($E.1$58("AE>'!I<F5S*2P**B`@(%!224U!4ED@2T59("AI
M9"P@8V%C:&5G<F]U<"D**B`I"BH**B`**B!`875T:&]R("`@56QF(%=E;F1E
M;"`@/'5L9BYW96YD96Q`<&AP9&]C+F1E/BP@4V5B87-T:6%N($)E<F=M86YN
M(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"BH@0'9E<G-I;VX@("1)9#H@
M<&AP;&EB+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D
M"BH@0'!A8VMA9V4@($-A8VAE"BH@0'-E92`@("`@('-A=F4H*0HJ+PIC;&%S
M<R!#86-H95]#;VYT86EN97)?<&AP;&EB(&5X=&5N9',@0V%C:&5?0V]N=&%I
M;F5R('L*("`*("`@("\J*@H@("`@*B!.86UE(&]F('1H92!$0B!T86)L92!T
M;R!S=&]R92!C86-H:6YG(&1A=&$*("`@("H@"B`@("`J($!S964@($-A8VAE
M7T-O;G1A:6YE<E]F:6QE.CHD9FEL96YA;65?<')E9FEX"B`@("`J+R`@"B`@
M("!V87(@)&-A8VAE7W1A8FQE(#T@)V-A8VAE)SL*"B`@("`O*BH*("`@("H@
M4$A03&EB(&]B:F5C=`H@("`@*B`*("`@("H@0'9A<B`@;V)J96-T(%!%05)?
M1$(*("`@("HO"B`@("!V87(@)&1B.PH*("`@("\J*@H@("`@*B!.86UE(&]F
M('1H92!02%!,:6(@1$(@8VQA<W,@=&\@=7-E"B`@("`J(`H@("`@*B!`=F%R
M("!S=')I;F<@(`H@("`@*B!`<V5E("`D9&)?<&%T:"P@)&QO8V%L7W!A=&@*
M("`@("HO"B`@("!V87(@)&1B7V-L87-S(#T@)R<["@H@("`@+RHJ"B`@("`J
M($9I;&5N86UE(&]F('EO=7(@;&]C86PN:6YC"B`@("`J(`H@("`@*B!)9B!E
M;7!T>2P@)VQO8V%L+FEN8R<@:7,@87-S=6UE9"X*("`@("H*("`@("H@0'9A
M<B`@("`@("!S=')I;F<*("`@("HO"B`@("!V87(@)&QO8V%L7V9I;&4@/2`G
M)SL*"B`@("`O*BH*("`@("H@26YC;'5D92!P871H(&9O<B!Y;W4@;&]C86PN
M:6YC"B`@("`J"B`@("`J($A)3E0Z($EF('EO=7(G<F4@;F]T('5S:6YG(%!(
M4$QI8B=S('!R97!E;F0N<&AP('EO=2!M=7-T(`H@("`@*B!T86ME(&-A<F4@
M=&AA="!A;&P@8VQA<W-E<R`H9FEL97,I(')E9F5R96YC97,@8GD@>6]U(`H@
M("`@*B!L;V-A;"YI;F,@87)E(&EN8VQU9&5D(&%U=&]M871I8V%L;'DN(%-O
M('EO=2!M:6=H="`*("`@("H@=V%N="!T;R!W<FET92!A(&YE=R!L;V-A;#(N
M:6YC('1H870@;VYL>2!R969E<G)S('1O(`H@("`@*B!T:&4@9&%T86)A<V4@
M8VQA<W,@*&9I;&4I('EO=2=R92!U<VEN9R!A;F0@:6YC;'5D97,@86QL(')E
M<75I<F5D(&9I;&5S+@H@("`@*@H@("`@*B!`=F%R("!S=')I;F<@('!A=&@@
M=&\@>6]U<B!L;V-A;"YI;F,@+2!M86ME('-U<F4@=&\@861D(&$@=')A:6QI
M;F<@<VQA<V@*("`@("H@0'-E92`@)&QO8V%L7V9I;&4*("`@("HO"B`@("!V
M87(@)&QO8V%L7W!A=&@@/2`G)SL*"B`@("`O*BH*("`@("H@0W)E871E<R!A
M;B!I;G-T86YC92!O9B!A('!H<&QI8B!D8B!C;&%S<R!T;R!U<V4@:70@9F]R
M('-T;W)A9V4N"B`@("`J"B`@("`J($!P87)A;2`@("!M:7AE9"`@($EF(&5M
M<'1Y('1H92!O8FIE8W0@=')I97,@=&\@=7-E9"!T:&4@"B`@("`J("`@("`@
M("`@("`@("`@("`@('!R96-O;F9I9W5R960@8VQA<W,@=F%R:6%B;&5S+B!)
M9B!G:79E;B!I="`*("`@("H@("`@("`@("`@("`@("`@("`@;75S="!B92!A
M;B!A<G)A>2!W:71H.@H@("`@*B`@("`@("`@("`@("`@("`@("`@(&1B7V-L
M87-S(#T^(&YA;64@;V8@=&AE($1"(&-L87-S('1O('5S90H@("`@*B`@("`@
M("`@("`@("`@("`@("!O<'1I;VYA;#H*("`@("H@("`@("`@("`@("`@("`@
M("`@("!D8E]F:6QE(#T^(&9I;&5N86UE(&]F('1H92!$0B!C;&%S<PH@("`@
M*B`@("`@("`@("`@("`@("`@("`@(&1B7W!A=&@@/3X@<&%T:"!T;R!T:&4@
M1$(@8VQA<W,*("`@("H@("`@("`@("`@("`@("`@("`@("!L;V-A;%]F:6QE
M(#T^(&MI;F0@;V8@;&]C86PN:6YC"B`@("`J("`@("`@("`@("`@("`@("`@
M("`@;&]C86Q?<&%T:R`]/B!P871H('1O('1H92!L;V-A;"YI;F,*("`@("H@
M("`@("`@("`@("`@("`@("`@<V5E("1L;V-A;%]P871H(&9O<B!S;VUE(&AI
M;G1S+G,*("`@("H@0'-E92`@)&QO8V%L7W!A=&@*("`@("HO"B`@("!F=6YC
M=&EO;B!#86-H95]#;VYT86EN97)?<&AP;&EB*"1O<'1I;VYS(#T@)R<I('L*
M("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I*0H@("`@("`@("`@("`D
M=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@(&%R<F%Y7VUE<F=E*"1T:&ES
M+3YA;&QO=V5D7V]P=&EO;G,L(&%R<F%Y*"=D8E]C;&%S<R<L("=D8E]F:6QE
M)RP@)V1B7W!A=&@G+"`G;&]C86Q?9FEL92<L("=L;V-A;%]P871H)RDI*3L*
M"B`@("`@("`@:68@*"$D=&AI<RT^9&)?8VQA<W,I"B`@("`@("`@("`@(')E
M='5R;B!N97<@0V%C:&5?17)R;W(H)TYO(&1A=&%B87-E(&-L87-S('-P96-I
M9FEE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`O+R!I;F-L
M=61E('1H92!R97%U:7)E9"!F:6QE<PH@("`@("`@(&EF("@D=&AI<RT^9&)?
M9FEL92D*("`@("`@("`@("`@:6YC;'5D95]O;F-E*"1T:&ES+3YD8E]P871H
M("X@)'1H:7,M/F1B7V9I;&4I.PH*("`@("`@("!I9B`H)'1H:7,M/FQO8V%L
M7V9I;&4I"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92@D=&AI<RT^;&]C86Q?
M<&%T:"`N("1T:&ES+3YL;V-A;%]F:6QE*3L*"B`@("`@("`@+R\@8W)E871E
M(&$@9&(@;V)J96-T(`H@("`@("`@("1T:&ES+3YD8B`](&YE=R`D=&AI<RT^
M9&)?8VQA<W,["B`@("!]("\O(&5N9"!C;VYS=')U8W1O<@H*("`@(&9U;F-T
M:6]N(&9E=&-H*"1I9"P@)&=R;W5P*2!["B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@B4T5,14-4(&5X<&ER97,L(&-A8VAE9&%T82P@=7-E<F1A=&$@1E)/
M32`E<R!72$5212!I9"`]("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M92P@"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:60L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9W)O=7`*("`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@
M("`@("`@(&EF("@A)'1H:7,M/F1B+3Y.97AT7U)E8V]R9"@I*0H@("`@("`@
M("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["@H@("`@("`@
M("\O(&QA<W0@=7-E9"!R97%U:7)E9"!B>2!T:&4@9V%R8F%G92!C;VQL96-T
M:6]N("`@"B`@("`@("`@+R\@5T%23DE.1SH@;6EG:'0@8F4@37E344P@<W!E
M8VEF:6,@("`@("`@("`*("`@("`@("`D<75E<GD@/2!S<')I;G1F*")54$1!
M5$4@)7,@4T54(&-H86YG960@/2`H3D]7*"D@*R`P*2!72$5212!I9"`]("<E
M<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1G<F]U<`H@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@
M)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(')E='5R;B!A<G)A
M>2@D=&AI<RT^9&(M/F8H)V5X<&ER97,G*2P@)'1H:7,M/F1E8V]D92@D=&AI
M<RT^9&(M/F8H)V-A8VAE9&%T82<I*2P@)'1H:7,M/F1B+3YF*"=U<V5R9&%T
M82<I*3L*("`@('T@+R\@96YD(&9U;F,@9F5T8V@*"B`@("`O*BH*("`@("H@
M4W1O<F5S(&$@9&%T87-E="X*("`@("H@"B`@("`J(%=!4DY)3D<Z('=E('5S
M92!T:&4@4U%,(&-O;6UA;F0@4D503$%#12!)3E1/('1H:7,@;6EG:'0@8F4@
M"B`@("`J($UY4U%,('-P96-I9FEC+B!!<R!->5-13"!I<R!V97)Y('!O<'5L
M87(@=&AE(&UE=&AO9"!S:&]U;&0*("`@("H@=V]R:R!F:6YE(&9O<B`Y-24@
M;V8@>6]U+@H@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T82P@
M)&5X<&ER97,L("1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO
M860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*")2
M15!,04-%($E.5$\@)7,@*&-A8VAE9&%T82P@97AP:7)E<RP@:60L(&-A8VAE
M9W)O=7`I(%9!3%5%4R`H)R5S)RP@)60L("<E<R<L("<E<R<I(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)'1H:7,M/F5N
M8V]D92@D9&%T82DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F=E=$5X<&ER97-!8G-O;'5T92@D97AP:7)E<RD@+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&=R;W5P"B`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@<F5T=7)N
M("AB;V]L96%N*21T:&ES+3YD8BT^869F96-T961?<F]W<R@I.R`*("`@('T@
M+R\@96YD(&9U;F,@<V%V90H*("`@(&9U;F-T:6]N(')E;6]V92@D:60L("1G
M<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O
M=7`I.PH@("`@("`@("1T:&ES+3YD8BT^<75E<GDH"B`@("`@("`@("`@("`@
M("`@("`@("`@('-P<FEN=&8H(D1%3$5412!&4D]-("5S(%=(15)%(&ED(#T@
M)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&=R;W5P"B`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`@("`@("`@("D["@H@("`@("`@(')E='5R;B`H8F]O;&5A;BDD=&AI
M<RT^9&(M/F%F9F5C=&5D7W)O=W,H*3L*("`@('T@+R\@96YD(&9U;F,@<F5M
M;W9E"@H@("`@9G5N8W1I;VX@9FQU<V@H)&=R;W5P*2!["B`@("`@("`@)'1H
M:7,M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("!I9B`H)&=R;W5P*2!["B`@
M("`@("`@("`@("1T:&ES+3YD8BT^<75E<GDH<W!R:6YT9B@B1$5,151%($92
M3TT@)7,@5TA%4D4@8V%C:&5G<F]U<"`]("<E<R<B+"`D=&AI<RT^8V%C:&5?
M=&%B;&4L("1G<F]U<"DI.R`@("`*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^9&(M/G%U97)Y*'-P<FEN=&8H(D1%3$5412!&4D]-("5S
M(BP@)'1H:7,M/F-A8VAE7W1A8FQE*2D[("`@(`H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YD8BT^869F96-T961?<F]W<R@I.PH@("`@?2`O
M+R!E;F0@9G5N8R!F;'5S:`H*("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@
M)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F1B+3YQ=65R>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@<W!R:6YT9B@B4T5,14-4(&ED($923TT@)7,@5TA%
M4D4@240@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L(`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&ED+"`*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1G<F]U<`H@("`@("`@("`@("`@("`@("`@("`@("`I
M("`@"B`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N("AB
M;V]L96%N*21T:&ES+3YD8BT^;F8H*3L@("`@("`@("`@("`@("`@("`@("`@
M("`@"B`@("!]("\O(&5N9"!F=6YC(&ES17AI<W1S"@H@("`@9G5N8W1I;VX@
M9V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE*2!["B`@("`@("`@)'1H
M:7,M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("`D=&AI<RT^9&(M/G%U97)Y
M*"`*("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@B1$5,151%($92
M3TT@)7,@5TA%4D4@*&5X<&ER97,@/#T@)60@04Y$(&5X<&ER97,@/B`P*2!/
M4B!C:&%N9V5D(#P]("A.3U<H*2`M("5D*2(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L(`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&UA>&QI9F5T:6UE"B`@("`@("`@("`@("`@("`@("`@("`@("D*
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`O+V-H96-K(&9O<B!T
M;W1A;"!S:7IE(&]F(&-A8VAE"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M<V5L96-T('-U;2AL96YG=&@H8V%C:&5D871A*2D@87,@0V%C:&53:7IE(&9R
M;VT@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)'1H
M:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@("1T:&ES+3YD8BT^3F5X
M=%]296-O<F0H*3L*("`@("`@("`D8V%C:&5S:7IE(#T@)'1H:7,M/F1B+3YF
M*"=#86-H95-I>F4G*3L*("`@("`@("`O+VEF(&-A8VAE(&ES('1O(&)I9RX*
M("`@("`@("!I9B`H)&-A8VAE<VEZ92`^("1T:&ES+3YH:6=H=V%T97(I"B`@
M("`@("`@>PH@("`@("`@("`@("`O+V9I;F0@=&AE(&QO=W=A=&5R(&UA<FLN
M"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)W-E;&5C="!L96YG=&@H
M8V%C:&5D871A*2!A<R!S:7IE+"!C:&%N9V5D(&9R;VT@)7,@;W)D97(@8GD@
M8VAA;F=E9"!$15-#)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@("`@
M("`@("D["B`@("`@("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*
M"B`@("`@("`@("`@("1K965P7W-I>F4],#L*("`@("`@("`@("`@=VAI;&4@
M*"1K965P7W-I>F4@/"`D=&AI<RT^;&]W=V%T97(@)B8@)'1H:7,M/F1B+3Y.
M97AT7U)E8V]R9"@I("D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M)&ME97!?<VEZ92`K/2`D=&AI<RT^9&(M/F8H)W-I>F4G*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`O+V1E;&5T92!A;&P@96YT<FEE<RP@=VAI8V@@
M=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO=W=W871E<B!M87)K(@H@("`@
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=D96QE=&4@9G)O;2`E<R!W:&5R
M92!C:&%N9V5D(#P]("<N)'1H:7,M/F1B+3YF*"=C:&%N9V5D)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?
M=&%B;&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*
M("`@("`@("`@("`@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@
M('T*("`@('T@+R\@96YD(&9U;F,@9V%R8F%G94-O;&QE8W1I;VX*?0H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]S:&TN<&AP````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q,3,U`#$P-3$U-#,Q,#4V`#`R,34V-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ
M($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O
M=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@
M("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A
M=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@
M?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S
M92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD
M93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\*+R\@)$ED.B!S:&TN<&AP+'8@,2XS(#(P,#,O,#$O,#0@,3$Z-30Z
M-#8@;6H@17AP("0*"G)E<75I<F5?;VYC92`G0V%C:&4O0V]N=&%I;F5R+G!H
M<"<["@HO*BH**B!3=&]R97,@8V%C:&4@9&%T82!I;G1O('-H87)E9"!M96UO
M<GDN"BH**B!796QL+"!T:&ES(&ES(&YO="!A('9E<GD@969F:6-I96YT(&EM
M<&QE;65N=&%T:6]N+B!);F1E960@:70G<R!M=6-H(`HJ('-L;W=E<B!T:&%N
M('1H92!F:6QE(&-O;G1A:6YE<B!A<R!F87(@87,@;7D@=&5S=',@<VAO=V5D
M+B!&:6QE<R!A<F4@"BH@8V%C:&5D(&)Y(&UO<W0@;W!E<F%T:6YG('-Y<W1E
M;7,@86YD(&ET('=I;&P@8F4@:&%R9"!T;R!W<FET92!A(&9A<W1E<B`**B!C
M86-H:6YG(&%L9V]R:71H;2!U<VEN9R!02%`N"BH**B!`875T:&]R("`@56QF
M(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^"BH@0'9E<G-I;VX@("1)
M9#H@<VAM+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D
M"BH@0'!A8VMA9V4@($-A8VAE"BHO"F-L87-S($-A8VAE7T-O;G1A:6YE<E]S
M:&T@97AT96YD<R!#86-H95]#;VYT86EN97(@>PH@("`@+RHJ"B`@("`J($ME
M>2!O9B!T:&4@<V5M87!H;W)E('5S960@=&\@<WEN8R!T:&4@4TA-(&%C8V5S
M<PH@("`@*B`*("`@("H@0'9A<B`@:6YT"B`@("`J+PH@("`@=F%R("1S96U?
M:V5Y(#T@3E5,3#L*"B`@("`O*BH*("`@("H@4&5R;6ES<VEO;G,@;V8@=&AE
M('-E;6%P:&]R92!U<V5D('1O('-Y;F,@=&AE(%-(32!A8V-E<W,*("`@("H@
M"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@('9A<B`D<V5M7W!E<FT@/2`P
M-C0T.PH*("`@("\J*@H@("`@*B!396UA<&AO<F4@:&%N9&QE<@H@("`@*B`*
M("`@("H@0'9A<B`@<F5S;W5R8V4*("`@("HO"B`@("!V87(@)'-E;5]I9"`]
M($Y53$P["@H@("`@+RHJ"B`@("`J($ME>2!O9B!T:&4@<VAA<F5D(&UE;6]R
M>2!B;&]C:R!U<V5D('1O('-T;W)E(&-A8VAE(&1A=&$*("`@("H*("`@("H@
M0'9A<B`@:6YT"B`@("`J+PH@("`@=F%R("1S:&U?:V5Y(#T@3E5,3#L*"B`@
M("`O*BH*("`@("H@4VEZ92!O9B!T:&4@<VAA<F5D(&UE;6]R>2!B;&]C:R!U
M<V5D"B`@("`J(`H@("`@*B!.;W1E.B!T:&4@8V]N=&%I;F5R(&1O97,@;VYL
M>2!U<V4@7V]N95\@<VAM(&)L;V-K(&YO(&UO<F4A"B`@("`J(`H@("`@*B!`
M=F%R("!I;G0*("`@("HO("`@("`@("`*("`@('9A<B`D<VAM7W-I>F4@/2`Q
M,S$P-S(["@H@("`@+RHJ"B`@("`J(%!E<FUI<W-I;VYS(&]F('1H92!S:&%R
M960@;65M;W)Y(&)L;V-K"B`@("`J(`H@("`@*B!`=F%R("!I;G0*("`@("HO
M"B`@("!V87(@)'-H;5]P97)M(#T@,#8T-#L*"B`@("`O*BH*("`@("H@4VAA
M<F5D(&UE;6]R>2!H86YD;&5R"B`@("`J(`H@("`@*B!`=F%R(')E<V]U<F-E
M"B`@("`J+PH@("`@=F%R("1S:&U?:60@/2!.54Q,.PH*("`@("\J*@H@("`@
M*B!(87-H(&]F(&-A8VAE(&5N=')I97,*("`@("H@"B`@("`J(%5S960@8GD@
M=&AE(&=A<F)A9V4@8V]L;&5C=&EO;B!T;R!F:6YD(&]L9"!E;G1R:65S+@H@
M("`@*@H@("`@*B!`=F%R("!A<G)A>0H@("`@*B\*("`@('9A<B`D96YT<FEE
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`J($YU;6)E<B!O9B!B>71E<R!C
M;VYS=6UE9"!B>2!T:&4@8V%C:&4*("`@("H@"B`@("`J($!V87(@(&EN=`H@
M("`@*B\*("`@('9A<B`D=&]T86Q?<VEZ92`](#`["@H@("`@+RHJ"B`@("`J
M($-R96%T97,@82!S:&%R960@;65M;W)Y(&-O;G1A:6YE<@H@("`@*@H@("`@
M*B!`<&%R86T@87)R87D@("`@<VAM7VME>2P@<V5M7VME>2P@<VAM7W-I>F4L
M('-E;5]P97)M+"!S:&U?<&5R;0H@("`@*B\@("`@"B`@("!F=6YC=&EO;B!#
M86-H95]#;VYT86EN97)?<VAM*"1O<'1I;VYS(#T@)R<I('L*("`@("`@("!I
M9B`H:7-?87)R87DH)&]P=&EO;G,I*0H@("`@("`@("`@("`D=&AI<RT^<V5T
M3W!T:6]N<R@D;W!T:6]N<RP@87)R87E?;65R9V4H)'1H:7,M/F%L;&]W961?
M;W!T:6]N<RP@"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G<VAM7VME>2<L("`G<V5M7VME>2<L
M(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W-H;5]S:7IE)RP@)W-E;5]P97)M)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S:&U?<&5R;2<*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*3L*"B`@("`@("`@+R\@0V%C:&4Z.D-O;G1A:6YE
M<B!H:6=H+2!A;F0@;&]W=V%T97(@9&5F875L=',@<VAO=6QD(&)E(&]V97)R
M:61D96X@:68*("`@("`@("`O+R!N;W0@86QR96%D>2!D;VYE(&)Y('1H92!U
M<V5R"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG:&EG:'=A=&5R)UTI
M*2`*("`@("`@("`@("`@)'1H:7,M/FAI9VAW871E<B`](')O=6YD*#`N-S4@
M*B`Q,S$P-S(I.PH@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)VQO=W=A
M=&5R)UTI*0H@("`@("`@("`@("`D=&AI<RT^;&]W=V%T97(@/2!R;W5N9"@P
M+C4@*B`Q,S$P-S(I.PH*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S
M:&U?<VEZ92==*2D*("`@("`@("`@("`@)'1H:7,M/G-H;5]S:7IE(#T@,3,Q
M,#<R.PH*("`@("`@("`O+V=E="!32$T@86YD(%-E;6%P:&]R92!H86YD;&5S
M"B`@("`@("`@:68@*"$H)'1H:7,M/G-H;5]I9"`]('-H;6]P7V]P96XH)'1H
M:7,M/G-H;5]K97DL("=C)RP@)'1H:7,M/G-H;5]P97)M+"`D=&AI<RT^<VAM
M7W-I>F4I*2D*("`@("`@("`@("`@;F5W($-A8VAE7T5R<F]R*")#86XG="!O
M<&5N(%-(32!S96=M96YT("=[)'1H:7,M/G-H;5]K97E])RP@<VEZ92`G>R1T
M:&ES+3YS:&U?<VEZ97TG+B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.
M15]?"B`@("`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@(&EF
M("@A*"1T:&ES+3YS96U?:60@/2!S96U?9V5T*"1T:&ES+3YS96U?:V5Y+"`Q
M+"`D=&AI<RT^<V5M7W!E<FTI*2D*("`@("`@("`@("`@;F5W($-A8VAE7T5R
M<F]R*")#86XG="!G970@<V5M87!H;W)E("=[)'1H:7,M/G-E;5]K97E])R!U
M<VEN9R!P97)M<R`G>R1T:&ES+3YS96U?<&5R;7TG+B(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?3$E.15]?"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D["@H@("`@?2`O+R!E;F0@8V]N<W1R=6-T;W(*"B`@("!F=6YC=&EO;B!F
M971C:"@D:60L("1G<F]U<"D@>PH@("`@("`@('-E;5]A8W%U:7)E*"1T:&ES
M+3YS96U?:60I.PH*("`@("`@("`D8V%C:&5D871A(#T@<VAM;W!?<F5A9"@D
M=&AI<RT^<VAM7VED+"`P+"`D=&AI<RT^<VAM7W-I>F4I.PH*("`@("`@("!S
M96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*"B`@("`@("`@)&-A8VAE9&%T
M82`]("1T:&ES+3YD96-O9&4H)&-A8VAE9&%T82D["@H@("`@("`@(&EF("@A
M:7-S970H)&-A8VAE9&%T85LD9W)O=7!=6R1I9%TI*0H@("`@("`@("`@("!R
M971U<FX@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["B`@("`@("`@96QS92`*
M("`@("`@("`@("`@)&-A8VAE9&%T82`]("1C86-H961A=&%;)&=R;W5P75LD
M:61=.PH*("`@("`@("!R971U<FX@87)R87DH)&-A8VAE9&%T85LG97AP:7)E
M)UTL"B`@("`@("`@("`@("`@("`@("`@("1C86-H961A=&%;)V-A8VAE9&%T
M82==+`H@("`@("`@("`@("`@("`@("`@("`D8V%C:&5D871A6R=U<V5R9&%T
M82=="B`@("`@("`@("`@("`@("`@("`@*3L*("`@('T@+R\@96YD(&9U;F,@
M9F5T8V@*"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F4L
M("1G<F]U<"P@)'5S97)D871A*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E
M;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@('-E;5]A8W%U:7)E*"1T:&ES
M+3YS96U?:60I.PH*("`@("`@("`D8V%C:&5D871A(#T@)'1H:7,M/F1E8V]D
M92AS:&UO<%]R96%D*"1T:&ES+3YS:&U?:60L(#`L("1T:&ES+3YS:&U?<VEZ
M92DI.PH@("`@("`@("1C86-H961A=&%;)&=R;W5P75LD:61=(#T@87)R87DH
M)V5X<&ER92<@("`@/3X@)'1H:7,M/F=E=$5X<&ER97-!8G-O;'5T92@D97AP
M:7)E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=C86-H961A=&$G(#T^("1D871A+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5S97)D871A)R`@/3X@)'5S97)D871A+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-H86YG
M960G("`@/3X@=&EM92@I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D["@H@("`@("`@(&EF("AS=')L96XH)&YE=V1A=&$@/2`D
M=&AI<RT^96YC;V1E*"1C86-H961A=&$I*2`^("1T:&ES+3YS:&U?<VEZ92D*
M("`@("`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES+3YG87)B86=E0V]L;&5C
M=&EO;BAT:6UE*"DL("1C86-H961A=&$I.PH*("`@("`@("!S:&UO<%]W<FET
M92@D=&AI<RT^<VAM7VED+"`D;F5W9&%T82P@,"D["@H@("`@("`@('-E;5]R
M96QE87-E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("!R971U<FX@=')U93L*
M("`@('T@+R\@96YD(&9U;F,@<V%V90H*("`@(&9U;F-T:6]N(')E;6]V92@D
M:60L("1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED
M+"`D9W)O=7`I.PH*("`@("`@("!S96U?86-Q=6ER92@D=&AI<RT^<V5M7VED
M*3L*"B`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES+3YD96-O9&4H<VAM;W!?
M<F5A9"@D=&AI<RT^<VAM7VED+"`P+"`D=&AI<RT^<VAM7W-I>F4I*3L*("`@
M("`@("!U;G-E="@D8V%C:&5D871A6R1G<F]U<%U;)&ED72D["B`@("`@("`@
M<VAM;W!?=W)I=&4H)'1H:7,M/G-H;5]I9"P@)'1H:7,M/F5N8V]D92@D8V%C
M:&5D871A*2P@,"D["@H@("`@("`@('-E;5]R96QE87-E*"1T:&ES+3YS96U?
M:60I.PH@("`@?2`O+R!E;F0@9G5N8R!R96UO=F4*"B`@("!F=6YC=&EO;B!F
M;'5S:"@D9W)O=7`@/2`G)RD@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO
M860H*3L*"B`@("`@("`@<V5M7V%C<75I<F4H)'1H:7,M/G-E;5]I9"D["@H@
M("`@("`@('-H;6]P7W=R:71E*"1T:&ES+3YS:&U?:60L("1T:&ES+3YE;F-O
M9&4H87)R87DH*2DL(#`I.PH*("`@("`@("!S96U?<F5L96%S92@D=&AI<RT^
M<V5M7VED*3L*("`@('T@+R\@96YD(&9U;F,@9FQU<V@*"B`@("!F=6YC=&EO
M;B!I9$5X:7-T<R@D:60L("1G<F]U<"D@>PH@("`@("`@('-E;5]A8W%U:7)E
M*"1T:&ES+3YS96U?:60I.PH*("`@("`@("`D8V%C:&5D871A(#T@<VAM7W)E
M860H)'1H:7,M/G-H;5]I9"P@,"P@)'1H:7,M/G-H;5]S:7IE*3L*"B`@("`@
M("`@<V5M7W)E;&5A<V4H)'1H:7,M/G-E;5]I9"D["@H@("`@("`@("1C86-H
M961A=&$@/2`D=&AI<RT^9&5C;V1E*"1C86-H961A=&$I.PH*("`@("`@("!R
M971U<FX@:7-S970H)&-A8VAE9&%T85LD9W)O=7!=6R1I9%TI.PH@("`@?2`O
M+R!E;F0@9G5N8R!I<T5X:7-T<PH*("`@(&9U;F-T:6]N(&=A<F)A9V5#;VQL
M96-T:6]N*"1M87AL:69E=&EM92P@)&-A8VAE9&%T82`](&%R<F%Y*"DI('L*
M("`@("`@("!I9B`H)&QO8VL@/2!E;7!T>2@D8V%C:&5D871A*2D@>PH@("`@
M("`@("`@("!S96U?86-Q=6ER92@D=&AI<RT^<V5M7VED*3L*("`@("`@("`@
M("`@)&-A8VAE9&%T82`]("1T:&ES+3YD96-O9&4H<VAM;W!?<F5A9"@D=&AI
M<RT^<VAM7VED+"`P+"`D=&AI<RT^<VAM7W-I>F4I*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YD;T=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM
M92P@)B1C86-H961A=&$I.PH@("`@("`@(&EF("@D=&AI<RT^=&]T86Q?<VEZ
M92`^("1T:&ES+3YH:6=H=V%T97(I('L*("`@("`@("`@("`@:W)S;W)T*"1T
M:&ES+3YE;G1R:65S*3L*("`@("`@("`@("`@<F5S970H)'1H:7,M/F5N=')I
M97,I.PH*("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3YT;W1A;%]S:7IE(#X@
M)'1H:7,M/FQO=W=A=&5R("8F(&QI<W0H)'-I>F4L("1E;G1R:65S*2`](&5A
M8V@H)'1H:7,M/F5N=')I97,I*2!["B`@("`@("`@("`@("`@("!R97-E="@D
M96YT<FEE<RD["@H@("`@("`@("`@("`@("`@=VAI;&4@*&QI<W0H)&LL("1E
M;G1R>2D@/2!E86-H*"1E;G1R:65S*2D@>PH@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1C86-H961A=&%;)&5N=')Y6R=G<F]U<"==75LD96YT<GE;)VED
M)UU=*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=&]T86Q?<VEZ92`M
M/2`D<VEZ93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"1L;V-K*0H@("`@("`@("`@("!S96U?<F5L
M96%S92@D=&AI<RT^<V5M7VED*3L*"B`@("`@("`@)'1H:7,M/F5N=')I97,@
M/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YT;W1A;%]S:7IE(#T@,#L*"B`@
M("`@("`@<F5T=7)N("1C86-H961A=&$[("`@("`@("`@("`*("`@('T@+R\@
M96YD(&9U;F,@9V%R8F%G94-O;&QE8W1I;VX*"B`@("!F=6YC=&EO;B!D;T=A
M<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92P@)B1C86-H961A=&$I('L*
M("`@("`@("`D8VAA;F=E9"`]('1I;64H*2`M("1M87AL:69E=&EM93L*("`@
M("`@("`D<F5M;W9E9"`](#`["@H@("`@("`@(')E<V5T*"1C86-H961A=&$I
M.PH*("`@("`@("!W:&EL92`H;&ES="@D9W)O=7`L("1G<F]U<&1A=&$I(#T@
M96%C:"@D8V%C:&5D871A*2D@>PH@("`@("`@("`@("!R97-E="@D9W)O=7!D
M871A*3L*"B`@("`@("`@("`@('=H:6QE("AL:7-T*"1I9"P@)&1A=&$I(#T@
M96%C:"@D9W)O=7!D871A*2D@>PH@("`@("`@("`@("`@("`@:68@*"1D871A
M6R=E>'!I<F4G72`\('1I;64H*2!\?"`D9&%T85LG8VAA;F=E9"==(#P@)&-H
M86YG960I('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D8V%C:&5D871A
M6R1G<F]U<%U;)&ED72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\O('5G;'D@8G5T('-I;7!L92!T;R!I;7!L96UE
M;G0@.B\*("`@("`@("`@("`@)'-I>F4@/2!S=')L96XH)'1H:7,M/F5N8V]D
M92@D9&%T82DI.PH@("`@("`@("`@("`D=&AI<RT^96YT<FEE<ULD<VEZ95U;
M72`](&%R<F%Y*"=G<F]U<"<@/3X@)&=R;W5P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I9"<@("`@/3X@)&ED"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*
M("`@("`@("`@("`@)'1H:7,M/G1O=&%L7W-I>F4@*ST@)'-I>F4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E;6]V960["B`@("!]("`O+R!E;F0@
M9G5N8R!D;T=A<F)A9V5#;VQL96-T:6]N"GT@+R\@96YD(&-L87-S($-A8VAE
M7T-O;G1A:6YE<E]S:&T*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+W1R:69I;&4N<&AP
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$R,S0`,3`U,34T,S$P-38`
M,#(R-#,U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!796YD96P@/'5L9BYW96YD96Q`
M<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@
M("`@("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G
M;6%N;BYD93X@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@26%N($5U
M<F4@/&EE=7)E0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!T<FEF:6QE+G!H<"QV(#$N,2`R,#`T+S`T+S`Q(#`W.C4P.C`W
M(&-H<F5G=2!%>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(O
M9FEL92YP:'`G.PH*+RHJ"B`J(%1R:2UF:6QE(&-A8VAE+@H@*@H@*B!4:&ES
M(&-A8VAE(&-O;G1A:6YE<B!S=&]R97,@9FEL97,@=VET:"!N;R!S<&5C:6%L
M(&5N8V]D:6YG('1O(')E9'5C92!O=F5R:&5A9"X*("H@17AP:7)A=&EO;B`F
M('5S97(@9&%T82!A<F4@<W1O<F5D(&EN('-E<&5R871E(&9I;&5S+"!P<F5F
M:7AE9"!W:71H(&$@)RXG(&%N9`H@*B!S=69F:7AE9"!W:71H("<N97AP)R`F
M("<N9&%T)R!R97-P96-T:79E;'DN"B`J"B`J(%-E92!H='1P.B\O871O;6EZ
M960N;W)G+U!%05(O0V%C:&5?=')I9FEL92YH=&UL(&9O<B!M;W)E(&EN9F]R
M;6%T:6]N+@H@*@H@*B!`875T:&]R($EA;B!%=7)E(#QI975R94!P:'`N;F5T
M/@H@*B!`=F5R<VEO;B`Q+C`*("HO"F-L87-S($-A8VAE7T-O;G1A:6YE<E]T
M<FEF:6QE(&5X=&5N9',@0V%C:&5?0V]N=&%I;F5R7V9I;&4@>PH@("`@+RHJ
M"B`@("`@*B!&971C:"!C86-H960@9FEL92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9"!#86-H92!)1"!T;R!F971C:`H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9W)O=7`@1W)O=7`@=&\@9F5T8V@@9G)O;0H@("`@("H@0')E
M='5R;B!A<G)A>2`Q+61I;65N<VEO;F%L(&%R<F%Y(&EN('1H92!F;W)M870Z
M(&5X<&ER871I;VXL9&%T82QU<V5R9&%T80H@("`@("HO"B`@("!F=6YC=&EO
M;B!F971C:"@D:60L("1G<F]U<"D*("`@('L*("`@("`@("`D9FEL92`]("1T
M:&ES+3YG971&:6QE;F%M92@D:60L("1G<F]U<"D["B`@("`@("`@:68@*"%F
M:6QE7V5X:7-T<R@D9FEL92DI"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A.
M54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@("`*("`@("`@("!R971U<FX@87)R
M87DH"B`@("`@("`@("`@("`@("!F:6QE7V=E=%]C;VYT96YT<R@D=&AI<RT^
M7V=E=$5X<$9I;&4H)&9I;&4I*2P*("`@("`@("`@("`@("`@(&9I;&5?9V5T
M7V-O;G1E;G1S*"1F:6QE*2P*("`@("`@("`@("`@("`@(&9I;&5?9V5T7V-O
M;G1E;G1S*"1T:&ES+3Y?9V5T541&:6QE*"1F:6QE*2D*("`@("`@("`I.PH@
M("`@?0H@("`@"B`@("`O*BH*("`@("`J($=E="!T:&4@9FEL92!T;R!S=&]R
M92!C86-H92!D871A(&EN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M($-A8VAE(&1A=&$@9FEL92!N86UE"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$9I;&4H)&9I;&4I"B`@("!["B`@
M("`@("`@)&1I<B`](&1I<FYA;64H)&9I;&4I.PH@("`@("`@("1F:6QE(#T@
M8F%S96YA;64H)&9I;&4I.PH@("`@("`@(')E='5R;B`D9&ER+B<O+B<N)&9I
M;&4["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@1V5T('1H92!F:6QE('1O
M('-T;W)E(&5X<&ER871I;VX@9&%T82!I;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!%>'!I<F%T:6]N(&1A=&$@9FEL92!N86UE"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$5X<$9I
M;&4H)&9I;&4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T1FEL
M92@D9FEL92DN)RYE>'`G.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J($=E
M="!T:&4@9FEL92!T;R!S=&]R92!U<V5R(&1A=&$@:6XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@57-E<B!D871A(&9I;&4@;F%M90H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G97151$9I
M;&4H)&9I;&4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T1FEL
M92@D9FEL92DN)RYD870G.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J($-A
M8VAE(&9I;&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"!#86-H
M92!)1`H@("`@("H@0'!A<F%M(&UI>&5D("1C86-H961A=&$@1&%T82!T;R!C
M86-H90H@("`@("H@0'!A<F%M(&UI>&5D("1E>'!I<F5S(%=H96X@=&AE(&1A
M=&$@97AP:7)E<PH@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@0V%C:&4@
M9W)O=7`@=&\@<W1O<F4@9&%T82!I;@H@("`@("H@0'!A<F%M(&UI>&5D("1U
M<V5R9&%T82!!9&1I=&EO;F%L(&1A=&$@=&\@<W1O<F4*("`@("`J($!R971U
M<FX@8F]O;&5A;B!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES90H@
M("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&-A8VAE9&%T82P@)&5X
M<&ER97,L("1G<F]U<"P@)'5S97)D871A*0H@("`@>PH@("`@("`@("1T:&ES
M+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D9FEL92`]
M("1T:&ES+3YG971&:6QE;F%M92@D:60L("1G<F]U<"D["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES+3Y?<V%V941A=&$H)&9I;&4L
M("1C86-H961A=&$I*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@
M("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES
M+3Y?<V%V941A=&$H)'1H:7,M/E]G971%>'!&:6QE*"1F:6QE*2P@)&5X<&ER
M97,I*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"B`@
M("`@("`@:68H4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'1H:7,M/E]S879E1&%T
M82@D=&AI<RT^7V=E=%5$1FEL92@D9FEL92DL("1U<V5R1&%T82DI*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E(&1A=&$@:6X@
M82!F:6QE"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92!&:6QE
M('1O('-A=F4@9&%T82!I;@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82!$
M871A('1O('-A=F4*("`@("`J($!R971U<FX@;6EX960@=')U92!O;B!S=6-C
M97-S+"!#86-H95]%<G)O<B!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-A=F5$871A*"1F:6QE+"`D9&%T82D@>PH@("`@("`@("\O(%-A=F4@
M9&%T80H@("`@("`@(&EF("@A*"1F:"`]($!F;W!E;B@D9FEL92P@)W=B)RDI
M*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#86XG="!A
M8V-E<W,@)R1F:6QE)R!T;R!S=&]R92!C86-H92!D871A+B!#:&5C:R!A8V-E
M<W,@<FEG:'1S(&%N9"!P871H+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@"B`@("`@("`@:68@*"1T:&ES+3YF:6QE3&]C:VEN9RD@>PH@("`@
M("`@("`@("!F;&]C:R@D9F@L($Q/0TM?15@I.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("!F=W)I=&4H)&9H+"`D9&%T82D["B`@("`@("`@"B`@("`@
M("`@:68H)'1H:7,M/F9I;&5,;V-K:6YG*2!["B`@("`@("`@("`@(&9L;V-K
M*"1F:"P@3$]#2U]53BD["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&9C
M;&]S92@D9F@I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0I]"@H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]D8G@N
M<&AP````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R-S4Q`#$P-3$U
M-#,Q,#4V`#`R,34V,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!#:')I<W1I86X@4W1O8VME
M<B`\8VAR96=U0'!H86YT+F-H/B`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&1B
M>"YP:'`L=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`H*"G)E
M<75I<F5?;VYC92`G0V%C:&4O0V]N=&%I;F5R+G!H<"<["@HO*BH**B!E>'0O
M9&)X($-A8VAE($-O;G1A:6YE<BX**@HJ(%=!4DY)3D<Z($]T:&5R('-Y<W1E
M;7,@;6EG:'0@;W(@;6EG:'0@;F]T('-U<'!O<G0@8V5R=&%I;B!D871A='EP
M97,@;V8@"BH@=&AE('1A8FQE<R!S:&]W;BX@07,@9F%R(&%S($D@:VYO=R!T
M:&5R92=S(&YO(&QA<F=E(&)I;F%R>2`**B!T>7!E(&EN(%-13"TY,B!O<B!3
M44PM.3DN(%!O<W1G<F5S('-E96US('1O(&QA8VL@86YY(`HJ($),3T(@;W(@
M5$585"!T>7!E+"!F;W(@35,M4U%,('EO=2!C;W5L9"!U<V4@24U!1T4L(&1O
M;B=T(&MN;W<@"BH@86)O=70@;W1H97(@9&%T86)A<V5S+B!0;&5A<V4@861D
M('-U9V5S=&EO;G,@9F]R(&]T:&5R(&1A=&%B87-E<R!T;R`**B!T:&4@:6YL
M:6YE(&1O8W,N"BH**B!4:&4@9FEE;&0@)V-H86YG960G(&AA<R!N;R!M96%N
M:6YG(&9O<B!T:&4@0V%C:&4@:71S96QF+B!)="=S(&IU<W0@=&AE<F4@"BH@
M8F5C875S92!I="=S(&$@9V]O9"!I9&5A('1O(&AA=F4@86X@875T;VUA=&EC
M86QL>2!U<&1A=&5D('1I;65S=&%M<`HJ(&9I96QD(&9O<B!D96)U9V=I;F<@
M:6X@86QL(&]F('EO=7(@=&%B;&5S+@HJ"BH@1F]R(%]->5-13%\@>6]U(&YE
M960@=&AI<R!$0B!T86)L93H**@HJ($-214%412!404),12!C86-H92`H"BH@
M("!I9"`@("`@("`@("!#2$%2*#,R*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ
M("`@8V%C:&5G<F]U<"`@5D%20TA!4B@Q,C<I($Y/5"!.54Q,($1%1D%53%0@
M)R<L"BH@("!C86-H961A=&$@("!"3$]"($Y/5"!.54Q,($1%1D%53%0@)R<L
M"BH@("!U<V5R9&%T82`@("!605)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,
M5"`G)RP**B`@(&5X<&ER97,@("`@($E.5"@Y*2!.3U0@3E5,3"!$149!54Q4
M(#`L"BH@(`HJ("`@8VAA;F=E9"`@("`@5$E-15-404U0*#$T*2!.3U0@3E5,
M3"P**B`@"BH@("!)3D1%6"`H97AP:7)E<RDL"BH@("!04DE-05)9($M%62`H
M:60L(&-A8VAE9W)O=7`I"BH@*0HJ"BH@0&%U=&AO<B`@($-H<FES=&EA;B!3
M=&]C:V5R(#QC:')E9W5`<&AA;G0N8V@^"BH@0'9E<G-I;VX@("1)9#H@9&)X
M+G!H<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"BH@0'!A
M8VMA9V4@($-A8VAE"BHO"F-L87-S($-A8VAE7T-O;G1A:6YE<E]D8G@@97AT
M96YD<R!#86-H95]#;VYT86EN97(@>PH*("`@("\J*@H@("`@*B!.86UE(&]F
M('1H92!$0B!T86)L92!T;R!S=&]R92!C86-H:6YG(&1A=&$*("`@("H@"B`@
M("`J($!S964@($-A8VAE7T-O;G1A:6YE<E]F:6QE.CHD9FEL96YA;65?<')E
M9FEX"B`@("`J+R`@"B`@("!V87(@)&-A8VAE7W1A8FQE(#T@)R<["@H@("`@
M+RHJ"B`@("`J($1">"!M;V1U;&4@=&\@=7-E"B`@("`J"B`@("`J("!A="!T
M:&4@;6]M96YT(&]N;'D@;7ES<6P@;W(@;V1B8PH@("`@*B`*("`@("H@0'9A
M<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1M;V1U;&4@/2`G)SL*"B`@("`O
M*BH*("`@("H@1$(@:&]S="!T;R!U<V4*("`@("H@"B`@("`J($!V87(@('-T
M<FEN9PH@("`@*B\*("`@('9A<B`D:&]S="`]("<G.PH*("`@("\J*@H@("`@
M*B!$0B!D871A8F%S92!T;R!U<V4*("`@("H@"B`@("`J($!V87(@('-T<FEN
M9PH@("`@*B\*("`@('9A<B`D9&(@/2`G)SL*"B`@("`O*BH*("`@("H@1$(@
M=7-E<FYA;64@=&\@=7-E"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@
M("HO"B`@("!V87(@)'5S97)N86UE(#T@)R<["@H@("`@+RHJ"B`@("`J($1"
M('!A<W-W;W)D('1O('5S90H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@
M("`J+PH@("`@=F%R("1P87-S=V]R9"`]("<G.PH*("`@("\J*@H@("`@*B!$
M0G@@:&%N9&QE(&]B:F5C=`H@("`@*B`*("`@("H@0'9A<B`@;V)J96-T($1"
M>"!H86YD;&4*("`@("HO"B`@("!V87(@)&1B.PH@("`@"B`@("`*("`@("\J
M*@H@("`@*B!%<W1A8FQI<V@@82!P97)S:7-T96YT(&-O;FYE8W1I;VX_"B`@
M("`J(`H@("`@*B!`=F%R("!B;V]L96%N(`H@("`@*B\*("`@('9A<B`D<&5R
M<VES=&5N="`]('1R=64["B`@("`*"B`@("!F=6YC=&EO;B!#86-H95]#;VYT
M86EN97)?9&)X*"1O<'1I;VYS*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R
M87DH)&]P=&EO;G,I("D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=.;R!O<'1I;VYS('-P96-I9FEE9"$G+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G-E=$]P=&EO;G,H
M)&]P=&EO;G,L("!A<G)A>5]M97)G92@D=&AI<RT^86QL;W=E9%]O<'1I;VYS
M+"!A<G)A>2@G;6]D=6QE)RPG:&]S="<L)V1B)RPG=7-E<FYA;64G+"=P87-S
M=V]R9"<L("=C86-H95]T86)L92<L("=P97)S:7-T96YT)RDI*3L*"B`@("`@
M("`@:68@*"$D=&AI<RT^;6]D=6QE*0H@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=.;R!M;V1U;&4@<W!E8VEF:65D(2<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@("1T:&ES+3YD8B`](&1B>%]C;VYN96-T
M*"1T:&ES+3YM;V1U;&4L("1T:&ES+3YH;W-T+"`D=&AI<RT^9&(L("1T:&ES
M+3YU<V5R;F%M92P@)'1H:7,M/G!A<W-W;W)D+"`D=&AI<RT^<&5R<VES=&5N
M="D["@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B*2D@>PH@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0G@@8V]N;F5C="!F
M86EL960Z("<@+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+VYO="!I
M;7!L96UE;G1E9"!Y970@:6X@9&)X"B`@("`@("`@("`@("\O)'1H:7,M/F1B
M+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O=7`I"B`@("![
M"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4T5,14-4(&-A8VAE9&%T82P@
M=7-E<F1A=&$L(&5X<&ER97,@1E)/32`E<R!72$5212!I9"`]("<E<R<@04Y$
M(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@
M(&%D9'-L87-H97,H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D
M9'-L87-H97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@("`@("`@("`I.PH*
M("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T:&ES+3YD8BP@)'%U97)Y*3L*
M("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@("`@("`@
M(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R>2!F86EL960Z("<@
M+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M"B`@("`@("`@)')O=R`]("1R97,M/F1A=&%;,%T["@H@("`@("`@(&EF("AI
M<U]A<G)A>2@D<F]W*2D*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@D<F]W
M6R=E>'!I<F5S)UTL("1T:&ES+3YD96-O9&4H)')O=ULG8V%C:&5D871A)UTI
M+"`D<F]W6R=U<V5R9&%T82==*3L*("`@("`@("!E;'-E(`H@("`@("`@("`@
M("`D9&%T82`](&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH*("`@("`@("`O
M+R!L87-T('5S960@<F5Q=6ER960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO
M;B`@(`H@("`@("`@("\O(%=!4DY)3D<Z(&UI9VAT(&)E($UY4U%,('-P96-I
M9FEC("`@("`@("`@"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B55!$051%
M("5S(%-%5"!C:&%N9V5D(#T@*$Y/5R@I("L@,"D@5TA%4D4@:60@/2`G)7,G
M($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@(`H@("`@("`@("1R97,@/2!D8GA?<75E
M<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH@("`@("`@(&EF("AD8GA?97)R;W(H
M)'1H:7,M/F1B*2D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@G1$)X('%U97)Y(&9A:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI<RT^9&(I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@"B`@("`@("`@("`@(`H@("`@("`@(')E='5R;B`D9&%T83L@("`@
M("`@("`@("`*("`@('T*"B`@("`O*BH*("`@("H@4W1O<F5S(&$@9&%T87-E
M="X*("`@("H@"B`@("`J(%=!4DY)3D<Z('=E('5S92!T:&4@4U%,(&-O;6UA
M;F0@4D503$%#12!)3E1/('1H:7,@;6EG:'0@8F4@"B`@("`J($UY4U%,('-P
M96-I9FEC+B!!<R!->5-13"!I<R!V97)Y('!O<'5L87(@=&AE(&UE=&AO9"!S
M:&]U;&0*("`@("H@=V]R:R!F:6YE(&9O<B`Y-24@;V8@>6]U+@H@("`@*B\*
M("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T82P@)&5X<&ER97,L("1G<F]U
M<"P@)'5S97)D871A*0H@("`@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO
M860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*")2
M15!,04-%($E.5$\@)7,@*'5S97)D871A+"!C86-H961A=&$L(&5X<&ER97,L
M(&ED+"!C86-H96=R;W5P*2!604Q515,@*"<E<R<L("<E<R<L("5D+"`G)7,G
M+"`G)7,G*2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C
M:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S
M*"1U<V5R9&%T82DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S
M:&5S*"1T:&ES+3YE;F-O9&4H)&1A=&$I*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YG971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I("P*
M("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&ED*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&=R;W5P*0H@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@9&)X7W%U
M97)Y*"1T:&ES+3YD8BP@)'%U97)Y*3L*"B`@("`@("`@:68@*&1B>%]E<G)O
M<B@D=&AI<RT^9&(I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?
M17)R;W(H)T1">"!Q=65R>2!F86EL960Z("<@+B!D8GA?97)R;W(H)'1H:7,M
M/F1B*2`L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(')E;6]V92@D:60L("1G<F]U<"D*("`@('L*("`@("`@
M("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($923TT@)7,@5TA%4D4@:60@/2`G
M)7,G(&%N9"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@("`@
M("`@*3L*"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q
M=65R>2D["@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B*2D*("`@
M("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X('%U97)Y(&9A
M:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@?0H*("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"`]("<G
M*0H@("`@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*"B`@("`@
M("`@:68@*"1G<F]U<"D@>PH@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*")$14Q%5$4@1E)/32`E<R!72$5212!C86-H96=R;W5P(#T@)R5S)R(L("1T
M:&ES+3YC86-H95]T86)L92P@861D<VQA<VAE<R@D9W)O=7`I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*")$14Q%
M5$4@1E)/32`E<R(L("1T:&ES+3YC86-H95]T86)L92D["B`@("`@("`@?0H*
M("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T:&ES+3YD8BPD<75E<GDI.PH*
M("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@("`@("`@
M(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R>2!F86EL960Z("<@
M+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D*("`@
M('L*("`@("`@("`D<75E<GD@/2!S<')I;G1F*")314Q%0U0@:60@1E)/32`E
M<R!72$5212!)1"`]("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@
M("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&ED*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&=R;W5P*0H@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@9&)X7W%U97)Y
M*"1T:&ES+3YD8BP@)'%U97)Y*3L*"B`@("`@("`@:68@*&1B>%]E<G)O<B@D
M=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H*("`@("`@("`D<F]W(#T@)')E<ULP
M73L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V%R
M8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE*0H@("`@>PH@("`@("`@("1T
M:&ES+3YF;'5S:%!R96QO860H*3L*("`@("`@("`*("`@("`@("`D<75E<GD@
M/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212`H97AP:7)E<R`\/2`E
M9"!!3D0@97AP:7)E<R`^(#`I($]2(&-H86YG960@/#T@*$Y/5R@I("T@)60I
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M92P*("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1M87AL:69E=&EM90H@("`@("`@("`@("`@("`@
M("`@("`@("D["@H*("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T:&ES+3YD
M8BP@)'%U97)Y*3L*"B`@("`@("`@:68@*&1B>%]E<G)O<B@D=&AI<RT^9&(I
M*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0G@@<75E
M<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)W-E;&5C
M="!S=6TH;&5N9W1H*&-A8VAE9&%T82DI(&%S($-A8VAE4VEZ92!F<F]M("5S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M90H@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("1R97,@/2!D
M8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH@("`@("`@("\O:68@8V%C
M:&4@:7,@=&\@8FEG+@H@("`@("`@(&EF("@D<F5S+3YD871A6S!=6T-A8VAE
M4VEZ95T@/B`D=&AI<RT^:&EG:'=A=&5R*0H@("`@("`@('L*("`@("`@("`@
M("`@+R]F:6YD('1H92!L;W=W871E<B!M87)K+@H@("`@("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=S96QE8W0@;&5N9W1H*&-A8VAE9&%T82D@87,@<VEZ
M92P@8VAA;F=E9"!F<F]M("5S(&]R9&5R(&)Y(&-H86YG960@1$530R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C
M:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`@
M("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D["B`@("`@
M("`@("`@("1K965P7W-I>F4],#L*("`@("`@("`@("`@)&D],#L*("`@("`@
M("`@("`@=VAI;&4@*"1K965P7W-I>F4@/"`D=&AI<RT^;&]W=V%T97(@)B8@
M)&D@/"`D<F5S+3YR;W=S("D*("`@("`@("`@("`@>PH*("`@("`@("`@("`@
M("`@("1K965P7W-I>F4@*ST@)')E<RT^9&%T85LD:5U;<VEZ95T["B`@("`@
M("`@("`@("`@("`D:2LK.PH@("`@?0H@("`@"B`@("`@("`@("`@("\O9&5L
M971E(&%L;"!E;G1R:65S+"!W:&EC:"!W97)E(&-H86YG960@8F5F;W)E('1H
M92`B;&]W=W=A=&5R(&UA<FLB"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H)V1E;&5T92!F<F]M("5S('=H97)E(&-H86YG960@/#T@)7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E<RT^9&%T85LD:5U;8VAA;F=E9%T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`D<F5S(#T@9&)X7W%U97)Y
M*"1T:&ES+3YD8BP@)'%U97)Y*3L*("`@("`@("!]"B`@("!]"GT*/SX`````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]#86-H92]%<G)O<BYP:'``````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S0U,P`Q,#4Q-30S,3`U-@`P,C`Q-3(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H
M92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@
M=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA
M8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!%<G)O<BYP:'`L=B`Q+C,@,C`P,R\P
M,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=014%2+G!H
M<"<["@HO*BH**B!#86-H92!%<G)O<B!C;&%S<PHJ(`HJ($!P86-K86=E($-A
M8VAE"BHO"F-L87-S($-A8VAE7T5R<F]R(&5X=&5N9',@4$5!4E]%<G)O<B![
M"@H*("`O*BH*("`J(%!R969I>"!O9B!A;&P@97)R;W(@;65S<V%G97,N"B`@
M*B`*("`J($!V87(@('-T<FEN9PH@("HO"B`@=F%R("1E<G)O<E]M97-S86=E
M7W!R969I>"`]("=#86-H92U%<G)O<CH@)SL*("`*("`O*BH*("`J($-R96%T
M97,@86X@8V%C:&4@97)R;W(@;V)J96-T+@H@("H@"B`@*B!`<&%R86T@('-T
M<FEN9R`@97)R;W(@;65S<V%G90H@("H@0'!A<F%M("!S=')I;F<@(&9I;&4@
M=VAE<F4@=&AE(&5R<F]R(&]C8W5R960*("`J($!P87)A;2`@<W1R:6YG("!L
M:6YE;G5M8F5R('=H97)E('1H92!E<G)O<B!O8V-U<F5D"B`@*B\*("!F=6YC
M=&EO;B!#86-H95]%<G)O<B@D;7-G+"`D9FEL92`](%]?1DE,15]?+"`D;&EN
M92`](%]?3$E.15]?*2!["B`@("`*("`@("1T:&ES+3Y014%27T5R<F]R*'-P
M<FEN=&8H(B5S(%LE<R!O;B!L:6YE("5D72XB+"`D;7-G+"`D9FEL92P@)&QI
M;F4I*3L*("`@(`H@('T@+R\@96YD(&9U;F,@0V%C:&5?17)R;W(*("`*?2`O
M+R!E;F0@8VQA<W,@0V%C:&5?17)R;W(*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M0V%C:&4O1G5N8W1I;VXN<&AP````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3$P-S4`,3`U,34T,S$P-38`,#(P-C0U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O
M('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO
M<G,Z(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@1G5N8W1I;VXN<&AP+'8@,2XV(#(P,#,O,#$O
M,#0@,3$Z-30Z-#4@;6H@17AP("0*"G)E<75I<F5?;VYC92`G0V%C:&4N<&AP
M)SL*"B\J*@HJ($9U;F-T:6]N7T-A8VAE"BH**B!0=7)P;W-E.@HJ"BH@("!#
M86-H:6YG('1H92!R97-U;'0@86YD(&]U='!U="!O9B!F=6YC=&EO;G,N"BH*
M*B!%>&%M<&QE.@HJ"BH@("!R97%U:7)E7V]N8V4@)T-A8VAE+T9U;F-T:6]N
M+G!H<"<["BH**B`@(&-L87-S(&9O;R!["BH@("`@(&9U;F-T:6]N(&)A<B@D
M=&5S="D@>PHJ("`@("`@(&5C:&\@(F9O;SHZ8F%R*"1T97-T*3QB<CXB.PHJ
M("`@("!]"BH@("!]"BH**B`@(&-L87-S(&)A<B!["BH@("`@(&9U;F-T:6]N
M(&9O;V)A<B@D;V)J96-T*2!["BH@("`@("`@96-H;R`G)"<N)&]B:F5C="XG
M+3YF;V]B87(H)RXD;V)J96-T+B<I/&)R/B<["BH@("`@('T**B`@('T**@HJ
M("`@)&)A<B`](&YE=R!B87(["BH**B`@(&9U;F-T:6]N(&9O;V)A<B@I('L*
M*B`@("`@96-H;R`G9F]O8F%R*"DG.PHJ("`@?0HJ"BH@("`D8V%C:&4@/2!N
M97<@0V%C:&5?1G5N8W1I;VXH*3L**@HJ("`@)&-A8VAE+3YC86QL*"=F;V\Z
M.F)A<B<L("=T97-T)RD["BH@("`D8V%C:&4M/F-A;&PH)V)A<BT^9F]O8F%R
M)RP@)V)A<B<I.PHJ("`@)&-A8VAE+3YC86QL*"=F;V]B87(G*3L**@HJ($YO
M=&4Z"BH@"BH@("!9;W4@8V%N;F]T(&-A8VAE(&5V97)Y(&9U;F-T:6]N+B!9
M;W4@<VAO=6QD(&]N;'D@8V%C:&4@"BH@("!F=6YC=&EO;G,@=&AA="!O;FQY
M(&1E<&5N9"!O;B!T:&5I<B!A<F=U;65N=',@86YD(&1O;B=T('5S90HJ("`@
M9VQO8F%L(&]R('-T871I8R!V87)I86)L97,L(&1O;B=T(')E;'D@;VX@9&%T
M86)A<V4@<75E<FEE<R!O<B`**B`@(&9I;&5S+"!A;F0@<V\@;VXN"BH@"BH@
M0&%U=&AO<B`@("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA
M;BUB97)G;6%N;BYD93X**B!`;6]D=6QE("`@("`@($9U;F-T:6]N7T-A8VAE
M"BH@0&UO9'5L96=R;W5P("!&=6YC=&EO;E]#86-H90HJ($!P86-K86=E("`@
M("`@0V%C:&4**B!`=F5R<VEO;B`@("`@("12979I<VEO;CH@,2XV("0**B!`
M86-C97-S("`@("`@('!U8FQI8PHJ+PIC;&%S<R!#86-H95]&=6YC=&EO;B!E
M>'1E;F1S($-A8VAE('L*("`@('9A<B`D97AP:7)E<SL*"B`@("`O*BH*("`@
M("H@0V]N<W1R=6-T;W(*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M3F%M92!O9B!C;VYT86EN97(@8VQA<W,*("`@("H@0'!A<F%M("`@(&%R<F%Y
M("`@07)R87D@=VET:"!C;VYT86EN97(@8VQA<W,@;W!T:6]N<PH@("`@*B!`
M<&%R86T@("`@:6YT96=E<B!.=6UB97(@;V8@<V5C;VYD<R!F;W(@=VAI8V@@
M=&\@8V%C:&4*("`@("HO"B`@("!F=6YC=&EO;B!#86-H95]&=6YC=&EO;B@D
M8V]N=&%I;F5R("`]("=F:6QE)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYT86EN97)?;W!T:6]N<R`](&%R<F%Y*"=C86-H95]D:7(G("`@
M("`@(#T^("<N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=F:6QE;F%M95]P<F5F:7@G(#T^("=C
M86-H95\G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D97AP:7)E<R`](#,V,#`*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*0H@("`@>PH@("`@("`D=&AI<RT^0V%C:&4H)&-O;G1A:6YE<BP@)&-O;G1A
M:6YE<E]O<'1I;VYS*3L*("`@("`@)'1H:7,M/F5X<&ER97,@/2`D97AP:7)E
M<SL@("`@("`*("`@('T*"B`@("`O*BH*("`@("H@4$5!4BU$96-O;G-T<G5C
M=&]R"B`@("`J($-A;&P@9&5C;VYS=')U8W1O<B!O9B!P87)E;G0*("`@("HO
M"B`@("!F=6YC=&EO;B!?0V%C:&5?1G5N8W1I;VXH*2!["B`@("`@("`@)'1H
M:7,M/E]#86-H92@I.PH@("`@?0H*("`@("\J*@H@("`@*B!#86QL<R!A(&-A
M8VAE86)L92!F=6YC=&EO;B!O<B!M971H;V0N"B`@("`J"B`@("`J($!R971U
M<FX@;6EX960@)')E<W5L=`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N(&-A;&PH*2!["B`@("`@("`@+R\@9V5T(&%R9W5M96YT
M<PH@("`@("`@("1A<F=U;65N=',@/2!F=6YC7V=E=%]A<F=S*"D["@H@("`@
M("`@("\O(&=E;F5R871E(&-A8VAE(&ED"B`@("`@("`@)&ED(#T@;60U*'-E
M<FEA;&EZ92@D87)G=6UE;G1S*2D["@H@("`@("`@("\O('%U97)Y(&-A8VAE
M"B`@("`@("`@)&-A8VAE9%]O8FIE8W0@/2`D=&AI<RT^9V5T*"1I9"P@)V9U
M;F-T:6]N7V-A8VAE)RD["@H@("`@("`@(&EF("@D8V%C:&5D7V]B:F5C="`A
M/2!.54Q,*2!["B`@("`@("`@("`@("\O(&-A8VAE(&AI=#H@<F5T=7)N(&-A
M8VAE9"!O=71P=70@86YD(')E<W5L=`H*("`@("`@("`@("`@)&]U='!U="`]
M("1C86-H961?;V)J96-T6S!=.PH@("`@("`@("`@("`D<F5S=6QT(#T@)&-A
M8VAE9%]O8FIE8W1;,5T["@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O(&-A8VAE(&UI<W,Z(&-A;&P@9G5N8W1I;VXL('-T;W)E(&]U='!U="!A
M;F0@<F5S=6QT(&EN(&-A8VAE"@H@("`@("`@("`@("!O8E]S=&%R="@I.PH@
M("`@("`@("`@("`D=&%R9V5T(#T@87)R87E?<VAI9G0H)&%R9W5M96YT<RD[
M"@H@("`@("`@("`@("`O+R!C;&%S<VYA;64Z.G-T871I8TUE=&AO9`H@("`@
M("`@("`@("!I9B`H<W1R<W1R*"1T87)G970L("<Z.B<I*2!["B`@("`@("`@
M("`@("`@("!L:7-T*"1C;&%S<RP@)&UE=&AO9"D@/2!E>'!L;V1E*"<Z.B<L
M("1T87)G970I.PH*("`@("`@("`@("`@("`@("1R97-U;'0@/2!C86QL7W5S
M97)?9G5N8U]A<G)A>2AA<G)A>2@D8VQA<W,L("1M971H;V0I+"`D87)G=6UE
M;G1S*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@;V)J96-T+3YM
M971H;V0*("`@("`@("`@("`@96QS96EF("AS=')S='(H)'1A<F=E="P@)RT^
M)RDI('L*("`@("`@("`@("`@("`@(&QI<W0H)&]B:F5C="P@)&UE=&AO9"D@
M/2!E>'!L;V1E*"<M/B<L("1T87)G970I.PH@("`@("`@("`@("`@("`@9VQO
M8F%L("0D;V)J96-T.PH*("`@("`@("`@("`@("`@("1R97-U;'0@/2!C86QL
M7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D)&]B:F5C="P@)&UE=&AO9"DL("1A
M<F=U;65N=',I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!F=6YC
M=&EO;@H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2!C86QL7W5S97)?9G5N8U]A<G)A>2@D=&%R9V5T+"`D87)G=6UE;G1S
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U="`](&]B7V=E
M=%]C;VYT96YT<R@I.PH@("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@
M("`@("`@("`@("1T:&ES+3YS879E*"1I9"P@87)R87DH)&]U='!U="P@)')E
M<W5L="DL("1T:&ES+3YE>'!I<F5S+"`G9G5N8W1I;VY?8V%C:&4G*3L*("`@
M("`@("!]"@H@("`@("`@(&5C:&\@)&]U='!U=#L*("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@('T*?0H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T-A8VAE+T=R87!H:6-S+G!H<```````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,P-3<P`#$P-3$U-#,Q,#4V`#`R,#8R,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A
M8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($=R87!H:6-S+G!H<"QV(#$N-2`R
M,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)T-A
M8VAE+G!H<"<["@HO*BH**B!'<F%P:&EC<R!D:7-K(&-A8VAE+@HJ(`HJ(%1H
M92!U<W5A;"!W87D@=&\@8W)E871E(&EM86=E<R!I<R!T;R!P87-S('-O;64@
M87)G=6UE;G1S('1H870@9&5S8W)I8F4@=&AE(&EM86=E(`HJ('1O(&$@<V-R
M:7!T('1H870@9'EN86UI8V%L;'D@8W)E871E<R!A;B!I;6%G92X@1F]R(&5V
M97)Y(&EM86=E(&]F(&$@<&%G92`**B!A(&YE=R!02%`@:6YT97)P<F5T97(@
M9V5T<R!S=&%R=&5D+B!4:&ES(&ES(&$@9V]O9"!W87D@=&\@:VEL;"!Y;W5R
M('=E8G-E<G9E<BX**B`**B!7:&5N(&1E86QI;F<@=VET:"!D>6YA;6EC86QL
M>2!G96YE<F%T960@:6UA9V5S('EO=2!S:&]U;&0@;F]T(&-A;&P@86YO=&AE
M<B!S8W)I<'0@"BH@=&\@9V5N97)A=&4@=&AE(&EM86=E<R!B=70@9V5N97)A
M=&4@=&AE(&EM86=E<R!B>2!T:&4@<V-R:7!T('1H870@<')O9'5C97,@=&AE
M('!A9V4**B!T:&%T(&-O;G1A:6YS('1H92!I;6%G97,N(%1H:7,@:7,@82!M
M86IO<B!I;7!R;W9E;65N="!B=70@:70G<R!O;FQY(&AA;&8@=&AE('=A>2X*
M*B`**B!4:&5R92=S(&YO(&YE960@=&\@<F5R96YD97(@86X@:6UA9V4@;VX@
M979E<GD@<F5Q=65S="X@02!S:6UP;&4@9&ES:R!C86-H92!C86X@<F5D=6-E
M"BH@=&AE(&-O;7!U=&%T:6]N('1I;64@9')A;6%T:6-A;&QY+B!4:&ES(&ES
M('=H870@=&AE(&-L87-S(&=R87!H:6-S7V-A8VAE(&ES(&9O<BX@"BH@"BH@
M57-A9V4Z"BH@"BH@+R\@8W)E871E(&%N(&EN<W1A;F-E(&]F('1H92!G<F%P
M:&EC<R!C86-H90HJ("1C86-H92`](&YE=R!G<F%P:&EC<U]C86-H93L**@HJ
M("1I;6<@/2!);6%G94-R96%T92@N+BXI.PHJ"BH@+R\@8V]M<'5T92!A;B!)
M1"!F;W(@>6]U<B!I;6%G92!B87-E9"!O;B!T>7!I8V%L('!A<F%M971E<G,*
M*B`D:60@/2!M-60H("1S:7IE+"`D8V]L;W)S+"`D;&%B96PI.PHJ(`HJ("\O
M(&-H96-K(&EF(&ET)W,@8V%C:&5D"BH@:68@*"$H)&QI;FL@/2`D8V%C:&4M
M/F=E=$EM86=E3&EN:R@D:60L("=G:68G*2DI('L**B`@"BH@("`O+R!H;6UM
M+"!I="=S(&YO="!C86-H960L(&-R96%T92!I=`HJ("`@+BXN"BH@("`O+R!C
M86-H94EM86=E3&EN:R@I(&%N9"!C86-H94EM86=E*"D@;6%K92!T:&4@26UA
M9V5'248H*2!C86QL(0HJ("`@+R\@8V%C:&5);6%G92@I(')E='5R;G,@=&AE
M('9A;'5E(&]F($EM86=E1TE&*"D@6V5T8RY=+"!C86-H94EM86=E3&EN:R@I
M(')E='5R;G,@82!54DP**B`@("1L:6YK(#T@)&-A8VAE+3YC86-H94EM86=E
M3&EN:R@D:60L("1I;6<L("=G:68G*3L**B`**B!]"BH**B`O+R!/:RP@;&5T
M)W,@8G5I;&0@=&AE($EM86=E3&EN:PHJ("1S:7IE(#T@9V5T26UA9V53:7IE
M*"1L:6YK6S!=*3L**B!P<FEN=&8H)SQI;6<@<W)C/2(E<R(@)7,^)RP@)&QI
M;FM;,5TL("1S:7IE6S-=*3L**@HJ("\O(&9O<B!C86-H94EM86=E*"DZ"BH@
M+R\@:&5A9&5R*"=#;VYT96YT+71Y<&4Z(&EM86=E+V=I9B<I.R!P<FEN="`D
M8V%C:&4M/F-A8VAE26UA9V4H)&ED+"`D:6UG+"`G9VEF)RD["BH@"BH**B!4
M:&4@8VQA<W,@<F5Q=6ER97,@4$A0(#0N,"XR*R!;26UA9V54>7!E*"E=+B!.
M;W1E('1H870@8V%C:&5);6%G92@I('=O<FMS('=I=&@**B!T:&4@;W5T<'5T
M(&)U9F9E<BX@36]D:69Y(&ET(&EF(')E<75I<F5D(0HJ"BH@0&%U=&AO<B`@
M(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S:6]N
M("`D260Z($=R87!H:6-S+G!H<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0U
M(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BHO"F-L87-S($-A8VAE7T=R
M87!H:6-S(&5X=&5N9',@0V%C:&4@>PH*"B`@("`O*BH*("`@("H@0V%C:&4@
M55),('!R969I>"X*("`@("H@"B`@("`J($UA:V4@<W5R92!T:&%T('1H92!C
M86-H92!54DP@<')E9FEX('!O:6YT<R!T;R!T:&4@)&-A8VAE7V1I<BP@;W1H
M97)W:7-E"B`@("`J('EO=7(@;&EN:W,@=VEL;"!B92!B<F]K96XN(%5S92!S
M971#86-H95523"!T;R!S<&5C:69Y('1H92!C86-H95]U<FP@86YD(`H@("`@
M*B!S971#86-H941I<B@I(&9O<B!T:&4@8V%C:&5?9&ER+@H@("`@*B`*("`@
M("H@0'9A<B`@<W1R:6YG"B`@("`J($!S964@('-E=$-A8VAE55),*"DL('-E
M=$-A8VAE1&ER*"D*("`@("HO"B`@("!V87(@)&-A8VAE7W5R;"`]("<G.PH*
M("`@("\J*@H@("`@*B!$:7)E8W1O<GD@=VAE<F4@8V%C:&5D(&9I;&5S(&=E
M="!S=&]R960N"B`@("`J(',*("`@("H@36%K92!S=7)E('1H870@=&AE(&-A
M8VAE7V1I<B!I<R!W<FET86)L92!A;F0@;V9F97)S(&5N;W5G:"!S<&%C92X@
M0VAE8VL@"B`@("`J(&%L<V\@:68@>6]U<B!C86-H95]U<FP@<&]I;G1S('1O
M('1H92!D:7)E8W1O<GDN(%5S92!S971#86-H941I<B@I('1O('-E=`H@("`@
M*B!T:&4@=F%R:6%B;&4N"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@
M("H@0'-E92`@<V5T0V%C:&5$:7(H*2P@<V5T0V%C:&554DPH*0H@("`@*B\*
M("`@('9A<B`D8V%C:&5?9&ER(#T@)R<["@H@("`@+RHJ"B`@("`J($YA;65P
M<F5F:7@@;V8@8V%C:&5D(&9I;&5S+@H@("`@*B`*("`@("H@4&5R(&1E9F%U
M;'0@=&AE('!R969I>"`B9W)A<&AI8W-?(B!G971S('5S960N(%EO=2!M:6=H
M="!U<V4@=&AI<R`*("`@("H@9F]R('9E<G-I;VYI;F<@;W(@=&\@96%S92`H
M;6%N=6%L*2!C;&5A;B!U<',N"B`@("`J"B`@("`J($!V87(@("`@("!S=')I
M;F<*("`@("HO"B`@("!V87(@)&-A8VAE7V9I;&5?<')E9FEX(#T@)V=R87!H
M:6-S7R<["B`@("`*("`@(`H@("`@+RHJ"B`@("`J($-A8VAE(&-O;G1A:6YE
M<B!G<F]U<"X*("`@("H*("`@("H@0'9A<B`@("`@('-T<FEN9PH@("`@*B\*
M("`@('9A<B`D8V%C:&5?9W)O=7`@/2`G9W)A<&AI8W,G.PH*("`@(`H@("`@
M+RHJ"B`@("`J($UA<'!I;F<@9G)O;2!S=7!P;W)T960@:6UA9V4@='EP92!T
M;R!A($EM86=E5'EP92@I(&-O;G-T86YT+@H@("`@*B`*("`@("H@4F5F97)R
M('1O('1H92!02%`@;6%N=6%L(&9O<B!M;W)E(&EN9F]R;6%T:6]N<R!O;B!)
M;6%G951Y<&4H*0H@("`@*B`*("`@("H@0'9A<B`@87)R87D*("`@("H@0&QI
M;FL@:'1T<#HO+W=W=RYP:'`N;F5T+TEM86=E5'EP90H@("`@*B\*("`@('9A
M<B`D:6UA9V5T>7!E<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=G:68G("`@/3X@24U'7T=)1BP@"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VIP9R<@("`]/B!)34=?2E!'+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=P;F<G("`@/3X@24U'7U!.1RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=V)M<"<@(#T^($E-
M1U]70DU0"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(`H@("`@+RHJ"B`@("`J($EN<W1A;G1I
M871E<R!A(&-A8VAE(&9I;&4@8V]N=&%I;F5R+@H@("`@*@H@("`@*B\*("`@
M(&9U;F-T:6]N($-A8VAE7T=R87!H:6-S*"D@>PH@("`@"B`@("`@("`@)'1H
M:7,M/D-A8VAE*"=F:6QE)RP@87)R87DH)V-A8VAE7V1I<B<@/3X@)'1H:7,M
M/F-A8VAE7V1I<BP@)V9I;&5N86UE7W!R969I>"<@/3X@)'1H:7,M/F-A8VAE
M7V9I;&5?<')E9FEX*2D["B`@("`@("`@"B`@("!]("\O(&5N9"!C;VYS=')U
M8W1O<@H*("`@(`H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G0@
M;V8@82!C86-H960@:6UA9V4@9FEL92X*("`@("H@"B`@("`J(%1H:7,@9G5N
M8W1I;VX@8V%N(&)E('5S960@=&\@<V5N9"!T:&4@:6UA9V4@9&ER96-T;'D@
M=&\@=&AE(&)R;W=S97(N"B`@("`J($UA:V4@<W5R92!T:&%T('EO=2!S96YD
M(&$@8V]R<F5S<&]N9&5N9&EN9R!H96%D97(@8F5F;W)E('-E;F1I;F<@=&AE
M(&EM86=E(&ET<V5L9BX*("`@("H*("`@("H@06QW87ES('1R>2!T;R!G970@
M=&AE(&EM86=E(&9R;VT@=&AE(&-A8VAE(&)E9F]R92!Y;W4@8V]M<'5T92!I
M="X@4V5E(`H@("`@*B!T:&4@8VQA<W,@9&]C<R!F;W(@86X@97AA;7!L92X*
M("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@26UA9V4M240*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@26UA9V4@='EP93H@9VEF+"!J<&<L('!N9RP@
M=V)M<`H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!);6%G92!F:6QE(&-O;G1E
M;G1S(&EF(&$@8V%C:&5D(&9I;&4@97AI<W1S(&]T:&5R=VES92!A;B!E;7!T
M>2!S=')I;F<*("`@("H@0'-E92`@("`@(&-A8VAE26UA9V4H*0H@("`@*B\@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`*("`@(&9U;F-T
M:6]N(&=E=$EM86=E*"1I9"P@)&9O<FUA="`]("=P;F<G*2!["B`@("`@("`@
M)&ED(#T@)'1H:7,M/F=E;F5R871E240H)&ED+"`D9F]R;6%T*3L*("`@("`@
M("`*("`@("`@("!R971U<FX@)'1H:7,M/F=E="@D:60L("1T:&ES+3YC86-H
M95]G<F]U<"D["B`@("!]("\O(&5N9"!F=6YC(&=E=$EM86=E"@H@("`@"B`@
M("`O*BH*("`@("H@4F5T=7)N<R!A;B!A<G)A>2!W:71H(&$@;&EN:R!T;R!T
M:&4@8V%C:&5D(&EM86=E(&%N9"!T:&4@:6UA9V4@9FEL92!P871H+@H@("`@
M*B`*("`@("H@06QW87ES('1R>2!T;R!G970@=&AE(&EM86=E(&9R;VT@=&AE
M(&-A8VAE(&)E9F]R92!Y;W4@8V]M<'5T92!I="X@4V5E(`H@("`@*B!T:&4@
M8VQA<W,@9&]C<R!F;W(@86X@97AA;7!L92X*("`@("H*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@26UA9V4M240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M26UA9V4@='EP93H@9VEF+"!J<&<L('!N9RP@=V)M<`H@("`@*B!`<F5T=7)N
M("`@87)R87D@("!;(&9U;&P@<&%T:"!T;R!T:&4@:6UA9V4@9FEL92P@:6UA
M9V4@=7)L(%T*("`@("H@0'1H<F]W("`@($-A8VAE7T5R<F]R"B`@("`J($!S
M964@("`@("!C86-H94EM86=E3&EN:R@I"B`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T26UA9V5,:6YK*"1I9"P@)&9O<FUA="`]("=P;F<G*2!["B`@("`@("`@
M)&ED(#T@)'1H:7,M/F=E;F5R871E240H)&ED+"`D9F]R;6%T*3L*("`@("`@
M("!I9B`H(21T:&ES+3YC;VYT86EN97(M/FED17AI<W1S*"1I9"P@)'1H:7,M
M/F-A8VAE7V=R;W5P*2D@"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH*
M("`@("`@("`D9FEL92`]("1T:&ES+3YC86-H95]U<FP@+B`D=&AI<RT^8V%C
M:&5?9FEL95]P<F5F:7@@+B`D:60["@H@("`@("`@(')E='5R;B!A<G)A>2@D
M=&AI<RT^8V]N=&%I;F5R+3YG971&:6QE;F%M92@D:60L("1T:&ES+3YC86-H
M95]G<F]U<"DL("1F:6QE*3L*("`@('T@+R\@96YD(&9U;F,@9V5T26UA9V5,
M:6YK"B`@("`*"B`@("`O*BH*("`@("H@0W)E871E(&%N(&EM86=E(&9R;VT@
M=&AE(&=I=F5N(&EM86=E(&AA;F1L97(L(&-A8VAE(&ET(&%N9"!R971U<FX@
M=&AE(&9I;&4@8V]N=&5N="X*("`@("H*("`@("H@06QW87ES('1R>2!T;R!R
M971R:79E('1H92!I;6%G92!F<F]M('1H92!C86-H92!B969O<F4@>6]U(&-O
M;7!U=&4@:70N"B`@("`J(`H@("`@*B!787)N:6YG.B!T:&ES(&9U;F-T:6]N
M('5S97,@=&AE(&]U='!U="!B=69F97(N($EF('EO=2!E>'!E8W0@8V]L;&ES
M:6]N<R`*("`@("H@;6]D:69Y('1H92!C;V1E+@H@("`@*@H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("!);6%G92U)1"X@57-E9"!A<R!A('!A<G0@;V8@=&AE
M(&-A8VAE(&9I;&5N86UE+@H@("`@*B`@("`@("`@("`@("`@("`@("!5<V4@
M;60U*"D@=&\@9V5N97)A=&4@82`B=6YI<75E(B!)1"!F;W(@>6]U<B!I;6%G
M90H@("`@*B`@("`@("`@("`@("`@("`@("!B87-E9"!O;B!C:&%R86-T97)I
M<W1I8R!V86QU97,@<W5C:"!A<R!T:&4@8V]L;W(L('-I>F4@971C+@H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!);6%G92!H86YD;&5R('1O(&-R96%T92!T
M:&4@:6UA9V4@9G)O;2X*("`@("H@0'!A<F%M("`@('-T<FEN9R`@26UA9V4@
M='EP93H@9VEF+"!J<&<L('!N9RP@=V)M<"X@06QS;R!U<V5D(&%S(&9I;&5N
M86UE('-U9F9I>"X*("`@("H@("`@("`@("`@("`@("`@("`@268@86X@=6YS
M=7!P;W)T960@='EP92!I<R!R97%U97-T960@=&AE(&9U;F-T:6]N<R!T<FEE
M<R!T;R`*("`@("H@("`@("`@("`@("`@("`@("`@9F%L;&)A8VL@=&\@82!S
M=7!P;W)T960@='EP92!B969O<F4@=&AR;W=I;F<@86X@97AE<'1I;VXN"B`@
M("`J($!R971U<FX@("!S=')I;F<@($EM86=E(&-O;G1E;G0@<F5T=7)N960@
M8GD@26UA9V5'248O+BXN(`H@("`@*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@9V5T26UA
M9V4H*0H@("`@*B\*("`@(&9U;F-T:6]N(&-A8VAE26UA9V4H)&ED+"`D:6UG
M+"`D9F]R;6%T(#T@)W!N9R<I('L*("`@("`@("!I9B`H(21I9"D*("`@("`@
M("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G66]U(&UU<W0@<')O=FED
M92!A;B!)1"!F;W(@86YD(&EM86=E('1O(&)E(&-A8VAE9"$G+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH*("`@("`@("`D:60@/2`D=&AI<RT^9V5N97)A=&5)
M1"@D:60L("1F;W)M870I.PH@("`@("`@("1T>7!E<R`]($EM86=E5'EP97,H
M*3L*"B`@("`@("`@+R\@0VAE8VL@:68@=&AE(')E<75E<W1E9"!I;6%G92!T
M>7!E(&ES('-U<'!O<G1E9"!B>2!T:&4@1T0@;&EB+@H@("`@("`@("\O($EF
M(&YO="P@=')Y(&$@8V%L;&)A8VL@=&\@=&AE(&9I<G-T(&%V86EL86)L92!I
M;6%G92!T>7!E+@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/FEM86=E='EP
M97-;)&9O<FUA=%TI('Q\("$H)'1Y<&5S("8@)'1H:7,M/FEM86=E='EP97-;
M)&9O<FUA=%TI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YI;6%G
M971Y<&5S(&%S("1S=7!P;W)T960@/3X@)&)I=&UA<VLI('L*("`@("`@("`@
M("`@("`@(&EF("@D='EP97,@)B`D8FET;6%S:RD@>PH@("`@("`@("`@("`@
M("`@("`@(&YE=R!#86-H95]%<G)O<B@B5&AE(&)U:6QD(&EN($=$(&QI8B!D
M;V5S(&YO="!S=7!P;W)T('1H92!I;6%G92!T>7!E("1F;W)M870N($9A;&QB
M86-K('1O("1S=7!P;W)T960N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@B2&UM+"!I<R!Y;W5R(%!(4"!B=6EL9"!W
M:71H($=$('-U<'!O<G0_($-A;B=T(&9I;F0@86YY('-U<'!O<G1E9"!T>7!E
M<RXB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&EM86=E(#T@
M)'1H:7,M/F=E="@D:60L("1T:&ES+3YC86-H95]G<F]U<"DI"B`@("`@("`@
M("`@(')E='5R;B`D:6UA9V4["@H@("`@("`@("\O('-A=F4@=&AE(&EM86=E
M('1O('1H92!O=71P=70@8G5F9F5R+"!W<FET92!I="!T;R!D:7-K(&%N9"`*
M("`@("`@("`O+R!R971U<FX@=&AE(&EM86=E+@H@("`@("`@(&]B7V5N9%]C
M;&5A;B@I.PH@("`@("`@(&]B7W-T87)T*"D[(`H*("`@("`@("!I9B`H<W1R
M=&]U<'!E<B@D9F]R;6%T*2`]/2`B2E!'(BD@>PH@("`@("`@("`@("`D9V5N
M1F]R;6%T(#T@(DI014<B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1G96Y&;W)M870@/2!S=')T;W5P<&5R*"1F;W)M870I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@9V5N97)A=&4@=&AE(&EM86=E"B`@("`@("`@)&9U;F,@
M/2`G26UA9V4G("X@)&=E;D9O<FUA=#L*("`@("`@("`D9G5N8R@D:6UG*3L*
M("`@("`@("!);6%G941E<W1R;WDH)&EM9RD["@H@("`@("`@(&]B7V5N9"@I
M.PH@("`@("`@("1I;6%G92`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@
M(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("`O+R!S879E('1H92!G96YE<F%T
M960@:6UA9V4@=&\@9&ES:PH@("`@("`@("1T:&ES+3YS879E*"1I9"P@)&EM
M86=E+"`P+"`D=&AI<RT^8V%C:&5?9W)O=7`I.PH*("`@("`@("!R971U<FX@
M)&EM86=E.PH@("`@?2`O+R!E;F0@9G5N8R!C86-H94EM86=E"B`@("`*"B`@
M("`O*BH*("`@("H@0W)E871E(&%N(&EM86=E(&9R;VT@=&AE(&=I=F5N(&EM
M86=E(&AA;F1L97(L(&-A8VAE(&ET(&%N9"!R971U<FX@82!U<FP@86YD('1H
M92!F:6QE('!A=&@@;V8@=&AE(&EM86=E+@H@("`@*@H@("`@*B!!;'=A>7,@
M=')Y('1O(')E=')I=F4@=&AE(&EM86=E(&9R;VT@=&AE(&-A8VAE(&)E9F]R
M92!Y;W4@8V]M<'5T92!I="X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@26UA9V4M240N(%5S960@87,@82!P87)T(&]F('1H92!C86-H92!F:6QE
M;F%M92X*("`@("H@("`@("`@("`@("`@("`@("`@57-E(&UD-2@I('1O(&=E
M;F5R871E(&$@(G5N:7%U92(@240@9F]R('EO=7(@:6UA9V4*("`@("H@("`@
M("`@("`@("`@("`@("`@8F%S960@;VX@8VAA<F%C=&5R:7-T:6,@=F%L=65S
M('-U8V@@87,@=&AE(&-O;&]R+"!S:7IE(&5T8RX*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@26UA9V4@:&%N9&QE<B!T;R!C<F5A=&4@=&AE(&EM86=E(&9R
M;VTN"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E('1Y<&4Z(&=I9BP@
M:G!G+"!P;F<L('=B;7`N($%L<V\@=7-E9"!A<R!F:6QE;F%M92!S=69F:7@N
M"B`@("`J("`@("`@("`@("`@("`@("`@($EF(&%N('5N<W5P<&]R=&5D('1Y
M<&4@:7,@<F5Q=65S=&5D('1H92!F=6YC=&EO;G,@=')I97,@=&\@"B`@("`J
M("`@("`@("`@("`@("`@("`@(&9A;&QB86-K('1O(&$@<W5P<&]R=&5D('1Y
M<&4@8F5F;W)E('1H<F]W:6YG(&%N(&5X97!T:6]N+@H@("`@*B!`<F5T=7)N
M("`@87)R87D@(%L@9G5L;"!P871H('1O('1H92!I;6%G92!F:6QE+"!I;6%G
M92!U<FP@70H@("`@*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&-A8VAE26UA9V5,
M:6YK*"1I9"P@)B1I;6<L("1F;W)M870@/2`G<&YG)RD@>PH@("`@("`@(&EF
M("@A)&ED*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R("@G
M66]U(&UU<W0@<')O=FED92!A;B!)1"!F;W(@86YD(&EM86=E('1O(&)E(&-A
M8VAE9"$G+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D:60@/2`D
M=&AI<RT^9V5N97)A=&5)1"@D:60L("1F;W)M870I.PH@("`@("`@("1T>7!E
M<R`]($EM86=E5'EP97,H*3L*"B`@("`@("`@+R\@0VAE8VL@:68@=&AE(')E
M<75E<W1E9"!I;6%G92!T>7!E(&ES('-U<'!O<G1E9"!B>2!T:&4@1T0@;&EB
M+@H@("`@("`@("\O($EF(&YO="P@=')Y(&$@8V%L;&)A8VL@=&\@=&AE(&9I
M<G-T(&%V86EL86)L92!I;6%G92!T>7!E+@H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/FEM86=E='EP97-;)&9O<FUA=%TI('Q\("$H)'1Y<&5S("8@)'1H
M:7,M/FEM86=E='EP97-;)&9O<FUA=%TI*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YI;6%G971Y<&5S(&%S("1S=7!P;W)T960@/3X@)&)I=&UA
M<VLI(`H@("`@("`@("`@("`@("`@:68@*"1T>7!E<R`F("1B:71M87-K*0H@
M("`@("`@("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B5&AE(&)U:6QD
M(&EN($=$(&QI8B!D;V5S(&YO="!S=7!P;W)T('1H92!I;6%G92!T>7!E("1F
M;W)M870N($9A;&QB86-K('1O("1S=7!P;W)T960N(BP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@("`@(&5L<V4*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")(;6TL(&ES('EO=7(@4$A0
M(&)U:6QD('=I=&@@1T0@<W5P<&]R=#\@0V%N)W0@9FEN9"!A;GD@<W5P<&]R
M=&5D('1Y<&5S+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*
M("`@("`@("`D=7)L(#T@)'1H:7,M/F-A8VAE7W5R;"`N("1T:&ES+3YC86-H
M95]F:6QE7W!R969I>"`N("1I9#L*("`@("`@("`D9F9I;&4@/2`D=&AI<RT^
M8V]N=&%I;F5R+3YG971&:6QE;F%M92@D:60L("1T:&ES+3YC86-H95]G<F]U
M<"D["@H@("`@("`@(&EF("@D=&AI<RT^:7-#86-H960H)&ED+"`D=&AI<RT^
M8V%C:&5?9W)O=7`I("8F("%I<T5X<&ER960H)&ED+"`D=&AI<RT^8V%C:&5?
M9W)O=7`I*0H@("`@("`@("`@("!R971U<FX@87)R87DH)&9F:6QE+"`D=7)L
M*3L*"B`@("`@("`@:68@*'-T<G1O=7!P97(H)&9O<FUA="D@/3T@(DI01R(I
M('L*("`@("`@("`@("`@)&=E;D9O<FUA="`](")*4$5'(CL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9V5N1F]R;6%T(#T@<W1R=&]U<'!E<B@D
M9F]R;6%T*3L*("`@("`@("!]"@H@("`@("`@("1F=6YC(#T@)TEM86=E)R`N
M("1G96Y&;W)M870["B`@("`@("`@)&9U;F,H)&EM9RP@)&9F:6QE*3L*"B`@
M("`@("`@26UA9V5$97-T<F]Y*"1I;6<I.PH*("`@("`@("!R971U<FX@87)R
M87DH)&9F:6QE+"`D=7)L*3L*("`@('T@+R\@96YD(&9U;F,@8V%C:&5);6%G
M94QI;FL*"B`@("`*("`@("\J*@H@("`@*B!3971S('1H92!54DP@<')E9FEX
M('5S960@=VAE;B!R96YD97)I;F<@2%1-3"!486=S+B`*("`@("H@"B`@("`J
M($UA:V4@<W5R92!T:&%T('1H92!54DP@;6%T8VAE<R!T:&4@8V%C:&4@9&ER
M96-T;W)Y+"`*("`@("H@;W1H97)W:7-E('EO=2=L;"!G970@8G)O:V5N(&QI
M;FMS+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9PH@("`@*B!`86-C
M97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!S971#86-H941I<B@I"B`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T0V%C:&554DPH)&-A8VAE7W5R;"D@>PH@
M("`@("`@(&EF("@D8V%C:&5?=7)L("8F("<O)R`A/2!S=6)S='(H)&-A8VAE
M7W5R;"P@,2DI(`H@("`@("`@("`@("`D8V%C:&5?=7)L("X]("<O)SL*("`@
M("`@("`@("`@"B`@("`@("`@)'1H:7,M/F-A8VAE7W5R;"`]("1C86-H95]U
M<FP["B`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC('-E=$-A8VAE55),"@H@
M("`@"B`@("`O*BH*("`@("H@4V5T<R!T:&4@9&ER96-T;W)Y('=H97)E('1O
M(&-A8VAE(&=E;F5R871E9"!);6%G97,*("`@("H@"B`@("`J($!P87)A;2`@
M("!S=')I;F<*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@
M("`@<V5T0V%C:&554DPH*0H@("`@*B\*("`@(&9U;F-T:6]N('-E=$-A8VAE
M1&ER*"1C86-H95]D:7(I('L*("`@("`@("!I9B`H)&-A8VAE7V1I<B`F)B`G
M+R<@(3T@<W5B<W1R*"1C86-H95]D:7(L(#$I*0H@("`@("`@("`@("`D8V%C
M:&5?9&ER("X]("<O)SL*"B`@("`@("`@)'1H:7,M/F-A8VAE7V1I<B`]("1C
M86-H95]D:7(["B`@("`@("`@)'1H:7,M/F-O;G1A:6YE<BT^8V%C:&5?9&ER
M(#T@)&-A8VAE7V1I<CL*("`@('T@+R\@96YD(&9U;F,@<V5T0V%C:&5$:7(*
M("`@(`H@("`@"B`@("!F=6YC=&EO;B!G96YE<F%T94E$*"1V87)I86)L92P@
M)&9O<FUA="`]("=P;F<G*2!["B`@("`@(')E='5R;B!M9#4H<V5R:6%L:7IE
M*"1V87)I86)L92DI("X@)RXG("X@)&9O<FUA=#L*("`@('T@+R\@96YD(&9U
M;F,@9V5N97)A=&5)1`H@("`@"B`@("`*?2`O+R!E;F0@8VQA<W,@0V%C:&5?
M1W)A<&AI8W,*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#
M86-H92](5%107U)E<75E<W0N<&AP````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R,S(U-``Q,#4Q-30S,3`U-@`P,C$S-3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M<SH@1F%B:65N($U!4E19(#QF86)I96XN;6%R='E`9G)E92YF<CX@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!(5%107U)E
M<75E<W0N<&AP+'8@,2XY(#(P,#,O,#<O,3,@,#@Z,C<Z,3@@9F%B($5X<"`D
M"@IR97%U:7)E7V]N8V4@)T-A8VAE+G!H<"<["G)E<75I<F5?;VYC92`G2%14
M4"]297%U97-T+G!H<"<["@ID969I;F4H)T-!0TA%7TA45%!?4D5154535%]'
M4D]54%].04U%)RP@)V-A8VAE7VAT='!?<F5Q=65S="<I.PID969I;F4H)T-!
M0TA%7TA45%!?4D5154535%]354-#15-37U)%4U!/3E-%7T-/1$4G+"`R,#`I
M.PID969I;F4H)T-!0TA%7TA45%!?4D5154535%]+14507TQ/0T%,7T-/4%DG
M+"`Q*3L*9&5F:6YE*"=#04-(15](5%107U)%455%4U1?4D5455).7T9!3%-%
M)RP@,BD["F1E9FEN92@G0T%#2$5?2%144%]215%515-47U)%5%523E]014%2
M7T524D]2)RP@,RD["@HO*BH**B!(5%107U)E<75E<W0@0V%C:&4**@HJ(%1H
M92!C;&%S<VEC86P@97AA;7!L92!I<R`Z"BH**B!9;W4@=V%N="!T;R!G970@
M;F5W<R!F<F]M(&%N;W1H97(@<VET92!T:')O=6=H(%)34R!R96UO=&4@9FEL
M97,N($)U="!Y;W4**B!D;VXG="!W86YT('1O(&%C8V5S<R!T;R!T;R!T:&4@
M<F5M;W1E('-I=&4@870@979E<GD@=&EM92!Y;W4@9&ES<&QA>0HJ(&ET<R!N
M97=S(&]N('EO=7(@<VET92X@0F5C875S92P@:68@=&AE(')E;6]T92!S:71E
M(&ES(&1O=VX@;W(@<VQO=RXN+@HJ(%-O('EO=2!Y;W4@;F5E9"!A(&-L87-S
M('=H:6-H(&UA:V5S(&$@;&]C86P@8V%C:&4@8V]P>2!O9B!T:&4@<F5M;W1E
M(&9I;&4N"BH@179E<GD@>"!H;W5R<RP@=&AE(&-A8VAE(&ES('5P9&%T960N
M($)U="!I9B!T:&4@<F5M;W1E('-I=&4@:7,@9&]W;BP@=&AE"BH@;&]C86P@
M8V%C:&4@8V]P>2!I<R!K965P960@*'EO=2!C86X@86QS;R!G970@97)R;W(@
M;65S<V%G97,@:68@>6]U('=A;G0I+@HJ"BH@4V\@>6]U(&YE960@=&AI<R!C
M;&%S<R$**@HJ($-A8VAE7TA45%!?4F5Q=65S="!I;FAE<FET<R!F<F]M($-A
M8VAE(&%N9"!U<V4@2%144%]297%U97-T('1O(&%C8V5S<R!T;PHJ('1H92!R
M96UO=&4@9FEL92X**@HJ(%5S86=E(&5X86UP;&4@.@HJ"BH@/#]P:'`**B!R
M97%U:7)E7V]N8V4H)T-A8VAE+TA45%!?4F5Q=65S="YP:'`G*3L**@HJ("1C
M86-H92`]("9N97<@0V%C:&5?2%144%]297%U97-T*"=H='1P.B\O=W=W+G!H
M<"YN970G+"!.54Q,+"`G9FEL92<L($Y53$PL(#,V,#`I.PHJ("1C86-H92T^
M<V5N9%)E<75E<W0H*3L**B`D<F5M;W1E1FEL94)O9'D@/2`D8V%C:&4M/F=E
M=%)E<W!O;G-E0F]D>2@I.PHJ"BH@*"XN+BD**B`_/@HJ"BH@0&%U=&AO<B`@
M($9A8FEE;B!-05)462`\9F%B:65N+FUA<G1Y0&9R964N9G(^"BH@0'9E<G-I
M;VX@("1)9#H@2%144%]297%U97-T+G!H<"QV(#$N.2`R,#`S+S`W+S$S(#`X
M.C(W.C$X(&9A8B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ+PH*8VQA<W,@
M0V%C:&5?2%144%]297%U97-T(&5X=&5N9',@0V%C:&4*>PH*("`@("\O("TM
M+2!0<FEV871E('!R;W!E<G1I97,@+2TM"@H@("`@+RHJ"B`@("`J($QI9F5T
M:6UE(&EN('-E8V]N9',@*#`@96YD;&5S<RD*("`@("H*("`@("H@0'9A<B!I
M;G0@)%]E>'!I<F5S"B`@("`J+PH@("`@=F%R("1?97AP:7)E<SL*"B`@("`O
M*BH*("`@("H@2%144"!297%U97-T"B`@("`J"B`@("`J($!V87(@;V)J96-T
M("1?<F5Q=65S=`H@("`@*B\*("`@('9A<B`D7W)E<75E<W0["@H@("`@+RHJ
M"B`@("`J($-A8VAE(&ED(&9O<B!T:&4@8VQA<W-I8R!C86-H92!F:6QE"B`@
M("`J"B`@("`J($!S964@<V5N9%)E<75E<W0H*0H@("`@*B!`=F%R('-T<FEN
M9R`D7VED"B`@("`J+PH@("`@=F%R("1?:60["@H@("`@+RHJ"B`@("`J($-A
M8VAE(&ED(&9O<B!T:&4@96YD;&5S<R!C86-H92!F:6QE"B`@("`J"B`@("`J
M($!S964@<V5N9%)E<75E<W0H*0H@("`@*B!`=F%R('-T<FEN9R`D7VED"B`@
M("`J+PH@("`@=F%R("1?:60R.PH*("`@("\J*@H@("`@*B!$871A('1O('5S
M90H@("`@*@H@("`@*B!`<V5E(&=E=%)E<&]N<V5";V1Y*"DL(&=E=%)E<&]N
M<V5(96%D97(H*2P@9V5T4F5P;VYS94-O9&4H*0H@("`@*B!`=F%R(&%R<F%Y
M("1?9&%T80H@("`@*B\*("`@('9A<B`D7V1A=&$@.PH*("`@("\O("TM+2!0
M=6)L:6,@;65T:&]D<R`M+2T*"B`@("`O*BH*("`@("H@0V]N<W1R=6-T;W(*
M("`@("H*("`@("H@0'!A<F%M("1U<FP@5&AE('5R;"!T;R!A8V-E<W,*("`@
M("H@0'!A<F%M("1P87)A;7,@07-S;V-I871I=F4@87)R87D@;V8@<&%R86UE
M=&5R<R!W:&EC:"!C86X@8F4Z"B`@("`J("`@("`@("`@("`@("`@("`@;65T
M:&]D("`@("`M($UE=&AO9"!T;R!U<V4L($=%5"P@4$]35"!E=&,*("`@("H@
M("`@("`@("`@("`@("`@("!H='1P("`@("`@("T@2%144"!697)S:6]N('1O
M('5S92P@,2XP(&]R(#$N,0H@("`@*B`@("`@("`@("`@("`@("`@('5S97(@
M("`@("`@+2!"87-I8R!!=71H('5S97)N86UE"B`@("`J("`@("`@("`@("`@
M("`@("`@<&%S<R`@("`@("`M($)A<VEC($%U=&@@<&%S<W=O<F0*("`@("H@
M("`@("`@("`@("`@("`@("!P<F]X>5]H;W-T("T@4')O>'D@<V5R=F5R(&AO
M<W0*("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]P;W)T("T@4')O>'D@
M<V5R=F5R('!O<G0*("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]U<V5R
M("T@4')O>'D@875T:"!U<V5R;F%M90H@("`@*B`@("`@("`@("`@("`@("`@
M('!R;WAY7W!A<W,@+2!0<F]X>2!A=71H('!A<W-W;W)D"B`@("`J($!P87)A
M;2!S=')I;F<@)&-O;G1A:6YE<B!.86UE(&]F(&-O;G1A:6YE<B!C;&%S<PH@
M("`@*B!`<&%R86T@87)R87D@)&-O;G1A:6YE<D]P=&EO;G,@07)R87D@=VET
M:"!C;VYT86EN97(@8VQA<W,@;W!T:6]N<PH@("`@*B!`<&%R86T@:6YT("1M
M;V1E(%=H870@=&\@9&\@=VAE;B!T:&4@<F5M;W1E('-E<G9E<B!I<R!D;W=N
M(#H*("`@("H@("`@("`@("`@("`@("`@("`@0T%#2$5?2%144%]215%515-4
M7TM%15!?3$]#04Q?0T]062!O<@H@("`@*B`@("`@("`@("`@("`@("`@("!#
M04-(15](5%107U)%455%4U1?4D5455).7T9!3%-%(&]R"B`@("`J("`@("`@
M("`@("`@("`@("`@($-!0TA%7TA45%!?4D5154535%]215154DY?4$5!4E]%
M4E)/4@H@("`@*B!`<&%R86T@:6YT("1E>'!I<F5S(&QI9F5T:6UE(&]F('1H
M92!C86-H960@9&%T82!I;B!S96-O;F1S("T@,"!F;W(@96YD;&5S<PH@("`@
M*B!`<V5E($-A8VAE+"!(5%107U)E<75E<W0*("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("HO"B`@("!F=6YC=&EO;B!#86-H95](5%107U)E<75E<W0H)'5R
M;"P@)'!A<F%M<R`]($Y53$PL("1C;VYT86EN97(@(#T@)V9I;&4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT86EN97)/<'1I;VYS
M(#T@3E5,3"P@)&5X<&ER97,@/2`S-C`P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1M;V1E(#T@0T%#2$5?2%144%]215%515-47TM%15!?
M3$]#04Q?0T]062D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7,I
M*2`D<&%R86US(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES<V5T*"1C;VYT
M86EN97)/<'1I;VYS*2D@>PH@("`@("`@("`@("`D8V]N=&%I;F5R3W!T:6]N
M<R`](&%R<F%Y("@*("`@("`@("`@("`@("`@("=C86-H95]D:7(G(#T^("<O
M=&UP+R<L"B`@("`@("`@("`@("`@("`G9FEL96YA;65?<')E9FEX)R`]/B`G
M8V%C:&5?)PH@("`@("`@("`@("`I.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^0V%C:&4H)&-O;G1A:6YE<BP@)&-O;G1A:6YE<D]P=&EO;G,I.PH@("`@
M("`@("1T:&ES+3Y?<F5Q=65S="`]("9N97<@2%144%]297%U97-T*"1U<FPL
M("1P87)A;7,I.PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H)'5R;"YS97)I
M86QI>F4H)'!A<F%M<RDI.PH@("`@("`@("1T:&ES+3Y?:60R(#T@;60U*"1T
M:&ES+3Y?:60I.R`O+R!W92!N965D('1W;R!K97ES"B`@("`@("`@)'1H:7,M
M/E]M;V1E(#T@)&UO9&4["B`@("`@("`@)'1H:7,M/E]E>'!I<F5S(#T@)&5X
M<&ER97,["B`@("!]"@H@("`@+RHJ"B`@("`J($1E8V]N<W1R=6-T;W(*("`@
M("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!?
M0V%C:&5?2%144%]297%U97-T*"D*("`@('L*("`@("`@("`D=&AI<RT^7T-A
M8VAE*"D["B`@("!]"@H@("`@+RHJ"B`@("`J($=E="!A;F0@<F5T=7)N('1H
M92!R97-P;VYS92!B;V1Y("A.54Q,(&EF(&YO(&1A=&$@879A:6QA8FQE*0H@
M("`@*@H@("`@*B!`<V5E('-E;F1297%U97-T*"D*("`@("H@0')E='5R;B!M
M:7AE9"!R97-P;VYS92!B;V1Y"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V5";V1Y*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D871A6R=B;V1Y)UT["B`@("!]"@H@("`@+RHJ
M"B`@("`J($=E="!A;F0@<F5T=7)N('1H92!R97-P;VYS92!C;V1E("A.54Q,
M(&EF(&YO(&1A=&$@879A:6QA8FQE*0H@("`@*@H@("`@*B!`<V5E('-E;F12
M97%U97-T*"D*("`@("H@0')E='5R;B!M:7AE9"!R97-P;VYS92!C;V1E"B`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S
M<&]N<V5#;V1E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A
M6R=C;V1E)UT["B`@("!]"@H@("`@+RHJ"B`@("`J($=E="!A;F0@<F5T=7)N
M('1H92!R97-P;VYS92!H96%D97(@*$Y53$P@:68@;F\@9&%T82!A=F%I;&%B
M;&4I"B`@("`J"B`@("`J($!S964@<V5N9%)E<75E<W0H*0H@("`@*B!`<F5T
M=7)N(&UI>&5D(')E<W!O;G-E(&AE861E<@H@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E2&5A9&5R*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A6R=H96%D97(G73L*("`@
M('T*"@H@("`@+RHJ"B`@("`J(%-E="!A(&YE=R!M;V1E('=H96X@=&AE('-E
M<G9E<B!I<R!D;W=N"B`@("`J"B`@("`J($!P87)A;2!I;G0@)&YE=TUO9&4@
M5VAA="!T;R!D;R!W:&5N('1H92!R96UO=&4@<V5R=F5R(&ES(&1O=VX@.@H@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!#04-(15](5%107U)%455%4U1?
M2T5%4%],3T-!3%]#3U!9(&]R"B`@("`J("`@("`@("`@("`@("`@("`@("`@
M($-!0TA%7TA45%!?4D5154535%]215154DY?1D%,4T4@;W(*("`@("H@("`@
M("`@("`@("`@("`@("`@("`@0T%#2$5?2%144%]215%515-47U)%5%523E]0
M14%27T524D]2"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T36]D92@D;F5W36]D92D*("`@('L*("`@("`@("`D=&AI<RT^
M7VUO9&4@/2`D;F5W36]D93L*("`@('T*"B`@("`O*BH*("`@("H@4V5N9"!T
M:&4@2%144"!R97%U97-T(&]R('5S92!T:&4@8V%C:&4@<WES=&5M"B`@("`J
M"B`@("`J($EF('1H97)E(&ES(&$@8V%C:&4@9FEL92!F;W(@=&AI<R!(5%10
M(')E<75E<W0L('1H92!R97%U97-T(&ES(&YO="!R92US96YT+@H@("`@*B!#
M86-H960@<F5S<&]N<V4@:7,@=7-E9"X@665T+"!I9B!T:&4@8V%C:&4@:7,@
M97AP:7)E9"P@=&AE($A45%`@<F5Q=65S=`H@("`@*B!I<R!R92US96YT+B!4
M:&5N+"!I9B!T:&4@<F5M;W1E('-E<G9E<B!I<R!D;W=N+"!T:&ES(&UE=&AO
M9"!W:6QL(')E='5R;B`Z"B`@("`J("AD97!E;F1I;F<@;VX@=&AE('-E;&5C
M=&5D(&UO9&4I"B`@("`J("T@9F%L<V4@;W(*("`@("H@+2!A(%!%05)?17)R
M;W(@;W(@*&)E='1E<BD*("`@("H@+2!T<G5E(&%N9"!T:&4@;&]C86P@8V]P
M>2!O9B!T:&4@;&%T97-T('9A;&ED(')E<W!O;G-E('=I;&P@8F4@=7-E9"X*
M("`@("H*("`@("H@*'1E8VAN:6-A;"D*("`@("H@1F]R('1H92!L87-T(&-H
M;VEC92P@=&AE<F4@:7,@82!T96-H;FEC86P@=&EP<RX*("`@("H@26YD965D
M+"!T:&5R92!A<F4@='=O(&-A8VAE(&9I;&5S+B!4:&4@9FER<W0@;VYE("AI
M9"!K97DI(&ES(&$@8VQA<W-I8V%L(&]N90H@("`@*B!W:71H('1H92!G:79E
M;B!L:69E=&EM92X@0G5T(&ET(&-A;B!B92!R96UO=F5D(&)Y(&%U=&]M871I
M8R!G87)B86=E(&-O;&QE8W1I;VX*("`@("H@9F]R(&5X86UP;&4N(%-O('1O
M(&)E(&%B;&4@=&\@=7-E('1H92!L871E<W0@=F%L:60@<F5S<&]N<V4@*'=H
M96X@=&AE(')E;6]T90H@("`@*B!S97)V97(@:7,@9&5A9"DL('=E(&UA:V4@
M82!S96-O;F0@8V%C:&4@9FEL92!W:71H(&YO(&QI9F5T:6UE("AI9#(@:V5Y
M*2X*("`@("H*("`@("H@0')E='5R;B!M:7AE9"!T<G5E(&]R(&9A;'-E(&]R
M(&$@4$5!4E]%4E)/4@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@
M(&9U;F-T:6]N('-E;F1297%U97-T*"D*("`@('L*("`@("`@("!I9B`H)&1A
M=&$@/2`D=&AI<RT^9V5T*"1T:&ES+3Y?:60L($-!0TA%7TA45%!?4D515453
M5%]'4D]54%].04U%*2D@>PH@("`@("`@("`@("`O+R`M+2T@0V%C:&4@:&ET
M("TM+0H@("`@("`@("`@("`D=&AI<RT^7V1A=&$@/2`D9&%T83L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+R\@+2TM($-A8VAE(&UI<W,@+2TM"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7W-E;F1297%U97-T06YD1V5T4F5S<&]N<V4H*2D@>PH@("`@("`@("`@
M("`@("`@+R\@4V\@=&AE(')E;6]T92!S97)V97(@:7,@;VLN+BX*("`@("`@
M("`@("`@("`@("1T:&ES+3YS879E*"1T:&ES+3Y?:60L("1T:&ES+3Y?9&%T
M82P@)'1H:7,M/E]E>'!I<F5S+"!#04-(15](5%107U)%455%4U1?1U)/55!?
M3D%-12D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@D=&AI<RT^7VED
M,BP@)'1H:7,M/E]D871A+"`P+"!#04-(15](5%107U)%455%4U1?1U)/55!?
M3D%-12D["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D9&%T85]S878@/2`D
M=&AI<RT^9V5T*"1T:&ES+3Y?:60R+"!#04-(15](5%107U)%455%4U1?1U)/
M55!?3D%-12DI('L*("`@("`@("`@("`@("`@("`@("`O+R!/:RP@=&AE(")R
M96-O=F5R(&-A8VAE(B!I<R!A=F%I;&%B;&4N+BX*("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*"1T:&ES+3Y?;6]D92D@>PH@("`@("`@("`@("`@("`@
M("`@(&-A<V4@0T%#2$5?2%144%]215%515-47TM%15!?3$]#04Q?0T]063H*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;6%K92!A(&YE=R!L;V-A
M;"!C;W!Y(&%N9"!K965P(&ET('5N=&EL(&ET(&5X<&ER97,N+BX*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H)'1H:7,M/E]I9"P@)&1A
M=&%?<V%V+"`D=&AI<RT^7V5X<&ER97,L($-!0TA%7TA45%!?4D5154535%]'
M4D]54%].04U%*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M871A(#T@)&1A=&%?<V%V.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@8V%S92!#04-(15](5%107U)%455%4U1?4D5455).
M7T9!3%-%.@H@("`@("`@("`@("`@("`@("`@("`@("`O+R!792!R971U<FX@
M9F%L<V4*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E($-!0TA%7TA45%!?4D5154535%]215154DY?4$5!4E]%4E)/
M4CH*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@<F5T=7)N(&$@4$5!
M4E]%<G)O<B$*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&YE=R!#
M86-H95]%<G)O<B@G4F5M;W1E(&9I;&4@:7,@;F]T(&%V86EL86)L92$G*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`O+R!)="=S('1E<G)I8FQE(2!4:&4@<F5M;W1E('-E<G9E<B!I
M<R!D;W=N(&%N9"!D969I;FET:79E;'D@;F\@8V%C:&4@879A:6QA8FQE(0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)U)E
M;6]T92!S97)V97(@9&]W;B!A;F0@;F\@8V%C:&4@879A:6QA8FQE(2<I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\O("TM+2!0<FEV871E($UE=&AO9',@+2TM"@H@("`@+RHJ"B`@
M("`J(%-E;F0@2%144"!R97%U97-T(&%N9"!G970@=&AE(')E<W!O;G-E"B`@
M("`J"B`@("`J($!R971U<FX@8F]O;&5A;B!S=6-C97-S(&]R(&YO="`_"B`@
M("`J($!S964@2%144%]297%U97-T"B`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@*B\*("`@(&9U;F-T:6]N(%]S96YD4F5Q=65S=$%N9$=E=%)E<W!O;G-E
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7W)E<75E<W0M/G-E;F1297%U97-T
M*"D["B`@("`@("`@)&)O9'D@/2`D=&AI<RT^7W)E<75E<W0M/F=E=%)E<W!O
M;G-E0F]D>2@I.PH@("`@("`@("1C;V1E(#T@)'1H:7,M/E]R97%U97-T+3YG
M971297-P;VYS94-O9&4H*3L*("`@("`@("`D:&5A9&5R(#T@)'1H:7,M/E]R
M97%U97-T+3YG971297-P;VYS94AE861E<B@I.PH@("`@("`@("1T:&ES+3Y?
M9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`G8F]D>2<@/3X@)&)O9'DL"B`@
M("`@("`@("`@("=C;V1E)R`]/B`D8V]D92P*("`@("`@("`@("`@)VAE861E
M<B<@/3X@)&AE861E<@H@("`@("`@("D["B`@("`@("`@<F5T=7)N("@H)&-O
M9&4]/4-!0TA%7TA45%!?4D5154535%]354-#15-37U)%4U!/3E-%7T-/1$4I
M(#\@=')U92`Z(&9A;'-E*3L*("`@('T*"GT*/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H
M92]/=71P=70N<&AP````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q-C$U,P`Q,#4Q-30S,3`U-@`P,C`S-C(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@
M56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@($-H<FES=&EA;B!3=&]C
M:V5R(#QC:')E9W5`<&AA;G0N8V@^("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"`@("`@("`@("!6:6YA:2!+;W!P(#QK;W!P0&YE='IA<F)E:71E
M<BYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($]U='!U="YP:'`L=B`Q
M+C8@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E
M("=#86-H92YP:'`G.PH*+RHJ"BH@0VQA<W,@=&\@8V%C:&4@=&AE(&]U='!U
M="!O9B!A('-C<FEP="!U<VEN9R!T:&4@;W5T<'5T(&)U9F9E<FEN9R!F=6YC
M=&EO;G,**@HJ(%-I;7!L92!O=71P=70@8V%C:&4N(%-O;64@<&%G97,@<F5Q
M=6ER92!L;W1S(&]F('1I;64@=&\@8V]M<'5T92X@0V%C:&EN9R!T:&4**B!O
M=71P=70@8V%N(&EN8W)E87-E('1H92!O=F5R86QL('-P965D(&1R86UA=&EC
M86QL>2P@97-P96-I86QL>2!I9B!Y;W4@=7-E"BH@82!3:&%R960@365M;W)Y
M('-T;W)A9V4@8V]N=&%I;F5R+@HJ"BH@07,@>6]U(&-A;B!S964@:6X@=&AE
M(&5X86UP;&4@=&AE('5S86=E(&ES(&5X=&5M96QY('-I;7!L92X@5&\@8V%C
M:&4@82!S8W)I<'0**B!S:6UP;&4@<'5T('-O;64@9F5W(&QI;F5S(&]F(&-O
M9&4@:6X@9G)O;G0@;V8@>6]U<B!S8W)I<'0@86YD('-O;64@870@=&AE(&5N
M9"X**B!!('!R969E<G)A8FQE('!L86-E(&9O<B!T:&ES(&%R92!T:&4@875T
M;U]P<F5P96YD(&%N9"!A=71O7V%P<&5N9"!F:6QE<R`H/3X@<&AP+FEN:2DN
M"BH**B!5<V%G92!E>&%M<&QE.@HJ"BH@("\O('!L86-E('1H:7,@<V]M97=H
M97)E(&EN(&$@8V5N=')A;"!C;VYF:6<@9FEL90HJ("!D969I;F4H0T%#2$5?
M4U1/4D%'15]#3$%34RP@)V9I;&4G*3L**B`@+R\@9FEL92!S=&]R86=E(&YE
M961S(&$@9&ER('1O('!U="!T:&4@8V%C:&4@9FEL97,**B`@9&5F:6YE*$-!
M0TA%7T1)4BP@)R]V87(O=&UP+R<I.PHJ"BH@("\O(&=E="!A(&-A8VAE(&]B
M:F5C=`HJ("`D8V%C:&4@/2!N97<@0V%C:&5?3W5T<'5T*$-!0TA%7U-43U)!
M1T5?0TQ!4U,L(&%R<F%Y*"=C86-H95]D:7(G(#T^($-!0TA%7T1)4BDI.PHJ
M"BH@("\O(&-O;7!U=&4@=&AE('5N:7%U92!H86YD;&4N"BH@("\O(&EF('EO
M=7(@<V-R:7!T(&1E<&5N9',@;VX@0V]O:VEE(&%N9"!(5%10(%!O<W0@9&%T
M82!A<R!W96QL"BH@("\O('EO=2!S:&]U;&0@=7-E.@HJ("`O+R`D8V%C:&5?
M:&%N9&QE(#T@87)R87DH"BH@("\O("`@("`@("`@("`@("`@("`@("`@("`G
M9FEL92<@/3X@)%)%455%4U1?55))+`HJ("`O+R`@("`@("`@("`@("`@("`@
M("`@("`@)W!O<W0G(#T^("1(5%107U!/4U1?5D%24RP**B`@+R\@("`@("`@
M("`@("`@("`@("`@("`@("=C;V]K:64G("`]/B`D2%144%]#3T]+245?5D%2
M4PHJ("`O+R`@("`@("`@("`@("`@("`@("`@*3L**B`@+R\@0G5T(&)E('=A
M<FYE9"P@=7-I;F<@86QL($=%5"!O<B!03U-4(%9A<FEA8FQE<R!A<R!A('-E
M960**B`@+R\@8V%N(&)E('5S960@9F]R(&$@1$]3(&%T=&%C:RX@0V%L;&EN
M9R!H='1P.B\O=W=W+F5X86UP;&4N8V]M+V5X86UP;&4N<&AP/W=H871E=F5R
M"BH@("\O('=H97)E('=H871E=F5R(&ES(&$@<F%N9&]M('1E>'0@;6EG:'0@
M8F4@=7-E9"!T;R!F;&]O9"!Y;W5R(&-A8VAE+@HJ("`D8V%C:&5?:&%N9&QE
M(#T@)&-A8VAE+3YG96YE<F%T94E$*"1215%515-47U5222D["BH**B`@+R\@
M;F]W('1H92!M86=I8R!H87!P96YS.B!I9B!C86-H960@8V%L;"!D:64H*0HJ
M("`O+R!T;R!E;F0@=&AE('1I;64@8V]N<W5M<'1I;VYG('-C<FEP="!S8W)I
M<'0@97AE8W5T:6]N(&%N9"!U<V4@=&AE(&-A8VAE9"!V86QU92$**B`@:68@
M*"1C;VYT96YT(#T@)&-A8VAE+3YS=&%R="@D8V%C:&5?:&%N9&QE*2D@>PHJ
M("`@("!P<FEN="`D8V]N=&5N=#L**B`@("`@<')I;G0@)SQP/D-A8VAE(&AI
M=#PO<#XG.PHJ("`@("!D:64H*3L**B`@?0HJ"BH@("\O('1I;64@8V]N<W5M
M<'1I;VX@<V-R:7!T(&=O97,@:&5R92X**@HJ("`O+R!S=&]R92!T:&4@;W5T
M<'5T(&]F('1H92!C86-H92!I;G1O('1H92!C86-H92!A;F0@<')I;G0@=&AE
M(&]U='!U="X**B`@<')I;G0@)&-A8VAE+3YE;F0H*3L**B`@<')I;G0@(CQP
M/D-A8VAE(&UI<W,L('-T;W)E9"!U<VEN9R!T:&4@240@)R1I9"<N/"]P/B([
M"BH**B`@268@>6]U(&1O(&YO="!W86YT('1O(&-A8VAE(&$@=VAO;&4@<&%G
M92`M(&YO('!R;V)L96TZ"BH**B`@:68@*"$H)&-O;G1E;G0@/2`D8V%C:&4M
M/G-T87)T*"1C86-H95]H86YD;&4I*2D@>PHJ("`@("`O+R!D;R!T:&4@8V]M
M<'5T871I;VX@:&5R90HJ("`@("!P<FEN="`D8V%C:&4M/F5N9"@I"BH@('T@
M96QS92!["BH@("`@('!R:6YT("1C;VYT96YT.PHJ("!]"BH**B`@268@>6]U
M(&YE960@86X@97AA;7!L92!S8W)I<'0@8VAE8VL@=&AE("AA=71O7REP<F5P
M96YD(&%N9"`H875T;U\I87!P96YD"BH@(&9I;&5S(&]F(&UY(&AO;65P86=E
M.@HJ"BH@("`@:'1T<#HO+W=W=RYU;&8M=V5N9&5L+F1E+W!H<"]S:&]W7W-O
M=7)C92YP:'`_9FEL93UP<F5P96YD"BH@("`@:'1T<#HO+W=W=RYU;&8M=V5N
M9&5L+F1E+W!H<"]S:&]W7W-O=7)C92YP:'`_9FEL93UA<'!E;F0**@HJ("!$
M;VXG="!K;F]W(&AO=R!T;R!U<V4@:70@;W(@>6]U(&YE960@<')O9FEL:6YG
M(&EN9F]R;6%T:6]N<S]@"BH@($%S:R!#:')I<W1I86X@:&4@=V%S('!A=&EE
M;G0@=VET:"!M92!A;F0@:&4G;&P@8F4@<V\@=VET:"!Y;W5R('%U97-T:6]N
M<R`[*2X**@HJ("!(879E(&9U;B$**@HJ($!A=71H;W)S("!5;&8@5V5N9&5L
M(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X**B!`=F5R<VEO;B`@)$E$.B`D"BH@
M0'!A8VMA9V4@($-A8VAE"BH@0&%C8V5S<R`@('!U8FQI8PHJ+PIC;&%S<R!#
M86-H95]/=71P=70@97AT96YD<R!#86-H92!["@H@("`@+RHJ"B`@("`J($E$
M('!A<W-E9"!T;R!S=&%R="@I"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@
M("`@*B!`<V5E("!S=&%R="@I+"!E;F0H*0H@("`@*B\*("`@('9A<B`D;W5T
M<'5T7VED(#T@)R<["@H@("`@+RHJ"B`@("`J($=R;W5P('!A<W-E9"!T;R!S
M=&%R="@I"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B!`<V5E("!S
M=&%R="@I+"!E;F0H*0H@("`@*B\*("`@('9A<B`D;W5T<'5T7V=R;W5P(#T@
M)R<["@H@("`@+RHJ"B`@("`J(%!%05(M1&5C;VYS=')U8W1O<@H@("`@*B!#
M86QL(&1E8V]N<W1R=6-T;W(@;V8@<&%R96YT"B`@("`J+PH@("`@9G5N8W1I
M;VX@7T-A8VAE7T]U='!U="@I"B`@("!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7T-A8VAE*"D["B`@("!]"@H@("`@+RHJ"B`@("`J('-T87)T<R!T:&4@
M;W5T<'5T(&)U9F9E<FEN9R!A;F0@<F5T=7)N<R!A;B!E;7!T>2!S=')I;F<@
M;W(@<F5T=7)N<R!T:&4@8V%C:&5D(&]U='!U="!F<F]M('1H92!C86-H92X*
M("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F
M=6YC=&EO;B!S=&%R="@D:60L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@
M("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B`G
M)SL*"B`@("`@("`@+R\@=&AI<R!I<R!A;')E861Y(&-A8VAE9"!R971U<FX@
M:70@9G)O;2!T:&4@8V%C:&4@<V\@=&AA="!T:&4@=7-E<@H@("`@("`@("\O
M(&-A;B!U<V4@=&AE(&-A8VAE(&-O;G1E;G0@86YD('-T;W`@<V-R:7!T(&5X
M96-U=&EO;@H@("`@("`@(&EF("@D8V]N=&5N="`]("1T:&ES+3YG970H)&ED
M+"`D9W)O=7`I*0H@("`@("`@("`@("!R971U<FX@)&-O;G1E;G0["@H@("`@
M("`@("\O(')E;65M8F5R('-O;64@9&%T82!T;R!B92!A8FQE('1O(&9I;&P@
M=&AE(&-A8VAE(&]N(&-A;&QI;F<@96YD*"D*("`@("`@("`D=&AI<RT^;W5T
M<'5T7VED(#T@)&ED.PH@("`@("`@("1T:&ES+3YO=71P=71?9W)O=7`@/2`D
M9W)O=7`["@H@("`@("`@("\O(%=!4DY)3D<Z('=E(&YE960@=&AE(&]U='!U
M="!B=69F97(@+2!P;W-S:6)L92!C;&%S:&5S"B`@("`@("`@;V)?<W1A<G0H
M*3L*("`@("`@("!O8E]I;7!L:6-I=%]F;'5S:"AF86QS92D["@H@("`@("`@
M(')E='5R;B`G)SL*("`@('T@+R\@96YD(&9U;F,@<W1A<G0*"B`@("`O*@H@
M("`@*B!3=&]R97,@=&AE(&-O;G1E;G0@;V8@=&AE(&]U='!U="!B=69F97(@
M:6YT;R!T:&4@8V%C:&4@86YD(')E='5R;G,@=&AE(&-O;G1E;G0N"B`@("`J
M"B`@("`J($!P87)A;2`@("!M:7AE9"`@(&QI9F5T:6UE(&]F('1H92!C86-H
M960@9&%T82!I;B!S96-O;F1S("T@,"!F;W(@96YD;&5S<RX@36]R92!F;W)M
M871S(&%V86EL86)L92X@<V5E($-O;G1A:6YE<CHZ9V5T17AP:7)E<T%B<V]L
M=71E*"D*("`@("H@0'!A<F%M("`@('-T<FEN9R`@861D:71I;VYA;"!U<V5R
M9&5F:6YE9"!D871A"B`@("`J($!R971U<FX@("!S=')I;F<@(&-A8VAE9"!O
M=71P=70*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@
M96YD4')I;G0H*2P@96YD1V5T*"DL($-O;G1A:6YE<CHZ9V5T17AP:7)E<T%B
M<V]L=71E*"D*("`@("HO"B`@("!F=6YC=&EO;B!E;F0H)&5X<&ER92`](#`L
M("1U<V5R9&%T82`]("<G*2!["B`@("`@("`@)&-O;G1E;G0@/2!O8E]G971?
M8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@("`@("`@
M+R\@<W1O<F4@:6X@=&AE(&-A8VAE"B`@("`@("`@:68@*"1T:&ES+3YC86-H
M:6YG*0H@("`@("`@("`@("`D=&AI<RT^8V]N=&%I;F5R+3YS879E*"1T:&ES
M+3YO=71P=71?:60L("1C;VYT96YT+"`D97AP:7)E+"`D=&AI<RT^;W5T<'5T
M7V=R;W5P+"`D=7-E<F1A=&$I.PH*("`@("`@("!R971U<FX@)&-O;G1E;G0[
M"B`@("!]("\O(&5N9"!F=6YC(&5N9"@I"@H@("`@+RHJ"B`@("`J(%-T;W)E
M<R!T:&4@8V]N=&5N="!O9B!T:&4@;W5T<'5T(&)U9F9E<B!I;G1O('1H92!C
M86-H92!A;F0@<')I;G1S('1H92!C;VYT96YT+@H@("`@*@H@("`@*B!`8G)O
M=&AE<B`@96YD*"D*("`@("HO"B`@("!F=6YC=&EO;B!E;F10<FEN="@D97AP
M:7)E(#T@,"P@)'5S97)D871A(#T@)R<I('L*("`@("`@("`D=&AI<RT^<')I
M;G1#;VYT96YT*"1T:&ES+3YE;F0H)&5X<&ER92P@)'5S97)D871A*2D["B`@
M("!]("\O(&5N9"!F=6YC(&5N9%!R:6YT"@H@("`@+RHJ"B`@("`J(%-E;F1S
M('1H92!D871A('1O('1H92!U<V5R+@H@("`@*B!4:&ES(&ES(&9O<B!C;VUP
M871I8FEL:71Y('=I=&@@3W5T<'5T0V]M<')E<W-I;VX*("`@("H@"B`@("`J
M($!P87)A;2`@("!S=')I;F<*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@
M*B\@("`@"B`@("!F=6YC=&EO;B!P<FEN=$-O;G1E;G0H)&-O;G1E;G0@/2`G
M)RD@>PH@("`@("`@(&EF("@G)R`]/2`D8V]N=&5N="D*("`@("`@("`@("`@
M)&-O;G1E;G0@/2`F)'1H:7,M/F-O;G1A:6YE<BT^8V%C:&5D871A.PH@("`@
M("`@("`@("`*("`@("`@("!P<FEN="`D8V]N=&5N=#L*("`@('T*("`@("\J
M*@H@("`@*B!2971U<FYS('1H92!C;VYT96YT(&]F('1H92!O=71P=70@8G5F
M9F5R(&)U="!D;V5S(&YO="!S=&]R92!I="!I;G1O('1H92!C86-H92X*("`@
M("H*("`@("H@57-E('1H:7,@;65T:&]D(&EF('1H92!C;VYT96YT(&]F('EO
M=7(@<V-R:7!T(&ES(&UA<FMU<"`H6$U,*0H@("`@*B!T:&%T(&AA<R!T;R!B
M92!P87)S960O8V]N=F5R=&5D("A84TQ4*2!B969O<F4@>6]U(&-A;B!O=71P
M=70*("`@("H@86YD('-T;W)E(&ET(&EN=&\@=&AE(&-A8VAE('5S:6YG('-A
M=F4H*2X*("`@("H*("`@("H@0')E='5R;B`@('-T<FEN9PH@("`@*B!`86-C
M97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!E;F10<FEN="@I+"!E;F0H
M*0H@("`@*B\*("`@(&9U;F-T:6]N(&5N9$=E="@I('L*("`@("`@("`D8V]N
M=&5N="`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@(&]B7V5N9%]C;&5A
M;B@I.PH*("`@("`@("`D=&AI<RT^;W5T<'5T7VED(#T@)R<["B`@("`@("`@
M)'1H:7,M/F]U='!U=%]G<F]U<"`]("<G.PH*("`@("`@("!R971U<FX@)&-O
M;G1E;G0["B`@("!]("\O(&5N9"!F=6YC(&5N9$=E=`I]("\O(&5N9"!C;&%S
M<R!O=71P=70*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A
M8VAE+T]U='!U=$-O;7!R97-S:6]N+G!H<```````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#(Q-3,T`#$P-3$U-#,Q,#4V`#`R,C8P,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S
M.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@0VAR:7-T:6%N(%-T
M;V-K97(@/&-H<F5G=4!P:&%N="YC:#X@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"G)E<75I<F5?
M;VYC92`G0V%C:&4O3W5T<'5T+G!H<"<["@HO*BH**B!#86-H92!U<VEN9R!/
M=71P=70@0G5F9F5R:6YG(&%N9"!C;VYT;F5T("AG>BD@8V]M<')E<W-I;VXN
M"BHJ(%5S86=E(&5X86UP;&4Z"BH**B`@+R\@<&QA8V4@=&AI<R!S;VUE=VAE
M<F4@:6X@82!C96YT<F%L(&-O;F9I9R!F:6QE"BH@(&1E9FEN92A#04-(15]3
M5$]204=%7T-,05-3+"`G9FEL92<I.PHJ("`O+R!F:6QE('-T;W)A9V4@;F5E
M9',@82!D:7(@=&\@<'5T('1H92!C86-H92!F:6QE<PHJ("!D969I;F4H0T%#
M2$5?1$E2+"`G+W9A<B]T;7`O)RD["BH**B`@+R\@9V5T(&$@8V%C:&4@;V)J
M96-T"BH@("1C86-H92`](&YE=R!#86-H95]/=71P=70H0T%#2$5?4U1/4D%'
M15]#3$%34RP@87)R87DH)V-A8VAE7V1I<B<@/3X@0T%#2$5?1$E2*2D["BH*
M*B`@:68@*"$H)&-O;G1E;G0@/2`D8V%C:&4M/G-T87)T*"1C86-H92T^9V5N
M97)A=&5)1"@D4D5154535%]54DDI*2DI('L**B`@("!P<FEN="`B:&5L;&\@
M=V]R;&0B.PHJ("`@("1C86-H92T^96YD4')I;G0H*S$P,#`I.PHJ("!]"BH@
M(&5L<V4@>PHJ("`@("1C86-H92T^<')I;G1#;VYT96YT*"D["BH@('T**@HJ
M("`@3U(**@HJ("!I9B`H*"1C;VYT96YT(#T@)&-A8VAE+3YS=&%R="@D8V%C
M:&4M/F=E;F5R871E240H)%)%455%4U1?55))*2DI*2!["BH@("`@)&-A8VAE
M+3YP<FEN=$-O;G1E;G0H*3L**B`@("!D:64H*3L**B`@?0HJ("`@('!R:6YT
M(")H96QL;R!W;W)L9"(["BH@("`@)&-A8VAE+3YE;F10<FEN="@K,3`P,"D[
M"BH**@HJ($)A<V5D('5P;VX@82!C87-E('-T=61Y(&9R;VT@0VAR:7-T:6%N
M(%-T;V-K97(@86YD(&EN<W!I<F5D(&)Y(&IP8V%C:&4N"BH**B!`=F5R<VEO
M;B`@)$ED.B!/=71P=71#;VUP<F5S<VEO;BYP:'`L=B`Q+C<@,C`P,R\P,2\P
M-"`Q,3HU-#HT-2!M:B!%>'`@)`HJ($!A=71H;W(@("!5;&8@5V5N9&5L(#QU
M;&8N=V5N9&5L0'!H<&1O8RYD93XL($-H<FES=&EA;B!3=&]C:V5R(#QC:')E
M9W5`<&AA;G0N8V@^"BH@0&%C8V5S<R`@('!U8FQI8PHJ($!P86-K86=E("!#
M86-H90HJ+PIC;&%S<R!#86-H95]/=71P=71#;VUP<F5S<VEO;B!E>'1E;F1S
M($-A8VAE7T]U='!U="!["B`@("`*("`@("\J*@H@("`@*B!%;F-O9&EN9RP@
M=VAA="!T:&4@=7-E<B`H:71S(&)R;W=S97(I(&]F('EO=7(@=V5B<VET92!A
M8V-E<'1S"B`@("`J(`H@("`@*B`B875T;R(@<W1A;F1S(&9O<B!T97-T('5S
M:6YG("1?4T525D526R=(5%107T%#0T505%]%3D-/1$E.1R==*"1(5%107T%#
M0T505%]%3D-/1$E.1RDN"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@
M*B!`<V5E("!#86-H95]/=71P=71#;VUP<F5S<VEO;B@I+"!S971%;F-O9&EN
M9R@I"B`@("`J+PH@("`@=F%R("1E;F-O9&EN9R`]("=A=71O)SL*(`H@("`@
M"B`@("`O*BH*("`@("H@365T:&]D('5S960@9F]R(&-O;7!R97-S:6]N"B`@
M("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B!`<V5E("!I<T-O;7!R97-S
M960H*0H@("`@*B\@"B`@("!V87(@)&-O;7!R97-S:6]N(#T@)R<["@H@("`@
M"B`@("`O*BH*("`@("H@4V5T<R!T:&4@<W1O<F%G92!D971A:6QS(&%N9"!T
M:&4@8V]N=&5N="!E;F-O9&EN9R!U<V5D("AI9B!N;W0@875T;V1E=&5C=&EO
M;BD*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@($YA;64@;V8@8V]N
M=&%I;F5R(&-L87-S"B`@("`J($!P87)A;2`@("!A<G)A>2`@($%R<F%Y('=I
M=&@@8V]N=&%I;F5R(&-L87-S(&]P=&EO;G,*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@8V]N=&5N="!E;F-O9&EN9R!M;V1E("T@875T;R`]/B!T97-T('=H
M:6-H(&5N8V]D:6YG('1H92!U<V5R(&%C8V5P=',*("`@("HO("`@(`H@("`@
M9G5N8W1I;VX@0V%C:&5?3W5T<'5T0V]M<')E<W-I;VXH)&-O;G1A:6YE<BP@
M)&-O;G1A:6YE<E]O<'1I;VYS(#T@)R<L("1E;F-O9&EN9R`]("=A=71O)RD@
M>PH@("`@"B`@("`@("`@)'1H:7,M/G-E=$5N8V]D:6YG*"1E;F-O9&EN9RD[
M"B`@("`@("`@)'1H:7,M/D-A8VAE*"1C;VYT86EN97(L("1C;VYT86EN97)?
M;W!T:6]N<RD["B`@("`@("`@"B`@("!]("\O(&5N9"!C;VYS=')U8W1O<@H*
M("`@(`H@("`@+RHJ"B`@("`J($-A;&P@<&%R96YT(&1E8V]N<W1R=6-T;W(N
M"B`@("`J+PH@("`@9G5N8W1I;VX@7T-A8VAE7T]U='!U=$-O;7!R97-S:6]N
M*"D@>PH@("`@("`@("1T:&ES+3Y?0V%C:&4H*3L*("`@('T@+R\@96YD(&1E
M8V]N<W1R=6-T;W(*("`@(`H*("`@(&9U;F-T:6]N(&=E;F5R871E240H)'9A
M<FEA8FQE*2!["B`@("`@("`@"B`@("`@("`@)'1H:7,M/F-O;7!R97-S:6]N
M(#T@)'1H:7,M/F=E=$5N8V]D:6YG*"D["B`@("`@("`@"B`@("`@("`@<F5T
M=7)N(&UD-2AS97)I86QI>F4H)'9A<FEA8FQE*2`N('-E<FEA;&EZ92@D=&AI
M<RT^8V]M<')E<W-I;VXI*3L*("`@('T@+R\@96YD(&=E;F5R871E240*"B`@
M("`*("`@(&9U;F-T:6]N(&=E="@D:60L("1G<F]U<"D@>PH@("`@("`@("1T
M:&ES+3YC;VYT96YT(#T@)R<["B`@("`@("`@"B`@("`@("`@:68@*"$D=&AI
M<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@(`H@
M("`@("`@(&EF("@D=&AI<RT^:7-#86-H960H)&ED+"`D9W)O=7`I("8F("$D
M=&AI<RT^:7-%>'!I<F5D*"1I9"P@)&=R;W5P*2D*("`@("`@("`@("`@)'1H
M:7,M/F-O;G1E;G0@/2`D=&AI<RT^;&]A9"@D:60L("1G<F]U<"D["B`@("`@
M("`@("`@(`H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&5N=#L*("`@('T@
M+R\@96YD(&9U;F,@9V5T"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(%-T;W!S
M('1H92!O=71P=70@8G5F9F5R:6YG+"!S879E<R!I="!T;R!T:&4@8V%C:&4@
M86YD(')E='5R;G,@=&AE(%]C;VUP<F5S<V5D7R!C;VYT96YT+B`*("`@("H*
M("`@("H@268@>6]U(&YE960@=&AE('5N8V]M<')E<W-E9"!C;VYT96YT(&9O
M<B!F=7)T:&5R('!R;V-E<W-I;VX@8F5F;W)E"B`@("`J(&ET)W,@<V%V960@
M:6X@=&AE(&-A8VAE('5S92!E;F1'970H*2X@96YD1V5T*"D@9&]E<R!?;F]T
M(&-O;7!R97-S7RX*("`@("HO("`@(`H@("`@9G5N8W1I;VX@96YD*"1E>'!I
M<F4@/2`P+"`D=7-E<F1A=&$@/2`G)RD@>PH@("`@("`@("1C;VYT96YT(#T@
M;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@;V)?96YD7V-L96%N*"D["@H@
M("`@("`@("\O('-T;W)E(&EN('1H92!C86-H90H@("`@("`@(&EF("@D=&AI
M<RT^8V%C:&EN9RD@>PH@("`@("`@("`@("`D=&AI<RT^97AT4V%V92@D=&AI
M<RT^;W5T<'5T7VED+"`D8V]N=&5N="P@)'5S97)D871A+"`D97AP:7)E+"`D
M=&AI<RT^;W5T<'5T7V=R;W5P*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YC;VYT96YT.R`@("`@("`@("`@("`@("`*("`@("`@("!]"B`@("`@("`@
M("`@(`H@("`@("`@(')E='5R;B`D8V]N=&5N=#L@("`@("`@(`H@("`@?2`O
M+R!E;F0@9G5N8R!E;F0H*0H@("`@"B`@("`*("`@(&9U;F-T:6]N(&5N9%!R
M:6YT*"1E>'!I<F4@/2`P+"`D=7-E<F1A=&$@/2`G)RD@>PH@("`@("`@("1T
M:&ES+3YP<FEN=$-O;G1E;G0H)'1H:7,M/F5N9"@D97AP:7)E+"`D=7-E<F1A
M=&$I*3L*("`@('T@+R\@96YD(&9U;F,@96YD4')I;G0*"B`@("`*("`@("\J
M*@H@("`@*B!3879E<R!T:&4@9VEV96X@9&%T82!T;R!T:&4@8V%C:&4N"B`@
M("`J(`H@("`@*B\@("`*("`@(&9U;F-T:6]N(&5X=%-A=F4H)&ED+"`D8V%C
M:&5D871A+"`D=7-E<F1A=&$L("1E>'!I<F5S(#T@,"P@)&=R;W5P(#T@)V1E
M9F%U;'0G*2!["B`@("`@("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@
M("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(&EF("@D=&AI<RT^8V]M<')E
M<W-I;VXI('L@("`@("`@("`@("`*("`@("`@("`@("`@"B`@("`@("`@("`@
M("1L96X@/2!S=')L96XH)&-A8VAE9&%T82D[("`@("`@("`@("`@"B`@("`@
M("`@("`@("1C<F,@/2!C<F,S,B@D8V%C:&5D871A*3L*("`@("`@("`@("`@
M)&-A8VAE9&%T82`](&=Z8V]M<')E<W,H)&-A8VAE9&%T82P@.2D["B`@("`@
M("`@("`@("1T:&ES+3YC;VYT96YT(#T@<W5B<W1R*"1C86-H961A=&$L(#`L
M('-T<FQE;B@D8V%C:&5D871A*2`M(#0I("X@<&%C:R@G5B<L("1C<F,I("X@
M<&%C:R@G5B<L("1L96XI.PH@("`@("`@("`@("`*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`*("`@("`@("`@("`@)'1H:7,M/F-O;G1E;G0@/2`D
M8V%C:&5D871A.PH@("`@("`@("`@("`*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YC;VYT86EN97(M/G-A=F4H)&ED+"`D=&AI<RT^8V]N=&5N
M="P@)&5X<&ER97,L("1G<F]U<"P@)'5S97)D871A*3L*("`@('T@+R\@96YD
M(&9U;F,@97AT4V%V90H@("`@"B`@("`O*BH*("`@("H@4V5N9',@=&AE(&-O
M;7!R97-S960@9&%T82!T;R!T:&4@=7-E<BX*("`@("H@"B`@("`J($!P87)A
M;2`@("!S=')I;F<*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\@("`@
M"B`@("!F=6YC=&EO;B!P<FEN=$-O;G1E;G0H)&-O;G1E;G0@/2`G)RD@>PH@
M("`@("`@("1S97)V97(@/2`F)'1H:7,M/E]I;7!O<G1';&]B86Q687)I86)L
M92@B<V5R=F5R(BD["@H@("`@("`@(&EF("@G)R`]/2`D8V]N=&5N="D*("`@
M("`@("`@("`@)&-O;G1E;G0@/2`F)'1H:7,M/F-O;G1A:6YE<BT^8V%C:&5D
M871A.PH@("`@("`@("`@("`@("`@(`H@("`@("`@(&EF("@D=&AI<RT^8V]M
M<')E<W-I;VX@)B8@)'1H:7,M/F-A8VAI;F<I('L*("`@"B`@("`@("`@("`@
M("1E=&%G(#T@)U!%05(M0V%C:&4M)R`N(&UD-2AS=6)S='(H)&-O;G1E;G0L
M("TT,"DI.PH@("`@("`@("`@("!H96%D97(H(D5486<Z("1E=&%G(BD["B`@
M("`@("`@("`@(&EF("AI<W-E="@D<V5R=F5R6R=(5%107TE&7TY/3D5?34%4
M0T@G72D@)B8@<W1R<W1R*'-T<FEP<VQA<VAE<R@D<V5R=F5R6R=(5%107TE&
M7TY/3D5?34%40T@G72DL("1E=&%G*2D@>PH@("`@("`@("`@("`@("`@+R\@
M;F]T(&UO9&EF:65D"B`@("`@("`@("`@("`@("!H96%D97(H)TA45%`O,2XP
M(#,P-"<I.PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`*("`@("`@("`@("`@("`@("\O(&-L:65N="!A8V-E<'!T
M<R!S;VUE(&5N8V]D:6YG("T@<V5N9"!H96%D97)S("8@9&%T80H@("`@("`@
M("`@("`@("`@:&5A9&5R*")#;VYT96YT+45N8V]D:6YG.B![)'1H:7,M/F-O
M;7!R97-S:6]N?2(I.PH@("`@("`@("`@("`@("`@:&5A9&5R*"=687)Y.B!!
M8V-E<'0M16YC;V1I;F<G*3L*("`@("`@("`@("`@("`@('!R:6YT(")<>#%F
M7'@X8EQX,#A<>#`P7'@P,%QX,#!<>#`P7'@P,"(["B`@("`@("`@("`@('T*
M("`@("`@("`*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@9&EE*"1C;VYT
M96YT*3L*("`@('T@+R\@96YD(&9U;F,@<')I;G1#;VYT96YT"B`@("`*("`@
M(`H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(&5N8V]D:6YG(&UE=&AO9"!O
M9B!T:&4@8W5R<F5N="!D871A<V5T+B`*("`@("H*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PH@("`@*B!`<F5T=7)N("`@<W1R:6YG("!%;7!T>2!S=')I;F<@
M*'=H:6-H(&5V86QU871E<R!T;R!F86QS92D@;65A;G,@;F\@8V]M<')E<W-I
M;VX*("`@("HO"B`@("!F=6YC=&EO;B!I<T-O;7!R97-S960H*2!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YC;VUP<F5S<VEO;CL*("`@('T@+R\@96YD(&9U
M;F,@:7-#;VUP<F5S<V5D"@H@("`@+RHJ"B`@("`J(%-E=',@=&AE(&5N8V]D
M:6YG('1O(&)E('5S960N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`B875T;R(@;65A;G,@875T;V1E=&5C="!F;W(@979E<GD@8VQI96YT"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@("1E;F-O9&EN
M9PH@("`@*B\*("`@(&9U;F-T:6]N('-E=$5N8V]D:6YG*"1E;F-O9&EN9R`]
M("=A=71O)RD@>PH@("`@("`@("1T:&ES+3YE;F-O9&EN9R`]("1E;F-O9&EN
M9SL*("`@('T@+R\@96YD(&9U;F,@<V5T16YC;V1I;F<*("`@(`H@("`@"B`@
M("`O*BH*("`@("H@4F5T=7)N<R!T:&4@96YC;V1I;F<@=&\@8F4@=7-E9"!F
M;W(@=&AE(&1A=&$@=')A;G-M:7-S:6]N('1O('1H92!C;&EE;G0N"B`@("`J
M"B`@("`J($!S964@("`@("!S971%;F-O9&EN9R@I"B`@("`J+R`@("`*("`@
M(&9U;F-T:6]N(&=E=$5N8V]D:6YG*"D@>PH@("`@("`@("1S97)V97(@/2`F
M)'1H:7,M/E]I;7!O<G1';&]B86Q687)I86)L92@B<V5R=F5R(BD["@H@("`@
M("`@("\O(&5N8V]D:6YG('-E="!B>2!U<V5R("`@(`H@("`@("`@(&EF("@G
M875T;R<@(3T@)'1H:7,M/F5N8V]D:6YG*0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F5N8V]D:6YG.PH@("`@("`@(`H@("`@("`@("\O(&-H96-K('=H
M870@=&AE(&-L:65N="!A8V-E<'1S"B`@("`@("`@:68@*&9A;'-E("$]/2!S
M=')P;W,H)'-E<G9E<ELG2%144%]!0T-%4%1?14Y#3T1)3D<G72P@)W@M9WII
M<"<I*0H@("`@("`@("`@("!R971U<FX@)W@M9WII<"<["B`@("`@("`@:68@
M*&9A;'-E("$]/2!S=')P;W,H)'-E<G9E<ELG2%144%]!0T-%4%1?14Y#3T1)
M3D<G72P@)V=Z:7`G*2D*("`@("`@("`@("`@<F5T=7)N("=G>FEP)SL*("`@
M("`@("`@("`@"B`@("`@("`@+R\@;F\@8V]M<')E<W-I;VX*("`@("`@("!R
M971U<FX@)R<["B`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC(&=E=$5N8V]D
M:6YG"@H@("`@+R\@>WM[(%]I;7!O<G1';&]B86Q687)I86)L92@I"@H@("`@
M+RHJ"B`@("`@*B!);7!O<G0@=F%R:6%B;&5S(&9R;VT@<W!E8VEA;"!N86UE
M<W!A8V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@
M0'!A<F%M('-T<FEN9R!4>7!E(&]F('9A<FEA8FQE("AS97)V97(L('-E<W-I
M;VXL('!O<W0I"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9?:6UP;W)T1VQO8F%L5F%R:6%B;&4H)'9A<FEA8FQE*2`*("`@
M('L*("`@("`@"B`@("`@("`@)'9A<B`](&YU;&P["@H@("`@("`@('-W:71C
M:"`H<W1R=&]L;W=E<B@D=F%R:6%B;&4I*2!["@H@("`@("`@("`@("!C87-E
M(")S97)V97(B(#H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D7U-%4E9%
M4BDI('L*("`@("`@("`@("`@("`@("`@("`D=F%R(#T@)B1?4T525D52.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M=F%R(#T@)B1'3$]"04Q36R=(5%107U-%4E9%4E]605)3)UT["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@(G-E<W-I;VXB(#H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M7U-%4U-)3TXI*2!["B`@("`@("`@("`@("`@("`@("`@)'9A<B`]("8D7U-%
M4U-)3TX["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1V87(@/2`F)$=,3T)!3%-;)TA45%!?4T534TE/3E]605)3)UT[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@(G!O<W0B(#H*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D7U!/4U0I*2!["B`@("`@("`@("`@("`@("`@("`@)'9A<B`]("8D
M7U!/4U0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1V87(@/2`F)$=,3T)!3%-;)TA45%!?4$]35%]605)3)UT["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'9A<CL*("`@('T@"@H@("`@+R\@?7T*
M?2`O+R!E;F0@8VQA<W,@3W5T<'5T0V]M<')E<W-I;VX*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O0V%C:&4O0V]N=&%I;F5R+G!H<```````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,S(S-S0`,3`U,34T,S$P-38`,#(Q,#`W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C
M:&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<G,Z(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!396)A
M<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@
M("`@("`@("`@("!\"B\O('P@("`@("`@("`@0VAR:7-T:6%N(%-T;V-K97(@
M/&-H<F5G=4!P:&%N="YC:#X@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!#;VYT
M86EN97(N<&AP+'8@,2XT(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0*
M"G)E<75I<F5?;VYC92`G0V%C:&4O17)R;W(N<&AP)SL*"B\J*@HJ($-O;6UO
M;B!B87-E(&-L87-S(&]F(&%L;"!C86-H92!S=&]R86=E(&-O;G1A:6YE<BX*
M*B`**B!4;R!S<&5E9"!U<"!T:&EN9W,@=V4@9&\@82!P<F5L;V%D('EO=2!S
M:&]U;&0@:VYO=R!A8F]U="P@;W1H97)W:7-E(&ET(&UI9VAT(`HJ('!L87D@
M>6]U(&$@=')I8VLN(%1H92!#86-H92!C;VYT<F]L;&5R(&-L87-S97,@*$-A
M8VAE+T-A8VAE+"!#86-H92]/=71P=70L("XN+BD**B!U<W5A;&QY(&1O('-O
M;65T:&EN9R!L:6ME(&ES("AI<T-A8VAE9"@D:60I("8F("%I<T5X<&ER960H
M)&ED*2D@<F5T=7)N("1C;VYT86EN97(M/FQO860H)&ED*2X**B!I9B!Y;W4@
M:6UP;&5M96YT(&ES0V%C:&5D*"DL(&ES17AP:7)E9"@I(&%N9"!L;V%D*"D@
M<W1R86EG:'0@86AE860L(&5A8V@@;V8@=&AI<R`**B!F=6YC=&EO;G,@=VEL
M;"!R97-U;'0@:6X@82!S=&]R86=E(&UE9&EU;2`H9&(L(&9I;&4L+BXN*2!A
M8V-E<W,N(%1H:7,@9V5N97)A=&5S('1O;R!M=6-H(&QO860N(`HJ($YO=RP@
M82!S:6UP;&4@<W!E8W5L871I=F4@<')E;&]A9"!S:&]U;&0@<V%V97,@=&EM
M92!I;B!M;W-T(&-A<V5S+B!7:&5N979E<B`**B!O;F4@;V8@=&AE(&UE;G1I
M;VYE9"!M971H;V1S(&ES(&EN=F]K960@=V4@<')E;&]A9"!T:&4@8V%C:&5D
M(&1A=&%S970@:6YT;R!C;&%S<R!V87)I86)L97,N"BH@5&AA="!M96%N<R!T
M:&%T('=E(&AA=F4@;VYL>2!O;F4@<W1O<F%G92!M961I=6T@86-C97-S(&9O
M<B!T:&4@<V5Q=65N8V4**B`@*&ES0V%C:&5D*"1I9"D@)B8@(6ES17AP:7)E
M9"@D:60I*2!R971U<FX@)&-O;G1A:6YE<BT^;&]A9"@D:60I+@HJ(%1H92!B
M860@=&AI;F<@:7,@=&AA="!T:&4@<')E;&]A9&5D(&1A=&$@;6EG:'0@8F4@
M;W5T9&%T960@;65A;G=H:6QE+"!W:&EC:"!I<R`**B!U;FQI:V5L>2!B=70@
M9F]R('EO=2!P;W=E<B!U<V5R<RP@8F4@=V%R;F5D+B!)9B!Y;W4@9&\@;F]T
M('=A;G0@=&AE('!R96QO860@"BH@>6]U('-H;W5L9"!S=VET8V@@:70@;V9F
M(&)Y('-E='1I;F<@=&AE(&-L87-S('9A<FEA8FQE("1P<F5L;V%D('1O(&9A
M;'-E+B!!;GEW87DL('1H:7,@:7,@"BH@;F]T(')E8V]M;65N9&5D(0HJ(`HJ
M($!A=71H;W(@("!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X*
M*B!`=F5R<VEO;B`@)$ED.B!#;VYT86EN97(N<&AP+'8@,2XT(#(P,#,O,#$O
M,#0@,3$Z-30Z-#4@;6H@17AP("0**B!`<&%C:V%G92`@0V%C:&4**B!`86-C
M97-S("`@<'5B;&EC"BH@0&%B<W1R86-T"BHO"F-L87-S($-A8VAE7T-O;G1A
M:6YE<B!["@H@("`@+RHJ"B`@("`J($9L86<@:6YD:6-A=&EN9R!W:&5T97(@
M=&\@<')E;&]A9"!D871A<V5T<RX*("`@("H*("`@("H@4V5E('1H92!C;&%S
M<R!D97-C<FEP=&EO;B!F;W(@;6]R92!D971A:6QS+@H@("`@*@H@("`@*B!`
M=F%R("!B;V]L96%N"B`@("`J+PH@("`@=F%R("1P<F5L;V%D(#T@=')U93L*
M"B`@("`O*BH*("`@("H@240@;V8@82!P<F5L;V%D960@9&%T87-E=`H@("`@
M*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)&ED(#T@)R<[
M"@H@("`@+RHJ"B`@("`J($-A8VAE(&=R;W5P(&]F(&$@<')E;&]A9&5D(&1A
M=&%S970*("`@("H*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R
M("1G<F]U<"`]("<G.PH*("`@("\J*@H@("`@*B!%>'!I<F%T:6]N('1I;65S
M=&%M<"!O9B!A('!R96QO861E9"!D871A<V5T+@H@("`@*B`*("`@("H@0'9A
M<B`@:6YT96=E<B`P(&UE86YS(&YE=F5R+"!E;F1L97-S"B`@("`J+PH@("`@
M=F%R("1E>'!I<F5S(#T@,#L*"B`@("`O*BH*("`@("H@5F%L=64@;V8@82!P
M<F5L;V%D960@9&%T87-E="X*("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@
M("`@*B\*("`@('9A<B`D8V%C:&5D871A(#T@)R<["@H@("`@+RHJ"B`@("`J
M(%!R96QO861E9"!U<V5R9&%T82!F:65L9"X*("`@("H@"B`@("`J($!V87(@
M('-T<FEN9PH@("`@*B\*("`@('9A<B`D=7-E<F1A=&$@/2`G)SL*"B`@("`O
M*BH*("`@("H@1FQA9R!I;F1I8V%T:6YG('1H870@=&AE(&1A=&%S970@<F5Q
M=65S=&5D(&9O<B!P<F5L;V%D:6YG(&ES('5N:VYO=VXN"B`@("`J("`*("`@
M("H@0'9A<B`@8F]O;&5A;@H@("`@*B\*("`@('9A<B`D=6YK;F]W;B`]('1R
M=64["@H@("`@+RHJ"B`@("`J($5N8V]D:6YG(&UO9&4@9F]R(&-A8VAE(&1A
M=&$Z(&)A<V4V-"!O<B!A9&1S;&%S:&5S*"D@*'-L87-H*2X*("`@("H*("`@
M("H@0'9A<B`@<W1R:6YG("!B87-E-C0@;W(@<VQA<V@*("`@("HO"B`@("!V
M87(@)&5N8V]D:6YG7VUO9&4@/2`G8F%S938T)SL*("`@(`H@("`@+RHJ"B`@
M("`J($AI9VAW871E<B!M87)K("T@;6%X:6UU;2!S<&%C92!R97%U:7)E9"!B
M>2!A;&P@8V%C:&4@96YT<FEE<RX*("`@("H@"B`@("`J(%=H96YE=F5R('1H
M92!G87)B86=E(&-O;&QE8W1I;VX@<G5N<R!I="!C:&5C:W,@=&AE(&%M;W5N
M="!O9B!S<&%C90H@("`@*B!R97%U:7)E9"!B>2!A;&P@8V%C:&4@96YT<FEE
M<RX@268@:70G<R!M;W)E('1H86X@;B`H:&EG:'=A=&5R*2!B>71E<PH@("`@
M*B!T:&4@9V%R8F%G92!C;VQL96-T:6]N(&1E;&5T97,@87,@;6%N>2!E;G1R
M:65S(&%S(&YE8V5S<V%R>2!T;R!R96%C:"!T:&4*("`@("H@;&]W=V%T97(@
M;6%R:RX@"B`@("`J(`H@("`@*B!`=F%R("!I;G0*("`@("H@0'-E92`@;&]W
M=V%T97(*("`@("HO"B`@("!V87(@)&AI9VAW871E<B`](#(P-#@P,#`[(`H@
M("`@"B`@("`*("`@("\J*@H@("`@*B!,;W=W871E<B!M87)K"B`@("`J"B`@
M("`J($!V87(@(&EN=`H@("`@*B!`<V5E("!H:6=H=V%T97(*("`@("HO"B`@
M("!V87(@)&QO=W=A=&5R(#T@,34S-C`P,#L*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@3W!T:6]N<R!T:&%T(&-A;B!B92!S970@:6X@979E<GD@9&5R:79E
M9"!C;&%S<R!U<VEN9R!I="=S(&-O;G-T<G5C=&]R+@H@("`@*B`*("`@("H@
M0'9A<B`@87)R87D*("`@("HO"B`@("!V87(@)&%L;&]W961?;W!T:6]N<R`]
M(&%R<F%Y*"=E;F-O9&EN9U]M;V1E)RP@)VAI9VAW871E<B<L("=L;W=W871E
M<B<I.PH@("`@"B`@("`*("`@("\J*@H@("`@*B!,;V%D<R!A(&1A=&%S970@
M9G)O;2!T:&4@8V%C:&4N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R
M;W5P"B`@("`J($!R971U<FX@("!M:7AE9"`@(&1A=&%S970@=F%L=64@;W(@
M3E5,3"!O;B!F86EL=7)E"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO
M"B`@("!F=6YC=&EO;B!L;V%D*"1I9"P@)&=R;W5P*2!["B`@("`@("`@:68@
M*"1T:&ES+3YP<F5L;V%D*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:60@
M(3T@)&ED('Q\("1T:&ES+3YG<F]U<"`A/2`D9W)O=7`I"B`@("`@("`@("`@
M("`@("`D=&AI<RT^<')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F-A8VAE9&%T83L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!L:7-T*"`L("1D871A+"`I(#T@)'1H:7,M/F9E=&-H*"1I
M9"P@)&=R;W5P*3L*("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@
M('T*("`@('T@+R\@96YD(&9U;F,@;&]A9`H*("`@("\J*@H@("`@*B!2971U
M<FYS('1H92!U<V5R9&%T82!F:65L9"!O9B!A(&-A8VAE9"!D871A('-E="X*
M("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("!U<V5R9&%T80H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T57-E<F1A=&$H)&ED+"`D9W)O=7`I('L*
M("`@("`@("!I9B`H)'1H:7,M/G!R96QO860I('L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YI9"`A/2`D:60@?'P@)'1H:7,M/F=R;W5P("$]("1G<F]U<"D*
M("`@("`@("`@("`@("`@("1T:&ES+3YP<F5L;V%D*"1I9"P@)&=R;W5P*3L*
M("`@("`@("`@("`@("`@(`H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G5S
M97)D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&QI<W0H("P@
M+"`D=7-E<F1A=&$I(#T@)'1H:7,M/F9E=&-H*"1I9"P@)&=R;W5P*3L*("`@
M("`@("`@("`@<F5T=7)N("1U<V5R9&%T83L*("`@("`@("!]"B`@("!]("\O
M(&5N9"!F=6YC(&=E=%5S97)D871A"@H@("`@+RHJ"B`@("`J($-H96-K<R!I
M9B!A(&1A=&%S970@:7,@97AP:7)E9"X*("`@("H@"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M8V%C:&4@9W)O=7`*("`@("H@0'!A<F%M("`@(&EN=&5G97(@;6%X:6UU;2!A
M9V4@=&EM97-T86UP"B`@("`J($!R971U<FX@("!B;V]L96%N(`H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@:7-%>'!I<F5D
M*"1I9"P@)&=R;W5P+"`D;6%X7V%G92D@>PH@("`@("`@(&EF("@D=&AI<RT^
M<')E;&]A9"D@>PH@("`@("`@("`@:68@*"1T:&ES+3YI9"`A/2`D:60@?'P@
M)'1H:7,M/F=R;W5P("$]("1G<F]U<"D*("`@("`@("`@("`@)'1H:7,M/G!R
M96QO860H)&ED+"`D9W)O=7`I.PH@("`@("`@("`@"B`@("`@("`@("!I9B`H
M)'1H:7,M/G5N:VYO=VXI"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!C:&5C:R!I9B!A="!A;&P@
M:70@:7,@8V%C:&5D"B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES0V%C:&5D
M*"1I9"P@)&=R;W5P*2D*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!))VT@;&%Z>2XN+@H@
M("`@("`@("`@("!L:7-T*"1T:&ES+3YE>'!I<F5S+"`L("D@/2`D=&AI<RT^
M9F5T8V@H)&ED+"`D9W)O=7`I.PH@("`@("`@('T*"B`@("`@("`@+R\@96YD
M;&5S<PH@("`@("`@(&EF("@P(#T]("1T:&ES+3YE>'!I<F5S*0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4["@H@("`@("`@("\O('EO=2!F965L(&9I;F4L
M(%5L9C\*("`@("`@("!I9B`H)&5X<&ER960@(#T@*"1T:&ES+3YE>'!I<F5S
M(#P]('1I;64H*2!\?"`H)&UA>%]A9V4@)B8@*"1T:&ES+3YE>'!I<F5S(#P]
M("1M87A?86=E*2DI("D@>PH*("`@("`@("`@("`D=&AI<RT^<F5M;W9E*"1I
M9"P@)&=R;W5P*3L*("`@("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D97AP:7)E9#L*("`@('T@+R\@
M96YD(&9U;F,@:7-%>'!I<F5D"@H@("`@+RHJ"B`@("`J($-H96-K<R!I9B!A
M(&1A=&%S970@:7,@8V%C:&5D+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE
M(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J+PH@("`@9G5N
M8W1I;VX@:7-#86-H960H)&ED+"`D9W)O=7`I('L*("`@("`@("!I9B`H)'1H
M:7,M/G!R96QO860I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YI9"`A/2`D
M:60@?'P@)'1H:7,M/F=R;W5P("$]("1G<F]U<"D*("`@("`@("`@("`@("`@
M("1T:&ES+3YP<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@("`@(')E
M='5R;B`A*"1T:&ES+3YU;FMN;W=N*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FED17AI<W1S*"1I9"P@)&=R;W5P*3L*
M("`@("`@("!]"B`@("!]("\O(&5N9"!F=6YC(&ES0V%C:&5D"@H@("`@+R\*
M("`@("\O(&%B<W1R86-T(&UE=&AO9',*("`@("\O"@H@("`@+RHJ"B`@("`J
M($9E=&-H97,@82!D871A<V5T(&9R;VT@=&AE('-T;W)A9V4@;65D:75M+@H@
M("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J
M($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@
M("!A<G)A>2`@(&9O<FUA=#H@6V5X<&ER92!D871E+"!C86-H960@9&%T82P@
M=7-E<B!D871A70H@("`@*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*("`@("H@
M0&%B<W1R86-T"B`@("`J+PH@("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O
M=7`I('L*("`@("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D[
M"B`@("!]("\O(&5N9"!F=6YC(&9E=&-H"@H@("`@+RHJ"B`@("`J(%-T;W)E
M<R!A(&1A=&%S970N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D
M871A<V5T($E$"B`@("`J($!P87)A;2`@("!M:7AE9"`@(&1A=&$@=&\@<W1O
M<F4*("`@("H@0'!A<F%M("`@(&UI>&5D("`@=7-E<F1E9FEN960@97AP:7)E
M(&1A=&4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@861D:71I;VYA;"!U<V5R9&5F:6YE9"!D
M871A"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J($!T:')O=W,@("!#
M86-H95]%<G)O<@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!A8G-T
M<F%C=`H@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T82P@)&5X
M<&ER92P@)&=R;W5P+"`D=7-E<F1A=&$I('L*("`@("`@("`O+R!154535$E/
M3CH@4VAO=6QD('=E('5P9&%T92!T:&4@<')E;&]A9"!B=69F97(@:6YS=&5A
M9#\*("`@("`@("`O+R!$;VXG="!T:&EN:R!S;R!A<R!T:&4@<V5Q=65N8V4@
M<V%V92@I+VQO860H*2!I<R!U;FQI:V5L>2X*("`@("`@("`D=&AI<RT^9FQU
M<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@<F5T=7)N($Y53$P[
M"B`@("!]("\O(&5N9"!F=6YC('-A=F4*"B`@("`O*BH*("`@("H@4F5M;W9E
M<R!A(&1A=&%S970N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D
M871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P
M"B`@("`J($!R971U<FX@("!B;V]L96%N("`*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@*B!`86)S=')A8W0*("`@("HO("`@("`*("`@(&9U;F-T:6]N
M(')E;6]V92@D:60L("1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R
M96QO860H)&ED+"`D9W)O=7`I.PH@("`@("`@(')E='5R;B!.54Q,.PH@("`@
M?2`O+R!E;F0@9G5N8R!R96UO=F4*"B`@("`O*BH*("`@("H@1FQU<VAE<R!T
M:&4@8V%C:&4@+2!R96UO=F5S(&%L;"!C86-H97,@9&%T87-E=',@9G)O;2!T
M:&4@8V%C:&4N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@
M268@82!C86-H92!G<F]U<"!I<R!G:79E;B!O;FQY('1H92!G<F]U<"!W:6QL
M(&)E(&9L=7-H960*("`@("H@0')E='5R;B`@(&EN=&5G97(@("`@($YU;6)E
M<B!O9B!R96UO=F5D(&1A=&%S971S+"`M,2!O;B!F86EL=7)E"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,*("`@("H@0&%B<W1R86-T"B`@("`J+PH@("`@9G5N
M8W1I;VX@9FQU<V@H)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E
M;&]A9"@I.PH@("`@("`@(')E='5R;B!.54Q,.PH@("`@?2`O+R!E;F0@9G5N
M8R!F;'5S:`H*("`@("\J*@H@("`@*B!#:&5C:W,@:68@82!D871A<V5T(&5X
M:7-T<RX*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@
M240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@
M0')E='5R;B`@(&)O;VQE86X@"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("H@0&%B<W1R86-T"B`@("`J+PH@("`@9G5N8W1I;VX@:61%>&ES=',H)&ED
M+"`D9W)O=7`I('L*("`@("`@("!R971U<FX@3E5,3#L*("`@('T@+R\@96YD
M(&9U;F,@:61%>&ES=',*"B`@("`O*BH*("`@("H@4W1A<G1S('1H92!G87)B
M86=E(&-O;&QE8W1I;VXN"B`@("`J(`H@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`J($!A8G-T<F%C=`H@("`@*B\*("`@(&9U;F-T:6]N(&=A<F)A9V5#
M;VQL96-T:6]N*"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*
M("`@('T@+R\@96YD(&9U;F,@9V%R8F%G94-O;&QE8W1I;VX*"B`@("`O*BH*
M("`@("H@1&]E<R!A('-P96-U;&%T:79E('!R96QO860@;V8@82!D871A<V5T
M"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R
M;B`@(&)O;VQE86X*("`@("HO(`H@("`@9G5N8W1I;VX@<')E;&]A9"@D:60L
M("1G<F]U<"D@>PH@("`@("`@("\O('=H871E=F5R(&AA<'!E;G,L(')E;65M
M8F5R('1H92!P<F5L;V%D960@240*("`@("`@("`D=&AI<RT^:60@/2`D:60[
M"B`@("`@("`@)'1H:7,M/F=R;W5P(#T@)&=R;W5P.R`@("`@("`@"@H@("`@
M("`@(&QI<W0H)'1H:7,M/F5X<&ER97,L("1T:&ES+3YC86-H961A=&$L("1T
M:&ES+3YU<V5R9&%T82D@/2`D=&AI<RT^9F5T8V@H)&ED+"`D9W)O=7`I.PH*
M("`@("`@("!I9B`H3E5,3"`]/3T@)'1H:7,M/F5X<&ER97,I('L*("`@("`@
M("`@("`@+R\@575U<',L('5N:VYO=VX@240*("`@("`@("`@("`@)'1H:7,M
M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/G5N:VYO=VX@/2!F86QS93L*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]("\O(&5N9"!F=6YC('!R96QO860*
M"B`@("`O*BH*("`@("H@1FQU<VAE<R!T:&4@:6YT97)N86P@<')E;&]A9"!B
M=69F97(N"B`@("`J"B`@("`J('-A=F4H*2P@<F5M;W9E*"D@86YD(&9L=7-H
M*"D@;75S="!C86QL('1H:7,@;65T:&]D"B`@("`J('1O('!R965V96YT(&1I
M9F9E<F5N8V5S(&)E='=E96X@=&AE('!R96QO861E9"!V86QU97,@86YD(`H@
M("`@*B!T:&4@<F5A;"!C86-H92!C;VYT96YT<RX*("`@("H*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@9&%T87-E="!)1"P@:68@;&5F="!O=70@=&AE('!R
M96QO861E9"!V86QU97,@=VEL;"!B92!F;'5S:&5D+B`*("`@("H@("`@("`@
M("`@("`@("`@("`@268@9VEV96X@=&AE('!R96QO861E9"!V86QU97,@=VEL
M;"!O;FQY(&)E(&9L=7-H960@:68@=&AE>2!A<F4*("`@("H@("`@("`@("`@
M("`@("`@("`@97%U86P@=&\@=&AE(&=I=F5N(&ED(&%N9"!G<F]U<`H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<V5E("!P
M<F5L;V%D*"D*("`@("HO"B`@("!F=6YC=&EO;B!F;'5S:%!R96QO860H)&ED
M(#T@)R<L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)&ED
M('Q\("@D=&AI<RT^:60@/3T@)&ED("8F("1T:&ES+3YG<F]U<"`]/2`D9W)O
M=7`I*2!["B`@("`@("`@("`@("\O(&-L96%R('1H92!I;G1E<FYA;"!P<F5L
M;V%D('9A;'5E<PH@("`@("`@("`@("`D=&AI<RT^:60@/2`G)SL*("`@("`@
M("`@("`@)'1H:7,M/F=R;W5P(#T@)R<["B`@("`@("`@("`@("1T:&ES+3YC
M86-H961A=&$@/2`G)SL*("`@("`@("`@("`@)'1H:7,M/G5S97)D871A(#T@
M)R<["B`@("`@("`@("`@("1T:&ES+3YE>'!I<F5S(#T@+3$["B`@("`@("`@
M("`@("1T:&ES+3YU;FMN;W=N(#T@=')U93L*("`@("`@("!]"B`@("!]("\O
M(&5N9"!F=6YC(&9L=7-H4')E;&]A9`H*("`@("\J*@H@("`@*B!);7!O<G1S
M('1H92!R97%U97-T960@9&%T869I96QD<R!A<R!O8FIE8W0@=F%R:6%B;&5S
M(&EF(&%L;&]W960*("`@("H@"B`@("`J($!P87)A;2`@("!A<G)A>2`@($QI
M<W0@;V8@9FEE;&1S('1O(&)E(&EM<&]R=&5D(&%S(&]B:F5C="!V87)I86)L
M97,*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@3&ES="!O9B!A;&QO=V5D(&1A
M=&%F:65L9',*("`@("HO"B`@("!F=6YC=&EO;B!S971/<'1I;VYS*"1R97%U
M97-T960L("1A;&QO=V5D*2!["B`@("`@("`@9F]R96%C:"`H)&%L;&]W960@
M87,@)&L@/3X@)&9I96QD*0H@("`@("`@("`@("!I9B`H:7-S970H)')E<75E
M<W1E9%LD9FEE;&1=*2D*("`@("`@("`@("`@("`@("1T:&ES+3XD9FEE;&0@
M/2`D<F5Q=65S=&5D6R1F:65L9%T["B`@("`@("`@("`@("`@("`*("`@('T@
M+R\@96YD(&9U;F,@<V5T3W!T:6]N<PH*("`@("\J*@H@("`@*B!%;F-O9&5S
M('1H92!D871A(&9O<B!T:&4@<W1O<F%G92!C;VYT86EN97(N"B`@("`J(`H@
M("`@*B!`=F%R("!M:7AE9"!D871A('1O(&5N8V]D90H@("`@*B\*("`@(&9U
M;F-T:6]N(&5N8V]D92@D9&%T82D@>PH@("`@("`@(&EF("@G8F%S938T)R`]
M/2`D=&AI<RT^96YC;V1I;F=?;6]D92D@"B`@("`@("`@("`@(')E='5R;B!B
M87-E-C1?96YC;V1E*'-E<FEA;&EZ92@D9&%T82DI.PH@("`@("`@(&5L<V4@
M"B`@("`@("`@("`@(')E='5R;B!S97)I86QI>F4H)&1A=&$I.PH@("`@?2`O
M+R!E;F0@9G5N8R!E;F-O9&4*"B`@("`*("`@("\J*@H@("`@*B!$96-O9&5S
M('1H92!D871A(&9R;VT@=&AE('-T;W)A9V4@8V]N=&%I;F5R+@H@("`@*B`*
M("`@("H@0'9A<B`@;6EX960*("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&4H
M)&1A=&$I('L*("`@("`@("!I9B`H)V)A<V4V-"<@/3T@)'1H:7,M/F5N8V]D
M:6YG7VUO9&4I"B`@("`@("`@("`@(')E='5R;B!U;G-E<FEA;&EZ92AB87-E
M-C1?9&5C;V1E*"1D871A*2D["B`@("`@("`@96QS90H@("`@("`@("`@("!R
M971U<FX@=6YS97)I86QI>F4H)&1A=&$I.PH@("`@?2`O+R!E;F0@9G5N8R!D
M96-O9&4*"B`@("`*("`@("\J*@H@("`@*B!4<F%N<VQA=&5S(&AU;6%N(')E
M861A8FQE+W)E;&%T:79E('1I;65S(&EN('5N:7AT:6UE"B`@("`J"B`@("`J
M($!P87)A;2`@;6EX960@("!C86X@8F4@:6X@=&AE(&9O;&QO=VEN9R!F;W)M
M871S.@H@("`@*B`@("`@("`@("`@("`@(&AU;6%N(')E861A8FQE("`@("`@
M("`@(#H@>7EY>6UM9&1H:&UM6W-S75T@96<Z(#(P,#$P,S`X,#DU,3`P"B`@
M("`J("`@("`@("`@("`@("`@<F5L871I=F4@:6X@<V5C;VYD<R`H,2D@.B`K
M>'@@("`@("`@("`@("`@(&5G.B`K,3`*("`@("H@("`@("`@("`@("`@("!R
M96QA=&EV92!I;B!S96-O;F1S("@R*2`Z('@@/"`@.30V-C@Q,C`P("`@96<Z
M(#$P"B`@("`J("`@("`@("`@("`@("`@86)S;VQU=&4@=6YI>'1I;64@("`@
M("`@.B!X(#P@,C$T-S0X,S8T."`@(&5G.B`R,30W-#@S-C0X"B`@("`J("`@
M("`@("`@("`@("`@<V5E(&-O;6UE;G1S(&EN(&-O9&4@9F]R(&1E=&%I;',*
M("`@("H@0')E='5R;B!I;G1E9V5R('5N:7@@=&EM97-T86UP"B`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T17AP:7)E<T%B<V]L=71E*"1E>'!I<F5S*0H@("`@
M>PH@("`@("`@(&EF("@A)&5X<&ER97,I"B`@("`@("`@("`@(')E='5R;B`P
M.PH@("`@("`@("\O9F]R(&%P:2UC;VUP871I8FEL:71Y+"!O;F4@:&%S(&YO
M="!T;R!P<F]V:61E(&$@(BLB+`H@("`@("`@("\O(&EF(&EN=&5G97(@:7,@
M/"`Y-#8V.#$R,#`@*#T@2F%N(#`Q(#(P,#`@,#`Z,#`Z,#`I"B`@("`@("`@
M:68@*"<K)R`]/2`D97AP:7)E<ULP72!\?"`D97AP:7)E<R`\(#DT-C8X,3(P
M,"D*("`@("`@("!["B`@("`@("`@("`@(')E='5R;BAT:6UE*"D@*R`D97AP
M:7)E<RD["B`@("`@("`@?0H@("`@("`@("\O:68@:6YT96=E<B!I<R`\(#$P
M,#`P,#`P,#`P,"`H/2!I;B`S,30P('EE87)S*2P*("`@("`@("`O+R!I="!M
M=7-T(&)E(&%N(&%B<V]L=70@=6YI>'1I;64*("`@("`@("`O+R`H<VEN8V4@
M=&AE(")H=6UA;B!R96%D86)L92(@9&5F:6YI=&EO;B!A<VMS(&9O<B!A(&AI
M9VAE<B!N=6UB97(I"B`@("`@("`@96QS96EF("@D97AP:7)E<R`\(#$P,#`P
M,#`P,#`P,"D*("`@("`@("!["B`@("`@("`@("`@(')E='5R;B`D97AP:7)E
M<SL*("`@("`@("!]"B`@("`@("`@+R\@96QS92!I="=S(")H=6UA;B!R96%D
M86)L92(["B`@("`@("`@96QS90H@("`@("`@('L*("`@("`@("`@("`@)'EE
M87(@/2!S=6)S='(H)&5X<&ER97,L(#`L(#0I.PH@("`@("`@("`@("`D;6]N
M=&@@/2!S=6)S='(H)&5X<&ER97,L(#0L(#(I.PH@("`@("`@("`@("`D9&%Y
M(#T@<W5B<W1R*"1E>'!I<F5S+"`V+"`R*3L*("`@("`@("`@("`@)&AO=7(@
M/2!S=6)S='(H)&5X<&ER97,L(#@L(#(I.PH@("`@("`@("`@("`D;6EN=71E
M(#T@<W5B<W1R*"1E>'!I<F5S+"`Q,"P@,BD["B`@("`@("`@("`@("1S96-O
M;F0@/2!S=6)S='(H)&5X<&ER97,L(#$R+"`R*3L*("`@("`@("`@("`@<F5T
M=7)N(&UK=&EM92@D:&]U<BP@)&UI;G5T92P@)'-E8V]N9"P@)&UO;G1H+"`D
M9&%Y+"`D>65A<BD["B`@("`@("`@?0H@("`@("`@(`H@("`@?2`O+R!E;F0@
M9G5N8R!G971%>'!I<F5!8G-O;'5T90H@("`@"GT@+R\@96YD(&-L87-S($-O
M;G1A:6YE<@H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]!<'!L:6-A
M=&EO;BYP:'``````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S`U
M,@`Q,#4Q-30S,3`U-@`P,C$S,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4FEC:&%R
M9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R9SX@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!!<'!L:6-A=&EO;BYP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU
M-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92YP:'`G.PH*+R\@
M07!P;&EC871I;VX@;&5V96P@=F%R:6%B;&5S"B\O"B\O(%!U<G!O<V4*+R\@
M5F%R:6%B;&5S('1H870@87)E('!E<G-I<V5N="!A8W)O<W,@86QL('5S97(@
M<V5S<VEO;G,L"B\O(&YO="!J=7-T(&$@<W!E8VEF:6,@=7-E<B!A;&$@;F]R
M;6%L('-E<W-I;VYS+@HO+PHO+R!5<V%G93H*+R\*+R\@17AA;7!L92`Q.@HO
M+PHO+R`D87!P("`])B!N97<@0V%C:&5?07!P;&EC871I;VXH*3L*+R\@)%]!
M4%`@/28@)&%P<"T^9V5T1&%T82@I.PHO+PHO+R!);B!T:&ES(&-A<V4@=&AE
M("1?05!0('9A<FEA8FQE(&ES(&%K:6X@=&\@=&AE("1?4T534TE/3B!V87)I
M86)L92X*+R\@268@>6]U(&%D9"]R96UO=F4@<W1U9F8L(&ET('=I;&P@8F4@
M<F5F;&5C=&5D(&EN('1H92!N97AT(')E<75E<W0*+R\@*&]F(&%N>2!U<V5R
M*2X*+R\*+R\@17AA;7!L92`R.@HO+PHO+R`D9F]O(#T@)U-O;64@9&%T82<[
M"B\O("1B87(@/2`G4V]M92!O=&AE<B!D871A)SL*+R\*+R\@)&%P<"`])B!N
M97<@0V%C:&5?07!P;&EC871I;VXH*3L*+R\@)&%P<"T^<F5G:7-T97(H)V9O
M;R<I.PHO+R`D87!P+3YR96=I<W1E<B@G8F%R)RP@)&)A<BD[(`HO+PHO+R`D
M9F]O(#T@)T1I9F9E<F5N="!D871A)SL*+R\*+R\@26X@=&AI<R!C87-E('1H
M92!V87)I86)L97,@87)E(')E9VES=&5R960@=VET:"!T:&4@<F5G:7-T97(H
M*2!F=6YC=&EO;BX*+R\@5&AI<R!I<R!A:VEN('1O('-E<W-I;VY?<F5G:7-T
M97(H*2X*+R\*+R\@07,@=VET:"!S97-S:6]N7W)E9VES=&5R*"DL('1H92!C
M;VYT96YT<R!O9B!T:&4@=F%R:6%B;&4@870@=&AE("IE;F0J(&]F('1H90HO
M+R!R97%U97-T(&ES(')E9VES=&5R960@86YD(&YO="!A="!T:&4@<&]I;G0@
M;V8@<F5G:7-T<F%T:6]N+B!4:&5R969O<F4@:6X@=&AI<PHO+R!E>&%M<&QE
M+"!F;W(@=&AE("1F;V\@=F%R:6%B;&4L('1H92!S=')I;F<@)T1I9F9E<F5N
M="!D871A)R!I<R!S=&]R960@86YD(&YO="`*+R\@)U-O;64@9&%T82<N(%1H
M92!E>&-E<'1I;VX@=&\@=&AI<R!R=6QE(&ES(&EF('EO=2!U<V4@=&AE('-E
M8V]N9"!A<F=U;65N="!T;PHO+R!R96=I<W1E<B@I(&%S(&EN('1H92!S96-O
M;F0@8V%L;"!T;R!I="!A8F]V92X@5&AI<R!W:6QL(&-A=7-E('1H92!D871A
M('-U<'!L:65D"B\O(&EN('1H92!S96-O;F0@87)G=6UE;G0@=&\@8F4@<W1O
M<F5D(&%N9"!N;W0@=&AE(&-O;G1E;G1S(&%T('1H92!E;F0@;V8@=&AE(')E
M<75E<W0N"B\O"B\O($YO=&4Z($EF('EO=2!U<V4@=&AI<R!M971H;V0@=VET
M:"!R96=I<W1E<E]G;&]B86QS('1U<FYE9"!O;BP@=&AE('9A<FEA8FQE<R!W
M:6QL(&)E"B\O("`@("`@(&%U=&]M871I8V%L;'D@9VQO8F%L;&5D('5P;VX@
M<W1A<G1U<"P@*&EE+B!W:&5N('EO=2!C<F5A=&4@=&AE(&]B:F5C="DN"B\O
M"B\O($YO=&4Z($EF('EO=2!R96=I<W1E<B!A('9A<FEA8FQE('1H870@:7,@
M;F]T('-E="!W:&5N('1H92!S8W)I<'0@9FEN:7-H97,L(&ET('=I;&P*+R\@
M("`@("`@<F5G:7-T97)E9"!A<R!.54Q,+@HO+PHO+PHO+R`J*BH@66]U(&%R
M92!S=')O;F=L>2!R96-O;6UE;F1E9"!T;R!U<V4@;VYL>2!O;F4@;65T:&]D
M(&]F('1H92!T=V\@86)O=F4N("HJ*@HO+PHO+R`H26X@9F%C="!I9B!Y;W4@
M=7-E('1H92!R96=I<W1E<B@I(&9U;F-T:6]N('=I=&@@<F5G:7-T97)?9VQO
M8F%L<R!/9F8L('EO=2!H879E('1O"B\O("!U<V4@=&AE("1?05!0(&UE=&AO
M9"!T;R!G970@870@=&AE(&1A=&$I+@H*8VQA<W,@0V%C:&5?07!P;&EC871I
M;VX@97AT96YD<R!#86-H92!["@H@("`@=F%R("1D871A.PH@("`@=F%R("1I
M9#L*("`@('9A<B`D9W)O=7`["B`@("!V87(@)')E9VES=&5R961?=F%R<SL*
M"B`@("`O*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@3F%M92!O9B!C;VYT86EN97(@8VQA<W,*("`@("H@0'!A
M<F%M("`@(&%R<F%Y("`@07)R87D@=VET:"!C;VYT86EN97(@8VQA<W,@;W!T
M:6]N<PH@("`@*B\*("`@(&9U;F-T:6]N($-A8VAE7T%P<&QI8V%T:6]N*"1C
M;VYT86EN97(@/2`G9FEL92<L("1C;VYT86EN97)?;W!T:6]N<R`](&%R<F%Y
M*"=C86-H95]D:7(G(#T^("<O=&UP+R<L("=F:6QE;F%M95]P<F5F:7@G(#T^
M("=C86-H95\G*2P@)&ED(#T@)V%P<&QI8V%T:6]N7W9A<B<L("1G<F]U<"`]
M("=A<'!L:6-A=&EO;E]C86-H92<I"B`@("!["B`@("`@("`@)'1H:7,M/FED
M("`@(#T@)&ED.PH@("`@("`@("1T:&ES+3YG<F]U<"`]("1G<F]U<#L*("`@
M("`@("`D=&AI<RT^<F5G:7-T97)E9%]V87)S(#T@87)R87DH*3L*"B`@("`@
M("`@)'1H:7,M/D-A8VAE*"1C;VYT86EN97(L("1C;VYT86EN97)?;W!T:6]N
M<RD["B`@("`@("`@)'1H:7,M/F1A=&$@/2`D=&AI<RT^:7-#86-H960H)'1H
M:7,M/FED+"`D=&AI<RT^9W)O=7`I(#\@=6YS97)I86QI>F4H)'1H:7,M/F=E
M="@D=&AI<RT^:60L("1T:&ES+3YG<F]U<"DI(#H@87)R87DH*3L*"B`@("`@
M("`@+R\@268@<F5G:7-T97)?9VQO8F%L<R!O;BP@9VQO8F%L(&%L;"!R96=I
M<W1E<F5D('9A<FEA8FQE<PH@("`@("`@(&EF("AI;FE?9V5T*"=R96=I<W1E
M<E]G;&]B86QS)RD@04Y$(&ES7V%R<F%Y*"1T:&ES+3YD871A*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%T82!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`@("`@9VQO8F%L("0D:V5Y.PH@("`@("`@("`@
M("`@("`@)"1K97D@/2`D=F%L=64["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`J($1E<W1R=6-T;W(*("`@("H*("`@("H@
M1V5T<R!V86QU97,@;V8@86QL(')E9VES=&5R960@=F%R:6%B;&5S(&%N9"!S
M=&]R97,@=&AE;2X@5&AE;B!C86QL<R!S879E*"D@=&\*("`@("H@=W)I=&4@
M9&%T82!A=V%Y+@H@("`@*B\*("`@(&9U;F-T:6]N(%]#86-H95]!<'!L:6-A
M=&EO;B@I"B`@("!["B`@("`@("`@+R\@1V5T(&-O;G1E;G1S(&]F(&%L;"!R
M96=I<W1E<F5D('9A<FEA8FQE<PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI
M<RT^<F5G:7-T97)E9%]V87)S*2!!3D0@(65M<'1Y*"1T:&ES+3YR96=I<W1E
M<F5D7W9A<G,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YR96=I
M<W1E<F5D7W9A<G,@87,@)'9A<FYA;64I('L*("`@("`@("`@("`@("`@(&=L
M;V)A;"`D)'9A<FYA;64["B`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD
M=F%R;F%M95T@/2`D)'9A<FYA;64["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O(%-A=F4@=&AE(&1A=&$*("`@("`@("`D=&AI<RT^<V%V
M92@D=&AI<RT^:60L('-E<FEA;&EZ92@D=&AI<RT^9&%T82DL(#`L("1T:&ES
M+3YG<F]U<"D["B`@("!]"@H@("`@+RHJ"B`@("`J(')E9VES=&5R*"D*("`@
M("H*("`@("H@4F5G:7-T97)S(&$@=F%R:6%B;&4@=&\@8F4@<W1O<F5D+@H@
M("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!.86UE(&]F('9A<FEA8FQE
M('1O(')E9VES=&5R"B`@("`J($!P87)A;2`@("!M:7AE9"`@($]P=&EO;F%L
M(&1A=&$@=&\@<W1O<F4*("`@("HO"B`@("!F=6YC=&EO;B!R96=I<W1E<B@D
M=F%R;F%M92P@)&1A=&$@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D9&%T82DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'9A<FYA;65=
M(#T@)&1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/G)E9VES=&5R961?=F%R<UM=(#T@)'9A<FYA;64["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@*B!U;G)E9VES=&5R*"D*("`@("H*("`@("H@56YR
M96=I<W1E<G,@82!V87)I86)L92!F<F]M(&)E:6YG('-T;W)E9"X*("`@("H*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@3F%M92!O9B!V87)I86)L92!T;R!U
M;G)E9VES=&5R"B`@("`J+PH@("`@9G5N8W1I;VX@=6YR96=I<W1E<B@D=F%R
M;F%M92D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F1A=&%;)'9A
M<FYA;65=*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LD=F%R
M;F%M95TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("H@8VQE87(H
M*0H@("`@*@H@("`@*B!296UO=F5S(&%L;"!S=&]R960@9&%T80H@("`@*B\*
M("`@(&9U;F-T:6]N(&-L96%R*"D*("`@('L*("`@("`@("`D=&AI<RT^9&%T
M82`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`J(&=E=$1A=&$H*0H@
M("`@*@H@("`@*B!5<V4@=&AI<R!T;R!G970@82!R969E<F5N8V4@=&\@=&AE
M(&1A=&$@=&\@;6%N:7!U;&%T90H@("`@*B!I;B!C86QL:6YG('-C<FEP="X@
M16<N("1?05!0(#TF("1O8FHM/F=E=$1A=&$H*3L*("`@("H*("`@("H@0')E
M='5R;B!M:7AE9"`@($$@<F5F97)E;F-E('1O('1H92!D871A"B`@("`J+PH@
M("`@9G5N8W1I;VX@)F=E=$1A=&$H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9&%T83L*("`@('T*?0H_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-O;G-O;&4O````````````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#4V`#`Q-C<T-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M0V]N<V]L92]'971O<'0N<&AP````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,C(U,#``,3`U,34T,S$P-38`,#(P-S$T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!U<FPZ("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W(Z($%N9')E:2!:;6EE=G-K:2`\86YD<F5I0'!H<"YN970^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z($=E=&]P="YP:'`L=B`Q+C(Q+C0N-R`R
M,#`S+S$R+S`U(#(Q.C4W.C`Q(&%N9')E:2!%>'`@)`H*<F5Q=6ER95]O;F-E
M("=014%2+G!H<"<["@HO*BH*("H@0V]M;6%N9"UL:6YE(&]P=&EO;G,@<&%R
M<VEN9R!C;&%S<RX*("H*("H@0&%U=&AO<B!!;F1R96D@6FUI979S:VD@/&%N
M9')E:4!P:'`N;F5T/@H@*@H@*B\*8VQA<W,@0V]N<V]L95]'971O<'0@>PH@
M("`@+RHJ"B`@("`@*B!087)S97,@=&AE(&-O;6UA;F0M;&EN92!O<'1I;VYS
M+@H@("`@("H*("`@("`J(%1H92!F:7)S="!P87)A;65T97(@=&\@=&AI<R!F
M=6YC=&EO;B!S:&]U;&0@8F4@=&AE(&QI<W0@;V8@8V]M;6%N9"UL:6YE"B`@
M("`@*B!A<F=U;65N=',@=VET:&]U="!T:&4@;&5A9&EN9R!R969E<F5N8V4@
M=&\@=&AE(')U;FYI;F<@<')O9W)A;2X*("`@("`J"B`@("`@*B!4:&4@<V5C
M;VYD('!A<F%M971E<B!I<R!A('-T<FEN9R!O9B!A;&QO=V5D('-H;W)T(&]P
M=&EO;G,N($5A8V@@;V8@=&AE"B`@("`@*B!O<'1I;VX@;&5T=&5R<R!C86X@
M8F4@9F]L;&]W960@8GD@82!C;VQO;B`G.B<@=&\@<W!E8VEF>2!T:&%T('1H
M92!O<'1I;VX*("`@("`J(')E<75I<F5S(&%N(&%R9W5M96YT+"!O<B!A(&1O
M=6)L92!C;VQO;B`G.CHG('1O('-P96-I9GD@=&AA="!T:&4@;W!T:6]N"B`@
M("`@*B!T86ME<R!A;B!O<'1I;VYA;"!A<F=U;65N="X*("`@("`J"B`@("`@
M*B!4:&4@=&AI<F0@87)G=6UE;G0@:7,@86X@;W!T:6]N86P@87)R87D@;V8@
M86QL;W=E9"!L;VYG(&]P=&EO;G,N(%1H90H@("`@("H@;&5A9&EN9R`G+2TG
M('-H;W5L9"!N;W0@8F4@:6YC;'5D960@:6X@=&AE(&]P=&EO;B!N86UE+B!/
M<'1I;VYS('1H870*("`@("`J(')E<75I<F4@86X@87)G=6UE;G0@<VAO=6QD
M(&)E(&9O;&QO=V5D(&)Y("<])RP@86YD(&]P=&EO;G,@=&AA="!T86ME(&%N
M"B`@("`@*B!O<'1I;VX@87)G=6UE;G0@<VAO=6QD(&)E(&9O;&QO=V5D(&)Y
M("<]/2<N"B`@("`@*@H@("`@("H@5&AE(')E='5R;B!V86QU92!I<R!A;B!A
M<G)A>2!O9B!T=V\@96QE;65N=',Z('1H92!L:7-T(&]F('!A<G-E9`H@("`@
M("H@;W!T:6]N<R!A;F0@=&AE(&QI<W0@;V8@;F]N+6]P=&EO;B!C;VUM86YD
M+6QI;F4@87)G=6UE;G1S+B!%86-H(&5N=')Y(&EN"B`@("`@*B!T:&4@;&ES
M="!O9B!P87)S960@;W!T:6]N<R!I<R!A('!A:7(@;V8@96QE;65N=',@+2!T
M:&4@9FER<W0@;VYE"B`@("`@*B!S<&5C:69I97,@=&AE(&]P=&EO;BP@86YD
M('1H92!S96-O;F0@;VYE('-P96-I9FEE<R!T:&4@;W!T:6]N(&%R9W5M96YT
M+`H@("`@("H@:68@=&AE<F4@=V%S(&]N92X*("`@("`J"B`@("`@*B!,;VYG
M(&%N9"!S:&]R="!O<'1I;VYS(&-A;B!B92!M:7AE9"X*("`@("`J"B`@("`@
M*B!-;W-T(&]F('1H92!S96UA;G1I8W,@;V8@=&AI<R!F=6YC=&EO;B!A<F4@
M8F%S960@;VX@1TY5(&=E=&]P=%]L;VYG*"DN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("`D87)G<R`@("`@("`@("`@86X@87)R87D@;V8@8V]M;6%N
M9"UL:6YE(&%R9W5M96YT<PH@("`@("H@0'!A<F%M('-T<FEN9R`D<VAO<G1?
M;W!T:6]N<R`@<W!E8VEF:65S('1H92!L:7-T(&]F(&%L;&]W960@<VAO<G0@
M;W!T:6]N<PH@("`@("H@0'!A<F%M(&%R<F%Y("`D;&]N9U]O<'1I;VYS("`@
M<W!E8VEF:65S('1H92!L:7-T(&]F(&%L;&]W960@;&]N9R!O<'1I;VYS"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!T=V\M96QE;65N="!A<G)A>2!C
M;VYT86EN:6YG('1H92!L:7-T(&]F('!A<G-E9"!O<'1I;VYS(&%N9`H@("`@
M("H@=&AE(&YO;BUO<'1I;VX@87)G=6UE;G1S"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=&]P
M=#(H)&%R9W,L("1S:&]R=%]O<'1I;VYS+"`D;&]N9U]O<'1I;VYS(#T@;G5L
M;"D*("`@('L*("`@("`@("!R971U<FX@0V]N<V]L95]'971O<'0Z.F1O1V5T
M;W!T*#(L("1A<F=S+"`D<VAO<G1?;W!T:6]N<RP@)&QO;F=?;W!T:6]N<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N(&5X<&5C=',@
M)&%R9W,@=&\@<W1A<G0@=VET:"!T:&4@<V-R:7!T(&YA;64@*%!/4TE8+7-T
M>6QE*2X*("`@("`J(%!R97-E<G9E9"!F;W(@8F%C:W=A<F1S(&-O;7!A=&EB
M:6QI='DN"B`@("`@*B!`<V5E(&=E=&]P=#(H*0H@("`@("HO("`@(`H@("`@
M9G5N8W1I;VX@9V5T;W!T*"1A<F=S+"`D<VAO<G1?;W!T:6]N<RP@)&QO;F=?
M;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N($-O;G-O;&5?
M1V5T;W!T.CID;T=E=&]P="@Q+"`D87)G<RP@)'-H;W)T7V]P=&EO;G,L("1L
M;VYG7V]P=&EO;G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&%C='5A
M;"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@87)G=6UE;G0@<&%R<VEN9R!C;V1E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D;T=E=&]P="@D=F5R<VEO;BP@)&%R
M9W,L("1S:&]R=%]O<'1I;VYS+"`D;&]N9U]O<'1I;VYS(#T@;G5L;"D*("`@
M('L*("`@("`@("`O+R!I;B!C87-E('EO=2!P87-S(&1I<F5C=&QY(')E8610
M2%!!<F=V*"D@87,@=&AE(&9I<G-T(&%R9PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1A<F=S*2D@>PH@("`@("`@("`@("!R971U<FX@)&%R9W,["B`@
M("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D87)G<RDI('L*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*&%R<F%Y*"DL(&%R<F%Y*"DI.PH@("`@("`@('T*
M("`@("`@("`D;W!T<R`@("`@/2!A<G)A>2@I.PH@("`@("`@("1N;VY?;W!T
M<R`](&%R<F%Y*"D["@H@("`@("`@('-E='1Y<&4H)&%R9W,L("=A<G)A>2<I
M.PH*("`@("`@("!I9B`H)&QO;F=?;W!T:6]N<RD@>PH@("`@("`@("`@("!S
M;W)T*"1L;VYG7V]P=&EO;G,I.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@
M("`@("`@*B!0<F5S97)V92!B86-K=V%R9',@8V]M<&%T:6)I;&ET>2!W:71H
M(&-A;&QE<G,@=&AA="!R96QI960@;VX*("`@("`@("`@*B!E<G)O;F5O=7,@
M4$]325@@9FEX+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D=F5R<VEO;B`\
M(#(I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1A<F=S6S!=>S!]*2`F)B`D
M87)G<ULP77LP?2`A/2`G+2<I('L*("`@("`@("`@("`@("`@(&%R<F%Y7W-H
M:69T*"1A<F=S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5S970H)&%R9W,I.PH@("`@("`@('=H:6QE("AL:7-T*"1I+"`D87)G*2`]
M(&5A8V@H)&%R9W,I*2!["@H@("`@("`@("`@("`O*B!4:&4@<W!E8VEA;"!E
M;&5M96YT("<M+2<@;65A;G,@97AP;&EC:70@96YD(&]F"B`@("`@("`@("`@
M("`@(&]P=&EO;G,N(%1R96%T('1H92!R97-T(&]F('1H92!A<F=U;65N=',@
M87,@;F]N+6]P=&EO;G,*("`@("`@("`@("`@("`@86YD(&5N9"!T:&4@;&]O
M<"X@*B\*("`@("`@("`@("`@:68@*"1A<F<@/3T@)RTM)RD@>PH@("`@("`@
M("`@("`@("`@)&YO;E]O<'1S(#T@87)R87E?;65R9V4H)&YO;E]O<'1S+"!A
M<G)A>5]S;&EC92@D87)G<RP@)&D@*R`Q*2D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1A<F=[,'T@
M(3T@)RTG('Q\("AS=')L96XH)&%R9RD@/B`Q("8F("1A<F=[,7T@/3T@)RTG
M("8F("$D;&]N9U]O<'1I;VYS*2D@>PH@("`@("`@("`@("`@("`@)&YO;E]O
M<'1S(#T@87)R87E?;65R9V4H)&YO;E]O<'1S+"!A<G)A>5]S;&EC92@D87)G
M<RP@)&DI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H<W1R;&5N*"1A<F<I(#X@,2`F)B`D87)G>S%](#T]("<M)RD@
M>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@0V]N<V]L95]'971O<'0Z.E]P
M87)S94QO;F=/<'1I;VXH<W5B<W1R*"1A<F<L(#(I+"`D;&]N9U]O<'1I;VYS
M+"`D;W!T<RP@)&%R9W,I.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<F]R*2D*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&5R
M<F]R(#T@0V]N<V]L95]'971O<'0Z.E]P87)S95-H;W)T3W!T:6]N*'-U8G-T
M<B@D87)G+"`Q*2P@)'-H;W)T7V]P=&EO;G,L("1O<'1S+"`D87)G<RD["B`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(I*0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D;W!T<RP@)&YO;E]O
M<'1S*3L*("`@('T*"B`@("`O*BH*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E4VAO<G1/<'1I;VXH
M)&%R9RP@)'-H;W)T7V]P=&EO;G,L("8D;W!T<RP@)B1A<F=S*0H@("`@>PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE;B@D87)G*3L@)&DK*RD@
M>PH@("`@("`@("`@("`D;W!T(#T@)&%R9WLD:7T["B`@("`@("`@("`@("1O
M<'1?87)G(#T@;G5L;#L*"B`@("`@("`@("`@("\J(%1R>2!T;R!F:6YD('1H
M92!S:&]R="!O<'1I;VX@:6X@=&AE('-P96-I9FEE<B!S=')I;F<N("HO"B`@
M("`@("`@("`@(&EF("@H)'-P96,@/2!S=')S='(H)'-H;W)T7V]P=&EO;G,L
M("1O<'0I*2`]/3T@9F%L<V4@?'P@)&%R9WLD:7T@/3T@)SHG*0H@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B0V]N<V]L95]'971O<'0Z('5N<F5C;V=N:7IE9"!O<'1I;VX@+2T@)&]P
M="(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<W1R;&5N*"1S
M<&5C*2`^(#$@)B8@)'-P96-[,7T@/3T@)SHG*2!["B`@("`@("`@("`@("`@
M("!I9B`H<W1R;&5N*"1S<&5C*2`^(#(@)B8@)'-P96-[,GT@/3T@)SHG*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1I("L@,2`\('-T<FQE;B@D87)G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!/<'1I;VX@=&%K97,@
M86X@;W!T:6]N86P@87)G=6UE;G0N(%5S92!T:&4@<F5M86EN9&5R(&]F"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H92!A<F<@<W1R:6YG(&EF('1H
M97)E(&ES(&%N>71H:6YG(&QE9G0N("HO"B`@("`@("`@("`@("`@("`@("`@
M("`@("1O<'1S6UT@/2!A<G)A>2@D;W!T+"!S=6)S='(H)&%R9RP@)&D@*R`Q
M*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@+RH@3W!T:6]N(')E<75I<F5S(&%N(&%R9W5M96YT+B!5
M<V4@=&AE(')E;6%I;F1E<B!O9B!T:&4@87)G"B`@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG(&EF('1H97)E(&ES(&%N>71H:6YG(&QE9G0N("HO"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1I("L@,2`\('-T<FQE;B@D87)G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T<UM=(#T@87)R87DH)&]P
M="P@('-U8G-T<B@D87)G+"`D:2`K(#$I*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E(&EF("AL
M:7-T*"P@)&]P=%]A<F<I(#T@96%C:"@D87)G<RDI"B`@("`@("`@("`@("`@
M("`@("`@("`@("\J($5L<V4@=7-E('1H92!N97AT(&%R9W5M96YT+B`J+SL*
M("`@("`@("`@("`@("`@("`@("!E;'-E"B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYS;VQE7T=E=&]P=#H@
M;W!T:6]N(')E<75I<F5S(&%N(&%R9W5M96YT("TM("1O<'0B*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]P='-;
M72`](&%R<F%Y*"1O<'0L("1O<'1?87)G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]P87)S94QO;F=/<'1I;VXH)&%R9RP@)&QO;F=?;W!T
M:6]N<RP@)B1O<'1S+"`F)&%R9W,I"B`@("!["B`@("`@("`@0&QI<W0H)&]P
M="P@)&]P=%]A<F<I(#T@97AP;&]D92@G/2<L("1A<F<I.PH@("`@("`@("1O
M<'1?;&5N(#T@<W1R;&5N*"1O<'0I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D;&]N9U]O<'1I;VYS*3L@)&DK*RD@>PH@("`@("`@("`@
M("`D;&]N9U]O<'0@(#T@)&QO;F=?;W!T:6]N<ULD:5T["B`@("`@("`@("`@
M("1O<'1?<W1A<G0@/2!S=6)S='(H)&QO;F=?;W!T+"`P+"`D;W!T7VQE;BD[
M"@H@("`@("`@("`@("`O*B!/<'1I;VX@9&]E<VXG="!M871C:"X@1V\@;VX@
M=&\@=&AE(&YE>'0@;VYE+B`J+PH@("`@("`@("`@("!I9B`H)&]P=%]S=&%R
M="`A/2`D;W!T*0H@("`@("`@("`@("`@("`@8V]N=&EN=64["@H@("`@("`@
M("`@("`D;W!T7W)E<W0@(#T@<W5B<W1R*"1L;VYG7V]P="P@)&]P=%]L96XI
M.PH*("`@("`@("`@("`@+RH@0VAE8VL@=&AA="!T:&4@;W!T:6]N<R!U;FEQ
M=65L>2!M871C:&5S(&]N92!O9B!T:&4@86QL;W=E9`H@("`@("`@("`@("`@
M("!O<'1I;VYS+B`J+PH@("`@("`@("`@("!I9B`H)&]P=%]R97-T("$]("<G
M("8F("1O<'1[,'T@(3T@)STG("8F"B`@("`@("`@("`@("`@("`D:2`K(#$@
M/"!C;W5N="@D;&]N9U]O<'1I;VYS*2`F)@H@("`@("`@("`@("`@("`@)&]P
M="`]/2!S=6)S='(H)&QO;F=?;W!T:6]N<ULD:2LQ72P@,"P@)&]P=%]L96XI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M0V]N<V]L95]'971O<'0Z(&]P=&EO;B`M+21O<'0@:7,@86UB:6=U;W5S(BD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AS=6)S='(H)&QO;F=?
M;W!T+"`M,2D@/3T@)STG*2!["B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1L;VYG7V]P="P@+3(I("$]("<]/2<I('L*("`@("`@("`@("`@("`@("`@
M("`O*B!,;VYG(&]P=&EO;B!R97%U:7)E<R!A;B!A<F=U;65N="X*("`@("`@
M("`@("`@("`@("`@("`@("!486ME('1H92!N97AT(&%R9W5M96YT(&EF(&]N
M92!W87-N)W0@<W!E8VEF:65D+B`J+SL*("`@("`@("`@("`@("`@("`@("!I
M9B`H(7-T<FQE;B@D;W!T7V%R9RD@)B8@(2AL:7-T*"P@)&]P=%]A<F<I(#T@
M96%C:"@D87)G<RDI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*")#;VYS;VQE7T=E=&]P=#H@;W!T:6]N("TM
M)&]P="!R97%U:7)E<R!A;B!A<F=U;65N="(I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E(&EF
M("@D;W!T7V%R9RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(D-O;G-O;&5?1V5T;W!T.B!O<'1I;VX@+2TD;W!T(&1O97-N
M)W0@86QL;W<@86X@87)G=6UE;G0B*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&]P='-;72`](&%R<F%Y*"<M+2<@+B`D;W!T+"`D;W!T7V%R9RD[
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*")#;VYS;VQE7T=E=&]P=#H@=6YR96-O9VYI
M>F5D(&]P=&EO;B`M+21O<'0B*3L*("`@('T*"B`@("`O*BH*("`@("H@4V%F
M96QY(')E860@=&AE("1A<F=V(%!(4"!A<G)A>2!A8W)O<W,@9&EF9F5R96YT
M(%!(4"!C;VYF:6=U<F%T:6]N<RX*("`@("H@5VEL;"!T86ME(&-A<F4@;VX@
M<F5G:7-T97)?9VQO8F%L<R!A;F0@<F5G:7-T97)?87)G8U]A<F=V(&EN:2!D
M:7)E8W1I=F5S"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R
M971U<FX@;6EX960@=&AE("1A<F=V(%!(4"!A<G)A>2!O<B!014%2(&5R<F]R
M(&EF(&YO="!R96=I<W1E<F5D"B`@("`J+PH@("`@9G5N8W1I;VX@<F5A9%!(
M4$%R9W8H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D87)G=CL*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1A<F=V*2D@>PH@("`@("`@("`@("!I9B`H(4!I<U]A
M<G)A>2@D7U-%4E9%4ELG87)G=B==*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"%`:7-?87)R87DH)$=,3T)!3%-;)TA45%!?4T525D527U9!4E,G75LG87)G
M=B==*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*")#;VYS;VQE7T=E=&]P=#H@0V]U;&0@;F]T(')E860@8VUD(&%R
M9W,@*')E9VES=&5R7V%R9V-?87)G=CU/9F8_*2(I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=(5%107U-%
M4E9%4E]605)3)UU;)V%R9W8G73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)%]315)615);)V%R9W8G73L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1A<F=V.PH@("`@?0H*?0H*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O````````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#4W`#`Q-C(W-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R](5%107U)E<75E<W0O````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(P-38R`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TA45%!?4F5Q=65S="]D;V-S+P``````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,C$U
M,3(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O2%144%]297%U
M97-T+V1O8W,O97AA;7!L92YP:'``````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-C`T
M`#$P-3$U-#,Q,#4V`#`R,S8V,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+"!2:6-H87)D($AE
M>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@
M('P*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@
M=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`HO+R!\(&%R92!M
M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?`HO+R!\
M("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@
M?`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS
M('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\"B\O('P@;R!4:&4@
M;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R
M<V4@;W(@<')O;6]T92`@("`@('P*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@
M9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I
M='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!42$E3(%-/1E1705)%
M($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].
M5%))0E543U)3("`@?`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2
M($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\
M"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!(%!!4E1)
M0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!
M3$P@5$A%($-/4%E224=(5"`@?`HO+R!\($]73D52($]2($-/3E1224)55$]2
M4R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.
M5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y4
M24%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P*+R\@?"!,
M24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2
M(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`HO+R!\($1!5$$L($]2(%!23T9)
M5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@
M04Y$($].($%.62!\"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%
M4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P*
M+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE3
M24Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?`HO+R!\($]&(%1(25,@
M4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@
M3T8@4U5#2"!$04U!1T4N("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R9SX@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*"@HO*BH**B!4:&ES('=I;&P@9W)A8B!A('=E8G!A9V4@
M86YD(&1I<W!L87D@:70**B\*"6EN8VQU9&4H)TA45%`O4F5Q=65S="YP:'`G
M*3L*"@DD<F5Q(#T@)FYE=R!(5%107U)E<75E<W0H)VAT='`Z+R]W=W<N<&AP
M+FYE="<I.PH))')E<2T^<V5T365T:&]D*$A45%!?4D5154535%]-151(3T1?
M4$]35"D["@DD<F5Q+3YA9&10;W-T1&%T82@G1F]O)RP@)V)A<B<I.PH))')E
M<2T^<V5N9%)E<75E<W0H*3L*"21R97-P;VYS93$@/2`D<F5Q+3YG971297-P
M;VYS94)O9'DH*3L*"0H))')E<2T^<V5T365T:&]D*$A45%!?4D5154535%]-
M151(3T1?1T54*3L*"21R97$M/G-E=%523"@G:'1T<#HO+W!E87(N<&AP+FYE
M="<I.PH))')E<2T^8VQE87)0;W-T1&%T82@I.PH))')E<2T^<V5N9%)E<75E
M<W0H*3L*"@DD<F5S<&]N<V4R(#T@)')E<2T^9V5T4F5S<&]N<V5";V1Y*"D[
M"@H)96-H;R`D<F5S<&]N<V4Q.PH)96-H;R`D<F5S<&]N<V4R.PH_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R](5%107U)E<75E<W0O9&]C<R]D;W=N;&]A
M9"UP<F]G<F5S<RYP:'``````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4V-#0`,3`U,34T,S$P-38`,#(U
M-S`R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!!;B!E>&%M<&QE(&]F($QI<W1E;F5R('5S86=E('=I
M=&@@2%144%]297%U97-T+B!4:&ES(&1O=VYL;V%D<R!A;F0@<V%V97,@"B`J
M('1H92!F:6QE(&1I<W!L87EI;F<@=&AE('!R;V=R97-S(&)A<B!I;B!T:&4@
M<')O8V5S<RX*("H@"B`J($YO=&4@='=O('1H:6YG<SH*("H@,2D@5&AE(&9I
M;&4@<VAO=6QD(&)E(')U;B!I;B!C;VYS;VQE+"!N;W0@:6X@8G)O=W-E<CL*
M("H@,BD@66]U('-H;W5L9"!T=7)N(&]U='!U="!B=69F97)I;F<@3T9&(&9O
M<B!T:&ES('1O('=O<FL@<')O<&5R;'DN"B`J(`H@*B`D260Z(&1O=VYL;V%D
M+7!R;V=R97-S+G!H<"QV(#$N,2`R,#`S+S$P+S(W(#$P.C0X.C0Y(&%V8B!%
M>'`@)`H@*B\*"G)E<75I<F5?;VYC92`G2%144"]297%U97-T+G!H<"<["G)E
M<75I<F5?;VYC92`G2%144"]297%U97-T+TQI<W1E;F5R+G!H<"<["G)E<75I
M<F5?;VYC92`G0V]N<V]L92]0<F]G<F5S<T)A<BYP:'`G.PH*4$5!4CHZ<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T1)12D["@IS971?=&EM95]L:6UI
M="@P*3L*"F-L87-S($A45%!?4F5Q=65S=%]$;W=N;&]A9$QI<W1E;F5R(&5X
M=&5N9',@2%144%]297%U97-T7TQI<W1E;F5R"GL*("`@+RHJ"B`@("`J($AA
M;F1L92!F;W(@=&AE('1A<F=E="!F:6QE"B`@("`J($!V87(@:6YT"B`@("`J
M+PH@("`@=F%R("1?9G`["@H@("`O*BH*("`@("H@0V]N<V]L95]0<F]G<F5S
M<T)A<B!I;G1A;F-E('5S960@=&\@9&ES<&QA>2!T:&4@:6YD:6-A=&]R"B`@
M("`J($!V87(@;V)J96-T"B`@("`J+PH@("`@=F%R("1?8F%R.PH*("`@+RHJ
M"B`@("`J($YA;64@;V8@=&AE('1A<F=E="!F:6QE"B`@("`J($!V87(@<W1R
M:6YG"B`@("`J+PH@("`@=F%R("1?=&%R9V5T.PH*("`@+RHJ"B`@("`J($YU
M;6)E<B!O9B!B>71E<R!R96-E:79E9"!S;R!F87(*("`@("H@0'9A<B!I;G0*
M("`@("HO"B`@("!V87(@)%]S:7IE(#T@,#L*"B`@("!F=6YC=&EO;B!(5%10
M7U)E<75E<W1?1&]W;FQO861,:7-T96YE<B@I"B`@("!["B`@("`@("`@)'1H
M:7,M/DA45%!?4F5Q=65S=%],:7-T96YE<B@I.PH@("`@?0H*("`@+RHJ"B`@
M("`J($]P96YS('1H92!T87)G970@9FEL90H@("`@*B!`<&%R86T@<W1R:6YG
M(%1A<F=E="!F:6QE(&YA;64*("`@("H@0'1H<F]W<R!014%27T5R<F]R"B`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T5&%R9V5T*"1T87)G970I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]T87)G970@/2`D=&%R9V5T.PH@("`@("`@("1T:&ES
M+3Y?9G`@/2!`9F]P96XH)'1A<F=E="P@)W=B)RD["B`@("`@("`@:68@*"$D
M=&AI<RT^7V9P*2!["B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(D-A
M;FYO="!O<&5N("=[)'1A<F=E='TG(BD["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N('5P9&%T92@F)'-U8FIE8W0L("1E=F5N="P@)&1A=&$@/2!N
M=6QL*0H@("`@>PH@("`@("`@('-W:71C:"`H)&5V96YT*2!["B`@("`@("`@
M("`@(&-A<V4@)W-E;G1297%U97-T)SH@"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W1A<F=E="`](&)A<V5N86UE*"1S=6)J96-T+3Y?=7)L+3YP871H*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9V]T
M2&5A9&5R<R<Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)V-O
M;G1E;G0M9&ES<&]S:71I;VXG72D@)B8*("`@("`@("`@("`@("`@("`@("!P
M<F5G7VUA=&-H*"<O9FEL96YA;64](BA;7B)=*RDB+R<L("1D871A6R=C;VYT
M96YT+61I<W!O<VET:6]N)UTL("1M871C:&5S*2D@>PH*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T5&%R9V5T*&)A<V5N86UE*"1M871C:&5S6S%=
M*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971487)G970H)'1H:7,M/E]T87)G970I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]B87(@/28@;F5W
M($-O;G-O;&5?4')O9W)E<W-"87(H"B`@("`@("`@("`@("`@("`@("`@)RH@
M)R`N("1T:&ES+3Y?=&%R9V5T("X@)R`E9G)A8W1I;VXE($M"(%LE8F%R)5T@
M)7!E<F-E;G0E)RP@)ST^)RP@)RTG+"`*("`@("`@("`@("`@("`@("`@("`W
M.2P@*&ES<V5T*"1D871A6R=C;VYT96YT+6QE;F=T:"==*3\@<F]U;F0H)&1A
M=&%;)V-O;G1E;G0M;&5N9W1H)UT@+R`Q,#(T*3H@,3`P*0H@("`@("`@("`@
M("`@("`@*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<VEZ92`](#`["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W1I8VLG
M.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]S:7IE("L]('-T<FQE;B@D9&%T
M82D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V)A<BT^=7!D871E*')O=6YD
M*"1T:&ES+3Y?<VEZ92`O(#$P,C0I*3L*("`@("`@("`@("`@("`@(&9W<FET
M92@D=&AI<RT^7V9P+"`D9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)V=O=$)O9'DG.@H@("`@("`@("`@("`@("`@
M9F-L;W-E*"1T:&ES+3Y?9G`I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@4$5!4CHZ<F%I
M<V5%<G)O<B@B56YH86YD;&5D(&5V96YT("=[)&5V96YT?2<B*3L*("`@("`@
M("!]("\O('-W:71C:`H@("`@?0I]"@HO+R!4<GD@=7-I;F<@86YY(&]T:&5R
M('!A8VMA9V4@:68@>6]U(&QI:V4L(&)U="!C:&]O<V4@=&AE(&)I9V=E<B!O
M;F5S"B\O('1O(&)E(&%B;&4@=&\@<V5E('1H92!P<F]G<F5S<R!B87(*)'5R
M;"`]("=H='1P.B\O<&5A<BYP:'`N;F5T+V=E="](5$U,7U%U:6-K1F]R;2US
M=&%B;&4G.PH*)')E<2`])B!N97<@2%144%]297%U97-T*"1U<FPI.PH*)&1O
M=VYL;V%D(#TF(&YE=R!(5%107U)E<75E<W1?1&]W;FQO861,:7-T96YE<B@I
M.PHD<F5Q+3YA='1A8V@H)&1O=VYL;V%D*3L*)')E<2T^<V5N9%)E<75E<W0H
M9F%L<V4I.PH_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+T1"+P``````````````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,38U-C``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O1$(O9&]C+P``````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`Q
M-S,R-0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]$0B]D;V,O
M34%)3E1!24Y%4E,`````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$R
M-3``,3`U,34T,S$P-38`,#(Q,#$U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$UA:6YT86EN97)S(&9O<B!$0B!D871A8F%S
M92!B86-K96YD<R]D<FEV97)S.@H*9&)A<V4@("`Z($1A;FEE;"!#;VYV:7-S
M;W(@/&1A;FEE;&-`<&AP+FYE=#X*9F)S<6P@("`Z($1A;FEE;"!#;VYV:7-S
M;W(@/&1A;FEE;&-`<&AP+FYE=#X*("`@("`@("`@($9R86YK($TN($MR;VUA
M;FX@/&9R86YK0&MR;VUA;FXN:6YF;SX*:6)A<V4@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*:69X("`@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*;7-Q;"`@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*;7-S<6P@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*;7ES<6P@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*;7ES<6QI("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*;V-I."`@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*;V1B8R`@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*<&=S<6P@("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*<W%L:71E("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*<WEB87-E("`Z($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]$
M0B]D;V,O4U1!5%53````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3`V-#4`,3`U,34T,S$P-38`,#(P,C<V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````%-405154R!/1B!42$4@4$5!4B!$
M0B!004-+04=%"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HD260Z
M(%-405154RQV(#$N,S,@,C`P-2\P,B\R,B`Q-3HT-3HS-B!D86YI96QC($5X
M<"`D"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*1$(@1')I=F5R($9E
M871U<F4@36%T<FEX"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I3>6UB;VQS
M.@H@('@@(#T@(&EM<&QE;65N=&5D+"!B=70@=VET:&]U="!T97-T<PH@('0@
M(#T@(&EM<&QE;65N=&5D+"!B=70@;VYE(&]R(&UO<F4@=&5S=',@9F%I;`H@
M(%0@(#T@(&EM<&QE;65N=&5D+"!P87-S:6YG(&%L;"!T97-T<PH@(&4@(#T@
M(&5M=6QA=&5D+"!W:71H;W5T('1E<W1S"B`@;"`@/2`@96UU;&%T960L(&)U
M="!O;F4@;W(@;6]R92!T97-T<R!F86EL"B`@12`@/2`@96UU;&%T960L('!A
M<W-I;F<@86QL('1E<W1S"B`@;B`@/2`@<F5T=7)N<R`B;F]T(&-A<&%B;&4B
M"B`@+2`@/2`@;F\@:6UP;&5M96YT871I;VX@;V8@=&AI<R!F96%T=7)E(&]R
M('-T871U<R!U;FMN;W=N"@H@("`@("`@("`@("`@("`@("`@(&9B<W%L("`@
M("`@:69X("`@("`@;7-S<6P@("`@(&UY<W%L:2`@("`@;V1B8R`@("`@<W%L
M:71E"D9%05154D4@("`@("`@(&1B87-E("!\("!I8F%S92`@?"`@;7-Q;"`@
M('P@(&UY<W%L("!\("`@;V-I."`@?"`@<&=S<6P@('P@('-Y8F%S90IS:6UP
M;&51=65R>2`@("`@("T@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@
M("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0*;G5M0V]L<R`@("`@("`@
M("!X("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@
M("!4("`@(%0@("`@5"`@("!4"FYU;5)O=W,@("`@("`@("`@>"`@("!4("`@
M($4@("`@12`@("!4("`@(%0@("`@5"`@("!4("`@($4@("`@5"`@("!4("`@
M(%0@("`@5`IE<G)O<DYA=&EV92`@("`@(&X@("`@5"`@("!4("`@(%0@("`@
M5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!%("`@(%0*<')E
M<&%R92]E>&5C=71E("!E("`@($4@("`@5"`@("!%("`@($4@("`@12`@("!%
M("`@($4@("`@5"`@("!%("`@($4@("`@12`@("!%"G-E<75E;F-E<R`@("`@
M("`@;B`@("!4("`@(%0@("`@;B`@("!4("`@(%0@("`@5"`@("!4("`@(%0@
M("`@12`@("!4("`@($4@("`@5`IA9F9E8W1E9%)O=W,@("`@(&X@("`@5"`@
M("!%("`@($4@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@12`@
M("!4("`@(%0*9F5T8V@@;6]D97,@("`@("!X("`@(%0@("`@5"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4"F9E
M=&-H(')O=R!B>2!N;R`@>"`@("!X("`@(&X@("`@;B`@("!X("`@('@@("`@
M>"`@("!X("`@(&X@("`@>"`@("!X("`@('@@("`@>`IT<F%N<V%C=&EO;G,@
M("`@("T@("`@5"`@("!4("`@(%0@("`@;B`@("!4("`@(%0@("`@5"`@("!4
M("`@(%0@("`@5"`@("!N("`@(%0*875T;RUC;VUM:70@("`@("!N("`@(%0@
M("`@12`@("!%("`@(&X@("`@12`@("!%("`@($4@("`@12`@("!4("`@($4@
M("`@;B`@("!%"F5R<F]R(&UA<'!I;F<@("`@+2`@("!4("`@(%0@("`@5"`@
M("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5`IT
M86)L94EN9F\@("`@("`@('@@("`@5"`@("!4("`@('0@("`@5"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0*"F=E=$QI<W1/9B@I
M(%194$53"G1A8FQE<R`@("`@("`@("`@+2`@("!4("`@(%0@("`@5"`@("!4
M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5`IV:65W
M<R`@("`@("`@("`@("T@("`@5"`@("!4("`@("T@("`@+2`@("!4("`@("T@
M("`@+2`@("`M("`@(%0@("`@5"`@("`M("`@(%0*=7-E<G,@("`@("`@("`@
M("`M("`@(%0@("`@5"`@("`M("`@("T@("`@+2`@("!4("`@(%0@("`@+2`@
M("`M("`@(%0@("`@+2`@("`M"F1A=&%B87-E<R`@("`@("`@+2`@("`M("`@
M("T@("`@+2`@("!4("`@("T@("`@5"`@("!4("`@("T@("`@5"`@("!4("`@
M("T@("`@+0IF=6YC=&EO;G,@("`@("`@("T@("`@5"`@("`M("`@("T@("`@
M+2`@("`M("`@("T@("`@+2`@("`M("`@("T@("`@5"`@("`M("`@("T*<WEN
M;VYY;7,@("`@("`@("`M("`@("T@("`@+2`@("`M("`@("T@("`@+2`@("`M
M("`@("T@("`@5"`@("`M("`@("T@("`@+2`@("`M"@H*5&5S="!#;VYF;W)M
M86YC90HM+2TM+2TM+2TM+2TM+2TM"E-Y;6)O;',Z"B`@("!O("`]("!497-T
M('!A<W-E9`H@("`@6"`@/2`@5&5S="!F86EL960*("`@($P@(#T@(%-O;64@
M<&]R=&EO;G,@;V8@=&AE('1E<W0@9F%I;&5D(&1U92!T;R!L:6UI=&%T:6]N
M<R!I;B!02%`@;W(@1$)-4PH@("`@;B`@/2`@5&5S="!R971U<FYS(")N;W0@
M8V%P86)L92(*("`@("T@(#T@($YO="!T97-T960*"B`@("`@("`@("`@("`@
M("`@("`@9F)S<6P@("`@("!I9G@@("`@("!M<W-Q;"`@("`@;7ES<6QI("`@
M("!O9&)C("`@("!S<6QI=&4*("`@("`@("`@("`@("`@9&)A<V4@('P@(&EB
M87-E("!\("!M<W%L("`@?"`@;7ES<6P@('P@("!O8VDX("!\("!P9W-Q;"`@
M?"`@<WEB87-E"C`Q8V]N;F5C="`@("`@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHP
M,F9E=&-H("`@("`@("`@("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,#-S:6UP;&5Q=65R
M>2`@("`M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O"C`T;G5M8V]L<R`@("`@("`@+2`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;PHP-7-E<75E;F-E<R`@("`@("T@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*
M,#9P<F5P97AE8R`@("`@("`M("`@(&\@("`@;R`@("!O("`@($P@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`X869F96-T961R
M;W=S("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;PHP.6YU;7)O=W,@("`@("`@("T@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\*,3!E<G)O<FUA<"`@("`@("`M("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M"C$Q=')A;G-A8W1I;VYS("`@+2`@("!O("`@(&\@("`@;R`@("!N("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&X@("`@;PHQ,VQI;6ET("`@
M("`@("`@("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\*,31F971C:&UO9&5?;V)J92`M("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O"C$U<75O=&4@("`@("`@("`@+2`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;PHQ-G1A8FQE:6YF;R`@("`@("T@("`@;R`@("!O("`@($P@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,3=Q=65R>2`@
M("`@("`@("`M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O"C$X9V5T("`@("`@("`@("`@+2`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;PHQ.6=E=&QI<W1O9B`@("`@("T@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\*"@I$0DU3(%9E<G-I;VYS(%1E<W1E9`HM+2TM+2TM+2TM+2TM+2TM+2TM
M+0ID8F%S92`@(&XO80IF8G-Q;"`@(#0N,2XV"FEB87-E("`@1FER96)I<F0@
M,2XU+C$@("A02%`@-2!O;FQY*0II9G@@("`@(#<N,B!3=&%N9&%R9"!%9'1I
M=&EO;@IM<W%L("`@(#,N-B`@*%!(4"!S;F%P<VAO=',@9&%T960@,C`P-2TP
M,BTQ."D*;7-S<6P@("`X+C`N-S8P"FUY<W%L("`@-"XP+C(Q"FUY<W%L:2`@
M-"XQ+C4@("A02%`@-2!O;FQY*0IO8VDX("`@(#DN,@IO9&)C("`@($1",B!%
M4T4@."XQ(&%N9"!-4R!!8V-E<W,@,C`P,`IP9W-Q;"`@(#<N-"XQ(&%N9"`X
M+C`N,0IS<6QI=&4@(%!(4"`U.B!E>'1E;G-I;VXN("!02%`@-#H@4$5#3"!S
M;F%P<VAO="X*<WEB87-E("!!4T4@,3(N-2XS"@I497-T<R!W97)E('!E<F9O
M<FUE9"!U;F1E<B!B;W1H(&]F('1H92!F;VQL;W=I;F<@4$A0('9E<G-I;VYS
M"G5N;&5S(&]T:&5R=VES92!N;W1E9#H*("`@(#0N,RXQ,2UD978@9&%T960@
M,C`P-2TP,BTR,@H@("`@-2XQ+C`M9&5V(&1A=&5D(#(P,#4M,#(M,C(*````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O8R]415-4
M15)3````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C,P,``Q
M,#4Q-30S,3`U-@`P,C`S-S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/3T]/3T]/3T]/3T]/3T]/3T]/0I(3U<@5$\@5$53
M5"!014%2($1""CT]/3T]/3T]/3T]/3T]/3T]/3T*"B1)9#H@5$535$524RQV
M(#$N,C`@,C`P-2\P,B\Q-B`P-CHS,SHQ,B!D86YI96QC($5X<"`D"@H*24Y4
M4D]$54-424]."CT]/3T]/3T]/3T]/0H*5&AE<V4@87)E(&EN<W1R=6-T:6]N
M<R!F;W(@=&5S=&EN9R!014%2($1"(&]N(&$@5VEN9&]W<R!M86-H:6YE('5S
M:6YG(&$*0WEG=VEN($)A<V@@<VAE;&PN("!!9&IU<W0@=&AE('!A=&AS(&%N
M9"!C;VUM86YD<R!T;R!M871C:"!Y;W5R('-Y<W1E;2X*5&AI<R!C;VYF:6=U
M<F%T:6]N(&ES('5S960@8F5C875S92!T:&5S92!P<F5C:7-E('-T97!S(&%R
M92!K;F]W;B!T;R!W;W)K+@H*3D]413H@(%EO=2!M=7-T(&QO9R!O;B!A<R!A
M('5S97(@=VAI8V@@:&%S('!E<FUI<W-I;VYS('1O(&UO9&EF>2!T:&4*8V]N
M=&5N=',@;V8@>6]U<B!02%`@97AE8W5T86)L92=S(&1I<F5C=&]R>2X@(%1H
M:7,@:7,@;F5C97-S87)Y(&9O<B!B;W1H"F-O;F9I9W5R:6YG($%.1"!R=6YN
M:6YG('1H92!T97-T('-Y<W1E;2X*"@I)3E-404Q,051)3TX*/3T]/3T]/3T]
M/3T]"@I/8G1A:6X@4$A0)W,@5&5S="!&<F%M97=O<FL*+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM"DEF('EO=2!D;VXG="!H879E(%!(4"=S('1E<W0@
M9G)A;65W;W)K+"!Y;W4@;F5E9"!T;R!O8G1A:6X@:70N("!4:&5S90IS=&5P
M<R!I;F-L=61E(&-H86YG:6YG('1H92!W;W)K:6YG(&1I<F5C=&]R>2P@9&]W
M;FQO861I;F<@<G5N+71E<W1S+G!H<`IV:6$@0U93(&%N9"!C;W!Y:6YG('1H
M92!F:6QE(&EN=&\@<&QA8V4N("!#:&%N9V4@=&AE(')E=FES:6]N(&9L86<@
M:6X@=&AE"D-64R!C;VUM86YD(&%S(&%P<')O<')I871E(&9O<B!Y;W5R('!R
M97-E;G0@=F5R<VEO;B!O9B!02%`N"@H@8V0@8SHO<')O9W)A?C$O<&AP"B!C
M=G,@+60@.G!S97)V97(Z8W9S<F5A9$!C=G,N<&AP+FYE=#HO<F5P;W-I=&]R
M>2!L;V=I;B`@(",@<&%S<W=O<F0@:7,@<&AP9FD*(&-V<R`M9"`Z<'-E<G9E
M<CIC=G-R96%D0&-V<RYP:'`N;F5T.B]R97!O<VET;W)Y(&-O("UR(%!(4%\T
M7S,@7`H@("`@("UD('1E<W0@<&AP+7-R8R]R=6XM=&5S=',N<&AP"B!C<"!T
M97-T+W)U;BUT97-T<RYP:'`@+@H@<FT@+7)F('1E<W0*"@I/8G1A:6X@1$(@
M86YD(&ET<R!497-T($9R86UE=V]R:PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0HJ($E&(%!%05(@1$(@25,@04Q214%$62!)3E-404Q,140Z
M"@H@($EF('EO=2!H879E(%!%05(@1$(@:6YS=&%L;&5D(&%L<F5A9'DL(&=O
M;V0N("!4:&4@=&5S="!S=6ET90H@(&ES(&EN('!L86-E+B`@3W!E;B!U<"!A
M(&-O;6UA;F0O<VAE;&P@<')O;7!T(&%N9"!M;W9E(&EN=&\*("!T:&4@=&5S
M="!D:7)E8W1O<GDN"@H@("!C9"`\<&%T:"!T;R!P96%R(&EN<V%L;#XO=&5S
M=',O1$(O=&5S=',*"BH@5DE!($$@3D57($E.4U1!3$Q!5$E/3B!54TE.1R!4
M2$4@4$5!4B!)3E-404Q,15(Z"@H@($EN<W1A;&QI;F<@4$5!4B!H87,@9V]T
M=&5N(&9A:7)L>2!E87-Y+B`@1F]L;&]W('1H92!I;G-T<G5C=&EO;G,*("!F
M<F]M('1H92!M86YU86PZ("!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E
M;B]I;G-T86QL871I;VXN<&AP"B`@3VYC92!014%2(&%N9"!$0B!A<F4@:6YS
M=&%L;&5D+"!M;W9E('1O('1H92!T97-T(&1I<F5C=&]R>2X*"B`@(&-D('!E
M87(O=&5S=',O1$(O=&5S=',*"BH@5DE!($-64SH*"B`@0W)E871E(&$@;&]C
M871I;VX@=&\@<W1O<F4@=&AE('1E<W0@:6YS=&%L;&%T:6]N(&]F($1"(&%N
M9"!I=',*("!T97-T('-C<FEP=',N"@H@("!M:V1I<B!D.B]P96%R=&5S=`H@
M("!C9"!D.B]P96%R=&5S=`H@("!C=G,@+60@.G!S97)V97(Z8W9S<F5A9$!C
M=G,N<&AP+FYE=#HO<F5P;W-I=&]R>2!C;R`M4"!P96%R+T1""@H@(%=E(&%S
M<W5M92!Y;W4@86QR96%D>2!H879E('1H92!014%2(&)A<V4@<&%C:V%G92!I
M;G-T86QL960N("!)9@H@('EO=2!D;VXG="P@>6]U('=I;&P@;F5E9"!T;R!D
M;R!S;RP@8G5T('1H92!I;G-T<G5C=&EO;G,@9F]R"B`@9&]I;F<@=&AA="!A
M<F4@8F5Y;VYD('1H92!S8V]P92!O9B!T:&ES(&1O8W5M96YT+B`@4V5E"B`@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO:6YS=&%L;&%T:6]N+G!H
M<"!F;W(@;6]R92!I;F9O+@H*("!-;W9E('1O('1H92!T97-T(&1I<F5C=&]R
M>2X*"B`@(&-D('!E87(O1$(O=&5S=',*"@I#;W!Y('1H92!3=&%R=&5R(%-H
M96QL(%-C<FEP="!A;F0@161I="!T:&4@4&%T:',*+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"E1O(&UA:V4@<W1A
M<G1I;F<@=7`@96%C:"!T97-T(')U;B!E87-I97(L('=E(&AA=F4@:6YC;'5D
M960@='=O('-H96QL"G-C<FEP=',N("!4:&4@;W)I9VEN86P@9FEL97,@87)E
M(&YA;65D(")R=6XN8W9S(BX@(%1H97D@;F5E9"!T;R!B90IR96YA;65D('1O
M(")R=6XB('-O($-64R!W;VXG="!B;W1H97(@>6]U('=I=&@@=')A8VMI;F<@
M=&AE;2X@(%1H96XL"G1H92!P871H<R!A;F0@9FEL92!N86UE<R!I;B!T:&5M
M(&YE960@=&\@8F4@<V5T('1O('1H;W-E('5S960@8GD*>6]U<B!S>7-T96TN
M"@H@8W`@<G5N+F-V<R!R=6X*(&-H;6]D(#<U-2!R=6X*('9I(')U;@H*(&-D
M(&1R:79E<@H@8W`@<G5N+F-V<R!R=6X*(&-H;6]D(#<U-2!R=6X*('9I(')U
M;@H*"D-O<'D@=&AE(%-E='5P($9I;&4@86YD($5D:70@=&AE($133B=S"BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"E1H92!T97-T
M('-U:71E(&-O;G1A:6YS(&$@9FEL92!T:&%T('-T;W)E<R!T:&4@1%-.)W,@
M;F5E9&5D('1O"F-O;FYE8W0@=&\@>6]U<B!D871A8F%S92X@(%1H92!O<FEG
M:6YA;"!F:6QE(&ES(")S971U<"YI;F,N8W9S(@IA;F0@:70@;F5E9',@=&\@
M8F4@<F5N86UE9"`B<V5T=7`N:6YC(B!S;R!#5E,@=V]N)W0@=')A8VL@:70N
M"E1H96X@>6]U)VQL(&YE960@=&\@961I="!T:&4@1%-.)W,@:6X@:70N"@H@
M8W`@<V5T=7`N:6YC+F-V<R!S971U<"YI;F,*('9I('-E='5P+FEN8PH*"E)5
M3B!42$4@5$535%,*/3T]/3T]/3T]/3T]/0H*5&\@<G5N(&%L;"!T97-T<SH@
M("XO<G5N"E1O(')U;B!O;F4@=&5S=#H@("`N+W)U;B`\=&5S="!F:6QE(&YA
M;64^"D5X86UP;&4Z("`@("`@("`@("`N+W)U;B!D8E]P87)S961S;BYP:'!T
M"@H*5&5S="!4>7!E<R!A;F0@3&]C871I;VYS"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0IT97-T<R`@("`@("`@("`@("!#;VUM;VX@4$5!4B!$0B!T97-T
M<PIT97-T<R]D<FEV97(@("`@("!#;VUM;VX@=&5S=',@9F]R(&%L;"!T:&4@
M9')I=F5R<PH*"E)E<W5L=',@86YD(%=H870@5&\@1&\@5VET:"!4:&5M"BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"D5A8V@@=&5S="!T:&%T
M(&9A:6QS(&=E;F5R871E<R!A("YP:'`@*'=H:6-H('EO=2!C86X@97AE8W5T
M92DL(&$@+F5X<`HH=&AE(&5X<&5C=&5D(&]U='!U="DL(&$@+F]U="`H=&AE
M('1E<W0@;W5T<'5T*2!A;F0@82`N9&EF9B`H82!D:69F("UU"F9R;VT@=&AE
M("YE>'`@86YD("YO=70@9FEL97,I+@H*268@>6]U(')U;B!T:&4@=&5S=',L
M('!L96%S92!R97!O<G0@;W(@9FEL;"!T:&4@5$535"!#3TY&3U)-04Y#12!T
M86)L90II;B!T:&4@4U1!5%53(&1O8W5M96YT+B`@0F5F;W)E(&%N>2!C;VUM
M:70@=&\@0U93(&)E('-U<F4@=&\@<G5N('1H90IT97-T<R!A;F0@;F]T:&EN
M9R!G;W0@8G)O:V5N('=I=&@@=&AE(&-H86YG92X*"DEF('EO=2!G970@=&AE
M(&UE<W-A9V4@(E-+25`B+"!M96%N<R!T:&%T('1H92!T97-T(&ET)W,@;F]T
M(&5X96-U=&5D+@I,;V]K(&%T('1H92!$0B]T97-T<R]D<FEV97(O<VMI<&EF
M+FEN8R!T;R!S964@=VAA="=S('1H92!P<F]B;&5M"BAP<F]B86)L>2!A(&-O
M;FYE8W1I;VX@<')O8FQE;2DN"@H*1$(@5$535$52($U!5%))6`H]/3T]/3T]
M/3T]/3T]/3T]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F)S
M<6P@("`@:69X("`@(&US<W%L("`@;7ES<6QI("`@;V1B8R`@('-Q;&ET90I4
M15-415(@("`@("`@("`@("`@("`@("`@("`@9&)A<V4@?"!I8F%S92!\("!M
M<W%L('P@;7ES<6P@?"`@;V-I."!\('!G<W%L('P@<WEB87-E"DIO:&X@2&]R
M=&]N("`@("`@("`@("`@("`@("`@("T@("`M("`@+2`@(%@@("`M("`@+2`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T*5&EM(%II8VMU<R`@("`@("`@
M("`@("`@("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8
M("`@+2`@("T@("`M("`@+0I4:6T@4&%R:VEN("`@("`@("`@("`@("`@("`@
M("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@(%@@("`M("`@+2`@
M("T@("`M"E!A=6P@1V%R9&EN97(@("`@("`@("`@("`@("`@("T@("`M("`@
M+2`@(%@@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T*<&5T
M97)W8D!I869R:6-A+F-O;2`@("`@("`@("`@+2`@("T@("`M("`@6"`@("T@
M("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+0I$86YI96PL($%D86T@
M("`@("`@("`@("`@("`@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@
M+2`@(%@@("`M("`@+2`@("T@("`M"G-Z:6E`<WII:7-O9G0N8V]M("`@("`@
M("`@("`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@(%BY
M("`M("`@+2`@("T*:FUH,T!L:6YU>&9R96%K+F-O;2`@("`@("`@("`@+2`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@(%@@("`M("`@
M+0I+979I;B!(96YR:6MS;VX@("`@("`@("`@("`@("`M("`@+2`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@(%@@("`M("`@+2`@("T@("`M"E-T:6<@0F%K
M:V5N("`@("`@("`@("`@("`@("`@("T@("`M("`@+2`@("T@("`M("`@+2`@
M(%@@("`M("`@+2`@("T@("!8("`@+2`@("T*0VAU8VL@2&%G96YB=6-H("`@
M("`@("`@("`@("`@+2`@("T@("`M("`@+2`@("T@("!8("`@+2`@("T@("`M
M("`@+2`@("T@("`M("`@+0I,=61O=FEC;R!-86=N;V-A=F%L;&\@("`@("`@
M("`M("`@+2`@(%@@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@
M("T@("`M"D1A;FEE;"!#;VYV:7-S;W(@("`@("`@("`@("`@(%@@("!8("`@
M6"`@("T@("!8("`@6"`@(%@@("!8("`@6"`@(%BR("!8("`@6"`@(%@*"DU)
M4U-)3D<@5$535$524R`@("`@("`@("`@("`@("T@("`M("`@+2`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T*"D-O;6UE;G1S.@H*
M6S%=.B!/1$)#('5S:6YG($E"32!$0C(*6S)=.B!/1$)#('5S:6YG($E"32!$
M0C(@86YD($U3($%C8V5S<PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+T1"+V1O8R])1$5!4P``````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-C4S-P`Q,#4Q-30S,3`U-@`P,C`Q,#4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````06)S=')A
M8W1E9"!4>7!E<R`H4W1I9RD*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"D1"
M(&YE961S(&$@<V5T(&]F('1Y<&5S(')E<')E<V5N=&EN9R!T:&4@;6]S="!C
M;VUM;VYL>2!U<V5D('1Y<&5S(&EN"F%L;"!B86-K96YD<RX@(%1H:7,@='EP
M92!S970@8V]U;&0@86QS;R!B92!G96%R960@=&]W87)D<R!I;G1E9W)A=&EO
M;@IW:71H('1H:6YG<R!L:6ME(%A-3"U24$,O4T]!4"!I;7!L96UE;G1A=&EO
M;G,L($A434P@9F]R;2!C;&%S<V5S+"!E=&,N"@I296%L(%%U97)Y(%!A<G-E
M<B`H4W1I9RD*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I7:71H(&$@<F5A
M;"!Q=65R>2!P87)S97(L($1"(&-A;B!I;7!L96UE;G0@;6]R92!O9B!I=',@
M<&]R=&%B:6QI='D*8F%S960@;VX@=&AE('%U97)Y+"!I;G-T96%D(&]F(&AA
M=FEN9R!S=7!P;W)T(&9U;F-T:6]N<R!F;W(*979E<GET:&EN9RX@($]N92!E
M>&%M<&QE('=O=6QD(&)E($Q)34E4+"!A;F]T:&5R("))3E-%4E0*+BXN(%)%
M5%523DE.1R(N"@I0;W)T86)L92!T<F%N<V%C=&EO;G,@*%-T:6<I"BTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"DEF($1"(&-A;B!P87)S92!Q=65R
M:65S(&5N;W5G:"!T;R!D971E<FUI;F4@=VAA="!T86)L97,@87)E(&%F9F5C
M=&5D"F)Y('%U97)I97,L(&ET('-H;W5L9"!B92!P;W-S:6)L92!T;R!M86ME
M(&$@<F5P;&%Y86)L92!T<F%N<V%C=&EO;@IL;V<N("!'3D]-12!U<V5S(&%N
M(%A-3"!F;W)M870@9F]R(&-O;F9I9W5R871I;VX@9&%T82!T:&%T(&QE=',@
M>6]U"F-H96-K<&]I;G0@<W1A=&4@;VYC92!I;B!A('=H:6QE+"!A;F0@<F5V
M97)T('1O('1H870@<W1A=&4@;&%T97(N"E=I=&@@82!S:6UI;&%R(&%P<')O
M86-H(&9O<B!T<F%N<V%C=&EO;G,@:6X@1$(@=V4@8V%N(&EM<&QE;65N=`IP
M;W)T86)L92!T<F%N<V%C=&EO;G,@86YD(&-H96-K<&]I;G1I;F<@979E;B!F
M;W(@=&AE(&1A=&%B87-E<R!T:&%T"F1O;B=T('-U<'!O<G0@=&AE;2X*"@I%
M<G)O<B!R97!O<G1I;F<@8VQE86XM=7`O9&5B=6<@*%1O;6%S*0HM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"DYO=R!E86-H(&1R:79E
M<B!H87,@:71S(&]W;B!R86ES945R<F]R(&UE=&AO9"P@8V]M;6]N(&AA<R!A
M(')A:7-E17)R;W(@86YD"D1"(&AA<R!A($1"7V5R<F]R(&-L87-S(&%N9"!I
M=',@;W=N(&ES17)R;W(H*2!M971H;V0N(%1H:7,@97)R;W(@<W1U9F8@"F]V
M97)H96%D(&-O=6QD(&)E('-I;7!L:69I960@=VET:"!O;FQY(&]N92!R86ES
M945R<F]R+"!D<F]P:6YG('1H92!$0B!%<G)O<@IC;&%S<R!A;F0@86QS;R!T
M:&4@1$(Z.FES17)R;W(H*2`H=7-E('1H92!014%2+G!H<"!O;F5S(&EN<W1E
M860I+@I/=&AE<B!I9&5A(&-O=6QD(&)E('1O(&%D9"!A('-Y<W1E;2!F;W(@
M86QL;W=I;F<@<&5O<&QE(&%C8V5S<R!T;R!A;&P@=&AE"G%U97)I97,@<V5N
M9&5D(&)Y(%!%05(@1$(@=&\@=&AE(&)A8VME;F0N($%L<V\@82!N97<@4$5!
M4E]%4E)/4E]$14)51PIF;&%G('1H870@875T;VUA=&EC86QL>2`H<VAO=WQT
M<FEG9V5R<RD@9&5B=6<@:6YF;RP@<&5R:&%P<PIW:71H(&$@;F5W(%!%05)?
M*%=A<FYI;F=\1&5B=6<I(&]B:F5C="X*"E%U;W1E(&-L96%N+75P("A3=&EG
M*0HM+2TM+2TM+2TM+2TM+2TM+2TM+2T*,2X@2V5E<"!Q=6]T92!A;F0@<75O
M=&53=')I;F<L(&)U="!M;W9E('%U;W1I;F<@;V8@<W1R:6YG<R!B86-K(&EN
M=&\*("`@<75O=&53=')I;F<@86YD(&UA:V4@<75O=&4@8V%L;"!I="!F;W(@
M<W1R:6YG<RX*"C(N($%D9"!A;B!O<'1I;VYA;"`B;W!E<F%T;W(B('!A<F%M
M971E<B!T;R!Q=6]T92!T:&%T(&ES(&]N92!O9B`B/2(L"B`@("(\(BP@(CXB
M(&]R("(\/B(@=&AA="!W:6QL(&)E(&EN<V5R=&5D(&EN(&9R;VYT(&]F('1H
M92!Q=6]T960@=F%L=64*("`@=6YL97-S(&ET(&ES($Y53$PL(&EN('=H:6-H
M(&-A<V4@:70@=VEL;"!B92!C;VYV97)T960@=&\@(DE3(B`H9F]R"B`@("(]
M(BD@;W(@(DE3($Y/5"(@*&9O<B!T:&4@;W1H97)S*2X*"D%U=&\@9G)E92!S
M=&%T96UE;G1S("A4;VUA<RD*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0I">2!S971T:6YG(&$@<&%R86T@:6X@<75E<GDH*2!O<B!F;W(@=&AE(&AO
M;&4@1$(@:6YS=&%N8V4L(%!%05(@1$(*8V]U;&0@875T;RUF<F5E(')E<W5L
M=',@:6X@1$)?<F5S=6QT+3YF971C:"A);G1O?%)O=RD@=VAE;B!T:&4@9')I
M=F5R"G)E='5R;G,@9F%L<V4N"@I$871A='EP97,@:6X@<')E<&%R92!S>6YT
M87@@*%1O;6%S*0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0I%>'1E;F0@=&AE(&%C='5A;"!P<F5P87)E+V5X96-U=&4@<&QA8V5H;VQD
M97)S('1O('-U<'!O<G0@9&%T82!T>7!E<RP@8F]T:`IT;R!C:&5C:R!T:&4@
M9&%T82!I;G1R;V1U8V5D('1O('1H92!Q=65R>2!A;F0@=&\@(F-A<W0B('1H
M92!R97-U;'0*=&\@;F%T:79E('!H<"!D871A('1Y<&5S+B!%>#H*"B1S<6P@
M/2`B24Y315)4($E.5$\@=&%B;&4@5D%,5453("A[>VEN="@T*7U]+"![>V)O
M;VQ]?2P@>WMD871E*"=9+6TM9"<I?7TI(CL*)')O=R`]("1D8BT^<75E<GDH
M)'-Q;"P@87)R87DH."P@)W0G+"`G,C`P,2TP-"TQ)RDI.PH*1F]R;6%T.B![
M>SQD871A7W1Y<&4^*#QP87)A;3$^+#QP87)A;3(^*7U]"@HB<&%R86TB(&-O
M=6QD(&)E('1H92!M87@@;&5N9VAT(&]F('1H92!D871A+"!D871E(&9O<FUA
M=',L(&YO=%]N=6QL"F-H96-K<R!O<B!D969A=6QT('9A;'5E<RX*"D]T:&5R
M(&ED96%S(&-O=6QD(&)E.@H*,2D*)'-Q;"`]("))3E-%4E0@24Y43R!T86)L
M92!604Q515,@*#\L(#\L(#\I(CL*)'-T:"`]("1D8BT^<')E<&%R92@D<W%L
M+"!A<G)A>2@G:6YT*#0I)RP@)V)O;VPG+"`G9&%T92<I.PHD<F5S(#T@)&1B
M+3YE>&5C=71E*"1S=&@L(&%R<F%Y*"1A+"`D8BP@)&,I.PH*,BD*)'-Q;"`]
M("))3E-%4E0@24Y43R!T86)L92!604Q515,@*#\L(#\L(#\I(CL*)'!A<F%M
M<R`](&%R<F%Y*`H),"`]/B!A<G)A>2@D82P@)VEN="@T*2<I+`H),2`]/B!A
M<G)A>2@D8BP@)V)O;VPG*0HI.PHD<F5S(#T@)&1B+3YQ=65R>2@D<W%L+"`D
M<&%R86US*3L*"D%U=&\@8V]N;F5C="!F96%T=7)E("A4;VUA<RD*+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I!9&0@=&AE(&%B:6QI='D@=&\@8W)E
M871E(&9O<B!E>&%M<&QE(&$@;&EG:'0@86YD(&1U;7`@1$(@;V)J96-T('=H
M:6-H"G=I;&P@;VYL>2!S970@=7`@=&AE(&-O;FYE8W1I;VX@=VAE;B!N965D
M960N(%=I=&@@=&AA="!P96]P;&4@8V]U;&0*8W)E871E('1H92!$0B!O8FIE
M8W0@:6X@82!C;VUM;VX@<')E<&5N9"!O<B!D969A=6QT(&9I;&4@=VET:&]U
M="!T:&4*;F5E9"!T;R!W87-T92!S>7-T96T@<F5S;W5R8V5S(&EF('1H92!U
M<V4@;V8@=&AE(&1A=&%B87-E(&ES(&9I;F%L;'D*;F]T(&YE961E9"X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R].971?4TU44"\`````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$W-C8T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]33510+V1O8W,O
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`U-@`P,C`V,30`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O3F5T7U--5%`O9&]C<R]E>&%M<&QE<R\`````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,C0S,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R].971?4TU44"]D;V-S+V5X86UP;&5S+V)A
M<VEC+G!H<```````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W-C4`,3`U,34T,S$P-38`,#(T
M,C,R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E("=.970O4TU44"YP:'`G.PH*)&AO<W0@/2`G;6%I
M;"YE>&%M<&QE+F-O;2<["B1F<F]M(#T@)W5S97)`97AA;7!L92YC;VTG.PHD
M<F-P="`](&%R<F%Y*"=R96-I<&EE;G0Q0&5X86UP;&4N8V]M)RP@)W)E8VEP
M:65N=#)`97AA;7!L92YC;VTG*3L*)'-U8FH@/2`B4W5B:F5C=#H@5&5S="!-
M97-S86=E7&XB.PHD8F]D>2`](")";V1Y($QI;F4@,5QN0F]D>2!,:6YE(#(B
M.PH*+RH@0W)E871E(&$@;F5W($YE=%]33510(&]B:F5C="X@*B\*:68@*"$@
M*"1S;71P(#T@;F5W($YE=%]33510*"1H;W-T*2DI('L*("`@(&1I92@B56YA
M8FQE('1O(&EN<W1A;G1I871E($YE=%]33510(&]B:F5C=%QN(BD["GT*"B\J
M($-O;FYE8W0@=&\@=&AE(%--5%`@<V5R=F5R+B`J+PII9B`H4$5!4CHZ:7-%
M<G)O<B@D92`]("1S;71P+3YC;VYN96-T*"DI*2!["B`@("!D:64H)&4M/F=E
M=$UE<W-A9V4H*2`N(")<;B(I.PI]"@HO*B!396YD('1H92`G34%)3"!&4D]-
M.B<@4TU44"!C;VUM86YD+B`J+PII9B`H4$5!4CHZ:7-%<G)O<B@D<VUT<"T^
M;6%I;$9R;VTH)&9R;VTI*2D@>PH@("`@9&EE*")5;F%B;&4@=&\@<V5T('-E
M;F1E<B!T;R`\)&9R;VT^7&XB*3L*?0H*+RH@061D<F5S<R!T:&4@;65S<V%G
M92!T;R!E86-H(&]F('1H92!R96-I<&EE;G1S+B`J+PIF;W)E86-H("@D<F-P
M="!A<R`D=&\I('L*("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D<VUT
M<"T^<F-P=%1O*"1T;RDI*2!["B`@("`@("`@9&EE*")5;F%B;&4@=&\@861D
M(')E8VEP:65N="`\)'1O/CH@(B`N("1R97,M/F=E=$UE<W-A9V4H*2`N(")<
M;B(I.PH@("`@?0I]"@HO*B!3970@=&AE(&)O9'D@;V8@=&AE(&UE<W-A9V4N
M("HO"FEF("A014%2.CII<T5R<F]R*"1S;71P+3YD871A*"1S=6)J("X@(EQR
M7&XB("X@)&)O9'DI*2D@>PH@("`@9&EE*")5;F%B;&4@=&\@<V5N9"!D871A
M7&XB*3L*?0H*+RH@1&ES8V]N;F5C="!F<F]M('1H92!33510('-E<G9E<BX@
M*B\*)'-M='`M/F1I<V-O;FYE8W0H*3L*```````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?4TU44"]D;V-S+V=U:61E
M+G1X=```````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30S-#(`,3`U,34T,S$P
M-38`,#(R-#4S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*(%1H92!.971?4TU44"!0
M86-K86=E"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM"B!5<V5R($1O8W5M96YT871I;VX*+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*"CI!=71H;W(Z("`@($IO;B!087)I<V4*.D-O;G1A8W0Z("`@:F]N0'!H
M<"YN970*.D1A=&4Z("`@("`@)$1A=&4Z(#(P,#4O,#,O,#0@,#,Z,S4Z-#4@
M)`HZ4F5V:7-I;VXZ("`D4F5V:7-I;VXZ(#$N-2`D"@HN+B!C;VYT96YT<SHZ
M(%1A8FQE(&]F($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*"D1E
M<&5N9&5N8VEE<PH]/3T]/3T]/3T]/3T*"E1H92!@4$5!4E]%<G)O<F`@0VQA
M<W,*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&AE($YE=%]33510('!A8VMA
M9V4@=7-E<R!T:&4@8%!%05)?17)R;W)@7R!C;&%S<R!F;W(@86QL(&]F(&ET
M<R!@97)R;W(*:&%N9&QI;F=@7RX*"E1H92!@3F5T7U-O8VME=&`@4&%C:V%G
M90HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"E1H92!.971?4V]C:V5T7R!P
M86-K86=E(&ES('5S960@87,@=&AE(&)A<VES(&9O<B!A;&P@;F5T=V]R:R!C
M;VUM=6YI8V%T:6]N<RX*"E1H92!@075T:%]305-,8"!086-K86=E"BTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&4@8$%U=&A?4T%33&!?('!A8VMA9V4@
M:7,@86X@;W!T:6]N86P@9&5P96YD96YC>2X@($EF(&ET(&ES(&%V86EL86)L
M92P@=&AE"DYE=%]33510('!A8VMA9V4@=VEL;"!B92!A8FQE('1O('-U<'!O
M<G0@=&AE($1)1T535"U-1#5?(&%N9"!#4D%-+4U$-5\@4TU44`IA=71H96YT
M:6-A=&EO;B!M971H;V1S+B`@3W1H97)W:7-E+"!O;FQY('1H92!,3T=)3E\@
M86YD(%!,04E.7R!M971H;V1S('=I;&P*8F4@879A:6QA8FQE+@H*17)R;W(@
M2&%N9&QI;F<*/3T]/3T]/3T]/3T]/3T*"D%L;"!O9B!T:&4@3F5T7U--5%`@
M8VQA<W,G<R!P=6)L:6,@;65T:&]D<R!R971U<FX@82!014%27T5R<F]R7R!O
M8FIE8W0@:68@86X*97)R;W(@;V-C=7)S+B`@5&AE('-T86YD87)D('=A>2!T
M;R!C:&5C:R!F;W(@82!014%27T5R<F]R(&]B:F5C="!I<R!B>2!U<VEN9PI@
M4$5!4CHZ:7-%<G)O<B@I8%\Z.@H*("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G)O<B`]("1S;71P+3YC;VYN96-T*"DI*2!["B`@("`@("`@9&EE*"1E<G)O
M<BT^9V5T365S<V%G92@I*3L*("`@('T*"BXN(%]014%2.CII<T5R<F]R*"DZ
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<&5A<BYP96%R
M+FES97)R;W(N<&AP"@I33510($%U=&AE;G1I8V%T:6]N"CT]/3T]/3T]/3T]
M/3T]/3T]/3T*"E1H92!.971?4TU44"!P86-K86=E('-U<'!O<G1S('1H92!3
M3510(&%U=&AE;G1I8V%T:6]N('-T86YD87)D("AA<R!D969I;F5D"F)Y(%)&
M0RTR-34T7RDN("!4:&4@3F5T7U--5%`@<&%C:V%G92!S=7!P;W)T<R!T:&4@
M9F]L;&]W:6YG(&%U=&AE;G1I8V%T:6]N"FUE=&AO9',L(&EN(&]R9&5R(&]F
M('!R969E<F5N8V4Z"@HN+B!?4D9#+3(U-30Z(&AT='`Z+R]W=W<N:65T9BYO
M<F<O<F9C+W)F8S(U-30N='AT"@I$24=%4U0M340U"BTM+2TM+2TM+2T*"E1H
M92!$24=%4U0M340U(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!U<V5S(&!24T$@
M1&%T82!396-U<FET>2!);F,N8%\G<R!-1#4*365S<V%G92!$:6=E<W0@86QG
M;W)I=&AM+B`@270@:7,@8V]N<VED97)E9"!T:&4@;6]S="!S96-U<F4@;65T
M:&]D(&]F(%--5%`*875T:&5N=&EC871I;VXN"@HJ*DYO=&4Z*BH@5&AE($1)
M1T535"U-1#4@875T:&5N=&EC871I;VX@;65T:&]D(&ES(&]N;'D@<W5P<&]R
M=&5D(&EF('1H90I!551(7U-!4TQ?('!A8VMA9V4@:7,@879A:6QA8FQE+@H*
M+BX@7U)302!$871A(%-E8W5R:71Y($EN8RXZ(&AT='`Z+R]W=W<N<G-A<V5C
M=7)I='DN8V]M+PH*0U)!32U-1#4*+2TM+2TM+2T*"E1H92!#4D%-+4U$-2!A
M=71H96YT:6-A=&EO;B!M971H;V0@:&%S(&)E96X@<W5P97)S961E9"!B>2!T
M:&4@1$E'15-4+4U$-5\*;65T:&]D(&EN('1E<FUS(&]F('-E8W5R:71Y+B`@
M270@:7,@<')O=FED960@:&5R92!F;W(@8V]M<&%T:6)I;&ET>2!W:71H"F]L
M9&5R(%--5%`@<V5R=F5R<R!T:&%T(&UA>2!N;W0@<W5P<&]R="!T:&4@;F5W
M97(@1$E'15-4+4U$-2!A;&=O<FET:&TN"@HJ*DYO=&4Z*BH@5&AE($-204TM
M340U(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!I<R!O;FQY('-U<'!O<G1E9"!I
M9B!T:&4*05542%]305-,7R!P86-K86=E(&ES(&%V86EL86)L92X*"DQ/1TE.
M"BTM+2TM"@I4:&4@3$]'24X@875T:&5N=&EC871I;VX@;65T:&]D(&5N8W)Y
M<'1S('1H92!U<V5R)W,@<&%S<W=O<F0@=7-I;F<@=&AE"D)A<V4V-%\@96YC
M;V1I;F<@<V-H96UE+B`@0F5C875S92!D96-R>7!T:6YG(&$@0F%S938T+65N
M8V]D960@<W1R:6YG(&ES"G1R:79I86PL($Q/1TE.(&ES(&YO="!C;VYS:61E
M<F5D(&$@<V5C=7)E(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!A;F0@<VAO=6QD
M"F)E(&%V;VED960N"@HN+B!?0F%S938T.B!H='1P.B\O=W=W+G!H<"YN970O
M;6%N=6%L+V5N+V9U;F-T:6]N+F)A<V4V-"UE;F-O9&4N<&AP"@I03$%)3@HM
M+2TM+0H*5&AE(%!,04E.(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!S96YD<R!T
M:&4@=7-E<B=S('!A<W-W;W)D(&EN('!L86EN('1E>'0N"E1H:7,@;65T:&]D
M(&]F(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!S96-U<F4@86YD('-H;W5L9"!B
M92!A=F]I9&5D+@H*4V5C=7)E($-O;FYE8W1I;VYS"CT]/3T]/3T]/3T]/3T]
M/3T]/0H*268@8'-E8W5R92!S;V-K970@=')A;G-P;W)T<V!?(&AA=F4@8F5E
M;B!E;F%B;&5D(&EN(%!(4"P@:70@:7,@<&]S<VEB;&4@=&\*97-T86)L:7-H
M(&$@<V5C=7)E(&-O;FYE8W1I;VX@=&\@=&AE(')E;6]T92!33510('-E<G9E
M<CHZ"@H@("`@)'-M='`@/2!N97<@3F5T7U--5%`H)W-S;#HO+VUA:6PN97AA
M;7!L92YC;VTG+"`T-C4I.PH*5&AI<R!E>&%M<&QE(&-O;FYE8W1S('1O(&!M
M86EL+F5X86UP;&4N8V]M8"!O;B!P;W)T(#0V-2`H82!C;VUM;VX@4TU44%,*
M<&]R="D@=7-I;F<@=&AE(&!S<VPZ+R]@('1R86YS<&]R="X*"BXN(%]S96-U
M<F4@<V]C:V5T('1R86YS<&]R=',Z(&AT='`Z+R]W=W<N<&AP+FYE="]T<F%N
M<W!O<G1S"@I$871A(%%U;W1I;F<*/3T]/3T]/3T]/3T]"@I">2!D969A=6QT
M+"!A;&P@;W5T8F]U;F0@<W1R:6YG(&1A=&$@:7,@<75O=&5D(&EN(&%C8V]R
M9&%N8V4@=VET:"!33510"G-T86YD87)D<RX@(%1H:7,@;65A;G,@=&AA="!A
M;&P@;F%T:79E(%5N:7@@*&!<7&Y@*2!A;F0@36%C("A@7%QR8"D@;&EN90IE
M;F1I;F=S(&%R92!C;VYV97)T960@=&\@26YT97)N970M<W1A;F1A<F0@0U),
M1B`H8%Q<<EQ<;F`I(&QI;F4@96YD:6YG<RX*06QS;RP@8F5C875S92!T:&4@
M4TU44"!P<F]T;V-O;"!U<V5S(&$@<VEN9VQE(&QE861I;F<@<&5R:6]D("A@
M+F`I('1O('-I9VYA;`IA;B!E;F0@=&\@=&AE(&UE<W-A9V4@9&%T82P@<VEN
M9VQE(&QE861I;F<@<&5R:6]D<R!I;B!T:&4@;W)I9VEN86P@9&%T80IS=')I
M;F<@87)E(")D;W5B;&5D(B`H92YG+B`B8"XN8"(I+@H*5&AE<V4@<W1R:6YG
M('1R86YS9F]R;6%T:6]N(&-A;B!B92!E>'!E;G-I=F4@=VAE;B!L87)G92!B
M;&]C:W,@;V8@9&%T82!A<F4*:6YV;VQV960N("!&;W(@97AA;7!L92P@=&AE
M($YE=%]33510('!A8VMA9V4@:7,@;F]T(&%W87)E(&]F($U)344@<&%R=',@
M*&ET"FIU<W0@<V5E<R!T:&4@34E-12!M97-S86=E(&%S(&]N92!B:6<@<W1R
M:6YG(&]F(&-H87)A8W1E<G,I+"!S;R!I="!I<R!N;W0*86)L92!T;R!S:VEP
M(&YO;BUT97AT(&%T=&%C:&UE;G1S('=H96X@<V5A<F-H:6YG(&9O<B!C:&%R
M86-T97)S('1H870@;6%Y"FYE960@=&\@8F4@<75O=&5D+@H*0F5C875S92!O
M9B!T:&ES+"!I="!I<R!P;W-S:6)L92!T;R!E>'1E;F0@=&AE($YE=%]33510
M(&-L87-S(&EN(&]R9&5R('1O"FEM<&QE;65N="!Y;W5R(&]W;B!C=7-T;VT@
M<75O=&EN9R!R;W5T:6YE+B`@2G5S="!C<F5A=&4@82!N97<@8VQA<W,@8F%S
M960@;VX*=&AE($YE=%]33510(&-L87-S(&%N9"!R96EM<&QE;65N="!T:&4@
M8'%U;W1E9&%T82@I8"!M971H;V0Z.@H*("`@(')E<75I<F4@)TYE=%]33510
M+G!H<"<["@H@("`@8VQA<W,@3F5T7U--5%!?8W5S=&]M(&5X=&5N9',@3F5T
M7U--5%`*("`@('L*("`@("`@("!F=6YC=&EO;B!Q=6]T961A=&$H)&1A=&$I
M"B`@("`@("`@>PH@("`@("`@("`@("`O*B!097)F;W)M(&-U<W1O;2!D871A
M('%U;W1I;F<@*B\*("`@("`@("!]"B`@("!]"@I.;W1E('1H870@=&AE(&`D
M9&%T86`@<&%R86UE=&5R('=I;&P@8F4@<&%S<V5D('1O('1H92!@<75O=&5D
M871A*"E@(&9U;F-T:6]N"F!B>2!R969E<F5N8V5@7RX@(%1H:7,@;65A;G,@
M=&AA="!Y;W4@8V%N(&]P97)A=&4@9&ER96-T;'D@;VX@8"1D871A8"X@($ET
M"F%L<V\@=&AE(&]V97)H96%D(&]F(&-O<'EI;F<@82!L87)G92!@)&1A=&%@
M('-T<FEN9R!T;R!A;F0@9G)O;2!T:&4*8'%U;W1E9&%T82@I8"!M971H;V0N
M"@HN+B!?8GD@<F5F97)E;F-E.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L
M+V5N+VQA;F=U86=E+G)E9F5R96YC97,N<&%S<RYP:'`*"D1E8G5G9VEN9PH]
M/3T]/3T]/3T*"E1H92!.971?4TU44"!P86-K86=E(&-O;G1A:6YS(&)U:6QT
M+6EN(&1E8G5G9VEN9R!O=71P=70@<F]U=&EN97,@*&1I<V%B;&5D"F)Y(&1E
M9F%U;'0I+B`@1&5B=6=G:6YG(&]U='!U="!M=7-T(&)E(&5X<&QI8VET;'D@
M96YA8FQE9"!V:6$@=&AE('-E=$1E8G5G*"D*;65T:&]D.CH*"B`@("`D<VUT
M<"T^<V5T1&5B=6<H=')U92D["@I4:&4@9&5B=6=G:6YG(&UE<W-A9V5S('=I
M;&P@8F4@<V5N="!T;R!T:&4@<W1A;F1A<F0@;W5T<'5T('-T<F5A;2X*"D5X
M86UP;&5S"CT]/3T]/3T]"@I"87-I8R!5<V4*+2TM+2TM+2TM"@I4:&4@9F]L
M;&]W:6YG('-C<FEP="!D96UO;G-T<F%T97,@:&]W(&$@<VEM<&QE(&5M86EL
M(&UE<W-A9V4@8V%N(&)E('-E;G0*=7-I;F<@=&AE($YE=%]33510('!A8VMA
M9V4Z.@H*("`@(')E<75I<F4@)TYE="]33510+G!H<"<["@H@("`@)&AO<W0@
M/2`G;6%I;"YE>&%M<&QE+F-O;2<["B`@("`D9G)O;2`]("=U<V5R0&5X86UP
M;&4N8V]M)SL*("`@("1R8W!T(#T@87)R87DH)W)E8VEP:65N=#%`97AA;7!L
M92YC;VTG+"`G<F5C:7!I96YT,D!E>&%M<&QE+F-O;2<I.PH@("`@)'-U8FH@
M/2`B4W5B:F5C=#H@5&5S="!-97-S86=E7&XB.PH@("`@)&)O9'D@/2`B0F]D
M>2!,:6YE(#%<;D)O9'D@3&EN92`R(CL*"B`@("`O*B!#<F5A=&4@82!N97<@
M3F5T7U--5%`@;V)J96-T+B`J+PH@("`@:68@*"$@*"1S;71P(#T@;F5W($YE
M=%]33510*"1H;W-T*2DI('L*("`@("`@("!D:64H(E5N86)L92!T;R!I;G-T
M86YT:6%T92!.971?4TU44"!O8FIE8W1<;B(I.PH@("`@?0H*("`@("\J($-O
M;FYE8W0@=&\@=&AE(%--5%`@<V5R=F5R+B`J+PH@("`@:68@*%!%05(Z.FES
M17)R;W(H)&4@/2`D<VUT<"T^8V]N;F5C="@I*2D@>PH@("`@("`@(&1I92@D
M92T^9V5T365S<V%G92@I("X@(EQN(BD["B`@("!]"@H@("`@+RH@4V5N9"!T
M:&4@)TU!24P@1E)/33HG(%--5%`@8V]M;6%N9"X@*B\*("`@(&EF("A014%2
M.CII<T5R<F]R*"1S;71P+3YM86EL1G)O;2@D9G)O;2DI*2!["B`@("`@("`@
M9&EE*")5;F%B;&4@=&\@<V5T('-E;F1E<B!T;R`\)&9R;VT^7&XB*3L*("`@
M('T*"B`@("`O*B!!9&1R97-S('1H92!M97-S86=E('1O(&5A8V@@;V8@=&AE
M(')E8VEP:65N=',N("HO"B`@("!F;W)E86-H("@D<F-P="!A<R`D=&\I('L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'-M='`M/G)C<'14
M;R@D=&\I*2D@>PH@("`@("`@("`@("!D:64H(E5N86)L92!T;R!A9&0@<F5C
M:7!I96YT(#PD=&\^.B`B("X@)')E<RT^9V5T365S<V%G92@I("X@(EQN(BD[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J(%-E="!T:&4@8F]D>2!O9B!T:&4@
M;65S<V%G92X@*B\*("`@(&EF("A014%2.CII<T5R<F]R*"1S;71P+3YD871A
M*"1S=6)J("X@(EQR7&XB("X@)&)O9'DI*2D@>PH@("`@("`@(&1I92@B56YA
M8FQE('1O('-E;F0@9&%T85QN(BD["B`@("!]"@H@("`@+RH@1&ES8V]N;F5C
M="!F<F]M('1H92!33510('-E<G9E<BX@*B\*("`@("1S;71P+3YD:7-C;VYN
M96-T*"D["@HN+B!?4$5!4E]%<G)O<CH@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO8V]R92YP96%R+G!E87(M97)R;W(N<&AP"BXN(%].971?4V]C
M:V5T.B!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O3F5T7U-O8VME=`HN
M+B!?075T:%]305-,.B!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O075T
M:%]305-,"@HN+B!V:6TZ('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-"!E>'!A;F1T86(@=&5X='=I9'1H/3<V.@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A
M<G-E<B\`````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#4V`#`R,#(T-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+P``````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#(R,#8U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S97(O97AA;7!L
M97,O>&UL7W!A<G-E<E]F:6QE+G!H<```````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S,@`Q,#4Q-30S
M,3`U-@`P,C4W-#,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]02%`*+RHJ"B`J(&5X86UP;&4@9F]R(%A-3%]087)S97)?
M4VEM<&QE"B`J"B`J($!A=71H;W(@("`@("!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"UT;V]L<RYN970^"B`J($!P86-K86=E("`@("!834Q?4&%R<V5R
M"B`J($!S=6)P86-K86=E("!%>&%M<&QE<PH@*B\*"B\J*@H@*B!R97%U:7)E
M('1H92!P87)S97(*("HO"G)E<75I<F5?;VYC92`G6$U,+U!A<G-E<BYP:'`G
M.PH*8VQA<W,@;7E087)S97(@97AT96YD<R!834Q?4&%R<V5R"GL*"B`@("!F
M=6YC=&EO;B!M>5!A<G-E<B@I"B`@("!["B`@("`@("`@<&%R96YT.CI834Q?
M4&%R<V5R*"D["B`@("!]"@H@("`O*BH*("`@("H@:&%N9&QE('-T87)T(&5L
M96UE;G0*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A
M<F%M("`@(')E<V]U<F-E("`@('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@
M("H@0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T=')I8G5T97,*("`@("HO"B`@
M("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H)'AP+"`D;F%M92P@)&%T=')I8G,I
M"B`@("!["B`@("`@("`@<')I;G1F*"=H86YD;&4@<W1A<G0@=&%G.B`E<SQB
M<B`O/B<L("1N86UE*3L*("`@('T*"B`@("\J*@H@("`@*B!H86YD;&4@<W1A
M<G0@96QE;65N=`H@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@
M*B!`<&%R86T@("`@<F5S;W5R8V4@("`@>&UL('!A<G-E<B!R97-O=7)C90H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@;F%M92!O9B!T:&4@96QE;65N
M=`H@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@871T<FEB=71E<PH@("`@
M*B\*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H)'AP+"`D;F%M92D*("`@('L*
M("`@("`@("!P<FEN=&8H)VAA;F1L92!E;F0@=&%G.B`E<SQB<B`O/B<L("1N
M86UE*3L*("`@('T*?0H*)'`@/2`F;F5W(&UY4&%R<V5R*"D["@HD<F5S=6QT
M(#T@)'`M/G-E=$EN<'5T1FEL92@G>&UL7W!A<G-E<E]F:6QE+GAM;"<I.PHD
M<F5S=6QT(#T@)'`M/G!A<G-E*"D["C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7VAA;F1L97(N
M<&AP`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q-S<V`#$P-3$U-#,Q,#4V`#`R-C0U-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/U!(4`HO*BH*("H@
M97AA;7!L92!F;W(@6$U,7U!A<G-E<E]3:6UP;&4*("H*("H@0&%U=&AO<B`@
M("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*("H@
M0'!A8VMA9V4@("`@(%A-3%]087)S97(*("H@0'-U8G!A8VMA9V4@($5X86UP
M;&5S"B`J+PH*+RHJ"B`J(')E<75I<F4@=&AE('!A<G-E<@H@*B\*<F5Q=6ER
M95]O;F-E("=834PO4&%R<V5R+G!H<"<["@IC;&%S<R!M>4AA;F1L97(*>PH@
M("`O*BH*("`@("H@:&%N9&QE('-T87)T(&5L96UE;G0*("`@("H*("`@("H@
M0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A<F%M("`@(')E<V]U<F-E("`@
M('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@(&%R<F%Y
M("`@("`@(&%T=')I8G5T97,*("`@("HO"B`@("!F=6YC=&EO;B!S=&%R=$AA
M;F1L97(H)'AP+"`D;F%M92P@)&%T=')I8G,I"B`@("!["B`@("`@("`@<')I
M;G1F*"=H86YD;&4@<W1A<G0@=&%G.B`E<SQB<B`O/B<L("1N86UE*3L*("`@
M('T*"B`@("\J*@H@("`@*B!H86YD;&4@<W1A<G0@96QE;65N=`H@("`@*@H@
M("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<F5S;W5R
M8V4@("`@>&UL('!A<G-E<B!R97-O=7)C90H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`@("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@
M87)R87D@("`@("`@871T<FEB=71E<PH@("`@*B\*("`@(&9U;F-T:6]N(&5N
M9$AA;F1L97(H)'AP+"`D;F%M92D*("`@('L*("`@("`@("!P<FEN=&8H)VAA
M;F1L92!E;F0@=&%G.B`E<SQB<B`O/B<L("1N86UE*3L*("`@('T*?0H*)'`@
M/2`F;F5W(%A-3%]087)S97(H*3L*)&@@/2`F;F5W(&UY2&%N9&QE<B@I.PH*
M)')E<W5L="`]("1P+3YS971);G!U=$9I;&4H)WAM;%]P87)S97)?9FEL92YX
M;6PG*3L*)')E<W5L="`]("1P+3YS971(86YD;&5R3V)J*"1H*3L*)')E<W5L
M="`]("1P+3YP87)S92@I.PH_/@``+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I
M;7!L93$N<&AP`````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,38V`#$P-3$U-#,Q,#4V`#`R-C0P-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/U!(4`HO
M*BH*("H@97AA;7!L92!F;W(@6$U,7U!A<G-E<E]3:6UP;&4*("H*("H@)$ED
M.B!X;6Q?<&%R<V5R7W-I;7!L93$N<&AP+'8@,2XS(#(P,#0O,#4O,C@@,38Z
M,#DZ-#@@<V-H<W0@17AP("0*("H*("H@0&%U=&AO<B`@("`@(%-T97!H86X@
M4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*("H@0'!A8VMA9V4@("`@
M(%A-3%]087)S97(*("H@0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PH*+RHJ
M"B`J(')E<75I<F4@=&AE('!A<G-E<@H@*B\*<F5Q=6ER95]O;F-E("=834PO
M4&%R<V5R+U-I;7!L92YP:'`G.PH*8VQA<W,@;7E087)S97(@97AT96YD<R!8
M34Q?4&%R<V5R7U-I;7!L90I["B`@("!F=6YC=&EO;B!M>5!A<G-E<B@I"B`@
M("!["B`@("`@("`@)'1H:7,M/EA-3%]087)S97)?4VEM<&QE*"D["B`@("!]
M"@H@("`O*BH*("`@("H@:&%N9&QE('1H92!E;&5M96YT"B`@("`J"B`@("`J
M(%1H92!E;&5M96YT('=I;&P@8F4@:&%N9&QE9"P@;VYC92!I="=S(&-L;W-E
M9`H@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`@("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R
M86T@("`@87)R87D@("`@("`@871T<FEB=71E<R!O9B!T:&4@96QE;65N=`H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@8VAA<F%C=&5R(&1A=&$@;V8@
M=&AE(&5L96UE;G0*("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5%;&5M96YT
M*"1N86UE+"`D871T<FEB<RP@)&1A=&$I"B`@("!["B`@("`@("`@<')I;G1F
M*"=H86YD;&EN9R`E<R!I;B!T86<@9&5P=&@@)60\8G(@+SXG+"`D;F%M92P@
M)'1H:7,M/F=E=$-U<G)E;G1$97!T:"@I*3L*("`@("`@("!P<FEN=&8H)V-H
M87)A8W1E<B!D871A.B`E<SQB<B`O/B<L("1D871A("D["B`@("`@("`@<')I
M;G0@)T%T=')I8G5T97,Z/&)R("\^)SL*("`@("`@("!P<FEN="`G/'!R93XG
M.PH@("`@("`@('!R:6YT7W(H("1A='1R:6)S("D["B`@("`@("`@<')I;G0@
M)SPO<')E/B<["B`@("`@("`@<')I;G0@)SQB<B`O/B<["B`@("!]"GT*"B1P
M(#T@)FYE=R!M>5!A<G-E<B@I.PH*)')E<W5L="`]("1P+3YS971);G!U=$9I
M;&4H)WAM;%]P87)S97)?<VEM<&QE,2YX;6PG*3L*)')E<W5L="`]("1P+3YP
M87)S92@I.PH_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R
M+V5X86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,2YX;6P`````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,3<`
M,3`U,34T,S$P-38`,#(V-#$S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#PA+2T@)$ED.B!X;6Q?<&%R<V5R7W-I;7!L93$N
M>&UL+'8@,2XR(#(P,#0O,#4O,C0@,C$Z-#(Z,S,@<V-H<W0@17AP("0@+2T^
M"CQF;V\^"B`@("`\8F%R/F-O;G1E;G0@;V8@8F%R/"]B87(^"B`@("`\96UP
M='DO/@H@("`@/&%R9V@@9F]O/2)B87(B/@H@("`@("`@('1E<W0*("`@("`@
M("`\=&]M871O/G!I>GIA/"]T;VUA=&\^"B`@("`\+V%R9V@^"CPO9F]O/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X
M;6Q?<&%R<V5R7W-I;7!L93(N<&AP`````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-3(T`#$P-3$U-#,Q,#4V
M`#`R-C0P-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/U!(4`HO*BH*("H@97AA;7!L92!F;W(@6$U,7U!A<G-E<E]3:6UP
M;&4*("H*("H@)$ED.B!X;6Q?<&%R<V5R7W-I;7!L93(N<&AP+'8@,2XQ(#(P
M,#0O,#4O,C0@,C$Z-#(Z,S,@<V-H<W0@17AP("0*("H*("H@0&%U=&AO<B`@
M("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*("H@
M0'!A8VMA9V4@("`@(%A-3%]087)S97(*("H@0'-U8G!A8VMA9V4@($5X86UP
M;&5S"B`J+PH*+RHJ"B`J(')E<75I<F4@=&AE('!A<G-E<@H@*B\*<F5Q=6ER
M95]O;F-E("=834PO4&%R<V5R+U-I;7!L92YP:'`G.PH*8VQA<W,@;7E087)S
M97(R(&5X=&5N9',@6$U,7U!A<G-E<E]3:6UP;&4*>PH@("`@9G5N8W1I;VX@
M;7E087)S97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y834Q?4&%R<V5R7U-I
M;7!L92@I.PH@("`@?0H*("`@+RHJ"B`@("`J(&AA;F1L92!T:&4@8V%T96=O
M<GD@96QE;65N=`H@("`@*@H@("`@*B!4:&4@96QE;65N="!W:6QL(&)E(&AA
M;F1L960L(&]N8V4@:70G<R!C;&]S960*("`@("H*("`@("H@0&%C8V5S<R`@
M('!R:79A=&4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&YA;64@;V8@
M=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T=')I
M8G5T97,@;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@(&-H87)A8W1E<B!D871A(&]F('1H92!E;&5M96YT"B`@("`J+PH@("`@
M9G5N8W1I;VX@:&%N9&QE16QE;65N=%]C871E9V]R>2@D;F%M92P@)&%T=')I
M8G,L("1D871A*0H@("`@>PH@("`@("`@('!R:6YT9B@@)T-A=&5G;W)Y(&ES
M("5S/&)R("\^)RP@)&1A=&$@*3L*("`@('T*"B`@("\J*@H@("`@*B!H86YD
M;&4@=&AE(&YA;64@96QE;65N=`H@("`@*@H@("`@*B!4:&4@96QE;65N="!W
M:6QL(&)E(&AA;F1L960L(&]N8V4@:70G<R!C;&]S960*("`@("H*("`@("H@
M0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@
M(&YA;64@;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@
M("`@(&%T=')I8G5T97,@;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@("`@(&-H87)A8W1E<B!D871A(&]F('1H92!E;&5M96YT"B`@
M("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE16QE;65N=%]N86UE*"1N86UE+"`D
M871T<FEB<RP@)&1A=&$I"B`@("!["B`@("`@("`@<')I;G1F*"`G3F%M92!I
M<R`E<SQB<B`O/B<L("1D871A("D["B`@("!]"GT*"B1P(#T@)FYE=R!M>5!A
M<G-E<C(H*3L*)')E<W5L="`]("1P+3YS971);G!U=$9I;&4H)WAM;%]P87)S
M97)?<VEM<&QE,BYX;6PG*3L*)'`M/G-E=$UO9&4H)V9U;F,G*3L*)')E<W5L
M="`]("1P+3YP87)S92@I.PH_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,BYX;6P`
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`R,S``,3`U,34T,S$P-38`,#(V-#`V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#PA+2T@)$ED.B!X;6Q?<&%R
M<V5R7W-I;7!L93(N>&UL+'8@,2XQ(#(P,#0O,#4O,C0@,C$Z-#(Z,S,@<V-H
M<W0@17AP("0@+2T^"CQP86-K86=E/@H@("`@/&-A=&5G;W)Y/EA-3#PO8V%T
M96=O<GD^"B`@("`\;F%M93Y834Q?4&%R<V5R/"]N86UE/@H\+W!A8VMA9V4^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E
M<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I;7!L95]H86YD;&5R+G!H<```````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#<R
M`#$P-3$U-#,Q,#4V`#`S,#`R,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/U!(4`HO*BH*("H@97AA;7!L92!F;W(@6$U,
M7U!A<G-E<E]3:6UP;&4*("H*("H@)$ED.B!X;6Q?<&%R<V5R7W-I;7!L95]H
M86YD;&5R+G!H<"QV(#$N,2`R,#`T+S`U+S(U(#$S.C(V.C0R('-C:'-T($5X
M<"`D"B`J"B`J($!A=71H;W(@("`@("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T
M0'!H<"UT;V]L<RYN970^"B`J($!P86-K86=E("`@("!834Q?4&%R<V5R"B`J
M($!S=6)P86-K86=E("!%>&%M<&QE<PH@*B\*"B\J*@H@*B!R97%U:7)E('1H
M92!P87)S97(*("HO"G)E<75I<F5?;VYC92`G6$U,+U!A<G-E<B]3:6UP;&4N
M<&AP)SL*"F-L87-S(&UY2&%N9&QE<E-I;7!L90I["B`@("\J*@H@("`@*B!H
M86YD;&4@=&AE(&-A=&5G;W)Y(&5L96UE;G0*("`@("H*("`@("H@5&AE(&5L
M96UE;G0@=VEL;"!B92!H86YD;&5D+"!O;F-E(&ET)W,@8VQO<V5D"B`@("`J
M"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@("!S=')I
M;F<@("`@("!N86UE(&]F('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@("!A
M<G)A>2`@("`@("!A='1R:6)U=&5S(&]F('1H92!E;&5M96YT"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("`@("!C:&%R86-T97(@9&%T82!O9B!T:&4@96QE
M;65N=`H@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L945L96UE;G1?8V%T96=O
M<GDH)&YA;64L("1A='1R:6)S+"`D9&%T82D*("`@('L*("`@("`@("!P<FEN
M=&8H("=#871E9V]R>2!I<R`E<SQB<B`O/B<L("1D871A("D["B`@("!]"@H@
M("`O*BH*("`@("H@:&%N9&QE('1H92!N86UE(&5L96UE;G0*("`@("H*("`@
M("H@5&AE(&5L96UE;G0@=VEL;"!B92!H86YD;&5D+"!O;F-E(&ET)W,@8VQO
M<V5D"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("`@("!N86UE(&]F('1H92!E;&5M96YT"B`@("`J($!P
M87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S(&]F('1H92!E;&5M96YT
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!C:&%R86-T97(@9&%T82!O
M9B!T:&4@96QE;65N=`H@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L945L96UE
M;G1?;F%M92@D;F%M92P@)&%T=')I8G,L("1D871A*0H@("`@>PH@("`@("`@
M('!R:6YT9B@@)TYA;64@:7,@)7,\8G(@+SXG+"`D9&%T82`I.PH@("`@?0I]
M"@HD<"`]("9N97<@6$U,7U!A<G-E<E]3:6UP;&4H*3L*)&@@/2`F;F5W(&UY
M2&%N9&QE<E-I;7!L92@I.PHD<"T^<V5T2&%N9&QE<D]B:B@D:"D["B1R97-U
M;'0@/2`D<"T^<V5T26YP=71&:6QE*"=X;6Q?<&%R<V5R7W-I;7!L93(N>&UL
M)RD["B1P+3YS971-;V1E*"=F=6YC)RD["B1R97-U;'0@/2`D<"T^<&%R<V4H
M*3L*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?
M9FEL92YX;6P`````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,C<`,3`U,34T,S$P-38`,#(U-S4W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QF;V\^
M"B`@("`\8F%R/F-O;G1E;G0@;V8@8F%R/"]B87(^"B`@("`\96UP='DO/@H@
M("`@/&%R9V@@9F]O/2)B87(B/G1E<W0\+V%R9V@^"CPO9F]O/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O3&]G+P``````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`Q-S`Q-``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R\`````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$W
M-S0T`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S
M+V5X86UP;&5S+P``````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`U-@`P,C$U-C(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O8V]M<&]S:71E+G!H<```````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-#8Q`#$P-3$U-#,Q,#4V`#`R-#(W,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYS;VQE(#T@)DQO9SHZ<VEN9VQE
M=&]N*"=C;VYS;VQE)RP@)R<L("=415-4)RD["B1F:6QE(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=F:6QE)RP@)V]U="YL;V<G+"`G5$535"<I.PH*)&-O;7!O<VET
M92`]("9,;V<Z.G-I;F=L971O;B@G8V]M<&]S:71E)RD["B1C;VUP;W-I=&4M
M/F%D9$-H:6QD*"1C;VYS;VQE*3L*)&-O;7!O<VET92T^861D0VAI;&0H)&9I
M;&4I.PH*)&-O;7!O<VET92T^;&]G*"=4:&ES(&5V96YT('=I;&P@8F4@;&]G
M9V5D('1O(&)O=&@@:&%N9&QE<G,N)RD["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO
M9R]D;V-S+V5X86UP;&5S+V1I<W!L87DN<&AP````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#0S,``Q,#4Q-30S,3`U-@`P,C,W,S(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G
M3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=E<G)O<E]P<F5P96YD)R`]/B`G
M/&9O;G0@8V]L;W(](B-F9C`P,#`B/CQT=#XG+`H@("`@("`@("`@("`@("=E
M<G)O<E]A<'!E;F0G("`]/B`G/"]T=#X\+V9O;G0^)RD["B1L;V=G97(@/2`F
M3&]G.CIS:6YG;&5T;VXH)V1I<W!L87DG+"`G)RP@)R<L("1C;VYF+"!014%2
M7TQ/1U]$14)51RD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@
M("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M
M<&QE<R]E<G)O<E]L;V<N<&AP````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R-3$`,3`U
M,34T,S$P-38`,#(T,C8P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*
M)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G97)R;W)?;&]G)RP@4$5!4E],
M3T=?5%E015]365-414TL("=I9&5N="<I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q
M,#L@)&DK*RD@>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O9FEL92YP
M:'```````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,P`#$P-3$U-#,Q,#4V`#`R
M,S(P,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R
M87DH)VUO9&4G(#T^(#`V,#`L("=T:6UE1F]R;6%T)R`]/B`G)5@@)7@G*3L*
M)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G9FEL92<L("=O=70N;&]G)RP@
M)VED96YT)RP@)&-O;F8I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@
M>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+VUA:6PN<&AP````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#,T,@`Q,#4Q-30S,3`U-@`P,C,R,3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=S=6)J96-T
M)R`]/B`G26UP;W)T86YT($QO9R!%=F5N=',G*3L*)&QO9V=E<B`]("9,;V<Z
M.G-I;F=L971O;B@G;6%I;"<L("=W96)M87-T97)`97AA;7!L92YC;VTG+"`G
M:61E;G0G+"`D8V]N9BD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2![
M"B`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],
M;V<O9&]C<R]E>&%M<&QE<R]N=6QL+G!H<```````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`R,#4`,3`U,34T,S$P-38`,#(S,C,W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)TQO9RYP:'`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G;G5L;"<I
M.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO9V=E<BT^
M;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA
M;7!L97,O;V)S97)V97)?;6%I;"YP:'``````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C$W`#$P
M-3$U-#,Q,#4V`#`R-3$R,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<O;V)S97)V
M97(N<&AP)SL*"F-L87-S($QO9U]O8G-E<G9E<E]M86EL(&5X=&5N9',@3&]G
M7V]B<V5R=F5R"GL*("`@('9A<B`D7W1O(#T@)R<["B`@("!V87(@)%]S=6)J
M96-T(#T@)R<["B`@("!V87(@)%]P871T97)N(#T@)R<["@H@("`@9G5N8W1I
M;VX@3&]G7V]B<V5R=F5R7VUA:6PH)'!R:6]R:71Y+"`D8V]N9BD*("`@('L*
M("`@("`@("`O*B!#86QL('1H92!B87-E(&-L87-S(&-O;G-T<G5C=&]R+B`J
M+PH@("`@("`@("1T:&ES+3Y,;V=?;V)S97)V97(H)'!R:6]R:71Y*3L*"B`@
M("`@("`@+RH@0V]N9FEG=7)E('1H92!O8G-E<G9E<BX@*B\*("`@("`@("`D
M=&AI<RT^7W1O(#T@)&-O;F9;)W1O)UT["B`@("`@("`@)'1H:7,M/E]S=6)J
M96-T(#T@)&-O;F9;)W-U8FIE8W0G73L*("`@("`@("`D=&AI<RT^7W!A='1E
M<FX@/2`D8V]N9ELG<&%T=&5R;B==.PH@("`@?0H*("`@(&9U;F-T:6]N(&YO
M=&EF>2@D979E;G0I"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H)'1H
M:7,M/E]P871T97)N+"`D979E;G1;)VUE<W-A9V4G72D@(3T@,"D@>PH@("`@
M("`@("`@("!M86EL*"1T:&ES+3Y?=&\L("1T:&ES+3Y?<W5B:F5C="P@)&5V
M96YT6R=M97-S86=E)UTI.PH@("`@("`@('T*("`@('T*?0H*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O
M8W,O97AA;7!L97,O<&5A<E]E<G)O<E]H86YD;&5R+G!H<```````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,34T`#$P-3$U-#,Q,#4V`#`R-C$R-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N
M<&AP)SL*"F9U;F-T:6]N(&5R<F]R2&%N9&QE<B@D97)R;W(I"GL*("`@(&=L
M;V)A;"`D;&]G9V5R.PH*("`@("1M97-S86=E(#T@)&5R<F]R+3YG971-97-S
M86=E*"D["@H@("`@:68@*"%E;7!T>2@D97)R;W(M/F)A8VMT<F%C95LQ75LG
M9FEL92==*2D@>PH@("`@("`@("1M97-S86=E("X]("<@*"<@+B`D97)R;W(M
M/F)A8VMT<F%C95LQ75LG9FEL92==.PH@("`@("`@(&EF("@A96UP='DH)&5R
M<F]R+3YB86-K=')A8V5;,5U;)VQI;F4G72DI('L*("`@("`@("`@("`@)&UE
M<W-A9V4@+CT@)R!A="!L:6YE("<@+B`D97)R;W(M/F)A8VMT<F%C95LQ75LG
M;&EN92==.PH@("`@("`@('T*("`@("`@("`D;65S<V%G92`N/2`G*2<["B`@
M("!]"@H@("`@)&QO9V=E<BT^;&]G*"1M97-S86=E+"`D97)R;W(M/F-O9&4I
M.PI]"@HD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L
M("=I9&5N="<I.PH*4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7T-!3$Q"04-++"`G97)R;W)(86YD;&5R)RD["E!%05(Z.G)A:7-E17)R;W(H
M)U1H:7,@:7,@86X@:6YF;W)M871I;VX@;&]G(&UE<W-A9V4N)RP@4$5!4E],
M3T=?24Y&3RD["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M3&]G+V1O8W,O97AA;7!L97,O<&AP7V5R<F]R7VAA;F1L97(N<&AP````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-#`P`#$P-3$U-#,Q,#4V`#`R-3<V,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M("=,;V<N<&AP)SL*"F9U;F-T:6]N(&5R<F]R2&%N9&QE<B@D8V]D92P@)&UE
M<W-A9V4L("1F:6QE+"`D;&EN92D*>PH@("`@9VQO8F%L("1L;V=G97(["@H@
M("`@+RH@36%P('1H92!02%`@97)R;W(@=&\@82!,;V<@<')I;W)I='DN("HO
M"B`@("!S=VET8V@@*"1C;V1E*2!["B`@("!C87-E($5?5T%23DE.1SH*("`@
M(&-A<V4@15]54T527U=!4DY)3D<Z"B`@("`@("`@)'!R:6]R:71Y(#T@4$5!
M4E],3T=?5T%23DE.1SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@15].3U1)
M0T4Z"B`@("!C87-E($5?55-%4E].3U1)0T4Z"B`@("`@("`@)'!R:6]R:71Y
M(#T@4$5!4E],3T=?3D]424-%.PH@("`@("`@(&)R96%K.PH@("`@8V%S92!%
M7T524D]2.@H@("`@8V%S92!%7U5315)?15)23U(Z"B`@("`@("`@)'!R:6]R
M:71Y(#T@4$5!4E],3T=?15)2.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L
M=#H*("`@("`@("`D<')I;W1I='D@/2!014%27TQ/1U])3D9/.PH@("`@?0H*
M("`@("1L;V=G97(M/FQO9R@D;65S<V%G92`N("<@:6X@)R`N("1F:6QE("X@
M)R!A="!L:6YE("<@+B`D;&EN92P*("`@("`@("`@("`@("`@("`D<')I;W)I
M='DI.PI]"@HD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@
M)R<L("=I9&5N="<I.PH*<V5T7V5R<F]R7VAA;F1L97(H)V5R<F]R2&%N9&QE
M<B<I.PIT<FEG9V5R7V5R<F]R*"=4:&ES(&ES(&%N(&EN9F]R;6%T:6]N(&QO
M9R!M97-S86=E+B<L($5?55-%4E].3U1)0T4I.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O<W%L+G!H<```````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S,T`#$P-3$U-#,Q,#4V`#`R,S`V-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)V1S;B<@/3X@)W!G
M<W%L.B\O:F]N0&QO8V%L:&]S="MU;FEX+VQO9W,G*3L*)&QO9V=E<B`]("9,
M;V<Z.G-I;F=L971O;B@G<W%L)RP@)VQO9U]T86)L92<L("=I9&5N="<L("1C
M;VYF*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G
M97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D
M;V-S+V5X86UP;&5S+W-Q;&ET92YP:'``````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#<U,0`Q,#4Q-30S,3`U-@`P,C,U-S0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G
M+G!H<"<["@HO*B!#<F5A=&EN9R!A(&YE=R!D871A8F%S92!C;VYN96-T:6]N
M+B`J+PHD8V]N9B`](&%R<F%Y*"=F:6QE;F%M92<@/3X@)VQO9RYD8B<L("=M
M;V1E)R`]/B`P-C8V+"`G<&5R<VES=&5N="<@/3X@=')U92D["B1L;V=G97(@
M/28@3&]G.CIF86-T;W)Y*"=S<6QI=&4G+"`G;&]G7W1A8FQE)RP@)VED96YT
M)RP@)&-O;F8I.PHD;&]G9V5R+3YL;V<H)VQO9V=I;F<@86X@979E;G0G+"!0
M14%27TQ/1U]705).24Y'*3L*"B\J(%5S:6YG(&%N(&5X:7-T:6YG(&1A=&%B
M87-E(&-O;FYE8W1I;VXN("HO"B1D8B`]('-Q;&ET95]O<&5N*"=L;V<N9&(G
M+"`P-C8V+"`D97)R;W(I.PHD;&]G9V5R(#TF($QO9SHZ9F%C=&]R>2@G<W%L
M:71E)RP@)VQO9U]T86)L92<L("=I9&5N="<L("1D8BD["B1L;V=G97(M/FQO
M9R@G;&]G9VEN9R!A;B!E=F5N="<L(%!%05)?3$]'7U=!4DY)3D<I.PIS<6QI
M=&5?8VQO<V4H)&1B*3L*```````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE
M<R]S>7-L;V<N<&AP````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,S0`,3`U,34T
M,S$P-38`,#(S-C`W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO
M9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G<WES;&]G)RP@3$]'7TQ/0T%,,"P@
M)VED96YT)RD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D
M;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O=VEN+G!H<```
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S(P`#$P-3$U-#,Q,#4V`#`R,S`V
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH
M)W1I=&QE)R`]/B`G4V%M<&QE($QO9R!/=71P=70G*3L*)&QO9V=E<B`]("9,
M;V<Z.G-I;F=L971O;B@G=VEN)RP@)TQO9U=I;F1O=R<L("=I9&5N="<L("1C
M;VYF*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G
M97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+V-O;G-O;&4N<&AP````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#(R-0`Q,#4Q-30S,3`U-@`P,C,W,S$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G3&]G+G!H<"<["@HD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N
M*"=C;VYS;VQE)RP@)R<L("=I9&5N="<I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q
M,#L@)&DK*RD@>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O
M9&]C<R]G=6ED92YT>'0`````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q
M,C0U,#``,3`U,34T,S$P-38`,#(Q-C`Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#T]/3T]/3T]/3T]/3T]/3T]"B!4:&4@
M3&]G(%!A8VMA9V4*/3T]/3T]/3T]/3T]/3T]/3T*"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM"B!5<V5R($1O8W5M96YT871I;VX*+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*"CI!=71H;W(Z("`@("`@("!*;VX@4&%R:7-E"CI#;VYT86-T.B`@("`@
M("!J;VY`<&AP+FYE=`HZ1&%T93H@("`@("`@("`@)$1A=&4Z(#(P,#8O,#0O
M,C$@,#4Z,C4Z,#D@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C(U
M("0*"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I
M;F<Z.@H*57-I;F<@3&]G($AA;F1L97)S"CT]/3T]/3T]/3T]/3T]/3T]/0H*
M5&AE($QO9R!P86-K86=E(&ES(&EM<&QE;65N=&5D(&%S(&$@9G)A;65W;W)K
M('1H870@<W5P<&]R=',@=&AE(&YO=&EO;B!O9@IB86-K96YD+7-P96-I9FEC
M(&QO9R!H86YD;&5R<RX@(%1H92!B87-E(&QO9V=I;F<@;V)J96-T("AD969I
M;F5D(&)Y('1H92!@3&]G"F-L87-S8%\I(&ES('!R:6UA<FEL>2!A;B!A8G-T
M<F%C="!I;G1E<F9A8V4@=&\@=&AE(&-U<G)E;G1L>2!C;VYF:6=U<F5D"FAA
M;F1L97(N"@I!('=I9&4@=F%R:65T>2!O9B!H86YD;&5R<R!A<F4@9&ES=')I
M8G5T960@=VET:"!T:&4@3&]G('!A8VMA9V4L(&%N9"P@<VAO=6QD"FYO;F4@
M;V8@=&AE;2!F:70@>6]U<B!A<'!L:6-A=&EO;B=S(&YE961S+"!I="=S(&5A
M<WD@=&\@8'=R:71E('EO=7(@;W=N8%]?+@H*+BX@7TQO9R!C;&%S<SH@:'1T
M<#HO+V-V<RYP:'`N;F5T+V-O+G!H<"]P96%R+TQO9R],;V<N<&AP"E]?(&!#
M=7-T;VT@2&%N9&QE<G-@7PH*0W)E871I;F<@82!,;V<@3V)J96-T"BTM+2TM
M+2TM+2TM+2TM+2TM+2TM+0I4:&5R92!A<F4@=&AR964@=V%Y<R!T;R!C<F5A
M=&4@3&]G(&]B:F5C=',Z"@H@("`@+2!5<VEN9R!T:&4@8&!,;V<Z.F9A8W1O
M<GDH*6!@(&UE=&AO9`H@("`@+2!5<VEN9R!T:&4@8&!,;V<Z.G-I;F=L971O
M;B@I8&`@;65T:&]D"B`@("`M($1I<F5C="!I;G-T86YT:6%T:6]N"@I4:&4@
M1F%C=&]R>2!-971H;V0*?GY^?GY^?GY^?GY^?GY^?GY^"E1H92!@8$QO9SHZ
M9F%C=&]R>2@I8&`@;65T:&]D(&EM<&QE;65N=',@=&AE(&!&86-T;W)Y(%!A
M='1E<FY@7RX@($ET(&%L;&]W<PIF;W(@=&AE('!A<F%M971E<FEZ960@8V]N
M<W1R=6-T:6]N(&]F(&-O;F-R971E($QO9R!I;G-T86YC97,@870@<G5N=&EM
M92X@(%1H90IF:7)S="!P87)A;65T97(@=&\@=&AE(&!@3&]G.CIF86-T;W)Y
M*"E@8"!M971H;V0@:6YD:6-A=&5S('1H92!N86UE(&]F('1H90IC;VYC<F5T
M92!H86YD;&5R('1O(&-R96%T92X@(%1H92!R97-T(&]F('1H92!P87)A;65T
M97)S('=I;&P@8F4@<&%S<V5D(&]N('1O"G1H92!H86YD;&5R)W,@8V]N<W1R
M=6-T;W(@*'-E92!@0V]N9FEG=7)I;F<@82!(86YD;&5R8%\@8F5L;W<I+@H*
M5&AE(&YE=R!@8$QO9V!@(&EN<W1A;F-E(&ES(')E='5R;F5D(&)Y(')E9F5R
M96YC92X*"CHZ"@H@("`@<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B`@("`D
M8V]N<V]L92`]("9,;V<Z.F9A8W1O<GDH)V-O;G-O;&4G+"`G)RP@)U1%4U0G
M*3L*("`@("1C;VYS;VQE+3YL;V<H)TQO9V=I;F<@=&\@=&AE(&-O;G-O;&4N
M)RD["@H@("`@)&9I;&4@/2`F3&]G.CIF86-T;W)Y*"=F:6QE)RP@)V]U="YL
M;V<G+"`G5$535"<I.PH@("`@)&9I;&4M/FQO9R@G3&]G9VEN9R!T;R!O=70N
M;&]G+B<I.PH*+BX@7T9A8W1O<GD@4&%T=&5R;CH@:'1T<#HO+W=W=RYP:'!P
M871T97)N<RYC;VTO:6YD97@N<&AP+V%R=&EC;&4O87)T:6-L979I97<O-#DO
M,2\Q+PH*5&AE(%-I;F=L971O;B!-971H;V0*?GY^?GY^?GY^?GY^?GY^?GY^
M?GX*5&AE(&!@3&]G.CIS:6YG;&5T;VXH*6!@(&UE=&AO9"!I;7!L96UE;G1S
M('1H92!@4VEN9VQE=&]N(%!A='1E<FY@7RX@(%1H90IS:6YG;&5T;VX@<&%T
M=&5R;B!E;G-U<F5S('1H870@;VYL>2!A('-I;F=L92!I;G-T86YC92!O9B!A
M(&=I=F5N(&QO9R!T>7!E(&%N9`IC;VYF:6=U<F%T:6]N(&ES(&5V97(@8W)E
M871E9"X@(%1H:7,@:&%S('1W;R!B96YE9FET<SH@9FER<W0L(&ET('!R979E
M;G1S"F1U<&QI8V%T92!@8$QO9V!@(&EN<W1A;F-E<R!F<F]M(&)E:6YG(&-O
M;G-T<G5C=&5D+"!A;F0L('-E8V]N9"P@:70@9VEV97,@86QL"F]F('EO=7(@
M8V]D92!A8V-E<W,@=&\@=&AE('-A;64@8&!,;V=@8"!I;G-T86YC92X@(%1H
M92!L871T97(@:7,@97-P96-I86QL>0II;7!O<G1A;G0@=VAE;B!L;V=G:6YG
M('1O(&9I;&5S(&)E8V%U<V4@;VYL>2!A('-I;F=L92!F:6QE(&AA;F1L97(@
M=VEL;"!N965D"G1O(&)E(&UA;F%G960N"@I4:&4@8&!,;V<Z.G-I;F=L971O
M;B@I8&`@;65T:&]D)W,@<&%R86UE=&5R<R!M871C:"!T:&4@8&!,;V<Z.F9A
M8W1O<GDH*6!@"FUE=&AO9"X@(%1H92!N97<@8&!,;V=@8"!I;G-T86YC92!I
M<R!R971U<FYE9"!B>2!R969E<F5N8V4N"@HZ.@H*("`@(')E<75I<F5?;VYC
M92`G3&]G+G!H<"<["@H@("`@+RH@4V%M92!C;VYS=')U8W1I;VX@<&%R86UE
M=&5R<R`J+PH@("`@)&$@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G
M)RP@)U1%4U0G*3L*("`@("1B(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE
M)RP@)R<L("=415-4)RD["@H@("`@:68@*"1A(#T]/2`D8BD@>PH@("`@("`@
M(&5C:&\@)R1A(&%N9"`D8B!P;VEN="!T;R!T:&4@<V%M92!,;V<@:6YS=&%N
M8V4N)R`N(")<;B(["B`@("!]"@H@("`@+RH@1&EF9F5R96YT(&-O;G-T<G5C
M=&EO;B!P87)A;65T97)S("HO"B`@("`D8R`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<L("<G+"`G5$535#$G*3L*("`@("1D(#T@)DQO9SHZ<VEN9VQE
M=&]N*"=C;VYS;VQE)RP@)R<L("=415-4,B<I.PH*("`@(&EF("@D8R`A/3T@
M)&0I('L*("`@("`@("!E8VAO("<D8R!A;F0@)&0@<&]I;G0@=&\@9&EF9F5R
M96YT($QO9R!I;G-T86YC97,N)R`N(")<;B(["B`@("!]"@HN+B!?4VEN9VQE
M=&]N(%!A='1E<FXZ(&AT='`Z+R]W=W<N<&AP<&%T=&5R;G,N8V]M+VEN9&5X
M+G!H<"]A<G1I8VQE+V%R=&EC;&5V:65W+S8O,2\Q+PH*1&ER96-T($EN<W1A
M;G1I871I;VX*?GY^?GY^?GY^?GY^?GY^?GY^?GX*270@:7,@86QS;R!P;W-S
M:6)L92!T;R!D:7)E8W1L>2!I;G-T86YT:6%T92!C;VYC<F5T92!@8$QO9V!@
M(&AA;F1L97(*:6YS=&%N8V5S+B`@2&]W979E<BP@=&AI<R!M971H;V0@:7,@
M*BIN;W0@<F5C;VUM96YD960J*B!B96-A=7-E(&ET(&-R96%T97,@80IT:6=H
M=&5R(&-O=7!L:6YG(&)E='=E96X@>6]U<B!A<'!L:6-A=&EO;B!C;V1E(&%N
M9"!T:&4@3&]G('!A8VMA9V4@=&AA;B!I<PIN96-E<W-A<GDN("!5<V4@;V8@
M8'1H92!F86-T;W)Y(&UE=&AO9&!?(&]R(&!T:&4@<VEN9VQE=&]N(&UE=&AO
M9&!?(&ES"G!R969E<G)E9"X*"@I#;VYF:6=U<FEN9R!A($AA;F1L97(*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"D$@;&]G(&AA;F1L97(G<R!C;VYF:6=U<F%T
M:6]N(&ES(&1E=&5R;6EN960@8GD@=&AE(&%R9W5M96YT<R!U<V5D(&EN(&ET
M<PIC;VYS=')U8W1I;VXN("!(97)E)W,@86X@;W9E<G9I97<@;V8@=&AO<V4@
M<&%R86UE=&5R<SHZ"@H@("`@+RH@57-I;F<@=&AE(&9A8W1O<GD@;65T:&]D
M("XN+B`J+PH@("`@)DQO9SHZ9F%C=&]R>2@D:&%N9&QE<BP@)&YA;64L("1I
M9&5N="P@)&-O;F8L("1M87A,979E;"D["@H@("`@+RH@57-I;F<@=&AE('-I
M;F=L971O;B!M971H;V0@+BXN("HO"B`@("`F3&]G.CIS:6YG;&5T;VXH)&AA
M;F1L97(L("1N86UE+"`D:61E;G0L("1C;VYF+"`D;6%X3&5V96PI.PH*("`@
M("\J(%5S:6YG(&1I<F5C="!I;G-T86YT:6%T:6]N("XN+B`J+PH@("`@;F5W
M($QO9U]H86YD;&5R*"1N86UE+"`D:61E;G0L("1C;VYF+"`D;6%X3&5V96PI
M.PH**RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T
M97(@("`@('P@5'EP92`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/2L]/3T]
M/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/2L*?"!@8"1H86YD;&5R8&`@('P@4W1R:6YG("`@('P@5&AE
M('1Y<&4@;V8@3&]G(&AA;F1L97(@=&\@8V]N<W1R=6-T+B`@5&AI<R`@('P*
M?"`@("`@("`@("`@("`@('P@("`@("`@("`@('P@<&%R86UE=&5R(&ES(&]N
M;'D@879A:6QA8FQE('=H96X@8'1H92!F86-T;W)Y('P*?"`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@;65T:&]D8%\@;W(@8'1H92!S:6YG;&5T;VX@
M;65T:&]D8%\@87)E('5S960N('P**RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*?"!@8"1N86UE8&`@("`@('P@4W1R:6YG("`@('P@5&AE(&YA
M;64@;V8@=&AE(&QO9R!R97-O=7)C92!T;R!W:&EC:"!T:&4@("`@('P*?"`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@979E;G1S('=I;&P@8F4@;&]G
M9V5D+B`@5&AE('5S92!O9B!T:&ES('9A;'5E('P*?"`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@:7,@9&5T97)M:6YE9"!B>2!T:&4@:&%N9&QE<B=S
M(&EM<&QE;65N=&%T:6]N+GP*?"`@("`@("`@("`@("`@('P@("`@("`@("`@
M('P@270@9&5F875L=',@=&\@86X@96UP='D@<W1R:6YG+B`@("`@("`@("`@
M("`@('P**RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8"1I
M9&5N=&!@("`@('P@4W1R:6YG("`@('P@06X@:61E;G1I9FEC871I;VX@<W1R
M:6YG('1H870@=VEL;"!B92!I;F-L=61E9'P*?"`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@:6X@86QL(&QO9R!E=F5N=',@;&]G9V5D(&)Y('1H:7,@
M:&%N9&QE<BX@("`@('P*?"`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M5&AI<R!V86QU92!D969A=6QT<R!T;R!A;B!E;7!T>2!S=')I;F<@86YD(&-A
M;GP*?"`@("`@("`@("`@("`@('P@("`@("`@("`@('P@8F4@8VAA;F=E9"!A
M="!R=6YT:6UE('5S:6YG('1H92!@8'-E=$ED96YT*"E@8'P*?"`@("`@("`@
M("`@("`@('P@("`@("`@("`@('P@;65T:&]D+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8"1C;VYF8&`@("`@('P@07)R87D@("`@('P@07-S
M;V-I871I=F4@87)R87D@;V8@:V5Y+79A;'5E('!A:7)S('1H870@87)E('P*
M?"`@("`@("`@("`@("`@('P@("`@("`@("`@('P@=7-E9"!T;R!S<&5C:69Y
M(&%N>2!H86YD;&5R+7-P96-I9FEC('-E='1I;F=S+GP**RTM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8"1L979E;&!@("`@('P@26YT96=E
M<B`@('P@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L
M979E;"X@('P*?"`@("`@("`@("`@("`@('P@("`@("`@("`@('P@5&AI<R!V
M86QU92!D969A=6QT<R!T;R!@8%!%05)?3$]'7T1%0E5'8&`N("`@('P*?"`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@4V5E(&!,;V<@3&5V96QS8%\@
M86YD(&!,;V<@3&5V96P@36%S:W-@7RX@("`@('P**RTM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*"@I,;V=G:6YG(&%N($5V96YT"BTM+2TM+2TM
M+2TM+2TM+2T*179E;G1S(&%R92!L;V=G960@=7-I;F<@=&AE(&!@;&]G*"E@
M8"!M971H;V0Z.@H*("`@("1L;V=G97(M/FQO9R@G365S<V%G92<L(%!%05)?
M3$]'7TY/5$E#12D["@I4:&4@9FER<W0@87)G=6UE;G0@8V]N=&%I;G,@=&AE
M(&QO9R!E=F5N="=S(&UE<W-A9V4N("!%=F5N('1H;W5G:"!T:&4@979E;G0@
M:7,*86QW87ES(&QO9V=E9"!A<R!A('-T<FEN9RP@:70@:7,@<&]S<VEB;&4@
M=&\@<&%S<R!A;B!O8FIE8W0@=&\@=&AE(&!@;&]G*"E@8`IM971H;V0N("!)
M9B!T:&4@;V)J96-T(&EM<&QE;65N=',@82!@8&=E=%-T<FEN9R@I8&`@;65T
M:&]D+"!A(&!@=&]3=')I;F<H*6!@"FUE=&AO9"!O<B!:96YD($5N9VEN92`R
M)W,@<W!E8VEA;"!@8%]?=&]3=')I;F<H*6!@(&-A<W1I;F<@;65T:&]D+"!I
M="!W:6QL(&)E"G5S960@=&\@9&5T97)M:6YE('1H92!O8FIE8W0G<R!S=')I
M;F<@<F5P<F5S96YT871I;VXN("!/=&AE<G=I<V4L('1H90I@<V5R:6%L:7IE
M9&!?(&9O<FT@;V8@=&AE(&]B:F5C="!W:6QL(&)E(&QO9V=E9"X*"E1H92!S
M96-O;F0L(&]P=&EO;F%L(&%R9W5M96YT('-P96-I9FEE<R!T:&4@;&]G(&5V
M96YT)W,@<')I;W)I='DN("!3964@=&AE"F!,;V<@3&5V96QS8%\@=&%B;&4@
M9F]R('1H92!C;VUP;&5T92!L:7-T(&]F('!R:6]R:71I97,N("!4:&4@9&5F
M875L="!P<FEO<FET>0II<R!014%27TQ/1U])3D9/+@H*5&AE(&!@;&]G*"E@
M8"!M971H;V0@=VEL;"!R971U<FX@8&!T<G5E8&`@:68@=&AE(&5V96YT('=A
M<R!S=6-C97-S9G5L;'D*;&]G9V5D+@H*(E-H;W)T8W5T(B!M971H;V1S(&%R
M92!A;'-O(&%V86EL86)L92!F;W(@;&]G9VEN9R!A;B!E=F5N="!A="!A('-P
M96-I9FEC(&QO9PIL979E;"X@(%-E92!T:&4@8$QO9R!,979E;'-@7R!T86)L
M92!F;W(@=&AE(&-O;7!L971E(&QI<W0N"@HN+B!?<V5R:6%L:7IE9#H@:'1T
M<#HO+W=W=RYP:'`N;F5T+W-E<FEA;&EZ90H*"DQO9R!,979E;',*+2TM+2TM
M+2TM+0I4:&ES('1A8FQE(&ES(&]R9&5R960@8GD@:&EG:&5S="!P<FEO<FET
M>2`H8&!014%27TQ/1U]%34521V!@*2!T;R!L;W=E<W0*<')I;W)I='D@*&!@
M4$5!4E],3T=?1$5"54=@8"DN"@HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PI\($QE=F5L("`@("`@("`@("`@("`@("!\(%-H;W)T8W5T("`@
M("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@("`@("`@("`@?`HK/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@4$5!4E],3T=?14U%
M4D=@8"`@("!\(&!@96UE<F<H*6!@("`@?"!3>7-T96T@:7,@=6YU<V%B;&4@
M("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PI\(&!@4$5!4E],3T=?04Q%4E1@8"`@("!\(&!@86QE<G0H*6!@("`@
M?"!);6UE9&EA=&4@86-T:6]N(')E<75I<F5D("`@("`@("`@?`HK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@4$5!4E],3T=?0U))5&!@
M("`@("!\(&!@8W)I="@I8&`@("`@?"!#<FET:6-A;"!C;VYD:71I;VYS("`@
M("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PI\(&!@4$5!4E],3T=?15)28&`@("`@("!\(&!@97)R*"E@8"`@("`@?"!%
M<G)O<B!C;VYD:71I;VYS("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@4$5!4E],3T=?5T%23DE.1V!@
M("!\(&!@=V%R;FEN9R@I8&`@?"!787)N:6YG(&-O;F1I=&EO;G,@("`@("`@
M("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@4$5!4E],3T=?3D]424-%8&`@("!\(&!@;F]T:6-E*"E@8"`@?"!.;W)M
M86P@8G5T('-I9VYI9FEC86YT("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@4$5!4E],3T=?24Y&3V!@("`@("!\
M(&!@:6YF;R@I8&`@("`@?"!);F9O<FUA=&EO;F%L("`@("`@("`@("`@("`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M4$5!4E],3T=?1$5"54=@8"`@("!\(&!@9&5B=6<H*6!@("`@?"!$96)U9RUL
M979E;"!M97-S86=E<R`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PH*"DQO9R!,979E;"!-87-K<PHM+2TM+2TM+2TM
M+2TM+2T*1&5F:6YI;F<@82!L;V<@;&5V96P@;6%S:R!A;&QO=W,@>6]U('1O
M(&EN8VQU9&4@86YD+V]R(&5X8VQU9&4@<W!E8VEF:6,@;&5V96QS"F]F(&5V
M96YT<R!F<F]M(&)E:6YG(&QO9V=E9"X@(%1H92!@8"1L979E;&!@(&-O;G-T
M<G5C=&EO;B!P87)A;65T97(@*'-E90I@0V]N9FEG=7)I;F<@82!(86YD;&5R
M8%\I('5S97,@=&AI<R!M96-H86YI<VT@=&\@97AC;'5D92!L;V<@979E;G1S
M(&)E;&]W(&$*8V5R=&%I;B!P<FEO<FET>2P@86YD(&ET)W,@<&]S<VEB;&4@
M=&\@9&5F:6YE(&UO<F4@8V]M<&QE>"!M87-K<R!O;F-E('1H92!,;V<*;V)J
M96-T(&AA<R!B965N(&-O;G-T<G5C=&5D+@H*16%C:"!P<FEO<FET>2!H87,@
M82!S<&5C:69I8R!M87-K(&%S<V]C:6%T960@=VET:"!I="X@(%1O(&-O;7!U
M=&4@82!P<FEO<FET>2=S"FUA<VLL('5S92!T:&4@<W1A=&EC(&!@3&]G.CI-
M05-+*"E@8"!M971H;V0Z.@H*("`@("1M87-K(#T@3&]G.CI-05-+*%!%05)?
M3$]'7TE.1D\I.PH*5&\@8V]M<'5T92!T:&4@;6%S:R!F;W(@86QL('!R:6]R
M:71I97,@=7`@=&\L(&%N9"!I;F-L=61I;F<L(&$@8V5R=&%I;B!L979E;"P*
M=7-E('1H92!@8$QO9SHZ34%8*"E@8"!S=&%T:6,@;65T:&]D.CH*"B`@("`D
M;6%S:R`]($QO9SHZ34%8*%!%05)?3$]'7TE.1D\I.PH*5&\@8V]M<'5T92!T
M:&4@;6%S:R!F;W(@86QL('!R:6]R:71I97,@9W)E871E<B!T:&%N(&]R(&5Q
M=6%L('1O(&$@8V5R=&%I;@IL979E;"P@=7-E('1H92!@8$QO9SHZ34E.*"E@
M8"!S=&%T:6,@;65T:&]D.CH*"B`@("`D;6%S:R`]($QO9SHZ34E.*%!%05)?
M3$]'7TE.1D\I.PH*5&AE(&%P<&QY('1H92!M87-K+"!U<V4@=&AE(&!@<V5T
M36%S:R@I8&`@;65T:&]D.CH*"B`@("`D;&]G9V5R+3YS971-87-K*"1M87-K
M*3L*"DUA<VMS(&-A;B!B92!B92!C;VUB:6YE9"!U<VEN9R!B:71W:7-E(&]P
M97)A=&EO;G,N("!4;R!R97-T<FEC="!L;V=G:6YG('1O"F]N;'D@=&AO<V4@
M979E;G1S(&UA<FME9"!A<R!@8%!%05)?3$]'7TY/5$E#16!@(&]R(&!@4$5!
M4E],3T=?1$5"54=@8#HZ"@H@("`@)&UA<VL@/2!,;V<Z.DU!4TLH4$5!4E],
M3T=?3D]424-%*2!\($QO9SHZ34%32RA014%27TQ/1U]$14)51RD["B`@("`D
M;&]G9V5R+3YS971-87-K*"1M87-K*3L*"D9O<B!C;VYV96YI96YC92P@='=O
M('-P96-I86P@;6%S:W,@87)E('!R961E9FEN960Z(&!@4$5!4E],3T=?3D].
M16!@(&%N9`I@8%!%05)?3$]'7T%,3&!@+B`@8&!014%27TQ/1U]!3$Q@8"!I
M<R!E<W!E8VEA;&QY('5S969U;"!F;W(@97AL=61I;F<@;VYL>0IS<&5C:69I
M8R!P<FEO<FET:65S.CH*"B`@("`D;6%S:R`](%!%05)?3$]'7T%,3"!>($QO
M9SHZ34%32RA014%27TQ/1U].3U1)0T4I.PH@("`@)&QO9V=E<BT^<V5T36%S
M:R@D;6%S:RD["@I)="!I<R!A;'-O('!O<W-I8FQE('1O(')E=')I979E(&%N
M9"!M;V1I9GD@82!,;V<@;V)J96-T)W,@97AI<W1I;F<@;6%S:SHZ"@H@("`@
M)&UA<VL@/2`D;&]G9V5R+3YG971-87-K*"D@?"!,;V<Z.DU!4TLH4$5!4E],
M3T=?24Y&3RD["B`@("`D;&]G9V5R+3YS971-87-K*"1M87-K*3L*"@I&;'5S
M:&EN9R!,;V<@179E;G1S"BTM+2TM+2TM+2TM+2TM+2TM+2T*4V]M92!L;V<@
M:&%N9&QE<G,@*'-U8V@@87,@8'1H92!C;VYS;VQE(&AA;F1L97)@7RD@<W5P
M<&]R="!E>'!L:6-I=`HB8G5F9F5R:6YG(BX@(%=H96X@8G5F9F5R:6YG(&ES
M(&5N86)L960L(&QO9R!E=F5N=',@=V]N)W0@86-T=6%L;'D@8F4@=W)I='1E
M;@IT;R!T:&4@;W5T<'5T('-T<F5A;2!U;G1I;"!T:&4@:&%N9&QE<B!I<R!C
M;&]S960N("!/=&AE<B!H86YD;&5R<R`H<W5C:"!A<PI@=&AE(&9I;&4@:&%N
M9&QE<F!?*2!S=7!P;W)T(&EM<&QI8VET(&)U9F9E<FEN9R!B96-A=7-E('1H
M97D@=7-E('1H92!O<&5R871I;F<*<WES=&5M)W,@24\@<F]U=&EN97,L('=H
M:6-H(&UA>2!B=69F97(@=&AE(&]U='!U="X*"DET)W,@<&]S<VEB;&4@=&\@
M9F]R8V4@=&AE<V4@:&%N9&QE<G,@=&\@9FQU<V@@=&AE:7(@;W5T<'5T+"!H
M;W=E=F5R+"!B>0IC86QL:6YG('1H96ER(&!@9FQU<V@H*6!@(&UE=&AO9#HZ
M"@H@("`@)&-O;F8@/2!A<G)A>2@G8G5F9F5R:6YG)R`]/B!T<G5E*3L*("`@
M("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)W1E
M<W0G+"`D8V]N9BD["@H@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI
M('L*("`@("`@("`D;&]G9V5R+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B92!B
M=69F97)E9"XG*3L*("`@('T*"B`@("`O*B!&;'5S:"!A;&P@;V8@=&AE(&)U
M9F9E<F5D(&QO9R!E=F5N=',N("HO"B`@("`D;&]G9V5R+3YF;'5S:"@I.PH*
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO
M9V=E<BT^;&]G*"=4:&ES(&5V96YT('=I;&P@8F4@8G5F9F5R960N)RD["B`@
M("!]"@H@("`@+RH@26UP;&EC:71L>2!F;'5S:"!T:&4@8G5F9F5R960@979E
M;G1S(&]N(&-L;W-E+B`J+PH@("`@)&QO9V=E<BT^8VQO<V4H*3L*"D%T('1H
M:7,@=&EM92P@=&AE(&!@9FQU<V@H*6!@(&UE=&AO9"!I<R!O;FQY(&EM<&QE
M;65N=&5D(&)Y(&!T:&4@8V]N<V]L90IH86YD;&5R8%\L(&!T:&4@9FEL92!H
M86YD;&5R8%\@86YD(&!T:&4@;6%I;"!H86YD;&5R8%\N"@H*4W1A;F1A<F0@
M3&]G($AA;F1L97)S"CT]/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE($-O;G-O
M;&4@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2TM"E1H92!#;VYS;VQE(&AA
M;F1L97(@;W5T<'5T<R!L;V<@979E;G1S(&1I<F5C=&QY('1O('1H92!C;VYS
M;VQE+B`@270@<W5P<&]R=',*;W5T<'5T(&)U9F9E<FEN9R!A;F0@8V]N9FEG
M=7)A8FQE('-T<FEN9R!F;W)M871S+@H*0V]N9FEG=7)A=&EO;@I^?GY^?GY^
M?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@4&%R
M86UE=&5R("`@("`@("`@?"!4>7!E("`@("`@?"!$969A=6QT("`@("`@('P@
M1&5S8W)I<'1I;VX@("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]
M/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3TK"GP@8&!S=')E86U@8"`@("`@("`@?"!&:6QE("`@
M("`@?"!35$1/551?("`@("`@('P@5&AE(&]U='!U="!S=')E86T@=&\@=7-E
M+B!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!B=69F
M97)I;F=@8"`@("`@?"!";V]L96%N("`@?"!&86QS92`@("`@("`@('P@4VAO
M=6QD('1H92!O=71P=70@8F4@("`@("!\"GP@("`@("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@8G5F9F5R960@=6YT:6P@
M<VAU=&1O=VX_("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&!L:6YE1F]R;6%T8&`@("`@?"!3=')I;F<@("`@?"!@8"4Q)',@)3(D
M<R`@('P@3&]G(&QI;F4@9F]R;6%T("`@("`@("`@("!\"GP@("`@("`@("`@
M("`@("`@("`@?"`@("`@("`@("`@?"!;)3,D<UT@)30D<V!@('P@<W!E8VEF
M:6-A=&EO;BX@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@8&!T:6UE1F]R;6%T8&`@("`@?"!3=')I;F<@("`@?"!@
M8"5B("5D("`@("`@('P@5&EM92!S=&%M<"!F;W)M870@("`@("`@("!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`E2#HE33HE4V!@("`@
M('P@*&9O<B!S=')F=&EM95\I+B`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"@HN+B!?4U1$3U54.B!H='1P.B\O=W=W+G!H
M<"YN970O=W)A<'!E<G,N<&AP"BXN(%]S=')F=&EM93H@:'1T<#HO+W=W=RYP
M:'`N;F5T+W-T<F9T:6UE"@I%>&%M<&QE"GY^?GY^?GX*.CH*"B`@("`D;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=I9&5N="<I
M.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D
M;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@?0H*"E1H92!$:7-P
M;&%Y($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+2TM+0I4:&4@1&ES<&QA>2!H
M86YD;&5R('-I;7!L>2!P<FEN=',@=&AE(&QO9R!E=F5N=',@8F%C:R!T;R!T
M:&4@8G)O=W-E<BX@($ET"G)E<W!E8W1S('1H92!@8&5R<F]R7W!R97!E;F1?
M<W1R:6YG8&`@86YD(&!@97)R;W)?87!P96YD7W-T<FEN9V!@(&!E<G)O<@IH
M86YD;&EN9R!V86QU97-@7R!A;F0@:7,@=7-E9G5L('=H96X@8&QO9V=I;F<@
M9G)O;2!S=&%N9&%R9"!E<G)O<B!H86YD;&5R<V!?+@H*0V]N9FEG=7)A=&EO
M;@I^?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"GP@4&%R86UE=&5R("`@("`@("`@?"!4>7!E("`@("`@?"!$969A=6QT
M("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@("!\"BL]/3T]/3T]
M/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/2L]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!E<G)O<E]P<F5P96YD8&`@
M?"!3=')I;F<@("`@?"!02%`@24Y)('9A;'5E('P@5&AI<R!S=')I;F<@=VEL
M;"!B92`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@
M?"`@("`@("`@("`@("`@('P@<')E<&5N9&5D('1O('1H92!L;V<@("`@("!\
M"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@
M("`@('P@;W5T<'5T+B`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!E<G)O<E]A<'!E;F1@8"`@?"!3
M=')I;F<@("`@?"!02%`@24Y)('9A;'5E('P@5&AI<R!S=')I;F<@=VEL;"!B
M92`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@
M("`@("`@("`@("`@('P@87!P96YD960@=&\@=&AE(&QO9R`@("`@("!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@
M('P@;W5T<'5T+B`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!L:6YE8G)E86M@8"`@("`@?"!3=')I
M;F<@("`@?"!@8#QB<B`O/EQN8&`@('P@5&AI<R!S=')I;F<@:7,@=7-E9"!T
M;R`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@
M("`@("`@("`@('P@<F5P<F5S96YT(&$@;&EN92!B<F5A:RX@("!\"BLM+2TM
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HN+B!?97)R;W(@:&%N9&QI
M;F<@=F%L=65S.B!H='1P.B\O=W=W+G!H<"YN970O97)R;W)F=6YC"@I%>&%M
M<&QE"GY^?GY^?GX*.CH*"B`@("`D8V]N9B`](&%R<F%Y*"=E<G)O<E]P<F5P
M96YD)R`]/B`G/&9O;G0@8V]L;W(](B-F9C`P,#`B/CQT=#XG+`H@("`@("`@
M("`@("`@("`@("`G97)R;W)?87!P96YD)R`@/3X@)SPO='0^/"]F;VYT/B<I
M.PH@("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G9&ES<&QA>2<L("<G
M+"`G)RP@)&-O;F8L(%!%05)?3$]'7T1%0E5'*3L*("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@
M96YT<GD@)&DB*3L*("`@('T*"@I4:&4@17)R;W)?3&]G($AA;F1L97(*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"E1H92!%<G)O<E],;V<@:&%N9&QE<B!S96YD
M<R!L;V<@979E;G1S('1O(%!(4"=S(&!E<G)O<E]L;V<H*6!?(&9U;F-T:6]N
M+@H*0V]N9FEG=7)A=&EO;@I^?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@4&%R86UE=&5R("`@("`@("`@?"!4>7!E
M("`@("`@?"!$969A=6QT("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@
M("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]
M/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!D
M97-T:6YA=&EO;F!@("`@?"!3=')I;F<@("`@?"`G)R!@*&5M<'1Y*6`@('P@
M3W!T:6]N86P@9&5S=&EN871I;VX@=F%L=65\"GP@("`@("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@9F]R(&!E<G)O<E]L
M;V<H*6!?+B`@4V5E("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@
M("`@?"`@("`@("`@("`@("`@('P@8$5R<F]R7TQO9R!4>7!E<V!?(&9O<B`@
M("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@
M("`@("`@('P@;6]R92!D971A:6QS+B`@("`@("`@("`@("!\"BLM+2TM+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!E>'1R85]H96%D97)S8&`@
M?"!3=')I;F<@("`@?"`G)R!@*&5M<'1Y*6`@('P@061D:71I;VYA;"!H96%D
M97)S('1O('!A<W-\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@
M?"`@("`@("`@("`@("`@('P@=&\@=&AE(&!M86EL*"E@7R!F=6YC=&EO;B!\
M"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@
M("`@('P@=VAE;B!T:&4@("`@("`@("`@("`@("`@("!\"GP@("`@("`@("`@
M("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@8&!014%2
M7TQ/1U]465!%7TU!24Q@8"`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@
M("`@("`@("`@?"`@("`@("`@("`@("`@('P@='EP92!I<R!S<&5C:69I960N
M("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@I%
M<G)O<E],;V<@5'EP97,*?GY^?GY^?GY^?GY^?GY^"D%L;"!O9B!T:&4@879A
M:6QA8FQE(&QO9R!T>7!E<R!A<F4@9&5T86EL960@:6X@=&AE(&!E<G)O<E]L
M;V<H*6!?('-E8W1I;VX@;V8*=&AE(%!(4"!M86YU86PN("!&;W(@>6]U<B!C
M;VYV96YI96YC92P@=&AE($QO9R!P86-K86=E(&%L<V\@9&5F:6YE<R!T:&4*
M9F]L;&]W:6YG(&-O;G-T86YT<R!T:&%T(&-A;B!B92!U<V5D(&9O<B!T:&4@
M8&`D;F%M96!@(&AA;F1L97(@8V]N<W1R=6-T:6]N"G!A<F%M971E<BX*"BLM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@0V]N<W1A;G0@("`@
M("`@("`@("`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3TK"GP@8&!014%27TQ/1U]465!%7U-94U1%36!@("!\($QO9R!E=F5N
M=',@87)E('-E;G0@=&\@4$A0)W,@<WES=&5M(&QO9V=E<BP@("!\"GP@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\('=H:6-H('5S97,@=&AE(&]P97)A
M=&EN9R!S>7-T96TG<R!L;V=G:6YG("`@("!\"GP@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(&UE8VAA;FES;2!O<B!A(&9I;&4@*&1E<&5N9&EN9R!O
M;B!T:&4@=F%L=64@("!\"GP@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(&]F('1H92!@97)R;W)?;&]G(&-O;F9I9W5R871I;VX@9&ER96-T:79E8%\I
M+B!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%2
M7TQ/1U]465!%7TU!24Q@8"`@("!\($QO9R!E=F5N=',@87)E('-E;G0@=FEA
M(&5M86EL('1O('1H92!A9&1R97-S("!\"GP@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\('-P96-I9FEE9"!I;B!T:&4@8&!D97-T:6YA=&EO;F!@('9A
M;'5E+B`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&!014%27TQ/1U]465!%7T1%0E5'8&`@("!\($QO9R!E=F5N=',@87)E
M('-E;G0@=&AR;W5G:"!02%`G<R!D96)U9V=I;F<@("!\"GP@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(&-O;FYE8W1I;VXN("!4:&ES('=I;&P@;VYL
M>2!W;W)K(&EF("`@("`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(&!R96UO=&4@9&5B=6=G:6YG8%\@:&%S(&)E96X@96YA8FQE9"X@
M(%1H92`@("!\"GP@("`@("`@("`@("`@("`@("`@("`@("`@("!\(&!@9&5S
M=&EN871I;VY@8"!V86QU92!I<R!U<V5D('1O('-P96-I9GD@=&AE("!\"GP@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(&AO<W0@;F%M92!O<B!)4"!A
M9&1R97-S(&]F('1H92!T87)G970@<V]C:V5T+B!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U]465!%7T9)3$5@8"`@
M("!\($QO9R!E=F5N=',@=VEL;"!B92!A<'!E;F1E9"!T;R!T:&4@9FEL92!N
M86UE9"!\"GP@("`@("`@("`@("`@("`@("`@("`@("`@("!\(&)Y('1H92!@
M8&1E<W1I;F%T:6]N8&`@=F%L=64N("`@("`@("`@("`@("`@("!\"BLM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HN+B!?97)R;W)?;&]G*"DZ
M(&AT='`Z+R]W=W<N<&AP+FYE="]E<G)O<E]L;V<*+BX@7VUA:6PH*3H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VUA:6P*+BX@7V5R<F]R7VQO9R!C;VYF:6=U<F%T
M:6]N(&1I<F5C=&EV93H@:'1T<#HO+W=W=RYP:'`N;F5T+V5R<F]R9G5N8R-I
M;FDN97)R;W(M;&]G"BXN(%]R96UO=&4@9&5B=6=G:6YG.B!H='1P.B\O=W=W
M+G!H<"YN970O:6YS=&%L;"YC;VYF:6=U<F4C:6YS=&%L;"YC;VYF:6=U<F4N
M96YA8FQE+61E8G5G9V5R"@I%>&%M<&QE"GY^?GY^?GX*.CH*"B`@("`D;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=E<G)O<E]L;V<G+"!014%27TQ/1U]4
M65!%7U-94U1%32P@)VED96YT)RD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q
M,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I
M(BD["B`@("!]"@H*5&AE($9I;&4@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM
M"E1H92!&:6QE(&AA;F1L97(@=W)I=&5S(&QO9R!E=F5N=',@=&\@82!T97AT
M(&9I;&4@=7-I;F<@8V]N9FEG=7)A8FQE('-T<FEN9PIF;W)M871S+@H*0V]N
M9FEG=7)A=&EO;@I^?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"GP@4&%R86UE=&5R("`@("`@("`@?"!4>7!E("`@("`@
M?"!$969A=6QT("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@("!\
M"BL]/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]/3T]
M/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!A<'!E;F1@
M8"`@("`@("`@?"!";V]L96%N("`@?"!4<G5E("`@("`@("`@('P@4VAO=6QD
M(&YE=R!L;V<@96YT<FEE<R!B92!\"GP@("`@("`@("`@("`@("`@("`@?"`@
M("`@("`@("`@?"`@("`@("`@("`@("`@('P@87!P96YD('1O(&%N(&5X:7-T
M:6YG(&QO9R!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@
M("`@("`@("`@("`@('P@9FEL92P@;W(@<VAO=6QD('1H92!A(&YE=R!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@
M('P@;&]G(&9I;&4@;W9E<G=R:71E(&%N("`@("!\"GP@("`@("`@("`@("`@
M("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@97AI<W1I;F<@
M;VYE/R`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@8&!L;V-K:6YG8&`@("`@("`@?"!";V]L96%N("`@?"!&86QS
M92`@("`@("`@('P@4VAO=6QD(&%D=FES;W)Y(&9I;&4@("`@("!\"GP@("`@
M("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@
M;&]C:VEN9R`H=7-I;F<@9FQO8VM?*2!B92!\"GP@("`@("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=7-E9#\@("`@("`@
M("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"GP@8&!M;V1E8&`@("`@("`@("`@?"!);G1E9V5R("`@?"`P-C0T("`@
M("`@("`@('P@3V-T86P@<F5P<F5S96YT871I;VX@;V8@("!\"GP@("`@("`@
M("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=&AE
M(&QO9R!F:6QE)W,@<&5R;6ES<VEO;G-\"GP@("`@("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@;6]D92X@("`@("`@("`@
M("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&!D:7)M;V1E8&`@("`@("`@?"!);G1E9V5R("`@?"`P-S4U("`@("`@
M("`@('P@3V-T86P@<F5P<F5S96YT871I;VX@;V8@("!\"GP@("`@("`@("`@
M("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=&AE(&9I
M;&4@<&5R;6ES<VEO;B!M;V1E("!\"GP@("`@("`@("`@("`@("`@("`@?"`@
M("`@("`@("`@?"`@("`@("`@("`@("`@('P@=&AA="!W:6QL(&)E('5S960@
M=VAE;B`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@
M("`@("`@("`@("`@('P@8W)E871I;F<@9&ER96-T;W)I97,@=&AA="!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@
M('P@9&\@;F]T(&%L<F5A9'D@97AI<W0N("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!E;VQ@8"`@("`@("`@("`@?"!3=')I
M;F<@("`@?"!/4R!D969A=6QT("`@('P@5&AE(&5N9"UO;BUL:6YE(&-H87)A
M8W1E<B!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@
M("`@("`@("`@('P@<V5Q=65N8V4N("`@("`@("`@("`@("`@("!\"BLM+2TM
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!L:6YE1F]R;6%T8&`@
M("`@?"!3=')I;F<@("`@?"!@8"4Q)',@)3(D<R`@('P@3&]G(&QI;F4@9F]R
M;6%T("`@("`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@
M("`@?"!;)3,D<UT@)30D<V!@('P@<W!E8VEF:6-A=&EO;BX@("`@("`@("`@
M("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!T:6UE
M1F]R;6%T8&`@("`@?"!3=')I;F<@("`@?"!@8"5B("5D("`@("`@('P@5&EM
M92!S=&%M<"!F;W)M870@("`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"`E2#HE33HE4V!@("`@('P@*&9O<B!S=')F=&EM95\I
M+B`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"@HN+B!?9FQO8VLZ(&AT='`Z+R]W=W<N<&AP+FYE="]F;&]C:PHN+B!?<W1R
M9G1I;64Z(&AT='`Z+R]W=W<N<&AP+FYE="]S=')F=&EM90H*5&AE(&9I;&4@
M:&%N9&QE<B!W:6QL(&]N;'D@871T96UP="!T;R!S970@=&AE(&!@;6]D96!@
M('9A;'5E(&EF(&ET('=A<PIR97-P;VYS:6)L92!F;W(@8W)E871I;F<@=&AE
M(&9I;&4N"@I%>&%M<&QE"GY^?GY^?GX*.CH*"B`@("`D8V]N9B`](&%R<F%Y
M*"=M;V1E)R`]/B`P-C`P+"`G=&EM949O<FUA="<@/3X@)R58("5X)RD["B`@
M("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=F:6QE)RP@)V]U="YL;V<G
M+"`G:61E;G0G+"`D8V]N9BD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@
M)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD[
M"B`@("!]"@H*5&AE($UA:6P@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM"E1H
M92!-86EL(&AA;F1L97(@86=G<F5G871E<R!A('-E<W-I;VXG<R!L;V<@979E
M;G1S(&%N9"!S96YD<R!T:&5M(&EN('1H92!B;V1Y"F]F(&%N(&5M86EL(&UE
M<W-A9V4@=7-I;F<@4$A0)W,@8&UA:6PH*6!?(&9U;F-T:6]N+@H*0V]N9FEG
M=7)A=&EO;@I^?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@4&%R86UE=&5R("`@("`@("`@?"!4>7!E("`@("`@?"!$
M969A=6QT("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@("!\"BL]
M/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]
M/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!F<F]M8&`@("`@
M("`@("`@?"!3=')I;F<@("`@?"!S96YD;6%I;%]F<F]M('P@5F%L=64@9F]R
M('1H92!M97-S86=E)W,@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@
M("`@("`@?"!)3DD@=F%L=64@("`@('P@8&!&<F]M.F!@(&AE861E<BX@("`@
M("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!S
M=6)J96-T8&`@("`@("`@?"!3=')I;F<@("`@?"!@8%M,;V=?;6%I;%T@('P@
M5F%L=64@9F]R('1H92!M97-S86=E)W,@("!\"GP@("`@("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"!,;V<@;65S<V%G96!@('P@8&!3=6)J96-T.F!@
M(&AE861E<BX@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"GP@8&!P<F5A;6)L96!@("`@("`@?"!3=')I;F<@("`@?"!@8"!@*&5M
M<'1Y*6`@('P@4')E86UB;&4@9F]R('1H92!M97-S86=E+B!\"BLM+2TM+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!L:6YE1F]R;6%T8&`@("`@
M?"!3=')I;F<@("`@?"!@8"4Q)',@)3(D<R`@('P@3&]G(&QI;F4@9F]R;6%T
M("`@("`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@
M?"!;)3,D<UT@)30D<V!@('P@<W!E8VEF:6-A=&EO;BX@("`@("`@("`@("!\
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!T:6UE1F]R
M;6%T8&`@("`@?"!3=')I;F<@("`@?"!@8"5B("5D("`@("`@('P@5&EM92!S
M=&%M<"!F;W)M870@("`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@
M("`@("`@("`@?"`E2#HE33HE4V!@("`@('P@*&9O<B!S=')F=&EM95\I+B`@
M("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HN
M+B!?;6%I;"@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%I;`H*17AA;7!L90I^
M?GY^?GY^"CHZ"@H@("`@)&-O;F8@/2!A<G)A>2@G<W5B:F5C="<@/3X@)TEM
M<&]R=&%N="!,;V<@179E;G1S)RD["B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=M86EL)RP@)W=E8FUA<W1E<D!E>&%M<&QE+F-O;2<L("=I9&5N
M="<L("1C;VYF*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2![
M"B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*
M"@I4:&4@341",B!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2T*5&AE($U$0C(@
M:&%N9&QE<B!I<R!S:6UI;&%R('1O(&!T:&4@4U%,("A$0BD@:&%N9&QE<F!?
M+"!B=70@:6YS=&5A9"!O9B!U<VEN9PIT:&4@4$5!4B!$0B!P86-K86=E+"!I
M="!U<V5S('1H92!@341",B!D871A8F%S92!A8G-T<F%C=&EO;B!P86-K86=E
M8%\N"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM+2TM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@("`@("!\(%1Y
M<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@
M("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3TK/3T]
M/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@
M8&1S;F!@("`@("`@("`@("!\($UI>&5D("`@("!\("<G(&`H96UP='DI8"`@
M?"!!(&!$871A(%-O=7)C92!.86UE8%\N("`@('P*?"`@("`@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!\<F5Q=6ER961\
M("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*?"!@8&]P=&EO;G-@8"`@("`@("!\($%R<F%Y("`@("!\(&!@<&5R
M<VES=&5N=&!@?"!!;B!A<G)A>2!O9B!@341",F!?("`@("`@('P*?"`@("`@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!O
M<'1I;VYS+B`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*?"!@8&1B8&`@("`@("`@("`@("!\($]B:F5C="`@
M("!\($Y53$P@("`@("`@("`@?"!!;B!E>&ES=&EN9R!@341",F!?("`@("`@
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@
M("`@("`@?"!O8FIE8W0N("!)9B!S<&5C:69I960L("`@('P*?"`@("`@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!T:&ES
M(&]B:F5C="!W:6QL(&)E('5S960L('P*?"`@("`@("`@("`@("`@("`@("!\
M("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!A;F0@8&!D<VY@8"!W:6QL
M(&)E("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\
M("`@("`@("`@("`@("`@?"!I9VYO<F5D+B`@("`@("`@("`@("`@("`@('P*
M*RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'-E<75E;F-E
M8&`@("`@("!\(%-T<FEN9R`@("!\(&!@;&]G7VED8&`@("`@?"!4:&4@;F%M
M92!O9B!T:&4@<V5Q=65N8V4@('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("`@("`@("`@("`@("`@?"!T;R!U<V4@=VAE;B!G96YE<F%T
M:6YG("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!U;FEQ=64@979E;G0@241S+B`@(%5N9&5R('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!M86YY(&1A=&%B87-E<RP@=&AI<R!W:6QL('P*?"`@("`@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!B92!U<V5D(&%S
M('1H92!N86UE(&]F("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\("`@("`@("`@("`@("`@?"!T:&4@<V5Q=65N8V4@=&%B;&4N("`@
M("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&ED
M96YT3&EM:71@8"`@("!\($EN=&5G97(@("!\(#$V("`@("`@("`@("`@?"!4
M:&4@;6%X:6UU;2!L96YG=&@@;V8@=&AE('P*?"`@("`@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!@8&ED96YT8&`@<W1R
M:6YG+B`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@
M("!\("`@("`@("`@("`@("`@?"`J*D-H86YG:6YG('1H:7,@=F%L=64@;6%Y
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@
M("`@("`@?"!R97%U:7)E('5P9&%T97,@=&\@=&AE(%-13'P*?"`@("`@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!S8VAE
M;6$L(&%S('=E;&PN*BH@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8'-I;F=L971O;F!@("`@("!\($)O;VQE86X@("!\
M(&9A;'-E("`@("`@("`@?"!)<R!T<G5E+"!U<V4@82!S:6YG;&5T;VX@('P*
M?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@
M("`@?"!D871A8F%S92!O8FIE8W0@=7-I;F<@("`@('P*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!@341",CHZ
M<VEN9VQE=&]N*"E@7RX@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*"BXN(%]-1$(R.B!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O341",@HN+B!?341",B!D871A8F%S92!A8G-T<F%C=&EO;B!P86-K86=E
M.B!-1$(R7PHN+B!?341",CHZ<VEN9VQE=&]N*"DZ(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]-1$(R+V1O8W,O;&%T97-T+TU$0C(O341",BYH=&UL
M(VUE=&AO9'-I;F=L971O;@H*5&AE($YU;&P@2&%N9&QE<@HM+2TM+2TM+2TM
M+2TM+2TM"E1H92!.=6QL(&AA;F1L97(@<VEM<&QY(&-O;G-U;65S(&QO9R!E
M=F5N=',@*&%K:6X@=&\@<V5N9&EN9R!T:&5M('1O"F!@+V1E=B]N=6QL8&`I
M+B`@8$QO9R!L979E;"!M87-K<V!?(&%R92!R97-P96-T960L(&%N9"!T:&4@
M979E;G0@=VEL;"!S=&EL;"!B90IS96YT('1O(&%N>2!R96=I<W1E<F5D(&!L
M;V<@;V)S97)V97)S8%\N"@I%>&%M<&QE"GY^?GY^?GX*.CH*"B`@("`D;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=N=6QL)RD["B`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G
M(&5N=')Y("1I(BD["B`@("!]"@H*5&AE(%-13"`H1$(I($AA;F1L97(*+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*"E1H92!344P@:&%N9&QE<B!S96YD<R!L;V<@
M979E;G1S('1O(&$@9&%T86)A<V4@=7-I;F<@8%!%05(G<R!$0B!A8G-T<F%C
M=&EO;@IL87EE<F!?+@H**BI.;W1E.BHJ($1U92!T;R!T:&4@8V]N<W1R86EN
M=',@;V8@=&AE(&1E9F%U;'0@9&%T86)A<V4@<V-H96UA+"!T:&4@4U%,"FAA
M;F1L97(@;&EM:71S('1H92!L96YG=&@@;V8@=&AE(&!@)&ED96YT8&`@<W1R
M:6YG('1O('-I>'1E96X@*#$V*2!C:&%R86-T97)S+@I4:&ES(&QI;6ET(&-A
M;B!B92!A9&IU<W1E9"!U<VEN9R!T:&4@8&!I9&5N=$QI;6ET8&`@8V]N9FEG
M=7)A=&EO;B!P87)A;65T97(N"@I4:&4@3&]G(%1A8FQE"GY^?GY^?GY^?GY^
M?GX*5&AE(&1E9F%U;'0@4U%,('1A8FQE('5S960@8GD@=&AI<R!H86YD;&5R
M(&QO;VMS(&QI:V4@=&AI<SHZ"@H@("`@0U)%051%(%1!0DQ%(&QO9U]T86)L
M92`H"B`@("`@("`@:60@("`@("`@("`@24Y4($Y/5"!.54Q,+`H@("`@("`@
M(&QO9W1I;64@("`@(%1)34535$%-4"!.3U0@3E5,3"P*("`@("`@("!I9&5N
M="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("`@("`@("!P<FEO<FET>2`@
M("!)3E0@3D]4($Y53$PL"B`@("`@("`@;65S<V%G92`@("`@5D%20TA!4B@R
M,#`I+`H@("`@("`@(%!224U!4ED@2T59("AI9"D*("`@("D["@I4:&ES(&ES
M('1H92`B;&]W97-T(&-O;6UO;B!D96YO;6EN871O<B(@=&AA="!S:&]U;&0@
M=V]R:R!A8W)O<W,@86QL(%-13`IC;VUP;&EA;G0@9&%T86)A<V4N("!9;W4@
M;6%Y('=A;G0@=&\@;6%K92!D871A8F%S92T@;W(@<VET92US<&5C:69I8R!C
M:&%N9V5S"G1O('1H:7,@<V-H96UA('1O('-U<'!O<G0@>6]U<B!S<&5C:69I
M8R!N965D<RP@:&]W979E<BX@($9O<B!E>&%M<&QE+`I@4&]S=&=R95-13&!?
M('5S97)S(&UA>2!P<F5F97(@=&\@=7-E(&$@8&!415A48&`@='EP92!F;W(@
M=&AE(&!@;65S<V%G96!@"F9I96QD+@H*+BX@7U!O<W1G<F5344PZ(&AT='`Z
M+R]W=W<N<&]S=&=R97-Q;"YO<F<O"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^
M?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A
M;65T97(@("`@("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$
M97-C<FEP=&EO;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/2L*?"!@8&1S;F!@("`@("`@("`@("!\($UI>&5D("`@
M("!\("<G(&`H96UP='DI8"`@?"!!(&!$871A(%-O=7)C92!.86UE8%\N("`@
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@
M("`@("`@?"!\<F5Q=6ER961\("`@("`@("`@("`@("`@('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'-Q;&!@("`@("`@("`@("!\
M(%-T<FEN9R`@("!\('QS<6PM9&5F875L='P@?"!344P@:6YS97)T:6]N('-T
M871E;65N="X@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M?"!@8&]P=&EO;G-@8"`@("`@("!\($%R<F%Y("`@("!\(&!@<&5R<VES=&5N
M=&!@?"!!;B!A<G)A>2!O9B!@1$)@7R!O<'1I;VYS+GP**RTM+2TM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&1B8&`@("`@("`@("`@("!\($]B
M:F5C="`@("!\($Y53$P@("`@("`@("`@?"!!;B!E>&ES=&EN9R!@1$)@7R!O
M8FIE8W0N('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!)9B!S<&5C:69I960L('1H:7,@;V)J96-T('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!W:6QL(&)E('5S960L(&%N9"!@8&1S;F!@('P*?"`@("`@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!W:6QL(&)E(&EG
M;F]R960N("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*?"!@8'-E<75E;F-E8&`@("`@("!\(%-T<FEN9R`@("!\(&!@;&]G
M7VED8&`@("`@?"!4:&4@;F%M92!O9B!T:&4@<V5Q=65N8V4@('P*?"`@("`@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!T
M;R!U<V4@=VAE;B!G96YE<F%T:6YG("`@('P*?"`@("`@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!U;FEQ=64@979E;G0@
M241S+B`@(%5N9&5R('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@
M("!\("`@("`@("`@("`@("`@?"!M86YY(&1A=&%B87-E<RP@=&AI<R!W:6QL
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@
M("`@("`@?"!B92!U<V5D(&%S('1H92!N86UE(&]F("`@('P*?"`@("`@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!T:&4@
M<V5Q=65N8V4@=&%B;&4N("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8&ED96YT3&EM:71@8"`@("!\($EN=&5G97(@("!\
M(#$V("`@("`@("`@("`@?"!4:&4@;6%X:6UU;2!L96YG=&@@;V8@=&AE('P*
M?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@
M("`@?"!@8&ED96YT8&`@<W1R:6YG+B`@("`@("`@('P*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"`J*D-H86YG
M:6YG('1H:7,@=F%L=64@;6%Y('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("`@("`@("`@("`@("`@?"!R97%U:7)E('5P9&%T97,@=&\@
M=&AE(%-13'P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!S8VAE;6$L(&%S('=E;&PN*BH@("`@("`@('P**RTM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"E1H92!N86UE(&]F('1H
M92!D871A8F%S92!T86)L92!T;R!W:&EC:"!T:&4@;&]G(&5N=')I97,@=VEL
M;"!B92!W<FET=&5N(&ES"G-P96-I9FEE9"!U<VEN9R!T:&4@8&`D;F%M96!@
M(&-O;G-T<G5C=&EO;B!P87)A;65T97(@*'-E92!@0V]N9FEG=7)I;F<@80I(
M86YD;&5R8%\I+@H*+BX@?'-Q;"UD969A=6QT?"!R97!L86-E.CH@8&!)3E-%
M4E0@24Y43R`D=&%B;&4@*&ED+"!L;V=T:6UE+"!I9&5N="P@<')I;W)I='DL
M(&UE<W-A9V4I(%9!3%5%4R@_+"!#55)214Y47U1)34535$%-4"P@/RP@/RP@
M/RE@8`H*+BX@7T1".B!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*
M+BX@7U!%05(G<R!$0B!A8G-T<F%C=&EO;B!L87EE<CH@1$)?"BXN(%]$871A
M(%-O=7)C92!.86UE.B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`*"D5X86UP;&5S"GY^
M?GY^?GY^"E5S:6YG(&$@8$1A=&$@4V]U<F-E($YA;65@7R!T;R!C<F5A=&4@
M82!N97<@9&%T86)A<V4@8V]N;F5C=&EO;CHZ"@H@("`@)&-O;F8@/2!A<G)A
M>2@G9'-N)R`]/B`G<&=S<6PZ+R]J;VY`;&]C86QH;W-T*W5N:7@O;&]G<R<I
M.PH@("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G<W%L)RP@)VQO9U]T
M86)L92<L("=I9&5N="<L("1C;VYF*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@
M)&DB*3L*("`@('T*"E5S:6YG(&%N(&5X:7-T:6YG(&!$0F!?(&]B:F5C=#HZ
M"@H@("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@)&1B(#T@)D1".CIC
M;VYN96-T*"=P9W-Q;#HO+VIO;D!L;V-A;&AO<W0K=6YI>"]L;V=S)RD["@H@
M("`@)&-O;F9;)V1B)UT@/2`D9&(["B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=S<6PG+"`G;&]G7W1A8FQE)RP@)VED96YT)RP@)&-O;F8I.PH@
M("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G
M9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@?0H*"E1H92!3<6QI=&4@
M2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2T*.D%U=&AO<CH@("`@("`@($)E
M<G1R86YD($UA;G-I;VX*.D-O;G1A8W0Z("`@("`@(&)M86YS:6]N0&UA;6%S
M86TN8V]M"@I4:&4@4W%L:71E(&AA;F1L97(@<V5N9',@;&]G(&5V96YT<R!T
M;R!A;B!3<6QI=&4@9&%T86)A<V4@=7-I;F<@=&AE(&!N871I=F4*4$A0('-Q
M;&ET92!F=6YC=&EO;G-@7RX*"DET(&ES(&9A<W1E<B!T:&%N(&!T:&4@4U%,
M("A$0BD@:&%N9&QE<F!?(&)E8V%U<V4@<F5Q=65S=',@87)E(&UA9&4@9&ER
M96-T;'D*=&\@=&AE(&1A=&%B87-E('=I=&AO=70@=7-I;F<@86X@86)S=')A
M8W1I;VX@;&%Y97(N("!)="!I<R!A;'-O(&EN=&5R97-T:6YG('1O"FYO=&4@
M=&AA="!3<6QI=&4@9&%T86)A<V4@9FEL97,@8V%N(&)E(&UO=F5D+"!C;W!I
M960L(&%N9"!D96QE=&5D(&]N('EO=7(*<WES=&5M(&IU<W0@;&EK92!A;GD@
M;W1H97(@9FEL97,L('=H:6-H(&UA:V5S(&QO9R!M86YA9V5M96YT(&5A<VEE
M<BX@($QA<W0@8G5T"FYO="!L96%S="P@=7-I;F<@82!D871A8F%S92!T;R!L
M;V<@>6]U<B!E=F5N=',@86QL;W=S('EO=2!T;R!U<V4@4U%,('%U97)I97,*
M=&\@8W)E871E(')E<&]R=',@86YD('-T871I<W1I8W,N"@I7:&5N('5S:6YG
M(&$@9&%T86)A<V4@86YD(&QO9V=I;F<@82!L;W0@;V8@979E;G1S+"!I="!I
M<R!R96-O;6UE;F1E9"!T;R!S<&QI=`IT:&4@9&%T86)A<V4@:6YT;R!S;6%L
M;&5R(&1A=&%B87-E<RX@(%1H:7,@:7,@86QL;W=E9"!B>2!3<6QI=&4L(&%N
M9"!Y;W4@8V%N"FQA=&5R('5S92!T:&4@4W%L:71E(&!!5%1!0TA@7R!S=&%T
M96UE;G0@=&\@<75E<GD@>6]U<B!L;V<@9&%T86)A<V4@9FEL97,*9VQO8F%L
M;'DN"@I)9B!T:&4@9&%T86)A<V4@9&]E<R!N;W0@97AI<W0@=VAE;B!T:&4@
M;&]G(&ES(&]P96YE9"P@<W%L:71E('=I;&P@=')Y('1O"F-R96%T92!I="!A
M=71O;6%T:6-A;&QY+B!)9B!T:&4@;&]G('1A8FQE(&1O97,@;F]T(&5X:7-T
M+"!I="!W:6QL(&%L<V\@8F4*875T;VUA=&EC86QL>2!C<F5A=&5D+B`@5&AE
M('1A8FQE(&-R96%T:6]N('5S97,@=&AE(&9O;&QO=VEN9R!344P@<F5Q=65S
M=#HZ"@H@("`@0U)%051%(%1!0DQ%(&QO9U]T86)L92`H"B`@("`@("`@:60@
M("`@("`@("`@24Y414=%4B!04DE-05)9($M%62!.3U0@3E5,3"P*("`@("`@
M("!L;V=T:6UE("`@("!.3U0@3E5,3"P*("`@("`@("!I9&5N="`@("`@("!#
M2$%2*#$V*2!.3U0@3E5,3"P*("`@("`@("!P<FEO<FET>2`@("!)3E0@3D]4
M($Y53$PL"B`@("`@("`@;65S<V%G90H@("`@*3L*"D-O;F9I9W5R871I;VX*
M?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L="`@
M("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]
M/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@9FEL96YA;65@8"`@("`@('P@
M4W1R:6YG("`@('P@)R<@8"AE;7!T>2E@("!\(%!A=&@@=&\@86X@4W%L:71E
M("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\(&1A=&%B87-E+B!\<F5Q=6ER961\("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@;6]D96!@("`@
M("`@("`@('P@26YT96=E<B`@('P@,#8V-B`@("`@("`@("!\($]C=&%L(&UO
M9&4@=7-E9"!T;R!O<&5N("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\('1H92!D871A8F%S92X@("`@("`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M<&5R<VES=&5N=&!@("`@('P@0F]O;&5A;B`@('P@9F%L<V4@("`@("`@("!\
M(%5S92!A('!E<G-I<W1E;G0@("`@("`@("`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&-O;FYE8W1I;VXN
M("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PH*06X@86QR96%D>2!O<&5N960@9&%T86)A<V4@8V]N;F5C=&EO;B!C
M86X@86QS;R!B92!P87-S960@87,@<&%R86UE=&5R(&EN<W1E860*;V8@=&AE
M(&%B;W9E(&-O;F9I9W5R871I;VXN("!);B!T:&ES(&-A<V4L(&-L;W-I;F<@
M=&AE(&1A=&%B87-E(&-O;FYE8W1I;VX@:7,*=7`@=&\@=&AE('5S97(N"@HN
M+B!?;F%T:79E(%!(4"!S<6QI=&4@9G5N8W1I;VYS.B!H='1P.B\O=W=W+G!H
M<"YN970O<W%L:71E"BXN(%]!5%1!0T@Z(&AT='`Z+R]W=W<N<W%L:71E+F]R
M9R]L86YG+FAT;6PC871T86-H"@I%>&%M<&QE<PI^?GY^?GY^?@I5<VEN9R!A
M(&-O;F9I9W5R871I;VX@=&\@8W)E871E(&$@;F5W(&1A=&%B87-E(&-O;FYE
M8W1I;VXZ.@H*("`@("1C;VYF(#T@87)R87DH)V9I;&5N86UE)R`]/B`G;&]G
M+F1B)RP@)VUO9&4G(#T^(#`V-C8L("=P97)S:7-T96YT)R`]/B!T<G5E*3L*
M("`@("1L;V=G97(@/28@3&]G.CIF86-T;W)Y*"=S<6QI=&4G+"`G;&]G7W1A
M8FQE)RP@)VED96YT)RP@)&-O;F8I.PH@("`@)&QO9V=E<BT^;&]G*"=L;V=G
M:6YG(&%N(&5V96YT)RP@4$5!4E],3T=?5T%23DE.1RD["@I5<VEN9R!A;B!E
M>&ES=&EN9R!C;VYN96-T:6]N.CH*"B`@("`D9&(@/2!S<6QI=&5?;W!E;B@G
M;&]G+F1B)RP@,#8V-BP@)&5R<F]R*3L*("`@("1L;V=G97(@/28@3&]G.CIF
M86-T;W)Y*"=S<6QI=&4G+"`G;&]G7W1A8FQE)RP@)VED96YT)RP@)&1B*3L*
M("`@("1L;V=G97(M/FQO9R@G;&]G9VEN9R!A;B!E=F5N="<L(%!%05)?3$]'
M7U=!4DY)3D<I.PH@("`@<W%L:71E7V-L;W-E*"1D8BD["@H*5&AE(%-Y<VQO
M9R!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+0I4:&4@4WES;&]G(&AA;F1L
M97(@<V5N9',@;&]G(&5V96YT<R!T;R!T:&4@<WES=&5M(&QO9V=I;F<@<V5R
M=FEC92`H<WES;&]G(&]N"E5N:7@M;&EK92!E;G9I<F]N;65N=',@;W(@=&AE
M($5V96YT($QO9R!O;B!7:6YD;W=S('-Y<W1E;7,I+B`@5&AE(&5V96YT<R!A
M<F4*<V5N="!U<VEN9R!02%`G<R!@<WES;&]G*"E@7R!F=6YC=&EO;BX*"D9A
M8VEL:71I97,*?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PI\($-O;G-T86YT("`@("`@("`@('P@0V%T96=O<GD@1&5S8W)I
M<'1I;VX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK/3T]
M/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@3$]'7T%55$A@8"`@
M("`@('P@4V5C=7)I='D@+R!A=71H;W)I>F%T:6]N(&UE<W-A9V5S.R!@8$Q/
M1U]!551(4%))5F!@(&ES?`I\("`@("`@("`@("`@("`@("`@('P@<')E9F5R
M<F5D(&]N('-Y<W1E;7,@=VAE<F4@:70@:7,@9&5F:6YE9"X@("`@("`@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'
M7T%55$A04DE68&`@('P@4')I=F%T92!S96-U<FET>2`O(&%U=&AO<FEZ871I
M;VX@;65S<V%G97,@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@3$]'7T-23TY@8"`@("`@('P@0VQO8VL@9&%E
M;6]N("A@8&-R;VY@8"!A;F0@8&!A=&!@*2`@("`@("`@("`@("`@("`@("`@
M?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7T1!
M14U/3F!@("`@('P@4WES=&5M(&1A96UO;B!P<F]C97-S97,@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(&!@3$]'7TM%4DY@8"`@("`@('P@2V5R;F5L(&UE<W-A
M9V5S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7TQ/0T%,
M,&!@("XN('P@4F5S97)V960@9F]R(&QO8V%L('5S93L@*BIN;W0J*B!A=F%I
M;&%B;&4@=6YD97(@("`@("`@?`I\(&!@3$]'7TQ/0T%,-V!@("`@('P@5VEN
M9&]W<RX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M3$]'7TQ04F!@("`@("`@('P@4')I;G1E<B!S=6)S>7-T96T@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7TU!24Q@8"`@("`@('P@36%I;"!S
M=6)S>7-T96T@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'
M7TY%5U-@8"`@("`@('P@55-%3D54(&YE=W,@<W5B<WES=&5M("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@3$]'7U-94TQ/1V!@("`@('P@26YT97)N86P@
M<WES;&]G(&UE<W-A9V5S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@3$]'7U53
M15)@8"`@("`@('P@1V5N97)I8R!U<V5R+6QE=F5L(&UE<W-A9V5S("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(&!@3$]'7U550U!@8"`@("`@('P@555#4"!S=6)S>7-T
M96T@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7W-Y<VQO9R@I
M.B!H='1P.B\O=W=W+G!H<"YN970O<WES;&]G"@I%>&%M<&QE"GY^?GY^?GX*
M.CH*"B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=S>7-L;V<G+"!,
M3T=?3$]#04PP+"`G:61E;G0G*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P
M.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB
M*3L*("`@('T*"@I4:&4@5VEN9&]W($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM
M+2TM"E1H92!7:6YD;W<@:&%N9&QE<B!S96YD<R!L;V<@979E;G1S('1O(&$@
M<V5P87)A=&4@8G)O=W-E<B!W:6YD;W<N("!4:&4*;W)I9VEN86P@:61E82!F
M;W(@=&AI<R!H86YD;&5R('=A<R!I;G-P:7)E9"!B>2!#<F%I9R!$879I<R<@
M6F5N9"YC;VT@87)T:6-L90IE;G1I=&QE9"!@(DIA=F%38W)I<'0@4&]W97(@
M4$A0($1E8G5G9VEN9R)@7RX*"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^
M?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E
M<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L="`@("`@("!\($1E<V-R
M:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]
M/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]*PI\(&!@=&ET;&5@8"`@("`@("`@('P@4W1R:6YG("`@('P@
M8&!,;V<@3W5T<'5T("!\(%1H92!T:71L92!O9B!T:&4@;W5T<'5T("`@?`I\
M("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@5VEN9&]W8&`@("`@
M("!\('=I;F1O=RX@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@8V]L;W)S8&`@("`@("`@('P@07)R
M87D@("`@('P@8%)/62!'($))5F!?("!\($UA<'!I;F<@;V8@;&]G('!R:6]R
M:71I97,@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@*&AI
M9V@@=&\@;&]W*2!\('1O(&-O;&]R<RX@("`@("`@("`@("`@("`@?`HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7R)*879A4V-R:7!T
M(%!O=V5R(%!(4"!$96)U9V=I;F<B.B!H='1P.B\O=W=W+GIE;F0N8V]M+WIE
M;F0O='5T+W1U=&]R:6%L+41E8G5G3&EB+G!H<`HN+B!?4D]9($<@0DE6.B!H
M='1P.B\O=W=W+F-I<RYR:70N961U+PH*17AA;7!L90I^?GY^?GY^"CHZ"@H@
M("`@)&-O;F8@/2!A<G)A>2@G=&ET;&4G(#T^("=386UP;&4@3&]G($]U='!U
M="<I.PH@("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G=VEN)RP@)TQO
M9U=I;F1O=R<L("=I9&5N="<L("1C;VYF*3L*("`@(&9O<B`H)&D@/2`P.R`D
M:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT
M<GD@)&DB*3L*("`@('T*"@I#;VUP;W-I=&4@2&%N9&QE<G,*/3T]/3T]/3T]
M/3T]/3T]/3T]"DET(&ES(&]F=&5N('5S969U;"!T;R!L;V<@979E;G1S('1O
M(&UU;'1I<&QE(&AA;F1L97)S+B`@5&AE($QO9R!P86-K86=E"G!R;W9I9&5S
M(&$@8V]M<&]S:71I;F<@<WES=&5M('1H870@;6%R:W,@=&AI<R!T87-K('1R
M:79I86PN"@I3=&%R="!B>2!C<F5A=&EN9R!T:&4@:6YD:79I9'5A;"!L;V<@
M:&%N9&QE<G,Z.@H*("`@("1C;VYS;VQE(#T@)DQO9SHZ<VEN9VQE=&]N*"=C
M;VYS;VQE)RP@)R<L("=415-4)RD["B`@("`D9FEL92`]("9,;V<Z.G-I;F=L
M971O;B@G9FEL92<L("=O=70N;&]G)RP@)U1%4U0G*3L*"E1H96XL(&-O;G-T
M<G5C="!A(&-O;7!O<VET92!H86YD;&5R(&%N9"!A9&0@=&AE(&EN9&EV:61U
M86P@:&%N9&QE<G,@87,*8VAI;&1R96X@;V8@=&AE(&-O;7!O<VET93HZ"@H@
M("`@)&-O;7!O<VET92`]("9,;V<Z.G-I;F=L971O;B@G8V]M<&]S:71E)RD[
M"B`@("`D8V]M<&]S:71E+3YA9&1#:&EL9"@D8V]N<V]L92D["B`@("`D8V]M
M<&]S:71E+3YA9&1#:&EL9"@D9FEL92D["@I4:&4@8V]M<&]S:71E(&AA;F1L
M97(@:6UP;&5M96YT<R!T:&4@<W1A;F1A<F0@8&!,;V=@8"!I;G1E<F9A8V4@
M<V\@>6]U(&-A;B!U<V4*:70@:G5S="!L:6ME(&%N>2!O9B!T:&4@;W1H97(@
M:&%N9&QE<G,Z.@H*("`@("1C;VUP;W-I=&4M/FQO9R@G5&AI<R!E=F5N="!W
M:6QL(&)E(&QO9V=E9"!T;R!B;W1H(&AA;F1L97)S+B<I.PH*0VAI;&1R96X@
M8V%N(&)E(')E;6]V960@9G)O;2!T:&4@8V]M<&]S:71E('=H96X@=&AE>2=R
M92!N;W0@;&]N9V5R(&YE961E9#HZ"@H@("`@)&-O;7!O<VET92T^<F5M;W9E
M0VAI;&0H)&9I;&4I.PH*"DQO9R!/8G-E<G9E<G,*/3T]/3T]/3T]/3T]/0I,
M;V<@;V)S97)V97)S('!R;W9I9&4@86X@:6UP;&5M96YT871I;VX@;V8@=&AE
M(&!O8G-E<G9E<B!P871T97)N8%\N("!);B!T:&4*8V]N=&5N="!O9B!T:&4@
M3&]G('!A8VMA9V4L('1H97D@<')O=FED92!A(&UE8VAA;FES;2!B>2!W:&EC
M:"!Y;W4@8V%N(&5X86UI;F4**&DN92X@;V)S97)V92D@96%C:"!E=F5N="!A
M<R!I="!I<R!L;V=G960N("!4:&ES(&%L;&]W<R!T:&4@:6UP;&5M96YT871I
M;VX@;V8*<W!E8VEA;"!B96AA=FEO<B!B87-E9"!O;B!T:&4@8V]N=&5N=',@
M;V8@82!L;V<@979E;G0N("!&;W(@97AA;7!L92P@=&AE"F]B<V5R=F5R(&-O
M9&4@8V]U;&0@<V5N9"!A;B!A;&5R="!E;6%I;"!I9B!A(&QO9R!E=F5N="!C
M;VYT86EN960@=&AE('-T<FEN9PI@8%!!3DE#8&`N"@I#<F5A=&EN9R!A(&QO
M9R!O8G-E<G9E<B!I;G9O;'9E<R!I;7!L96UE;G1I;F<@82!S=6)C;&%S<R!O
M9B!T:&4*8&!,;V=?;V)S97)V97)@8"!C;&%S<RX@(%1H92!S=6)C;&%S<R!M
M=7-T(&]V97)R:61E('1H92!B87-E(&-L87-S)W,*8&!N;W1I9GDH*6!@(&UE
M=&AO9"X@(%1H:7,@;65T:&]D(&ES('!A<W-E9"!A(&AA<V@@8V]N=&%I;FEN
M9R!T:&4@979E;G0G<PIP<FEO<FET>2!A;F0@979E;G0N("!4:&4@<W5B8VQA
M<W,G<R!I;7!L96UE;G1A=&EO;B!I<R!F<F5E('1O(&%C="!U<&]N('1H:7,*
M:6YF;W)M871I;VX@:6X@86YY('=A>2!I="!L:6ME<RX*"DQO9R!O8G-E<G9E
M<G,@87)E(&%T=&%C:&5D('1O(&!@3&]G8&`@:6YS=&%N8V5S('9I82!T:&4@
M8&!A='1A8V@H*6!@(&UE=&AO9#HZ"@H@("`@)&]B<V5R=F5R(#T@)DQO9U]O
M8G-E<G9E<CHZ9F%C=&]R>2@G>6]U<E1Y<&4G*3L*("`@("1L;V=G97(M/F%T
M=&%C:"@D;V)S97)V97(I.PH*3V)S97)V97)S(&-A;B!B92!D971A8VAE9"!U
M<VEN9R!T:&4@8&!D971A8V@H*6!@(&UE=&AO9#HZ"@H@("`@)&QO9V=E<BT^
M9&5T86-H*"1O8G-E<G9E<BD["@I!="!T:&ES('1I;64L(&YO(&-O;F-R971E
M(&!@3&]G7V]B<V5R=F5R8&`@:6UP;&5M96YT871I;VYS(&%R92!D:7-T<FEB
M=71E9`IW:71H('1H92!,;V<@<&%C:V%G92X*"BXN(%]O8G-E<G9E<B!P871T
M97)N.B!H='1P.B\O<&AP<&%T=&5R;G,N8V]M+VEN9&5X+G!H<"]A<G1I8VQE
M+V%R=&EC;&5V:65W+S(W+S$O,2\*"@I,;V=G:6YG($9R;VT@4W1A;F1A<F0@
M17)R;W(@2&%N9&QE<G,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"@I,;V=G:6YG(%!(4"!%<G)O<G,*+2TM+2TM+2TM+2TM+2TM+2TM
M"E!(4"=S(&1E9F%U;'0@97)R;W(@:&%N9&QE<B!C86X@8F4@;W9E<G)I9&1E
M;B!U<VEN9R!T:&4@8'-E=%]E<G)O<E]H86YD;&5R*"E@7PIF=6YC=&EO;BX@
M(%1H92!C=7-T;VT@97)R;W(@:&%N9&QI;F<@9G5N8W1I;VX@8V%N('5S92!A
M(&=L;V)A;"!,;V<@:6YS=&%N8V4@=&\*;&]G('1H92!02%`@97)R;W)S+@H*
M*BI.;W1E.BHJ($9A=&%L(%!(4"!E<G)O<G,@8V%N;F]T(&)E(&AA;F1L960@
M8GD@82!C=7-T;VT@97)R;W(@:&%N9&QE<B!A="!T:&ES"G1I;64N"@HZ.@H*
M("`@(&9U;F-T:6]N(&5R<F]R2&%N9&QE<B@D8V]D92P@)&UE<W-A9V4L("1F
M:6QE+"`D;&EN92D*("`@('L*("`@("`@("!G;&]B86P@)&QO9V=E<CL*"B`@
M("`@("`@+RH@36%P('1H92!02%`@97)R;W(@=&\@82!,;V<@<')I;W)I='DN
M("HO"B`@("`@("`@<W=I=&-H("@D8V]D92D@>PH@("`@("`@(&-A<V4@15]7
M05).24Y'.@H@("`@("`@(&-A<V4@15]54T527U=!4DY)3D<Z"B`@("`@("`@
M("`@("1P<FEO<FET>2`](%!%05)?3$]'7U=!4DY)3D<["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@(&-A<V4@15].3U1)0T4Z"B`@("`@("`@8V%S92!%
M7U5315)?3D]424-%.@H@("`@("`@("`@("`D<')I;W)I='D@/2!014%27TQ/
M1U].3U1)0T4["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@15]%
M4E)/4CH*("`@("`@("!C87-E($5?55-%4E]%4E)/4CH*("`@("`@("`@("`@
M)'!R:6]R:71Y(#T@4$5!4E],3T=?15)2.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D<')I;W1I='D@/2!014%2
M7TQ/1U])3D9/.PH@("`@("`@('T*"B`@("`@("`@)&QO9V=E<BT^;&]G*"1M
M97-S86=E("X@)R!I;B`G("X@)&9I;&4@+B`G(&%T(&QI;F4@)R`N("1L:6YE
M+`H@("`@("`@("`@("`@("`@("`@("`D<')I;W)I='DI.PH@("`@?0H*("`@
M('-E=%]E<G)O<E]H86YD;&5R*"=E<G)O<DAA;F1L97(G*3L*("`@('1R:6=G
M97)?97)R;W(H)U1H:7,@:7,@86X@:6YF;W)M871I;VX@;&]G(&UE<W-A9V4N
M)RP@15]54T527TY/5$E#12D["@HN+B!?<V5T7V5R<F]R7VAA;F1L97(H*3H@
M:'1T<#HO+W=W=RYP:'`N;F5T+W-E=%]E<G)O<E]H86YD;&5R"@I,;V=G:6YG
M(%!%05(@17)R;W)S"BTM+2TM+2TM+2TM+2TM+2TM+2T*5&AE($QO9R!P86-K
M86=E(&-A;B!B92!U<V5D('=I=&@@8%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M*6!?)W,*8&!014%27T524D]27T-!3$Q"04-+8&`@;65C:&%N:7-M(&)Y('=R
M:71I;F<@86X@97)R;W(@:&%N9&QI;F<@9G5N8W1I;VX@=&AA=`IU<V5S(&$@
M9VQO8F%L($QO9R!I;G-T86YC92X@($AE<F4G<R!A;B!E>&%M<&QE.CH*"B`@
M("!F=6YC=&EO;B!E<G)O<DAA;F1L97(H)&5R<F]R*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D;&]G9V5R.PH*("`@("`@("`D;65S<V%G92`]("1E<G)O<BT^
M9V5T365S<V%G92@I.PH*("`@("`@("!I9B`H(65M<'1Y*"1E<G)O<BT^8F%C
M:W1R86-E6S%=6R=F:6QE)UTI*2!["B`@("`@("`@("`@("1M97-S86=E("X]
M("<@*"<@+B`D97)R;W(M/F)A8VMT<F%C95LQ75LG9FEL92==.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1E<G)O<BT^8F%C:W1R86-E6S%=6R=L:6YE)UTI
M*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`N/2`G(&%T(&QI;F4@)R`N
M("1E<G)O<BT^8F%C:W1R86-E6S%=6R=L:6YE)UT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&UE<W-A9V4@+CT@)RDG.PH@("`@("`@('T*"B`@("`@
M("`@)&QO9V=E<BT^;&]G*"1M97-S86=E+"`D97)R;W(M/F-O9&4I.PH@("`@
M?0H*("`@(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,
M0D%#2RP@)V5R<F]R2&%N9&QE<B<I.PH@("`@4$5!4CHZ<F%I<V5%<G)O<B@G
M5&AI<R!I<R!A;B!I;F9O<FUA=&EO;B!L;V<@;65S<V%G92XG+"!014%27TQ/
M1U])3D9/*3L*"BXN(%]014%2.CIS971%<G)O<DAA;F1L:6YG*"DZ(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<&5A<BYP96%R+G-E=&5R
M<F]R:&%N9&QI;F<N<&AP"@H*0W5S=&]M($AA;F1L97)S"CT]/3T]/3T]/3T]
M/3T]/0I4:&5R92!A<F4@=&EM97,@=VAE;B!T:&4@<W1A;F1A<F0@:&%N9&QE
M<G,@87)E;B=T(&$@<&5R9F5C="!M871C:"!F;W(@>6]U<@IN965D<RX@($EN
M('1H;W-E('-I='5A=&EO;G,L('1H92!S;VQU=&EO;B!M:6=H="!B92!T;R!W
M<FET92!A(&-U<W1O;2!H86YD;&5R+@H*57-I;F<@82!#=7-T;VT@2&%N9&QE
M<@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"E5S:6YG(&$@8W5S=&]M($QO9R!H
M86YD;&5R(&ES('9E<GD@<VEM<&QE+B`@3VYC92!W<FET=&5N("AS964@8%=R
M:71I;F<@3F5W"DAA;F1L97)S8%\@86YD(&!%>'1E;F1I;F<@17AI<W1I;F<@
M2&%N9&QE<G-@7R!B96QO=RDL('EO=2!H879E('1H92!C:&]I8V4@;V8*<&QA
M8VEN9R!T:&4@9FEL92!I;B!Y;W5R(%!%05(@:6YS=&%L;&%T:6]N)W,@;6%I
M;B!@8$QO9R]@8"!D:7)E8W1O<GD@*'5S=6%L;'D*<V]M971H:6YG(&QI:V4@
M8&`O=7-R+VQO8V%L+VQI8B]P:'`O3&]G8&`@;W(@8&!#.EQP:'!<<&5A<EQ,
M;V=@8"DL('=H97)E(&ET"F-A;B!B92!F;W5N9"!A;F0@=7-E(&)Y(&%N>2!0
M2%`@87!P;&EC871I;VX@;VX@=&AE('-Y<W1E;2P@;W(@<&QA8VEN9R!T:&4@
M9FEL90IS;VUE=VAE<F4@:6X@>6]U<B!A<'!L:6-A=&EO;B=S(&QO8V%L(&AI
M97)A<F-H>2!A;F0@:6YC;'5D:6YG(&ET(&)E9F]R92!T:&4*=&AE(&-U<W1O
M;2!,;V<@;V)J96-T(&ES(&-O;G-T<G5C=&5D+@H*365T:&]D(#$Z($AA;F1L
M97(@:6X@=&AE(%-T86YD87)D($QO8V%T:6]N"GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@I!9G1E<B!C;W!Y:6YG('1H92!H
M86YD;&5R(&9I;&4@=&\@>6]U<B!014%2(&EN<W1A;&QA=&EO;B=S(&!@3&]G
M+V!@(&1I<F5C=&]R>2P*<VEM<&QY('1R96%T('1H92!H86YD;&5R(&%S(&EF
M(&ET('=E<F4@<&%R="!O9B!T:&4@<W1A;F1A<F0@9&ES=')I8G5T960N("!)
M9@IY;W5R(&AA;F1L97(@:7,@;F%M960@8&!C=7-T;VU@8"`H86YD('1H97)E
M9F]R92!I;7!L96UE;G1E9"!B>2!A(&-L87-S(&YA;65D"F!@3&]G7V-U<W1O
M;6!@*3HZ"@H@("`@<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B`@("`D;&]G
M9V5R(#T@)DQO9SHZ9F%C=&]R>2@G8W5S=&]M)RP@)R<L("=#55-43TTG*3L*
M"@I-971H;V0@,CH@2&%N9&QE<B!I;B!A($-U<W1O;2!,;V-A=&EO;@I^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@I)9B!Y;W4@<')E
M9F5R('-T;W)I;F<@>6]U<B!H86YD;&5R(&EN('EO=7(@87!P;&EC871I;VXG
M<R!L;V-A;"!H:65R87)C:'DL"GEO=2=L;"!N965D('1O(&EN8VQU9&4@=&AA
M="!F:6QE(&)E9F]R92!Y;W4@8V%N(&-R96%T92!A($QO9R!I;G-T86YC92!B
M87-E9"!O;@II="X*"CHZ"@H@("`@<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*
M("`@(')E<75I<F5?;VYC92`G3&]C86Q(86YD;&5R<R]C=7-T;VTN<&AP)SL*
M"B`@("`D;&]G9V5R(#T@)DQO9SHZ9F%C=&]R>2@G8W5S=&]M)RP@)R<L("=#
M55-43TTG*3L*"@I7<FET:6YG($YE=R!(86YD;&5R<PHM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*5$]$3PH*17AT96YD:6YG($5X:7-T:6YG($AA;F1L97)S"BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5$]$3PH*"BXN('QR97%U:7)E
M9'P@<F5P;&%C93HZ("HJ6W)E<75I<F5D72HJ"@HN+B!V:6TZ('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-"!E>'!A;F1T86(@=&5X='=I
M9'1H/3<X(&9T/7)S=#H*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O1&%T92\`````````````````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`Q-S$U
M,``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]$871E+TQ)0T5.
M4T4`````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U,#<`
M,3`U,34T,S$P-38`,#(P,34V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="!M;V1I9FEC
M871I;VX*+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO
M=VEN9R!C;VYD:71I;VYS(&%R92!M970Z"@HQ+B!2961I<W1R:6)U=&EO;G,@
M;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L('1H"B`@(&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H*,BX@4F5D:7-T<FEB=71I;VYS(&EN
M(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG
M:'0@;F]T:6-E+`H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N(&%N
M9"\*("`@;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BX*"C,N(%1H92!N86UE(&]F('1H92!A=71H;W(@;6%Y(&YO
M="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I
M=F5D"B`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R
M:6]R('=R:71T96X@<&5R;6ES<VEO;BX*"E1(25,@4T]&5%=!4D4@25,@4%)/
M5DE$140@0ED@5$A%($%55$A/4B!@8$%3($E3)R<@04Y$($%.62!%6%!215-3
M($]2($E-4$Q)140@5T$*4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,
M24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3`I)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@"D%55$A/
M4B!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.
M5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($,*3TY315%514Y424%,($1!
M34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%
M345.5"!/1B!354)35$E4551%(`I'3T]$4R!/4B!315)624-%4SL@3$]34R!/
M1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E50
M5$E/3BD@2$]7"D5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)
M04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$D*
M5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE3
M12D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@50I312!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+T1A=&4O5$]$3P``````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#,W,@`Q,#4Q-30S,3`U-@`P,3<V,S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2!&:7@@
M;VYC92!T:&4@=&EM97IO;F4@<')O8FQE;0H*+2!/;F-E(%1:('=O<FMS(&YI
M8V5L>2P@=7!D871E('1H92!T97-T=6YI=%]D871E(&%N9"!U<V4*("!T:&4@
M<F5A;"!T:6UE>F]N92!A;F0@9&-T('1O(&-H96-K('1H92!E>'!E8W1E9"!T
M:6UE(&]F9G-E=`H*+2!#;&5A;B!T:&4@=&5S="!C87-E<R!A;F0@871O;6EC
M(&1I<W!L87D@:6YS=&5A9"!O9B!A(&=L;V)A;"!O:R!O<B!F86EL960*"BT@
M=W)I=&4@=&AE(&1O8W,N+BXN"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R].971?55),+P``````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-38`,#$W-30S`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]54DPO9&]C<R\`````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-@`P,C`T
M-S,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U523"]D
M;V-S+V5X86UP;&4N<&AP````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,S8T
M`#$P-3$U-#,Q,#4V`#`R,C8T-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,L(%)I8VAA
M<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V
M:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@
M87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C
M92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\
M"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES
M=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@
M86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E
M<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@"B\O('P@
M;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O
M(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P*+R\@?"`@('!R;V1U8W1S(&1E
M<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!42$E3(%-/
M1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!
M3D0@0T].5%))0E543U)3("`@?`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!2
M15-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4
M("`@("!\"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%
M4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!
M(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%
M3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`HO+R!\($]73D52($]2($-/3E12
M24)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)
M3D-)1$5.5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY3
M15%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P*
M+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/
M3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`HO+R!\($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!\"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@
M5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]2
M5"`@('P*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?`HO+R!\($]&
M(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"
M24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9"!A="!P:'`@;F5T
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@)$ED.B!E>&%M<&QE+G!H<"QV(#$N.2`R
M,#`T+S`U+S`X(#$W.C0X.C`X(')I8VAA<F0@17AP("0*+RHJ"BH@5&AI<R!E
M>&%M<&QE('=I;&P@9&5C;V1E('1H92!U<FP@9VEV96X@86YD(&1I<W!L87D@
M:71S"BH@8V]N<W1I='5E;G0@<&%R=',N"BHO"@HO+PEI;F-L=61E*"<N+B]5
M4DPN<&AP)RD["@EI;F-L=61E*"=.970O55),+G!H<"<I.PH*"2\O)'5R;"`]
M("9N97<@3F5T7U523"@G:'1T<',Z+R]W=W<N97AA;7!L92YC;VTO9F]O+V)A
M<B]I;F1E>"YP:'`_9F]O/6)A<B<I.PH))'5R;"`](&YE=R!.971?55),*"=H
M='1P<SHO+V5X86UP;&4N8V]M+W!L<R]P;W)T86PS,"]03U)404PS,"YW=W!O
M8E]P86=E+F-H86YG971A8G,_<%]B86-K7W5R;#UH='1P)3-!)3)&)3)&97AA
M;7!L92YC;VTE,D9S97)V;&5T)3)&<&%G924S1E]P86=E:60E,T0S-C`E,D,S
M-C8E,D,S-C@E,D,S.#(E,C9?9&%D)3-$<&]R=&%L,S`E,C9?<V-H96UA)3-$
M4$]25$%,,S`F9F]O/6)A<B<I.PH_/@H\:'1M;#X*/&)O9'D^"@H\<')E/@I0
M<F]T;V-O;"XN+CH@/#\])'5R;"T^<')O=&]C;VP_/@H*57-E<FYA;64N+BXZ
M(#P_/21U<FPM/G5S97(_/@H*4&%S<W=O<F0N+BXZ(#P_/21U<FPM/G!A<W,_
M/@H*4V5R=F5R+BXN+BXZ(#P_/21U<FPM/FAO<W0_/@H*4&]R="XN+BXN+BXZ
M(#P_/21U<FPM/G!O<G0_/@H*1FEL92]P871H+BXZ(#P_/21U<FPM/G!A=&@_
M/@H*475E<GES=')I;F<Z(#P_<')I;G1?<B@D=7)L+3YQ=65R>7-T<FEN9RD_
M/@H*06YC:&]R+BXN+BXZ(#P_/21U<FPM/F%N8VAO<C\^"@H*1G5L;"!54DPN
M+BXZ(#P_/21U<FPM/F=E=%5R;"@I/SX*/"]P<F4^"@H\+V)O9'D^"CPO:'1M
M;#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T%R8VAI=F5?
M5&%R+P``````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`U-@`P,C`T-C(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O07)C:&EV95]487(O9&]C<R\`````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,30Q,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]!<F-H:79E7U1A<B]D;V-S+T%R
M8VAI=F5?5&%R+G1X=```````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#0V,3``,3`U,34T,S$P
M-38`,#(T,S0T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$1O8W5M96YT871I;VX@9F]R(&-L87-S($%R8VAI=F5?5&%R#0H]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0T*3&%S="!U<&1A
M=&4@.B`R,#`Q+3`X+3$U#0H-"@T*#0I/=F5R=FEE=R`Z#0HM+2TM+2TM+2TM
M#0H-"B`@5&AE($%R8VAI=F5?5&%R(&-L87-S(&AE;'!S(&EN(&-R96%T:6YG
M(&%N9"!M86YA9VEN9R!'3E4@5$%2(&9O<FUA=`T*("!F:6QE<R!C;VUP<F5S
M<V5D(&)Y($=.52!:25`@;W(@;F]T+B`-"B`@5&AE(&-L87-S(&]F9F5R<R!B
M87-I8R!F=6YC=&EO;G,@;&EK92!C<F5A=&EN9R!A;B!A<F-H:79E+"!A9&1I
M;F<-"B`@9FEL97,@:6X@=&AE(&%R8VAI=F4L(&5X=')A8W1I;F<@9FEL97,@
M9G)O;2!T:&4@87)C:&EV92!A;F0@;&ES=&EN9PT*("!T:&4@87)C:&EV92!C
M;VYT96YT+B`-"B`@270@86QS;R!P<F]V:61E(&%D=F%N8V5D(&9U;F-T:6]N
M<R!T:&%T(&%L;&]W('1H92!A9&1I;F<@86YD#0H@(&5X=')A8W1I;VX@;V8@
M9FEL97,@=VET:"!P871H(&UA;FEP=6QA=&EO;BX@#0H-"@T*4V%M<&QE(#H-
M"BTM+2TM+2TM#0H-"B`@+R\@+2TM+2T@0W)E871I;F<@=&AE(&]B:F5C="`H
M=6YC;VUP<F5S<V5D(&%R8VAI=F4I#0H@("1T87)?;V)J96-T(#T@;F5W($%R
M8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B:F5C="T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L-"@T*("`O+R`M+2TM
M+2!#<F5A=&EN9R!T:&4@87)C:&EV90T*("`D=E]L:7-T6S!=/2)F:6QE+G1X
M="([#0H@("1V7VQI<W1;,5T](F1A=&$O(CL-"B`@)'9?;&ES=%LR73TB9FEL
M92YL;V<B.PT*("`D=&%R7V]B:F5C="T^8W)E871E*"1V7VQI<W0I.PT*#0H@
M("\O("TM+2TM($%D9&EN9R!F:6QE<PT*("`D=E]L:7-T6S!=/2)D978O9FEL
M92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D978O9&%T82\B.PT*("`D=E]L:7-T
M6S)=/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^861D*"1V7VQI
M<W0I.PT*#0H@("\O("TM+2TM($%D9&EN9R!M;W)E(&9I;&5S#0H@("1T87)?
M;V)J96-T+3YA9&0H(G)E;&5A<V4O;F5W9FEL92YL;V<@<F5L96%S92]R96%D
M;64N='AT(BD[#0H-"B`@+R\@+2TM+2T@3&ES=&EN9R!T:&4@8V]N=&5N=`T*
M("!I9B`H*"1V7VQI<W0@(#T@("1T87)?;V)J96-T+3YL:7-T0V]N=&5N="@I
M*2`A/2`P*0T*("`@(&9O<B`H)&D],#L@)&D\<VEZ96]F*"1V7VQI<W0I.R`D
M:2LK*0T*("`@('L-"B`@("`@(&5C:&\@(D9I;&5N86UE(#HG(BXD=E]L:7-T
M6R1I75MF:6QE;F%M95TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N<VEZ92`Z
M)R(N)'9?;&ES=%LD:5U;<VEZ95TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N
M;71I;64@.B<B+B1V7VQI<W1;)&E=6VUT:6UE72XB)R`H(BYD871E*")L(&13
M(&]F($8@62!H.FDZ<R!!(BP@)'9?;&ES=%LD:5U;;71I;65=*2XB*3QB<CXB
M.PT*("`@("`@96-H;R`B("YM;V1E(#HG(BXD=E]L:7-T6R1I75MM;V1E72XB
M)SQB<CXB.PT*("`@("`@96-H;R`B("YU:60@.B<B+B1V7VQI<W1;)&E=6W5I
M9%TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N9VED(#HG(BXD=E]L:7-T6R1I
M75MG:61=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G1Y<&5F;&%G(#HG(BXD
M=E]L:7-T6R1I75MT>7!E9FQA9UTN(B<\8G(^(CL-"B`@("!]#0H-"B`@+R\@
M+2TM+2T@17AT<F%C=&EN9R!T:&4@87)C:&EV92!I;B!D:7)E8W1O<GD@(FEN
M<W1A;&PB#0H@("1T87)?;V)J96-T+3YE>'1R86-T*")I;G-T86QL(BD[#0H-
M"@T*4'5B;&EC(&%R9W5M96YT<R`Z#0HM+2TM+2TM+2TM+2TM+2TM+2T-"@T*
M3F]N90T*#0H-"E!U8FQI8R!-971H;V1S(#H-"BTM+2TM+2TM+2TM+2TM+2T-
M"@T*365T:&]D(#H@07)C:&EV95]487(H)'!?=&%R;F%M92P@)&-O;7!R97-S
M(#T@;G5L;"D-"D1E<V-R:7!T:6]N(#H-"B`@07)C:&EV95]487(@0VQA<W,@
M8V]N<W1R=6-T;W(N(%1H:7,@9FQA=F]U<B!O9B!T:&4@8V]N<W1R=6-T;W(@
M;VYL>0T*("!D96-L87)E(&$@;F5W($%R8VAI=F5?5&%R(&]B:F5C="P@:61E
M;G1I9GEI;F<@:70@8GD@=&AE(&YA;64@;V8@=&AE#0H@('1A<B!F:6QE+@T*
M("!)9B!T:&4@8V]M<')E<W,@87)G=6UE;G0@:7,@<V5T('1H92!T87(@=VEL
M;"!B92!R96%D(&]R(&-R96%T960@87,@80T*("!G>FEP(&]R(&)Z,B!C;VUP
M<F5S<V5D(%1!4B!F:6QE+B`-"D%R9W5M96YT<R`Z#0H@("1P7W1A<FYA;64@
M.B!!('9A;&ED(&9I;&5N86UE(&9O<B!T:&4@=&%R(&%R8VAI=F4@9FEL92X-
M"B`@)'!?8V]M<')E<W,@.B!C86X@8F4@;G5L;"P@)V=Z)R!O<B`G8GHR)RX@
M1F]R#0H@("`@("`@("`@("`@("`@8V]M<&%T:6)I;&ET>2!R96%S;VX@:70@
M8V%N(&%L<V\@8F4@=')U92X@5&AI<PT*("`@("`@("`@("`@("`@('!A<F%M
M971E<B!I;F1I8V%T97,@:68@9WII<"!O<B!B>C(@8V]M<')E<W-I;VX-"B`@
M("`@("`@("`@("`@("!I<R!R97%U:7)E9"X@#0I2971U<FX@=F%L=64@.@T*
M("!4:&4@07)C:&EV95]487(@;V)J96-T+@T*4V%M<&QE(#H-"B`@)'1A<E]O
M8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T
M87)?;V)J96-T7V-O;7!R97-S960@/2!N97<@07)C:&EV95]487(H(G1A<FYA
M;64N=&=Z(BP@=')U92D[#0I(;W<@:70@=V]R:W,@.@T*("!);FET:6%L:7IE
M('1H92!O8FIE8W0N#0H-"DUE=&AO9"`Z(&-R96%T92@D<%]F:6QE;&ES="D-
M"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@8W)E871E<R!T:&4@87)C
M:&EV92!F:6QE(&%N9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T;W)I97,-"B`@
M=&AA="!A<F4@;&ES=&5D(&EN("1P7V9I;&5L:7-T+B`-"B`@268@=&AE(&9I
M;&4@86QR96%D>2!E>&ES=',@86YD(&ES('=R:71A8FQE+"!I="!I<R!R97!L
M86-E9"!B>2!T:&4-"B`@;F5W('1A<BX@270@:7,@82!C<F5A=&4@86YD(&YO
M="!A;B!A9&0N($EF('1H92!F:6QE(&5X:7-T<R!A;F0@:7,-"B`@<F5A9"UO
M;FQY(&]R(&ES(&$@9&ER96-T;W)Y(&ET(&ES(&YO="!R97!L86-E9"X@5&AE
M(&UE=&AO9"!R971U<FX-"B`@9F%L<V4@86YD(&$@4$5!4B!E<G)O<B!T97AT
M+B`-"B`@5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C86X@8F4@86X@87)R
M87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("!R97!R97-E;G1I;F<@82!F
M:6QE;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE('=I=&@@=&AE:7(@<&%T:"!I
M9@T*("!N965D960N($ET(&-A;B!A;'-O(&)E(&$@<VEN9VQE('-T<FEN9R!W
M:71H(&YA;65S('-E<&%R871E9"!B>2!A#0H@('-I;F=L92!B;&%N:RX@#0H@
M(%-E92!A;'-O(&-R96%T94UO9&EF>2@I(&UE=&AO9"!F;W(@;6]R92!D971A
M:6QS+@T*07)G=6UE;G1S(#H-"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A>2!O
M9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-
M"B`@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L
M86YK('-P86-E+B`-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1T87)?;V)J96-T
M(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B
M:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L@("\O
M($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V7VQI<W1;,%T](F9I;&4N
M='AT(CL-"B`@)'9?;&ES=%LQ73TB9&%T82\B.R`H3W!T:6]N86P@)R\G(&%T
M('1H92!E;F0I#0H@("1V7VQI<W1;,ET](F9I;&4N;&]G(CL-"B`@)'1A<E]O
M8FIE8W0M/F-R96%T92@D=E]L:7-T*3L-"E-A;7!L92`R(#H-"B`@)'1A<E]O
M8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T
M87)?;V)J96-T+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0I
M.R`@+R\@3W!T:6]N86P@97)R;W(@:&%N9&QI;F<-"B`@)'1A<E]O8FIE8W0M
M/F-R96%T92@B9FEL92YT>'0@9&%T82\@9FEL92YL;V<B*3L-"DAO=R!I="!W
M;W)K<R`Z#0H@($IU<W0@8V%L;&EN9R!T:&4@8W)E871E36]D:69Y*"D@;65T
M:&]D('=I=&@@=&AE(')I9VAT('!A<F%M971E<G,N#0H-"DUE=&AO9"`Z(&-R
M96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP@)'!?<F5M;W9E
M7V1I<B`]("(B*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!C<F5A
M=&5S('1H92!A<F-H:79E(&9I;&4@86YD(&%D9"!T:&4@9FEL97,@+R!D:7)E
M8W1O<FEE<PT*("!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N(`T*
M("!)9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&%B;&4L
M(&ET(&ES(')E<&QA8V5D(&)Y('1H90T*("!N97<@=&%R+B!)="!I<R!A(&-R
M96%T92!A;F0@;F]T(&%N(&%D9"X@268@=&AE(&9I;&4@97AI<W1S(&%N9"!I
M<PT*("!R96%D+6]N;'D@;W(@:7,@82!D:7)E8W1O<GD@:70@:7,@;F]T(')E
M<&QA8V5D+B!4:&4@;65T:&]D(')E='5R;@T*("!F86QS92!A;F0@82!014%2
M(&5R<F]R('1E>'0N(`T*("!4:&4@)'!?9FEL96QI<W0@<&%R86UE=&5R(&-A
M;B!B92!A;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG#0H@(')E<')E
M<V5N=&EN9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@=VET:"!T
M:&5I<B!P871H(&EF#0H@(&YE961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG
M;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@<VEN9VQE
M(&)L86YK+B`-"B`@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7W)E;6]V95]D
M:7(@=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE#0H@(&UE;6]R:7IE9"!P871H
M(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R>2!L:7-T960@=VAE;B!T:&ES('!A
M=&@-"B`@97AI<W1S+B!">2!D969A=6QT(&YO=&AI;F<@:7,@<F5M;W9E9"`H
M96UP='D@<&%T:"`B(BD@#0H@(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]A
M9&1?9&ER('=I;&P@8F4@861D960@870@=&AE(&)E9VEN;FEN9R!O9@T*("!T
M:&4@;65M;W)I>F5D('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI
M<W1E9"X@2&]W979E<B!I="!C86X-"B`@8F4@<V5T('1O(&5M<'1Y("(B+B!4
M:&4@861D:6YG(&]F(&$@<&%T:"!I<R!D;VYE(&%F=&5R('1H92!R96UO=FEN
M9PT*("!O9B!P871H+B`-"B`@5&AE('!A=&@@861D+W)E;6]V92!A8FEL:71Y
M(&5N86)L97,@=&AE('5S97(@=&\@<')E<&%R92!A;B!A<F-H:79E#0H@(&9O
M<B!E>'1R86-T:6]N(&EN(&$@9&EF9F5R96YT('!A=&@@=&AA;B!T:&4@;W)I
M9VEN(&9I;&5S(&%R92X@#0H@(%-E92!A;'-O(&%D9$UO9&EF>2@I(&UE=&AO
M9"!F;W(@9FEL92!A9&1I;F<@<')O<&5R=&EE<RX-"D%R9W5M96YT<R`Z#0H@
M("1P7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E
M8W1O<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@("`@("`@("`@("`@("`@<W1R
M:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L86YK('-P
M86-E+@T*("`D<%]A9&1?9&ER(#H@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@
M82!P871H('1O(&)E(&%D9&5D('1O('1H90T*("`@("`@("`@("`@("`@;65M
M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H92!L:7-T+B`-"B`@
M)'!?<F5M;W9E7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T
M:"!T;R!B92!R96UO=F5D(&9R;VT-"B`@("`@("`@("`@("`@("`@('1H92!M
M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE(&QI<W0L('=H
M96X-"@D)("!R96QE=F%N="X-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1T87)?
M;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D
M=&%R7V]B:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4
M*3L@("\O($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V7VQI<W1;,%T]
M(F9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&%T82\B.R`H3W!T:6]N86P@
M)R\G(&%T('1H92!E;F0I#0H@("1V7VQI<W1;,ET](F9I;&4N;&]G(CL-"B`@
M)'1A<E]O8FIE8W0M/F-R96%T94UO9&EF>2@D=E]L:7-T+"`B:6YS=&%L;"(I
M.PT*("`O+R!F:6QE<R!A<F4@<W1O<F5D(&EN('1H92!A<F-H:79E(&%S(#H-
M"B`@+R\@("!I;G-T86QL+V9I;&4N='AT#0H@("\O("`@:6YS=&%L;"]D871A
M#0H@("\O("`@:6YS=&%L;"]D871A+V9I;&4Q+G1X=`T*("`O+R`@(&EN<W1A
M;&PO9&%T82\N+BX@86QL('1H92!F:6QE<R!A;F0@<W5B+61I<G,@;V8@9&%T
M82\-"B`@+R\@("!I;G-T86QL+V9I;&4N;&]G#0I386UP;&4@,B`Z#0H@("1T
M87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*
M("`D=&%R7V]B:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!2
M24Y4*3L@("\O($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V7VQI<W1;
M,%T](F1E=B]F:6QE+G1X="([#0H@("1V7VQI<W1;,5T](F1E=B]D871A+R([
M("A/<'1I;VYA;"`G+R<@870@=&AE(&5N9"D-"B`@)'9?;&ES=%LR73TB;&]G
M+V9I;&4N;&]G(CL-"B`@)'1A<E]O8FIE8W0M/F-R96%T94UO9&EF>2@D=E]L
M:7-T+"`B:6YS=&%L;"(L(")D978B*3L-"B`@+R\@9FEL97,@87)E('-T;W)E
M9"!I;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O("`@:6YS=&%L;"]F:6QE+G1X
M=`T*("`O+R`@(&EN<W1A;&PO9&%T80T*("`O+R`@(&EN<W1A;&PO9&%T82]F
M:6QE,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$O+BXN(&%L;"!T:&4@9FEL
M97,@86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@("\O("`@:6YS=&%L;"]L;V<O
M9FEL92YL;V<-"DAO=R!I="!W;W)K<R`Z#0H@($]P96X@=&AE(&9I;&4@:6X@
M=W)I=&4@;6]D92`H97)A<VEN9R!T:&4@97AI<W1I;F<@;VYE(&EF(&]N92DL
M#0H@(&-A;&P@=&AE(%]A9&1,:7-T*"D@;65T:&]D(&9O<B!A9&1I;F<@=&AE
M(&9I;&5S(&EN(&%N(&5M<'1Y(&%R8VAI=F4L#0H@(&%D9"!T:&4@=&%R(&9O
M;W1E<B`H-3$R(&)Y=&5S(&)L;V-K*2P@8VQO<V4@=&AE('1A<B!F:6QE+@T*
M#0H-"DUE=&AO9"`Z(&%D9$UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I
M<BP@)'!?<F5M;W9E7V1I<CTB(BD-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M
M971H;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S(&QI<W1E9"!I;B`D
M<%]F:6QE;&ES="!A="!T:&4-"B`@96YD(&]F('1H92!E>&ES=&EN9R!A<F-H
M:79E+B!)9B!T:&4@87)C:&EV92!D;V5S(&YO="!Y970@97AI<W1S(&ET#0H@
M(&ES(&-R96%T960N#0H@(%1H92`D<%]F:6QE;&ES="!P87)A;65T97(@8V%N
M(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I;F<-"B`@<F5P<F5S
M96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M92!W:71H('1H
M96ER('!A=&@@:68-"B`@;F5E9&5D+B!)="!C86X@86QS;R!B92!A('-I;F=L
M92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@80T*("!S:6YG;&4@
M8FQA;FLN(`T*("!4:&4@<&%T:"!I;F1I8V%T960@:6X@)'!?<F5M;W9E7V1I
M<B!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4-"B`@;65M;W)I>F5D('!A=&@@
M;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"!W:&5N('1H:7,@<&%T
M:`T*("!E>&ES=',N($)Y(&1E9F%U;'0@;F]T:&EN9R!I<R!R96UO=F5D("AE
M;7!T>2!P871H("(B*2`-"B`@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7V%D
M9%]D:7(@=VEL;"!B92!A9&1E9"!A="!T:&4@8F5G:6YN:6YG(&]F#0H@('1H
M92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O<GD@;&ES
M=&5D+B!(;W=E=F5R(&ET(&-A;@T*("!B92!S970@=&\@96UP='D@(B(N(%1H
M92!A9&1I;F<@;V8@82!P871H(&ES(&1O;F4@869T97(@=&AE(')E;6]V:6YG
M#0H@(&]F('!A=&@N(`T*("!4:&4@<&%T:"!A9&0O<F5M;W9E(&%B:6QI='D@
M96YA8FQE<R!T:&4@=7-E<B!T;R!P<F5P87)E(&%N(&%R8VAI=F4-"B`@9F]R
M(&5X=')A8W1I;VX@:6X@82!D:69F97)E;G0@<&%T:"!T:&%N('1H92!O<FEG
M:6X@9FEL97,@87)E+B`-"B`@268@82!F:6QE+V1I<B!I<R!A;')E861Y(&EN
M('1H92!A<F-H:79E(&ET('=I;&P@;VYL>2!B92!A9&1E9"!A="!T:&4-"B`@
M96YD(&]F('1H92!A<F-H:79E+B!4:&5R92!I<R!N;R!U<&1A=&4@;V8@=&AE
M(&5X:7-T:6YG(&%R8VAI=F5D#0H@(&9I;&4O9&ER+B!(;W=E=F5R('=H:6QE
M(&5X=')A8W1I;F<@=&AE(&%R8VAI=F4L('1H92!L87-T(&9I;&4@=VEL;`T*
M("!R97!L86-E('1H92!F:7)S="!O;F4N(%1H:7,@<F5S=6QT<R!I;B!A(&YO
M;F4@;W!T:6UI>F%T:6]N(&]F('1H90T*("!A<F-H:79E('-I>F4N(`T*("!)
M9B!A(&9I;&4O9&ER(&1O97,@;F]T(&5X:7-T('1H92!F:6QE+V1I<B!I<R!I
M9VYO<F5D+B!(;W=E=F5R(&%N#0H@(&5R<F]R('1E>'0@:7,@<V5N9"!T;R!0
M14%2(&5R<F]R+B`-"B`@268@82!F:6QE+V1I<B!I<R!N;W0@<F5A9&%B;&4@
M=&AE(&9I;&4O9&ER(&ES(&EG;F]R960N($AO=V5V97(@86X-"B`@97)R;W(@
M=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N(`T*("!)9B!T:&4@<F5S=6QT
M:6YG(&9I;&5N86UE+V1I<FYA;64@*&%F=&5R('1H92!A9&0O<F5M;W9E(&]P
M=&EO;B!O<@T*("!N;W0I('-T<FEN9R!I<R!G<F5A=&5R('1H86X@.3D@8VAA
M<BP@=&AE(&9I;&4O9&ER(&ES#0H@(&EG;F]R960N($AO=V5V97(@86X@97)R
M;W(@=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N(`T*07)G=6UE;G1S(#H-
M"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I
M<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-"B`@("`@("`@("`@("`@("!S
M=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@82!S:6YG;&4@8FQA;FL@
M<W!A8V4N(`T*("`D<%]A9&1?9&ER(#H@02!S=')I;F<@=VAI8V@@8V]N=&%I
M;G,@82!P871H('1O(&)E(&%D9&5D('1O('1H90T*("`@("`@("`@("`@("`@
M;65M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H92!L:7-T+B`-
M"B`@)'!?<F5M;W9E7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@
M<&%T:"!T;R!B92!R96UO=F5D(&9R;VT-"B`@("`@("`@("`@("`@("`@('1H
M92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE(&QI<W0L
M('=H96X-"@D)("!R96QE=F%N="X-"E)E='5R;B!V86QU92`Z#0H@('1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1T
M87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*
M("!;+BXN70T*("`D=E]L:7-T6S!=/2)D978O9FEL92YT>'0B.PT*("`D=E]L
M:7-T6S%=/2)D978O9&%T82\B.R`H3W!T:6]N86P@)R\G(&%T('1H92!E;F0I
M#0H@("1V7VQI<W1;,ET](FQO9R]F:6QE+FQO9R([#0H@("1T87)?;V)J96-T
M+3YA9&1-;V1I9GDH)'9?;&ES="P@(FEN<W1A;&PB*3L-"B`@+R\@9FEL97,@
M87)E('-T;W)E9"!I;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O("`@:6YS=&%L
M;"]F:6QE+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T80T*("`O+R`@(&EN<W1A
M;&PO9&%T82]F:6QE,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$O+BXN(&%L
M;"!T:&4@9FEL97,@86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@("\O("`@:6YS
M=&%L;"]F:6QE+FQO9PT*4V%M<&QE(#(@.@T*("`D=&%R7V]B:F5C="`](&YE
M=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@6RXN+ET-"B`@)'9?
M;&ES=%LP73TB9&5V+V9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A
M=&$O(CL@*$]P=&EO;F%L("<O)R!A="!T:&4@96YD*0T*("`D=E]L:7-T6S)=
M/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^861D36]D:69Y*"1V
M7VQI<W0L(")I;G-T86QL(BP@(F1E=B(I.PT*("`O+R!F:6QE<R!A<F4@<W1O
M<F5D(&EN('1H92!A<F-H:79E(&%S(#H-"B`@+R\@("!I;G-T86QL+V9I;&4N
M='AT#0H@("\O("`@:6YS=&%L;"]D871A#0H@("\O("`@:6YS=&%L;"]D871A
M+V9I;&4Q+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T82\N+BX@86QL('1H92!F
M:6QE<R!A;F0@<W5B+61I<G,@;V8@9&%T82\-"B`@+R\@("!I;G-T86QL+VQO
M9R]F:6QE+FQO9PT*2&]W(&ET('=O<FMS(#H-"B`@268@=&AE(&%R8VAI=F4@
M9&]E<R!N;W0@97AI<W1S(&ET(&-R96%T92!I="!A;F0@861D('1H92!F:6QE
M<RX-"B`@268@=&AE(&%R8VAI=F4@9&]E<R!E>&ES=',@86YD(&ES(&YO="!C
M;VUP<F5S<V5D+"!I="!O<&5N(&ET+"!J=6UP#0H@(&)E9F]R92!T:&4@;&%S
M="!E;7!T>2`U,3(@8GET97,@8FQO8VL@*'1A<B!F;V]T97(I(&%N9"!A9&0@
M=&AE(&9I;&5S#0H@(&%T('1H:7,@<&]I;G0N#0H@($EF('1H92!A<F-H:79E
M(&1O97,@97AI<W1S(&%N9"!I<R!C;VUP<F5S<V5D+"!A('1E;7!O<F%R>2!C
M;W!Y(&9I;&4-"B`@:7,@8W)E871E9"X@5&AI<R!T96UP;W)A<GD@9FEL92!I
M<R!T:&5N("=G>FEP)R!R96%D(&)L;V-K(&)Y(&)L;V-K#0H@('5N=&EL('1H
M92!L87-T(&5M<'1Y(&)L;V-K+B!4:&4@;F5W(&9I;&5S(&%R92!T:&5N(&%D
M9&5D(&EN('1H90T*("!C;VUP<F5S<V5D(&9I;&4N#0H@(%1H92!A9&1I;F<@
M;V8@9FEL97,@:7,@9&]N92!B>2!G;VEN9R!T:')O=6=H('1H92!F:6QE+V1I
M<B!L:7-T+`T*("!A9&1I;F<@9FEL97,@<&5R(&9I;&5S+"!I;B!A(')E8W5R
M<VEV92!W87D@=&AR;W5G:"!T:&4-"B`@9&ER96-T;W)Y+B!%86-H('1I;64@
M82!P871H(&YE960@=&\@8F4@861D960O<F5M;W9E9"!I="!I<R!D;VYE#0H@
M(&)E9F]R92!W<FET:6YG('1H92!F:6QE(&AE861E<B!I;B!T:&4@87)C:&EV
M92X-"@T*365T:&]D(#H@861D*"1P7V9I;&5L:7-T*0T*1&5S8W)I<'1I;VX@
M.@T*("!4:&ES(&UE=&AO9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T;W)I97,@
M;&ES=&5D(&EN("1P7V9I;&5L:7-T(&%T('1H90T*("!E;F0@;V8@=&AE(&5X
M:7-T:6YG(&%R8VAI=F4N($EF('1H92!A<F-H:79E(&1O97,@;F]T('EE="!E
M>&ES=',@:70-"B`@:7,@8W)E871E9"X@#0H@(%1H92`D<%]F:6QE;&ES="!P
M87)A;65T97(@8V%N(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I
M;F<-"B`@<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@
M;F%M92!W:71H('1H96ER('!A=&@@:68-"B`@;F5E9&5D+B!)="!C86X@86QS
M;R!B92!A('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@
M80T*("!S:6YG;&4@8FQA;FLN(`T*("!3964@861D36]D:69Y*"D@;65T:&]D
M(&9O<B!D971A:6QS(&%N9"!L:6UI=&%T:6]N<RX-"D%R9W5M96YT<R`Z#0H@
M("1P7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E
M8W1O<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@('-T<FEN9R!W:71H(&YA;65S
M('-E<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S<&%C92X@#0I2971U<FX@
M=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*
M4V%M<&QE(#$@.@T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B
M=&%R;F%M92YT87(B*3L-"B`@6RXN+ET-"B`@)'9?;&ES=%LP73TB9&5V+V9I
M;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A=&$O(CL@*$]P=&EO;F%L
M("<O)R!A="!T:&4@96YD*0T*("`D=E]L:7-T6S)=/2)L;V<O9FEL92YL;V<B
M.PT*("`D=&%R7V]B:F5C="T^861D*"1V7VQI<W0I.PT*4V%M<&QE(#(@.@T*
M("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT9WHB
M+"!T<G5E*3L-"B`@6RXN+ET-"B`@)'9?;&ES=%LP73TB9&5V+V9I;&4N='AT
M(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A=&$O(CL@*$]P=&EO;F%L("<O)R!A
M="!T:&4@96YD*0T*("`D=E]L:7-T6S)=/2)L;V<O9FEL92YL;V<B.PT*("`D
M=&%R7V]B:F5C="T^861D*"1V7VQI<W0I.PT*2&]W(&ET('=O<FMS(#H-"B`@
M4VEM<&QY(&-A;&P@=&AE(&%D9$UO9&EF>2@I(&UE=&AO9"!W:71H('1H92!R
M:6=H="!P87)A;65T97)S+@T*#0I-971H;V0@.B!A9&13=')I;F<H)'!?9FEL
M96YA;64L("1P7W-T<FEN9RD-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H
M;V0@861D(&$@<VEN9VQE('-T<FEN9R!A<R!A(&9I;&4@870@=&AE#0H@(&5N
M9"!O9B!T:&4@97AI<W1I;F<@87)C:&EV92X@268@=&AE(&%R8VAI=F4@9&]E
M<R!N;W0@>65T(&5X:7-T<R!I=`T*("!I<R!C<F5A=&5D+@T*07)G=6UE;G1S
M(#H-"B`@)'!?9FEL96YA;64@.B!!('-T<FEN9R!W:&EC:"!C;VYT86EN<R!T
M:&4@9G5L;"!F:6QE;F%M92!P871H#0H@("`@("`@("`@("`@("`@=&AA="!W
M:6QL(&)E(&%S<V]C:6%T960@=VET:"!T:&4@<W1R:6YG+@T*("`D<%]S=')I
M;F<@.B`@(%1H92!C;VYT96YT(&]F('1H92!F:6QE(&%D9&5D(&EN('1H92!A
M<F-H:79E+@T*4F5T=7)N('9A;'5E(#H-"B`@=')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!E<G)O<BX-"E-A;7!L92`Q(#H-"B`@)'9?87)C:&EV92`]("8@
M;F5W($%R8VAI=F5?5&%R*"1P7V9I;&5N86UE*3L-"B`@)'9?87)C:&EV92T^
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L-"B`@)'9?<F5S
M=6QT(#T@)'9?87)C:&EV92T^861D4W1R:6YG*"=D871A+W1E<W0N='AT)RP@
M)U1H:7,@:7,@=&AE('1E>'0@;V8@=&AE('-T<FEN9R<I.PT*#0H-"DUE=&AO
M9"`Z(&5X=')A8W0H)'!?<&%T:"`]("(B*0T*1&5S8W)I<'1I;VX@.@T*("!4
M:&ES(&UE=&AO9"!E>'1R86-T(&%L;"!T:&4@8V]N=&5N="!O9B!T:&4@87)C
M:&EV92!I;B!T:&4@9&ER96-T;W)Y#0H@(&EN9&EC871E9"!B>2`D<%]P871H
M+DEF("1P7W!A=&@@:7,@;W!T:6]N86PL(&EF(&YO="!S970@=&AE(&%R8VAI
M=F4-"B`@:7,@97AT<F%C=&5D(&EN('1H92!C=7)R96YT(&1I<F5C=&]R>2X@
M#0H@(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!T:&4@9&ER96-T;W)Y
M('!A=&@@9&]E<R!N;W0@97AI<W1S(&ET(&ES#0H@(&-R96%T960N(`T*("!3
M964@97AT<F%C=$UO9&EF>2@I(&9O<B!D971A:6QS(&%N9"!L:6UI=&%T:6]N
M<RX-"D%R9W5M96YT<R`Z#0H@("1P7W!A=&@@.B!/<'1I;VYA;"!P871H('=H
M97)E('1H92!F:6QE<R]D:7(@;F5E9"!T;R!B>2!E>'1R86-T960N#0I2971U
M<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R
M+@T*4V%M<&QE(#H-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H
M(G1A<FYA;64N=&%R(BD[#0H@("1T87)?;V)J96-T+3YE>'1R86-T*"D[#0I(
M;W<@:70@=V]R:W,@.@T*("!3:6UP;'D@8V%L;"!T:&4@97AT<F%C=$UO9&EF
M>2@I(&UE=&AO9"!W:71H(&%P<')O<')I871E('!A<F%M971E<G,N#0H-"DUE
M=&AO9"`Z(&5X=')A8W1-;V1I9GDH)'!?<&%T:"P@)'!?<F5M;W9E7W!A=&@I
M#0I$97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&5X=')A8W0@86QL('1H
M92!C;VYT96YT(&]F('1H92!A<F-H:79E(&EN('1H92!D:7)E8W1O<GD-"B`@
M:6YD:6-A=&5D(&)Y("1P7W!A=&@N(%=H96X@<F5L979A;G0@=&AE(&UE;6]R
M:7IE9"!P871H(&]F('1H90T*("!F:6QE<R]D:7(@8V%N(&)E(&UO9&EF:65D
M(&)Y(')E;6]V:6YG('1H92`D<%]R96UO=F5?<&%T:"!P871H(&%T('1H90T*
M("!B96=I;FYI;F<@;V8@=&AE(&9I;&4O9&ER('!A=&@N(`T*("!7:&EL92!E
M>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&1I<F5C=&]R>2!P871H(&1O97,@
M;F]T(&5X:7-T<R!I="!I<PT*("!C<F5A=&5D+B`-"B`@5VAI;&4@97AT<F%C
M=&EN9R!A(&9I;&4L(&EF('1H92!F:6QE(&%L<F5A9'D@97AI<W1S(&ET(&ES
M(')E<&QA8V5D#0H@('=I=&AO=70@;&]O:VEN9R!F;W(@;&%S="!M;V1I9FEC
M871I;VX@9&%T92X@#0H@(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!T
M:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&4-"B`@<')O=&5C
M=&5D+"!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+B`-"B`@5VAI;&4@97AT
M<F%C=&EN9R!A(&9I;&4L(&EF(&$@9&ER96-T;W)Y('=I=&@@=&AE('-A;64@
M;F%M92!A;')E861Y#0H@(&5X:7-T<RP@=&AE(&5X=')A8W1I;VX@:7,@86)O
M<G1E9"X@#0H@(%=H:6QE(&5X=')A8W1I;F<@82!D:7)E8W1O<GDL(&EF(&$@
M9FEL92!W:71H('1H92!S86UE(&YA;64@86QR96%D>0T*("!E>&ES=',L('1H
M92!E>'1R86-T:6]N(&ES(&%B;W)T960N(`T*("!7:&EL92!E>'1R86-T:6YG
M(&$@9FEL92]D:7)E8W1O<GD@:68@=&AE(&1E<W1I;F%T:6]N(&1I<F5C=&]R
M>2!E>&ES=`T*("!A;F0@:7,@=W)I=&4@<')O=&5C=&5D+"!O<B!D;V5S(&YO
M="!E>&ES="!B=70@8V%N(&YO="!B92!C<F5A=&5D+`T*("!T:&4@97AT<F%C
M=&EO;B!I<R!A8F]R=&5D+B`-"B`@268@869T97(@97AT<F%C=&EO;B!A;B!E
M>'1R86-T960@9FEL92!D;V5S(&YO="!S:&]W('1H92!C;W)R96-T#0H@('-T
M;W)E9"!F:6QE('-I>F4L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N(`T*
M("!7:&5N('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960L(&$@4$5!4B!E<G)O
M<B!T97AT(&ES('-E="!A;F0@9F%L<V4-"B`@:7,@<F5T=7)N960N($AO=V5V
M97(@=&AE(')E<W5L="!C86X@8F4@82!P87)T:6%L(&5X=')A8W1I;VX@=&AA
M="!M87D-"B`@;F5E9"!T;R!B92!M86YU86QL>2!C;&5A;F5D+B`-"D%R9W5M
M96YT<R`Z#0H@("1P7W!A=&@@.B!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y
M('=H97)E('1H92!F:6QE<R]D:7(@;F5E9"!T;R!B>0T*("`@("`@("`@("`@
M97AT<F%C=&5D+B`-"B`@)'!?<F5M;W9E7W!A=&@@.B!087)T(&]F('1H92!M
M96UO<FEZ960@<&%T:"!T:&%T(&-A;B!B92!R96UO=F5D(&EF#0H@("`@("`@
M("`@("`@("`@("`@<')E<V5N="!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE+V1I<B!P871H+B`-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@.@T*("`O+R!);6%G:6YE
M('1A<FYA;64N=&%R('=I=&@@9FEL97,@.@T*("`O+R`@(&1E=B]D871A+V9I
M;&4N='AT#0H@("\O("`@9&5V+V1A=&$O;&]G+G1X=`T*("`O+R`@(')E861M
M92YT>'0-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA
M;64N=&%R(BD[#0H@("1T87)?;V)J96-T+3YE>'1R86-T36]D:69Y*")I;G-T
M86QL(BP@(F1E=B(I.PT*("`O+R!&:6QE<R!W:6QL(&)E(&5X=')A8W1E9"!T
M:&5R92`Z#0H@("\O("`@:6YS=&%L;"]D871A+V9I;&4N='AT#0H@("\O("`@
M:6YS=&%L;"]D871A+VQO9RYT>'0-"B`@+R\@("!I;G-T86QL+W)E861M92YT
M>'0-"DAO=R!I="!W;W)K<R`Z#0H@($]P96X@=&AE(&%R8VAI=F4@86YD(&-A
M;&P@82!M;W)E(&=E;F5R:6,@9G5N8W1I;VX@=&AA="!C86X@97AT<F%C=`T*
M("!O;FQY(&$@<&%R="!O9B!T:&4@87)C:&EV92!O<B!A;&P@=&AE(&%R8VAI
M=F4N(`T*("!3964@97AT<F%C=$QI<W0H*2!M971H;V0@9F]R(&UO<F4@9&5T
M86EL<RX-"@T*365T:&]D(#H@97AT<F%C=$EN4W1R:6YG*"1P7V9I;&5N86UE
M*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!E>'1R86-T(&9R;VT@
M=&AE(&%R8VAI=F4@;VYE(&9I;&4@:61E;G1I9FEE9"!B>2`D<%]F:6QE;F%M
M92X-"B`@5&AE(')E='5R;B!V86QU92!I<R!A('-T<FEN9R!W:71H('1H92!F
M:6QE(&-O;G1E;G0L(&]R($Y53$P@;VX@97)R;W(N(`T*07)G=6UE;G1S(#H-
M"B`@)'!?9FEL96YA;64@.B!4:&4@<&%T:"!O9B!T:&4@9FEL92!T;R!E>'1R
M86-T(&EN(&$@<W1R:6YG+B`-"E)E='5R;B!V86QU92`Z#0H@(&$@<W1R:6YG
M('=I=&@@=&AE(&9I;&4@8V]N=&5N="!O<B!.54Q,+@T*4V%M<&QE(#H-"B`@
M+R\@26UA9VEN92!T87)N86UE+G1A<B!W:71H(&9I;&5S(#H-"B`@+R\@("!D
M978O9&%T82]F:6QE+G1X=`T*("`O+R`@(&1E=B]D871A+VQO9RYT>'0-"B`@
M+R\@("!D978O<F5A9&UE+G1X=`T*("`D=E]A<F-H:79E(#T@)B!N97<@07)C
M:&EV95]487(H)W1A<FYA;64N=&%R)RD[#0H@("1V7V%R8VAI=F4M/G-E=$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[#0H@("1V7W-T<FEN9R`]
M("1V7V%R8VAI=F4M/F5X=')A8W1);E-T<FEN9R@G9&5V+W)E861M92YT>'0G
M*3L-"B`@96-H;R`D=E]S=')I;F<[#0H-"DUE=&AO9"`Z(&QI<W1#;VYT96YT
M*"D-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@<F5T=7)N<R!A;B!A
M<G)A>2!O9B!A<G)A>7,@=&AA="!D97-C<FEB92!E86-H#0H@(&9I;&4O9&ER
M96-T;W)Y('!R97-E;G0@:6X@=&AE(&%R8VAI=F4N(`T*("!4:&4@87)R87D@
M:7,@;F]T('-O<G1E9"P@<V\@:70@<VAO=R!T:&4@<&]S:71I;VX@;V8@=&AE
M(&9I;&4@:6X@=&AE#0H@(&%R8VAI=F4N(`T*("!4:&4@9FEL92!I;F9O<FUA
M=&EO;G,@87)E(#H-"B`@("`D9FEL95MF:6QE;F%M95T@.B!.86UE(&%N9"!P
M871H(&]F('1H92!F:6QE+V1I<BX-"B`@("`D9FEL95MM;V1E72`Z($9I;&4@
M<&5R;6ES<VEO;G,@*')E<W5L="!O9B!F:6QE<&5R;7,H*2D-"B`@("`D9FEL
M95MU:61=(#H@=7-E<B!I9`T*("`@("1F:6QE6V=I9%T@.B!G<F]U<"!I9`T*
M("`@("1F:6QE6W-I>F5=(#H@9FEL97-I>F4-"B`@("`D9FEL95MM=&EM95T@
M.B!,87-T(&UO9&EF:6-A=&EO;B!T:6UE("AR97-U;'0@;V8@9FEL96UT:6UE
M*"DI#0H@("`@)&9I;&5;='EP969L86==(#H@(B(@9F]R(&9I;&4L("(U(B!F
M;W(@9&ER96-T;W)Y#0I!<F=U;65N=',@.@T*4F5T=7)N('9A;'5E(#H-"B`@
M06X@87)R87D@;V8@87)R87ES(&]R(#`@;VX@97)R;W(N#0I386UP;&4@.@T*
M("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B
M*3L-"B`@:68@*"@D=E]L:7-T("`]("`D=&%R7V]B:F5C="T^;&ES=$-O;G1E
M;G0H*2D@(3T@,"D-"B`@("!F;W(@*"1I/3`[("1I/'-I>F5O9B@D=E]L:7-T
M*3L@)&DK*RD-"B`@("![#0H@("`@("!E8VAO(")&:6QE;F%M92`Z)R(N)'9?
M;&ES=%LD:5U;9FEL96YA;65=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G-I
M>F4@.B<B+B1V7VQI<W1;)&E=6W-I>F5=+B(G/&)R/B([#0H@("`@("!E8VAO
M("(@+FUT:6UE(#HG(BXD=E]L:7-T6R1I75MM=&EM95TN(B<@*"(N#0H@("`@
M("`@("`@(&1A=&4H(FP@9%,@;V8@1B!9(&@Z:3IS($$B+"`D=E]L:7-T6R1I
M75MM=&EM95TI+B(I/&)R/B([#0H@("`@("!E8VAO("(@+FUO9&4@.B<B+B1V
M7VQI<W1;)&E=6VUO9&5=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G5I9"`Z
M)R(N)'9?;&ES=%LD:5U;=6ED72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YG
M:60@.B<B+B1V7VQI<W1;)&E=6V=I9%TN(B<\8G(^(CL-"B`@("`@(&5C:&\@
M(B`N='EP969L86<@.B<B+B1V7VQI<W1;)&E=6W1Y<&5F;&%G72XB)SQB<CXB
M.PT*("`@('T-"DAO=R!I="!W;W)K<R`Z#0H@($-A;&P@=&AE('-A;64@9G5N
M8W1I;VX@87,@86X@97AT<F%C="!H;W=E=F5R('=I=&@@82!F;&%G('1O(&]N
M;'D@9V\-"B`@=&AR;W5G:"!T:&4@87)C:&EV92!W:71H;W5T(&5X=')A8W1I
M;F<@=&AE(&9I;&5S+B`-"@T*365T:&]D(#H@97AT<F%C=$QI<W0H)'!?9FEL
M96QI<W0L("1P7W!A=&@@/2`B(BP@)'!?<F5M;W9E7W!A=&@@/2`B(BD-"D1E
M<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@97AT<F%C="!F<F]M('1H92!A
M<F-H:79E(&]N;'D@=&AE(&9I;&5S(&EN9&EC871E9"!I;B!T:&4-"B`@)'!?
M9FEL96QI<W0N(%1H97-E(&9I;&5S(&%R92!E>'1R86-T960@:6X@=&AE(&-U
M<G)E;G0@9&ER96-T;W)Y(&]R#0H@(&EN('1H92!D:7)E8W1O<GD@:6YD:6-A
M=&5D(&)Y('1H92!O<'1I;VYA;"`D<%]P871H('!A<F%M971E<BX@#0H@($EF
M(&EN9&EC871E9"!T:&4@)'!?<F5M;W9E7W!A=&@@8V%N(&)E('5S960@:6X@
M=&AE('-A;64@=V%Y(&%S(&ET(&ES#0H@('5S960@:6X@97AT<F%C=$UO9&EF
M>2@I(&UE=&AO9"X@#0I!<F=U;65N=',@.@T*("`D<%]F:6QE;&ES="`Z($%N
M(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@9&ER96-T;W)Y(&YA;65S+"!O<B!A
M('-I;F=L90T*("`@("`@("`@("`@("`@('-T<FEN9R!W:71H(&YA;65S('-E
M<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S<&%C92X@#0H@("1P7W!A=&@@
M.B!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('=H97)E('1H92!F:6QE<R]D
M:7(@;F5E9"!T;R!B>0T*("`@("`@("`@("`@97AT<F%C=&5D+B`-"B`@)'!?
M<F5M;W9E7W!A=&@@.B!087)T(&]F('1H92!M96UO<FEZ960@<&%T:"!T:&%T
M(&-A;B!B92!R96UO=F5D(&EF#0H@("`@("`@("`@("`@("`@("`@<')E<V5N
M="!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE+V1I<B!P871H+B`-"E)E
M='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R
M;W(N#0I386UP;&4@.@T*("`O+R!);6%G:6YE('1A<FYA;64N=&%R('=I=&@@
M9FEL97,@.@T*("`O+R`@(&1E=B]D871A+V9I;&4N='AT#0H@("\O("`@9&5V
M+V1A=&$O;&]G+G1X=`T*("`O+R`@(')E861M92YT>'0-"B`@)'1A<E]O8FIE
M8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T87)?
M;V)J96-T+3YE>'1R86-T3&ES="@B9&5V+V1A=&$O9FEL92YT>'0@<F5A9&UE
M+G1X="(L(")I;G-T86QL(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(")D978B*3L-"B`@+R\@1FEL97,@=VEL;"!B92!E>'1R86-T960@=&AE<F4@
M.@T*("`O+R`@(&EN<W1A;&PO9&%T82]F:6QE+G1X=`T*("`O+R`@(&EN<W1A
M;&PO<F5A9&UE+G1X=`T*2&]W(&ET('=O<FMS(#H-"B`@1V\@=&AR;W5G:"!T
M:&4@87)C:&EV92!A;F0@97AT<F%C="!O;FQY('1H92!F:6QE<R!P<F5S96YT
M(&EN('1H90T*("!L:7-T+B`-"@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4V5R
M=FEC97-?5V5A=&AE<B\`````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#4V`#`R,34S-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+P``````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(S,S4T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H
M97(O97AA;7!L97,O;65T87(M8F%S:6,N<&AP````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S`U,P`Q,#4Q
M-30S,3`U-@`P,C8R-34`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA
M<FME<CH@*B\*"B\J*@H@*B!"87-I8R!E>&%M<&QE(&9O<B!T:&4@345405(O
M5$%&+7-E<G9I8V4*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@
M/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I
M<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J(`H@*B!2961I<W1R:6)U
M=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H
M(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R
M;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M
M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@
M<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@
M<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A;F0O;W(@;W1H97(@
M;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@
M;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R92!N;W(@=&AE(&YA
M;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@8F4@=7-E9"!T;R!E
M;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@
M<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@
M<&5R;6ES<VEO;BX*("H@"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@
M0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3
M($E3(@H@*B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453
M+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%"B`J($E-4$Q)
M140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@
M1D]2($$@4$%25$E#54Q!4B!055)03U-%"B`J($%212!$25-#3$%)345$+B!)
M3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4($]73D52($]2($-/3E12
M24)55$]24R!"10H@*B!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4
M+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%
M455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@
M5$\L(%!23T-54D5-14Y4($]&"B`J(%-50E-425155$4@1T]/1%,@3U(@4T52
M5DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)
M3D534PH@*B!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!
M3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3@H@*B!#3TY44D%#
M5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)
M1T5.0T4@3U(@3U1(15)725-%*0H@*B!!4DE324Y'($E.($%.62!705D@3U54
M($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$
M($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H@/"],
M24-%3E-%/@H@*B`*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`
M<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@
M06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z
M+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP
M("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z(&UE=&%R
M+6)A<VEC+G!H<"QV(#$N,3$@,C`P-2\Q,2\P."`Q-SHU,CHT,B!E<G4@17AP
M("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]397)V:6-E<U]796%T:&5R"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER
M95]O;F-E(")397)V:6-E<R]796%T:&5R+G!H<"(["@HO+R!/8FIE8W0@:6YI
M=&EA;&EZ871I;VX@+2!E<G)O<B!C:&5C:VEN9R!I<R!I;7!O<G1A;G0L(&)E
M8V%U<V4@;V8*+R\@:&%N9&QI;F<@97AC97!T:6]N<R!S=6-H(&%S(&UI<W-I
M;F<@4$5!4B!M;V1U;&5S"B1M971A<B`]("9397)V:6-E<U]796%T:&5R.CIS
M97)V:6-E*")-151!4B(L(&%R<F%Y*")D96)U9R(@/3X@,"DI.PII9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;65T87(I*2!["B`@("!D:64H(D5R
M<F]R.B`B+B1M971A<BT^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO+R!3970@
M<&%R86UE=&5R<R!F;W(@1$(@86-C97-S+"!N965D960@9F]R(&QO8V%T:6]N
M('-E87)C:&5S"B1M971A<BT^<V5T365T87)$0B@B<W%L:71E.B\O;&]C86QH
M;W-T+R]U<W(O;&]C86PO;&EB+W!H<"]D871A+U-E<G9I8V5S7U=E871H97(O
M<V5R=FEC97-796%T:&5R1$(B*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES
M17)R;W(H)&UE=&%R*2D@>PH@("`@96-H;R`B17)R;W(Z("(N)&UE=&%R+3YG
M971-97-S86=E*"DN(EQN(CL*?0H*+RH@17)A<V4@8V]M;65N=',@=&\@96YA
M8FQE(&-A8VAI;F<*)'-T871U<R`]("1M971A<BT^<V5T0V%C:&4H(F9I;&4B
M+"!A<G)A>2@B8V%C:&5?9&ER(B`]/B`B+W1M<"]C86-H92\B*2D["FEF("A3
M97)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO
M(")%<G)O<CH@(BXD<W1A='5S+3YG971-97-S86=E*"DN(EQN(CL*?0HJ+PH*
M)&UE=&%R+3YS9715;FET<T9O<FUA="@B8W5S=&]M(BP@87)R87DH"B`@("`B
M=VEN9"(@("`]/B`B:W0B+`H@("`@(G9I<R(@("`@/3X@(FMM(BP*("`@(")H
M96EG:'0B(#T^(")F="(L"B`@("`B=&5M<"(@("`]/B`B8R(L"B`@("`B<')E
M<R(@("`]/B`B:'!A(BP*("`@(")R86EN(B`@(#T^(")I;B(I*3L*)&UE=&%R
M+3YS971$871E5&EM949O<FUA="@B9"YM+EDB+"`B2#II(BD["@HO+R!&:7)S
M="!G970@8V]D92!F;W(@;&]C871I;VX*)'-E87)C:"`]("1M971A<BT^<V5A
M<F-H3&]C871I;VXH(D)O;FXL($=E<FUA;GDB*3L*:68@*%-E<G9I8V5S7U=E
M871H97(Z.FES17)R;W(H)'-E87)C:"DI('L*("`@(&1I92@B17)R;W(Z("(N
M)'-E87)C:"T^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO+R!.;W<@:71E<F%T
M92!T:')O=6=H(&%V86EL86)L92!F=6YC=&EO;G,@9F]R(')E=')I979I;F<@
M9&%T80IF;W)E86-H("AA<G)A>2@B9V5T3&]C871I;VXB+"`B9V5T5V5A=&AE
M<B(L(")G971&;W)E8V%S="(I(&%S("1F=6YC=&EO;BD@>PH@("`@)&1A=&$@
M/2`D;65T87(M/B1F=6YC=&EO;B@D<V5A<F-H*3L*("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1D871A*2D@>PH@("`@("`@(&5C:&\@(D5R
M<F]R.B`B+B1D871A+3YG971-97-S86=E*"DN(EQN(CL*("`@("`@("!C;VYT
M:6YU93L*("`@('T*"B`@("!V87)?9'5M<"@D9&%T82D["GT*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O;65T87(M97AT96YS:79E
M+G!H<``````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`V-S$U,@`Q,#4Q-30S,3`U-@`P,C<R,30`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T
M;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!%;&%B;W)A=&4@
M97AA;7!L92!F;W(@=&AE($U%5$%2+U1!1BUS97)V:6-E"B`J"B`J(%=E;&PL
M('1H:7,@:7,@82!M;W)E(&5L86)O<F%T92!E>&%M<&QE(&AO=R!T;R!C<F5A
M=&4@82!N96%T(&QI='1L92!P86=E"B`J('=I=&@@9F5T8VAI;F<@345405(O
M5$%&(&1A=&$@9G)O;2!.3T%!(&%N9"!P=71T:6YG(&ET(&EN=&\@82!D97-I
M9VXN"B`J($DG;2!N;W0@=&]O('!R;W5D(&]F(&UY(&1E<VEG;BUS:VEL;',L
M(&UO<W0@;V8@=&AE('-T=69F(&AE<F4@:7,@=&%K96X*("H@9G)O;2!T:&4@
M;65T87(M8FQO8VL@=VAI8V@@8V%N(&)E(&9O=6YD('=I=&AI;B!T:&4@2&]R
M9&4@1G)A;65W;W)K+`H@*B!C;W5R=&5S>2!O9B!2:6-K($5M97)Y("T@8W)E
M871I=F4@<&EX96QS:&]V:6YG(&ES;B=T(&UY(&1O;6%I;B`Z+5`*("H@22=V
M92!U<V5D(&$@1FER969O>"!F;W(@8VAE8VMI;F<@=&AE(&1E<VEG;BP@<V\@
M9&]N)W0@8F4@=&]O"B`J(&1I<V%P<&]I;G1E9"P@:68@=&AE('!A9V4@;&]O
M:W,@<VAA8F)Y('=I=&@@=&AE($E%+"!N;W0@=&AA="!)(&-A<F4*("H@=F5R
M>2!M=6-H(&%N>7=A>2`[+2D*("H@2&%V92!F=6XA"B`J(`H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I9VAT("AC
M*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R97-E<G9E
M9"X*("H@"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N
M9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I
M;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG
M(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@
M;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@
M:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER
M:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD
M('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO
M;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T
M:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE
M('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@
M*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T
M<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E
M8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*B`*("H@5$A)4R!3
M3T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@
M04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/
M4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)
M5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*
M("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!9
M4DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($58
M14U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)
M3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"
M4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L
M($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7
M159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!7
M2$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!4
M3U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%2
M25-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E17
M05)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&
M(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J(`H@*B!`8V%T96=O<GD@
M("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T
M:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T
M<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@
M*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E
M;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N
M("`@("!#5E,Z("1)9#H@;65T87(M97AT96YS:79E+G!H<"QV(#$N,3<@,C`P
M-2\Q,2\Q,R`R,CHT-3HR,2!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J
M($!F:6QE<V]U<F-E"B`J+PH*+R\M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"B\O(%1H:7,@:7,@=&AE(&%R96$L('=H97)E('EO=2!C86X@8W5S=&]M
M:7IE('1H92!S8W)I<'0*+R\M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"B1L;V-A=&EO;B`@("`@("`@/2`B0F]N;BP@1V5R;6%N>2([("\O(%1H92!C
M:71Y('=E('=A;G0@=&\@9F5T8V@@=&AE(&1A=&$@9F]R+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!7:&5R92!T:&4@<V5A<F-H
M(&9U;F-T:6]N('=I;&P@;&]O:R!F;W(*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@=&AE($E#04\@9&%T86)A<V4@*&=E;F5R871E
M9"!W:71H('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!B=6EL9$UE=&%R1$(N<&AP('-C<FEP="D*)&1S;B`@("`@("`@("`@
M("`](")S<6QI=&4Z+R]L;V-A;&AO<W0O+W5S<B]L;V-A;"]L:6(O<&AP+V1A
M=&$O4V5R=FEC97-?5V5A=&AE<B]S97)V:6-E<U=E871H97)$0B([(`HD<V]U
M<F-E365T87(@("`@(#T@(FAT='`B.R`@("`@("`@("`O+R!4:&ES('-C<FEP
M="!W:6QL('!U;&P@=&AE($U%5$%2(&1A=&$@=FEA(&AT='`*)'-O=7)C951A
M9B`@("`@("`](")H='1P(CL@("`@("`@("`@+R\@("`@("`@("`@("`@("`@
M("`@("`@("`@("!4048*)'-O=7)C95!A=&A-971A<B`]("(B.R`@("`@("`@
M("`@("`@+R\@3VYL>2!N965D960@=VAE;B!N;VXM<W1A;F1A<F0@86-C97-S
M(&ES('5S960*)'-O=7)C95!A=&A4868@("`]("(B.R`@("`@("`@("`@("`@
M+R\*)&-A8VAE5'EP92`@("`@("`]("(B.R`@("`@("`@("`@("`@+R\@4V5T
M(&$@='EP92`H9FEL92P@9&(L(&UD8BP@+BXN*2!T;PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!E;F%B;&4@8V%C:&EN9RX*)&-A
M8VAE3W!T("`@("`@("`](&%R<F%Y*"D[("`@("`@("`@+R\@0V%C:&4@;F5E
M9',@=F%R:6]U<R!O<'1I;VYS+"!D97!E;F1I;F<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@;VX@=&AE(&-O;G1A:6YE<BUT>7!E
M("T@<&QE87-E(&-O;G-U;'0*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@=&AE($-A8VAE(&UA;G5A;"`O('-O=7)C96-O9&4A"B1U
M;FET<T9O<FUA="`@("`@/2`B;65T<FEC(CL@("`@("`@("\O(%1H92!F;W)M
M870@=&AE('5N:71S(&%R92!D:7-P;&%Y960@:6X@+0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!M971R:6,L('-T86YD87)D(&]R
M('-O;64@8W5S=&]M:7IA=&EO;BX*)&1A=&5&;W)M870@("`@("`](")J+B!-
M(%DB.R`@("`@("`@+R\@4V5T('1H92!F;W)M870@=&AE(&1A=&4@:7,@9&ES
M<&QA>65D(&EN"B1T:6UE1F]R;6%T("`@("`@/2`B2#II(CL@("`@("`@("`@
M("\O("`@("`@("`@("`@("`@("`@("!T:6UE"B\O+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H*+R\@3&]A9"!T:&4@5V5A=&AE<B!C;&%S<PIR97%U
M:7)E7V]N8V4@(E-E<G9I8V5S+U=E871H97(N<&AP(CL*"B\O($]B:F5C="!I
M;FET:6%L:7IA=&EO;B`M(&5R<F]R(&-H96-K:6YG(&ES(&EM<&]R=&%N="P@
M8F5C875S92!O9@HO+R!H86YD;&EN9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES
M<VEN9R!014%2(&UO9'5L97,*)&UE=&%R(#T@)E-E<G9I8V5S7U=E871H97(Z
M.G-E<G9I8V4H(DUE=&%R(BD["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1M971A<BDI('L*("`@(&1I92@B17)R;W(Z("(N)&UE=&%R+3YG971-
M97-S86=E*"DN(EQN(BD["GT*"B\O(%-E="!P87)A;65T97)S(&9O<B!$0B!A
M8V-E<W,L(&YE961E9"!F;W(@;&]C871I;VX@<V5A<F-H97,*)&UE=&%R+3YS
M971-971A<D1"*"1D<VXI.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D;65T87(I*2!["B`@("!E8VAO(")%<G)O<CH@(BXD;65T87(M/F=E=$UE
M<W-A9V4H*2XB7&XB.PI]"@HO+R!);FET:6%L:7IE(&-A8VAI;F<*:68@*'-T
M<FQE;B@D8V%C:&54>7!E*2D@>PH@("`@)'-T871U<R`]("1M971A<BT^<V5T
M0V%C:&4H)&-A8VAE5'EP92P@)&-A8VAE3W!T*3L*("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@96-H;R`B
M17)R;W(Z("(N)'-T871U<RT^9V5T365S<V%G92@I+B)<;B(["B`@("!]"GT*
M"B\O($1E9FEN92!T:&4@=6YI=',@9F]R;6%T+"!B<FEN9R!T:&4@<F5T<FEE
M=F5D(&9O<FUA="!I;G1O"B\O('-O;65T:&EN9R!M;W)E(&-O;6UO;BXN+@HD
M;65T87(M/G-E=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="D["B1U;FET<R`]
M("1M971A<BT^9V5T56YI='-&;W)M870H*3L*)'5N:71S6R)T96UP(ET@("`]
M("(F9&5G.R(N<W1R=&]U<'!E<B@D=6YI='-;(G1E;7`B72D["B1U;FET<ULB
M=VEN9")=("`@/2`B)FYB<W`[(BYS=')?<F5P;&%C92@B:VUH(BP@(FMM+V@B
M+"`D=6YI='-;(G=I;F0B72D["B1U;FET<ULB=FES(ET@("`@/2`B)FYB<W`[
M(BXD=6YI='-;(G9I<R)=.PHD=6YI='-;(FAE:6=H=")=(#T@(B9N8G-P.R(N
M)'5N:71S6R)H96EG:'0B73L*)'5N:71S6R)P<F5S(ET@("`]("(F;F)S<#LB
M+B1U;FET<ULB<')E<R)=.PHD=6YI='-;(G)A:6XB72`@(#T@(B9N8G-P.R(N
M)'5N:71S6R)R86EN(ET["@HD;65T87(M/G-E=$UE=&%R4V]U<F-E*"1S;W5R
M8V5-971A<BP@)'-O=7)C95!A=&A-971A<BP@)'-O=7)C951A9BP@)'-O=7)C
M95!A=&A4868I.PH*+R\@4V5T(&1A=&4M+W1I;64M9F]R;6%T"B1M971A<BT^
M<V5T1&%T951I;65&;W)M870H)&1A=&5&;W)M870L("1T:6UE1F]R;6%T*3L*
M"B\O(%-E87)C:"!F;W(@9&5F:6YE9"!L;V-A=&EO;B!A;F0@9F5T8V@@=&AE
M(&9I<G-T(&ET96T@9F]U;F0N"B\O($)A:6P@;W5T(&EF('-O;65T:&EN9R!B
M860@:&%P<&5N<RXN+@HD<V5A<F-H(#T@)&UE=&%R+3YS96%R8VA,;V-A=&EO
M;B@D;&]C871I;VXL('1R=64I.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<V5A<F-H*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD<V5A<F-H+3YG
M971-97-S86=E*"DN(EQN(BD["GT*"B\O(%)E=')I979E(&1A=&$L('-T;W)E
M(&EN('9A<FEA8FQE<RP@8F%I;"!O=70@;VX@97)R;W(*)&9E=&-H(#T@87)R
M87DH"B`@("`B;&]C871I;VXB(#T^(")G971,;V-A=&EO;B(L"B`@("`B=V5A
M=&AE<B(@(#T^(")G971796%T:&5R(BP*("`@(")F;W)E8V%S="(@/3X@(F=E
M=$9O<F5C87-T(@HI.PIF;W)E86-H("@D9F5T8V@@87,@)'9A<FEA8FQE(#T^
M("1F=6YC=&EO;BD@>PH@("`@)"1V87)I86)L92`]("1M971A<BT^)&9U;F-T
M:6]N*"1S96%R8V@I.PH@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)"1V87)I86)L92DI('L*("`@("`@("!E8VAO(")%<G)O<CH@(BXD)'9A
M<FEA8FQE+3YG971-97-S86=E*"DN(EQN(CL*("`@("`@("!C;VYT:6YU93L*
M("`@('T*?0H*+R\@3F]W('=E(&]U='!U="!A;&P@=&AE(&1A=&$L('!L96%S
M92!D;VXG="!E>'!E8W0@97AT96YS:79E(&-O;6UE;G1S(&AE<F4L('1H:7,@
M:7,@8F%S:6,*+R\@2%1-3"]#4U,@<W1U9F8N($%L<V\@=&AI<R!I<VXG="!A
M('9E<GD@9F%N8WD@9&5S:6=N+"!I="=S(&IU<W0@=&\@<VAO=R!Y;W4L('=H
M870*+R\@=&AE('-C<FEP="!I<R!A8FQE('1O(&1O("AA;F0@;6]R92`[+2DI
M+BXN"C\^"CQH=&UL/@H\:&5A9#X*("`@(#QT:71L93Y397)V:6-E<U]796%T
M:&5R.CI-151!4B]4048\+W1I=&QE/@H@("`@/'-T>6QE('1Y<&4](G1E>'0O
M8W-S(CX*("`@("`@("`N;F]R;6%L("`@("![(&9O;G0M9F%M:6QY.B!!<FEA
M;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$Q<'0[(&9O
M;G0M=V5I9VAT.B!N;W)M86P[(&9O;G0M<W1Y;&4Z(&YO<FUA;"!]"B`@("`@
M("`@+FET86QI8R`@("`@>R!F;VYT+7=E:6=H=#H@;F]R;6%L.R!F;VYT+7-T
M>6QE.B!I=&%L:6,@?0H@("`@("`@("YB;VQD("`@("`@('L@9F]N="UW96EG
M:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&YO<FUA;"!]"B`@("`@("`@+F)O;&1I
M=&%L:6,@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@:71A;&EC
M('T*("`@("`@("`N<F5D8F]L9"`@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F
M;VYT+7-T>6QE.B!N;W)M86P[(&-O;&]R.B`C9F8P,#`P('T*("`@("`@("`N
M8FQU96)O;&0@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!N
M;W)M86P[(&-O;&]R.B`C,#`P,&9F('T*("`@("`@("`N8F=G<F5Y("`@("![
M(&)A8VMG<F]U;F0M8V]L;W(Z("-E.64Y93D@?0H@("`@("`@("YB9VMH86MI
M("`@('L@8F%C:V=R;W5N9"UC;VQO<CH@(V0X9#AC,"!]"B`@("`@("`@+G)E
M9R`@("`@("`@>R!F;VYT+7-I>F4Z(#=P=#L@=F5R=&EC86PM86QI9VXZ('-U
M<&5R('T*("`@("`@("!I;6<@("`@("`@("![('9E<G1I8V%L+6%L:6=N.B!M
M:61D;&4[(&)O<F1E<BUS='EL93H@;F]N93L@8F]R9&5R+7=I9'1H.B`P<'@@
M?0H@("`@("`@(&$@("`@("`@("`@('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O
M;G0M<W1Y;&4Z(&ET86QI8SL@8V]L;W(Z(",Y.3,S,#`[('1E>'0M9&5C;W)A
M=&EO;CH@;F]N92!]"B`@("`@("`@83IV:7-I=&5D("`@>R!F;VYT+7=E:6=H
M=#H@8F]L9#L@9F]N="US='EL93H@:71A;&EC.R!C;VQO<CH@(SDY,S,P,#L@
M=&5X="UD96-O<F%T:6]N.B!N;VYE('T*("`@("`@("!A.FAO=F5R("`@("![
M(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!I=&%L:6,[(&-O;&]R
M.B`C8V,S,S`P.R!T97AT+61E8V]R871I;VXZ('5N9&5R;&EN92!]"B`@("`@
M("`@=&%B;&4@("`@("`@>R!B;W)D97(Z(#!P>"!N;VYE(&)L86-K.R!B;W)D
M97(M<W!A8VEN9SH@,'!X('T*("`@("`@("!T9"`@("`@("`@("![(&9O;G0M
M9F%M:6QY.B!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.R!F;VYT+7-I
M>F4Z(#$Q<'0[(&9O;G0M=V5I9VAT.B!N;W)M86P[(&9O;G0M<W1Y;&4Z(&YO
M<FUA;"!]"B`@("`\+W-T>6QE/@H\+VAE860^"CQB;V1Y(&-L87-S/2)N;W)M
M86PB/@H\/W!H<`HO+R!$96)U9R!O=71P=71S('1H92!R87<@9&%T82!F971C
M:&5D(&)Y('1H92!F;W)E86-H+6QO;W`@86)O=F4L(&IU<W0@9F]R(&-H96-K
M:6YG+BXN"FEF("AI<W-E="@D7T=%5%LB9&5B=6<B72DI('L*("`@(&5C:&\@
M(CQP<F4^7&XB.PH@("`@=F%R7V1U;7`H)&QO8V%T:6]N+"`D=V5A=&AE<BP@
M)&9O<F5C87-T*3L*("`@(&5C:&\@(CPO<')E/EQN(CL*?2`*/SX*/'-P86X@
M8VQA<W,](F)L=65B;VQD(B!S='EL93TB9F]N="US:7IE.B`Q,W!T(CY796%T
M:&5R($9O<F5C87-T/"]S<&%N/B!C<F5A=&5D('=I=&@@/&$@<W1Y;&4](F9O
M;G0M<VEZ93H@,3-P="(@:')E9CTB:'1T<#HO+W!E87(N<&AP+FYE="\B/E!%
M05)S/"]A/B`\82!S='EL93TB9F]N="US:7IE.B`Q,W!T(B!H<F5F/2)H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<B\B/E-E
M<G9I8V5S7U=E871H97(\+V$^/&)R/@H\=&%B;&4@<W1Y;&4](G=I9'1H.B`Q
M,#`E(CX*/'1R/@H@("`@/'1D/@H@("`@("`@(#QT86)L92!B;W)D97(](C`B
M('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(S4R-&(Y.#L@8F]R9&5R
M+6)O='1O;3H@,G!X('-O;&ED("-E,&4S8V4[(&)O<F1E<BUL969T.B`R<'@@
M<V]L:60@(V(X8C9C,3L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A
M,#L@=VED=&@Z(#$P,"4B/@H@("`@("`@(#QT<B!C;&%S<STB8F=K:&%K:2(^
M"B`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(T(B!S='EL93TB8F]R9&5R+6)O
M='1O;3H@,G!X('-O;&ED("-A8F%D83(B/CQS<&%N(&-L87-S/2)B;VQD(CX\
M/STD;&]C871I;VY;(FYA;64B73\^("@\/STD<V5A<F-H/SXI/"]S<&%N/CPO
M=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(^"B`@("`@("`@("`@(#QT
M9#X\<W!A;B!C;&%S<STB8F]L9"(^4W5N<FES93H\+W-P86X^(#QI;6<@<W1Y
M;&4](G=I9'1H.B`R.'!X.R!H96EG:'0Z(#$S<'@[('9E<G1I8V%L+6%L:6=N
M.B!B87-E;&EN92(@86QT/2)3=6YR:7-E(B!S<F,](FEM86=E<R]S=6YR:7-E
M+F=I9B(^(#P_/21L;V-A=&EO;ELB<W5N<FES92)=/SX\+W1D/@H@("`@("`@
M("`@("`\=&0^/'-P86X@8VQA<W,](F)O;&0B/E-U;G-E=#H\+W-P86X^(#QI
M;6<@<W1Y;&4](G=I9'1H.B`S,'!X.R!H96EG:'0Z(#$U<'@[('9E<G1I8V%L
M+6%L:6=N.B!B87-E;&EN92(@86QT/2)3=6YS970B('-R8STB:6UA9V5S+W-U
M;G-E="YG:68B/B`\/STD;&]C871I;VY;(G-U;G-E=")=/SX\+W1D/@H@("`@
M("`@("`@("`\=&0@<W1Y;&4](G=I9'1H.B`Q.3!P>"(^)FYB<W`[/"]T9#X*
M("`@("`@("`@("`@/'1D('-T>6QE/2)W:61T:#H@875T;R(^)FYB<W`[/"]T
M9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<B!S='EL93TB:&5I9VAT.B`Q
M-7!X(CX*("`@("`@("`@("`@/'1D(&YO=W)A<#X\<W!A;B!C;&%S<STB8F]L
M9"(^5&5M<&5R871U<F4Z/"]S<&%N/B`\/SUR;W5N9"@D=V5A=&AE<ELB=&5M
M<&5R871U<F4B72P@,2DN)'5N:71S6R)T96UP(ET_/CPO=&0^"B`@("`@("`@
M("`@(#QT9"!N;W=R87`^/'-P86X@8VQA<W,](F)O;&0B/D1E=R!P;VEN=#H\
M+W-P86X^(#P_/7)O=6YD*"1W96%T:&5R6R)D97=0;VEN=")=+"`Q*2XD=6YI
M='-;(G1E;7`B73\^/"]T9#X*("`@("`@("`@("`@/'1D(&YO=W)A<#X\<W!A
M;B!C;&%S<STB8F]L9"(^1F5L="!T96UP97)A='5R93H\+W-P86X^(#P_/7)O
M=6YD*"1W96%T:&5R6R)F96QT5&5M<&5R871U<F4B72P@,2DN)'5N:71S6R)T
M96UP(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9"!R;W=S<&%N/2(T(B!V86QI
M9VX](G1O<"(^"B`@("`@("`@("`@("`@("`\<W!A;B!C;&%S<STB8F]L9"(^
M5')E;F0Z/"]S<&%N/CQB<CX*/#]P:'`*:68@*&ES<V5T*"1W96%T:&5R6R)T
M<F5N9")=*2`F)B!S:7IE;V8H)'=E871H97);(G1R96YD(ETI*2!["B`@("`O
M+R!/=71P=70@=&AE('1R96YD<RP@;&]O<"!T:')O=6=H('1H92!A<G)A>7,L
M"B`@("`O+R!C;VYV97)T('1H92!S='5F9B!T;R!N:6-E(&QO;VMI;F<@9&5S
M:6=N+"!J861D82P@:F%D9&$N+BX*("`@(&9O<F5A8V@@*"1W96%T:&5R6R)T
M<F5N9")=(&%S("1T<F5N9"D@>PH@("`@("`@(&9O<F5A8V@@*"1T<F5N9"!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@<W=I=&-H("@D:V5Y*2![
M"B`@("`@("`@("`@("`@("!C87-E(")T>7!E(CH*("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*"1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B3D]324<B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T
M<FEN9R`](").;R!3:6=N:69I8V%N="!796%T:&5R(CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(")414U03R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1R:6YG(#T@(E1E;7!O<F%R>2!796%T:&5R(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E(")"14--1R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@(E=E871H97(@0F5C;VUI;F<B.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1V86QU92`@/2`B(CL*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("AA<G)A>2@B9G)O;2(L(")T;R(L(")A="(I(&%S("1T:6UE
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=')E;F1;
M)'1I;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M("X]("(@(BXD=&EM92XB("(N)'1R96YD6R1T:6UE73L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`H)'9A;'5E("$]("(B*2`_("1V86QU92`@/2!T<FEM*"1V
M86QU92DN(CHB.B(B.PH@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`G
M/'-P86X@8VQA<W,](FET86QI8R(^)RXD<W1R:6YG+B<\+W-P86X^)SL*("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@(#T@)SQS<&%N(&-L87-S/2)I=&%L
M:6,B/B<N)'9A;'5E+B<\+W-P86X^)SL*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(G=I;F0B.@H@("`@("`@("`@
M("`@("`@("`@("1S=')I;F<@/2`B5VEN9#HB.PH@("`@("`@("`@("`@("`@
M("`@("1V86QU92`@/2`H<W1R=&]L;W=E<B@D=')E;F1;(G=I;F1$:7)E8W1I
M;VXB72D@/3T@(F-A;&TB*2`_(")#86QM(B`Z(")&<F]M('1H92`B+B1T<F5N
M9%LB=VEN9$1I<F5C=&EO;B)=+B(@*"(N)'1R96YD6R)W:6YD1&5G<F5E<R)=
M+B(F9&5G.RD@870@(BYR;W5N9"@D=')E;F1;(G=I;F0B72P@,2DN)'5N:71S
M6R)W:6YD(ET["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T<F5N
M9%LB=VEN9%9A<FEA8FEL:71Y(ETI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU92`N/2`B+"!V87)I86)L92!F<F]M("(N)'1R96YD6R)W:6YD
M5F%R:6%B:6QI='DB75LB9G)O;2)=+B(F9&5G.R!T;R`B+B1T<F5N9%LB=VEN
M9%9A<FEA8FEL:71Y(EU;(G1O(ETN(B9D96<[(CL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T<F5N9%LB
M=VEN9$=U<W0B72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M("X]("(L('=I=&@@9W5S=',@=7`@=&\@(BYR;W5N9"@D=')E;F1;(G=I;F1'
M=7-T(ETL(#$I+B1U;FET<ULB=VEN9")=.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&-A<V4@(G9I<VEB:6QI='DB.@H@("`@("`@("`@("`@("`@("`@("1S=')I
M;F<@/2`B5FES:6)I;&ET>3HB.PH@("`@("`@("`@("`@("`@("`@("1V86QU
M92`@/2!S=')T;VQO=V5R*"1T<F5N9%LB=FES475A;&EF:65R(ETI+B(@(BYR
M;W5N9"@D=')E;F1;(G9I<VEB:6QI='DB72P@,2DN)'5N:71S6R)V:7,B73L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@(F-L;W5D<R(Z"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`](")#
M;&]U9',Z(CL*("`@("`@("`@("`@("`@("`@("`D=F%L=64@(#T@(B(["B`@
M("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1V
M86PI.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`]
M('5C=V]R9',H)'9A;%LD:5U;(F%M;W5N=")=*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1V86Q;)&E=6R)T>7!E(ETI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@+CT@(B`B+B1V86Q;)&E=
M6R)T>7!E(ET["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86Q;)&E=6R)H96EG:'0B72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`N/2`B(&%T
M("(N)'9A;%LD:5U;(FAE:6=H=")=+B1U;FET<ULB:&5I9VAT(ET["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E("X]("1C;&]U9"XB("(["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`B8V]N9&ET:6]N(CH*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@
M(D-O;F1I=&EO;CHB.PH@("`@("`@("`@("`@("`@("`@("1V86QU92`@/2!U
M8W=O<F1S*"1V86PI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B<')E<W-U<F4B.@H@("`@("`@("`@("`@("`@
M("`@("1S=')I;F<@/2`B4')E<W-U<F4Z(CL*("`@("`@("`@("`@("`@("`@
M("`D=F%L=64@(#T@<F]U;F0H)'9A;"P@,2DN)'5N:71S6R)P<F5S(ET["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M(")F<F]M(CH*("`@("`@("`@("`@("`@(&-A<V4@(G1O(CH*("`@("`@("`@
M("`@("`@(&-A<V4@(F%T(CH*("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1$
M:7)E8W1I;VXB.@H@("`@("`@("`@("`@("`@8V%S92`B=VEN9$1E9W)E97,B
M.@H@("`@("`@("`@("`@("`@8V%S92`B=VEN9%9A<FEA8FEL:71Y(CH*("`@
M("`@("`@("`@("`@(&-A<V4@(G=I;F1'=7-T(CH*("`@("`@("`@("`@("`@
M(&-A<V4@(G9I<U%U86QI9FEE<B(Z"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64@,CL*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("`@("`@)'-T<FEN9R`]("(B.R`D=F%L=64@/2`B(CL*("`@("`@("`@
M("`@("`@("`@("!V87)?9'5M<"@D:V5Y+"`D=F%L*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H_/@H@("`@("`@("`@("`@
M("`@/#\])'-T<FEN9S\^(#P_/21V86QU93\^/&)R/@H\/W!H<`H@("`@("`@
M('T*"B`@("!]"GT@96QS92!["C\^"B`@("`@("`@("`@("`@("!N;VYE/&)R
M/@H\/W!H<`I]"C\^"B`@("`@("`@("`@("`@("`\<W!A;B!C;&%S<STB8F]L
M9"(^4F5M87)K<SH\+W-P86X^/&)R/@H\/W!H<`II9B`H:7-S970H)'=E871H
M97);(G)E;6%R:R)=*2`F)B!S:7IE;V8H)'=E871H97);(G)E;6%R:R)=*2D@
M>PH@("`@+R\@4V%M92!F;W(@=&AE(')E;6%R:W,L(&5V96X@;&5S<R!S<&5C
M=&%C=6QA<BXN+@H@("`@9F]R96%C:"@D=V5A=&AE<ELB<F5M87)K(ET@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@<W=I=&-H("@D:V5Y*2!["B`@("`@
M("`@("`@(&-A<V4@(F%U=&]S=&%T:6]N(CH*("`@("`@("`@("`@8V%S92`B
M<')E<W-C:&<B.@H@("`@("`@("`@("!C87-E(")N;W-P96-I(CH*("`@("`@
M("`@("`@8V%S92`B<W5N9'5R871I;VXB.@H@("`@("`@("`@("!C87-E(")M
M86EN=&%I;B(Z"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(B(["B`@("`@
M("`@("`@("`@("`D=F%L=64@(#T@)'9A;#L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E(")S96%P<F5S<W5R92(Z"B`@("`@("`@
M("`@("`@("`D<W1R:6YG(#T@(E!R97-S=7)E(&%T('-E86QE=F5L.B(["B`@
M("`@("`@("`@("`@("`D=F%L=64@(#T@<F]U;F0H)'9A;"P@,2DN)'5N:71S
M6R)P<F5S(ET["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M8V%S92`B,6AT96UP(CH*("`@("`@("`@("`@("`@("1S=')I;F<@/2`B5&5M
M<&5R871U<F4@9F]R(&QA<W0@:&]U<CHB.PH@("`@("`@("`@("`@("`@)'9A
M;'5E("`](')O=6YD*"1V86PL(#$I+B1U;FET<ULB=&5M<")=.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(C%H9&5W(CH*("`@
M("`@("`@("`@("`@("1S=')I;F<@/2`B1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z(CL*("`@("`@("`@("`@("`@("1V86QU92`@/2!R;W5N9"@D=F%L+"`Q
M*2XD=6YI='-;(G1E;7`B73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!C87-E("(V:&UA>'1E;7`B.@H@("`@("`@("`@("!C87-E("(V
M:&UI;G1E;7`B.@H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=V5A=&AE
M<ELB<F5M87)K(EU;(C9H;6%X=&5M<")=*2`F)B`A:7-S970H)'=E871H97);
M(G)E;6%R:R)=6R(V:&UI;G1E;7`B72DI('L*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU92@R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1S=')I;F<@/2`B36%X+TUI;B!496UP(&9O<B!L87-T(#8@:&]U<G,Z
M(CL*("`@("`@("`@("`@("`@("1V86QU92`@/2`H:7-S970H)'=E871H97);
M(G)E;6%R:R)=6R(V:&UA>'1E;7`B72DI(#\@<F]U;F0H)'=E871H97);(G)E
M;6%R:R)=6R(V:&UA>'1E;7`B72P@,2DN)'5N:71S6R)T96UP(ET@.B`B+2([
M"B`@("`@("`@("`@("`@("`D=F%L=64@+CT@(B\B.PH@("`@("`@("`@("`@
M("`@)'9A;'5E("X]("AI<W-E="@D=V5A=&AE<ELB<F5M87)K(EU;(C9H;6EN
M=&5M<")=*2D@/R!R;W5N9"@D=V5A=&AE<ELB<F5M87)K(EU;(C9H;6EN=&5M
M<")=+"`Q*2XD=6YI='-;(G1E;7`B72`Z("(M(CL*("`@("`@("`@("`@("`@
M('5N<V5T*"1W96%T:&5R6R)R96UA<FLB75LB-FAM87AT96UP(ETI.R!U;G-E
M="@D=V5A=&AE<ELB<F5M87)K(EU;(C9H;6EN=&5M<")=*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("(R-&AM87AT96UP(CH*
M("`@("`@("`@("`@8V%S92`B,C1H;6EN=&5M<"(Z"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1W96%T:&5R6R)R96UA<FLB75LB,C1H;6%X=&5M<")=
M*2`F)B`A:7-S970H)'=E871H97);(G)E;6%R:R)=6R(R-&AM:6YT96UP(ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64H,BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(DUA>"]-:6X@
M5&5M<"!F;W(@;&%S="`R-"!H;W5R<SHB.PH@("`@("`@("`@("`@("`@)'9A
M;'5E("`]("AI<W-E="@D=V5A=&AE<ELB<F5M87)K(EU;(C(T:&UA>'1E;7`B
M72DI(#\@<F]U;F0H)'=E871H97);(G)E;6%R:R)=6R(R-&AM87AT96UP(ETL
M(#$I+B1U;FET<ULB=&5M<")=(#H@(BTB.PH@("`@("`@("`@("`@("`@)'9A
M;'5E("X]("(O(CL*("`@("`@("`@("`@("`@("1V86QU92`N/2`H:7-S970H
M)'=E871H97);(G)E;6%R:R)=6R(R-&AM:6YT96UP(ETI*2`_(')O=6YD*"1W
M96%T:&5R6R)R96UA<FLB75LB,C1H;6EN=&5M<")=+"`Q*2XD=6YI='-;(G1E
M;7`B72`Z("(M(CL*("`@("`@("`@("`@("`@('5N<V5T*"1W96%T:&5R6R)R
M96UA<FLB75LB,C1H;6%X=&5M<")=*3L@=6YS970H)'=E871H97);(G)E;6%R
M:R)=6R(R-&AM:6YT96UP(ETI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@(G-N;W=D97!T:"(Z"B`@("`@("`@("`@("`@("`D
M<W1R:6YG(#T@(E-N;W<@9&5P=&@Z(CL*("`@("`@("`@("`@("`@("1V86QU
M92`@/2`D=F%L+B1U;FET<ULB<F%I;B)=.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@(G-N;W=E<75I=B(Z"B`@("`@("`@("`@
M("`@("`D<W1R:6YG(#T@(E=A=&5R(&5Q=6EV86QE;G0@;V8@<VYO=SHB.PH@
M("`@("`@("`@("`@("`@)'9A;'5E("`]("1V86PN)'5N:71S6R)R86EN(ET[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`B<V5N
M<V]R<R(Z"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(B(["B`@("`@("`@
M("`@("`@("`D=F%L=64@(#T@:6UP;&]D92@B/&)R/B(L("1V86PI.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`D<W1R:6YG(#T@(B([("1V86QU92`]("(B.PH@("`@("`@
M("`@("`@("`@=F%R7V1U;7`H)&ME>2P@)'9A;"D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"C\^"B`@("`@("`@("`@("`@("`\/STD<W1R
M:6YG/SX@/#\])'9A;'5E/SX\8G(^"CP_<&AP"B`@("!]"GT@96QS92!["C\^
M"B`@("`@("`@("`@("`@("!N;VYE/&)R/@H\/W!H<`I]"C\^"B`@("`@("`@
M("`@(#PO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(@<W1Y;&4](FAE
M:6=H=#H@,35P>"(^"B`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(R(B!S='EL
M93TB=VED=&@Z(#,Q,'!X(B!N;W=R87`^/'-P86X@8VQA<W,](F)O;&0B/E!R
M97-S=7)E.CPO<W!A;CX@/#\]<F]U;F0H)'=E871H97);(G!R97-S=7)E(ETL
M(#$I+B1U;FET<ULB<')E<R)=/SX\+W1D/@H@("`@("`@("`@("`\=&0@;F]W
M<F%P/CQS<&%N(&-L87-S/2)B;VQD(CY(=6UI9&ET>3H\+W-P86X^(#P_/21W
M96%T:&5R6R)H=6UI9&ET>2)=/SXE/"]T9#X*("`@("`@("`\+W1R/@H@("`@
M("`@(#QT<B!S='EL93TB:&5I9VAT.B`Q-7!X(CX*("`@("`@("`@("`@/'1D
M(&-O;'-P86X](C(B(&YO=W)A<#X*("`@("`@("`@("`@("`@(#QS<&%N(&-L
M87-S/2)B;VQD(CY7:6YD.CPO<W!A;CX@/#\]<W1R=&]L;W=E<B@D=V5A=&AE
M<ELB=VEN9$1I<F5C=&EO;B)=*2`]/2`B8V%L;2(@/R`B0V%L;2(@.B`B1G)O
M;2!T:&4@(BXD=V5A=&AE<ELB=VEN9$1I<F5C=&EO;B)=+B(@*"(N)'=E871H
M97);(G=I;F1$96=R965S(ETN(B9D96<[*2!A="`B+G)O=6YD*"1W96%T:&5R
M6R)W:6YD(ETL(#$I+B1U;FET<ULB=VEN9")=/SX@"B`@("`@("`@("`@("`@
M("`\/SUI<W-E="@D=V5A=&AE<ELB=VEN9%9A<FEA8FEL:71Y(ETI(#\@(CQB
M<CYV87)I86)L92!F<F]M("(N)'=E871H97);(G=I;F1687)I86)I;&ET>2)=
M6R)F<F]M(ETN(B9D96<[('1O("(N)'=E871H97);(G=I;F1687)I86)I;&ET
M>2)=6R)T;R)=+B(F9&5G.R(@.B`B(C\^(`H@("`@("`@("`@("`@("`@/#\]
M:7-S970H)'=E871H97);(G=I;F1'=7-T(ETI(#\@(CQB<CYW:71H(&=U<W1S
M('5P('1O("(N<F]U;F0H)'=E871H97);(G=I;F1'=7-T(ETL(#$I+B1U;FET
M<ULB=VEN9")=(#H@(B(_/B`*("`@("`@("`@("`@/"]T9#X*("`@("`@("`@
M("`@/'1D('9A;&EG;CTB=&]P(B!N;W=R87`^/'-P86X@8VQA<W,](F)O;&0B
M/E9I<VEB:6QI='DZ/"]S<&%N/B`\/SUS=')T;VQO=V5R*"1W96%T:&5R6R)V
M:7-1=6%L:69I97(B72D_/B`\/SUR;W5N9"@D=V5A=&AE<ELB=FES:6)I;&ET
M>2)=+"`Q*2XD=6YI='-;(G9I<R)=/SX\+W1D/@H@("`@("`@(#PO='(^"B`@
M("`@("`@/'1R/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O;&0B
M/D-U<G)E;G0@8V]N9&ET:6]N.CPO<W!A;CX\8G(^/#\]:7-S970H)'=E871H
M97);(F-O;F1I=&EO;B)=*2`_('5C=V]R9',H)'=E871H97);(F-O;F1I=&EO
M;B)=*2`Z(").;R!3:6=N:69I8V%N="!796%T:&5R(C\^/"]T9#X*("`@("`@
M("`@("`@/'1D/CQI;6<@<W1Y;&4](FAE:6=H=#H@,S)P>#L@=VED=&@Z(#,R
M<'@B(&%L=#TB/#\]:7-S970H)'=E871H97);(F-O;F1I=&EO;B)=*2`_('5C
M=V]R9',H)'=E871H97);(F-O;F1I=&EO;B)=*2`Z(").;R!3:6=N:69I8V%N
M="!796%T:&5R(C\^(B!S<F,](FEM86=E<R\S,G@S,B\\/STD=V5A=&AE<ELB
M8V]N9&ET:6]N26-O;B)=/SXN<&YG(CX\+W1D/@H\/W!H<`II9B`H:7-S970H
M)'=E871H97);(G!R96-I<&ET871I;VXB72D@)B8@<VEZ96]F*"1W96%T:&5R
M6R)P<F5C:7!I=&%T:6]N(ETI*2!["B`@("`O+R!/=71P=70@82!L:6YE(&9O
M<B!E86-H('1Y<&4@;V8@<')E8VEP:71A=&EO;BP*("`@("\O(&1I<W1I;F=U
M:7-H(&)E='=E96X@<W1R:6YG(&%N9"!N=6UE<FEC('9A;'5E<PH_/@H@("`@
M("`@("`@("`@("`@/&)R/CQS<&%N(&-L87-S/2)B;VQD(CY0<F5C:7!I=&%T
M:6]N.CPO<W!A;CX\8G(^"CP_<&AP"B`@("!F;W(@*"1I(#T@,#L@)&D@/"!S
M:7IE;V8H)'=E871H97);(G!R96-I<&ET871I;VXB72D[("1I*RLI('L*("`@
M("`@("`D<')E8VEP(#T@(FQA<W0@(BXD=V5A=&AE<ELB<')E8VEP:71A=&EO
M;B)=6R1I75LB:&]U<G,B72XB:#H@(BXD=V5A=&AE<ELB<')E8VEP:71A=&EO
M;B)=6R1I75LB86UO=6YT(ET["B`@("`@("`@)'!R96-I<"`N/2`H8W1Y<&5?
M86QP:&$H)'=E871H97);(G!R96-I<&ET871I;VXB75LD:5U;(F%M;W5N=")=
M*2D@/R`B(B`Z("1U;FET<ULB<F%I;B)=.PH_/@H@("`@("`@("`@("`@("`@
M/#\])'!R96-I<#\^/&)R/@H\/W!H<`H@("`@?0I]"C\^"B`@("`@("`@("`@
M(#PO=&0^"B`@("`@("`@("`@(#QT9"!V86QI9VX](G1O<"(^"B`@("`@("`@
M("`@("`@("`\<W!A;B!C;&%S<STB8F]L9"(^0VQO=61S.CPO<W!A;CX\8G(^
M"CP_<&AP"FEF("AI<W-E="@D=V5A=&AE<ELB8VQO=61S(ETI("8F('-I>F5O
M9B@D=V5A=&AE<ELB8VQO=61S(ETI*2!["B`@("`O+R!996%H+"!C;&]U9',N
M+BX@<V%M92!A<R!I;B!T:&4@=')E;F0@:&%N9&QI;F<N+BX*("`@(&9O<B`H
M)&D@/2`P.R`D:2`\('-I>F5O9B@D=V5A=&AE<ELB8VQO=61S(ETI.R`D:2LK
M*2!["B`@("`@("`@)&-L;W5D(#T@=6-W;W)D<R@D=V5A=&AE<ELB8VQO=61S
M(EU;)&E=6R)A;6]U;G0B72D["B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R
M6R)C;&]U9',B75LD:5U;(G1Y<&4B72DI('L*("`@("`@("`@("`@)&-L;W5D
M("X]("(@(BXD=V5A=&AE<ELB8VQO=61S(EU;)&E=6R)T>7!E(ET["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELB8VQO=61S(EU;)&E=
M6R)H96EG:'0B72DI('L*("`@("`@("`@("`@)&-L;W5D("X]("(@870@(BXD
M=V5A=&AE<ELB8VQO=61S(EU;)&E=6R)H96EG:'0B72XD=6YI='-;(FAE:6=H
M=")=.PH@("`@("`@('T*/SX*("`@("`@("`@("`@("`@(#P_/21C;&]U9#\^
M/&)R/@H\/W!H<`H@("`@?0I](&5L<V4@>PH_/@H@("`@("`@("`@("`@("`@
M0VQE87(@0F5L;W<@/#\])&UE=&%R+3YC;VYV97)T1&ES=&%N8V4H,3(P,#`L
M(")F="(L("1U;FET<ULB:&5I9VAT(ETI+B1U;FET<ULB:&5I9VAT(ET_/B`*
M/#]P:'`*?0H_/@H@("`@("`@("`@("`\+W1D/@H@("`@("`@(#PO='(^"B`@
M("`@("`@/"]T86)L93X*("`@(#PO=&0^"CPO='(^"CQT<CX*("`@(#QT9#X*
M("`@("`@("`\=&%B;&4@<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C
M-3(T8CDX.R!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V4P93-C93L@8F]R
M9&5R+6QE9G0Z(#)P>"!S;VQI9"`C8CAB-F,Q.R!B;W)D97(M<FEG:'0Z(#)P
M>"!S;VQI9"`C.&(X-V$P.R!W:61T:#H@,3`P)2(^"B`@("`@("`@/'1R(&-L
M87-S/2)B9VMH86MI(CX*("`@("`@("`@("`@/'1D(&-O;'-P86X](C,B(&%L
M:6=N/2)C96YT97(B('-T>6QE/2)B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@
M(V%B861A,B(^/'-P86X@8VQA<W,](F)O;&0B/D9O<F5C87-T("A4048I/"]S
M<&%N/CQB<CYV86QI9"!F<F]M(#QS<&%N(&-L87-S/2)B;VQD(CX\/STD9F]R
M96-A<W1;(G9A;&ED1G)O;2)=/SX\+W-P86X^('1O(#QS<&%N(&-L87-S/2)B
M;VQD(CX\/STD9F]R96-A<W1;(G9A;&ED5&\B73\^/"]S<&%N/CPO=&0^"B`@
M("`@("`@/"]T<CX*("`@("`@("`\='(@=F%L:6=N/2)T;W`B/@H@("`@("`@
M("`@("`\=&0@8V]L<W!A;CTB,R(^"B`@("`@("`@("`@("`@("`\=&%B;&4@
M<W1Y;&4](G=I9'1H.B`Q,#`E(CX*("`@("`@("`@("`@("`@(#QT<CX*("`@
M("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@8VQA<W,](F)G
M:VAA:VDB('-T>6QE/2)H96EG:'0Z(#$U<'@[(&)O<F1E<BUT;W`Z(#)P>"!S
M;VQI9"`C9#AD.&,P.R!B;W)D97(M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X-V$P
M.R!B;W)D97(M;&5F=#H@,G!X('-O;&ED("-D.&0X8S`B/B9N8G-P.SPO=&0^
M"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE
M/2)W:61T:#H@,3@E(CX\<W!A;B!C;&%S<STB8F]L9"(^365T96]R;VQO9VEC
M86P@0V]N9&ET:6]N<SPO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@("`@
M(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB=VED=&@Z(#$X)2(@8VQA<W,]
M(F)G9W)E>2(^/'-P86X@8VQA<W,](F)O;&0B/E=I;F0\+W-P86X^/"]T9#X*
M("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4]
M(G=I9'1H.B`Q."4B/CQS<&%N(&-L87-S/2)B;VQD(CY6:7-I8FEL:71Y/"]S
M<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT
M97(B('-T>6QE/2)W:61T:#H@,3@E(B!C;&%S<STB8F=G<F5Y(CX\<W!A;B!C
M;&%S<STB8F]L9"(^0VQO=61S/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@
M("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)W:61T:#H@,3@E(CX\
M<W!A;B!C;&%S<STB8F]L9"(^0V]N9&ET:6]N/"]S<&%N/CPO=&0^"B`@("`@
M("`@("`@("`@("`\+W1R/@H\/W!H<`HD=&EM97,@/2!A<G)A>5]K97ES*"1F
M;W)E8V%S=%LB=&EM92)=*3L*)'!R92`@(#T@87)R87DH(G=I;F0B(#T^(#`L
M(")V:7,B(#T^(#`L(")C;&]U9',B(#T^(#`L(")C;VYD(B`]/B`P*3L*+R\@
M3VLL('1H92!F;W)E8V%S="!I<R!A(&)I="!M;W)E(&EN=&5R97-T:6YG+"!A
M<R!))VT@=&%K:6YG(&$@9F5W"B\O('!R96-A=71I;VYS(&AE<F4@<V\@=&AA
M="!T:&4@=&%B;&4@:7-N)W0@9FEL;&5D('5P('1O('1H92!M87@N"B\O(&\@
M268@82!V86QU92!I<R!R97!E871E9"!I;B!T:&4@;F5X="!M86IO<B!T:6UE
M<VQO="`H;F]T('=H96X*+R\@("!S:6=N:69I8V%N="!W96%T:&5R(&-H86YG
M97,@87)E('!R;V-E<W-E9"DL(&ET)W,@;F]T('!R:6YT960*+R\@;R!3:6=N
M:69I8V%N="!W96%T:&5R(&=E=',@:71S(&]W;B!R;W=S+"!W:71H('1I;65S
M('!R:6YT960@;F]R;6%L"B\O("`@87,@:6X@;W!P;W-I=&EO;B!T;R!B;VQD
M('!R:6YT(&9O<B!M86IO<B!T:6UE<VQO=',*+R\@;R!4:&4@=VAI;&4H)')O
M=RDM8V]N<W1R=6-T(&)E;&]W(&ES(&9O<B!H86YD;&EN9R!T:&4@<VEG;FEF
M:6-A;G0*+R\@("!W96%T:&5R+"!A<R!)('!O:6YT("1R;W<@=&\@)')O=ULB
M9FUC(ET@869T97)W87)D<RP@=VAE<F4@=&AE"B\O("`@<VUA;&QE<B!C:&%N
M9V5S(&%R92!M96YT:6]N960*9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1F
M;W)E8V%S=%LB=&EM92)=*3L@)&DK*RD@>PH@("`@)')O=R`]("1F;W)E8V%S
M=%LB=&EM92)=6R1T:6UE<ULD:5U=.PH*("`@("\O($-R96%T92!T:6UE<W1A
M;7`*("`@("1S=&%R="`]("1T:6UE<ULD:5T["B`@("!I9B`H)&D@*R`Q(#P@
M<VEZ96]F*"1F;W)E8V%S=%LB=&EM92)=*2D@>PH@("`@("`@("1E;F0@/2`D
M=&EM97-;)&D@*R`Q73L*("`@('T@96QS92!["B`@("`@("`@)&5N9"`]('-U
M8G-T<B@D9F]R96-A<W1;(G9A;&ED4F%W(ETL("TR*2XB.C`P(CL*("`@("`@
M("`D96YD(#T@*"1E;F0@/3T@(C(T.C`P(BD@/R`B,#`Z,#`B(#H@)&5N9#L*
M("`@('T*("`@("1T:6UE("`@(#T@)'-T87)T+B(@+2`B+B1E;F0["B`@("`D
M8VQA<W,@("`]("<@8VQA<W,](F)O;&0B)SL*("`@("\O(%1H:7,@:7,@9F]R
M(&]U='!U='1I;F<@(D)E8V]M:6YG(BP@(E1E;7!O<F%R>2(@86YD('-U8V@*
M("`@("1F;6,@("`@(#T@:7-S970H)')O=ULB9FUC(ETI(#\@)')O=ULB9FUC
M(ET@.B!F86QS93L@"B`@("`D9FUC='EP92`]("(B.PH@("`@)&9M8V-N="`@
M/2`P.PH*("`@('=H:6QE("@D<F]W*2!["C\^"B`@("`@("`@("`@("`@("`\
M='(@8VQA<W,](F)G:VAA:VDB/@H@("`@("`@("`@("`@("`@("`@(#QT9"!S
M='EL93TB:&5I9VAT.B`Q<'@[(&5M<'1Y+6-E;&QS.B!S:&]W.R!B;W)D97(M
M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X-V$P.R!B;W)D97(M;&5F=#H@,G!X('-O
M;&ED("-D.&0X8S`B/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/'1D('-T
M>6QE/2)H96EG:'0Z(#%P>"(@8V]L<W!A;CTB-2(^/"]T9#X*("`@("`@("`@
M("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@
M("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B(&-L87-S/2)B9VMH86MI(B!S
M='EL93TB8F]R9&5R+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A,#L@8F]R9&5R
M+6QE9G0Z(#)P>"!S;VQI9"`C9#AD.&,P(B!N;W=R87`^/'-P86X\/STD8VQA
M<W,_/CX\/STD=&EM93\^/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`@
M("`@/'1D(&%L:6=N/2)C96YT97(B/CP_/21F;6-T>7!E/SX\+W1D/@H\/W!H
M<`H@("`@("`@("\O(%1H:7,@;&]O<',@=&AR;W5G:"!T:&4@879A:6QA8FQE
M(&1A=&$@86YD('!R;V-E<W-E<R!I=`H@("`@("`@("\O(&9O<B!O=71P=70L
M('1H92!D:69F97)E;G0@;65T:&]D<R!W97)E(&%L<F5A9'D@=7-E9"!A8F]V
M90H@("`@("`@("\O("A/;FQY(&1I9F9E<F5N8V4@:7,@=&AE(&-H96-K:6YG
M(&9O<B!T:&4@<')E+79A;'5E<RXI"B`@("`@("`@9F]R96%C:"AA<G)A>2@B
M=VEN9"(L(")V:7,B+"`B8VQO=61S(BP@(F-O;F0B*2!A<R`D=F%L*2!["B`@
M("`@("`@("`@('-W:71C:"`H)'9A;"D@>PH@("`@("`@("`@("`@("`@8V%S
M92`B=VEN9"(Z"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F]W
M6R)W:6YD1&ER96-T:6]N(ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1S=')I;F<@/2`B)FYB<W`[(CL*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@<W1R=&]L
M;W=E<B@D<F]W6R)W:6YD1&ER96-T:6]N(ETI(#T](")C86QM(B`_(")#86QM
M(B`Z(")&<F]M('1H92`B+B1R;W=;(G=I;F1$:7)E8W1I;VXB72XB("@B+B1R
M;W=;(G=I;F1$96=R965S(ETN(B9D96<[*3QB<CYA="`B+G)O=6YD*"1R;W=;
M(G=I;F0B72P@,2DN)'5N:71S6R)W:6YD(ET["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<F]W6R)W:6YD4')O8B)=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`B("@B+B1R;W=;(G=I
M;F10<F]B(ETN(B4F;F)S<#M0<F]B+BDB.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<W1R:6YG(#T]
M/2`D<')E6R)W:6YD(ETI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S=')I;F<@/2`B)FYB<W`[(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5;(G=I
M;F0B72`]("1S=')I;F<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&-L87-S
M(#T@)R!C;&%S<STB8F=G<F5Y(B<["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")V:7,B.@H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)')O=ULB=FES:6)I;&ET>2)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(B9N8G-P.R(["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T<FEN9R`]('-T<G1O;&]W97(H)')O=ULB=FES475A;&EF:65R(ETI
M+B(@(BYR;W5N9"@D<F]W6R)V:7-I8FEL:71Y(ETL(#$I+B1U;FET<ULB=FES
M(ET["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F]W6R)V
M:7-0<F]B(ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R
M:6YG("X]("(@*"(N)')O=ULB=FES4')O8B)=+B(E)FYB<W`[4')O8BXI(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)'-T<FEN9R`]/3T@)'!R95LB=FES(ETI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B)FYB<W`[(CL*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P<F5;(G9I<R)=(#T@)'-T<FEN9SL*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D8VQA<W,@/2`G)SL*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F-L;W5D<R(Z"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D<F]W6R)C;&]U9',B72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]("(F;F)S<#LB.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92![(`H@("`@("`@("`@("`@("`@("`@
M("`@("`D8VQO=61S("`]("(B.PH@("`@("`@("`@("`@("`@("`@("`@("!F
M;W(@*"1J(#T@,#L@)&H@/"!S:7IE;V8H)')O=ULB8VQO=61S(ETI.R`D:BLK
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@/2!U8W=O
M<F1S*"1R;W=;(F-L;W5D<R)=6R1J75LB86UO=6YT(ETI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R;W=;(F-L;W5D<R)=6R1J
M75LB='EP92)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C;&]U9"`N/2`B("(N)')O=ULB8VQO=61S(EU;)&I=6R)T>7!E(ET["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)')O=ULB8VQO=61S(EU;)&I=6R)H96EG
M:'0B72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO
M=60@+CT@(B!A="`B+B1R;W=;(F-L;W5D<R)=6R1J75LB:&5I9VAT(ETN)'5N
M:71S6R)H96EG:'0B73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F]W6R)C
M;&]U9',B75LD:EU;(G!R;V(B72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8VQO=60@+CT@(B`H(BXD<F]W6R)C;&]U9',B75LD:EU;
M(G!R;V(B72XB)29N8G-P.U!R;V(N*2(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=61S
M("X]("1C;&]U9"XB/&)R/B(["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C;&]U9',@/3T]("1P<F5;
M(F-L;W5D<R)=*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@(B9N8G-P.R(["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("`@("`@
M("`]("1C;&]U9',["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E
M6R)C;&]U9',B72`]("1C;&]U9',["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)&-L87-S(#T@)R!C;&%S<STB8F=G<F5Y(B<["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")C;VYD(CH*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R;W=;(F-O;F1I=&EO;B)=*2!\
M?"`H:7-S970H)'!R97)O=RD@)B8@)'!R97)O=ULB8V]N9&ET:6]N(ET@/3T@
M)')O=ULB8V]N9&ET:6]N(ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1S=')I;F<@/2`B)FYB<W`[(CL*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@=6-W;W)D
M<R@D<F]W6R)C;VYD:71I;VXB72D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1C;&%S<R`]("<G.PH@("`@("`@("`@("!]
M"C\^"B`@("`@("`@("`@("`@("`@("`@/'1D('9A;&EG;CTB=&]P(CP_/21C
M;&%S<S\^/CP_/21S=')I;F<_/CPO=&0^"CP_<&AP"B`@("`@("`@?0H_/B`@
M("`@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`\+W1R/@H\/W!H
M<`H@("`@("`@("\O($YO=R!C:&5C:R!F;W(@<VEG;FEF:6-A;G0@=V5A=&AE
M<B!C:&%N9V5S(&%N9"!M;W9E"B`@("`@("`@+R\@=&AE(')O=R!A8V-O<F1I
M;F=L>2XN+B!M87EB92!U9VQY(&-O9&EN9RP@8G5T('1H:7,*("`@("`@("`O
M+R!I<R!F;W(@<VAO=VEN9R!D97-I9VXL(&YO="!F;W(@9F%N>2!P<F]G<F%M
M;6EN9R`[+2D*("`@("`@("!I9B`H)&9M8R`F)B`D9FUC8VYT(#P@<VEZ96]F
M*"1F;6,I*2!["B`@("`@("`@("`@("1R;W<@("`@(#T@)&9M8ULD9FUC8VYT
M73L*("`@("`@("`@("`@)&9M8V-N="LK.PH@("`@("`@("`@("`D9FUC='EP
M92`]("1R;W=;(G1Y<&4B73L*("`@("`@("`@("`@+R\@0VAE8VL@:68@=V4@
M:&%V92!A('1I;65S=&%M<"P@9&]N)W0@;W5T<'5T(&EF(&ET)W,*("`@("`@
M("`@("`@+R\@=&AE('-A;64@87,@=&AE(&UA:F]R+71I;65S;&]T"B`@("`@
M("`@("`@(&EF("@A:7-S970H)')O=ULB9G)O;2)=*2!\?"`D<F]W6R)F<F]M
M(ETN(B`M("(N)')O=ULB=&\B72`]/2`D=&EM92D@>PH@("`@("`@("`@("`@
M("`@)'1I;64@/2`B)FYB<W`[(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:6UE("`@(#T@)')O=ULB9G)O;2)=+B(@+2`B+B1R
M;W=;(G1O(ET["B`@("`@("`@("`@('T*("`@("`@("`@("`@<W=I=&-H("@D
M<F]W6R)T>7!E(ETI('L*("`@("`@("`@("`@("`@(&-A<V4@(E!23T(B.@H@
M("`@("`@("`@("`@("`@("`@("1F;6-T>7!E(#T@(B(["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")414U03R(Z
M"B`@("`@("`@("`@("`@("`@("`@)&9M8W1Y<&4@/2`B5&5M<&]R87)Y(CL*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@(D)%0TU'(CH*("`@("`@("`@("`@("`@("`@("`D9FUC='EP92`](")"
M96-O;6EN9R(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1R;W=;(G!R;V)A8FEL:71Y
M(ETI*2!["B`@("`@("`@("`@("`@("`D9FUC='EP92`N/2`B("@B+B1R;W=;
M(G!R;V)A8FEL:71Y(ETN(B4F;F)S<#M0<F]B+BDB.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')O=R`](&9A;'-E.PH@
M("`@("`@('T*("`@('T*?0H_/B`@("`@("`@("`@("`@("`*("`@("`@("`@
M("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\=&0@8VQA<W,](F)G
M:VAA:VDB('-T>6QE/2)H96EG:'0Z(#%P>#L@96UP='DM8V5L;',Z('-H;W<[
M(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C9#AD.&,P.R!B;W)D97(M;&5F
M=#H@,G!X('-O;&ED("-D.&0X8S`[(&)O<F1E<BUR:6=H=#H@,G!X('-O;&ED
M(",X8C@W83`B/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/'1D('-T>6QE
M/2)H96EG:'0Z(#%P>"(@8V]L<W!A;CTB-2(^/"]T9#X*("`@("`@("`@("`@
M("`@(#PO='(^"B`@("`@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@
M("`\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R(&-L87-S/2)B9VMH
M86MI(CX*("`@(`D@("`@/'1D('-T>6QE/2)W:61T:#H@.3-P>#L@8F]R9&5R
M+71O<#H@,G!X('-O;&ED("-A8F%D83(B/B9N8G-P.SPO=&0^"B`@("`@("`@
M("`@(#QT9"!S='EL93TB8F]R9&5R+71O<#H@,G!X('-O;&ED("-A8F%D83(B
M/E5P9&%T960Z("@\/SUS=6)S='(H)'=E871H97);(G5P9&%T92)=+"`M-2D_
M/B9N8G-P.R\F;F)S<#L\/SUS=6)S='(H)&9O<F5C87-T6R)U<&1A=&4B72P@
M+34I/SXI/"]T9#X*("`@("`@("`@("`@/'1D('-T>6QE/2)B;W)D97(M=&]P
M.B`R<'@@<V]L:60@(V%B861A,B(@86QI9VX](G)I9VAT(CY!;&P@=&EM97,@
M551#/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@(#PO=&%B;&4^"B`@("`\
M+W1D/@H\+W1R/@H\+W1A8FQE/@H\82!H<F5F/2)J879A<V-R:7!T.FAI<W1O
M<GDN8F%C:R@I(CYB86-K/"]A/@H\+V)O9'D^"CPO:'1M;#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O
M97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N<&AP````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C4T-@`Q,#4Q-30S
M,3`U-@`P,C<S-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME
M<CH@*B\*"B\J*@H@*B!"87-I8R!E>&%M<&QE(&9O<B!T:&4@5V5A=&AE<BYC
M;VTM<V5R=FEC90H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\
M3$E#14Y313X*("H@0V]P>7)I9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER
M='H*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H@"B`J(%)E9&ES=')I8G5T
M:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@
M;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O
M=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE
M=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R
M971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R
M97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O
M($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M
M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N
M9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S
M;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P
M97)M:7-S:6]N+@H@*B`*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"
M62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`B05,@
M25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L
M($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4*("H@24U03$E%
M1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&
M3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%($1)4T-,04E-140N($E.
M($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))
M0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L
M($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(*("H@0T].4T51
M545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!4
M3RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%5412!'3T]$4R!/4B!315)6
M24-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.
M15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.
M62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E."B`J($-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@24X@04Y9(%=!62!/550@
M3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@
M3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)
M0T5.4T4^"B`J(`H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P
M86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!
M;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@
M("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@=V5A=&AE
M<BYC;VTM8F%S:6,N<&AP+'8@,2XW(#(P,#4O,3$O,#@@,3<Z-3(Z-#(@97)U
M($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`9FEL97-O=7)C90H@*B\*"G)E
M<75I<F5?;VYC92`B4V5R=FEC97,O5V5A=&AE<BYP:'`B.PH*+R\@3V)J96-T
M(&EN:71I86QI>F%T:6]N("T@97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT
M+"!B96-A=7-E(&]F"B\O(&AA;F1L:6YG(&5X8V5P=&EO;G,@<W5C:"!A<R!M
M:7-S:6YG(%!%05(@;6]D=6QE<PHD=V5A=&AE<D1O=$-O;2`]("9397)V:6-E
M<U]796%T:&5R.CIS97)V:6-E*")796%T:&5R1&]T0V]M(BP@87)R87DH(F1E
M8G5G(B`]/B`R+"`B:'1T<%1I;65O=70B(#T^(#,P*2D["FEF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R1&]T0V]M*2D@>PH@("`@9&EE
M*")%<G)O<CH@(BXD=V5A=&AE<D1O=$-O;2T^9V5T365S<V%G92@I+B)<;B(I
M.PI]"@HO+R!3970@=V5A=&AE<BYC;VT@<&%R=&YE<B!D871A"B1W96%T:&5R
M1&]T0V]M+3YS971!8V-O=6YT1&%T82@B/%!A<G1N97))1#XB+"`B/$QI8V5N
M<V5+97D^(BD["@HO*B!%<F%S92!C;VUM96YT<R!T;R!E;F%B;&4@8V%C:&EN
M9PHD<W1A='5S(#T@)'=E871H97)$;W1#;VTM/G-E=$-A8VAE*")F:6QE(BP@
M87)R87DH(F-A8VAE7V1I<B(@/3X@(B]T;7`O8V%C:&4O(BDI.PII9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`B
M17)R;W(Z("(N)'-T871U<RT^9V5T365S<V%G92@I+B)<;B(["GT**B\*"B1W
M96%T:&5R1&]T0V]M+3YS9715;FET<T9O<FUA="@B;65T<FEC(BD["B1W96%T
M:&5R1&]T0V]M+3YS971$871E5&EM949O<FUA="@B9"YM+EDB+"`B2#II(BD[
M"@HO+R!&:7)S="!G970@8V]D92!F;W(@;&]C871I;VX*)'-E87)C:"`]("1W
M96%T:&5R1&]T0V]M+3YS96%R8VA,;V-A=&EO;B@B0F]N;BP@1V5R;6%N>2(I
M.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<V5A<F-H*2D@>PH@
M("`@9&EE*")%<G)O<CH@(BXD<V5A<F-H+3YG971-97-S86=E*"DN(EQN(BD[
M"GT*"B\O($YO=R!I=&5R871E('1H<F]U9V@@879A:6QA8FQE(&9U;F-T:6]N
M<R!F;W(@<F5T<FEE=FEN9R!D871A"F9O<F5A8V@@*&%R<F%Y*")G971,;V-A
M=&EO;B(L(")G971796%T:&5R(BP@(F=E=$9O<F5C87-T(BD@87,@)&9U;F-T
M:6]N*2!["B`@("`D9&%T82`]("1W96%T:&5R1&]T0V]M+3XD9G5N8W1I;VXH
M)'-E87)C:"D["B`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D
M9&%T82DI('L*("`@("`@("!E8VAO(")%<G)O<CH@(BXD9&%T82T^9V5T365S
M<V%G92@I+B)<;B(["B`@("`@("`@8V]N=&EN=64["B`@("!]"@H@("`@=F%R
M7V1U;7`H)&1A=&$I.PI]"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R
M+V5X86UP;&5S+W=E871H97(N8V]M+65X=&5N<VEV92YP:'``````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#4S,#(`,3`U,34T
M,S$P-38`,#,P,S$Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K
M97(Z("HO"@HO*BH*("H@16QA8F]R871E(&5X86UP;&4@9F]R('1H92!';&]B
M86Q796%T:&5R+7-E<G9I8V4*("H*("H@5V5L;"P@=&AI<R!I<R!A(&UO<F4@
M96QA8F]R871E(&5X86UP;&4@:&]W('1O(&-R96%T92!A(&YE870@;&ET=&QE
M('!A9V4*("H@=VET:"!F971C:&EN9R!D871A(&9R;VT@=V5A=&AE<BYC;VT@
M86YD('!U='1I;F<@:70@:6YT;R!A(&1E<VEG;BX*("H@22=M(&YO="!T;V\@
M<')O=60@;V8@;7D@9&5S:6=N+7-K:6QL<RP@;6]S="!O9B!T:&4@<W1U9F8@
M:&5R92!I<R!T86ME;@H@*B!F<F]M('1H92!W96%T:&5R+6)L;V-K('=H:6-H
M(&-A;B!B92!F;W5N9"!W:71H:6X@=&AE($AO<F1E($9R86UE=V]R:RP*("H@
M8V]U<G1E<WD@;V8@4FEC:R!%;65R>2`M(&-R96%T:79E('!I>&5L<VAO=FEN
M9R!I<VXG="!M>2!D;VUA:6X@.BU0"B`J($DG=F4@=7-E9"!A($9I<F5F;W@@
M9F]R(&-H96-K:6YG('1H92!D97-I9VXL('-O(&1O;B=T(&)E('1O;PH@*B!D
M:7-A<'!O:6YT960L(&EF('1H92!P86=E(&QO;VMS('-H86)B>2!W:71H('1H
M92!)12P@;F]T('1H870@22!C87)E"B`J('9E<GD@;75C:"!A;GEW87D@.RTI
M"B`J($EF('EO=2!W86YT('1O(&MN;W<@=VAE<F4@>6]U(&-A;B!O8G1A:6X@
M=&AE(&EC;VYS+"!P;&5A<V4@<F5G:7-T97(@870*("H@:'1T<#HO+W=W=RYW
M96%T:&5R+F-O;2]S97)V:6-E<R]X;6QO87`N:'1M;"!A;F0@>6]U)VQL(')E
M8V5I=F4@86X@94UA:6P*("H@8V]N=&%I;FEN9R!T:&4@<&%R=&YE<B!I9"P@
M=&AE(&QI8V5N<V4@:V5Y(&%N9"!A(&QI;FL@<&]I;G1I;F<@=&\@=&AE"B`J
M(%-$2RX@4'5T('1H92`S,G@S,B!A;F0@=&AE(&QO9V]S(&9O;&1E<G,@:6YT
M;R!T:&4@:6UA9V5S+R!D:7)E8W1O<GDN"B`J(%1H92!D97-I9VX@<VAO=6QD
M(&%D:&5R92!T;R!T:&4@8V]N=F5N=&EO;G,@9&5F:6YE9"!B>2!T:&4@=V5A
M=&AE<BYC;VT*("H@4T1++6=U:61E+"!T:&]U9V@@22!W;VXG="!G:79E(&%N
M>2!L96=A;"!C97)T86EN='D@9F]R('1H:7,@*&]F(&-O=7)S92DN"B`J($AA
M=F4@9G5N(0H@*B`*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)
M0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z
M"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J(`H@*B!2961I<W1R:6)U=&EO
M;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R
M('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I
M9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z
M"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T
M86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES
M="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N
M"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P
M<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T
M97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.
M96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S
M(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O
M<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F
M='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R
M;6ES<VEO;BX*("H@"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@
M5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3
M(@H@*B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%"B`J($E-4$Q)140@
M5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%"B`J($%212!$25-#3$%)345$+B!)3B!.
M3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4($]73D52($]2($-/3E1224)5
M5$]24R!"10H@*B!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)
M3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%455%
M3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L
M(%!23T-54D5-14Y4($]&"B`J(%-50E-425155$4@1T]/1%,@3U(@4T525DE#
M15,[($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D53
M4PH@*B!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@
M5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@
M4U1224-4($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.
M0T4@3U(@3U1(15)725-%*0H@*B!!4DE324Y'($E.($%.62!705D@3U54($]&
M(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&
M(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H@/"],24-%
M3E-%/@H@*B`*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C
M:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE
M>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@
M,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W
M=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"
M4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z('=E871H97(N
M8V]M+65X=&5N<VEV92YP:'`L=B`Q+C$T(#(P,#4O,3$O,#@@,3<Z-3(Z-#(@
M97)U($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`9FEL97-O=7)C90H@*B\*
M"B\O+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HO+R!4:&ES(&ES('1H
M92!A<F5A+"!W:&5R92!Y;W4@8V%N(&-U<W1O;6EZ92!T:&4@<V-R:7!T"B\O
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HD;&]C871I;VX@("`@(#T@
M(D)O;FXL($=E<FUA;GDB.R`O+R!4:&4@8VET>2!W92!W86YT('1O(&9E=&-H
M('1H92!D871A(&9O<BX*)&9O<F5C87-T1&%Y<R`](#0[("`@("`@("`@("`@
M("`@+R\@5&AI<R!R96=U;&%T97,@=&AE(&%M;W5N="!O9B!D:7-P;&%Y960*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@9&%T97,@:6X@
M=&AE(&9O<F5C87-T+B`H,2`\/2!X(#P](#$P*0HD<&%R=&YE<DE$("`@(#T@
M(CQ087)T;F5R240^(CL@("`O+R!!<R!P<F]V:61E9"!B>2!W96%T:&5R+F-O
M;2!I;B!T:&4*)&QI8V5N<V5+97D@("`]("(\3&EC96YS94ME>3XB.R`@+R\@
M<F5G:7-T<F%T:6]N(&5-86EL+@HD8V%C:&54>7!E("`@(#T@(B([("`@("`@
M("`@("`@("`O+R!3970@82!T>7!E("AF:6QE+"!D8BP@;61B+"`N+BXI('1O
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&5N86)L92!C
M86-H:6YG+@HD8V%C:&5/<'0@("`@(#T@87)R87DH*3L@("`@("`@("`O+R!#
M86-H92!N965D<R!V87)I;W5S(&]P=&EO;G,L(&1E<&5N9&EN9PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!O;B!T:&4@8V]N=&%I;F5R
M+71Y<&4@+2!P;&5A<V4@8V]N<W5L=`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!T:&4@0V%C:&4@;6%N=6%L("\@<V]U<F-E8V]D92$*
M)'5N:71S1F]R;6%T("`](")M971R:6,B.R`@("`@("`@+R\@5&AE(&9O<FUA
M="!T:&4@=6YI=',@87)E(&1I<W!L87EE9"!I;B`M"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&UE=')I8RP@<W1A;F1A<F0@;W(@<V]M
M92!C=7-T;VUI>F%T:6]N+@HD9&%T949O<FUA="`@(#T@(EDM;2UD(CL@("`@
M("`@("`O+R!3970@=&AE(&9O<FUA="!T:&4@9&%T92!I<R!D:7-P;&%Y960@
M:6X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@0VAA;F=I
M;F<@:70@=VEL;"!B<F5A:R!A(&9E=R!T:&EN9W,@:6X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@=&AI<R!S8W)I<'0L(&)U="!U<W5A
M;&QY('EO=2!C86X@9&5F:6YE"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O('1H:7,@=&\@>6]U<B!L:6MI;F=S+@HD=&EM949O<FUA="`@
M(#T@(D@Z:2([("`@("`@("`@("`O+R!3970@=&AE(&9O<FUA="!T:&4@=&EM
M92!I<R!D:7-P;&%Y960@:6X*+R\M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"@HO+R!,;V%D('1H92!796%T:&5R(&-L87-S"G)E<75I<F5?;VYC92`B
M4V5R=FEC97,O5V5A=&AE<BYP:'`B.PH*+R\@3V)J96-T(&EN:71I86QI>F%T
M:6]N("T@97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F
M"B\O(&AA;F1L:6YG(&5X8V5P=&EO;G,@<W5C:"!A<R!M:7-S:6YG(%!%05(@
M;6]D=6QE<PHD=V5A=&AE<D1O=$-O;2`]("9397)V:6-E<U]796%T:&5R.CIS
M97)V:6-E*")796%T:&5R1&]T0V]M(BP@87)R87DH(FAT='!4:6UE;W5T(B`]
M/B`S,"DI.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=V5A=&AE
M<D1O=$-O;2DI('L*("`@(&1I92@B17)R;W(Z("(N)'=E871H97)$;W1#;VTM
M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+R\@4V5T('=E871H97(N8V]M('!A
M<G1N97(@9&%T80HD=V5A=&AE<D1O=$-O;2T^<V5T06-C;W5N=$1A=&$H)'!A
M<G1N97))1"P@)&QI8V5N<V5+97DI.PH*+R\@26YI=&EA;&EZ92!C86-H:6YG
M"FEF("AS=')L96XH)&-A8VAE5'EP92DI('L*("`@("1S=&%T=7,@/2`D=V5A
M=&AE<D1O=$-O;2T^<V5T0V%C:&4H)&-A8VAE5'EP92P@)&-A8VAE3W!T*3L*
M("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2![
M"B`@("`@("`@96-H;R`B17)R;W(Z("(N)'-T871U<RT^9V5T365S<V%G92@I
M+B)<;B(["B`@("!]"GT*"B\O($1E9FEN92!T:&4@=6YI=',@9F]R;6%T+"!B
M<FEN9R!T:&4@<F5T<FEE=F5D(&9O<FUA="!I;G1O"B\O('-O;65T:&EN9R!M
M;W)E(&-O;6UO;BXN+@HD=V5A=&AE<D1O=$-O;2T^<V5T56YI='-&;W)M870H
M)'5N:71S1F]R;6%T*3L*)'5N:71S(#T@)'=E871H97)$;W1#;VTM/F=E=%5N
M:71S1F]R;6%T*"D["B1U;FET<ULB=&5M<")=("`@/2`B)F1E9SLB+G-T<G1O
M=7!P97(H)'5N:71S6R)T96UP(ETI.PHD=6YI='-;(G=I;F0B72`@(#T@(B9N
M8G-P.R(N<W1R7W)E<&QA8V4H(FMM:"(L(")K;2]H(BP@)'5N:71S6R)W:6YD
M(ETI.PHD=6YI='-;(G9I<R)=("`@(#T@(B9N8G-P.R(N)'5N:71S6R)V:7,B
M73L*)'5N:71S6R)H96EG:'0B72`]("(F;F)S<#LB+B1U;FET<ULB:&5I9VAT
M(ET["B1U;FET<ULB<')E<R)=("`@/2`B)FYB<W`[(BXD=6YI='-;(G!R97,B
M73L*)'5N:71S6R)R86EN(ET@("`]("(F;F)S<#LB+B1U;FET<ULB<F%I;B)=
M.PH*+R\@4V5T(&1A=&4M+W1I;64M9F]R;6%T"B1W96%T:&5R1&]T0V]M+3YS
M971$871E5&EM949O<FUA="@D9&%T949O<FUA="P@)'1I;65&;W)M870I.PH*
M+R\@4V5A<F-H(&9O<B!D969I;F5D(&QO8V%T:6]N(&%N9"!F971C:"!T:&4@
M9FER<W0@:71E;2!F;W5N9"X*+R\@0F%I;"!O=70@:68@<V]M971H:6YG(&)A
M9"!H87!P96YS+BXN"B1S96%R8V@@/2`D=V5A=&AE<D1O=$-O;2T^<V5A<F-H
M3&]C871I;VXH)&QO8V%T:6]N+"!T<G5E*3L*:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-E87)C:"DI('L*("`@(&1I92@B17)R;W(Z("(N)'-E
M87)C:"T^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO+R!2971R:65V92!D871A
M+"!S=&]R92!I;B!V87)I86)L97,L(&)A:6P@;W5T(&]N(&5R<F]R"B1F971C
M:"`](&%R<F%Y*`H@("`@(FQI;FMS(B`@("`]/B`B9V5T3&EN:W,B+`H@("`@
M(FQO8V%T:6]N(B`]/B`B9V5T3&]C871I;VXB+`H@("`@(G=E871H97(B("`]
M/B`B9V5T5V5A=&AE<B(L"B`@("`B9F]R96-A<W0B(#T^(")G971&;W)E8V%S
M="(**3L*9F]R96%C:"`H)&9E=&-H(&%S("1V87)I86)L92`]/B`D9G5N8W1I
M;VXI('L*("`@("0D=F%R:6%B;&4@/2`D=V5A=&AE<D1O=$-O;2T^)&9U;F-T
M:6]N*"1S96%R8V@L("1F;W)E8V%S=$1A>7,I.PH@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)"1V87)I86)L92DI('L*("`@("`@("!E8VAO
M(")%<G)O<CH@(BXD)'9A<FEA8FQE+3YG971-97-S86=E*"DN(EQN(CL*("`@
M("`@("!C;VYT:6YU93L*("`@('T*?0H*+R\@5V4@;F5E9"!T:&ES(&9O<B!S
M;VUE('1I;64M8VAE8VMS(&%N9"!D:7-P;&%Y<R!L871E<@HD=W5P9"`]('-T
M<G1O=&EM92@D=V5A=&AE<ELB=7!D871E(ETI("`K(&1A=&4H(EHB*3L*)&9U
M<&0@/2!S=')T;W1I;64H)&9O<F5C87-T6R)U<&1A=&4B72D@*R!D871E*"):
M(BD["B1F=7`@(#T@<W1R=&]T:6UE*"1F;W)E8V%S=%LB=7!D871E(ETI("L@
M)&QO8V%T:6]N6R)T:6UE>F]N92)=("H@,S8P,#L*"B\O($-H96-K+"!I9B!W
M92=R92!I;B!T:&4@869T97)N;V]N(&%N9"!I9B!T:&4@9F]R96-A<W0@=V%S
M('5P9&%T960@>65T+BXN"B\O(%1H:7,@=')I9V=E<G,@:68@=&AE(&1A>2UF
M;W)E8V%S="!F;W(@=&AE(&-U<G)E;G0@9&%Y('=I;&P@9V5T('-H;W=N+@HD
M869T97)N;V]N(#T@*"1L;V-A=&EO;ELB=&EM92)=(#X@(C$S.C4Y(B!\?"!D
M871E*")9;60B+"`D9G5P*2`\(&1A=&4H(EEM9"(I*2`_('1R=64@.B!F86QS
M93L*"B\O(%1H92!U<W5A;"!N;W1A=&EO;B!F;W(@8V]N9&ET:6]N(&EC;VYS
M(&ES(&YU;65R:6,N($-H96-K(&9O<B!N=6UE<FEC(&EC;VX@;W(@(FYA(B!A
M;F0@<V5T('1O(")N82(@:68@=&AA="=S(&YO="!T:&4@8V%S90II9B`H(2AC
M='EP95]D:6=I="@D=V5A=&AE<ELB8V]N9&ET:6]N26-O;B)=*2!\?"`D=V5A
M=&AE<ELB8V]N9&ET:6]N26-O;B)=(#T](")N82(I*2!["B`@("`D=V5A=&AE
M<ELB8V]N9&ET:6]N26-O;B)=(#T@(FYA(CL*?0H*+R\@3F]W('=E(&]U='!U
M="!A;&P@=&AE(&1A=&$L('!L96%S92!D;VXG="!E>'!E8W0@97AT96YS:79E
M(&-O;6UE;G1S(&AE<F4L('1H:7,@:7,@8F%S:6,*+R\@2%1-3"]#4U,@<W1U
M9F8N($%L<V\@=&AI<R!I<VXG="!A('9E<GD@9F%N8WD@9&5S:6=N+"!I="=S
M(&IU<W0@=&\@<VAO=R!Y;W4L('=H870*+R\@=&AE('-C<FEP="!I<R!A8FQE
M('1O(&1O("AA;F0@;6]R92`[+2DI+BXN"C\^"CQH=&UL/@H\:&5A9#X*("`@
M(#QT:71L93Y397)V:6-E<U]796%T:&5R.CI796%T:&5R9&]T8V]M/"]T:71L
M93X*("`@(#QS='EL92!T>7!E/2)T97AT+V-S<R(^"B`@("`@("`@+FYO<FUA
M;"`@("`@>R!F;VYT+69A;6EL>3H@07)I86PL($AE;'9E=&EC82P@<V%N<RUS
M97)I9CL@9F]N="US:7IE.B`Q,7!T.R!F;VYT+7=E:6=H=#H@;F]R;6%L.R!F
M;VYT+7-T>6QE.B!N;W)M86P@?0H@("`@("`@("YI=&%L:6,@("`@('L@9F]N
M="UW96EG:'0Z(&YO<FUA;#L@9F]N="US='EL93H@:71A;&EC('T*("`@("`@
M("`N8F]L9"`@("`@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE
M.B!N;W)M86P@?0H@("`@("`@("YB;VQD:71A;&EC('L@9F]N="UW96EG:'0Z
M(&)O;&0[(&9O;G0M<W1Y;&4Z(&ET86QI8R!]"B`@("`@("`@+G)E9&)O;&0@
M("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@;F]R;6%L.R!C
M;VQO<CH@(V9F,#`P,"!]"B`@("`@("`@+F)L=65B;VQD("`@>R!F;VYT+7=E
M:6=H=#H@8F]L9#L@9F]N="US='EL93H@;F]R;6%L.R!C;VQO<CH@(S`P,#!F
M9B!]"B`@("`@("`@+F)G9W)E>2`@("`@>R!B86-K9W)O=6YD+6-O;&]R.B`C
M93EE.64Y('T*("`@("`@("`N8F=K:&%K:2`@("![(&)A8VMG<F]U;F0M8V]L
M;W(Z("-D.&0X8S`@?0H@("`@("`@("YR96<@("`@("`@('L@9F]N="US:7IE
M.B`W<'0[('9E<G1I8V%L+6%L:6=N.B!S=7!E<B!]"B`@("`@("`@:6UG("`@
M("`@("`@>R!V97)T:6-A;"UA;&EG;CH@;6ED9&QE.R!B;W)D97(M<W1Y;&4Z
M(&YO;F4[(&)O<F1E<BUW:61T:#H@,'!X('T*("`@("`@("!A("`@("`@("`@
M("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!I=&%L:6,[(&-O
M;&]R.B`C.3DS,S`P.R!T97AT+61E8V]R871I;VXZ(&YO;F4@?0H@("`@("`@
M(&$Z=FES:71E9"`@('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z
M(&ET86QI8SL@8V]L;W(Z(",Y.3,S,#`[('1E>'0M9&5C;W)A=&EO;CH@;F]N
M92!]"B`@("`@("`@83IH;W9E<B`@("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@
M9F]N="US='EL93H@:71A;&EC.R!C;VQO<CH@(V-C,S,P,#L@=&5X="UD96-O
M<F%T:6]N.B!U;F1E<FQI;F4@?0H@("`@("`@('1A8FQE("`@("`@('L@8F]R
M9&5R.B`P<'@@;F]N92!B;&%C:SL@8F]R9&5R+7-P86-I;F<Z(#!P>"!]"B`@
M("`@("`@=&0@("`@("`@("`@>R!F;VYT+69A;6EL>3H@07)I86PL($AE;'9E
M=&EC82P@<V%N<RUS97)I9CL@9F]N="US:7IE.B`Q,7!T.R!F;VYT+7=E:6=H
M=#H@;F]R;6%L.R!F;VYT+7-T>6QE.B!N;W)M86P@?0H@("`@/"]S='EL93X*
M/"]H96%D/@H\8F]D>2!C;&%S<STB;F]R;6%L(CX*/#]P:'`*+R\@1&5B=6<@
M;W5T<'5T<R!T:&4@<F%W(&1A=&$@9F5T8VAE9"!B>2!T:&4@9F]R96%C:"UL
M;V]P(&%B;W9E+"!J=7-T(&9O<B!C:&5C:VEN9RXN+@II9B`H:7-S970H)%]'
M151;(F1E8G5G(ETI*2!["B`@("!E8VAO("(\<')E/EQN(CL*("`@('9A<E]D
M=6UP*"1L:6YK<RP@)&QO8V%T:6]N+"`D=V5A=&AE<BP@)&9O<F5C87-T*3L*
M("`@(&5C:&\@(CPO<')E/EQN(CL*?2`*/SX*/'-P86X@8VQA<W,](F)L=65B
M;VQD(B!S='EL93TB9F]N="US:7IE.B`Q,W!T(CY796%T:&5R($9O<F5C87-T
M/"]S<&%N/B!C<F5A=&5D('=I=&@@/&$@<W1Y;&4](F9O;G0M<VEZ93H@,3-P
M="(@:')E9CTB:'1T<#HO+W!E87(N<&AP+FYE="\B/E!%05)S/"]A/B`\82!S
M='EL93TB9F]N="US:7IE.B`Q,W!T(B!H<F5F/2)H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<B\B/E-E<G9I8V5S7U=E871H
M97(\+V$^/&)R/@H\=&%B;&4@<W1Y;&4](G=I9'1H.B`Q,#`E(CX*/'1R/@H@
M("`@/'1D/@H@("`@("`@(#QT86)L92!S='EL93TB8F]R9&5R+71O<#H@,G!X
M('-O;&ED(",U,C1B.3@[(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C93!E
M,V-E.R!B;W)D97(M;&5F=#H@,G!X('-O;&ED("-B.&(V8S$[(&)O<F1E<BUR
M:6=H=#H@,G!X('-O;&ED(",X8C@W83`[('=I9'1H.B`Q,#`E(CX*("`@("`@
M("`\='(@8VQA<W,](F)G:VAA:VDB/@H@("`@("`@("`@("`\=&0@<W1Y;&4]
M(G=I9'1H.B`S,3!P>#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-A8F%D
M83(B(&-O;'-P86X](C(B/CQS<&%N(&-L87-S/2)B;VQD(CX\/STD;&]C871I
M;VY;(FYA;64B73\^/"]S<&%N/CPO=&0^"B`@("`@("`@("`@(#QT9"!S='EL
M93TB=VED=&@Z(#$Y,'!X.R!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V%B
M861A,B(^/'-P86X@8VQA<W,](F)O;&0B/DQO8V%L('1I;64Z/"]S<&%N/B`\
M/STD;&]C871I;VY;(G1I;64B73\^("A'350\/STH*"1L;V-A=&EO;ELB=&EM
M97IO;F4B72`\(#`I(#\@(B(@.B`B*R(I+B1L;V-A=&EO;ELB=&EM97IO;F4B
M73\^*3PO=&0^"B`@("`@("`@("`@(#QT9"!S='EL93TB8F]R9&5R+6)O='1O
M;3H@,G!X('-O;&ED("-A8F%D83(B/B9N8G-P.SPO=&0^"B`@("`@("`@/"]T
M<CX*("`@("`@("`\='(^"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S<STB
M8F]L9"(^4W5N<FES93H\+W-P86X^(#QI;6<@<W1Y;&4](G=I9'1H.B`R.'!X
M.R!H96EG:'0Z(#$S<'@[('9E<G1I8V%L+6%L:6=N.B!B87-E;&EN92(@86QT
M/2)3=6YR:7-E(B!S<F,](FEM86=E<R]S=6YR:7-E+F=I9B(^(#P_/21L;V-A
M=&EO;ELB<W5N<FES92)=/SX\+W1D/@H@("`@("`@("`@("`\=&0@8V]L<W!A
M;CTB,B(^/'-P86X@8VQA<W,](F)O;&0B/E-U;G-E=#H\+W-P86X^(#QI;6<@
M<W1Y;&4](G=I9'1H.B`S,'!X.R!H96EG:'0Z(#$U<'@[('9E<G1I8V%L+6%L
M:6=N.B!B87-E;&EN92(@86QT/2)3=6YS970B('-R8STB:6UA9V5S+W-U;G-E
M="YG:68B/B`\/STD;&]C871I;VY;(G-U;G-E=")=/SX\+W1D/@H@("`@("`@
M("`@("`\=&0@<F]W<W!A;CTB-2(@=F%L:6=N/2)M:61D;&4B(&%L:6=N/2)C
M96YT97(B/@H@("`@("`@("`@("`@("`@/'1A8FQE('-T>6QE/2)B;W)D97(M
M=&]P.B`R<'@@<V]L:60@(S4R-&(Y.#L@8F]R9&5R+6)O='1O;3H@,G!X('-O
M;&ED("-E,&4S8V4[(&)O<F1E<BUL969T.B`R<'@@<V]L:60@(V(X8C9C,3L@
M8F]R9&5R+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A,"(^"B`@("`@("`@("`@
M("`@("`\='(@8VQA<W,](F)G:VAA:VDB/@H@("`@("`@("`@("`@("`@("`@
M(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB8F]R9&5R+6)O='1O;3H@,G!X
M('-O;&ED("-A8F%D83(B/CQS<&%N(&-L87-S/2)B;VQD(CY&96%T=7)E9"!O
M;B`\<W!A;B!C;&%S<STB8F]L9&ET86QI8R(^=V5A=&AE<BYC;VT\<W!A;B!C
M;&%S<STB<F5G(CXF<F5G.SPO<W!A;CX\+W-P86X^/"]S<&%N/CPO=&0^"B`@
M("`@("`@("`@("`@("`\+W1R/@H\/W!H<`HO+R!,;V]P('1H<F]U9V@@=&AE
M(&UA;F1A=&]R>2!L:6YK<RP@;F]T:&EN9R!S<&5C=&%C=6QA<@IF;W(@*"1I
M(#T@,#L@)&D@/"!S:7IE;V8H)&QI;FMS6R)P<F]M;R)=*3L@)&DK*RD@>PH_
M/@H@("`@("`@("`@("`@("`@/'1R(&-L87-S/2)B9V=R97DB/@H@("`@("`@
M("`@("`@("`@("`@(#QT9#X\82!H<F5F/2(\/STD;&EN:W-;(G!R;VUO(EU;
M)&E=6R)L:6YK(ET_/B(^/#\])&QI;FMS6R)P<F]M;R)=6R1I75LB=&ET;&4B
M73\^/"]A/CPO=&0^"B`@("`@("`@("`@("`@("`\+W1R/@H\/W!H<`I]"C\^
M"B`@("`@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@("`\+W1D/@H@
M("`@("`@(#PO='(^"B`@("`@("`@/'1R/@H@("`@("`@("`@("`\=&0^/'-P
M86X@8VQA<W,](F)O;&0B/E1E;7!E<F%T=7)E.CPO<W!A;CX@/#\]<F]U;F0H
M)'=E871H97);(G1E;7!E<F%T=7)E(ETL(#$I+B1U;FET<ULB=&5M<")=/SX\
M+W1D/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O;&0B/D1E=R!P
M;VEN=#H\+W-P86X^(#P_/7)O=6YD*"1W96%T:&5R6R)D97=0;VEN=")=+"`Q
M*2XD=6YI='-;(G1E;7`B73\^/"]T9#X*("`@("`@("`@("`@/'1D/CQS<&%N
M(&-L87-S/2)B;VQD(CY&96QT('1E;7!E<F%T=7)E.CPO<W!A;CX@/#\]<F]U
M;F0H)'=E871H97);(F9E;'1496UP97)A='5R92)=+"`Q*2XD=6YI='-;(G1E
M;7`B73\^/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<CX*("`@("`@
M("`@("`@/'1D(&-O;'-P86X](C(B/CQS<&%N(&-L87-S/2)B;VQD(CY0<F5S
M<W5R93H\+W-P86X^(#P_/7)O=6YD*"1W96%T:&5R6R)P<F5S<W5R92)=+"`Q
M*2XD=6YI='-;(G!R97,B73\^(&%N9"`\/STD=V5A=&AE<ELB<')E<W-U<F54
M<F5N9")=/SX\+W1D/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O
M;&0B/DAU;6ED:71Y.CPO<W!A;CX@/#\])'=E871H97);(FAU;6ED:71Y(ET_
M/B4\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R/@H@("`@("`@("`@
M("`\=&0@8V]L<W!A;CTB,B(^/'-P86X@8VQA<W,](F)O;&0B/E=I;F0Z/"]S
M<&%N/B`\/SUS=')T;VQO=V5R*"1W96%T:&5R6R)W:6YD1&ER96-T:6]N(ETI
M(#T](")C86QM(B`_(")#86QM(B`Z(")&<F]M('1H92`B+B1W96%T:&5R6R)W
M:6YD1&ER96-T:6]N(ETN(B`H(BXD=V5A=&AE<ELB=VEN9$1E9W)E97,B72XB
M)F1E9SLI(&%T("(N<F]U;F0H)'=E871H97);(G=I;F0B72P@,2DN)'5N:71S
M6R)W:6YD(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S<STB
M8F]L9"(^5FES:6)I;&ET>3H\+W-P86X^(#P_/7)O=6YD*"1W96%T:&5R6R)V
M:7-I8FEL:71Y(ETL(#$I+B1U;FET<ULB=FES(ET_/CPO=&0^"B`@("`@("`@
M/"]T<CX*("`@("`@("`\='(^"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S
M<STB8F]L9"(^0W5R<F5N="!C;VYD:71I;VXZ/"]S<&%N/CQB<CX\/STD=V5A
M=&AE<ELB8V]N9&ET:6]N(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9#X\:6UG
M('-T>6QE/2)H96EG:'0Z(#,R<'@[('=I9'1H.B`S,G!X(B!A;'0](CP_/21W
M96%T:&5R6R)C;VYD:71I;VXB73\^(B!S<F,](FEM86=E<R\S,G@S,B\\/STD
M=V5A=&AE<ELB8V]N9&ET:6]N26-O;B)=/SXN<&YG(CX\+W1D/@H@("`@("`@
M("`@("`\=&0@=F%L:6=N/2)T;W`B/CQS<&%N(&-L87-S/2)B;VQD(CY55BU)
M;F1E>#H\+W-P86X^(#P_/21W96%T:&5R6R)U=DEN9&5X(ET_/B`H/#\])'=E
M871H97);(G5V5&5X=")=/SXI/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@
M(#PO=&%B;&4^"B`@("`\+W1D/@H\+W1R/@H\='(^"B`@("`\=&0^"B`@("`@
M("`@/'1A8FQE('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(S4R-&(Y
M.#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-E,&4S8V4[(&)O<F1E<BUL
M969T.B`R<'@@<V]L:60@(V(X8C9C,3L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L
M:60@(SAB.#=A,"(^"B`@("`@("`@/'1R(&-L87-S/2)B9VMH86MI(CX*("`@
M("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)B;W)D97(M8F]T
M=&]M.B`R<'@@<V]L:60@(V%B861A,B(@8V]L<W!A;CTB/#\]*#$@*R`D9F]R
M96-A<W1$87ES*3\^(CX\<W!A;B!C;&%S<STB8F]L9"(^/#\])&9O<F5C87-T
M1&%Y<S\^+61A>2!F;W)E8V%S=#PO<W!A;CX\+W1D/@H@("`@("`@(#PO='(^
M"B`@("`@("`@/'1R('9A;&EG;CTB=&]P(CX*("`@("`@("`@("`@/'1D('-T
M>6QE/2)W:61T:#H@,3`E(CX*("`@("`@("`@("`@("`@(#QT86)L92!C;&%S
M<STB8F=K:&%K:2(@<W1Y;&4](G=I9'1H.B`Q,#`E.R!B;W)D97(M=&]P.B`R
M<'@@<V]L:60@(V0X9#AC,#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-D
M.&0X8S`[(&)O<F1E<BUL969T.B`R<'@@<V]L:60@(V0X9#AC,#L@8F]R9&5R
M+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A,"(^"B`@("`@("`@("`@("`@("`\
M='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T
M>6QE/2)H96EG:'0Z(#$U<'@B/B9N8G-P.SPO=&0^"B`@("`@("`@("`@("`@
M("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B
M('-T>6QE/2)H96EG:'0Z(#0U<'@B/CQS<&%N(&-L87-S/2)B;VQD(CY496UP
M97)A='5R93PO<W!A;CX@/'-P86X@8VQA<W,](G)E9&)O;&0B/DAI9V@\+W-P
M86X^("\@/'-P86X@8VQA<W,](F)L=65B;VQD(CY,;W<\+W-P86X^/"]T9#X*
M("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`\='(^"B`@
M("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H
M96EG:'0Z(#$U<'@B/B9N8G-P.SPO=&0^"B`@("`@("`@("`@("`@("`\+W1R
M/@H@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@(#QT
M9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`W-7!X(CX\<W!A;B!C
M;&%S<STB8F]L9"(^0V]N9&ET:6]N/"]S<&%N/CPO=&0^"B`@("`@("`@("`@
M("`@("`\+W1R/@H@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@
M("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`T-7!X
M(CX\<W!A;B!C;&%S<STB8F]L9"(^4')E8VEP:71A=&EO;B!P<F]B86)I;&ET
M>3PO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@/"]T<CX@("`@("`@("`@
M("`*("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@-#5P>"(^/'-P86X@
M8VQA<W,](F)O;&0B/E=I;F0\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@
M(#PO='(^"B`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@
M("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#$U<'@B/CQS
M<&%N(&-L87-S/2)B;VQD(CY(=6UI9&ET>3PO<W!A;CX\+W1D/@H@("`@("`@
M("`@("`@("`@/"]T<CX*("`@("`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@
M("`@("`@(#PO=&0^"CP_<&AP"F9O<B`H)&1A>2`](#`[("1D87D@/"`D9F]R
M96-A<W1$87ES.R`D9&%Y*RLI('L*("`@("\O(%-E="!N86UE(&]F(&1A>0H@
M("`@:68@*"1D87D@/3T@,"D@>PH@("`@("`@("1D87EN86UE(#T@(E1O9&%Y
M(CL*("`@('T@96QS96EF("@D9&%Y(#T](#$I('L*("`@("`@("`D9&%Y;F%M
M92`](")4;VUO<G)O=R(["B`@("!](&5L<V4@>PH@("`@("`@("1D87EN86UE
M(#T@9&%T92@B;"(L("1F=7`@*R`D9&%Y("H@.#8T,#`I.PH@("`@?0H@("`@
M+R\@069T97)N;V]N(&ES(&]N;'D@:6UP;W)T86YT(&9O<B!T;V1A>0H@("`@
M)&%F=&5R;F]O;B`]("@D9&%Y(#T](#`I(#\@)&%F=&5R;F]O;B`Z(&9A;'-E
M.PH*("`@("\O(%1H92!U<W5A;"!N;W1A=&EO;B!F;W(@8V]N9&ET:6]N(&EC
M;VYS(&ES(&YU;65R:6,N($-H96-K(&9O<B!N=6UE<FEC(&EC;VX@;W(@(FYA
M(B!A;F0@<V5T('1O(")N82(@:68@=&AA="=S(&YO="!T:&4@8V%S90H@("`@
M:68@*"$H8W1Y<&5?9&EG:70H)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A
M>2)=6R)C;VYD:71I;VY)8V]N(ETI('Q\("1F;W)E8V%S=%LB9&%Y<R)=6R1D
M87E=6R)D87DB75LB8V]N9&ET:6]N26-O;B)=(#T](")N82(I*2!["B`@("`@
M("`@)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=6R)C;VYD:71I;VY)
M8V]N(ET@/2`B;F$B.PH@("`@?0H@("`@:68@*"$H8W1Y<&5?9&EG:70H)&9O
M<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI9VAT(EU;(F-O;F1I=&EO;DEC;VXB
M72D@?'P@)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI9VAT(EU;(F-O;F1I
M=&EO;DEC;VXB72`]/2`B;F$B*2D@>PH@("`@("`@("1F;W)E8V%S=%LB9&%Y
M<R)=6R1D87E=6R)N:6=H=")=6R)C;VYD:71I;VY)8V]N(ET@/2`B;F$B.PH@
M("`@?0H_/@H@("`@("`@("`@("`\=&0@<W1Y;&4](G=I9'1H.B`\/STH.3`@
M+R`D9F]R96-A<W1$87ES*3\^)2(^"B`@("`@("`@("`@("`@("`\=&%B;&4@
M<W1Y;&4](G=I9'1H.B`Q,#`E(CP_/2@D9&%Y("4@,BD@/R`G(&-L87-S/2)B
M9V=R97DB)R`Z("(B/SX^"B`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@8V]L<W!A
M;CTB,B(@<W1Y;&4](FAE:6=H=#H@,35P>"(^/'-P86X@8VQA<W,](F)O;&0B
M/CP_/21D87EN86UE/SX\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@("`@
M("`\+W1R/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B(&-O;'-P86X](C(B('-T
M>6QE/2)H96EG:'0Z(#0U<'@B/CP_/21A9G1E<FYO;VX@/R`B(B`Z("<\<W!A
M;B!C;&%S<STB<F5D8F]L9"(^)RYR;W5N9"@D9F]R96-A<W1;(F1A>7,B75LD
M9&%Y75LB=&5M<&5R871U<F5(:6=H(ETL(#`I+B1U;FET<ULB=&5M<")=+B<\
M+W-P86X^("\@)S\^/'-P86X@8VQA<W,](F)L=65B;VQD(CX\/SUR;W5N9"@D
M9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB=&5M<&5R871U<F5,;W<B72P@,"DN
M)'5N:71S6R)T96UP(ET_/CPO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@
M("`@(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](G=I9'1H
M.B`U,"4[(&AE:6=H=#H@,35P>"(^/#\])&%F=&5R;F]O;B`_("(F;F)S<#LB
M(#H@)SQS<&%N(&-L87-S/2)B;VQD(CY$87D\+W-P86X^)S\^/"]T9#X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE
M/2)W:61T:#H@-3`E.R!H96EG:'0Z(#$U<'@B/CQS<&%N(&-L87-S/2)B;VQD
M(CY.:6=H=#PO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*
M("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`W-7!X(B!V
M86QI9&X](G1O<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\/STD
M869T97)N;V]N(#\@(B9N8G-P.R(@.B`G/&EM9R!S='EL93TB:&5I9VAT.B`S
M,G!X.R!W:61T:#H@,S)P>"(@86QI9VX](G1O<"(@86QT/2(G+B1F;W)E8V%S
M=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB8V]N9&ET:6]N(ETN)R(@<W)C/2)I
M;6%G97,O,S)X,S(O)RXD9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB9&%Y(EU;
M(F-O;F1I=&EO;DEC;VXB72XG+G!N9R(^)S\^/&)R/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/#\])&%F=&5R;F]O;B`_("(F;F)S<#LB(#H@)&9O
M<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=6R)C;VYD:71I;VXB73\^(`H@
M("`@("`@("`@("`@("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@-S5P
M>"(@=F%L:61N/2)T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/&EM9R!S='EL93TB:&5I9VAT.B`S,G!X.R!W:61T:#H@,S)P>"(@86QI9VX]
M(G1O<"(@86QT/2(\/STD9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB;FEG:'0B
M75LB8V]N9&ET:6]N(ET_/B(@<W)C/2)I;6%G97,O,S)X,S(O/#\])&9O<F5C
M87-T6R)D87ES(EU;)&1A>5U;(FYI9VAT(EU;(F-O;F1I=&EO;DEC;VXB73\^
M+G!N9R(^/&)R/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#\])&9O
M<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI9VAT(EU;(F-O;F1I=&EO;B)=/SX@
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@
M("`@("`@/"]T<CX*("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I
M9VAT.B`T-7!X(CX\/STD869T97)N;V]N(#\@(B9N8G-P(B`Z("1F;W)E8V%S
M=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB<')E8VEP:71A=&EO;B)=+B(E(C\^
M/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT
M97(B('-T>6QE/2)H96EG:'0Z(#0U<'@B/CP_/21F;W)E8V%S=%LB9&%Y<R)=
M6R1D87E=6R)N:6=H=")=6R)P<F5C:7!I=&%T:6]N(ET_/B4\+W1D/@H@("`@
M("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/'1R
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@
M<W1Y;&4](FAE:6=H=#H@-#5P>"(^/#\])&%F=&5R;F]O;B`_("(F;F)S<#LB
M(#H@<F]U;F0H)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=6R)W:6YD
M(ETL(#`I+B1U;FET<ULB=VEN9")=+B(@9G)O;29N8G-P.R(N)&9O<F5C87-T
M6R)D87ES(EU;)&1A>5U;(F1A>2)=6R)W:6YD1&ER96-T:6]N(ET_/CPO=&0^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S
M='EL93TB:&5I9VAT.B`T-7!X(CX\/SUR;W5N9"@D9F]R96-A<W1;(F1A>7,B
M75LD9&%Y75LB;FEG:'0B75LB=VEN9")=+"`P*2XD=6YI='-;(G=I;F0B73\^
M(&9R;VTF;F)S<#L\/STD9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB;FEG:'0B
M75LB=VEN9$1I<F5C=&EO;B)=/SX\+W1D/@H@("`@("`@("`@("`@("`@("`@
M(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@
M,35P>"(^/#\])&%F=&5R;F]O;B`_("(B(#H@)&9O<F5C87-T6R)D87ES(EU;
M)&1A>5U;(F1A>2)=6R)H=6UI9&ET>2)=+B(E(C\^/"]T9#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG
M:'0Z(#$U<'@B/CP_/21F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=
M6R)H=6UI9&ET>2)=/SXE/"]T9#X*("`@("`@("`@("`@("`@("`@("`\+W1R
M/@H@("`@("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`@("`@/"]T9#X*
M/#]P:'`*?0H_/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R(&-L87-S/2)B
M9VMH86MI(CX*("`@(`D@("`@/'1D('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@
M<V]L:60@(V%B861A,B(^)FYB<W`[/"]T9#X*("`@("`@("`@("`@/'1D('-T
M>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(V%B861A,B(^57!D871E9#H@
M*#P_/61A=&4H)'1I;65&;W)M870L("1W=7!D*3\^)FYB<W`[+R9N8G-P.SP_
M/61A=&4H)'1I;65&;W)M870L("1F=7!D*3\^*3PO=&0^"B`@("`@("`@("`@
M(#QT9"!A;&EG;CTB<FEG:'0B('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L
M:60@(V%B861A,B(@8V]L<W!A;CTB/#\]*"1F;W)E8V%S=$1A>7,@+2`Q*3\^
M(CY796%T:&5R(&1A=&$@<')O=FED960@8GD@/&$@:')E9CTB:'1T<#HO+W=W
M=RYW96%T:&5R+F-O;2\_<')O9#UX;V%P)G!A<CT\/STD<&%R=&YE<DE$/SXB
M/G=E871H97(N8V]M/'-P86X@8VQA<W,](G)E9R(^)G)E9SL\+W-P86X^/"]A
M/CQA(&AR968](FAT='`Z+R]W=W<N=V5A=&AE<BYC;VTO/W!R;V0]>&]A<"9P
M87(]/#\])'!A<G1N97))1#\^(CX\:6UG('-T>6QE/2)H96EG:'0Z(#,R<'@[
M('=I9'1H.B`T,W!X(B!A;'0](G=E871H97(N8V]M*%(I(&QO9V\B('-R8STB
M:6UA9V5S+VQO9V]S+U170VQO9V]?,S)P>"YP;F<B/CPO83X\+W1D/@H@("`@
M("`@(#PO='(^"B`@("`@("`@/"]T86)L93X*("`@(#PO=&0^"CPO='(^"CPO
M=&%B;&4^"CQA(&AR968](FIA=F%S8W)I<'0Z:&ES=&]R>2YB86-K*"DB/F)A
M8VL\+V$^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V5J
M<V4M8F%S:6,N<&AP````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R-#,`,3`U,34T,S$P-38`,#(V,#<S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*
M("H@0F%S:6,@97AA;7!L92!F;W(@=&AE($5*4T4M<V5R=FEC90H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I
M9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R
M97-E<G9E9"X*("H@"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I
M9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L
M;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U
M=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O
M<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE
M;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@
M=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@
M;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U
M=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P
M<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO
M=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*B`*("H@
M5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/
M3$1%4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A0
M4D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/
M5"!,24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%
M4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!5
M4E!/4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(
M12!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),
M12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)
M04PL($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)
M3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*
M("H@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L
M($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/
M3BD@2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,
M2519+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519
M+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I
M"B`J($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,
M2519($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J(`H@*B!`8V%T
M96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E
M<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L
M97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7
M:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R
M9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V
M97)S:6]N("`@("!#5E,Z("1)9#H@96IS92UB87-I8RYP:'`L=B`Q+C0@,C`P
M-2\Q,2\P."`Q-SHU,CHT,B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J
M($!F:6QE<V]U<F-E"B`J+PH@"G)E<75I<F5?;VYC92`B4V5R=FEC97,O5V5A
M=&AE<BYP:'`B.PH*+R\@3V)J96-T(&EN:71I86QI>F%T:6]N("T@97)R;W(@
M8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F"B\O(&AA;F1L:6YG
M(&5X8V5P=&EO;G,@<W5C:"!A<R!M:7-S:6YG(%!%05(@;6]D=6QE<R!O<B!N
M;W0@8F5I;F<@;VYL:6YE"B1E:G-E(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E
M<G9I8V4H(D5J<V4B+"!A<G)A>2@B9&5B=6<B(#T^(#(I*3L*:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)&5J<V4I*2!["B`@("!D:64H(D5R<F]R
M.B`B+B1E:G-E+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\J($5R87-E(&-O
M;6UE;G1S('1O(&5N86)L92!C86-H:6YG"B1S=&%T=7,@/2`D96IS92T^<V5T
M0V%C:&4H(F9I;&4B+"!A<G)A>2@B8V%C:&5?9&ER(B`]/B`B+W1M<"]C86-H
M92\B*2D["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I
M*2!["B`@("!E8VAO(")%<G)O<CH@(BXD<W1A='5S+3YG971-97-S86=E*"DN
M(EQN(CL*?0HJ+PH*)&5J<V4M/G-E=%5N:71S1F]R;6%T*")M971R:6,B*3L*
M)&5J<V4M/G-E=$1A=&54:6UE1F]R;6%T*")D+FTN62(L(")(.FDB*3L*"B1L
M;V-A=&EO;B`]("(X,38Q,2([("\O($%S<&5N+"!#3PHO+R1L;V-A=&EO;B`]
M("(P,C$Q-2([("\O($)O<W1O;BP@34$*+R\D;&]C871I;VX@/2`B.38W.3DB
M.R`O+R!086=O(%!A9V\L($%3"B\O)&QO8V%T:6]N(#T@(C`Y,#`Y(CL@+R\@
M07)M960@1F]R8V5S($5U<F]P92`M/B!%<G)O<@H*+R\@3F]W(&ET97)A=&4@
M=&AR;W5G:"!A=F%I;&%B;&4@9G5N8W1I;VYS(&9O<B!R971R:65V:6YG(&1A
M=&$*9F]R96%C:"`H87)R87DH(F=E=$QO8V%T:6]N(BP@(F=E=%=E871H97(B
M+"`B9V5T1F]R96-A<W0B*2!A<R`D9G5N8W1I;VXI('L*("`@("1D871A(#T@
M)&5J<V4M/B1F=6YC=&EO;B@D;&]C871I;VXI.PH@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)&1A=&$I*2!["B`@("`@("`@96-H;R`B17)R
M;W(Z("(N)&1A=&$M/F=E=$UE<W-A9V4H*2XB7&XB.PH@("`@("`@(&-O;G1I
M;G5E.PH@("`@?0H*("`@('9A<E]D=6UP*"1D871A*3L*?0H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]G
M;&]B86QW96%T:&5R+6)A<VEC+G!H<````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-#$P`#$P-3$U-#,Q,#4W`#`R-S<V
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ
M"B`J($)A<VEC(&5X86UP;&4@9F]R('1H92!';&]B86Q796%T:&5R+7-E<G9I
M8V4*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^
M"B`J($-O<'ER:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L
M;"!R:6=H=',@<F5S97)V960N"B`J(`H@*B!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H
M870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@
M4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H
M92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@
M4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E
M('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@
M=&AE(&1O8W5M96YT871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS
M('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R
M('1H92!N86UE(&]F('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET
M<R!C;VYT<FEB=71O<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R
M('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*
M("H@("!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO
M;BX*("H@"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/
M4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!
M3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)
M3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.
M5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%2
M5$E#54Q!4B!055)03U-%"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.
M5"!32$%,3"!42$4@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"
M10H@*B!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.
M5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@
M1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-5
M4D5-14Y4($]&"B`J(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/
M4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)
M3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9
M($]&($Q)04))3$E462P@5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4
M($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@
M3U1(15)725-%*0H@*B!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!5
M4T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@
M*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H@/"],24-%3E-%/@H@
M*B`*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@
M("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R
M(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!
M;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E
M;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC
M96YS90H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z(&=L;V)A;'=E871H97(M
M8F%S:6,N<&AP+'8@,2XU(#(P,#4O,3$O,#@@,3<Z-3(Z-#(@97)U($5X<"`D
M"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4V5R=FEC97-?5V5A=&AE<@H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?
M;VYC92`B4V5R=FEC97,O5V5A=&AE<BYP:'`B.PH*+R\@3V)J96-T(&EN:71I
M86QI>F%T:6]N("T@97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A
M=7-E(&]F"B\O(&AA;F1L:6YG(&5X8V5P=&EO;G,@<W5C:"!A<R!M:7-S:6YG
M(%!%05(@;6]D=6QE<R!O<B!N;W0@8F5I;F<@;VYL:6YE"B1G;&]B86QW96%T
M:&5R(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E<G9I8V4H(D=L;V)A;%=E871H
M97(B+"!A<G)A>2@B9&5B=6<B(#T^(#(I*3L*:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)&=L;V)A;'=E871H97(I*2!["B`@("!D:64H(D5R<F]R
M.B`B+B1G;&]B86QW96%T:&5R+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\J
M($5R87-E(&-O;6UE;G1S('1O(&5N86)L92!C86-H:6YG"B1S=&%T=7,@/2`D
M9VQO8F%L=V5A=&AE<BT^<V5T0V%C:&4H(F9I;&4B+"!A<G)A>2@B8V%C:&5?
M9&ER(B`]/B`B+W1M<"]C86-H92\B*2D["FEF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO(")%<G)O<CH@(BXD<W1A
M='5S+3YG971-97-S86=E*"DN(EQN(CL*?0HJ+PH*)&=L;V)A;'=E871H97(M
M/G-E=%5N:71S1F]R;6%T*")M971R:6,B*3L*)&=L;V)A;'=E871H97(M/G-E
M=$1A=&54:6UE1F]R;6%T*")D+FTN62(L(")(.FDB*3L*"B\O($9I<G-T(&=E
M="!C;V1E(&9O<B!L;V-A=&EO;@HD<V5A<F-H(#T@)&=L;V)A;'=E871H97(M
M/G-E87)C:$QO8V%T:6]N*")+;V5L;B`O($)O;FXB*3L*:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)'-E87)C:"DI('L*("`@(&1I92@B17)R;W(Z
M("(N)'-E87)C:"T^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO+R!.;W<@:71E
M<F%T92!T:')O=6=H(&%V86EL86)L92!F=6YC=&EO;G,@9F]R(')E=')I979I
M;F<@9&%T80IF;W)E86-H("AA<G)A>2@B9V5T3&]C871I;VXB+"`B9V5T5V5A
M=&AE<B(L(")G971&;W)E8V%S="(I(&%S("1F=6YC=&EO;BD@>PH@("`@)&1A
M=&$@/2`D9VQO8F%L=V5A=&AE<BT^)&9U;F-T:6]N*"1S96%R8V@I.PH@("`@
M:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&1A=&$I*2!["B`@("`@
M("`@96-H;R`B17)R;W(Z("(N)&1A=&$M/F=E=$UE<W-A9V4H*2XB7&XB.PH@
M("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@('9A<E]D=6UP*"1D871A*3L*
M?0H_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]5=&EL+P``````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,3<W
M,S$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U5T:6PO
M97AA;7!L97,O````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#4W`#`R,34T-P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?571I;"]E>&%M<&QE<R]E>&%M<&QE,BYP:'``````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#4W,#4`,3`U,34T,S$P-3<`,#(T,#`Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_4$A0#0HO*BH-
M"B`J('-E=F5R86P@97AA;7!L97,@9F]R('1H92!M971H;V1S(&]F(%A-3%]5
M=&EL#0H@*@T*("H@)$ED.B!E>&%M<&QE,BYP:'`L=B`Q+C@@,C`P-"\P-B\R
M-R`Q.#HQ-SHS.2!S8VAS="!%>'`@)`T*("H-"B`J($!A=71H;W(@("`@("!3
M=&5P:&%N(%-C:&UI9'0-"B`J($!P86-K86=E("`@("!834Q?571I;`T*("H@
M0'-U8G!A8VMA9V4@(&5X86UP;&5S#0H@*B!`8V%T96=O<GD@("`@6$U,#0H@
M*B\-"B`@("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PT*#0H@("`@<F5Q=6ER
M95]O;F-E("=834PO571I;"YP:'`G.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A
M=&EN9R!A('-T87)T(&5L96UE;G0-"B`@("`J+PT*("`@('!R:6YT(")C<F5A
M=&EN9R!A('-T87)T(&5L96UE;G0Z/&)R/B([#0H@("`@<')I;G0@:'1M;&5N
M=&ET:65S*%A-3%]5=&EL.CIC<F5A=&53=&%R=$5L96UE;G0H(FUY3G,Z;7E4
M86<B+"!A<G)A>2@B9F]O(B`]/B`B8F%R(BDL(")H='1P.B\O=W=W+G<S8RYO
M<F<O;7E.<R,B*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"@T*
M("`@("\J*@T*("`@("H@8W)E871I;F<@82!S=&%R="!E;&5M96YT#0H@("`@
M*B\-"B`@("!P<FEN="`B8W)E871I;F<@82!S=&%R="!E;&5M96YT.CQB<CXB
M.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E4W1A
M<G1%;&5M96YT*")M>51A9R(L(&%R<F%Y*"DL(")H='1P.B\O=W=W+G<S8RYO
M<F<O;7E.<R,B*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@
M("`O*BH-"B`@("`J(&-R96%T:6YG(&$@<W1A<G0@96QE;65N=`T*("`@("HO
M#0H@("`@<')I;G0@(F-R96%T:6YG(&$@<W1A<G0@96QE;65N=#H\8G(^(CL-
M"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA8
M34Q?571I;#HZ8W)E871E4W1A<G1%;&5M96YT*")M>51A9R(L(&%R<F%Y*"`B
M9F]O(B`]/B`B8F%R(BP@(F%R9V@B(#T^(")T;VUA=&\B("DL(")H='1P.B\O
M=W=W+G<S8RYO<F<O;7E.<R,B+"!T<G5E*2D[#0H@("`@<')I;G0@(CPO<')E
M/B([#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"@T*("`@("\J*@T*
M("`@("H@8W)E871I;F<@86X@96YD(&5L96UE;G0-"B`@("`J+PT*("`@('!R
M:6YT(")C<F5A=&EN9R!A;B!E;F0@96QE;65N=#H\8G(^(CL-"B`@("!P<FEN
M="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T945N9$5L96UE;G0H(FUY
M3G,Z;7E486<B*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@
M("`O*BH-"B`@("`J(&-R96%T:6YG(&$@0T1A=&$@<V5C=&EO;@T*("`@("HO
M#0H@("`@<')I;G0@(F-R96%T:6YG(&$@0T1A=&$@<V5C=&EO;CH\8G(^(CL-
M"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T94-$871A
M4V5C=&EO;B@B22!A;2!C;VYT96YT+B(I*3L-"B`@("!P<FEN="`B7&X\8G(^
M/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@82!C;VUM96YT
M#0H@("`@*B\-"B`@("!P<FEN="`B8W)E871I;F<@82!C;VUM96YT.CQB<CXB
M.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E0V]M
M;65N="@B22!A;2!A(&-O;6UE;G0N(BDI.PT*("`@('!R:6YT(")<;CQB<CX\
M8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A;B!834P@=&%G
M('=I=&@@;75L=&EL:6YE(&UO9&4-"B`@("`J+PT*("`@("1T86<@/2!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`@(#T^(")F;V\Z
M8F%R(BP-"B`@("`@("`@("`@("`@("`@(")N86UE<W!A8V55<FDB(#T^(")H
M='1P.B\O9F]O+F-O;2(L#0H@("`@("`@("`@("`@("`@("`B871T<FEB=71E
M<R(@("`]/B!A<G)A>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F
M<G5I="9V96=E=&%B;&4B("DL#0H@("`@("`@("`@("`@("`@("`B8V]N=&5N
M="(@("`@("`]/B`B22=M(&EN<VED92!T:&4@=&%G("8@8V]N=&%I;B!D86YG
M97)O=7,@8VAA<G,B#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@('!R:6YT
M(")C<F5A=&EN9R!A('1A9R!W:71H('%U86QI9FEE9"!N86UE(&%N9"!N86UE
M<W!A8V55<FDZ/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R
M:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y
M*"1T86<L(%A-3%]55$E,7U)%4$Q!0T5?14Y4251)15,L('1R=64I*3L-"B`@
M("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-
M"@T*("`@("\J*@T*("`@("H@8W)E871E(&%N(&%T=')I8G5T92!S=')I;F<@
M=VET:&]U="!R97!L86-I;F<@=&AE(&5N=&ET:65S#0H@("`@*B\-"B`@("`D
M871T<R`](&%R<F%Y*"`G<V5R:65S)R`]/B`G4W1A<G-K>2`F86UP.R!(=71C
M:"<L("=C:&%N;F5L)R`]/B`G04)#)R`I.PT*("`@('!R:6YT(")C<F5A=&EN
M9R!A(&%T=')I8G5T92!S=')I;F<L(&5N=&ET:65S(&EN('9A;'5E<R!A;')E
M861Y(&AA9"!B965N(')E<&QA8V5D.CQB<CXB.PT*("`@('!R:6YT(&AT;6QE
M;G1I=&EE<RA834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='1S+"!T
M<G5E+"!F86QS92P@9F%L<V4L(&9A;'-E+"!834Q?551)3%]%3E1)5$E%4U].
M3TY%*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-
M"B`@("`J('5S:6YG('1H92!A<G)A>2US>6YT87@@9F]R(&%T=')I8G5T97-4
M;U-T<FEN9R@I#0H@("`@*B\-"B`@("`D871T<R`](&%R<F%Y*"`G<V5R:65S
M)R`]/B`G4W1A<G-K>2`F86UP.R!(=71C:"<L("=C:&%N;F5L)R`]/B`G04)#
M)R`I.PT*("`@('!R:6YT(")U<VEN9R!T:&4@87)R87DM<WEN=&%X(&9O<B!A
M='1R:6)U=&5S5&]3=')I;F<H*3QB<CXB.PT*("`@('!R:6YT(&AT;6QE;G1I
M=&EE<RA834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='1S+"!A<G)A
M>2@G96YT:71I97,G(#T^(%A-3%]55$E,7T5.5$E424537TY/3D4I*2D[#0H@
M("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"@T*/SX`````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]5=&EL
M+V5X86UP;&5S+V5X86UP;&4N<&AP````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C`V
M,``Q,#4Q-30S,3`U-P`P,C,W,3,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]02%`-"B\J*@T*("H@<V5V97)A;"!E>&%M
M<&QE<R!F;W(@=&AE(&UE=&AO9',@;V8@6$U,7U5T:6P-"B`J#0H@*B`D260Z
M(&5X86UP;&4N<&AP+'8@,2XQ,B`R,#`T+S$R+S(S(#$S.C(R.C`P('-C:'-T
M($5X<"`D#0H@*@T*("H@0&%U=&AO<B`@("`@(%-T97!H86X@4V-H;6ED=`T*
M("H@0'!A8VMA9V4@("`@(%A-3%]5=&EL#0H@*B!`<W5B<&%C:V%G92`@97AA
M;7!L97,-"B`J($!C871E9V]R>2`@("!834P-"B`J+PT*("`@(&5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D[#0H-"B`@("!R97%U:7)E7V]N8V4@)UA-3"]5=&EL
M+G!H<"<[#0H@("`@#0H@("`@+RHJ#0H@("`@*B!R97!L86-I;F<@6$U,(&5N
M=&ET:65S#0H@("`@*B\-"B`@("!P<FEN="`B<F5P;&%C92!834P@96YT:71I
M97,Z/&)R/EQN(CL-"B`@("!P<FEN="!834Q?571I;#HZ<F5P;&%C945N=&ET
M:65S*")4:&ES('-T<FEN9R!C;VYT86EN<R`\("8@/BXB*3L-"B`@("!P<FEN
M="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@<F5V97)S:6YG
M(%A-3"!E;G1I=&EE<PT*("`@("HO#0H@("`@<')I;G0@(G)E<&QA8V4@6$U,
M(&5N=&ET:65S.CQB<CY<;B([#0H@("`@<')I;G0@6$U,7U5T:6PZ.G)E=F5R
M<V5%;G1I=&EE<R@B5&AI<R!S=')I;F<@8V]N=&%I;G,@)FQT.R`F86UP.R`F
M9W0[+B(I.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ
M#0H@("`@*B!B=6EL9&EN9R!834P@9&5C;&%R871I;VX-"B`@("`J+PT*("`@
M('!R:6YT(")B=6EL9&EN9R!834P@9&5C;&%R871I;VXZ/&)R/EQN(CL-"B`@
M("!P<FEN="!H=&UL<W!E8VEA;&-H87)S*%A-3%]5=&EL.CIG971834Q$96-L
M87)A=&EO;B@I*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@
M('!R:6YT(")B=6EL9&EN9R!834P@9&5C;&%R871I;VX@=VET:"!A9&1I=&EO
M;F%L(&%T=')I8G5T97,Z/&)R/B([#0H@("`@<')I;G0@:'1M;'-P96-I86QC
M:&%R<RA834Q?571I;#HZ9V5T6$U,1&5C;&%R871I;VXH(C$N,"(L(")55$8M
M."(L('1R=64I*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@
M("\J*@T*("`@("H@8G5I;&1I;F<@9&]C=6UE;G0@='EP92!D96-L87)A=&EO
M;@T*("`@("HO#0H@("`@<')I;G0@(F)U:6QD:6YG($1O8U1Y<&4@9&5C;&%R
M871I;VXZ/&)R/EQN(CL-"B`@("!P<FEN="!H=&UL<W!E8VEA;&-H87)S*%A-
M3%]5=&EL.CIG971$;V-4>7!E1&5C;&%R871I;VXH)W!A8VMA9V4G+"`G:'1T
M<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TQ+C`G*2D[#0H@("`@<')I
M;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("!P<FEN="`B8G5I;&1I;F<@1&]C
M5'EP92!D96-L87)A=&EO;B!W:71H('!U8FQI8R!)1"`H9&]E<R!N;W0@97AI
M<W0I.CQB<CY<;B([#0H@("`@<')I;G0@:'1M;'-P96-I86QC:&%R<RA834Q?
M571I;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*"=P86-K86=E)RP@87)R87DH
M)W5R:2<@/3X@)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,2XP
M)RP@)VED)R`]/B`G+2\O4$A0+R]014%2+T141"!004-+04=%(#`N,2<I*2D[
M#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("!P<FEN="`B8G5I
M;&1I;F<@1&]C5'EP92!D96-L87)A=&EO;B!W:71H(&EN=&5R;F%L($141#H\
M8G(^7&XB.PT*("`@('!R:6YT("(\<')E/B([#0H@("`@<')I;G0@:'1M;'-P
M96-I86QC:&%R<RA834Q?571I;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*"=P
M86-K86=E)RP@)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,2XP
M)RP@)SPA14Q%345.5"!A9&1I=&EO;F%L26YF;R`H(U!#1$%402D^)RDI.PT*
M("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB
M.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A;B!A='1R:6)U=&4@<W1R
M:6YG#0H@("`@*B\-"B`@("`D871T(#T@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`B9F]O(B`@(#T^("`B8F%R(BP-"B`@("`@("`@("`@("`@("`@(")A
M<F=H(B`@/3X@(")T;VUA=&\B#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@
M('!R:6YT(")C;VYV97)T:6YG(&%R<F%Y('1O('-T<FEN9SH\8G(^7&XB.PT*
M("`@('!R:6YT(%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H)&%T="D[
M#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"@T*("`@("\J*@T*("`@
M("H@8W)E871I;F<@86X@871T<FEB=71E('-T<FEN9R!W:71H(&QI;F5B<F5A
M:W,-"B`@("`J+PT*("`@("1A='0@/2!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@(")F;V\B("`@/3X@(")B87(B+`T*("`@("`@("`@("`@("`@("`@(F%R
M9V@B("`]/B`@(G1O;6%T;R(-"B`@("`@("`@("`@("`@("`I.PT*#0H@("`@
M<')I;G0@(F-O;G9E<G1I;F<@87)R87D@=&\@<W1R:6YG("AI;F-L=61I;F<@
M;&EN92!B<F5A:W,I.CQB<CY<;B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@
M("!P<FEN="!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='0L('1R
M=64L('1R=64I.PT*("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<
M;CQB<CX\8G(^7&XB.PT*#0H-"B`@("`O*BH-"B`@("`J('-P;&ET=&EN9R!A
M('%U86QI9FEE9"!T86<@;F%M90T*("`@("HO#0H@("`@<')I;G0@(G-P;&ET
M=&EN9R!Q=6%L:69I960@=&%G(&YA;64Z/&)R/EQN(CL-"B`@("!P<FEN="`B
M/'!R93XB.PT*("`@('!R:6YT7W(H6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D
M3F%M92@B>'-L=#IS='EL97-H965T(BDI.PT*("`@('!R:6YT("(\+W!R93XB
M.PT*("`@('!R:6YT(")<;CQB<CY<;B([#0H-"@T*("`@("\J*@T*("`@("H@
M<W!L:71T:6YG(&$@<75A;&EF:65D('1A9R!N86UE("AN;R!N86UE<W!A8V4I
M#0H@("`@*B\-"B`@("!P<FEN="`B<W!L:71T:6YG('%U86QI9FEE9"!T86<@
M;F%M92`H;F\@;F%M97-P86-E*3H\8G(^7&XB.PT*("`@('!R:6YT("(\<')E
M/B([#0H@("`@<')I;G1?<BA834Q?571I;#HZ<W!L:711=6%L:69I961.86UE
M*")F;V\B*2D[#0H@("`@<')I;G0@(CPO<')E/B([#0H@("`@<')I;G0@(EQN
M/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@<W!L:71T:6YG(&$@<75A;&EF
M:65D('1A9R!N86UE("AN;R!N86UE<W!A8V4L(&)U="!D969A=6QT(&YA;65S
M<&%C92!S<&5C:69I960I#0H@("`@*B\-"B`@("!P<FEN="`B<W!L:71T:6YG
M('%U86QI9FEE9"!T86<@;F%M92`H;F\@;F%M97-P86-E+"!B=70@9&5F875L
M="!N86UE<W!A8V4@<W!E8VEF:65D*3H\8G(^7&XB.PT*("`@('!R:6YT("(\
M<')E/B([#0H@("`@<')I;G1?<BA834Q?571I;#HZ<W!L:711=6%L:69I961.
M86UE*")F;V\B+"`B8F%R(BDI.PT*("`@('!R:6YT("(\+W!R93XB.PT*("`@
M('!R:6YT(")<;CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J('9E<FEF>6EN
M9R!834P@;F%M97,-"B`@("`J+PT*("`@('!R:6YT(")V97)I9GEI;F<@)TUY
M('!R:79A=&4@=&%G)SH\8G(^7&XB.PT*("`@('!R:6YT("(\<')E/B([#0H@
M("`@<')I;G1?<BA834Q?571I;#HZ:7-686QI9&YA;64H)TUY(%!R:79A=&4@
M5&%G)RDI.PT*("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<;CQB
M<CX\8G(^7&XB.PT*("`@(`T*("`@('!R:6YT(")V97)I9GEI;F<@)RU->51A
M9R<Z/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R:6YT7W(H
M6$U,7U5T:6PZ.FES5F%L:61N86UE*"<M37E486<G*2D[#0H@("`@<')I;G0@
M(CPO<')E/B([#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O
M*BH-"B`@("`J(&-R96%T:6YG(&%N(%A-3"!T86<-"B`@("`J+PT*("`@("1T
M86<@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@(")N86UE<W!A8V4B("`@
M/3X@(F9O;R(L#0H@("`@("`@("`@("`@("`@("`B;&]C86Q087)T(B`@(#T^
M(")B87(B+`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`]/B!A
M<G)A>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F<G5I="9V96=E
M=&%B;&4B("DL#0H@("`@("`@("`@("`@("`@("`B8V]N=&5N="(@("`@(#T^
M(")))VT@:6YS:61E('1H92!T86<B#0H@("`@("`@("`@("`@("`@*3L-"@T*
M("`@('!R:6YT(")C<F5A=&EN9R!A('1A9R!W:71H(&YA;65S<&%C92!A;F0@
M;&]C86P@<&%R=#H\8G(^(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,
M7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*2D[#0H@("`@<')I;G0@
M(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&%N
M(%A-3"!T86<-"B`@("`J+PT*("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@(")Q;F%M92(@("`@("`@(#T^(")F;V\Z8F%R(BP-"B`@("`@
M("`@("`@("`@("`@(")N86UE<W!A8V55<FDB(#T^(")H='1P.B\O9F]O+F-O
M;2(L#0H@("`@("`@("`@("`@("`@("`B871T<FEB=71E<R(@("`]/B!A<G)A
M>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F<G5I="9V96=E=&%B
M;&4B("DL#0H@("`@("`@("`@("`@("`@("`B8V]N=&5N="(@("`@("`]/B`B
M22=M(&EN<VED92!T:&4@=&%G(@T*("`@("`@("`@("`@("`@("D[#0H-"B`@
M("!P<FEN="`B8W)E871I;F<@82!T86<@=VET:"!Q=6%L:69I960@;F%M92!A
M;F0@;F%M97-P86-E57)I.CQB<CY<;B([#0H@("`@<')I;G0@:'1M;&5N=&ET
M:65S*%A-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RDI.PT*("`@
M('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A
M=&EN9R!A;B!834P@=&%G#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`B<6YA;64B("`@("`@("`]/B`B8F%R(BP-"B`@
M("`@("`@("`@("`@("`@(")N86UE<W!A8V55<FDB(#T^(")H='1P.B\O9F]O
M+F-O;2(L#0H@("`@("`@("`@("`@("`@("`B871T<FEB=71E<R(@("`]/B!A
M<G)A>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F<G5I="9V96=E
M=&%B;&4B("D-"B`@("`@("`@("`@("`@("`I.PT*#0H@("`@<')I;G0@(F-R
M96%T:6YG(&%N(&5M<'1Y('1A9R!W:71H;W5T(&YA;65S<&%C92!B=70@;F%M
M97-P86-E(%5R:3H\8G(^7&XB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA8
M34Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<I*3L-"B`@("!P<FEN
M="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@
M86X@6$U,('1A9R!W:71H(&$@0T1A=&$@4V5C=&EO;@T*("`@("HO#0H@("`@
M)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@(G%N86UE(B`@("`@
M("`@/3X@(F9O;R(L#0H@("`@("`@("`@("`@("`@("`B871T<FEB=71E<R(@
M("`]/B!A<G)A>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F<G5I
M="9V96=E=&%B;&4B("DL#0H@("`@("`@("`@("`@("`@("`B8V]N=&5N="(@
M("`@("`]/B`B22=M(&EN<VED92!T:&4@=&%G(@T*("`@("`@("`@("`@("`@
M("D[#0H-"B`@("!P<FEN="`B8W)E871I;F<@82!T86<@=VET:"!#1&%T82!S
M96-T:6]N.CQB<CY<;B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5
M=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RP@6$U,7U5424Q?0T1!5$%?
M4T5#5$E/3BDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@
M+RHJ#0H@("`@*B!C<F5A=&EN9R!A;B!834P@=&%G('=I=&@@82!#1&%T82!3
M96-T:6]N#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`B<6YA;64B("`@("`@("`]/B`B9F]O(BP-"B`@("`@("`@("`@
M("`@("`@(")A='1R:6)U=&5S(B`@(#T^(&%R<F%Y*"`B:V5Y(B`]/B`B=F%L
M=64B+"`B87)G:"(@/3X@(G3\=/PB("DL#0H@("`@("`@("`@("`@("`@("`B
M8V]N=&5N="(@("`@("`]/B`B06QS;R!82%1-3"UT86=S(&-A;B!B92!C<F5A
M=&5D(&%N9"!(5$U,(&5N=&ET:65S(&-A;B!B92!R97!L86-E9"#$(.0@W"#V
M(#P^+B(-"B`@("`@("`@("`@("`@("`I.PT*#0H@("`@<')I;G0@(F-R96%T
M:6YG(&$@=&%G('=I=&@@2%1-3"!E;G1I=&EE<SH\8G(^7&XB.PT*("`@('!R
M:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y
M*"1T86<L(%A-3%]55$E,7T5.5$E424537TA434PI*3L-"B`@("!P<FEN="`B
M7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@86X@
M6$U,('1A9R!W:71H(&-R96%T951A9PT*("`@("HO#0H@("`@<')I;G0@(F-R
M96%T:6YG(&$@=&%G('=I=&@@8W)E871E5&%G.CQB<CXB.PT*("`@('!R:6YT
M(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E5&%G*")M>4YS.FUY5&%G
M(BP@87)R87DH(F9O;R(@/3X@(F)A<B(I+"`B5&AI<R!I<R!I;G-I9&4@=&AE
M('1A9R(L(")H='1P.B\O=W=W+G<S8RYO<F<O;7E.<R,B*2D[#0H@("`@<')I
M;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`-"B`@("`O*BH-"B`@("`J('1R
M>6EN9R!T;R!C<F5A=&4@86X@6$U,('1A9R!W:71H(&%N(&%R<F%Y(&%S(&-O
M;G1E;G0-"B`@("`J+PT*("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@(")Q;F%M92(@("`@("`@(#T^(")B87(B+`T*("`@("`@("`@("`@
M("`@("`@(F-O;G1E;G0B("`@("`@/3X@87)R87DH(")F;V\B(#T^(")B87(B
M("D-"B`@("`@("`@("`@("`@("`I.PT*("`@('!R:6YT(")T<GEI;F<@=&\@
M8W)E871E(&%N(%A-3"!T86<@=VET:"!A;B!A<G)A>2!A<R!C;VYT96YT.CQB
M<CY<;B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN=%]R*%A-3%]5
M=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RDI.PT*("`@('!R:6YT("(\
M+W!R93XB.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*("`@(`T*("`@
M("\J*@T*("`@("H@=')Y:6YG('1O(&-R96%T92!A;B!834P@=&%G('=I=&AO
M=70@82!N86UE#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`B871T<FEB=71E<R(@("`]/B!A<G)A>2@@(F9O;R(@/3X@
M(F)A<B(@*2P-"B`@("`@("`@("`@("`@("`I.PT*("`@('!R:6YT(")T<GEI
M;F<@=&\@8W)E871E(&%N(%A-3"!T86<@=VET:&]U="!A(&YA;64Z/&)R/EQN
M(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R:6YT7W(H6$U,7U5T:6PZ
M.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*2D[#0H@("`@<')I;G0@(CPO<')E
M/B([#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E
M<FEA;&EZ97(O````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#4W`#`R,3$R-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R\`````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(R-S0S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X
M86UP;&5S+W-E<FEA;&EZ94%N9$5N8V]D92YP:'``````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8S-@`Q,#4Q-30S
M,3`U-P`P,C<R,3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]02%`*+RHJ"B`J($5X86UP;&4@=&\@9&5M;VYS=')A=&4@
M=&AE(&5N8V]D949U;F-T:6]N(&%N9"!D96-O9&5&=6YC=&EO;@H@*B!O<'1I
M;VYS+@H@*@H@*B!4:&ES(&%L;&]W<R!Y;W4@=&\@87!P;'D@8V%L;&)A8VMS
M('1O('EO=7(@9&%T82!T:&%T(&ES(&-A;&QE9`H@*B!O;B!A;&P@<W1R:6YG
M<R!W:&EL92!S97)I86QI>FEN9R!A;F0@=6YS97)I86QI>FEN9RX*("H*("H@
M0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PH@
M("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B`@("!R97%U:7)E7V]N8V4@
M)UA-3"]397)I86QI>F5R+G!H<"<["B`@("!R97%U:7)E7V]N8V4@)UA-3"]5
M;G-E<FEA;&EZ97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.
M5"`@("`@("`@("`@("`@(#T^("<@("`@)RP*("`@("`@("`@("`@("`@("`@
M("`@(%A-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M3("`@("`@("`@
M("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:
M15)?3U!424].7U-#04Q!4E]!4U]!5%1224)55$53(#T^('1R=64L"B`@("`@
M("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?14Y#3T1%
M7T953D,@("`@("`@("`@/3X@)W-T<G1O=7!P97(G"B`@("`@("`@("`@("`@
M("`@("`@*3L*("`@(`H@("`@)&9O;R`](&YE=R!S=&1#;&%S<R@I.PH@("`@
M)&9O;RT^8F%R(#T@;F5W('-T9$-L87-S*"D["B`@("`D9F]O+3YB87(M/G1E
M<W0@(#T@)U1H:7,@:7,@82!T97-T+B<["B`@("`D9F]O+3YB87(M/G9A;'5E
M(#T@)U1H:7,@:7,@82!V86QU92XG.PH@("`@"B`@("`D<V5R:6%L:7IE<B`]
M("9N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH@("`@"B`@("`D<F5S
M=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O*3L*("`@(`H@("`@
M:68@*"1R97-U;'0@/3T]('1R=64I('L*"0DD>&UL(#T@)'-E<FEA;&EZ97(M
M/F=E=%-E<FEA;&EZ961$871A*"D["B`@("!]"@H@("`@96-H;PDB/'!R93XB
M.PH@("`@<')I;G1?<B@@:'1M;'-P96-I86QC:&%R<R@D>&UL*2`I.PH@("`@
M96-H;PDB/"]P<F4^(CL*"B`@("`D=6YS97)I86QI>F5R(#T@)FYE=R!834Q?
M56YS97)I86QI>F5R*"D["B`@("`D=6YS97)I86QI>F5R+3YS971/<'1I;VXH
M)W!A<G-E071T<FEB=71E<R<L('1R=64I.PH@("`@)'5N<V5R:6%L:7IE<BT^
M<V5T3W!T:6]N*"=D96-O9&5&=6YC=&EO;B<L("=S=')T;VQO=V5R)RD["@H@
M("`@)')E<W5L="`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PI
M.PH@("`@"B`@("!E8VAO("<\<')E/B<["B`@("!P<FEN=%]R*"1U;G-E<FEA
M;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*2D["B`@("!E8VAO("<\+W!R
M93XG.PH_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE07)R87E7
M:71H3V)J96-T<RYP:'```````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,S<R`#$P-3$U-#,Q,#4W`#`S,#8Q,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/U!(4`HO*BH*("H@
M5&AI<R!E>&%M<&QE('-H;W=S(&AO=R!T;R!C<F5A=&4@86X@4D1&(&1O8W5M
M96YT"B`J('=I=&@@82!F97<@;&EN97,@;V8@8V]D92X*("H@5&AI<R!C86X@
M86QS;R!B92!D;VYE('=I=&@@;6]D92`]/B!S:6UP;&5X;6P*("H*("H@0&%U
M=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J($!S964@
M("`@<V5R:6%L:7IE26YD97AE9$%R<F%Y+G!H<`H@*B\*("`@(&5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D["@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L
M:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@(")I;F1E;G0B("`@("`@("`@(#T^("(@("`@(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@("`@/3X@(EQN
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@(G1Y<&5(:6YT<R(@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@(")A9&1$96-L(B`@
M("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@(")E;F-O
M9&EN9R(@("`@("`@(#T^(")55$8M."(*("`@("`@("`@("`@("`@("`@("`I
M.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D
M;W!T:6]N<RD["@H@("`@)'-E<FEA;&EZ97(M/G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]$244I.PH@("`@"B`@("`D87)R87D@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("!N97<@<W1D0VQA<W,H*2P*("`@("`@("`@("`@
M("`@("`@("!N97<@<W1D0VQA<W,H*0H@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1A
M<G)A>2D["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@
M("`@(&5C:&\@("`@(CQP<F4^(CL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I
M=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@
M("`@96-H;R`@("`B/"]P<F4^(CL*("`@('T*"B`@("`D<F5S=6QT(#T@)'-E
M<FEA;&EZ97(M/G-E<FEA;&EZ92@D87)R87DL(&%R<F%Y*"`G8VQA<W-!<U1A
M9TYA;64G(#T^('1R=64@*2D["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T
M<G5E("D@>PH@("`@("`@(&5C:&\@("`@(CQP<F4^(CL*("`@("`@("!E8VAO
M("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A
M=&$H*2D["B`@("`@("`@96-H;R`@("`B/"]P<F4^(CL*("`@('T*("`@(`H_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E
M>&%M<&QE<R]S97)I86QI>F5#1&%T82YP:'``````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T-S(`,3`U,34T
M,S$P-3<`,#(V,S0Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_4$A0"B\J*@H@*B!834P@4V5R:6%L:7IE<B!E>&%M<&QE
M"B`J"B`J(%1H:7,@97AA;7!L92!M86ME<R!U<V4@;V8@=&AE($-$871A('-E
M8W1I;VYS(&]P=&EO;@H@*@H@*B!`875T:&]R("!3=&5P:&%N(%-C:&UI9'0@
M/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R97!O<G1I;F<H15]!3$PI.PIR
M97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["@HD<V5R:6%L:7IE
M<B`](&YE=R!834Q?4V5R:6%L:7IE<B@I.PHD<V5R:6%L:7IE<BT^<V5T3W!T
M:6]N*%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0L("<@("`@)RD["B1S
M97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U-%4DE!3$E:15)?3U!424].7T1%
M1D%53%1?5$%'+"`G:71E;2<I.PHD<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-
M3%]315))04Q)6D527T]05$E/3E]#1$%405]314-424].4RP@=')U92D["@HD
M9&%T82`](&%R<F%Y*`H@("`@("`@("`@("=F;V\G(#T^("=4:&ES(&ES('-O
M;64@=&5X="XN+B<L"B`@("`@("`@("`@)V)A<B<@/3X@)R8@979E;B!M;W)E
M('1E>'0N+BXG+`H@("`@("`@("`@("=T97-T)R`]/B!A<G)A>2@G1F]O)RP@
M)T9O;R`F(&)A<B<I"@D)"2D["@HD<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E
M<FEA;&EZ92@D9&%T82D["@II9B@@)')E<W5L="`]/3T@=')U92`I('L*"21X
M;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C
M:&\@)SQP<F4^)SL*("`@(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D>&UL*3L*
M("`@(&5C:&\@)SPO<')E/B<["GT@96QS92!["B`@("`D<F5S=6QT+3YG971-
M97-S86=E*"D["B`@("!E>&ET*"D["GT*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]S97)I86QI>F5%;7!T>4%R<F%Y+G!H<```````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P-C$`
M,3`U,34T,S$P-3<`,#(W-#4T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_4$A0"B\J*@H@*B!4:&ES('-H;W=S('1H870@
M6$U,7U-E<FEA;&EZ97(@:7,@86)L92!T;R!W;W)K('=I=&@*("H@96UP='D@
M87)R87ES"B`J"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*<F5Q=6ER95]O
M;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@HD>&UL(#T@/#P\($5/1@H\
M875T;W!A9V5?;W!T:6]N<R!?8VQA<W,](F%U=&]P86=E7V]P=&EO;G,B(`I?
M='EP93TB;V)J96-T(CX*/'9E<G-I;VX@7W1Y<&4](G-T<FEN9R(^,2XP/"]V
M97)S:6]N/@H\;W!T:6]N<R!?='EP93TB87)R87DB("\^"CPO875T;W!A9V5?
M;W!T:6]N<SX*14]&.PH*)'5N<V5R:6%L:7IE<B`](&YE=R!834Q?56YS97)I
M86QI>F5R*"D["B1R97-U;'0@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ
M92@D>&UL*3L*"FEF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@96-H;R`G
M/'!R93XG.PH@("`@<')I;G1?<B@D=6YS97)I86QI>F5R+3YG9715;G-E<FEA
M;&EZ961$871A*"DI.PH@("`@96-H;R`G/"]P<F4^)SL*?0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?
M4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5);F1E>&5D07)R87DN<&AP
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#,W,#4`,3`U,34T,S$P-3<`,#(W-S0U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP
M;&4@9&5M;VYS=')A=&5S('1H92!U<V4@;V8*("H@;6]D92`]/B!S:6UP;&5X
M;6P*("H*("H@270@8V%N(&)E('5S960@=&\@<V5R:6%L:7IE(&%N(&EN9&5X
M960@87)R87D*("H@;&EK92!E>'0O<VEM<&QE>&UL(&1O97,L(&)Y('5S:6YG
M('1H92!N86UE"B`J(&]F('1H92!P87)E;G0@=&%G+"!W:&EL92!O;6ET=&EN
M9R!T:&ES('1A9RX*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"YN970^"B`J+PH@("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*
M("`@(`H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*
M("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0@("`@("`@/3X@)R`@("`G
M+`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)
M3TY?3$E.14)214%+4R`@(#T^(")<;B(L"@D)"0D)"5A-3%]315))04Q)6D52
M7T]05$E/3E]23T]47TY!344@("`@/3X@)W)D9CI21$8G+`H@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%]!5%12
M24)3(#T^(&%R<F%Y*"=V97)S:6]N)R`]/B`G,"XY,2<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?34]$12`@("`@
M("`@(#T^(%A-3%]315))04Q)6D527TU/1$5?4TE-4$Q%6$U,"B`@("`@("`@
M("`@("`@("`@("`@*3L*("`@(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,
M7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*("`@(`H@("`@)')D9B`](&%R<F%Y
M*`H)"0D))V-H86YN96PG(#T^(&%R<F%Y*`H)"0D)"0D)"0DG=&ET;&4G(#T^
M("=%>&%M<&QE(%)$1B!C:&%N;F5L)RP*"0D)"0D)"0D))VQI;FLG("`]/B`G
M:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4G+`H)"0D)"0D)"0DG:6UA9V4G"3T^
M"6%R<F%Y*`H)"0D)"0D)"0D)"0D)"2=T:71L92<)/3X@)T5X86UP;&4@:6UA
M9V4G+`H)"0D)"0D)"0D)"0D)"2=U<FPG"3T^"2=H='1P.B\O=W=W+G!H<"UT
M;V]L<RYD92]I;6%G92YG:68G+`H)"0D)"0D)"0D)"0D)"2=L:6YK)PD]/@DG
M:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4G"@D)"0D)"0D)"0D)"0DI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:71E;2<@("`]/B`@
M87)R87DH"B`@("`@("`@("`@(`D)"0D)"0D)"0D)87)R87DH"B`@("`@("`@
M("`@(`D)"0D)"0D)"0D)"2=T:71L92<)/3X@)T5X86UP;&4@:71E;2<L"B`@
M("`@("`@("`@(`D)"0D)"0D)"0D)"2=L:6YK)PD]/B`G:'1T<#HO+V5X86UP
M;&4N8V]M)PH@("`@("`@("`@("`)"0D)"0D)"0D)"2DL"B`@("`@("`@("`@
M(`D)"0D)"0D)"0D)87)R87DH"B`@("`@("`@("`@(`D)"0D)"0D)"0D)"2=T
M:71L92<)/3X@)T%N;W1H97(@:71E;2<L"B`@("`@("`@("`@(`D)"0D)"0D)
M"0D)"2=L:6YK)PD]/B`G:'1T<#HO+V5X86UP;&4N8V]M)PH@("`@("`@("`@
M("`)"0D)"0D)"0D)"2DL"B`@("`@("`@("`@(`D)"0D)"0D)"0D)87)R87DH
M"B`@("`@("`@("`@(`D)"0D)"0D)"0D)"2=T:71L92<)/3X@)TD@=&AI;FL@
M>6]U(&=E="!I="XN+B<L"B`@("`@("`@("`@(`D)"0D)"0D)"0D)"2=L:6YK
M)PD]/B`G:'1T<#HO+V5X86UP;&4N8V]M)PH@("`@("`@("`@("`)"0D)"0D)
M"0D)"2D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*0H)"0D)"0D)"2D*("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@"B`@("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ
M92@D<F1F*3L*("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@
M("`@("`@96-H;R`@("`G/'!R93XG.PH@("`@("`@(&5C:&\@("`@:'1M;&5N
M=&ET:65S*"1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I*3L*("`@
M("`@("!E8VAO("`@("<\+W!R93XG.PH@("`@?0H_/@``````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE26YD97AE9$%R<F%Y5VET:$-O;G1E
M>'0N<&AP`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,38U
M`#$P-3$U-#,Q,#4W`#`S,C$T-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE(&1E
M;6]N<W1R871E<R!T:&4@=7-E(&]F"B`J(&UO9&4@/3X@<VEM<&QE>&UL"B`J
M"B`J($ET(&-A;B!B92!U<V5D('1O('-E<FEA;&EZ92!A;B!I;F1E>&5D(&%R
M<F%Y"B`J(&QI:V4@97AT+W-I;7!L97AM;"!D;V5S+"!B>2!U<VEN9R!T:&4@
M;F%M90H@*B!O9B!T:&4@<&%R96YT('1A9RP@=VAI;&4@;VUI='1I;F<@=&AI
M<R!T86<N"B`J"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@H@*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["B`@("`*
M("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D
M;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M4T5224%,25I%4E]/4%1)3TY?24Y$14Y4("`@("`@(#T^("<@("`@)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TQ)
M3D5"4D5!2U,@("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404<@(#T^(&%R<F%Y*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E]$149!54Q47U1!1R`@/3X@87)R87DH)V9O;W,G(#T^("=F;V\G+"`G8F%R
M<R<@/3X@)V)A<B<I"B`@("`@("`@("`@("`@("`@("`@*3L*("`@(`H@("`@
M)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH@
M("`@"B`@("`D9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=F
M;V]S)R`]/B!A<G)A>2@G;VYE(&9O;R<L("=T=V\@9F]O<R<L("=T:')E92!F
M;V]S)RDL"B`@("`@("`@("`@("`@("`@("`@)V)A<G,G(#T^(&%R<F%Y*"=O
M;F4@8F%R)RP@)W1W;R!B87)S)RP@)W1H<F5E(&)A<G,G*2P*("`@("`@("`@
M("`@("`@("D["@H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI
M>F4H)&1A=&$I.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*
M("`@("`@("!E8VAO("`@("<\<')E/B<["B`@("`@("`@96-H;R`@("!H=&UL
M96YT:71I97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@
M("`@("`@(&5C:&\@("`@)SPO<')E/B<["B`@("!]"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI
M>F5.=6QL4')O<&5R=&EE<RYP:'``````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,Q,3,`,3`U,34T,S$P-3<`,#,P,S0V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_4$A0
M"B\J*@H@*B!4:&ES(&5X86UP;&4@9&5M;VYS=')A=&5S('1H92!U<V4@;V8*
M("H@:6=N;W)E3G5L;"`]/B!T<G5E"B`J"B`J($ET(&-A;B!B92!U<V5D('1O
M('-E<FEA;&EZ92!A;B!I;F1E>&5D(&%R<F%Y"B`J(&QI:V4@97AT+W-I;7!L
M97AM;"!D;V5S+"!B>2!U<VEN9R!T:&4@;F%M90H@*B!O9B!T:&4@<&%R96YT
M('1A9RP@=VAI;&4@;VUI='1I;F<@=&AI<R!T86<N"B`J"B`J($!A=71H;W(@
M4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*("`@(&5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["B`@("`*("`@(')E<75I<F5?;VYC92`G6$U,
M+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`B:6YD96YT(B`@("`@("`@(#T^("<@("`@
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@("`]
M/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@("1S97)I
M86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@
M("`@)&]B:F5C="`](&YE=R!S=&1#;&%S<R@I.PH@("`@)&]B:F5C="T^9F]O
M(#T@)V)A<B<["B`@("`D;V)J96-T+3YB87(@/2!N=6QL.PH@("`@"B`@("`D
M87)R87D@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9F]O)R`]/B`G
M8F%R)RP*("`@("`@("`@("`@("`@("`@("`G8F%R)R`]/B!N=6QL"B`@("`@
M("`@("`@("`@("`I.PH@("`@"B`@("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M
M/G-E<FEA;&EZ92@D;V)J96-T*3L*("`@(`H@("`@:68H("1R97-U;'0@/3T]
M('1R=64@*2!["B`@("`@("`@96-H;R`@("`B/'!R93XB.PH@("`@("`@(&5C
M:&\@("`@:'1M;&5N=&ET:65S*"1S97)I86QI>F5R+3YG971397)I86QI>F5D
M1&%T82@I*3L*("`@("`@("!E8VAO("`@("(\+W!R93XB.PH@("`@?0H*("`@
M("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1A<G)A>2D["B`@
M("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@("`@(&5C:&\@
M("`@(CQP<F4^(CL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I=&EE<R@D<V5R
M:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@("`@96-H;R`@
M("`B/"]P<F4^(CL*("`@('T*("`@(`H@("`@)'-E<FEA;&EZ97(M/G-E=$]P
M=&EO;B@G:6=N;W)E3G5L;"<L('1R=64I.PH@("`@)')E<W5L="`]("1S97)I
M86QI>F5R+3YS97)I86QI>F4H)&]B:F5C="D["B`@("`*("`@(&EF*"`D<F5S
M=6QT(#T]/2!T<G5E("D@>PH@("`@("`@(&5C:&\@("`@(CQP<F4^(CL*("`@
M("`@("!E8VAO("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R
M:6%L:7IE9$1A=&$H*2D["B`@("`@("`@96-H;R`@("`B/"]P<F4^(CL*("`@
M('T*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H
M)&%R<F%Y*3L*("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@
M("`@("`@96-H;R`@("`B/'!R93XB.PH@("`@("`@(&5C:&\@("`@:'1M;&5N
M=&ET:65S*"1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I*3L*("`@
M("`@("!E8VAO("`@("(\+W!R93XB.PH@("`@?0H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE3V)J
M96-T+G!H<````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,S0V`#$P-3$U-#,Q,#4W`#`R-C4W-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/U!(4`HO*BH*
M("H@5&AI<R!I<R!J=7-T(&$@8F%S:6,@97AA;7!L92!T:&%T('-H;W=S"B`J
M(&AO=R!O8FIE8W1S(&-A;B!B92!S97)I86QI>F5D('-O('1H97D@8V%N"B`J
M(&)E(&9U;&QY(')E<W1O<F5D(&QA=&5R+@H@*@H@*B!`875T:&]R(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"@HO*BH*("H@17AA;7!L
M92!C;&%S<R!T:&%T(&EM<&QE;65N=',@7U]S;&5E<"@I"B`J"B`J($!P86-K
M86=E("`@(%A-3%]397)I86QI>F5R"B`J($!S=6)P86-K86=E($5X86UP;&5S
M"B`J+PIC;&%S<R!->4-L87-S"GL*("`@('9A<B`D9F]O(#T@)U1H:7,@:7,@
M9F]O+B<["B`@("!V87(@)&)A<B`]("=4:&ES(&ES(&)A<BXG.PH@("`@"B`@
M("!F=6YC=&EO;B!?7W-L965P*"D*("`@('L*("`@("`@("!R971U<FX@87)R
M87DH)V9O;R<I.PH@("`@?0I]"@IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*
M+RHJ"B`J($QO860@6$U,7U-E<FEA;&EZ97(*("HO"G)E<75I<F5?;VYC92`G
M6$U,+U-E<FEA;&EZ97(N<&AP)SL*"@HO+R!T:&ES(&ES(&IU<W0@=&\@9V5T
M(&$@;F5S=&5D(&]B:F5C=`HD<&5A<D5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O
M<B@G5&AI<R!I<R!J=7-T(&%N(&5R<F]R(&]B:F5C="<L,3(S*3L*"B1O<'1I
M;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FEN9&5N="(@("`@
M("`@("`]/B`B("`@("(L"B`@("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A
M:R(@("`@("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@(")D969A=6QT
M5&%G3F%M92(@/3X@(G5N;F%M961)=&5M(BP*("`@("`@("`@("`@("`@("`@
M("`B='EP94AI;G1S(B`@("`@(#T^('1R=64*("`@("`@("`@("`@("`@("D[
M"@HD9F]O("`@(#T@("!N97<@<W1D0VQA<W,["B1F;V\M/G9A;'5E(#T@(DUY
M('9A;'5E(CL*)&9O;RT^97)R;W(@/2`D<&5A<D5R<F]R.PHD9F]O+3YX;6P@
M("`](")C;V]L(CL*"B1F;V\M/F]B:@D](&YE=R!->4-L87-S*"D["B1F;V\M
M/F%R<B`@(#T@87)R87DH*3L*)&9O;RT^>F5R;R`@/2`P.PH*"B1S97)I86QI
M>F5R(#T@)FYE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["@HD<F5S=6QT
M(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O*3L*"FEF*"`D<F5S=6QT
M(#T]/2!T<G5E("D@>PH))'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI
M>F5D1&%T82@I.PI]"@IE8VAO("<\<')E/B<["F5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D>&UL*3L*96-H;R`G/"]P<F4^)SL*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE
M<B]E>&%M<&QE<R]S97)I86QI>F521$8N<&AP````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0S-C0`,3`U
M,34T,S$P-3<`,#(V,#`S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@
M:&]W('1O(&-R96%T92!A;B!21$8@9&]C=6UE;G0*("H@=VET:"!A(&9E=R!L
M:6YE<R!O9B!C;V1E+@H@*B!4:&ES(&-A;B!A;'-O(&)E(&1O;F4@=VET:"!M
M;V1E(#T^('-I;7!L97AM;`H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED
M="`\<V-H<W1`<&AP+FYE=#X*("H@0'-E92`@("!S97)I86QI>F5);F1E>&5D
M07)R87DN<&AP"B`J+PH@("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B`@
M("!R97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["@H@("`@)&]P
M=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@(FEN9&5N
M="(@("`@("`@("`@/3X@(B`@("`B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`B;&EN96)R96%K(B`@("`@("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`B='EP94AI;G1S(B`@("`@("`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@(F%D9$1E8VPB("`@("`@("`@/3X@=')U92P*("`@
M("`@("`@("`@("`@("`@("`@("`@(F5N8V]D:6YG(B`@("`@("`@/3X@(E54
M1BTX(BP*"0D)"0D)(G)O;W1.86UE(B`@("`@("`@/3X@(G)D9CI21$8B+`H@
M("`@("`@("`@("`@("`@("`@("`@("`B<F]O=$%T=')I8G5T97,B("`]/B!A
M<G)A>2@B=F5R<VEO;B(@/3X@(C`N.3$B*2P*"0D)"0D)(F1E9F%U;'1486=.
M86UE(B`@/3X@(FET96TB+`H@("`@("`@("`@("`@("`@("`@("`@("`B871T
M<FEB=71E<T%R<F%Y(B`]/B`B7V%T=')I8G5T97,B"B`@("`@("`@("`@("`@
M("`@("`@*3L*("`@(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA
M;&EZ97(H)&]P=&EO;G,I.PH*("`@(`H@("`@)')D9B`@("`]("`@87)R87DH
M"@D)"0D)"2)C:&%N;F5L(B`]/B!A<G)A>2@*"0D)"0D)"0D)"0DB=&ET;&4B
M(#T^(")%>&%M<&QE(%)$1B!C:&%N;F5L(BP*"0D)"0D)"0D)"0DB;&EN:R(@
M(#T^(")H='1P.B\O=W=W+G!H<"UT;V]L<RYD92(L"@D)"0D)"0D)"0D)(FEM
M86=E(@D]/@EA<G)A>2@*"0D)"0D)"0D)"0D)"0D)"2)T:71L92()/3X@(D5X
M86UP;&4@:6UA9V4B+`H)"0D)"0D)"0D)"0D)"0D)(G5R;"()/3X)(FAT='`Z
M+R]W=W<N<&AP+71O;VQS+F1E+VEM86=E+F=I9B(L"@D)"0D)"0D)"0D)"0D)
M"0DB;&EN:R()/3X)(FAT='`Z+R]W=W<N<&AP+71O;VQS+F1E(@H)"0D)"0D)
M"0D)"0D)"0DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(")?871T<FEB=71E<R(@/3X@87)R87DH(")R9&8Z86)O=70B
M(#T^(")H='1P.B\O97AA;7!L92YC;VTO9F]O8F%R+FAT;6PB("DL"@D)"0D)
M"0D)"0D)87)R87DH"@D)"0D)"0D)"0D)"2)T:71L92()/3X@(D5X86UP;&4@
M:71E;2(L"@D)"0D)"0D)"0D)"2)L:6YK(@D]/B`B:'1T<#HO+V5X86UP;&4N
M8V]M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(E]A='1R:6)U=&5S(B`]/B!A<G)A>2@@(G)D9CIA8F]U="(@
M/3X@(FAT='`Z+R]E>&%M<&QE+F-O;2]F;V]B87(N:'1M;"(@*0H)"0D)"0D)
M"0D)"2DL"@D)"0D)"0D)"0D)87)R87DH"@D)"0D)"0D)"0D)"2)T:71L92()
M/3X@(D%N;W1H97(@:71E;2(L"@D)"0D)"0D)"0D)"2)L:6YK(@D]/B`B:'1T
M<#HO+V5X86UP;&4N8V]M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(E]A='1R:6)U=&5S(B`]/B!A<G)A>2@@
M(G)D9CIA8F]U="(@/3X@(FAT='`Z+R]E>&%M<&QE+F-O;2]F;V]B87(N:'1M
M;"(@*0H)"0D)"0D)"0D)"2DL"@D)"0D)"0D)"0D)87)R87DH"@D)"0D)"0D)
M"0D)"2)T:71L92()/3X@(DD@=&AI;FL@>6]U(&=E="!I="XN+B(L"@D)"0D)
M"0D)"0D)"2)L:6YK(@D]/B`B:'1T<#HO+V5X86UP;&4N8V]M(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(E]A
M='1R:6)U=&5S(B`]/B!A<G)A>2@@(G)D9CIA8F]U="(@/3X@(FAT='`Z+R]E
M>&%M<&QE+F-O;2]F;V]B87(N:'1M;"(@*0H)"0D)"0D)"0D)"2D*"0D)"0D)
M"0D)"2D*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D<F5S=6QT
M(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D<F1F*3L*("`@(`H@("`@:68H
M("1R97-U;'0@/3T]('1R=64@*2!["B`@("`@("`@96-H;R`@("`B/'!R93XB
M.PH@("`@("`@(&5C:&\@("`@:'1M;&5N=&ET:65S*"1S97)I86QI>F5R+3YG
M971397)I86QI>F5D1&%T82@I*3L*("`@("`@("!E8VAO("`@("(\+W!R93XB
M.PH@("`@?0H_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]8
M34Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5396QE8W1I=F5!='1R
M:6)U=&5S+G!H<```````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#,Q-3$`,3`U,34T,S$P-3<`,#,Q,S4S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_4$A0"B\J*@H@*B!4:&ES('-H
M;W=S('1H870@6$U,7U-E<FEA;&EZ97(@:7,@86)L92!T;R!W;W)K('=I=&@*
M("H@96UP='D@87)R87ES"B`J"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T
M(#QS8VAS=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*
M<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*)&1A=&$@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@(&%R<F%Y*"=N86UE)R`]/B`G4W5P97)M
M86XG+"`G86=E)R`]/B`S-"P@)W)E86QN86UE)R`]/B`G0VQA<FL@2V5N="<I
M+`H@("`@("`@("`@("`@("`@87)R87DH)VYA;64G(#T^("="871M86XG+"`G
M86=E)R`]/B`S,BP@)W)E86QN86UE)R`]/B`G0G)U8V4@5V%Y;F4G*2P*("`@
M("`@("`@("`@("`@("=V:6QL86EN)R`]/B!A<G)A>2@G;F%M92<@/3X@)U!R
M;V9E<W-O<B!:;V]M)RP@)V%G92<@/3X@)W5N:VYO=VXG+"`G<F5A;&YA;64G
M(#T^("=(=6YT97(@6F]L;VUO;B<I"B`@("`@("`@("`@("D["@HD<V5R:6%L
M:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@I.PHD<V5R:6%L:7IE<BT^<V5T
M3W!T:6]N*%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0L("<@("`@)RD[
M"B1S97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U-%4DE!3$E:15)?3U!424].
M7T1%1D%53%1?5$%'+"`G:&5R;R<I.PH*)'-E<FEA;&EZ97(M/G-E<FEA;&EZ
M92@D9&%T82D["F5C:&\@)SQP<F4^)SL*96-H;R`B1&5F875L="!B96AA=FEO
M=7(Z7&XB.PIE8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'-E<FEA;&EZ97(M/F=E
M=%-E<FEA;&EZ961$871A*"DI.PIE8VAO("<\+W!R93XG.PH*)'-E<FEA;&EZ
M97(M/G-E=$]P=&EO;BA834Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%3
M7T%45%))0E5415,L('1R=64I.PH*)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D
M9&%T82D["F5C:&\@)SQP<F4^)SL*96-H;R`B6$U,7U-%4DE!3$E:15)?3U!4
M24].7U-#04Q!4E]!4U]!5%1224)55$53(#T@=')U93I<;B(["F5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H
M*2D["F5C:&\@)SPO<')E/B<["@HD<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-
M3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"551%4RP@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE<F\G("`@(#T^(&%R
M<F%Y*"=N86UE)RP@)V%G92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=V:6QL86EN)R`]/B!A<G)A>2@G<F5A;&YA;64G*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@("`@("D["@HD<V5R
M:6%L:7IE<BT^<V5R:6%L:7IE*"1D871A*3L*96-H;R`G/'!R93XG.PIE8VAO
M(")834Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415,@
M:7,@86X@87)R87DZ7&XB.PIE8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'-E<FEA
M;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PIE8VAO("<\+W!R93XG.PH_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E
M<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE5VET:$%T=')I8G5T97,N<&AP
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,C,V`#$P-3$U-#,Q,#4W`#`S,#,T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/U!(4`HO*BH*("H@6$U,(%-E<FEA;&EZ
M97(@97AA;7!L90H@*@H@*B!4:&ES(&5X86UP;&4@9&5M;VYS=')A=&5S+"!H
M;W<@6$U,7U-E<FEA;&EZ97(@:7,@86)L90H@*B!T;R!S97)I86QI>F4@<V-A
M;&%R('9A;'5E<R!A<R!A;B!A='1R:6)U=&4@:6YS=&5A9"!O9B!A(&YE<W1E
M9"!T86<N"B`J"B`J(%1H92!S86UE('-T<G5C='5R92!L:6ME(&EN('-E<FEA
M;&EZ94]B:F5C="YP:'`@:7,@<V5R:6%L:7IE9"X*("H*("H@0&%U=&AO<B`@
M4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*("`@(&5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R
M:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@(")I;F1E;G0B("`@("`@("`@("`@(#T^("(@("`@
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@("`@
M("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@(F1E9F%U;'14
M86=.86UE(B`@("`@/3X@(G5N;F%M961)=&5M(BP*"0D)"0D)(G-C86QA<D%S
M071T<FEB=71E<R(@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`I.PH@
M("`@"B`@("`O+R!T:&ES(&ES(&IU<W0@=&\@9V5T(&$@;F5S=&5D(&]B:F5C
M=`H@("`@)'!E87)%<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@
M:G5S="!A;B!E<G)O<B!O8FIE8W0G+#$R,RD["@D*("`@("1F;V\@("`@/2`@
M(&YE=R!S=&1#;&%S<SL*("`@(`H@("`@)&9O;RT^=F%L=64@/2`B37D@=F%L
M=64B.PH@("`@)&9O;RT^97)R;W(@/2`D<&5A<D5R<F]R.PH@("`@)&9O;RT^
M>&UL("`@/2`B8V]O;"(["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-
M3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S
M97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF*"`D<F5S
M=6QT(#T]/2!T<G5E("D@>PH)"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R
M:6%L:7IE9$1A=&$H*3L*"@D@("`@96-H;PDB/'!R93XB.PH)("`@('!R:6YT
M7W(H(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*"2`@("!E8VAO"2(\+W!R
M93XB.PH@("`@?2!E;'-E('L*"0EE8VAO"2(\<')E/B(["@D)<')I;G1?<B@D
M<F5S=6QT*3L*"0EE8VAO"2(\+W!R93XB.PH)?0H*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I
M86QI>F57:71H071T<FEB=71E<S(N<&AP````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T,S4`,3`U,34T,S$P-3<`,#,P-#,Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M4$A0"B\J*@H@*B!834P@4V5R:6%L:7IE<B!E>&%M<&QE"B`J"B`J(%1H:7,@
M97AA;7!L92!D96UO;G-T<F%T97,L(&AO=R!834Q?4V5R:6%L:7IE<B!I<R!A
M8FQE"B`J('1O('-E<FEA;&EZ92!P<F5D969I;F5D('9A;'5E<R!A<R!T:&4@
M871T<FEB=71E<R!O9B!A('1A9PH@*@H@*B!`875T:&]R("!3=&5P:&%N(%-C
M:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PH@("`@97)R;W)?<F5P;W)T:6YG
M*$5?04Q,*3L*"B`@("!R97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H
M<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@("`@(FEN9&5N="(@("`@("`@("`@("`@/3X@(B`@("`B+`H@("`@("`@
M("`@("`@("`@("`@("`@("`B;&EN96)R96%K(B`@("`@("`@("`]/B`B7&XB
M+`H@("`@("`@("`@("`@("`@("`@("`@("`B9&5F875L=%1A9TYA;64B("`@
M("`]/B`B=6YN86UE9$ET96TB+`H)"0D)"0DB<V-A;&%R07-!='1R:6)U=&5S
M(B`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@(F%T=')I8G5T
M97-!<G)A>2(@("`@/3X@)U]A='1R:6)U=&5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@(F-O;G1E;G1.86UE(B`@("`@("`@/3X@)U]C;VYT96YT)PH@
M("`@("`@("`@("`@("`@("`@("D["@H@("`@)&1A=&$@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G9F]O)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)U]A='1R:6)U=&5S)R`]/B!A<G)A
M>2@@)W9E<G-I;VXG(#T^("<Q+C`G+"`G9F]O)R`]/B`G8F%R)R`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7V-O;G1E;G0G("`@
M(#T^("=T97-T)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*2P*("`@("`@("`@("`@("`@("`@("`G<V-H<W0G(#T^("=3=&5P:&%N(%-C
M:&UI9'0G"B`@("`@("`@("`@("`@("`I.R`@("`*("`@(`H@("`@)'-E<FEA
M;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH@("`@"B`@
M("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9&%T82D["B`@
M("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH)"21X;6P@/2`D<V5R
M:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*"@D@("`@96-H;PDB/'!R
M93XB.PH)("`@('!R:6YT7W(H(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*
M"2`@("!E8VAO"2(\+W!R93XB.PH@("`@?2!E;'-E('L*"0EE8VAO"2(\<')E
M/B(["@D)<')I;G1?<B@D<F5S=6QT*3L*"0EE8VAO"2(\+W!R93XB.PH)?0H*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]3
M97)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A#;VUM96YT+G!H<```
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C$P,``Q,#4Q-30S,3`U-P`P,C<V,3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@:7,@:G5S
M="!A(&)A<VEC(&5X86UP;&4@=&AA="!S:&]W<PH@*B!H;W<@;V)J96-T<R!C
M86X@8F4@<V5R:6%L:7IE9"!S;R!T:&5Y(&-A;@H@*B!B92!F=6QL>2!R97-T
M;W)E9"!L871E<BX*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"YN970^"B`J+PH@("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*
M"B`@("!R97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["@H@("`@
M)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7TE.1$5.5"`@("`@(#T^("<@("`@)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TQ)
M3D5"4D5!2U,@(#T^(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E]#3TU-14Y47TM%62`]/B`G8V]M;65N="<*
M("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D9F]O(#T@;F5W('-T
M9$-L87-S.PH@("`@)&9O;RT^8V]M;65N="`]("=4:&ES(&ES(&$@8V]M;65N
M="<["B`@("`D9F]O+3YV86QU92`@(#T@)TUY('9A;'5E)SL*("`@(`H@("`@
M)&9O;RT^8F%R("`@("`](&YE=R!S=&1#;&%S<R@I.PH@("`@)&9O;RT^8F%R
M+3YV86QU92`@(#T@)T%N;W1H97(@=F%L=64G.PH@("`@)&9O;RT^8F%R+3YC
M;VUM96YT(#T@)T%N;W1H97(@8V]M;65N="<["B`@("`*("`@("1F;V\M/G1O
M;6%T;R`@("`@("`@("`](&YE=R!S=&1#;&%S<R@I.PH@("`@)&9O;RT^=&]M
M871O+3YC;VUM96YT(#T@)T%N9"!A(&QA<W0@8V]M;65N="<["B`@("`*("`@
M("1S97)I86QI>F5R(#T@)FYE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD[
M"B`@("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F
M;V\I.PH@("`@"B`@("!I9B`H)')E<W5L="`]/3T@=')U92D@>PH)"21X;6P@
M/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*("`@('T*"B`@
M("!E8VAO("<\<')E/B<["B`@("!P<FEN=%]R*&AT;6QS<&5C:6%L8VAA<G,H
M)'AM;"DI.PH@("`@96-H;R`G/"]P<F4^)SL*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O97AA
M;7!L92YX;6P``````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3(R`#$P-3$U-#,Q,#4W`#`R-3$Q
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M>&UL/@H@("`@/'1E<W0@9F]O/2)B87(B/@H@("`@("`@(%1E<W0*("`@("`@
M("`\=&%G/G1E<W0\+W1A9SX*("`@(#PO=&5S=#X*/"]X;6P^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A$
M=&0N<&AP```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`P-P`Q,#4Q-30S,3`U-P`P,C8W,C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]02%`*+RHJ"B`J
M(%1H:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@861D(&$@1&]C5'EP92!$96-L
M87)A=&EO;B!T;R!T:&4@6$U,(&1O8W5M96YT"B`J"B`J($!A=71H;W(@4W1E
M<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*("`@(&5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D["@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L
M:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@(")I;F1E;G0B("`@("`]/B`B("`@("(L"B`@("`@("`@
M("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`]/B`B7&XB+`H@("`@("`@
M("`@("`@("`@("`@("`@("`B861D1&5C;"(@("`@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@(F%D9$1O8W1Y<&4B(#T^('1R=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@(")D;V-T>7!E(B`@("`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W5R:2<@/3X@)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,2XP
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VED)R`]/B`G+2\O4$A0+R]014%2+T141"!004-+04=%(#`N,2<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@("1S97)I86QI>F5R
M(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*"B`@("`D9F]O("`@
M(#T@("!014%2.CIR86ES945R<F]R*")*=7-T(&$@=&5S="(L(#$R,S0I.R`@
M("`*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H
M)&9O;RD["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@
M("`@(&5C:&\@("`@(CQP<F4^(CL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I
M=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@
M("`@96-H;R`@("`B/"]P<F4^(CL*("`@('T*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O
M97AA;7!L97,O<V5R:6%L:7IE5VET:$EN9&5N=&5D071T<FEB=71E<RYP:'``
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-C$R`#$P-3$U
M-#,Q,#4W`#`S,C`Q-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/U!(4`HO*BH*("H@6$U,(%-E<FEA;&EZ97(@97AA;7!L
M90H@*@H@*B!4:&ES(&5X86UP;&4@9&5M;VYS=')A=&5S+"!H;W<@6$U,7U-E
M<FEA;&EZ97(@:7,@86)L90H@*B!T;R!S97)I86QI>F4@<V-A;&%R('9A;'5E
M<R!A<R!A;B!A='1R:6)U=&4@:6YS=&5A9"!O9B!A(&YE<W1E9"!T86<N"B`J
M"B`J($EN('1H:7,@97AA;7!L92!T86=S('=I=&@@;6]R92!T:&%N(&]N92!A
M='1R:6)U=&4@8F5C;VUE"B`J(&UU;'1I;&EN92!T86=S+"!A<R!E86-H(&%T
M=')I8G5T92!G971S('=R:71T96X@=&\@80H@*B!S97!A<F%T92!L:6YE(&%S
M("=I;F1E;G1!='1R:6)U=&5S)R!I<R!S970@=&\@)U]A=71O)RX*("H*("H@
M0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*
M("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["B`@("!R97%U:7)E7V]N8V4@
M)UA-3"]397)I86QI>F5R+G!H<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@(FEN9&5N="(@("`@("`@("`@("`@
M/3X@(B`@("`B+`H@("`@("`@("`@("`@("`@("`@("`@("`B;&EN96)R96%K
M(B`@("`@("`@("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M='EP94AI;G1S(B`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@(F1E9F%U;'1486=.86UE(B`@("`@/3X@(G5N;F%M961)=&5M
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@(G-C86QA<D%S071T<FEB=71E
M<R(@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@(FEN9&5N=$%T
M=')I8G5T97,B("`@/3X@(E]A=71O(@H@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`*("`@("\O('1H:7,@:7,@:G5S="!T;R!G970@82!N97-T960@;V)J
M96-T"B`@("`D<&5A<D5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G5&AI<R!I
M<R!J=7-T(&%N(&5R<F]R(&]B:F5C="<L,3(S*3L*"0H@("`@)&9O;R`@("`]
M("`@;F5W('-T9$-L87-S.PH@("`@"B`@("`D9F]O+3YV86QU92`](")->2!V
M86QU92(["B`@("`D9F]O+3YE<G)O<B`]("1P96%R17)R;W(["B`@("`D9F]O
M+3YX;6P@("`](")C;V]L(CL*("`@(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@
M6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH@("`@"B`@("`D<F5S=6QT(#T@
M)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O*3L*("`@(`H@("`@:68H("1R
M97-U;'0@/3T]('1R=64@*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG9713
M97)I86QI>F5D1&%T82@I.PH*"2`@("!E8VAO"2(\<')E/B(["@D@("`@<')I
M;G1?<B@@:'1M;'-P96-I86QC:&%R<R@D>&UL*2`I.PH)("`@(&5C:&\)(CPO
M<')E/B(["B`@("!](&5L<V4@>PH)"65C:&\)(CQP<F4^(CL*"0EP<FEN=%]R
M*"1R97-U;'0I.PH)"65C:&\)(CPO<')E/B(["@E]"@H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H
M3F%M97-P86-E+G!H<```````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,S,`,3`U,34T,S$P-3<`,#,P,3`W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_4$A0"B\J*@H@
M*B!%>&%M<&QE('1H870@8W)E871E<R!T86=S('=I=&@@82!N86UE<W!A8V4*
M("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^
M"B`J+PIE<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*<F5Q=6ER95]O;F-E("=8
M34PO4V5R:6%L:7IE<BYP:'`G.PH*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`G:6YD96YT)R`@("`@("`@(#T^("<@("<L"B`@("`@
M("`@("`@("`@("`@("`@)VQI;F5B<F5A:R<@("`@("`]/B`B7&XB+`H@("`@
M("`@("`@("`@("`@("`@("=D969A=6QT5&%G3F%M92<@/3X@)VET96TG+`H@
M("`@("`@("`@("`@("`@("`@("=N86UE<W!A8V4G("`@("`@/3X@)V9O;R<*
M("`@("`@("`@("`@("`@("D["@HD9F]O("`@(#T@("!N97<@<W1D0VQA<W,[
M"B1F;V\M/G9A;'5E(#T@)TUY('9A;'5E)SL*)&9O;RT^>&UL("`@/2`G8V]O
M;"<["@HD9F]O+3YO8FH)/2!N97<@<W1D0VQA<W,["B1F;V\M/F%R<B`@(#T@
M87)R87DH*3L*)&9O;RT^>F5R;R`@/2`P.PH*)'-E<FEA;&EZ97(@/2`F;F5W
M(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*"B1R97-U;'0@/2`D<V5R:6%L
M:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH*:68H("1R97-U;'0@/3T]('1R=64@
M*2!["@DD>&UL(#T@)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D[
M"GT*"F5C:&\))SQP<F4^)SL*<')I;G1?<B@@:'1M;'-P96-I86QC:&%R<R@D
M>&UL*2`I.PIE8VAO"2<\+W!R93XG.PH*+R\@86QS;R!P87-S('1H92!54DD*
M)'-E<FEA;&EZ97(M/G-E=$]P=&EO;B@G;F%M97-P86-E)RP@87)R87DH)V)A
M<B<L("=H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U-E<FEA;&EZ
M97(G*2D["@HD<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O
M*3L*"FEF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH))'AM;"`]("1S97)I86QI
M>F5R+3YG971397)I86QI>F5D1&%T82@I.PI]"@IE8VAO"2<\<')E/B<["G!R
M:6YT7W(H(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*96-H;PDG/"]P<F4^
M)SL*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R
M+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A486=-87`N<&AP````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#$T-``Q,#4Q
M-30S,3`U-P`P,C<S-S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]02%`*+RHJ"B`J(%A-3"!397)I86QI>F5R(&5X86UP
M;&4*("H*("H@5&AI<R!E>&%M<&QE(&1E;6]N<W1R871E<RP@:&]W(%A-3%]3
M97)I86QI>F5R(&ES(&%B;&4*("H@=&\@<V5R:6%L:7IE('-C86QA<B!V86QU
M97,@87,@86X@871T<FEB=71E(&EN<W1E860@;V8@82!N97-T960@=&%G+@H@
M*@H@*B!);B!T:&ES(&5X86UP;&4@=&%G<R!W:71H(&UO<F4@=&AA;B!O;F4@
M871T<FEB=71E(&)E8V]M90H@*B!M=6QT:6QI;F4@=&%G<RP@87,@96%C:"!A
M='1R:6)U=&4@9V5T<R!W<FET=&5N('1O(&$*("H@<V5P87)A=&4@;&EN92!A
M<R`G:6YD96YT071T<FEB=71E<R<@:7,@<V5T('1O("=?875T;R<N"B`J"B`J
M($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO
M"B`@("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PH@("`@<F5Q=6ER95]O;F-E
M("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("=I;F1E;G0G("`@("`@("`@("`@
M(#T^("<@("`@)RP*("`@("`@("`@("`@("`@("`@("`@("`@)VQI;F5B<F5A
M:R<@("`@("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M)VUO9&4G("`@("`@("`@("`@("`@/3X@)W-I;7!L97AM;"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=R;V]T3F%M92<)"0D@/3X@)VET96US)PH@("`@
M("`@("`@("`@("`@("`@("D["@H@("`@)&1A=&$@/2!A<G)A>2@*"0D)"0DG
M:71E;2<@/3X@87)R87DH(&%R<F%Y*`H)"0D)"0D)"0D))W1I=&QE)R`@("`@
M("`]/B`G1F]O8F%R(2<L"@D)"0D)"0D)"0DG9&5S8W)I<'1I;VXG(#T^("=4
M:&ES(&ES('-O;64@=&5X="XN+BXG+`H)"0D)"0D)"0D))VQI;FLG("`@("`@
M("`]/B`G:'1T<#HO+V9O;V)A<BYC;VTG"@D)"0D)"0D)"2DL"@D)"0D)"0D)
M"6%R<F%Y*`H)"0D)"0D)"0D))W1I=&QE)R`@("`@("`]/B`G1F]O8F%R,B$G
M+`H)"0D)"0D)"0D))V1E<V-R:7!T:6]N)R`]/B`G5&AI<R!I<R!S;VUE('1E
M>'0N_"`F=75M;#L@Y"#V)RP*"0D)"0D)"0D)"2=L:6YK)R`@("`@("`@/3X@
M)VAT='`Z+R]F;V]B87(N8V]M)PH)"0D)"0D)"0DI"@D)"0D)"0D)*0H)("`@
M(`D)"0D)"0D)"0D)"0H@("`@"0D)*3L*("`@("`@("`@("`@("`@("`@("`*
M("`@(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P
M=&EO;G,I.PH@("`@"B`@("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA
M;&EZ92@D9&%T82D["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@
M>PH)"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*
M"@D@("`@96-H;PDG/'!R93XG.PH)("`@('!R:6YT7W(H(&AT;6QS<&5C:6%L
M8VAA<G,H)'AM;"D@*3L*"2`@("!E8VAO"2<\+W!R93XG.PH@("`@?2!E;'-E
M('L*"0EE8VAO"2<\<')E/B<["@D)<')I;G1?<B@D<F5S=6QT*3L*"0EE8VAO
M"2<\+W!R93XG.PH)?0H*"21N97=/<'1I;VYS(#T@87)R87DH"@D)"0D)"2=R
M;V]T3F%M92<@/3X@)V)O9'DG+`H)"0D)"0DG<F5P;&%C945N=&ET:65S)R`]
M/B!834Q?4T5224%,25I%4E]%3E1)5$E%4U](5$U,+`H)"0D)"0DG=&%G36%P
M)R`@(#T^(&%R<F%Y*`H)"0D)"0D@("`@("`@("`@("`@("`@("`@("`@)VET
M96TG("`@("`@("`]/B`G9&EV)RP*"0D)"0D)("`@("`@("`@("`@("`@("`@
M("`@("=T:71L92<@("`@("`@/3X@)V@Q)RP*"0D)"0D)("`@("`@("`@("`@
M("`@("`@("`@("=D97-C<FEP=&EO;B<@/3X@)W`G+`H)"0D)"0D@("`@("`@
M("`@("`@("`@("`@("`@)VQI;FLG("`@("`@("`]/B`G='0G"@D)"0D)"2`@
M("`@("`@("`@("`@("`@("D*"0D)"0DI.PH)"B`@("`D<F5S=6QT(#T@)'-E
M<FEA;&EZ97(M/G-E<FEA;&EZ92@D9&%T82P@)&YE=T]P=&EO;G,I.PH@("`@
M"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*"0DD>&UL(#T@)'-E<FEA
M;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D["@H)("`@(&5C:&\))SQP<F4^
M)SL*"2`@("!P<FEN=%]R*"!H=&UL<W!E8VEA;&-H87)S*"1X;6PI("D["@D@
M("`@96-H;PDG/"]P<F4^)SL*("`@('T@96QS92!["@D)96-H;PDG/'!R93XG
M.PH)"7!R:6YT7W(H)')E<W5L="D["@D)96-H;PDG/"]P<F4^)SL*"7T*"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE06YY6$U,+G!H<```
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-3`V,0`Q,#4Q-30S,3`U-P`P,C<P,S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA
M;7!L92!S:&]W<R!D:69F97)E;G0@;65T:&]D<R!H;W<*("H@6$U,7U5N<V5R
M:6%L:7IE<B!C86X@8F4@=7-E9"!T;R!C<F5A=&4@9&%T82!S=')U8W1U<F5S
M"B`J(&9R;VT@6$U,(&1O8W5M96YT<RX*("H*("H@0&%U=&AO<B`@4W1E<&AA
M;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T:6YG
M*$5?04Q,*3L*"B\O('1H:7,@:7,@82!S:6UP;&4@6$U,(&1O8W5M96YT"B1X
M;6P@/2`G/'5S97)S/B<@+@H@("`@("`@)R`@/'5S97(@:&%N9&QE/2)S8VAS
M="(^4W1E<&AA;B!38VAM:61T/"]U<V5R/B<@+@H@("`@("`@)R`@/'5S97(@
M:&%N9&QE/2)M:B(^36%R=&EN($IA;G-E;CPO=7-E<CXG("X*("`@("`@("<@
M(#QG<F]U<"!N86UE/2)Q82(^4$5!4B!102!496%M/"]G<F]U<#XG("X*("`@
M("`@("<@(#QF;V\@:60](G1E<W0B/E1H:7,@:7,@:&%N9&QE9"!B>2!T:&4@
M9&5F875L="!K97E!='1R:6)U=&4\+V9O;SXG("X*("`@("`@("<@(#QF;V\@
M:60](G1E<W0R(CY!;F]T:&5R(&9O;R!T86<\+V9O;SXG("X*("`@("`@("<\
M+W5S97)S/B<["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP
M)SL*"B\O(&-O;7!L97@@<W1R=6-T=7)E<R!A<F4@87)R87ES+"!T:&4@:V5Y
M(&ES('1H92!A='1R:6)U=&4@)VAA;F1L92<@;W(@)VYA;64G+"!I9B!H86YD
M;&4@:7,@;F]T('!R97-E;G0*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E012`]
M/B`G87)R87DG+`H@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7T%45%))0E5415]+15D@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=U<V5R)R`@("`@/3X@)VAA;F1L92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=G<F]U<"<@("`@/3X@)VYA;64G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G(V1E9F%U;'0G(#T^("=I9"<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*
M("`@("`@("`@("`@("`@("D["@HO+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@
M=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O
M<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D;W!T
M:6]N<RD["@HO+R!U<V5R:6%L:7IE('1H92!D;V-U;65N=`HD<W1A='5S(#T@
M)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;"P@9F%L<V4I.R`@("`*
M"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O
M<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D
M871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@
M("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO
M("<\+W!R93XG.PI]"@H*+R\@=6YS97)I86QI>F4@:70@86=A:6X@86YD(&-H
M86YG92!T:&4@8V]M<&QE>%1Y<&4@;W!T:6]N"B\O(&)U="!L96%V92!O=&AE
M<B!O<'1I;VYS('5N=&]U8VAE9`HO+R!N;W<@8V]M<&QE>"!T>7!E<R!W:6QL
M(&)E(&%N(&]B:F5C="P@86YD('1H92!P<F]P97)T>2!N86UE('=I;&P@8F4@
M:6X@=&AE"B\O(&%T=')I8G5T92`G:&%N9&QE)PHD<W1A='5S(#T@)'5N<V5R
M:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;"P@9F%L<V4L(&%R<F%Y*%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%(#T^("=O8FIE8W0G*2D[
M"@II9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R
M;W(Z("<@+B`D<W1A='5S+3YG971-97-S86=E*"D["GT@96QS92!["B`@("`D
M9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*
M("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H
M;R`G/"]P<F4^)SL*?0H*+R\@=6YS97)I86QI>F4@:70@86=A:6X@86YD(&-H
M86YG92!T:&4@8V]M<&QE>%1Y<&4@;W!T:6]N"B\O(&%N9"!R97-E="!A;&P@
M;W1H97(@;W!T:6]N<PHO+R!.;W<L('1H97)E)W,@;F\@:V5Y('-O('1H92!T
M86=S(&%R92!S=&]R960@:6X@86X@87)R87D*)'-T871U<R`]("1U;G-E<FEA
M;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PL(&9A;'-E+"!A<G)A>2A834Q?54Y3
M15))04Q)6D527T]05$E/3E]/5D524DE$15]/4%1)3TY3(#T^('1R=64L(%A-
M3%]53E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%(#T^("=O8FIE8W0G
M*2D[("`@(`H*:68@*%!%05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C
M:&\@)T5R<F]R.B`G("X@)'-T871U<RT^9V5T365S<V%G92@I.PI](&5L<V4@
M>PH@("`@)&1A=&$@/2`D=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$
M871A*"D["B`@("!E8VAO("<\<')E/B<["B`@("!P<FEN=%]R*"1D871A*3L*
M("`@(&5C:&\@)SPO<')E/B<["GT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA
M;7!L97,O=6YS97)I86QI>F5#;&%S<TYA;65S+G!H<```````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S`V`#$P-3$U-#,Q
M,#4W`#`R-S<U-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/U!(4`HO*BH*("H@17AA;7!L92!T:&%T('-H;W=S(&AO=R!T
M;R!I;F9L=65N8V4@=&AE(&-L87-S97,@=&AA="!A<F4@8W)E871E9"X*("H*
M("H@0&%U=&AO<B`@("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("H@0&-A=&5G;W)Y("`@(%A-3`H@*B!`<&%C:V%G92`@("`@6$U,7U-E
M<FEA;&EZ97(*("H@0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PIE<G)O<E]R
M97!O<G1I;F<H15]!3$PI.PH*+RHJ"B`J('5S97,@6$U,7U5N<V5R:6%L:7IE
M<@H@*B\*<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@HD
M>&UL(#T@/#P\14]4"CQR;V]T/@H@("`\9F]O/@H@("`@(#QT>7!E/F)A<CPO
M='EP93X*("`@/"]F;V\^"B`@(#QB87(@='EP93TB9F]O(B\^"CPO<F]O=#X*
M14]4.PH*8VQA<W,@9F]O"GL*?0IC;&%S<R!B87(*>PI]"@IE8VAO("<\<')E
M/B<["B\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N
M9"!I;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I86QI>F5R
M(#T@)FYE=R!834Q?56YS97)I86QI>F5R*"D["B1U;G-E<FEA;&EZ97(M/G-E
M=$]P=&EO;BA834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E012P@
M)V]B:F5C="<I.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%4U]005)312P@=')U92D["B1U;G-E
M<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?54Y315))04Q)6D527T]05$E/3E]2
M15154DY?4D5354Q4+"!T<G5E*3L*"B1D871A(#T@)'5N<V5R:6%L:7IE<BT^
M=6YS97)I86QI>F4H)'AM;"D[("`@(`IV87)?9'5M<"@D9&%T82D["@IE8VAO
M(")$;R!N;W0@=7-E('1A9VYA;64@87,@8VQA<W,@;F%M95QN(CL*)'5N<V5R
M:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7U1!
M1U]!4U]#3$%34TY!344L(&9A;'-E*3L*)&1A=&$@/2`D=6YS97)I86QI>F5R
M+3YU;G-E<FEA;&EZ92@D>&UL*3L@("`@"G9A<E]D=6UP*"`D9&%T82`I.PH*
M96-H;R`B57-E(&$@9&EF9F5R96YT(&1E9F%U;'0@8VQA<W-<;B(["B1U;G-E
M<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?54Y315))04Q)6D527T]05$E/3E]$
M149!54Q47T-,05-3+"`G9F]O)RD["B1D871A(#T@)'5N<V5R:6%L:7IE<BT^
M=6YS97)I86QI>F4H)'AM;"D[("`@(`IV87)?9'5M<"@@)&1A=&$@*3L*"F5C
M:&\@)SPO<')E/B<["C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ945N8V]D
M960N<&AP````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$V-C4`,3`U,34T,S$P-3<`,#(W,C<U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_4$A0"B\J*@H@*B!4
M:&ES(&5X86UP;&4@<VAO=W,@:&]W('1O('-E="!A(&1I9F9E<F5N="!T87)G
M970@96YC;V1I;F<*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS
M8VAS=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"G)E
M<75I<F5?;VYC92`G6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PH*)'AM;"`]("<\
M9&EC=#X*("`@/'=O<F0^"B`@("`@/&5N/F-H:6-K96YW:6YG<SPO96X^"B`@
M("`@/&1E/B<N=71F.%]E;F-O9&4H)TCD:&YC:&5N9FS\9V5L)RDN)SPO9&4^
M"B`@(#PO=V]R9#X*(#PO9&EC=#XG.PH@("`@"B\O('-P96-I9GD@9&EF9F5R
M96YT('-O=7)C92!A;F0@=&%R9V5T(&5N8V]D:6YG<PHD;W!T:6]N<R`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/
M3E]%3D-/1$E.1U]33U520T4@/3X@)U541BTX)RP*("`@("`@("`@("`@("`@
M("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T54(#T^
M("=)4T\M.#@U.2TQ)PH@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M("`@("`*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S92!T:&4@86UP97)S
M86YD(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@"B1U;G-E<FEA;&EZ
M97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*+R\@=7-E
M<FEA;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M
M/G5N<V5R:6%L:7IE*"1X;6PI.PH*:68@*%!%05(Z.FES17)R;W(H)'-T871U
M<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G("X@)'-T871U<RT^9V5T365S<V%G
M92@I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D=6YS97)I86QI>F5R+3YG9715
M;G-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\<')E/B<["B`@("!P<FEN
M=%]R*"1D871A*3L*("`@(&5C:&\@)SPO<')E/B<["GT*/SX`````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ
M945N=6TN<&AP````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(R-#,`,3`U,34T,S$P-3<`,#(V-C,Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_4$A0"B\J
M*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W('1O('5S92!T:&4@6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?1D]20T5?14Y530H@*B!O<'1I;VX*("H*("H@
M0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*
M97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U5N
M<V5R:6%L:7IE<BYP:'`G.PH*)'AM;#$@/2`G/')O;W0^"B`@(#QI=&5M/@H@
M("`@(#QN86UE/G-C:'-T/"]N86UE/@H@("`\+VET96T^"B`@(#QI=&5M/@H@
M("`@(#QN86UE/FQU8VME8SPO;F%M93X*("`@/"]I=&5M/@H@/"]R;V]T/B<[
M"B`@("`*)'AM;#(@/2`G/')O;W0^"B`@(#QI=&5M/@H@("`@(#QN86UE/G-C
M:'-T/"]N86UE/@H@("`\+VET96T^"B`\+W)O;W0^)SL*("`@(`HD;W!T:6]N
M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D52
M7T]05$E/3E]&3U)#15]%3E5-(#T^(&%R<F%Y*"=I=&5M)RD*("`@("`@("`@
M("`@("`@("D["@H@("`@("`@("`@("`@("`@"B\O("!B92!C87)E9G5L('1O
M(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T:&4@;F5W
M(&]P97)A=&]R(`HD=6YS97)I86QI>F5R(#T@)FYE=R!834Q?56YS97)I86QI
M>F5R*"1O<'1I;VYS*3L*"B\O('5S97)I86QI>F4@=&AE(&1O8W5M96YT"B1S
M=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL,2D["@II
M9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z
M("<@+B`D<W1A='5S+3YG971-97-S86=E*"D["GT@96QS92!["B`@("`D9&%T
M82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@
M(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G
M/"]P<F4^)SL*?0H*+R\@=7-E<FEA;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U
M<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PR*3L*"FEF("A0
M14%2.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N
M("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@
M)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H
M;R`G/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R
M93XG.PI]"C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI
M>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE3V)J96-T+G!H<```````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<P,``Q
M,#4Q-30S,3`U-P`P,C<Q,S$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!S:&]W
M<R!H;W<@6$U,7U-E<FEA;&EZ97(@86YD(%A-3%]5;G-E<FEA;&EZ97(*("H@
M=V]R:R!T;V=E=&AE<BX*("H*("H@02!S=')U8W1U<F4@:7,@<V5R:6%L:7IE
M9"!A;F0@;&%T97(@:70G<R!U;G-E<FEA;&EZ960@9G)O;2!T:&4*("H@<F5S
M=6QT:6YG(%A-3"!D;V-U;65N="X*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!3
M8VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T:6YG*$5?
M04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*<F5Q
M=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["B\O('1H:7,@:7,@
M:G5S="!T;R!G970@82!N97-T960@;V)J96-T"B1P96%R17)R;W(@/2!014%2
M.CIR86ES945R<F]R*"=4:&ES(&ES(&IU<W0@86X@97)R;W(@;V)J96-T)RPQ
M,C,I.PH*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y4("`@("`@/3X@)R`@("`G+`H@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E],24Y%
M0E)%04M3("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E]$149!54Q47U1!1R`]/B`G=6YN86UE9$ET96TG+`H@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]465!%
M2$E.5%,@("`]/B!T<G5E"B`@("`@("`@("`@("`@("`I.PH*)&9O;R`](&YE
M=R!S=&1#;&%S<R@I.PHD9F]O+3YV86QU92`]("=->2!V86QU92<["B1F;V\M
M/F5R<F]R(#T@)'!E87)%<G)O<CL*)&9O;RT^>&UL("`@/2!A<G)A>2@G5&AI
M<R!I<R<@/3X@)V-O;VPG*3L*)&9O;RT^<F5S;W5R8V4@/2!F;W!E;BA?7T9)
M3$5?7RP@)W(G*3L*"B1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R
M*"1O<'1I;VYS*3L*)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H
M)&9O;RD["@II9B`H)')E<W5L="`]/3T@=')U92D@>PH@("`@)'AM;"`]("1S
M97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I.PI]"@IE8VAO("<\<')E
M/B<["F5C:&\@:'1M;'-P96-I86QC:&%R<R@D>&UL*3L*96-H;R`G/"]P<F4^
M)SL*"B\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N
M9"!I;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I86QI>F5R
M(#T@)FYE=R!834Q?56YS97)I86QI>F5R*"D["@HD<W1A='5S(#T@)'5N<V5R
M:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;"D[("`@(`H*:68@*%!%05(Z.FES
M17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G("X@)'-T871U
M<RT^9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D=6YS97)I
M86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\<')E
M/B<["B`@("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@)SPO<')E/B<["GT*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI
M>F521$8N<&AP`````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`T,3(R`#$P-3$U-#,Q,#4W`#`R-C,S-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/U!(4`HO
M*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S(&AO=R!T;R!C<F5A=&4@86YY(&]B
M:F5C=`H@*B!F<F]M(&%N(%A-3"!D;V-U;65N="X@26X@=&AI<R!C87-E('=E
M(&=E=`H@*B!S;VUE(&%G9W)E9V%T960@;V)J96-T<R!F;W(@8VAA;FYE;"!A
M;F0@:71E;7,*("H@9G)O;2!A;B!24U,@9F5E9"X*("H*("H@0&%U=&AO<B`@
M4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P
M;W)T:6YG*$5?04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U5N<V5R:6%L:7IE
M<BYP:'`G.PH*+RHJ"BH@8VQA<W,@9F]R('1H92!21$8@9&]C=65M;G0**@HJ
M"BHO"F-L87-S(')D9D1O8W5M96YT"GL*("`@('9A<B`D8VAA;FYE;#L*("`@
M('9A<B`D:71E;3L*"B`@("!F=6YC=&EO;B!G971)=&5M<R@D86UO=6YT*0H@
M("`@>PH@("`@("`@(')E='5R;B!A<G)A>5]S<&QI8V4H)'1H:7,M/FET96TL
M,"PD86UO=6YT*3L*("`@('T*?0H*"B\J*@HJ(&-L87-S('1H870@:7,@=7-E
M9"!F;W(@82!C:&%N;F5L(&EN('1H92!24U,@9FEL90HJ"BH@>6]U(&-O=6QD
M(&EM<&QE;65N="!W:&%T979E<B!Y;W4@;&EK92!I;B!T:&ES(&-L87-S+`HJ
M('!R;W!E<G1I97,@=VEL;"!B92!S970@9G)O;2!T:&4@6$U,(&1O8W5M96YT
M"BHO"F-L87-S(&-H86YN96P*>PH@("`@9G5N8W1I;VX@9V5T5&ET;&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`@)'1H:7,M/G1I=&QE.PH@("`@?0I]"@HO
M*BH**B!C;&%S<R!T:&%T(&ES('5S960@9F]R(&%N(&ET96T@:6X@=&AE(%)3
M4R!F:6QE"BH**B!Y;W4@8V]U;&0@:6UP;&5M96YT('=H871E=F5R('EO=2!L
M:6ME(&EN('1H:7,@8VQA<W,L"BH@<')O<&5R=&EE<R!W:6QL(&)E('-E="!F
M<F]M('1H92!834P@9&]C=6UE;G0**B\*8VQA<W,@:71E;0I["B`@("!F=6YC
M=&EO;B!G9714:71L92@I"B`@("!["B`@("`@("`@<F5T=7)N("`D=&AI<RT^
M=&ET;&4["B`@("!]"GT*"@HD;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%(#T^
M("=O8FIE8W0G+`H@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7U1!1U]-05`@("`@(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F1F.E)$1B<@/3X@)W)D9D1O8W5M96YT)RP@("`O+R!T:&ES(&ES('5S960@
M=&\@<W!E8VEF>2!A(&-L87-S;F%M92!F;W(@=&AE(')O;W0@=&%G"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*0H@("`@("`@("`@("`@("`@*3L*"B\O("!B92!C87)E9G5L('1O
M(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T:&4@;F5W
M(&]P97)A=&]R(`HD=6YS97)I86QI>F5R(#T@)FYE=R!834Q?56YS97)I86QI
M>F5R*"1O<'1I;VYS*3L*"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E
M<FEA;&EZ92@G:'1T<#HO+W!E87(N<&AP+FYE="]F965D<R]L871E<W0N<G-S
M)RQT<G5E*3L@("`@"@II9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@
M("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG971-97-S86=E*"D["GT@
M96QS92!["B`@("`D<G-S(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI
M>F5D1&%T82@I.PH*("`@(&5C:&\@)U1H:7,@:&%S(&)E96X@<F5T=7)N960@
M8GD@6$U,7U5N<V5R:6%L:7IE<CH\8G(^)SL*("`@(`H@("`@96-H;R`G/'!R
M93XG.PH@("`@<')I;G1?<B@D<G-S*3L*("`@(&5C:&\@)SPO<')E/B<["@H@
M("`@96-H;R`G/&)R/CQB<CY2;V]T(%1A9VYA;64Z("<N)'5N<V5R:6%L:7IE
M<BT^9V5T4F]O=$YA;64H*2XG/&)R/B<["B`@("`*("`@(&5C:&\@)U1I=&QE
M(&]F('1H92!C:&%N;F5L.B`G+B1R<W,M/F-H86YN96PM/F=E=%1I=&QE*"DN
M)SQB<CXG.PH*("`@("1I=&5M<R`]("1R<W,M/F=E=$ET96US*#,I.PH@("`@
M96-H;R`G/&)R/E1I=&QE<R!O9B!T:&4@;&%S="!T:')E92!R96QE87-E<SH\
M8G(^)SL*("`@(&9O<F5A8V@@*"1I=&5M<R!A<R`D:71E;2D@>PH@("`@("`@
M(&5C:&\@)U1I=&QE(#H@)RXD:71E;2T^9V5T5&ET;&4H*2XG/&)R/B<["B`@
M("!]"GT*/SX`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L
M97,O=6YS97)I86QI>F57:&ET97-P86-E+G!H<````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3,P`#$P-3$U-#,Q,#4W
M`#`S,#`Q-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S(&AO=R!T;R!S
M970@82!D:69F97)E;G0@=&%R9V5T(&5N8V]D:6YG"B`J"B`J($!A=71H;W(@
M(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ
M97(N<&AP)SL*"B1X;6P@/2`G/'AM;#X*("`@/'-T<FEN9SX*("`@"B`@("!4
M:&ES(%A-3`H@("`@9&]C=6UE;G0*("`@(&-O;G1A:6YS"B`@("!L:6YE(&)R
M96%K<RX*"B`@(#PO<W1R:6YG/@H@/"]X;6P^)SL*"@HO+R`@8F4@8V%R969U
M;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE
M(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R
M:6%L:7IE<B@I.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"P@=')U92D["@IE8VAO("<\
M<')E/B<["@IE8VAO(")$969A=6QT(&)E:&%V:6]R("A834Q?54Y315))04Q)
M6D527U=(251%4U!!0T5?5%))32E<;B(["B1D871A(#T@)'5N<V5R:6%L:7IE
M<BT^=6YS97)I86QI>F4H)'AM;"D["G9A<E]D=6UP*"1D871A*3L*96-H;R`B
M7&Y<;B(["@IE8VAO(").;W)M86QI>F4@=VAI=&5S<&%C92`H6$U,7U5.4T52
M24%,25I%4E]72$E415-004-%7TY/4DU!3$E:12E<;B(["B1U;G-E<FEA;&EZ
M97(M/G-E=$]P=&EO;BA834Q?54Y315))04Q)6D527T]05$E/3E]72$E415-0
M04-%+"!834Q?54Y315))04Q)6D527U=(251%4U!!0T5?3D]234%,25I%*3L*
M)&1A=&$@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L*=F%R
M7V1U;7`H)&1A=&$I.PIE8VAO(")<;EQN(CL*"F5C:&\@(DME97`@=VAI=&5S
M<&%C92`H6$U,7U5.4T5224%,25I%4E]72$E415-004-%7TM%15`I7&XB.PHD
M=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?5TA)5$534$%#12P@6$U,7U5.4T5224%,25I%4E]72$E415-004-%7TM%
M15`I.PHD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PI
M.PIV87)?9'5M<"@D9&%T82D["@IE8VAO("<\+W!R93XG.PH_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95=I=&A!='1R
M:6)U=&5S+G!H<```````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$T,S0`,3`U,34T,S$P-3<`,#,P-S$P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_4$A0"B\J*@H@*B!4:&ES
M(&5X86UP;&4@<VAO=W,@:&]W('1O('!A<G-E(&%T=')I8G5T97,@9G)O;0H@
M*B!834P@=&%G<RX*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS
M8VAS=$!P:'`N;F5T/@H@*B!`=7-E<R`@("!E>&%M<&QE+GAM;`H@*B\*97)R
M;W)?<F5P;W)T:6YG*$5?04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U5N<V5R
M:6%L:7IE<BYP:'`G.PH*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]005)3
M12`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)
M6D527T]05$E/3E]!5%1224)55$537T%24D%92T59(#T^(&9A;'-E"B`@("`@
M("`@("`@("`@("`I.PH*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S92!T
M:&4@86UP97)S86YD(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@"B1U
M;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I
M.PH*+R\@=7-E<FEA;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]("1U;G-E
M<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"=E>&%M<&QE+GAM;"<L('1R=64I.PH*
M:68@*%!%05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R
M.B`G("X@)'-T871U<RT^9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A
M=&$@/2`D=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@
M("!E8VAO("<\<')E/B<["B`@("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@
M)SPO<')E/B<["GT*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95=I
M=&A486=-87`N<&AP````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,Q-S4`,3`U,34T,S$P-3<`,#(W-S,W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_4$A0"B\J*@H@
M*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W('1O('5S92!T:&4@=&%G36%P(&]P
M=&EO;BX*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B\O('1H:7,@
M:7,@82!S:6UP;&4@6$U,(&1O8W5M96YT"B1X;6P@/2`G/')O;W0^)R`N"B`@
M("`@("`G("`\9F]O/D9/3SPO9F]O/B<@+@H@("`@("`@)R`@/&)A<CY"05(\
M+V)A<CXG("X*("`@("`@("<\+W)O;W0^)SL*"G)E<75I<F5?;VYC92`G6$U,
M+U5N<V5R:6%L:7IE<BYP:'`G.PH*+R\@8V]M<&QE>"!S=')U8W1U<F5S(&%R
M92!A<G)A>7,L('1H92!K97D@:7,@=&AE(&%T=')I8G5T92`G:&%N9&QE)R!O
M<B`G;F%M92<L(&EF(&AA;F1L92!I<R!N;W0@<')E<V5N=`HD;W!T:6]N<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!4
M24].7T-/35!,15A465!%(#T^("=A<G)A>2<L"B`@("`@("`@("`@("`@("`@
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!4"`@("`@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=F;V\G(#T^("=B87(G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8F%R)R`]/B`G9F]O)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@
M("`@("D["@HO+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E
M<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L
M:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D;W!T:6]N<RD["@HO+R!U
M<V5R:6%L:7IE('1H92!D;V-U;65N=`HD<W1A='5S(#T@)'5N<V5R:6%L:7IE
M<BT^=6YS97)I86QI>F4H)'AM;"P@9F%L<V4I.R`@("`*"FEF("A014%2.CII
M<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T
M=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R
M:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R
M93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]
M"@HO+R!A('1A9"!M;W)E(&-O;7!L97@*)'AM;"`]("<\<F]O=#XG("X*("`@
M("`@("<@(#QF;V\^)RX*("`@("`@("<@("`@/'1O;6%T;SXT-3PO=&]M871O
M/B<N"B`@("`@("`G("`\+V9O;SXG+@H@("`@("`@)R`@/&)A<CXG+@H@("`@
M("`@)R`@("`\=&]M871O/C,Q/"]T;VUA=&\^)RX*("`@("`@("<@(#PO8F%R
M/B<N"B`@("`@("`G/"]R;V]T/B<["@HO+R!U<V5R:6%L:7IE('1H92!D;V-U
M;65N=`HD<W1A='5S(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM
M;"P@9F%L<V4I.R`@("`*"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I*2![
M"B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*
M?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I
M86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D
M9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]"C\^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F57:71H5'EP
M94=U97-S:6YG+G!H<````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q-C8V`#$P-3$U-#,Q,#4W`#`S,3(Q-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/U!(4`HO*BH*("H@17AA
M;7!L92!T:&%T('-H;W=S(&AO=R!T;R!U<V4@6$U,7U5N<V5R:6%L:7IE<B!T
M;PH@*B!A=71O;6%T:6-A;&QY(&%D:G5S="!T:&4@='EP92!O9B!T:&4@9&%T
M80H@*@H@*B!`875T:&]R("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@H@*B!`8V%T96=O<GD@("`@6$U,"B`J($!P86-K86=E("`@("!8
M34Q?4V5R:6%L:7IE<@H@*B!`<W5B<&%C:V%G92`@17AA;7!L97,*("HO"F5R
M<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO*BH*("H@=7-E<R!834Q?56YS97)I
M86QI>F5R"B`J+PIR97%U:7)E7V]N8V4@)RXN+U5N<V5R:6%L:7IE<BYP:'`G
M.PH*)'AM;"`](#P\/$5/5`H\<F]O=#X*("`@/'-T<FEN9SY*=7-T(&$@<W1R
M:6YG+BXN/"]S=')I;F<^"B`@(#QB;V]L96%N5F%L=64^=')U93PO8F]O;&5A
M;E9A;'5E/@H@("`\9F]O/BTU-C,\+V9O;SX*("`@/&)A<CXT+C<S-S,V/"]B
M87(^"B`@(#QA<G)A>2!F;V\](F9A;'-E(B!B87(](C$R(CYT<G5E/"]A<G)A
M>3X*/"]R;V]T/@I%3U0["@HD=6YS97)I86QI>F5R(#T@)FYE=R!834Q?56YS
M97)I86QI>F5R*"D["B1U;G-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?54Y3
M15))04Q)6D527T]05$E/3E]#3TU03$585%E012P@)V%R<F%Y)RD["B1U;G-E
M<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?54Y315))04Q)6D527T]05$E/3E]!
M5%1224)55$537U!!4E-%+"!T<G5E*3L*)'5N<V5R:6%L:7IE<BT^<V5T3W!T
M:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7U)%5%523E]215-53%0L('1R
M=64I.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?1U5%4U-?5%E015,L('1R=64I.PH*)&1A=&$@/2`D=6YS97)I
M86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L@("`@"F5C:&\@)SQP<F4^)SL*
M=F%R7V1U;7`H)&1A=&$I.PIE8VAO("<\+W!R93XG.PH_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE06YD
M4F5T=7)N+G!H<````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,30Q`#$P-3$U-#,Q,#4W`#`R-S(V,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/U!(4`HO*BH*
M("H@17AA;7!L92!T:&%T('5S97,@=&AE(')E='5R;E)E<W5L="!O<'1I;VX@
M=&\@9&ER96-T;'D@<F5T=7)N('1H92!S97)I86QI>F5D"B`J(%A-3"!D;V-U
M;65N="!I;B!T:&4@<V5R:6%L:7IE*"D@;65T:&]D+@H@*@H@*B!`875T:&]R
M(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R
M+G!H<"<["@HD;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M(%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0@("`@("`@(#T^("<@("`@
M)RP*("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M4D5455).7U)%4U5,5"`]/B!T<G5E"B`@("`@("`@("`@("`@("`I.PH*)'-E
M<FEA;&EZ97(@/2`F;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*"B1F
M;V\@/2!014%2.CIR86ES945R<F]R*"=*=7-T(&$@=&5S="<L(#$R,S0I.PH*
M)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["@IE8VAO
M("<\<')E/B<["F5C:&\@:'1M;'-P96-I86QC:&%R<R@D<F5S=6QT*3L*96-H
M;R`G/"]P<F4^)SL*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O4T]!4"\`````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`Q-S`S-@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-3<`,#(P-#<Q`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U-/05`O97AA;7!L92]A='1A8VAM96YT+G!H<```````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,34R-0`Q,#4Q-30S,3`U-P`P,C,S,S(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*<F5Q=6ER95]O
M;F-E*")33T%0+T-L:65N="YP:'`B*3L*<F5Q=6ER95]O;F-E*")33T%0+W1E
M<W0O=&5S="YU=&EL:71Y+G!H<"(I.PIR97%U:7)E7V]N8V4H(E-/05`O5F%L
M=64N<&AP(BD["@HD9FEL96YA;64@/2`G871T86-H;65N="YP:'`G.PHD=B`]
M("!N97<@4T]!4%]!='1A8VAM96YT*"=T97-T)RPG=&5X="]P;&%I;B<L)&9I
M;&5N86UE*3L*)&UE=&AO9%9A;'5E(#T@;F5W(%-/05!?5F%L=64H)W1E<W1A
M='1A8V@G+"`G4W1R=6-T)RP@87)R87DH)'8I*3L*"B1C;&EE;G0@/2!N97<@
M4T]!4%]#;&EE;G0H)VUA:6QT;SIU<V5R0&1O;6%I;BYC;VTG*3L*(R!C86QL
M:6YG('=I=&@@;6EM90HD<F5S<"`]("1C;&EE;G0M/F-A;&PH)V5C:&]-:6UE
M071T86-H;65N="<L87)R87DH)'8I+`H@("`@("`@("`@("`@("`@87)R87DH
M)V%T=&%C:&UE;G1S)ST^)TUI;64G+`H@("`@("`@("`@("`@("`@)VYA;65S
M<&%C92<]/B=H='1P.B\O<V]A<&EN=&5R;W`N;W)G+R<L"B`@("`@("`@("`@
M("`@("`G9G)O;2<]/B=U<V5R0&1O;6%I;BYC;VTG+`H@("`@("`@("`@("`@
M("`@)VAO<W0G/3XG<VUT<"YD;VUA:6XN8V]M)RDI.PIP<FEN="`D8VQI96YT
M+3YW:7)E+B)<;EQN7&XB.PIP<FEN=%]R*"1R97-P*3L*"B,@8V%L;&EN9R!W
M:71H($1)344*)')E<W`@/2`D8VQI96YT+3YC86QL*"=E8VAO36EM94%T=&%C
M:&UE;G0G+&%R<F%Y*"1V*2D["B,@1$E-12!H87,@;G5L;"!S<&%C97,L(&-H
M86YG92!T:&5M('-O('=E(&-A;B!S964@=&AE('=I<F4*)'=I<F4@/2!S=')?
M<F5P;&%C92@B7#`B+"<J)RPD8VQI96YT+3YW:7)E*3L*<')I;G0@)'=I<F4N
M(EQN7&Y<;B(["G!R:6YT7W(H)')E<W`I.PH_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+U-/05`O97AA;7!L92]C;VU?8VQI96YT+G!H<```````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#(R-@`Q,#4Q-30S,3`U-P`P,C,S,3<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+R\*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I
M;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A
M:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@
M<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!C;VU?8VQI96YT+G!H<"QV(#$N
M,R`R,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PHO+R!33T%0
M4W1R=6-T(&ES(&1E9FEN960@:6X@=&AE(&9O;&QO=VEN9R!F:6QE"G)E<75I
M<F5?;VYC92`G97AA;7!L95]T>7!E<RYP:'`G.PH*+RH@:G5S="!A('-I;7!L
M92!E>&%M<&QE(&]F('5S:6YG($U3(%-/05`@;VX@=VEN,S(@87,@82!C;&EE
M;G0*("`@=&\@=&AE('!H<"!S97)V97(N("`J+PH*+R]L;V%D($-/32!33T%0
M(&-L:65N="!O8FIE8W0*)'-O87!C;&EE;G0@/2!N97<@0T]-*")-4U-/05`N
M4V]A<$-L:65N=#,P(BD["@HO+V-O;FYE8W0@=&\@=V5B('-E<G9I8V4*)'-O
M87!C;&EE;G0M/FUS<V]A<&EN:70H(FAT='`Z+R]L;V-A;&AO<W0O4T]!4"]E
M>&%M<&QE+W-E<G9E<BYP:'`_=W-D;"(I.PH*+R]O8G1A:6X@<F5S=6QT(&9R
M;VT@=V5B('-E<G9I8V4@;65T:&]D"B1R970@/2`D<V]A<&-L:65N="T^96-H
M;U-T<FEN9R@B5&AI<R!I<R!A('1E<W0A(BD["G!R:6YT*"(D<F5T7&XB*3L*
M"B1R970@/2`D<V]A<&-L:65N="T^96-H;U-T<FEN9U-I;7!L92@B5&AI<R!I
M<R!A;F]T:&5R('1E<W0A(BD["G!R:6YT*"(D<F5T7&XB*3L*"B,@=&AE(&9O
M;&QO=VEN9R!C875S97,@86X@97AC97!T:6]N(&EN('1H92!#3TT@97AT96YS
M:6]N"@HC)')E="`]("1S;V%P8VQI96YT+3YD:79I9&4H,C(L-RD["B-P<FEN
M="`D<V]A<&-L:65N="T^9F%U;'1C;V1E.PHC<')I;G0@)'-O87!C;&EE;G0M
M/F9A=6QT<W1R:6YG.PHC<')I;G0H(C(R+S<])')E=%QN(BD["B-P<FEN=%]R
M*"1R970I.PHC)')E="`]("1S;V%P8VQI96YT+3YD:79I9&4H,C(L,"D["B-P
M<FEN="@B,C(O,#TD<F5T7&XB*3L*"B,D<W1R=6-T(#T@;F5W(%-/05!3=')U
M8W0H)W1E<W0@<W1R:6YG)RPQ,C,L,3(S+C$R,RD["B,D<F5T(#T@)'-O87!C
M;&EE;G0M/F5C:&]3=')U8W0H)'-T<G5C="D["B-P<FEN=%]R*"1R970I.PH*
M(R1R970@/2`D<V]A<&-L:65N="T^96-H;U-T<G5C=$%S4VEM<&QE5'EP97,H
M)'-T<G5C="D["B-P<FEN=%]R*"1R970I.PH*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]D:7-C;U]S97)V
M97(N<&AP```````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C(P,``Q,#4Q-30S,3`U-P`P
M,C,V-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R.B!$;6ET<FD@5FEN;V=R861O=B`\9&EM:71R
M:4!V:6YO9W)A9&]V+F1E/B`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!D:7-C;U]S97)V
M97(N<&AP+'8@,2XU(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D
M"@HO*@H@(%1H:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@;6%R:R!U<"!A('-E
M<G9E<B!O8FIE8W0@<V\@=&AA=`H@('=S9&P@9FEL97,@;6%Y(&)E(&1Y;F%M
M:6-A;'D@9V5N97)A=&5D(&)Y('1H92!S;V%P"B`@<V5R=F5R+B`@5&AI<R!A
M;'-O('!R;W9I9&5S(&%C8V5S<R!T;R!A(&=E;F5R871E9"!$25-#3R!D;V-U
M;65N="X*("!4:&4@9F%C="!T:&%T('1H:7,@97AA;7!L92!H87,@86X@35`S
M(&-L87-S(&ES(&EN(&YO('=A>0H@(')E;&%T960@=&\@1$E30T\N(#LI"B`@
M"B`@1$E30T\Z(&AT='`Z+R]M<V1N+FUI8W)O<V]F="YC;VTO;7-D;FUA9R]I
M<W-U97,O,#(O,#(O>&UL+V1E9F%U;'0N87-P>`H@(`H@($$@=7)L(&%C8V5S
M<VEN9R!T:&ES('-E<G9E<B!W;W5L9"!L;V]K(&QI:V4Z"B`@"B`@:'1T<#HO
M+VQO8V%L:&]S="]D:7-C;U]S97)V97(N<&AP/W=S9&P@*&=E;F5R871E(%=3
M1$P@9FEL92D*("!H='1P.B\O;&]C86QH;W-T+V1I<V-O7W-E<G9E<BYP:'`@
M*$=%5"!R97%U97-T(&=E;F5R871E<R!$25-#3RD*("!H='1P.B\O;&]C86QH
M;W-T+V1I<V-O7W-E<G9E<BYP:'`@*%!/4U0@9F]R(&YO<FUA;"!S;V%P(')E
M<75E<W1S*0HJ+PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*<F5Q=6ER95]O
M;F-E("=33T%0+U-E<G9E<BYP:'`G.PH*8VQA<W,@35`S1$)?0VQA<W,@>PH@
M("`@=F%R("1?7V1I<W!A=&-H7VUA<"`](&%R<F%Y*"D["B`@("!V87(@)%]?
M='EP961E9B`@("`@/2!A<G)A>2@I.PH@("`@"B`@("!F=6YC=&EO;B!-4#-$
M0E]#;&%S<R`H*2!["B`@("`@("`@+RHJ"B`@("`@("`@*B!T:&4@;VYL>2!W
M87D@=&\@9&5S8W)I8F4@86QL(&UE=&AO9',@:6X@5U-$3"`H;65S<V%G97,L
M"B`@("`@("`@*B!0;W)T5'EP92UO<&5R871I;VYS(&%N9"!B:6YD:6YG<RD@
M:7,@=&\@=7-E(%]?9&ES<&%T8VA?;6%P"B`@("`@("`@*B!T;R!D97-C<FEB
M92!E=F5R>2!M971H;V0@*&5V96X@;65T:&]D<R!U<VEN9R!S:6UP;&4@9&%T
M82`*("`@("`@("`J('1Y<&5S(&EN("=I;B<@86YD("=O=70G('!A<F%M971E
M<G,N+BXI"B`@("`@("`@*B\*("`@("`@("`*("`@("`@("`D=&AI<RT^7U]D
M:7-P871C:%]M87!;)U-A>4AA;&QO)UT@/0H@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G:6XG(#T^(&%R<F%Y
M*"=I;G!U="<@/3X@)W-T<FEN9R<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G;W5T)R`]/B!A<G)A>2@G<F5T=7)N)R`]/B`G<W1R:6YG)RD*("`@("`@
M("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@
M("1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG4V%Y5&AI<TY4:6UE<R==(#T*("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)VEN)R`]/B!A<G)A>2@G4V%Y5&AI<R<]/B=S=')I;F<G+"=.5&EM97,G
M(#T^("=I;G0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V]U="<@/3X@
M87)R87DH)W)E='5R;B<@/3X@)WMU<FXZ35`S1$)]07)R87E/9E-T<FEN9W,G
M*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@
M"B`@("`@("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R='971-4#-4<F%C:W,G
M72`]"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=I;B<@/3X@87)R87DH)W%U97)Y)R`]/B`G<W1R:6YG)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("=O=70G(#T^(&%R<F%Y*"=R971U
M<FXG(#T^("=[=7)N.DU0,T1"?4=E=$U0,U1R86-K<U)E<W5L="<I"B`@("`@
M("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@("`@
M("`D=&AI<RT^7U]D:7-P871C:%]M87!;)T%D9$U0,U1R86-K)UT@/0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`G:6XG(#T^(&%R<F%Y*"=-4#-4<F%C:R<@/3X@)WMU<FXZ35`S1$)]35`S
M5')A8VLG*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V]U="<@/3X@87)R
M87DH)W)E='5R;B<@/3X@)WMU<FXZ35`S1$)]061D35`S5')A8VM297-U;'0G
M*0H@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("\J*@H@("`@("`@
M("H@22!U<V4@7U]T>7!E9&5F('1O(&1E<V-R:6)E('5S97)D969I;F5D(%1Y
M<&5S(&EN(%=31$PN"B`@("`@("`@*B!3=')U8W1S(&%N9"!O;F4M9&EM96YS
M:6]N86P@87)R87ES(&%R92!S=7!P;W)T960Z"B`@("`@("`@*B!3=')U8W0@
M97AA;7!L93H@)'1H:7,M/E]?='EP961E9ELG5'EP94YA;64G72`](&%R<F%Y
M*"=687).86UE)R`]/B`G>'-D5'EP92<L("XN+B`I.PH@("`@("`@("H@("`@
M;W(@)'1H:7,M/E]?='EP961E9ELG5'EP94YA;64G72`](&%R<F%Y*"=687).
M86UE)R`]/B`G>VYA;65S<&%C97U3;VUE3W1H97)4>7!E)RD["B`@("`@("`@
M*B!!<G)A>2!E>&%M<&QE.B`D=&AI<RT^7U]T>7!E9&5F6R=4>7!E3F%M92==
M(#T@87)R87DH87)R87DH)VET96TG(#T^("=X<V14>7!E)RDI.PH@("`@("`@
M("H@("`@;W(@)'1H:7,M/E]?='EP961E9ELG5'EP94YA;64G72`](&%R<F%Y
M*&%R<F%Y*"=I=&5M)R`]/B`G>VYA;65S<&%C97U3;VUE3W1H97)4>7!E)RDI
M.PH@("`@("`@("HO"B`@("`*("`@("`@("`O*BH*("`@("`@("`J(%-T<G5C
M="`G35`S5')A8VLG"B`@("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T>7!E
M9&5F6R=-4#-4<F%C:R==(#T@"B`@("`@("`@("`@("`@("`@("`@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("=4:71L92<@/3X@)W-T<FEN9R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=!<G1I<W0G(#T^("=S=')I;F<G
M+"`*("`@("`@("`@("`@("`@("`@("`@("`@)T%L8G5M)R`]/B`G<W1R:6YG
M)RP@"B`@("`@("`@("`@("`@("`@("`@("`@("=996%R)R`]/B`G:6YT)RP@
M"B`@("`@("`@("`@("`@("`@("`@("`@("='96YR92<@/3X@)VEN="<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=#;VUM96YT)R`]/B`G<W1R:6YG)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)T-O;7!O<V5R)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@)T]R:6=?07)T:7-T)R`]/B`G
M<W1R:6YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@)U523"<@/3X@)W-T
M<FEN9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=%;F-O9&5D7V)Y)R`]
M/B`G<W1R:6YG)PH@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@
M("`@("`@("`@"B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@
M("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@*B!-4#-4<F%C:W-!<G)A>2`M
M(&%R<F%Y(&]F("=-4#-4<F%C:R<@<W1R=6-T<PH@("`@("`@("HO"B`@("`@
M("`@)'1H:7,M/E]?='EP961E9ELG35`S5')A8VMS07)R87DG72`](`H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I=&5M)R`]
M/B`G>W5R;CI-4#-$0GU-4#-4<F%C:R<*("`@("`@("`@("`@("`@("`@("`@
M("`@*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@
M("`@"B`@("`@("`@+RHJ"B`@("`@("`@*B!3=')U8W0@)TUE=&AO9$1E8G5G
M)PH@("`@("`@("HO"B`@("`@("`@)'1H:7,M/E]?='EP961E9ELG365T:&]D
M1&5B=6<G72`](`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`G<F,G(#T^("=B;V]L96%N)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@)T5R<DYO)R`]/B`G:6YT)RP@"B`@("`@("`@("`@
M("`@("`@("`@("`@("=%<G)O<B<@/3X@)W-T<FEN9R<*("`@("`@("`@("`@
M("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("\J*@H@
M("`@("`@("H@<F5T=7)N(%-T<G5C="!O9B!M971H;V0@1V5T35`S5')A8VMS
M"B`@("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T>7!E9&5F6R='971-4#-4
M<F%C:W-297-U;'0G72`](`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G365T:&]D1&5B=6<G(#T^("=[=7)N
M.DU0,T1"?4UE=&AO9$1E8G5G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M)TU0,U1R86-K<R<@/3X@)WMU<FXZ35`S1$)]35`S5')A8VMS07)R87DG"B`@
M("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@
M("`@("`O*BH*("`@("`@("`J(')E='5R;B!3=')U8W0@;V8@;65T:&]D($%D
M9$U0,U1R86-K"B`@("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T>7!E9&5F
M6R=!9&1-4#-4<F%C:U)E<W5L="==(#T@"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=-971H;V1$96)U9R<@
M/3X@)WMU<FXZ35`S1$)]365T:&]D1&5B=6<G"B`@("`@("`@("`@("`@("`@
M("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@("`@("`O*BH*("`@("`@
M("`J($%R<F%Y(&]F('-T<FEN9W,*("`@("`@("`J+PH@("`@("`@("1T:&ES
M+3Y?7W1Y<&5D969;)T%R<F%Y3V93=')I;F=S)UT@/2`*("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)VET96TG/3XG<W1R:6YG)RD*("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M"B`@("!]"B`@("`*("`@(`H@("`@9G5N8W1I;VX@4V%Y2&%L;&\H)&YA;64I
M('L*("`@("`@("!R971U<FX@(DAA;&QO+"`B("X@)&YA;64["B`@("!]"B`@
M("`*("`@(`H@("`@9G5N8W1I;VX@4V%Y5&AI<TY4:6UE<R@D4V%Y5&AI<RPD
M3E1I;65S*2!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)$Y4:6UE<SL@
M)&DK*RD@>PH@("`@("`@("`@("`D<F5T=7)N6R1I72`]("1387E4:&ES("X@
M(B`D:2(["B`@("`@("`@?0H@("`@("`@(')E='5R;B!N97<@4T]!4%]686QU
M92@G<F5T=7)N)RPG>W5R;CI-4#-$0GU!<G)A>4]F4W1R:6YG<R<L)')E='5R
M;BD["B`@("!]"B`@("`*("`@(`H@("`@9G5N8W1I;VX@1V5T35`S5')A8VMS
M*"1Q=65R>2`]("(B*2!["B`@("`@("`@9F]R*"1I(#T@,#L@)&D@/"`U.R`D
M:2LK*2!["B`@("`@("`@("`@("1T:&ES+3Y-4#-4<F%C:W-;)&E=(#T@;F5W
M(%-/05!?5F%L=64H"B`@("`@("`@("`@("`@("`@("`@)VET96TG+`H@("`@
M("`@("`@("`@("`@("`@("=[=7)N.DU0,T1"?4U0,U1R86-K)RP*("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M(E1I=&QE(B`@("`@("`@(#T^(&YE=R!33T%07U9A;'5E*")4:71L92(L(G-T
M<FEN9R(L(G-O;64@=')A8VL@)&DB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@(D%R=&ES="(@("`@("`@(#T^(&YE=R!33T%07U9A;'5E*")!<G1I<W0B
M+")S=')I;F<B+")S;VUE(&%R=&ES="`D:2(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`B06QB=6TB("`@("`@("`@/3X@;F5W(%-/05!?5F%L=64H(D%L
M8G5M(BPB<W1R:6YG(BPB<V]M92!A;&)U;2`D:2(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`B665A<B(@("`@("`@("`@/3X@;F5W(%-/05!?5F%L=64H
M(EEE87(B+")I;G0B+"AI;G1E9V5R*3$Y.3DI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`B1V5N<F4B("`@("`@("`@/3X@;F5W(%-/05!?5F%L=64H(D=E
M;G)E(BPB:6YT(BPH:6YT96=E<BDQ,#`I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`B0V]M;65N="(@("`@("`@/3X@;F5W(%-/05!?5F%L=64H(D-O;6UE
M;G0B+")S=')I;F<B+")B;&%B;&$@)&DB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@(D-O;7!O<V5R(B`@("`@(#T^(&YE=R!33T%07U9A;'5E*")#;VUP
M;W-E<B(L(G-T<FEN9R(L(B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M3W)I9U]!<G1I<W0B("`@/3X@;F5W(%-/05!?5F%L=64H(D]R:6=?07)T:7-T
M(BPB<W1R:6YG(BPB(BDL"B`@("`@("`@("`@("`@("`@("`@("`@(")54DPB
M("`@("`@("`@("`]/B!N97<@4T]!4%]686QU92@B55),(BPB<W1R:6YG(BPB
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@(")%;F-O9&5D7V)Y(B`@("`]
M/B!N97<@4T]!4%]686QU92@B16YC;V1E9%]B>2(L(G-T<FEN9R(L(B(I"B`@
M("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("D["B`@
M("`@("`@?0H@("`@("`@(`H@("`@("`@("1-971H;V1$96)U9ULB<F,B72`@
M("`](&YE=R!33T%07U9A;'5E*")R8R(L(F)O;VQE86XB+'1R=64I.PH@("`@
M("`@("1-971H;V1$96)U9ULB17)R3F\B72`](&YE=R!33T%07U9A;'5E*")%
M<G).;R(L(FEN="(L*&EN=&5G97(I,"D["B`@("`@("`@)$UE=&AO9$1E8G5G
M6R)%<G)O<B)=(#T@;F5W(%-/05!?5F%L=64H(D5R<F]R(BPB<W1R:6YG(BPB
M(BD["B`@("`@("`@("`@(`H@("`@("`@(')E='5R;B!N97<@4T]!4%]686QU
M92@G<F5T=7)N)RPG>W5R;CI-4#-$0GU'971-4#-4<F%C:W-297-U;'0G+&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@(")-971H;V1$96)U9R(@/3X@;F5W
M(%-/05!?5F%L=64H)TUE=&AO9$1E8G5G)RPG>W5R;CI-4#-$0GU-971H;V1$
M96)U9R<L)$UE=&AO9$1E8G5G*2P*("`@("`@("`@("`@("`@("`@("`B35`S
M5')A8VMS(B`@(#T^(&YE=R!33T%07U9A;'5E*"=-4#-4<F%C:W,G+"=[=7)N
M.DU0,T1"?4U0,U1R86-K<T%R<F%Y)RPD=&AI<RT^35`S5')A8VMS*0H@("`@
M("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("D["B`@("!]"B`@
M("`*("`@(`H@("`@9G5N8W1I;VX@061D35`S5')A8VLH)$U0,U1R86-K*2![
M"B`@("`@("`@(R!W96QL+"!L971S(&EM86=I;F4@:&5R92!S;VUE(&-O9&4@
M9F]R(&%D9&EN9R!G:79E;B!M<#-T<F%C:R!T;R!D8B!O<B!W:&%T979E<BXN
M+@H@("`@("`@("1-971H;V1$96)U9ULB<F,B72`@("`](&YE=R!33T%07U9A
M;'5E*")R8R(L(F)O;VQE86XB+'1R=64I.PH@("`@("`@("1-971H;V1$96)U
M9ULB17)R3F\B72`](&YE=R!33T%07U9A;'5E*")%<G).;R(L(FEN="(L*&EN
M=&5G97(I,"D["B`@("`@("`@)$UE=&AO9$1E8G5G6R)%<G)O<B)=(#T@;F5W
M(%-/05!?5F%L=64H(D5R<F]R(BPB<W1R:6YG(BPB(BD["B`@("`@("`@"B`@
M("`@("`@<F5T=7)N(&YE=R!33T%07U9A;'5E*"=R971U<FXG+"=[=7)N.DU0
M,T1"?4%D9$U0,U1R86-K4F5S=6QT)RQA<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`B365T:&]D1&5B=6<B(#T^(&YE=R!33T%07U9A;'5E*"=-971H;V1$
M96)U9R<L)WMU<FXZ35`S1$)]365T:&]D1&5B=6<G+"1-971H;V1$96)U9RD*
M("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I.PH@("`@
M?0H@("`@"B`@("`*("`@(&9U;F-T:6]N(%]?9&ES<&%T8V@H)&UE=&AO9&YA
M;64I('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]?9&ES<&%T8VA?;6%P
M6R1M971H;V1N86UE72DI"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7U]D
M:7-P871C:%]M87!;)&UE=&AO9&YA;65=.PH@("`@("`@(')E='5R;B!.54Q,
M.PH@("`@?0I]"@HD<V5R=F5R(#T@;F5W(%-/05!?4V5R=F5R.PHD<V5R=F5R
M+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["B1-4#-$0E]#;&%S<R`](&YE
M=R!-4#-$0E]#;&%S<R@I.PHD<V5R=F5R+3YA9&1/8FIE8W1-87`H)$U0,T1"
M7T-L87-S+"=U<FXZ35`S1$(G*3L*"@II9B`H:7-S970H)%]315)615);)U)%
M455%4U1?34542$]$)UTI("8F"B`@("`D7U-%4E9%4ELG4D5154535%]-151(
M3T0G73T])U!/4U0G*2!["B`@("`D<V5R=F5R+3YS97)V:6-E*"1(5%107U)!
M5U]03U-47T1!5$$I.PI](&5L<V4@>PH@("`@<F5Q=6ER95]O;F-E("=33T%0
M+T1I<V-O+G!H<"<["B`@("`D9&ES8V\@/2!N97<@4T]!4%]$25-#3U]397)V
M97(H)'-E<G9E<BPB35`S1$(B*3L*("`@(&AE861E<B@B0V]N=&5N="UT>7!E
M.B!T97AT+WAM;"(I.PH@("`@:68@*&ES<V5T*"1?4T525D526R=1545265]3
M5%))3D<G72D@)B8*("`@("`@('-T<F-A<V5C;7`H)%]315)615);)U%515)9
M7U-44DE.1R==+"=W<V1L)RD]/3`I('L*("`@("`@("!E8VAO("1D:7-C;RT^
M9V5T5U-$3"@I.PH@("`@?2!E;'-E('L*("`@("`@("!E8VAO("1D:7-C;RT^
M9V5T1$E30T\H*3L*("`@('T*("`@(&5X:70["GT*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]33T%0+V5X86UP;&4O96UA:6Q?8VQI96YT+G!H<```````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#,S,C(`,3`U,34T,S$P-3<`,#(S-C(T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O
M('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO
M<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@
M=&\@4$5!4B!A;F0@;6]R92`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@96UA:6Q?8VQI96YT+G!H<"QV(#$N-"`R,#`U
M+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*+RH*5&AI<R!R96%D
M<R!A(&UE<W-A9V4@9G)O;2!S=&1I;BP@86YD(&-A;&QS('1H92!S;V%P('-E
M<G9E<B!D969I;F5D"@I9;W4@8V%N('5S92!T:&ES(&9R;VT@<6UA:6P@8GD@
M8W)E871I;F<@82`N<6UA:6PM<V]A<'1E<W0@9FEL92!W:71H.@H@("`@?"`O
M=7-R+V)I;B]P:'`@+W!A=&@O=&\O96UA:6Q?<V5R=F5R+G!H<`HJ+PH*(R!I
M;F-L=61E('1H92!E;6%I;"!S97)V97(@8VQA<W,*<F5Q=6ER95]O;F-E("=3
M3T%0+U-E<G9E<B]%;6%I;"YP:'`G.PH*)'-E<G9E<B`](&YE=R!33T%07U-E
M<G9E<E]%;6%I;#L*"B,@<F5A9"!S=&1I;@HD9FEN(#T@9F]P96XH)W!H<#HO
M+W-T9&EN)RPG<F(G*3L*:68@*"$D9FEN*2!E>&ET*#`I.PH*)&5M86EL(#T@
M)R<["G=H:6QE("@A9F5O9B@D9FEN*2`F)B`D9&%T82`](&9R96%D*"1F:6XL
M(#@P.38I*2!["B`@)&5M86EL("X]("1D871A.PI]"@IF8VQO<V4H)&9I;BD[
M"@H*)')E<W!O;G-E(#T@)'-E<G9E<BT^8VQI96YT*"1E;6%I;"D["@IP<FEN
M=%]R*"1R97-P;VYS92D["@H_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!
M4"]E>&%M<&QE+V5M86EL7V=A=&5W87DN<&AP````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S-#<S`#$P-3$U-#,Q,#4W`#`R-#`Q-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3
M:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%
M05(@86YD(&UO<F4@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+PHO+R`D260Z(&5M86EL7V=A=&5W87DN<&AP+'8@,2XU(#(P,#4O,#,O
M,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO*@I4:&ES(')E861S(&$@
M;65S<V%G92!F<F]M('-T9&EN+"!A;F0@<&%S<V5S('1H92!R97%U97-T('1O
M"F$@<V]A<"!S97)V97(@<F5S:61I;F<@;VX@82!W96(@<V5R=F5R+"!S96YD
M<R!T:&4@<F5S<&]N<V4*;W5T(&%S(&%N(&5M86EL"@I9;W4@8V%N('5S92!T
M:&ES(&9R;VT@<6UA:6P@8GD@8W)E871I;F<@82`N<6UA:6PM<V]A<&=A=&5W
M87D@9FEL92!W:71H.@H@("`@?"`O=7-R+V)I;B]P:'`@+W!A=&@O=&\O96UA
M:6Q?<V5R=F5R+G!H<`HJ+PH*(R!I;F-L=61E('1H92!E;6%I;"!S97)V97(@
M8VQA<W,*<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E<B]%;6%I;%]'871E=V%Y
M+G!H<"<["@HC(')E860@<W1D:6X*)&9I;B`](&9O<&5N*"=P:'`Z+R]S=&1I
M;B<L)W)B)RD["FEF("@A)&9I;BD@97AI="@P*3L*"B1E;6%I;"`]("<G.PIW
M:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A=&$@/2!F<F5A9"@D9FEN+"`X,#DV
M*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*?0H*9F-L;W-E*"1F:6XI.PH*(R!D
M;VET(0HD<V5R=F5R(#T@;F5W(%-/05!?4V5R=F5R7T5M86EL7T=A=&5W87DH
M*3L*)'-E<G9E<BT^<V5R=FEC92@D9&%T82P@)VAT='`Z+R]L;V-A;&AO<W0O
M<V]A<"]E>&%M<&QE+W-E<G9E<BYP:'`G*3L*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA
M;7!L92]E;6%I;%]P;W!?9V%T97=A>2YP:'``````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`P
M,P`Q,#4Q-30S,3`U-P`P,C0V-C,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@
M0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N
M9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!E;6%I;%]P;W!?9V%T97=A>2YP:'`L=B`Q+C8@,C`P-2\P,R\Q
M,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*"B\J(&EN8VQU9&4@=&AE($5M
M86EL('-E<G9E<B!C;&%S<RP@=VAI8V@@:VYO=W,@:&]W('1O"B`@('!A<G-E
M(&$@<W1A;F1A<F0@96UA:6P@87,@82!S;V%P(&UE<W-A9V4@*B\*"G)E<75I
M<F5?;VYC92`G4T]!4"]397)V97(O16UA:6Q?1V%T97=A>2YP:'`G.PH*+RH@
M:6YC;'5D92!A(&-L87-S('1O(&%C8V5S<R!03U`S("HO"@IR97%U:7)E7V]N
M8V4@)TYE="]03U`S+G!H<"<["@HO*B!C<F5A=&4@=&AE(%-/05`@4V5R=F5R
M(&]B:F5C="`J+PH*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E<E]%;6%I;%]'
M871E=V%Y*"=H='1P.B\O;&]C86QH;W-T+W-O87!?:6YT97)O<"]S97)V97)?
M<F]U;F0R+G!H<"<I.PH*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O
M(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?
M875T;U]T<F%N<VQA=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@)V5X86UP
M;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L
M95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L
M)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@H*+RH@0V]N;F5C="!T;R!A
M(%!/4#,@<V5R=F5R(&%N9"!R96%D('1H92!M97-S86=E<R`J+PH*)'!O<#,@
M/28@;F5W($YE=%]03U`S*"D["FEF("@D<&]P,RT^8V]N;F5C="@G;&]C86QH
M;W-T)RP@,3$P*2D@>PH@("`@:68@*"1P;W`S+3YL;V=I;B@G=7-E<FYA;64G
M+"`G<&%S<W=O<F0G*2D@>PH@("`@("`@("1L:7-T:6YG(#T@)'!O<#,M/F=E
M=$QI<W1I;F<H*3L*"@DO*B!N;W<@;&]O<"!T:')O=6=H(&5A8V@@;65S<V%G
M92P@86YD(&-A;&P@=&AE(`H@("`@("`@("`@(%-/05`@<V5R=F5R('=I=&@@
M=&AA="!M97-S86=E("HO"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T:6YG(&%S
M("1M<V<I('L*"B`@("`@("`@("`@("1E;6%I;"`]("1P;W`S+3YG971-<V<H
M)&US9ULG;7-G7VED)UTI.PH*("`@("`@("`@("`@+RH@=&AI<R!I<R!W:&5R
M92!W92!A8W1U86QL>2!H86YD;&4@=&AE(%-/05`*("`@("`@("`@("`@("`@
M<F5S<&]N<V4N("!4:&4@4T]!4#HZ4V5R=F5R.CI%;6%I;"!C;&%S<R!W90H@
M("`@("`@("`@("`@("!A<F4@=7-I;F<@=VEL;"!S96YD('1H92!33T%0(')E
M<W!O;G-E('1O(`H@("`@("`@("`@("`@("!T:&4@<V5N9&5R('9I82!E;6%I
M;"X@*B\*"B`@("`@("`@("`@(&EF("@D96UA:6PI("1S97)V97(M/G-E<G9I
M8V4H)&5M86EL*3L*"B`@("`@("`@("`@(",D<&]P,RT^9&5L971E37-G*"1M
M<V=;)VUS9U]I9"==*3L*("`@("`@("!]"B`@("!]"B`@("`D<&]P,RT^9&ES
M8V]N;F5C="@I.PI]"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7W!O<%]S
M97)V97(N<&AP`````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S0Q`#$P-3$U-#,Q,#4W`#`R
M-#4T,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#
M87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&5M86EL7W!O
M<%]S97)V97(N<&AP+'8@,2XV(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H
M($5X<"`D"B\O"@HO*B!I;F-L=61E('1H92!%;6%I;"!S97)V97(@8VQA<W,L
M('=H:6-H(&MN;W=S(&AO=R!T;PH@("!P87)S92!A('-T86YD87)D(&5M86EL
M(&%S(&$@<V]A<"!M97-S86=E("HO"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R
M=F5R+T5M86EL+G!H<"<["@HO*B!I;F-L=61E(&$@8VQA<W,@=&\@86-C97-S
M(%!/4#,@*B\*"G)E<75I<F5?;VYC92`G3F5T+U!/4#,N<&AP)SL*"B\J(&-R
M96%T92!T:&4@4T]!4"!397)V97(@;V)J96-T("HO"@HD<V5R=F5R(#T@;F5W
M(%-/05!?4V5R=F5R7T5M86EL.PH*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L
M871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R
M=F5R+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@
M)V5X86UP;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?
M17AA;7!L95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P
M8VQA<W,L)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@H*+RH@0V]N;F5C
M="!T;R!A(%!/4#,@<V5R=F5R(&%N9"!R96%D('1H92!M97-S86=E<R`J+PH*
M)'!O<#,@/28@;F5W($YE=%]03U`S*"D["FEF("@D<&]P,RT^8V]N;F5C="@G
M;&]C86QH;W-T)RP@,3$P*2D@>PH@("`@:68@*"1P;W`S+3YL;V=I;B@G=7-E
M<FYA;64G+"`G<&%S<W=O<F0G*2D@>PH@("`@("`@("1L:7-T:6YG(#T@)'!O
M<#,M/F=E=$QI<W1I;F<H*3L*"@DO*B!N;W<@;&]O<"!T:')O=6=H(&5A8V@@
M;65S<V%G92P@86YD(&-A;&P@=&AE(`H@("`@("`@("`@(%-/05`@<V5R=F5R
M('=I=&@@=&AA="!M97-S86=E("HO"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T
M:6YG(&%S("1M<V<I('L*"B`@("`@("`@("`@("1E;6%I;"`]("1P;W`S+3YG
M971-<V<H)&US9ULG;7-G7VED)UTI.PH*("`@("`@("`@("`@+RH@=&AI<R!I
M<R!W:&5R92!W92!A8W1U86QL>2!H86YD;&4@=&AE(%-/05`*("`@("`@("`@
M("`@("`@<F5S<&]N<V4N("!4:&4@4T]!4#HZ4V5R=F5R.CI%;6%I;"!C;&%S
M<R!W90H@("`@("`@("`@("`@("!A<F4@=7-I;F<@=VEL;"!S96YD('1H92!3
M3T%0(')E<W!O;G-E('1O(`H@("`@("`@("`@("`@("!T:&4@<V5N9&5R('9I
M82!E;6%I;"X@*B\*"B`@("`@("`@("`@(&EF("@D96UA:6PI('L*("`@("`@
M("`@("`@("`@("1S97)V97(M/F-L:65N="@D96UA:6PI.PH*("`@("`@("`@
M("`@("`@("1P;W`S+3YD96QE=&5-<V<H)&US9ULG;7-G7VED)UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@)'!O<#,M/F1I<V-O;FYE
M8W0H*3L*?0H_/@H`````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE
M+V5M86EL7W-E<G9E<BYP:'``````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C4P`#$P
M-3$U-#,Q,#4W`#`R,S8V,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A
M=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO
M<F4@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D
M260Z(&5M86EL7W-E<G9E<BYP:'`L=B`Q+C4@,C`P-2\P,R\Q,"`R,SHQ-CHT
M,"!Y=6YO<V@@17AP("0*+R\*"B\J"E1H:7,@<F5A9',@82!M97-S86=E(&9R
M;VT@<W1D:6XL(&%N9"!C86QL<R!T:&4@<V]A<"!S97)V97(@9&5F:6YE9`H*
M66]U(&-A;B!U<V4@=&AI<R!F<F]M('%M86EL(&)Y(&-R96%T:6YG(&$@+G%M
M86EL+7-O87!T97-T(&9I;&4@=VET:#H*("`@('P@+W5S<B]B:6XO<&AP("]P
M871H+W1O+V5M86EL7W-E<G9E<BYP:'`**B\*"B,@:6YC;'5D92!T:&4@96UA
M:6P@<V5R=F5R(&-L87-S"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(O16UA
M:6PN<&AP)SL*"B1S97)V97(@/2!N97<@4T]!4%]397)V97)?16UA:6P["@HO
M*B!T96QL('-E<G9E<B!T;R!T<F%N<VQA=&4@=&\@8VQA<W-E<R!W92!P<F]V
M:61E(&EF('!O<W-I8FQE("HO"B1S97)V97(M/E]A=71O7W1R86YS;&%T:6]N
M(#T@=')U93L*"G)E<75I<F5?;VYC92`G97AA;7!L95]S97)V97(N<&AP)SL*
M"B1S;V%P8VQA<W,@/2!N97<@4T]!4%]%>&%M<&QE7U-E<G9E<B@I.PHD<V5R
M=F5R+3YA9&1/8FIE8W1-87`H)'-O87!C;&%S<RPG=7)N.E-/05!?17AA;7!L
M95]397)V97(G*3L*"B,@<F5A9"!S=&1I;@HD9FEN(#T@9F]P96XH)W!H<#HO
M+W-T9&EN)RPG<F(G*3L*:68@*"$D9FEN*2!E>&ET*#`I.PH*)&5M86EL(#T@
M)R<["G=H:6QE("@A9F5O9B@D9FEN*2`F)B`D9&%T82`](&9R96%D*"1F:6XL
M(#@P.38I*2!["B`@)&5M86EL("X]("1D871A.PI]"@IF8VQO<V4H)&9I;BD[
M"@HC(&1O:70A"B1S97)V97(M/G-E<G9I8V4H)&5M86EL*3L*"C\^````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]E>&%M
M<&QE7W-E<G9E<BYP:'``````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#(U-0`Q,#4Q-30S
M,3`U-P`P,C0R,C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\
M4VAA;F5`0V%R879E;RYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!E
M>&%M<&QE7W-E<G9E<BYP:'`L=B`Q+C4@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y
M=6YO<V@@17AP("0*+R\*"B\O(&9I<G-T+"!I;F-L=61E('1H92!33T%0+U-E
M<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@)U-/05`O5F%L=64N<&AP)SL*<F5Q
M=6ER95]O;F-E("=33T%0+T9A=6QT+G!H<"<["@HO+R!33T%04W1R=6-T(&ES
M(&1E9FEN960@:6X@=&AE(&9O;&QO=VEN9R!F:6QE"G)E<75I<F5?;VYC92`G
M97AA;7!L95]T>7!E<RYP:'`G.PH*+R\@8W)E871E(&$@8VQA<W,@9F]R('EO
M=7(@<V]A<"!F=6YC=&EO;G,*8VQA<W,@4T]!4%]%>&%M<&QE7U-E<G9E<B![
M"B`@("`O*BH*("`@("`J(%1H92!D:7-P86-T8V@@;6%P(&1O97,@;F]T(&YE
M960@=&\@8F4@=7-E9"P@8G5T(&%I9',*("`@("`J('1H92!S97)V97(@8VQA
M<W,@:6X@:VYO=VEN9R!W:&%T('!A<F%M971E<G,@87)E('5S960*("`@("`J
M('=I=&@@=&AE(&9U;F-T:6]N<RX@(%1H:7,@:7,@=&AE($].3%D@=V%Y('1O
M(&AA=F4*("`@("`J(&UU;'1I<&QE($]55"!P87)A;65T97)S+B`@268@>6]U
M('5S92!A(&1I<W!A=&-H(&UA<"P@>6]U"B`@("`@*B!-55-4(&%D9"!!3$P@
M9G5N8W1I;VYS('EO=2!W:7-H('1O(&%L;&]W(&)E(&-A;&QE9"X@($EF"B`@
M("`@*B!Y;W4@9&\@;F]T('5S92!A(&1I<W!A=&-H(&UA<"P@=&AE;B!A;GD@
M<'5B;&EC(&9U;F-T:6]N"B`@("`@*B!C86X@8F4@8V%L;&5D(&9R;VT@<V]A
M<"`H:6X@<&AP-"P@=V4@8V]N<VED97(@=&AI<R!T;R!B90H@("`@("H@86YY
M(&9U;F-T:6]N(&EN('1H92!C;&%S<R!U;FQE<W,@:70@<W1A<G1S('=I=&@@
M=6YD97)S8V]R92P*("`@("`J('!H<#4@<W5P<&]R="!I<R!N;W0@8V]M<&QE
M=&4@>65T(&EN('1H:7,@<F5G87)D*2X@(`H@("`@("H@:68@>6]U(&1O(&YO
M="!D969I;F4@:6XO;W5T('!A<F%M971E<G,L('1H92!F=6YC=&EO;B!C86X@
M8F4*("`@("`J(&-A;&QE9"!W:71H('!A<F%M971E<G,L(&)U="!N;R!V86QI
M9&%T:6]N(&]N('!A<F%M971E<G,@=VEL;`H@("`@("H@;V-C=7)E+@H@("`@
M("HO"B`@("!V87(@)%]?9&ES<&%T8VA?;6%P(#T@87)R87DH*3L*"B`@("!F
M=6YC=&EO;B!33T%07T5X86UP;&5?4V5R=F5R*"D@>PH@("`@("`@("\J*@H@
M("`@("`@("H@=VAE;B!G96YE<F%T:6YG('=S9&P@9F]R(&$@<V5R=F5R+"!Y
M;W4@:&%V92!T;R!D969I;F4*("`@("`@("`J(&%N>2!S<&5C:6%L(&-O;7!L
M97@@='EP97,@=&AA="!Y;W4@=7-E("AI92!C;&%S<V5S*2X*("`@("`@("`J
M('5S:6YG(&$@;F%M97-P86-E(&ED(&)E9F]R92!T:&4@='EP92!W:6QL(&-R
M96%T92!A;@H@("`@("`@("H@>&UL('-C:&5M82!W:71H('1H92!T87)G971.
M86UE<W!A8V4@9F]R('1H92!T>7!E"B`@("`@("`@*B!M=6QT:7!L92!T>7!E
M<R!W:71H('1H92!S86UE(&YA;65S<&%C92!W:6QL(&%P<&5A<@H@("`@("`@
M("H@:6X@=&AE('-A;64@<V-H96UA('-E8W1I;VXN("!T>7!E<R!W:71H(&1I
M9F9E<F5N=`H@("`@("`@("H@;F%M97-P86-E<R!W:6QL(&)E(&EN('-E<&5R
M871E('-C:&5M82!S96-T:6]N<RX*("`@("`@("`J('1H92!F;VQL;W=I;F<@
M4T]!4%-T<G5C="!T>7!E9&5F(&-O;W)E<W!O;F1S('1O('1H90H@("`@("`@
M("H@4T]!4%-T<G5C="!C;&%S<R!A8F]V92X*("`@("`@("`J+PH@("`@("`@
M("1T:&ES+3Y?7W1Y<&5D969;)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS
M9'U33T%04W1R=6-T)UT@/2`*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@)W9A<E-T<FEN9R<@/3X@)W-T<FEN
M9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=V87));G0G(#T^("=I;G0G
M+"`*("`@("`@("`@("`@("`@("`@("`@("`@)W9A<D9L;V%T)R`]/B`G9FQO
M870G"B`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`O+R!A
M;B!A;&EA<V5D(&9U;F-T:6]N('=I=&@@;75L=&EP;&4@;W5T('!A<F%M971E
M<G,*"21T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG96-H;U-T<G5C=$%S4VEM<&QE
M5'EP97,G72`]"@D)87)R87DH)VEN)R`]/B!A<G)A>2@G:6YP=713=')U8W0G
M(#T^("=[:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C="<I
M+`H)"2`@("`@("=O=70G(#T^(&%R<F%Y*"=O=71P=713=')I;F<G(#T^("=S
M=')I;F<G+"`G;W5T<'5T26YT96=E<B<@/3X@)VEN="<L("=O=71P=71&;&]A
M="<@/3X@)V9L;V%T)RDL"@D)("`@("`@)V%L:6%S)R`]/B`G;7E%8VAO4W1R
M=6-T07-3:6UP;&54>7!E<R<*"0D@("`@("`I.PH))'1H:7,M/E]?9&ES<&%T
M8VA?;6%P6R=E8VAO4W1R:6YG4VEM<&QE)UT@/0H)"6%R<F%Y*"=I;B<@/3X@
M87)R87DH)VEN<'5T4W1R:6YG4VEM<&QE)R`]/B`G<W1R:6YG)RDL"@D)("`@
M("`@)V]U="<@/3X@87)R87DH)V]U='!U=%-T<FEN9U-I;7!L92<@/3X@)W-T
M<FEN9R<I+`H)"2`@("`@("D["@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V5C
M:&]3=')I;F<G72`]"@D)87)R87DH)VEN)R`]/B!A<G)A>2@G:6YP=713=')I
M;F<G(#T^("=S=')I;F<G*2P*"0D@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T
M<'5T4W1R:6YG)R`]/B`G<W1R:6YG)RDL"@D)("`@("`@*3L*"21T:&ES+3Y?
M7V1I<W!A=&-H7VUA<%LG9&EV:61E)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R
M87DH)V1I=FED96YD)R`]/B`G:6YT)RP@)V1I=FES;W(G(#T^("=I;G0G*2P*
M"0D@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T<'5T1FQO870G(#T^("=F;&]A
M="<I+`H)"2`@("`@("D["@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V5C:&]3
M=')U8W0G72`]"@D)87)R87DH)VEN)R`]/B!A<G)A>2@G:6YP=713=')U8W0G
M(#T^("=[:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C="<I
M+`H)"2`@("`@("=O=70G(#T^(&%R<F%Y*"=O=71P=713=')U8W0G(#T^("=[
M:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C="<I+`H)"2`@
M("`@("D["@D*"21T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG96-H;TUI;65!='1A
M8VAM96YT)UT@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J('1H:7,@<')I=F%T
M92!F=6YC=&EO;B!I<R!C86QL960@;VX@8GD@4T]!4%]397)V97(@=&\@9&5T
M97)M:6YE(&%N>0H@("`@("`@('-P96-I86P@9&ES<&%T8V@@:6YF;W)M871I
M;VX@=&AA="!M:6=H="!B92!N96-E<W-A<GDN("!4:&ES+"!F;W(@97AA;7!L
M92P*("`@("`@("!C86X@8F4@=7-E9"!T;R!S970@=7`@82!D:7-P871C:"!M
M87`@9F]R(&9U;F-T:6]N<R!T:&%T(')E='5R;B!M=6QT:7!L90H@("`@("`@
M($]55"!P87)A;65T97)S("HO"B`@("!F=6YC=&EO;B!?7V1I<W!A=&-H*"1M
M971H;V1N86UE*2!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?7V1I<W!A
M=&-H7VUA<%LD;65T:&]D;F%M95TI*0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]?9&ES<&%T8VA?;6%P6R1M971H;V1N86UE73L*("`@("`@("!R971U
M<FX@3E5,3#L*("`@('T*"B`@("`O+R!A('-I;7!L92!E8VAO4W1R:6YG(&9U
M;F-T:6]N"B`@("!F=6YC=&EO;B!E8VAO4W1R:6YG4VEM<&QE*"1I;G!U=%-T
M<FEN9RD*("`@('L*"7)E='5R;B`D:6YP=713=')I;F<["B`@("!]"B`@("`*
M("`@("\O(&%N(&5X<&QI8VET(&5C:&]S=')I;F<@9G5N8W1I;VX*("`@(&9U
M;F-T:6]N(&5C:&]3=')I;F<H)&EN<'5T4W1R:6YG*0H@("`@>PH)<F5T=7)N
M(&YE=R!33T%07U9A;'5E*"=O=71P=713=')I;F<G+"=S=')I;F<G+"1I;G!U
M=%-T<FEN9RD["B`@("!]"@H@("`@9G5N8W1I;VX@9&EV:61E*"1D:79I9&5N
M9"P@)&1I=FES;W(I"B`@("!["B`@("`@("`@+R\@=&AE('-O87`@<V5R=F5R
M('=O=6QD(&YO<FUA;&QY(&-A=&-H(&5R<F]R<R!L:6ME('1H:7,*("`@("`@
M("`O+R!A;F0@<F5T=7)N(&$@9F%U;'0L(&)U="!T:&ES(&ES(&AO=R!Y;W4@
M9&\@:70@>6]U<G-E;&8N"B`@("`@("`@:68@*"1D:79I<V]R(#T](#`I"B`@
M("`@("`@("`@(')E='5R;B!N97<@4T]!4%]&875L="@G66]U(&-A;FYO="!D
M:79I9&4@8GD@>F5R;R<L("=#;&EE;G0G*3L*("`@("`@("!E;'-E"B`@("`@
M("`@("`@(')E='5R;B`D9&EV:61E;F0@+R`D9&EV:7-O<CL*("`@('T*"B`@
M("!F=6YC=&EO;B!E8VAO4W1R=6-T*"1I;G!U=%-T<G5C="D*("`@('L*("`@
M("`@("!R971U<FX@)&EN<'5T4W1R=6-T+3Y?7W1O7W-O87`H)V]U='!U=%-T
M<G5C="<I.PH)(W)E='5R;B!N97<@4T]!4%]686QU92@G;W5T<'5T4W1R=6-T
M)RPG>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G+"1I
M;G!U=%-T<G5C="D["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@96-H;U-T
M<G5C=$%S4VEM<&QE5'EP97,*("`@("`J('1A:V5S(&$@4T]!4%-T<G5C="!A
M<R!I;G!U="P@86YD(')E='5R;G,@96%C:"!O9B!I=',@96QE;65N=',*("`@
M("`J(&%S($]55"!P87)A;65T97)S"B`@("`@*@H@("`@("H@=&AI<R!F=6YC
M=&EO;B!I<R!A;'-O(&%L:6%S960@<V\@>6]U(&AA=F4@=&\@8V%L;"!I="!W
M:71H"B`@("`@*B!E8VAO4W1R=6-T07-3:6UP;&54>7!E<PH@("`@("H*("`@
M("`J(%-/05!3=')U8W0@:7,@9&5F:6YE9"!A<SH*("`@("`J"B`@("`@*B!S
M=')U8W0@4T]!4%-T<G5C=#H*("`@("`J("`@('-T<FEN9R!V87)3=')I;F<*
M("`@("`J("`@(&EN=&5G97(@=F%R26YT"B`@("`@*B`@("!F;&]A="!V87)&
M;&]A=`H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@;7E%8VAO4W1R=6-T
M07-3:6UP;&54>7!E<R@D<W1R=6-T*0H@("`@>PH)(R!C;VYV97)T(&$@4T]!
M4%-T<G5C="!T;R!A;B!A<G)A>0H)<F5T=7)N(&%R<F%Y*`H)("`@(&YE=R!3
M3T%07U9A;'5E*"=O=71P=713=')I;F<G+"=S=')I;F<G+"1S=')U8W0M/G9A
M<E-T<FEN9RDL"@D@("`@;F5W(%-/05!?5F%L=64H)V]U='!U=$EN=&5G97(G
M+"=I;G0G+"1S=')U8W0M/G9A<DEN="DL"@D@("`@;F5W(%-/05!?5F%L=64H
M)V]U='!U=$9L;V%T)RPG9FQO870G+"1S=')U8W0M/G9A<D9L;V%T*0H)("`@
M("D["B`@("!]"B`@("`*("`@(&9U;F-T:6]N(&5C:&]-:6UE071T86-H;65N
M="@D<W1U9F8I"B`@("!["B`@("`@("`@<F5T=7)N(&YE=R!33T%07T%T=&%C
M:&UE;G0H)W)E='5R;B<L)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<L3E5,
M3"PD<W1U9F8I.PH@("`@?2`@("`*?0H*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0
M+V5X86UP;&4O97AA;7!L95]T>7!E<RYP:'``````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(V,S<`,3`U,34T,S$P-3<`,#(T,#8V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*@HJ('1H:7,@:7,@82!D
M871A('1Y<&4@=&AA="!I<R!U<V5D(&EN(%-/05`@26YT97)O<"!T97-T:6YG
M+"!B=70@:7,**B!H97)E(&%S(&%N(&5X86UP;&4@;V8@=7-I;F<@8V]M<&QE
M>"!T>7!E<RX@(%=H96X@=&AE(&-L87-S(&ES"BH@9&5S97)I86QI>F5D(&9R
M;VT@82!33T%0(&UE<W-A9V4L(&ET)W,@8V]N<W1R=6-T;W(@25,@3D]4($-!
M3$Q%1"$**B!3;R!Y;W5R('1Y<&4@8VQA<W-E<R!N965D('1O(&)E:&%V92!I
M;B!A('=A>2!T:&%T('=I;&P@=V]R:PHJ('=I=&@@=&AA="X**@HJ(%-O;64@
M='EP97,@;6%Y(&YE960@;6]R92!E>'!L:6-I="!S97)I86QI>F%T:6]N(&9O
M<B!33T%0+B`@5&AE"BH@7U]T;U]S;V%P(&9U;F-T:6]N(&%L;&]W<R!Y;W4@
M=&\@8F4@=F5R>2!E>'!L:6-I="!I;B!B=6EL9&EN9R!T:&4**B!33T%07U9A
M;'5E('-T<G5C='5R97,N("!4:&4@<V]A<"!L:6)R87)Y(&1O97,@;F]T(&-A
M;&P@=&AI<R!D:7)E8W1L>2P**B!Y;W4@=V]U;&0@8V%L;"!I="!F<F]M('EO
M=7(@<V]A<"!S97)V97(@8VQA<W,L(&5C:&]3=')U8W0@:6X@=&AE('-E<G9E
M<@HJ(&-L87-S(&ES(&%N(&5X86UP;&4@;V8@9&]I;F<@=&AI<RX**B\*8VQA
M<W,@4T]!4%-T<G5C="!["B`@("!V87(@)'9A<E-T<FEN9SL*("`@('9A<B`D
M=F%R26YT.PH@("`@=F%R("1V87)&;&]A=#L*("`@(&9U;F-T:6]N(%-/05!3
M=')U8W0H)',]3E5,3"P@)&D]3E5,3"P@)&8]3E5,3"D@>PH@("`@("`@("1T
M:&ES+3YV87)3=')I;F<@/2`D<SL*("`@("`@("`D=&AI<RT^=F%R26YT(#T@
M)&D["B`@("`@("`@)'1H:7,M/G9A<D9L;V%T(#T@)&8["B`@("!]"B`@("`*
M("`@(&9U;F-T:6]N("9?7W1O7W-O87`H)&YA;64@/2`G:6YP=713=')U8W0G
M+"`D:&5A9&5R/69A;'-E+"`D;75S=%5N9&5R<W1A;F0],"P@)&%C=&]R/2=H
M='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V%C=&]R+VYE>'0G*0H@
M("`@>PH@("`@("`@("1I;FYE<EM=(#TF(&YE=R!33T%07U9A;'5E*"=V87)3
M=')I;F<G+"=S=')I;F<G+"1T:&ES+3YV87)3=')I;F<I.PH@("`@("`@("1I
M;FYE<EM=(#TF(&YE=R!33T%07U9A;'5E*"=V87));G0G+"=I;G0G+"1T:&ES
M+3YV87));G0I.PH@("`@("`@("1I;FYE<EM=(#TF(&YE=R!33T%07U9A;'5E
M*"=V87)&;&]A="<L)V9L;V%T)RPD=&AI<RT^=F%R1FQO870I.PH@("`@("`@
M(&EF("@D:&5A9&5R*2!["B`@("`@("`@("`@(')E='5R;B!N97<@4T]!4%](
M96%D97(H)&YA;64L)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%0
M4W1R=6-T)RPD:6YN97(L)&UU<W15;F1E<G-T86YD+"1A8W1O<BD["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!N97<@4T]!4%]686QU92@D;F%M92PG>VAT
M='`Z+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G+"1I;FYE<BD[
M"B`@("`@("`@"B`@("!]"GT*"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S97)V97(N<&AP````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<T-0`Q,#4Q-30S,3`U-P`P,C(U
M,38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R
M879E;RYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!S97)V97(N<&AP
M+'8@,2XQ,"`R,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*
M+R\@9FER<W0L(&EN8VQU9&4@=&AE(%-/05`O4V5R=F5R(&-L87-S"G)E<75I
M<F5?;VYC92`G4T]!4"]397)V97(N<&AP)SL*"B1S97)V97(@/2!N97<@4T]!
M4%]397)V97(["B\J('1E;&P@<V5R=F5R('1O('1R86YS;&%T92!T;R!C;&%S
M<V5S('=E('!R;W9I9&4@:68@<&]S<VEB;&4@*B\*)'-E<G9E<BT^7V%U=&]?
M=')A;G-L871I;VX@/2!T<G5E.PH*<F5Q=6ER95]O;F-E("=E>&%M<&QE7W-E
M<G9E<BYP:'`G.PH*)'-O87!C;&%S<R`](&YE=R!33T%07T5X86UP;&5?4V5R
M=F5R*"D["B1S97)V97(M/F%D9$]B:F5C=$UA<"@D<V]A<&-L87-S+"=U<FXZ
M4T]!4%]%>&%M<&QE7U-E<G9E<B<I.PH*:68@*&ES<V5T*"1?4T525D526R=2
M15%515-47TU%5$A/1"==*2`F)@H@("`@)%]315)615);)U)%455%4U1?3454
M2$]$)UT]/2=03U-4)RD@>PH@("`@)'-E<G9E<BT^<V5R=FEC92@D2%144%]2
M05=?4$]35%]$051!*3L*?2!E;'-E('L*("`@(')E<75I<F5?;VYC92`G4T]!
M4"]$:7-C;RYP:'`G.PH@("`@)&1I<V-O(#T@;F5W(%-/05!?1$E30T]?4V5R
M=F5R*"1S97)V97(L)U-E<G9E<D5X86UP;&4G*3L*("`@(&AE861E<B@B0V]N
M=&5N="UT>7!E.B!T97AT+WAM;"(I.PH@("`@:68@*&ES<V5T*"1?4T525D52
M6R=1545265]35%))3D<G72D@)B8*("`@("`@('-T<F-A<V5C;7`H)%]315)6
M15);)U%515)97U-44DE.1R==+"=W<V1L)RD]/3`I('L*("`@("`@("!E8VAO
M("1D:7-C;RT^9V5T5U-$3"@I.PH@("`@?2!E;'-E('L*("`@("`@("!E8VAO
M("1D:7-C;RT^9V5T1$E30T\H*3L*("`@('T*("`@(&5X:70["GT*/SX`````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O<V5R=F5R,BYP:'``````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4P-3,`,3`U,34T,S$P-3<`,#(R-3<R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS
M92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N
M8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@<V5R=F5R,BYP:'`L=B`Q
M+C,@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*"B\O(&9I
M<G-T+"!I;F-L=61E('1H92!33T%0+U-E<G9E<B!C;&%S<PIR97%U:7)E7V]N
M8V4@)U-/05`O4V5R=F5R+G!H<"<["@HD<V5R=F5R(#T@;F5W(%-/05!?4V5R
M=F5R.PHO*B!T96QL('-E<G9E<B!T;R!T<F%N<VQA=&4@=&\@8VQA<W-E<R!W
M92!P<F]V:61E(&EF('!O<W-I8FQE("HO"B1S97)V97(M/E]A=71O7W1R86YS
M;&%T:6]N(#T@=')U93L*"B\J(%1H:7,@:7,@82!S:6UP;&4@97AA;7!L92!O
M9B!I;7!L96UE;G1I;F<@82!C=7-T;VT*("`@8V%L;"!H86YD;&5R+B`@268@
M>6]U(&1O('1H:7,L('1H92!S;V%P('-E<G9E<B!W:6QL(&EG;F]R90H@("!O
M8FIE8W1S(&]R(&9U;F-T:6]N<R!A9&1E9"!T;R!I="P@86YD('=I;&P@8V%L
M;"!Y;W5R(&AA;F1L97(*("`@9F]R("HJ04Q,*BH@<V]A<"!C86QL<R!T:&4@
M<V5R=F5R(')E8V5I=F5S+"!W971H97(@=&AE(&-A;&P*("`@:7,@9&5F:6YE
M9"!I;B!Y;W5R(%=31$P@;W(@;F]T+B`@5&AE(&AA;F1L97(@<F5C96EV97,@
M='=O"B`@(&%R9W5M96YT<RP@=&AE(&UE=&AO9"!N86UE(&)E:6YG(&-A;&QE
M9"P@86YD('1H92!A<F=U;65N=',*("`@<V5N="!F;W(@=&AA="!C86QL+@HJ
M+PIF=6YC=&EO;B!M>4-A;&Q(86YD;&5R*"1M971H;V1N86UE+"`D87)G<RD*
M>PH@("`@9VQO8F%L("1S;V%P8VQA<W,["B`@("!R971U<FX@0&-A;&Q?=7-E
M<E]F=6YC7V%R<F%Y*&%R<F%Y*"1S;V%P8VQA<W,L("1M971H;V1N86UE*2PD
M87)G<RD["GT*)'-E<G9E<BT^<V5T0V%L;$AA;F1L97(H)VUY0V%L;$AA;F1L
M97(G+&9A;'-E*3L*"G)E<75I<F5?;VYC92`G97AA;7!L95]S97)V97(N<&AP
M)SL*"B1S;V%P8VQA<W,@/2!N97<@4T]!4%]%>&%M<&QE7U-E<G9E<B@I.PHD
M<V5R=F5R+3YA9&1/8FIE8W1-87`H)'-O87!C;&%S<RPG=7)N.E-/05!?17AA
M;7!L95]397)V97(G*3L*"FEF("AI<W-E="@D7U-%4E9%4ELG4D5154535%]-
M151(3T0G72D@)B8*("`@("1?4T525D526R=215%515-47TU%5$A/1"==/3TG
M4$]35"<I('L*("`@("1S97)V97(M/G-E<G9I8V4H)$A45%!?4D%77U!/4U1?
M1$%402D["GT@96QS92!["B`@("!R97%U:7)E7V]N8V4@)U-/05`O1&ES8V\N
M<&AP)SL*("`@("1D:7-C;R`](&YE=R!33T%07T1)4T-/7U-E<G9E<B@D<V5R
M=F5R+"=397)V97)%>&%M<&QE)RD["B`@("!H96%D97(H(D-O;G1E;G0M='EP
M93H@=&5X="]X;6PB*3L*("`@(&EF("AI<W-E="@D7U-%4E9%4ELG455%4EE?
M4U1224Y')UTI("8F"B`@("`@("!S=')C87-E8VUP*"1?4T525D526R=15452
M65]35%))3D<G72PG=W-D;"<I/3TP*2!["B`@("`@("`@96-H;R`D9&ES8V\M
M/F=E=%=31$PH*3L*("`@('T@96QS92!["B`@("`@("`@96-H;R`D9&ES8V\M
M/F=E=$1)4T-/*"D["B`@("!]"B`@("!E>&ET.PI]"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/
M05`O97AA;7!L92]S;71P+G!H<```````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S(W,P`Q,#4Q-30S,3`U-P`P,C(Q-C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#\*+R\*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA
M;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\*+R\@)$ED.B!S;71P+G!H<"QV(#$N-2`R,#`U+S`S+S$P(#(S.C$V.C0P
M('EU;F]S:"!%>'`@)`HO+PHO+R!I;F-L=61E('-O87`@8VQI96YT(&-L87-S
M"FEN8VQU9&4H(E-/05`O0VQI96YT+G!H<"(I.PH*)'-O87!C;&EE;G0@/2!N
M97<@4T]!4%]#;&EE;G0H(FUA:6QT;SIU<V5R0&1O;6%I;BYC;VTB*3L*)&]P
M=&EO;G,@/2!A<G)A>2@G;F%M97-P86-E)ST^)VAT='`Z+R]S;V%P:6YT97)O
M<"YO<F<O)RPG9G)O;2<]/B=U<V5R0&1O;6%I;BYC;VTG+"=H;W-T)ST^)VQO
M8V%L:&]S="<I.PHD<F5T=7)N(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3
M=')I;F<B+&%R<F%Y*")I;G!U=%-T<FEN9R(]/B)T:&ES(&ES(&$@=&5S="(I
M+"`D;W!T:6]N<RD["B1R971U<FX@/2`D<V]A<&-L:65N="T^8V%L;"@B96-H
M;U-T<FEN9T%R<F%Y(BQA<G)A>2@G:6YP=713=')I;F=!<G)A>2<@/3X@87)R
M87DH)V=O;V0G+"=B860G+"=U9VQY)RDI+"`D;W!T:6]N<RD["B\O(&1O;B=T
M(&5X<&5C="!M=6-H(&]F(&$@<F5S=6QT(0IP<FEN=%]R*"1R971U<FXI.PIP
M<FEN="`B/&)R/EQN(BXD<V]A<&-L:65N="T^=VER93L*/SX*"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X
M86UP;&4O<W1O8VMQ=6]T92YP:'``````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T
M,3(`,3`U,34T,S$P-3<`,#(S-#`Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QH=&UL/CQB;V1Y/@H\/PHO+PHO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T
M('1O(%!%05(@86YD(&UO<F4@("!\"B\O('P@075T:&]R<SH@1&EE=')I8V@@
M07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@
M)$ED.B!S=&]C:W%U;W1E+G!H<"QV(#$N-R`R,#`U+S`S+S$P(#(S.C$V.C0P
M('EU;F]S:"!%>'`@)`HO+PHO+R!I;F-L=61E('-O87`@8VQI96YT(&-L87-S
M"FEN8VQU9&4H(E-/05`O0VQI96YT+G!H<"(I.PH*<')I;G0@(CQB<CY<;CQS
M=')O;F<^=W-D;#H\+W-T<F]N9SXB.PHD=W-D;"`](&YE=R!33T%07U=31$PH
M(FAT='`Z+R]S97)V:6-E<RYX;65T:&]D<RYN970O<V]A<"]U<FXZ>&UE=&AO
M9',M9&5L87EE9"UQ=6]T97,N=W-D;"(I.PHD<V]A<&-L:65N="`]("1W<V1L
M+3YG9710<F]X>2@I.PIP<FEN=%]R*"1S;V%P8VQI96YT+3YG9711=6]T92@B
M:6)M(BDI.PIP<FEN="`B7&Y<;B(["@II9B`H97AT96YS:6]N7VQO861E9"@G
M;W9E<FQO860G*2D@>PH)<')I;G0@(EQN/&)R/CQS=')O;F<^;W9E<FQO861E
M9#H\+W-T<F]N9SXB.PH))')E="`]("1S;V%P8VQI96YT+3YG9711=6]T92@B
M:6)M(BD["@EP<FEN=%]R*"1R970I.PH)<')I;G0@(EQN7&XB.PI]"G5N<V5T
M*"1S;V%P8VQI96YT*3L*"G!R:6YT(")<;CQB<CX\<W1R;VYG/FYO;B!W<V1L
M.CPO<W1R;VYG/B(["B1S;V%P8VQI96YT(#T@;F5W(%-/05!?0VQI96YT*")H
M='1P.B\O<V5R=FEC97,N>&UE=&AO9',N;F5T.C@P+W-O87`B*3L*)&YA;65S
M<&%C92`](")U<FXZ>&UE=&AO9',M9&5L87EE9"UQ=6]T97,B.PHO*BH*("H@
M<V]M92!S;V%P('-E<G9E<G,@<F5Q=6ER92!A(%-O87!A8W1I;VX@:'1T<"!H
M96%D97(N("!014%2.CI33T%0(&1O97,*("H@;F]T('5S92!T:&5M(&EN(&%N
M>2!W87DL(&]T:&5R('1O('-E;F0@=&AE;2!I9B!Y;W4@<W5P<&QY('1H96TN
M"B`J('-O87!A8W1I;VX@:7,@9&5P<F5C871E9"!I;B!L871E<B!33T%0('9E
M<G-I;VYS+@H@*B\*)'-O87!A8W1I;VX@/2`B=7)N.GAM971H;V1S+61E;&%Y
M960M<75O=&5S(V=E=%%U;W1E(CL*)')E="`]("1S;V%P8VQI96YT+3YC86QL
M*")G9711=6]T92(L87)R87DH(G-Y;6)O;"(]/B)I8FTB*2PD;F%M97-P86-E
M+"1S;V%P86-T:6]N*3L*<')I;G1?<B@D<F5T*3L*<')I;G0@(EQN7&XB.PIU
M;G-E="@D<V]A<&-L:65N="D["@H_/@H\+VAT;6P^/"]B;V1Y/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]33T%0+V5X86UP;&4O=&-P7V-L:65N="YP:'``````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,T,#``,3`U,34T,S$P-3<`,#(S,S(P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\O"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\
M"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L
M92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<G,Z(%-H86YE($AA;FYA(#QI;W)D>5]A=%]I;W)D>5]D;W1?8V]M/B`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@=&-P7V-L:65N="YP:'`L=B`Q+C,@,C`P
M-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*"G)E<75I<F5?;VYC
M92@G4T]!4"]#;&EE;G0N<&AP)RD["@HC(&-L:65N=`HD<V]A<&-L:65N="`]
M(&YE=R!33T%07T-L:65N="@B=&-P.B\O,3(W+C`N,"XQ.C@R(BD["@HC(&YA
M;65S<&%C90HD;W!T:6]N<R`](&%R<F%Y*"=N86UE<W!A8V4G(#T^("=U<FXZ
M4T]!4%]%>&%M<&QE7U-E<G9E<B<L("=T<F%C92<@/3X@,2D["@HC(&]N90HD
M<&%R86US(#T@87)R87DH(G-T<FEN9R(@/3X@(G1H:7,@:7,@<W1R:6YG(#$B
M*3L*)')E=#$@/2`D<V]A<&-L:65N="T^8V%L;"@B96-H;U-T<FEN9R(L("1P
M87)A;7,L("1O<'1I;VYS*3L*(R!E8VAO(")725)%.B!<;B(N)'-O87!C;&EE
M;G0M/E]?9V5T7W=I<F4H*3L*<')I;G1?<B@D<F5T,2D["F5C:&\@(CQB<B`O
M/EQN(CL*"B,@='=O"B1P87)A;7,@/2!A<G)A>2@B<W1R:6YG(B`]/B`B=&AI
M<R!I<R!S=')I;F<@,B(I.PHD<F5T,B`]("1S;V%P8VQI96YT+3YC86QL*")E
M8VAO4W1R:6YG(BP@)'!A<F%M<RP@)&]P=&EO;G,I.PHC(&5C:&\@(E=)4D4Z
M(%QN(BXD<V]A<&-L:65N="T^7U]G971?=VER92@I.PIP<FEN=%]R*"1R970R
M*3L*96-H;R`B/&)R("\^7&XB.PH*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M4T]!4"]E>&%M<&QE+W1C<%]D865M;VXN<&P`````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S,34W`#$P-3$U-#,Q,#4W`#`R,S$T,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C(2]U<W(O8FEN+W!E<FP@+7<*
M=7-E('-T<FEC=#L*"CUH96%D,2!3:6UP;&4@4T]!4"!40U`@4V5R=F5R"@H@
M("`@4VEM<&QE(%-/05`@5$-0(%-E<G9E<B!W:71H('1E<W0@8VQA<W,@*&IU
M<W0@=&\@8VAE8VL@=&AI;F=S(&%R92!W;W)K:6YG*0H*("`@($)E9F]R92!Y
M;W4@<G5N('1H:7,@=&5S="!S97)V97(@>6]U('=I;&P@;F5E9"!S;VUE('!E
M<FP@8VQA<W-E<RP@;F%M96QY.@H@("`@("`@(%-/05`Z.DQI=&4*("`@("`@
M("!(;V]K.CI,97A7<F%P("AI9B!Y;W4@=V%N="!T;R!S964@<V]M92!D96)U
M9V=I;F<I"@H@("`@("`@($9L964@;V9F('1O('1H92!#4$%.(&EF('EO=2!N
M965D('1H96T@.BD*"B`@("!4;R!R=6X@='EP92`G<&5R;"`\9FEL96YA;64^
M)R!A;F0@:68@>6]U(&1O;G0@9V5T(&%N>2!E<G)O<G,L(&ET)W,@=&EM90H@
M("`@=&\@9V\@=W)I=&4@<V]M92!C;V1E('1O(&-O;FYE8W0N"CUC=70*"G5S
M92!33T%0.CI4<F%N<W!O<G0Z.E1#4"!Q=RAT<F%C92D["G5S92!$871A.CI$
M=6UP97(["@H*(R,C(R,C(R,C(R,C(PHC(R!I9B!Y;W4@=V%N="!T;R!S964@
M:6YC;VUI;F<O;W5T9V]I;F<@<F%W('AM;`HC(R!U;F-O;6UE;G0@=&AE(&9O
M;&QO=VEN9RX*"B-U<V4@2&]O:SHZ3&5X5W)A<#L*(W=R87`@*DE/.CI397-S
M:6]N1&%T83HZ<F5A9"P@<&]S="`]/B!<)G-H;W=?<F5A9#L*(W=R87`@*DE/
M.CI397-S:6]N1&%T83HZ=W)I=&4L('!O<W0@/3X@7"9S:&]W7W=R:71E.PH*
M(R,*(R,C(R,C(R,C(R,C(PH*"FUY("1D865M;VX@/2!33T%0.CI4<F%N<W!O
M<G0Z.E1#4#HZ4V5R=F5R+3YN97<H"B`@("!,;V-A;$%D9'(@/3X@)S$R-RXP
M+C`N,2<L"B`@("!,;V-A;%!O<G0@/3X@)S@R)RP*("`@($QI<W1E;B`@("`]
M/B`U+`H@("`@4F5U<V4@("`@(#T^(#$**3L*"B,@9&ES<&%T8V@*)&1A96UO
M;BT^9&ES<&%T8VA?=&\H)U-/05!?17AA;7!L95]397)V97(G*3L*)&1A96UO
M;BT^:&%N9&QE.PH*(R,C(R,C(R,C(R,C(PHC(R!C86QL8F%C:R!F=6YC=&EO
M;G,@9F]R($AO;VLZ.DQE>%=R87`["B,C"@HC('-H;W<@:6YC;VUI;F<@>&UL
M"G-U8B!S:&]W7W)E860@>PH@("`@<')I;G0@)"\L)R,C(')E860@(R,G+"0O
M.PH@("`@<')I;G0@1'5M<&5R*"1?6S!=*3L*?0H*(R!S:&]W(&]U=&=O:6YG
M('AM;`IS=6(@<VAO=U]W<FET92!["B`@("!P<FEN="`D+RPG(R,@=W)I=&4@
M(R,G+"0O.PH@("`@<')I;G0@1'5M<&5R*"1?6S!=*3L*?0HC(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PH*"@HC(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%-/05!?17AA;7!L95]397)V97(*(R!3
M:6UP;&4@=&5S="!C;&%S<RP@;65T:&]D('1E<W0@<F5T=7)N<R!D;W5B;&4@
M=VAA="!Y;W4@<V5N9"!T;R!I="P@=&AA=',@86QL(0HC(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PIP86-K86=E(%-/05!?17AA;7!L95]3
M97)V97(["@IS=6(@96-H;U-T<FEN9R!["B`@("!R971U<FX@)%];,5T@>"`R
M.PI]"@HQ.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O
M97AA;7!L92]T8W!?<V5R=F5R+G!H<```````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S$R,0`Q,#4Q-30S,3`U-P`P,C,S-3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA
M;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\*+R\@)$ED.B!T8W!?<V5R=F5R+G!H<"QV(#$N-"`R,#`U+S`S+S$P(#(S
M.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*+R\@9FER<W0L(&EN8VQU9&4@=&AE
M(%-/05`O4V5R=F5R(&-L87-S"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(O
M5$-0+G!H<"<["G-E=%]T:6UE7VQI;6ET*#`I.PH*)'-E<G9E<B`](&YE=R!3
M3T%07U-E<G9E<E]40U`H(C$R-RXP+C`N,2(L.#(I.PHO*B!T96QL('-E<G9E
M<B!T;R!T<F%N<VQA=&4@=&\@8VQA<W-E<R!W92!P<F]V:61E(&EF('!O<W-I
M8FQE("HO"B1S97)V97(M/E]A=71O7W1R86YS;&%T:6]N(#T@=')U93L*"G)E
M<75I<F5?;VYC92`G97AA;7!L95]S97)V97(N<&AP)SL*"B1S;V%P8VQA<W,@
M/2!N97<@4T]!4%]%>&%M<&QE7U-E<G9E<B@I.PHD<V5R=F5R+3YA9&1/8FIE
M8W1-87`H)'-O87!C;&%S<RPG=7)N.E-/05!?17AA;7!L95]397)V97(G*3L*
M)'-E<G9E<BT^<G5N*"D["C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP
M;&4O=W-D;%]C;&EE;G0N<&AP````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8T-C0`
M,3`U,34T,S$P-3<`,#(S-3(P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A
M<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("1)9#H@=W-D;%]C;&EE;G0N<&AP+'8@,2XS(#(P,#4O,#,O,3`@,C,Z,38Z
M-#`@>75N;W-H($5X<"`D"B\O"FEN8VQU9&4H(E-/05`O0VQI96YT+G!H<"(I
M.PH*+RHJ"B`J('1H:7,@8VQI96YT(')U;G,@86=A:6YS="!T:&4@97AA;7!L
M92!S97)V97(@:6X@4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'`*("H@:70@9&]E
M<R!N;W0@=7-E(%=31$P@=&\@<G5N('1H97-E(')E<75E<W1S+"!B=70@=&AA
M="!C86X@8F4@8VAA;F=E9"!E87-I;'D@8GD@<VEM<&QY"B`J(&%D9&EN9R`G
M/W=S9&PG('1O('1H92!E;F0@;V8@=&AE('5R;"X*("HO"B1W<V1L(#T@;F5W
M(%-/05!?5U-$3"@B:'1T<#HO+VQO8V%L:&]S="]33T%0+V5X86UP;&4O<V5R
M=F5R+G!H<#]W<V1L(BD["B1S;V%P8VQI96YT(#T@)'=S9&PM/F=E=%!R;WAY
M*"D["@HD<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')I;F=3:6UP;&4H(G1H
M:7,@:7,@82!T97-T('-T<FEN9R(I.PHC<')I;G0@)'-O87!C;&EE;G0M/E]?
M9V5T7W=I<F4H*3L*<')I;G1?<B@D<F5T*3ME8VAO("(\8G(^7&XB.PH*)')E
M="`]("1S;V%P8VQI96YT+3YE8VAO4W1R:6YG*")T:&ES(&ES(&$@=&5S="!S
M=')I;F<B*3L*<')I;G1?<B@D<F5T*3ME8VAO("(\8G(^7&XB.PH*)')E="`]
M("1S;V%P8VQI96YT+3YD:79I9&4H,C(L-RD["B,@<')I;G0@)'-O87!C;&EE
M;G0M/E]?9V5T7W=I<F4H*3L*:68@*%!%05(Z.FES17)R;W(H)')E="DI"B`@
M("!P<FEN="@B17)R;W(Z("(@+B`D<F5T+3YG971-97-S86=E*"D@+B`B/&)R
M/EQN(BD["F5L<V4*("`@('!R:6YT*")1=6]T:65N="!I<R`B("X@)')E="`N
M("(\8G(^7&XB*3L*"B1R970@/2`D<V]A<&-L:65N="T^9&EV:61E*#(R+#`I
M.PII9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D*("`@('!R:6YT*")%<G)O<CH@
M(B`N("1R970M/F=E=$UE<W-A9V4H*2`N("(\8G(^7&XB*3L*96QS90H@("`@
M<')I;G0H(E%U;W1I96YT(&ES("(@+B`D<F5T("X@(CQB<CY<;B(I.PH*"B\O
M(%-/05!3=')U8W0@:7,@9&5F:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9I;&4*
M<F5Q=6ER95]O;F-E("=E>&%M<&QE7W1Y<&5S+G!H<"<["@HD<W1R=6-T(#T@
M;F5W(%-/05!3=')U8W0H)W1E<W0@<W1R:6YG)RPQ,C,L,3(S+C$R,RD["@HO
M*B!S96YD(&%N(&]B:F5C="P@9V5T(&%N(&]B:F5C="!B86-K("HO"B\J('1E
M;&P@8VQI96YT('1O('1R86YS;&%T92!T;R!C;&%S<V5S('=E('!R;W9I9&4@
M:68@<&]S<VEB;&4@*B\*)'-O87!C;&EE;G0M/E]A=71O7W1R86YS;&%T:6]N
M(#T@=')U93L*+RH@;W(@>6]U(&-A;B!E>'!L:6-I=&QY('-E="!T:&4@=')A
M;G-L871I;VX@9F]R"B`@(&$@<W!E8VEF:6,@8VQA<W,N("!A=71O7W1R86YS
M;&%T:6]N('=O<FMS(&9O<B!A;&P@8V%S97,L"B`@(&)U="!O<&5N<R!!3ED@
M8VQA<W,@:6X@=&AE('-C<FEP="!T;R!B92!U<V5D(&%S(&$@9&%T82!T>7!E
M+`H@("!A;F0@;6%Y(&YO="!B92!D97-I<F5A8FQE+B`@8F]T:"!C86X@8F4@
M=7-E9"!O;B!C;&EE;G0@;W(*("`@<V5R=F5R("HO"B1S;V%P8VQI96YT+3Y?
M7W-E=%]T>7!E7W1R86YS;&%T:6]N*"=[:'1T<#HO+W-O87!I;G1E<F]P+F]R
M9R]X<V1]4T]!4%-T<G5C="<L)U-/05!3=')U8W0G*3L*)')E="`]("1S;V%P
M8VQI96YT+3YE8VAO4W1R=6-T*"1S=')U8W0M/E]?=&]?<V]A<"@I*3L*(W!R
M:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E="D[
M"@HO*BH*("H@4$A0(&1O97-N)W0@<W5P<&]R="!M=6QT:7!L92!/550@<&%R
M86UE=&5R<R!I;B!F=6YC=&EO;B!C86QL<RP@<V\@=V4*("H@;75S="!D;R!A
M(&QI='1L92!W;W)K('1O(&UA:V4@:70@:&%P<&5N(&AE<F4N("!4:&ES(')E
M<75I<F5S(&MN;W=L961G92!O;B!T:&4*("H@9&5V96QO<&5R<R!P87)T('1O
M(&9I9W5R92!O=70@:&]W('1H97D@=V%N="!T;R!D96%L('=I=&@@:70N"B`J
M+PHD<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')U8W1!<U-I;7!L951Y<&5S
M*"1S=')U8W0M/E]?=&]?<V]A<"@I*3L*:68@*%!%05(Z.FES17)R;W(H)')E
M="DI('L*("`@('!R:6YT*")%<G)O<CH@(B`N("1R970M/F=E=$UE<W-A9V4H
M*2`N("(\8G(^7&XB*3L*?2!E;'-E('L*("`@(&QI<W0H)'-T<FEN9RP@)&EN
M="P@)&9L;V%T*2`](&%R<F%Y7W9A;'5E<R@D<F5T*3L*?0IE8VAO(")V87)3
M=')I;F<Z("1S=')I;F<\8G(^7&YV87));G0Z("1I;G0\8G(^7&YV87)&;&]A
M=#H@)&9L;V%T/&)R/EQN(CL*"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+V-L:65N="YP:'``````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,#$U
M`#$P-3$U-#,Q,#4W`#`R,C0U,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#
M87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z(&-L:65N="YP:'`L=B`Q+C$P(#(P,#4O,#,O,3`@,C,Z,38Z,SD@
M>75N;W-H($5X<"`D"B\O"FEN8VQU9&4H(E-/05`O0VQI96YT+G!H<"(I.PH*
M+RHJ"B`J('1H:7,@8VQI96YT(')U;G,@86=A:6YS="!T:&4@97AA;7!L92!S
M97)V97(@:6X@4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'`*("H@:70@9&]E<R!N
M;W0@=7-E(%=31$P@=&\@<G5N('1H97-E(')E<75E<W1S+"!B=70@=&AA="!C
M86X@8F4@8VAA;F=E9"!E87-I;'D@8GD@<VEM<&QY"B`J(&%D9&EN9R`G/W=S
M9&PG('1O('1H92!E;F0@;V8@=&AE('5R;"X*("HO"B1S;V%P8VQI96YT(#T@
M;F5W(%-/05!?0VQI96YT*")H='1P.B\O;&]C86QH;W-T+U-/05`O97AA;7!L
M92]S97)V97(N<&AP(BD["B\O('1H:7,@;F%M97-P86-E(&ES('1H92!S86UE
M(&%S(&1E8VQA<F5D(&EN('-E<G9E<BYP:'`*)&]P=&EO;G,@/2!A<G)A>2@G
M;F%M97-P86-E)R`]/B`G=7)N.E-/05!?17AA;7!L95]397)V97(G+`H@("`@
M("`@("`@("`@("`@("=T<F%C92<@/3X@,2D["@HD<F5T(#T@)'-O87!C;&EE
M;G0M/F-A;&PH(F5C:&]3=')I;F=3:6UP;&4B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*")I;G!U=%-T<FEN9U-I;7!L92(]
M/B)T:&ES(&ES(&$@=&5S="!S=')I;F<B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1O<'1I;VYS*3L*(W!R:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W
M:7)E*"D["G!R:6YT7W(H)')E="D[96-H;R`B/&)R/EQN(CL*"B1R970@/2`D
M<V]A<&-L:65N="T^8V%L;"@B96-H;U-T<FEN9R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US(#T@87)R87DH(FEN<'5T4W1R:6YG(CT^(G1H
M:7,@:7,@82!T97-T('-T<FEN9R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;G,I.PIP<FEN=%]R*"1R970I.V5C:&\@(CQB<CY<;B(["@HD
M<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH(F1I=FED92(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH(F1I=FED96YD(CT^,C(L
M(F1I=FES;W(B/3XW*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I
M;VYS*3L*(R!P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER92@I.PII9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5T*2D*("`@('!R:6YT*")%<G)O<CH@(B`N("1R
M970M/F=E=$UE<W-A9V4H*2`N("(\8G(^7&XB*3L*96QS90H@("`@<')I;G0H
M(E%U;W1I96YT(&ES("(@+B`D<F5T("X@(CQB<CY<;B(I.PH*)')E="`]("1S
M;V%P8VQI96YT+3YC86QL*")D:79I9&4B+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*")D:79I9&5N9"(]/C(R+")D:79I<V]R
M(CT^,"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<RD["FEF
M("A014%2.CII<T5R<F]R*"1R970I*0H@("`@<')I;G0H(D5R<F]R.B`B("X@
M)')E="T^9V5T365S<V%G92@I("X@(CQB<CY<;B(I.PIE;'-E"B`@("!P<FEN
M="@B475O=&EE;G0@:7,@(B`N("1R970@+B`B/&)R/EQN(BD["@H*+R\@4T]!
M4%-T<G5C="!I<R!D969I;F5D(&EN('1H92!F;VQL;W=I;F<@9FEL90IR97%U
M:7)E7V]N8V4@)V5X86UP;&5?='EP97,N<&AP)SL*"B1S=')U8W0@/2!N97<@
M4T]!4%-T<G5C="@G=&5S="!S=')I;F<G+#$R,RPQ,C,N,3(S*3L*"B\J('-E
M;F0@86X@;V)J96-T+"!G970@86X@;V)J96-T(&)A8VL@*B\*+RH@=&5L;"!C
M;&EE;G0@=&\@=')A;G-L871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P
M;W-S:6)L92`J+PHD<V]A<&-L:65N="T^7V%U=&]?=')A;G-L871I;VX@/2!T
M<G5E.PHO*B!O<B!Y;W4@8V%N(&5X<&QI8VET;'D@<V5T('1H92!T<F%N<VQA
M=&EO;B!F;W(*("`@82!S<&5C:69I8R!C;&%S<RX@(&%U=&]?=')A;G-L871I
M;VX@=V]R:W,@9F]R(&%L;"!C87-E<RP*("`@8G5T(&]P96YS($%.62!C;&%S
M<R!I;B!T:&4@<V-R:7!T('1O(&)E('5S960@87,@82!D871A('1Y<&4L"B`@
M(&%N9"!M87D@;F]T(&)E(&1E<VER96%B;&4N("!B;W1H(&-A;B!B92!U<V5D
M(&]N(&-L:65N="!O<@H@("!S97)V97(@*B\*)'-O87!C;&EE;G0M/E]?<V5T
M7W1Y<&5?=')A;G-L871I;VXH)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS
M9'U33T%04W1R=6-T)RPG4T]!4%-T<G5C="<I.PHD<F5T(#T@)'-O87!C;&EE
M;G0M/F-A;&PH(F5C:&]3=')U8W0B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'`@/2!A<G)A>2@G:6YP=713=')U8W0G(#T^("1S=')U8W0M/E]?=&]?
M<V]A<"@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS*3L*
M(W!R:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E
M="D["@HO*BH*("H@4$A0(&1O97-N)W0@<W5P<&]R="!M=6QT:7!L92!/550@
M<&%R86UE=&5R<R!I;B!F=6YC=&EO;B!C86QL<RP@<V\@=V4*("H@;75S="!D
M;R!A(&QI='1L92!W;W)K('1O(&UA:V4@:70@:&%P<&5N(&AE<F4N("!4:&ES
M(')E<75I<F5S(&MN;W=L961G92!O;B!T:&4*("H@9&5V96QO<&5R<R!P87)T
M('1O(&9I9W5R92!O=70@:&]W('1H97D@=V%N="!T;R!D96%L('=I=&@@:70N
M"B`J+PHD<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3=')U8W1!<U-I
M;7!L951Y<&5S(BP*("`@("`@("`@("`@("`@("`@("`@("`@("1P(#T@87)R
M87DH)VEN<'5T4W1R=6-T)R`]/B`D<W1R=6-T+3Y?7W1O7W-O87`H*2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<RD["FEF("A014%2.CII
M<T5R<F]R*"1R970I*2!["B`@("!P<FEN="@B17)R;W(Z("(@+B`D<F5T+3YG
M971-97-S86=E*"D@+B`B/&)R/EQN(BD["GT@96QS92!["B`@("!L:7-T*"1S
M=')I;F<L("1I;G0L("1F;&]A="D@/2!A<G)A>5]V86QU97,H)')E="D["GT*
M96-H;R`B=F%R4W1R:6YG.B`D<W1R:6YG/&)R/EQN=F%R26YT.B`D:6YT/&)R
M/EQN=F%R1FQO870Z("1F;&]A=#QB<CY<;B(["@H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?1E10+P``````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P
M-3<`,#$W-3,S`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE
M=%]&5%`O97AA;7!L92\`````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C$Q-C8`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O3F5T7T944"]E>&%M<&QE+VEN9&5X+G!H<```````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,S`S`#$P-3$U-#,Q,#4W`#`R,S`P,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!.971?1E10(&=E;F5R86P@
M97AA;7!L92X*("H*("H@1V5N97)A;"!E>&%M<&QE(&9I;&4@9F]R('1H92!U
M<V%G92!O9B!.971?1E10+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@
M*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PH@*B!`<&%C:V%G92`@
M("!&5%`*("H@0&%U=&AO<B`@("`@5&]B:6%S(%-C:&QI='0@/'1O8GE`<&AP
M+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED
M.B!I;F1E>"YP:'`L=B`Q+C0@,C`P-2\P,B\R,R`Q,CHQ,CHR,R!T;V)Y($5X
M<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92].971?1E10"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,"XP+C$*("HO"@IR97%U:7)E7V]N8V4@)TYE="]&5%`N<&AP
M)SL*<F5Q=6ER95]O;F-E("=687)?1'5M<"YP:'`G.PH*+RHJ"B`J(%-E='1I
M;F<@=7`@=&5S="!V87)I86)L97,N(%1H92!F;VQL;W=I;F<@=F%R:6%B;&5S
M(&AA=F4@=&\@8F4@<V5T"B`J('5P+"!T;R!S=6ET92!T:&4@;F5E9',@;V8@
M>6]U<B!E;G9I<F]N;65N="X*("HO"@HD:&]S="`@("`@("`@("`@/2`G)SL*
M)'!O<G0@("`@("`@("`@(#T@,C$["B1U<V5R("`@("`@("`@("`]("<G.PHD
M<&%S<R`@("`@("`@("`@/2`G)SL*"B\O(%1H92!L;V-A;"!B87-E(&1I<F5C
M=&]R>2!F;W(@1E10(&]P97)A=&EO;G,N"B1B87-E1&ER("`@("`@("`]("<N
M+W1E<W0O)SL*+R\@5&AE(&1I<F5C=&]R>2!T;R!U<&QO860@=&\@=&AE($94
M4"!S97)V97(@9F]R('1E<W1I;F<N"B1T97-T57!$:7(@("`@("`]("=T97-T
M7W5P+R<["B\O(%1H92!D:7)E8W1O<GD@=&\@9&]W;FQO860@=&\@9F]R('1E
M<W1I;F<N"B1T97-T1&]W;D1I<B`@("`]("=T97-T7V1O=VXO)SL*+R\@5&AE
M(&9I;&4@9F]R('-I;F=L92!F:6QE('5P+2!A;F0@9&]W;FQO860@=&5S=&EN
M9RX*)'-I;F=L951E<W1&:6QE(#T@)W1E<W0N>FEP)SL*"B\O($EN:71I86QI
M>FEN9R!687)?5F%R7T1U;7`Z.F1I<W!L87D*:68@*&ES<V5T*"1?4T525D52
M*2D@>PH@("`@+R\@4V5T=7`@9F]R(&1I<W!L87EI;F<@6$A434P@;W5T<'5T
M+@H@("`@5F%R7T1U;7`Z.F1I<W!L87E);FET*&%R<F%Y*`H@("`@("`@("=D
M:7-P;&%Y7VUO9&4G/3XG6$A434Q?5&5X="<*("`@("DL(&%R<F%Y*`H@("`@
M("`@("=M;V1E)ST^)VYO<FUA;"<L"B`@("`@("`@)V]F9G-E="<]/C0*("`@
M("DI.PH@("`@+R\@2&5A9&QI;F4@9G5N8W1I;VX@9F]R(%A(5$U,(&]U='!U
M="X*("`@(&9U;F-T:6]N(&AE860@*"`D=&5X="`I('L*("`@("`@("!E8VAO
M("<\8G(@+SX\8CXG+B1T97AT+B<\+V(^/&)R("\^)SL*("`@('T*?2!E;'-E
M('L*("`@("\O(%-E='5P(&9O<B!D:7-P;&%Y:6YG(&-O;G-O;&4@;W5T<'5T
M+@H@("`@5F%R7T1U;7`Z.F1I<W!L87E);FET*&%R<F%Y*"=D:7-P;&%Y7VUO
M9&4G/3XG5&5X="<I*3L*("`@("\O($AE861L:6YE(&9U;F-T:6]N(&9O<B!8
M2%1-3"!O=71P=70N"B`@("!F=6YC=&EO;B!H96%D("@@)'1E>'0@*2!["B`@
M("`@("`@96-H;R`B7&XM+2T@(BXD=&5X="XB("TM+5QN(CL*("`@('T*?0H*
M:&5A9"@B7"1F='`@/2!N97<@3F5T7T944"@I.R(I.PHD9G1P(#T@;F5W($YE
M=%]&5%`H*3L*"FAE860H(EPD9G1P+3YS971(;W-T;F%M92@D:&]S="DB*3L*
M5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^<V5T2&]S=&YA;64H)&AO<W0I*3L*
M"FAE860H(EPD9G1P+3YS9710;W)T*"1P;W)T*2(I.PI687)?1'5M<#HZ9&ES
M<&QA>2@D9G1P+3YS9710;W)T*"1P;W)T*2D["@IH96%D*")<)&9T<"T^8V]N
M;F5C="@D:&]S="P@)'!O<G0I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M
M/F-O;FYE8W0H*2D["@IH96%D*")<)&9T<"T^<V5T57-E<FYA;64H)'5S97(I
M(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/G-E=%5S97)N86UE*"1U<V5R
M*2D["@IH96%D*")<)&9T<"T^<V5T4&%S<W=O<F0H>'AX*2(I.PI687)?1'5M
M<#HZ9&ES<&QA>2@D9G1P+3YS971087-S=V]R9"@D<&%S<RDI.PH*:&5A9"@B
M7"1F='`M/FQO9VEN*"1U<V5R+"!X>'@I(BD["E9A<E]$=6UP.CID:7-P;&%Y
M*"1F='`M/FQO9VEN*"1U<V5R+"`D<&%S<RDI.PH*:&5A9"@B7"1F='`M/G!W
M9"@I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/G!W9"@I*3L*"FAE860H
M(EPD9G1P+3YL<RAN=6QL+"!.151?1E107T1)4E-?1DE,15,I(BD["E9A<E]$
M=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1$E24U]&24Q%
M4RDI.PH*:&5A9"@B7"1F='`M/FUK9&ER*"1B87-E1&ER*2(I.PI687)?1'5M
M<#HZ9&ES<&QA>2@D9G1P+3YM:V1I<B@D8F%S941I<BDI.PH*:&5A9"@B7"1F
M='`M/F-D*"1B87-E1&ER*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YC
M9"@D8F%S941I<BDI.PH*:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?
M4D%73$E35"DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;',H;G5L;"P@
M3D547T944%]205=,25-4*2D["@IH96%D*")<)&9T<"T^<'5T*"1B87-E1&ER
M)'-I;F=L951E<W1&:6QE+"`D<VEN9VQE5&5S=$9I;&4I(BD["E9A<E]$=6UP
M.CID:7-P;&%Y*"1F='`M/G!U="@D8F%S941I<BXD<VEN9VQE5&5S=$9I;&4L
M("1S:6YG;&5497-T1FEL92DI.PH*:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%
M5%]&5%!?1DE,15-?3TY,62DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^
M;',H;G5L;"P@3D547T944%]&24Q%4U]/3DQ9*2D["@IH96%D*")<)&9T<"T^
M<'5T*"1B87-E1&ER)'-I;F=L951E<W1&:6QE+"`D<VEN9VQE5&5S=$9I;&4L
M('1R=64I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/G!U="@D8F%S941I
M<BXD<VEN9VQE5&5S=$9I;&4L("1S:6YG;&5497-T1FEL92P@=')U92DI.PH*
M:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1DE,15-?3TY,62DB*3L*
M5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;',H;G5L;"P@3D547T944%]&24Q%
M4U]/3DQ9*2D["@IH96%D*")<)&9T<"T^;61T;2@D<VEN9VQE5&5S=$9I;&4L
M("=D+FTN62!(.FDZ<R<I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FUD
M=&TH)'-I;F=L951E<W1&:6QE+"`G9"YM+EDG*2D["@IH96%D*")<)&9T<"T^
M<VEZ92@D<VEN9VQE5&5S=$9I;&4I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F
M='`M/G-I>F4H)'-I;F=L951E<W1&:6QE*2D["@IH96%D*")<)&9T<"T^9V5T
M*"1S:6YG;&5497-T1FEL92P@)&)A<V5$:7(D<VEN9VQE5&5S=$9I;&4L('1R
M=64I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/F=E="@D<VEN9VQE5&5S
M=$9I;&4L("1B87-E1&ER+B1S:6YG;&5497-T1FEL92P@=')U92DI.PH*:&5A
M9"@B7"1F='`M/F-H;6]D*"1S:6YG;&5497-T1FEL92P@-S`P*2(I.PI687)?
M1'5M<#HZ9&ES<&QA>2@D9G1P+3YC:&UO9"@D<VEN9VQE5&5S=$9I;&4L(#<P
M,"DI.PH*:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1DE,15-?3TY,
M62DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;',H;G5L;"P@3D547T94
M4%]&24Q%4U]/3DQ9*2D["@IH96%D*")<)&9T<"T^8V0H)RXN+R<I(BD["E9A
M<E]$=6UP.CID:7-P;&%Y*"1F='`M/F-D*"<N+B\G*2D["@IH96%D*")<)&9T
M<"T^8VAM;V1296-U<G-I=F4H)&)A<V5$:7(L(#<W-RDB*3L*5F%R7T1U;7`Z
M.F1I<W!L87DH)&9T<"T^8VAM;V1296-U<G-I=F4H)&)A<V5$:7(L(#<W-RDI
M.PH*:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1$E24U]/3DQ9*2(I
M.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E107T1)
M4E-?3TY,62DI.PH*:&5A9"@B7"1F='`M/G!U=%)E8W5R<VEV92@D8F%S941I
M<B1T97-T57!$:7(L("1B87-E1&ER)'1E<W15<$1I<BDB*3L*5F%R7T1U;7`Z
M.F1I<W!L87DH)&9T<"T^<'5T4F5C=7)S:79E*"1B87-E1&ER+B1T97-T57!$
M:7(L("1B87-E1&ER+B1T97-T57!$:7(I*3L*"FAE860H(EPD9G1P+3YP=712
M96-U<G-I=F4H)&)A<V5$:7(D=&5S=%5P1&ER+"`D8F%S941I<B1T97-T57!$
M:7(I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/G!U=%)E8W5R<VEV92@D
M8F%S941I<BXD=&5S=%5P1&ER+"`D8F%S941I<BXD=&5S=%5P1&ER+"!T<G5E
M*2D["@IH96%D*")<)&9T<"T^8V0H)&)A<V5$:7(Z)'1E<W15<$1I<BDB*3L*
M5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^8V0H)&)A<V5$:7(N)'1E<W15<$1I
M<BDI.PH*:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1$E24U]&24Q%
M4RDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;',H;G5L;"P@3D547T94
M4%]$25)37T9)3$53*2D["@IH96%D*")<)&9T<"T^8V0H+BXO+BXO*2(I.PI6
M87)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YC9"@G+BXO+BXO)RDI.PH*:&5A9"@B
M7"1F='`M/F=E=%)E8W5R<VEV92@D8F%S941I<B1T97-T57!$:7(L("1B87-E
M1&ER)'1E<W1$;W=N1&ER*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YG
M971296-U<G-I=F4H)&)A<V5$:7(N)'1E<W15<$1I<BP@)&)A<V5$:7(N)'1E
M<W1$;W=N1&ER+"!T<G5E*2D["@IH96%D*")<)&9T<"T^<FTH)&)A<V5$:7(L
M('1R=64I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/G)M*"1B87-E1&ER
M+"!T<G5E*2D["@IH96%D*")<)&9T<"T^;',H;G5L;"P@3D547T944%]$25)3
M7T].3%DI(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU;&PL($Y%
M5%]&5%!?1$E24U]/3DQ9*2D["@IH96%D*")<)&9T<"T^9&ES8V]N;F5C="@I
M(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/F1I<V-O;FYE8W0H*2D["C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7T94
M4"]E>&%M<&QE+V]B<V5R=F5R+G!H<```````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S
M,#<R`#$P-3$U-#,Q,#4W`#`R,S4R-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*#0HO*B!V:6TZ('-E="!E>'!A
M;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J
M+PT*#0HO*BH-"B`J($YE=%]&5%`@;V)S97)V97(@97AA;7!L92X-"B`J#0H@
M*B!.970@1E10($]B<V5R=F5R(&5X86UP;&4@=&\@=7-E('=I=&@@2%1-3%]0
M<F]G<F5S<R!P86-K86=E#0H@*B`H4$A0(#0@/CT@4$A0(#0N,RXP*0T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@($YE='=O<FMI;F<-"B`J($!P86-K86=E("`@($944`T*("H@
M0&%U=&AO<B`@("`@5&]B:6%S(%-C:&QI='0@/'1O8GE`<&AP+FYE=#X-"B`J
M($!A=71H;W(@("`@($QA=7)E;G0@3&%V:6QL92`\<&5A<D!L875R96YT+6QA
M=FEL;&4N;W)G/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(&]B<V5R=F5R+G!H<"QV(#$N,B`R,#`U+S`R+S(S(#$R.C$R
M.C(S('1O8GD@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92].971?1E10#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O2%1-3%]0<F]G<F5S<PT*("H@0'-I;F-E
M("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C,N,`T*("HO
M#0H-"G)E<75I<F5?;VYC92`G3F5T+T944"YP:'`G.PT*<F5Q=6ER95]O;F-E
M("=.970O1E10+T]B<V5R=F5R+G!H<"<[#0IR97%U:7)E7V]N8V4@)TA434PO
M4')O9W)E<W,N<&AP)SL-"@T*+RHJ#0H@*B!);FET:6%L:7II;F<@=&5S="!V
M87)I86)L97,@*')E<75I<F5D(2D-"B`J+PT*)&9T<"`](&%R<F%Y*`T*("`@
M("=H;W-T)R`]/B`G)RP-"B`@("`G<&]R="<@/3X@,C$L#0H@("`@)W5S97(G
M(#T^("<G+`T*("`@("=P87-S)R`]/B`G)PT**3L@("`@#0H-"B1D97-T(#T@
M)W1M<"<[("`@("`@("`@("`@("`@("`@("\O('1H:7,@9&ER96-T;W)Y(&UU
M<W0@97AI<W1S(&EN('EO=7(@9G1P('-E<G9E<B`A#0HD;W9E<G=R:71E(#T@
M=')U93L@("`@("`@("`@("`@("`O+R!O=F5R=W)I=&4@86QL(&5X:7-T:6YG
M(&9I;&5S(&]N('1H92!F='`@<V5R=F5R#0HD9FEL97,@/2!A<G)A>2@-"B`@
M("`G2%1-3%]0<F]G<F5S<RTQ+C(N,"YT9WHG+`T*("`@("=P:'`T979E<BYP
M;F<G("`@("`@("`@("`@("`@+R\@:6YI=&EA;&EZ:6YG(&-O;G1E;G1S("AR
M97%U:7)E9"$I(&9I;&4H<RD@;75S="!E>&ES=',-"BD[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&9I;&4H<RD@=&\@=7!L;V%D#0H-"@T*
M+R\-"B\O(#$N($1E9FEN97,@=&AE($944"]0<F]G<F5S<R!/8G-E<G9E<B`-
M"B\O#0IC;&%S<R!/8G-E<G9E<E]0<F]G<F5S<U5P;&]A9"!E>'1E;F1S($YE
M=%]&5%!?3V)S97)V97(-"GL-"B`@("!V87(@)'!R;V=R97-S.PT*#0H@("`@
M9G5N8W1I;VX@3V)S97)V97)?4')O9W)E<W-5<&QO860H)B1P<F]G<F5S<RD-
M"B`@("![#0H@("`@("`@("\J($-A;&P@=&AE(&)A<V4@8VQA<W,@8V]N<W1R
M=6-T;W(N("HO#0H@("`@("`@('!A<F5N=#HZ3F5T7T944%]/8G-E<G9E<B@I
M.PT*#0H@("`@("`@("\J*@T*("`@("`@("`@("!#;VYF:6=U<F4@=&AE(&]B
M<V5R=F5R.@T*("`@("`@("`@("`-"B`@("`@("`@("`@0F4@<W5R92!T;R!H
M879E(&%N(&EN9&5T97)M:6YA=&4@<')O9W)E<W,@;65T97(@=VAE;@T*("`@
M("`@("`@("!`;&EN:R!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U
M;F-T:6]N+F9T<"UN8BUP=70N<&AP#0H@("`@("`@("`@('-T;W)E<R!A(&9I
M;&4@;VX@=&AE($944"!S97)V97(@*&YO;BUB;&]C:VEN9RD-"B`@("`@("`@
M("HO#0H@("`@("`@("1T:&ES+3YP<F]G<F5S<R`])B`D<')O9W)E<W,[#0H@
M("`@("`@("1T:&ES+3YP<F]G<F5S<RT^<V5T26YD971E<FUI;F%T92AT<G5E
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!N;W1I9GDH)&5V96YT*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/G!R;V=R97-S+3YD:7-P;&%Y*"D[#0H@("`@
M("`@("1T:&ES+3YP<F]G<F5S<RT^<VQE97`H*3L-"B`@("`@("`@("`@("`@
M("`@#0H@("`@("`@(&EF("@D=&AI<RT^<')O9W)E<W,M/F=E=%!E<F-E;G1#
M;VUP;&5T92@I(#T](#$I('L-"B`@("`@("`@("`@("1T:&ES+3YP<F]G<F5S
M<RT^<V5T5F%L=64H,"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D=&AI<RT^<')O9W)E<W,M/FEN8U9A;'5E*"D[#0H@("`@("`@('T-"B`@
M("!]#0I]#0H-"B\O#0HO+R`R+B!D969I;F5S('1H92!P<F]G<F5S<R!M971E
M<B`-"B\O#0HD;65T97(@/2!N97<@2%1-3%]0<F]G<F5S<R@I.PT*)'5I(#T@
M)B`D;65T97(M/F=E=%5)*"D[#0HD=6DM/G-E=%!R;V=R97-S071T<FEB=71E
M<RAA<G)A>2@-"B`@("`G8F%C:V=R;W5N9"UC;VQO<B<@/3X@)R-E,&4P93`G
M#0HI*3L@("`@("`@(`T*)'5I+3YS9713=')I;F=!='1R:6)U=&5S*&%R<F%Y
M*`T*("`@("=C;VQO<B<@(#T^("<C.3DV)RP-"B`@("`G8F%C:V=R;W5N9"UC
M;VQO<B<@/3X@)R-#0T-#.3DG#0HI*3L@("`@("`@(`T*)'5I+3YS971#96QL
M071T<FEB=71E<RAA<G)A>2@-"B`@("`G86-T:79E+6-O;&]R)R`]/B`G(SDY
M-B<-"BDI.PT*#0HD;65T97(M/G-E=$%N:6U3<&5E9"@R,#`I.PT*)&UE=&5R
M+3YS971);F-R96UE;G0H,3`I.PT*)&UE=&5R+3YS9713=')I;F=086EN=&5D
M*'1R=64I.R`@("`@+R\@9V5T('-P86-E(&9O<B!T:&4@<W1R:6YG#0HD;65T
M97(M/G-E=%-T<FEN9R@B(BD[("`@("`@("`@("`@("`O+R!B=70@9&]N)W0@
M<&%I;G0@:70-"B1M971E<BT^<V5T26YD971E<FUI;F%T92AT<G5E*3L@("`@
M("\O('!R;V=R97-S(&UE=&5R('-T87)T(&EN(&EN9&5T97)M:6YA=&4@;6]D
M90T*/SX-"CPA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A4
M34P@,2XP(%1R86YS:71I;VYA;"\O14XB#0H@("`@(FAT='`Z+R]W=W<N=S,N
M;W)G+U12+WAH=&UL,2]$5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD=&0B/@T*
M/&AT;6P@>&UL;G,](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&AT;6PB/@T*
M/&AE860^#0H\=&ET;&4^1E10+U!R;V=R97-S($]B<V5R=F5R(&5X86UP;&4\
M+W1I=&QE/@T*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX-"CPA+2T-"F)O9'D@
M>PT*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-#0T-#.3D[#0H@("`@8V]L;W(Z
M(",Y.38[#0H@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($%R:6%L.PT*?0T*
M#0H\/W!H<"!E8VAO("1M971E<BT^9V5T4W1Y;&4H*3L@/SX-"B\O("TM/@T*
M/"]S='EL93X-"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX-"CPA
M+2T-"CP_<&AP(&5C:&\@)&UE=&5R+3YG97138W)I<'0H*3L@/SX-"B\O+2T^
M#0H\+W-C<FEP=#X-"CPO:&5A9#X-"CQB;V1Y/@T*#0H\/W!H<"`-"F5C:&\@
M)&UE=&5R+3YT;TAT;6PH*3L-"D!S971?=&EM95]L:6UI="@P*3L@("\O('5N
M;&EM:71E9"!T:6UE(&]P97)A=&EO;B`H<F5M;W9E9"`S,',@9&5F875L="!R
M97-T<FEC=&EO;BD-"@T*)&8@/2!N97<@3F5T7T944"@I.PT*#0HO+PT*+R\@
M,RX@8V]N;F5C="!T;R!T:&4@1E10('-E<G9E<B`-"B\O#0HD<F5T(#T@)&8M
M/F-O;FYE8W0H)&9T<%LG:&]S="==+"`D9G1P6R=P;W)T)UTI.PT*:68@*%!%
M05(Z.FES17)R;W(H)')E="DI('L-"B`@("!D:64H)')E="T^9V5T365S<V%G
M92@I*3L-"GT-"G!R:6YT9B@G8V]N;F5C=&5D(&%T(#QB/B5S/"]B/CQB<B`O
M/B<L("1F='!;)VAO<W0G72D[#0H-"B\O#0HO+R`T+B!L;V=I;B!T;R!T:&4@
M1E10('-E<G9E<B!A<R!A('=E;&PM:VYO=VX@=7-E<@T*+R\-"B1R970@/2`D
M9BT^;&]G:6XH)&9T<%LG=7-E<B==+"`D9G1P6R=P87-S)UTI.PT*:68@*%!%
M05(Z.FES17)R;W(H)')E="DI('L-"B`@("`D9BT^9&ES8V]N;F5C="@I.PT*
M("`@(&1I92@D<F5T+3YG971-97-S86=E*"DI.PT*?0T*<')I;G1F*"=L;V=I
M;B!A<R`\8CXE<SPO8CX\8G(@+SXG+"`D9G1P6R=U<V5R)UTI.PT*#0HO+PT*
M+R\@-2X@8VAA;F=E<R!D:7)E8W1O<GD@=&\@9FEN86P@9&5S=&EN871I;VX@
M9F]R('5P;&]A9"!O<&5R871I;VX-"B\O#0HD<F5T(#T@)&8M/F-D*"1D97-T
M*3L-"FEF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@)&8M/F1I<V-O
M;FYE8W0H*3L-"B`@("!D:64H)')E="T^9V5T365S<V%G92@I*3L-"GT-"@T*
M+R\-"B\O(#8N(&%T=&%C:',@86X@:6YS=&%N8V4@;V8@=&AE($944"]0<F]G
M<F5S<R!S=6)C;&%S<R!O8G-E<G9E<@T*+R\-"B1O8G-E<G9E<B`](&YE=R!/
M8G-E<G9E<E]0<F]G<F5S<U5P;&]A9"@D;65T97(I.PT*)&]K(#T@)&8M/F%T
M=&%C:"@D;V)S97)V97(I.PT*:68@*"$D;VLI('L-"B`@("!D:64H)V-A;FYO
M="!A='1A8V@@82!&5%`@3V)S97)V97(G*3L-"GT-"@T*+R\-"B\O(#<N(&UO
M=F5S(&9I;&5S(&]N('1H92!&5%`@<V5R=F5R#0HO+PT*9F]R96%C:"@D9FEL
M97,@87,@)&9I;&4I('L-"B`@("`D<F5T(#T@)&8M/G!U="@D9FEL92P@8F%S
M96YA;64H)&9I;&4I+"`D;W9E<G=R:71E*3L-"B`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5T*2D@>PT*("`@(`EI9B`H*"1R970M/F=E=$-O9&4H*2`]/2!.
M151?1E107T524E]/5D525U))5$5214U/5$5&24Q%7T9/4D))1$1%3BD@86YD
M("@A)&]V97)W<FET92DI('L-"B`@("`)("`@('!R:6YT9B@G)7,@/&)R("\^
M)RP@)')E="T^9V5T365S<V%G92@I*3L-"B`@("`)("`@(&-O;G1I;G5E.R`@
M+R\@:70@:7,@:G5S="!A('=A<FYI;F<@=VAE;B!<)&]V97)W<FET92!V87)I
M86)L92!I<R!S970@=&\@9F%L<V4-"B`@("`)?0T*("`@("`@("!D:64H)')E
M="T^9V5T365S<V%G92@I*3L-"B`@("!]#0H@("`@<')I;G1F*"<\8CXE<SPO
M8CX@=')A;G-F97(@8V]M<&QE=&5D(#QB<B`O/B<L(&)A<V5N86UE*"1F:6QE
M*2D[#0I]#0HD9BT^9&5T86-H*"1O8G-E<G9E<BD[#0H-"B\O#0HO+R`X+B!C
M:&5C:W,@:68@9FEL97,@87)E(')E86QL>2!O;B!T:&4@1E10('-E<G9E<@T*
M+R\-"B1R970@/2`D9BT^;',H;G5L;"P@3D547T944%]205=,25-4*3L-"FEF
M("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@)&8M/F1I<V-O;FYE8W0H
M*3L-"B`@("!D:64H)')E="T^9V5T365S<V%G92@I*3L-"GT-"G!R:6YT("<\
M<')E/B<[#0IV87)?9'5M<"@D<F5T*3L-"G!R:6YT("<\+W!R93XG.PT*#0HO
M+PT*+R\@.2X@<V%Y<R!G;V]D8GEE('1O('1H92!&5%`@<V5R=F5R("$-"B\O
M#0HD9BT^9&ES8V]N;F5C="@I.PT*96-H;R`G1&]N92$G.PT*/SX-"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?1E10+V5X
M86UP;&4O97AT96YS:6]N<RYI;FD`````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R,3,`
M,3`U,34T,S$P-3<`,#(T,#8Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#L@5&AI<R!F:6QE(&-A;B!D971E<FUI;F4@9FEL
M92UE>'1E;G-I;VX@86YD('=E=&AE<B!T;R!T<F%N<V9E<B!T:&5M(&EN(`H[
M(&)I;F%R>2T@;W(@87-C:6DM;6]D92X@5&AE('1W;R!D:69F97)E;G0@=F%L
M=65S(&9O<B!F:6QE+6UO9&5S(&%R93H*.PH[($944%]!4T-)22`H=VAI8V@@
M97%U86QS(#`I"CL@1E107T))3D%262`H=VAI8V@@97%U86QS(#$I"CL*.R!4
M:&ES(&9I;&4@=VEL;"!B92!D:7)E8W1L>2!P87)S960@8GD@<&%R<V5?:6YI
M7V9I;&4H*2P@<V\@8F5W87)E(&]F(&UA:VEN9R!M:7-T86ME<PH[(&EN<VED
M92!T:&ES(&9I;&4L(&]R('EO=7(@87!P;&EC871I;VX@;6%Y(&-R87-H+"!E
M=F5R>71I;64@>6]U('!A<G-E('EO=7(@9FEL92X*.PH[(%EO=2!C86X@:&%V
M92!M;W)E('1H86X@,2!F:6QE(&-O;G1A:6YI;F<@97AT96YS:6]N+7-E='1I
M;F=S+"!F;W(@9&EF9F5R96YT(&MI;F1S(&]F"CL@87!P;&EC871I;VXL('-E
M<G9E<B!O<B!C87-E+B!"=70@8F5W87)E+"!I9B!Y;W4G=F4@<&%R<V5D(&$@
M9FEL92!I;G1O('EO=7(@3F5T7T944"UO8FIE8W0L"CL@86YD(&%F=&5R('1H
M870@>6]U('!A<G-E(&%N;W1H97(@9FEL92P@=&AE(&]L9"!S971T:6YG<R!W
M:6QL(&)E(&]V97)W<FET96XA"CL*.R!!4T-)22U%>'1E;G-I;VYS.@H*6T%3
M0TE)70H*87-C(#T@,`IA<V-X(#T@,`IA<W`@/2`P"F%S<'@@/2`P"F)A<R`]
M(#`*8F%S:"`](#`*8F%T(#T@,`IC(#T@,`IC9F,@/2`P"F-F;2`](#`*8V=I
M(#T@,`IC;&%S<R`](#`*8V]N9B`](#`*8W-S(#T@,`IH(#T@,`IH:&,@/2`P
M"FAH:R`](#`*:'!P(#T@,`IH=&$@/2`P"FAT;2`](#`*:'1M;"`](#`*:6YC
M(#T@,`IN9F\@/2`P"FEN:2`](#`*:6YF(#T@,`IJ878@/2`P"FIA=F$@/2`P
M"FIS(#T@,`IJ<W`@/2`P"FQO9R`](#`*;F9O(#T@,`IP87,@/2`P"G!H<"`]
M(#`*<&AP,R`](#`*<&AP-"`](#`*<&AT;6P@/2`P"G!L(#T@,`IS=F<@/2`P
M"G-H(#T@,`IS:'1M;"`](#`*=&-L(#T@,`IT97AT(#T@,`IT>'0@/2`P"G9B
M(#T@,`IV8G,@/2`P"G=M;"`](#`*>&AT;2`](#`*>&AT;6P@/2`P"GAM;"`]
M(#`*>'-D(#T@,`IX<VP@/2`P"GAS;"`](#`*>'-L="`](#`*>'5L(#T@,`H*
M.R!"24Y!4EDM17AT96YS:6]N<PH*6T))3D%265T*"FIP9R`](#$*9VEF(#T@
M,0IB;7`@/2`Q````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D871A+P``````````````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,38R-34`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O4$5!4B\`````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#4W`#`Q-S`P-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T
M82]014%2+W1E;7!L871E+G-P96,`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0P,S4`,3`U,34T,S$P-3<`,#(Q-#<R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````%-U;6UA<GDZ(%!%05(Z($!S
M=6UM87)Y0`T*3F%M93H@0')P;5]P86-K86=E0`T*5F5R<VEO;CH@0'9E<G-I
M;VY`#0I296QE87-E.B`Q#0I,:6-E;G-E.B!`<F5L96%S95]L:6-E;G-E0`T*
M1W)O=7`Z($1E=F5L;W!M96YT+TQI8G)A<FEE<PT*4V]U<F-E.B!H='1P.B\O
M0&UA<W1E<E]S97)V97)`+V=E="]`<&%C:V%G94`M)7MV97)S:6]N?2YT9WH-
M"D)U:6QD4F]O=#H@)7M?=&UP<&%T:'TO)7MN86UE?2UR;V]T#0I54DPZ(&AT
M='`Z+R]`;6%S=&5R7W-E<G9E<D`O<&%C:V%G92]`<&%C:V%G94`-"E!R969I
M>#H@)7M?<')E9FEX?0T*0G5I;&1!<F-H:71E8W1U<F5S.B!`87)C:$`-"D!E
M>'1R85]H96%D97)S0`T*#0HE9&5S8W)I<'1I;VX-"D!D97-C<FEP=&EO;D`-
M"@T*)7!R97`-"G)M("UR9B`E>V)U:6QD<F]O='TO*@T*)7-E='5P("UC("U4
M#0HC(%A86"!3;W5R8V4@9FEL97,@;&]C871I;VX@:7,@;6ES<VEN9R!H97)E
M(&EN('!E87(@8VUD#0IP96%R("UV("UC("5[8G5I;&1R;V]T?2]P96%R<F,@
M7`T*("`@("`@("`M9"!P:'!?9&ER/25[7VQI8F1I<GTO<&AP+W!E87(@7`T*
M("`@("`@("`M9"!D;V-?9&ER/2]D;V-S(%P-"B`@("`@("`@+60@8FEN7V1I
M<CTE>U]B:6YD:7)](%P-"B`@("`@("`@+60@9&%T85]D:7(])7M?;&EB9&ER
M?2]P:'`O<&5A<B]D871A(%P-"B`@("`@("`@+60@=&5S=%]D:7(])7M?;&EB
M9&ER?2]P:'`O<&5A<B]T97-T<R!<#0H@("`@("`@("UD(&5X=%]D:7(])7M?
M;&EB9&ER?2!<0&5X=')A7V-O;F9I9T`-"B`@("`@("`@+7,-"@T*)6)U:6QD
M#0IE8VAO($)U:6QD4F]O=#TE>V)U:6QD<F]O='T-"@T*)7!O<W1U;@T*(R!I
M9B!R969C;W5N="`](#`@=&AE;B!P86-K86=E(&AA<R!B965N(')E;6]V960@
M*&YO="!U<&=R861E9"D-"FEF(%L@(B0Q(B`M97$@(C`B(%T[('1H96X-"B`@
M("!P96%R('5N:6YS=&%L;"`M+6YO9&5P<R`M<B!`<&]S<VEB;&5?8VAA;FYE
M;$!`<&%C:V%G94`-"B`@("!R;2!`<G!M7WAM;%]D:7)`+T!P86-K86=E0"YX
M;6P-"F9I#0H-"@T*)7!O<W0-"B,@:68@<F5F8V]U;G0@/2`R('1H96X@<&%C
M:V%G92!H87,@8F5E;B!U<&=R861E9`T*:68@6R`B)#$B("UG92`B,B(@73L@
M=&AE;@T*("`@('!E87(@=7!G<F%D92`M+6YO9&5P<R`M<B!`<G!M7WAM;%]D
M:7)`+T!P86-K86=E0"YX;6P-"F5L<V4-"B`@("!P96%R(&EN<W1A;&P@+2UN
M;V1E<',@+7(@0')P;5]X;6Q?9&ER0"]`<&%C:V%G94`N>&UL#0IF:0T*#0HE
M:6YS=&%L;`T*<&5A<B`M8R`E>V)U:6QD<F]O='TO<&5A<G)C(&EN<W1A;&P@
M+2UN;V1E<',@+5(@)7MB=6EL9')O;W1](%P-"B`@("`@("`@)%)035]33U52
M0T5?1$E2+T!P86-K86=E0"TE>W9E<G-I;VY]+G1G>@T*<FT@)7MB=6EL9')O
M;W1]+W!E87)R8PT*<FT@)7MB=6EL9')O;W1]+R5[7VQI8F1I<GTO<&AP+W!E
M87(O+F9I;&5M87`-"G)M("5[8G5I;&1R;V]T?2\E>U]L:6)D:7)]+W!H<"]P
M96%R+RYL;V-K#0IR;2`M<F8@)7MB=6EL9')O;W1]+R5[7VQI8F1I<GTO<&AP
M+W!E87(O+G)E9VES=')Y#0II9B!;(")`9&]C7V9I;&5S0"(@(3T@(B(@73L@
M=&AE;@T*("`@("!M=B`E>V)U:6QD<F]O='TO9&]C<R]`<&%C:V%G94`O*B`N
M#0H@("`@(')M("UR9B`E>V)U:6QD<F]O='TO9&]C<PT*9FD-"FUK9&ER("UP
M("5[8G5I;&1R;V]T?4!R<&U?>&UL7V1I<D`-"G1A<B`M>'IF("124$U?4T]5
M4D-%7T1)4B]`<&%C:V%G94`M)7MV97)S:6]N?2YT9WH@<&%C:V%G94!P86-K
M86=E,GAM;$`N>&UL#0IC<"`M<"!P86-K86=E0'!A8VMA9V4R>&UL0"YX;6P@
M)7MB=6EL9')O;W1]0')P;5]X;6Q?9&ER0"]`<&%C:V%G94`N>&UL#0H-"B-R
M;2`M<F8@)7MB=6EL9')O;W1]+RH-"B-P96%R("UQ(&EN<W1A;&P@+5(@)7MB
M=6EL9')O;W1]("UN('!A8VMA9V5`<&%C:V%G93)X;6Q`+GAM;`T*(VUK9&ER
M("UP("5[8G5I;&1R;V]T?4!R<&U?>&UL7V1I<D`-"B-C<"`M<"!P86-K86=E
M0'!A8VMA9V4R>&UL0"YX;6P@)7MB=6EL9')O;W1]0')P;5]X;6Q?9&ER0"]`
M<&%C:V%G94`N>&UL#0H-"B5F:6QE<PT*("`@("5D969A='1R*"TL<F]O="QR
M;V]T*0T*("`@("5D;V,@0&1O8U]F:6QE<T`-"B`@("`O#0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&%T82]014%2+W!A8VMA9V4N9'1D````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#8V-#8`,3`U,34T,S$P-3<`,#(Q,3`U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PA+2T-
M"B`@("`@)$ED.B!P86-K86=E+F1T9"QV(#$N,S@@,C`P-2\Q,2\Q,B`P,CHR
M,SHP-R!C96QL;V<@17AP("0-"@T*("`@("!4:&ES(&ES('1H92!014%2('!A
M8VMA9V4@9&5S8W)I<'1I;VXL('9E<G-I;VX@,2XP+@T*("`@("!)="!S:&]U
M;&0@8F4@=7-E9"!W:71H('1H92!I;F9O<FUA;"!P=6)L:6,@:61E;G1I9FEE
M<CH-"@T*("`@("`@("`@(BTO+U!(4"!'<F]U<"\O1%1$(%!%05(@4&%C:V%G
M92`Q+C`O+T5.+R]834PB#0H-"B`@("`@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`-"@T*("`@("!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`P(&]F('1H92!0
M2%`@;&EC96YS92P-"B`@("`@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<PT*("`@("!A=F%I
M;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870-"B`@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@#0H@("`@($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS
M92!A;F0@87)E('5N86)L92!T;PT*("`@("!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;PT*("`@
M("!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X-"@T*("`@("!!=71H;W)S.@T*("`@("`@("`@4W1I9R!3
M+B!"86MK96X@/'-S8D!F87-T+FYO/@T*("`@("`@("`@1W)E9V]R>2!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*#0H@("TM/@T*/"%%3E1)5%D@)2!.54U"
M15(@(D-$051!(CX-"CPA14Q%345.5"!P86-K86=E("AN86UE+'-U;6UA<GDL
M9&5S8W)I<'1I;VXL;&EC96YS93\L;6%I;G1A:6YE<G,L<F5L96%S92QC:&%N
M9V5L;V<_*3X-"CPA05143$E35"!P86-K86=E('1Y<&4@("`@*'-O=7)C97QB
M:6YA<GE\96UP='DI(")E;7!T>2(-"B`@("`@("`@("`@("`@("`@('9E<G-I
M;VX@0T1!5$$@("`@("`@("`@("`@("`@("-215%525)%1`T*("`@("`@("`@
M("`@("`@("`@<&%C:V%G97)V97)S:6]N($-$051!("`@("`@("`@(TE-4$Q)
M140^#0H-"CPA14Q%345.5"!N86UE("@C4$-$051!*3X-"@T*/"%%3$5-14Y4
M('-U;6UA<GD@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@;&EC96YS92`H(U!#
M1$%402D^#0H-"CPA14Q%345.5"!D97-C<FEP=&EO;B`H(U!#1$%402D^#0H-
M"CPA14Q%345.5"!M86EN=&%I;F5R<R`H;6%I;G1A:6YE<BDK/@T*#0H\(45,
M14U%3E0@;6%I;G1A:6YE<B`H=7-E<GQR;VQE?&YA;65\96UA:6PI*SX-"@T*
M/"%%3$5-14Y4('5S97(@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@<F]L92`H
M(U!#1$%402D^#0H-"CPA14Q%345.5"!E;6%I;"`H(U!#1$%402D^#0H-"CPA
M14Q%345.5"!C:&%N9V5L;V<@*')E;&5A<V4I*SX-"@T*/"%%3$5-14Y4(')E
M;&5A<V4@*'9E<G-I;VXL9&%T92QL:6-E;G-E+'-T871E+&YO=&5S+'=A<FYI
M;F=S/RQP<F]V:61E<RHL9&5P<S\L8V]N9FEG=7)E;W!T:6]N<S\L9FEL96QI
M<W0_*3X-"@T*/"%%3$5-14Y4('9E<G-I;VX@*"-00T1!5$$I/@T*#0H\(45,
M14U%3E0@9&%T92`H(U!#1$%402D^#0H-"CPA14Q%345.5"!S=&%T92`H(U!#
M1$%402D^#0H-"CPA14Q%345.5"!N;W1E<R`H(U!#1$%402D^#0H-"CPA14Q%
M345.5"!W87)N:6YG<R`H(U!#1$%402D^#0H-"CPA14Q%345.5"!D97!S("AD
M97`J*3X-"@T*/"%%3$5-14Y4(&1E<"`H(U!#1$%402D^#0H\(4%45$Q)4U0@
M9&5P('1Y<&4@("`@*'!K9WQE>'1\<&AP*2`C4D5154E2140-"@D@("`@("`@
M("`@("`@("`@("`@("`@(')E;"`@("`@*&AA<WQE<7QL='QL97QG='QG92D@
M("`@("`@("`@("`@("`@("`@("`@("`@("-)35!,245$#0H)("`@("`@("`@
M("`@("`@("`@("`@("!V97)S:6]N($-$051!("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("-)35!,245$#0H)("`@("`@("`@("`@("`@
M("`@("`@("!O<'1I;VYA;"`H>65S?&YO*2`@("`@)VYO)SX-"@T*/"%%3$5-
M14Y4(&-O;F9I9W5R96]P=&EO;G,@*&-O;F9I9W5R96]P=&EO;BDK/@T*#0H\
M(45,14U%3E0@8V]N9FEG=7)E;W!T:6]N($5-4%19/@T*/"%!5%1,25-4(&-O
M;F9I9W5R96]P=&EO;B!N86UE($-$051!("-215%525)%1`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0@0T1!
M5$$@(TE-4$Q)140-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!P<F]M<'0@0T1!5$$@(U)%455)4D5$/@T*#0H\(45,14U%
M3E0@<')O=FED97,@14U05%D^#0H\(4%45$Q)4U0@<')O=FED97,@='EP92`H
M97AT?'!R;V=\8VQA<W-\9G5N8W1I;VY\9F5A='5R97QA<&DI("-215%525)%
M1`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE($-$051!
M("-215%525)%1`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M>'1E;F1S($-$051!("-)35!,245$/@T*/"%%3$5-14Y4(&9I;&5L:7-T("AD
M:7)\9FEL92DK/@T*#0H\(45,14U%3E0@9&ER("AD:7)\9FEL92DK/@T*/"%!
M5%1,25-4(&1I<B!N86UE("`@("`@("`@("!#1$%402`C4D5154E2140-"B`@
M("`@("`@("`@("`@<F]L92`@("`@("`@("`@*'!H<'QE>'1\<W)C?'1E<W1\
M9&]C?&1A=&%\<V-R:7!T*2`G<&AP)PT*("`@("`@("`@("`@("!B87-E:6YS
M=&%L;&1I<B!#1$%402`C24U03$E%1#X-"@T*/"%%3$5-14Y4(&9I;&4@*')E
M<&QA8V4J*3X-"CPA05143$E35"!F:6QE(')O;&4@("`@("`@("`@("AP:'!\
M97AT?'-R8WQT97-T?&1O8WQD871A?'-C<FEP="D@)W!H<"<-"B`@("`@("`@
M("`@("`@(&1E8G5G("`@("`@("`@("AN87QO;GQO9F8I("`@("`@("`G;F$G
M#0H@("`@("`@("`@("`@("!F;W)M870@("`@("`@("!#1$%402`@("`@("`@
M("`@("`@(TE-4$Q)140-"B`@("`@("`@("`@("`@(&)A<V5I;G-T86QL9&ER
M($-$051!("`@("`@("`@("`@("`C24U03$E%1`T*("`@("`@("`@("`@("`@
M<&QA=&9O<FT@("`@("`@0T1!5$$@("`@("`@("`@("`@("-)35!,245$#0H@
M("`@("`@("`@("`@("!M9#5S=6T@("`@("`@("!#1$%402`@("`@("`@("`@
M("`@(TE-4$Q)140-"B`@("`@("`@("`@("`@(&YA;64@("`@("`@("`@($-$
M051!("`@("`@("`@("`@("`C4D5154E2140-"B`@("`@("`@("`@("`@(&EN
M<W1A;&PM87,@("`@($-$051!("`@("`@("`@("`@("`C24U03$E%1#X-"@T*
M/"%%3$5-14Y4(')E<&QA8V4@14U05%D^#0H\(4%45$Q)4U0@<F5P;&%C92!T
M>7!E("AP:'`M8V]N<W1\<&5A<BUC;VYF:6=\<&%C:V%G92UI;F9O*2`C4D51
M54E2140-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9R;VT@0T1!
M5$$@(U)%455)4D5$#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M;R!#1$%402`C4D5154E2140^#0H-"@T*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1A=&$O36%I;%]-:6UE+P``````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`R,#$P-@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]-86EL7TUI;64O>&UA
M:6PN>'-L````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0Q,C<`,3`U
M,34T,S$P-3<`,#(Q-S4Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](DE3
M3RTX.#4Y+3$B/SX-"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B('AM
M;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M
M(B!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T
M(CX-"CQX<VPZ;W5T<'5T(&UE=&AO9#TB=&5X="(@;VUI="UX;6PM9&5C;&%R
M871I;VX](GEE<R(@:6YD96YT/2)N;R(O/@T*/'AS;#IP<F5S97)V92US<&%C
M92!E;&5M96YT<STB:&5A9&5R=F%L=64@<&%R86UV86QU92!B;V1Y(B\^#0H-
M"@D\>'-L.G1E;7!L871E(&YA;64](FUI;65P87)T(CX-"@T*"0D\>'-L.G9A
M<FEA8FQE(&YA;64](F)O=6YD87)Y(CX-"@D)"0D\>'-L.F9O<BUE86-H('-E
M;&5C=#TB+B]H96%D97(B/@T*"0D)"0D\>'-L.FEF('1E<W0](G-T<FEN9R@N
M+VAE861E<FYA;64I(#T@)T-O;G1E;G0M5'EP92<B/@T*"0D)"0D)/'AS;#IF
M;W(M96%C:"!S96QE8W0](BXO<&%R86UE=&5R(CX-"@D)"0D)"0D\>'-L.FEF
M('1E<W0](G-T<FEN9R@N+W!A<F%M;F%M92D@/2`G8F]U;F1A<GDG(CX-"@D)
M"0D)"0D)/'AS;#IV86QU92UO9B!S96QE8W0](G!A<F%M=F%L=64B+SX-"@D)
M"0D)"0D\+WAS;#II9CX-"@D)"0D)"3PO>'-L.F9O<BUE86-H/@T*"0D)"0D\
M+WAS;#II9CX-"@D)"0D\+WAS;#IF;W(M96%C:#X-"@D)/"]X<VPZ=F%R:6%B
M;&4^#0H-"@D)/'AS;#IF;W(M96%C:"!S96QE8W0](FAE861E<B(^#0H-"@D)
M"3QX<VPZ=F%L=64M;V8@<V5L96-T/2)H96%D97)N86UE(B\^#0H)"0D\>'-L
M.G1E>'0^.B`\+WAS;#IT97AT/@T*"0D)/'AS;#IV86QU92UO9B!S96QE8W0]
M(FAE861E<G9A;'5E(B\^#0H-"@D)"3QX<VPZ:68@=&5S=#TB8V]U;G0H+B]P
M87)A;65T97(I(#T@,"(^#0H)"0D)/'AS;#IT97AT/B8C,3,[)B,Q,#L\+WAS
M;#IT97AT/@T*"0D)/"]X<VPZ:68^#0H-"@D)"3QX<VPZ9F]R+65A8V@@<V5L
M96-T/2)P87)A;65T97(B/@T*"0D)"3QX<VPZ=&5X=#X[)B,Q,SLF(S$P.R8C
M,#D[/"]X<VPZ=&5X=#X-"@D)"0D\>'-L.G9A;'5E+6]F('-E;&5C=#TB<&%R
M86UN86UE(B\^#0H)"0D)/'AS;#IT97AT/CTB/"]X<VPZ=&5X=#X-"@D)"0D\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<&%R86UV86QU92(O/@T*"0D)"3QX<VPZ
M=&5X=#XB/"]X<VPZ=&5X=#X-"@D)"3PO>'-L.F9O<BUE86-H/@T*#0H)"0D\
M>'-L.FEF('1E<W0](F-O=6YT*"XO<&%R86UE=&5R*2`^(#`B/@T*"0D)"3QX
M<VPZ=&5X=#XF(S$S.R8C,3`[/"]X<VPZ=&5X=#X-"@D)"3PO>'-L.FEF/@T*
M#0H)"3PO>'-L.F9O<BUE86-H/@T*#0H)"3QX<VPZ=&5X=#XF(S$S.R8C,3`[
M/"]X<VPZ=&5X=#X-"@T*"0D\(2TM(%=H:6-H('1O(&1O+"!P<FEN="!A(&)O
M9'D@;W(@<')O8V5S<R!S=6)P87)T<S\@+2T^#0H)"3QX<VPZ8VAO;W-E/@T*
M"0D)/'AS;#IW:&5N('1E<W0](F-O=6YT*"XO;6EM97!A<G0I(#T@,"(^#0H)
M"0D)/'AS;#IV86QU92UO9B!S96QE8W0](F)O9'DB+SX-"@D)"0D\>'-L.G1E
M>'0^)B,Q,SLF(S$P.SPO>'-L.G1E>'0^#0H)"0D\+WAS;#IW:&5N/@T*#0H)
M"0D\>'-L.F]T:&5R=VES93X-"@D)"0D\>'-L.F9O<BUE86-H('-E;&5C=#TB
M;6EM97!A<G0B/@T*"0D)"0D\>'-L.G1E>'0^+2T\+WAS;#IT97AT/CQX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D8F]U;F1A<GDB+SX\>'-L.G1E>'0^)B,Q,SLF
M(S$P.SPO>'-L.G1E>'0^#0H)"0D)"3QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)M:6UE<&%R="(O/@T*"0D)"3PO>'-L.F9O<BUE86-H/@T*#0H)"0D)/'AS
M;#IT97AT/BTM/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&)O
M=6YD87)Y(B\^/'AS;#IT97AT/BTM)B,Q,SLF(S$P.SPO>'-L.G1E>'0^#0H-
M"@D)"3PO>'-L.F]T:&5R=VES93X-"@D)/"]X<VPZ8VAO;W-E/@T*"3PO>'-L
M.G1E;7!L871E/@T*#0H\(2TM(%1H:7,@:7,@=VAE<F4@=&AE('-T>6QE<VAE
M970@<F5A;&QY('-T87)T<RP@;6%T8VAI;F<@=&AE('1O<"!L979E;"!E;6%I
M;"!E;&5M96YT("TM/@T*"3QX<VPZ=&5M<&QA=&4@;6%T8V@](F5M86EL(CX-
M"@D)/'AS;#IC86QL+71E;7!L871E(&YA;64](FUI;65P87)T(B\^#0H)/"]X
M<VPZ=&5M<&QA=&4^#0H-"CPO>'-L.G-T>6QE<VAE970^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]-
M86EL7TUI;64O>&UA:6PN9'1D````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$P-C8`,3`U,34T,S$P-3<`,#(Q-S$U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(@
M96YC;V1I;F<](DE33RTX.#4Y+3$B/SX-"@T*/"%%3E1)5%D@;'0@(B8C,S@[
M(S8P.R(^#0H\(45.5$E462!G="`B)B,V,CLB/@T*/"%%3E1)5%D@86UP("(F
M(S,X.R,S.#LB/@T*/"%%3E1)5%D@87!O<R`B)B,S.3LB/@T*/"%%3E1)5%D@
M<75O="`B)B,S-#LB/@T*/"%%3E1)5%D@8W)L9B`B)B,Q,SLF(S$P.R(^#0H-
M"CPA14Q%345.5"!E;6%I;"`H:&5A9&5R*RP@*&)O9'D@?"!M:6UE<&%R="LI
M*3X-"CPA14Q%345.5"!M:6UE<&%R="`H:&5A9&5R*RP@*&)O9'D@?"!M:6UE
M<&%R="LI*3X-"CPA14Q%345.5"!B;V1Y("@C4$-$051!*3X-"CPA14Q%345.
M5"!H96%D97(@*"AH96%D97)N86UE?&AE861E<G9A;'5E?'!A<F%M971E<BDJ
M*3X-"CPA14Q%345.5"!H96%D97)N86UE("@C4$-$051!*3X-"CPA14Q%345.
M5"!H96%D97)V86QU92`H(U!#1$%402D^#0H\(45,14U%3E0@<&%R86UE=&5R
M("@H<&%R86UN86UE?'!A<F%M=F%L=64I*RD^#0H\(45,14U%3E0@<&%R86UV
M86QU92`H(U!#1$%402D^#0H\(45,14U%3E0@<&%R86UN86UE("@C4$-$051!
M*3X-"@T*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&%T82],;V<O````````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$V-S<V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]D871A+TQO9R]M:7-C+P``````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P
M,3<W,S$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O3&]G+VUI
M<V,O;&]G+G-Q;```````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#`W`#$P-3$U-#,Q,#4W`#`R,3(S,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+2`D260Z(&QO9RYS<6PL=B`Q+C$@,C`P
M-"\P,R\Q.2`P.#HP,#HQ,"!J;VX@17AP("0*"D-214%412!404),12!L;V=?
M=&%B;&4@*`H@("`@:60@("`@("`@("`@24Y4($Y/5"!.54Q,+`H@("`@;&]G
M=&EM92`@("`@5$E-15-404U0($Y/5"!.54Q,+`H@("`@:61E;G0@("`@("`@
M0TA!4B@Q-BD@3D]4($Y53$PL"B`@("!P<FEO<FET>2`@("!)3E0@3D]4($Y5
M3$PL"B`@("!M97-S86=E("`@("!605)#2$%2*#(P,"DL"B`@("!04DE-05)9
M($M%62`H:60I"BD["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U-E<G9I8V5S7U=E871H97(O
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`U-P`P,C$U,3<`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O
M4V5R=FEC97-?5V5A=&AE<B]I;6%G97,O````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`R,C<V-``@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&%T82]397)V:6-E<U]796%T:&5R+VEM86=E<R]S=6YS
M970N9VEF````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T,S0`,3`U,34T,S$P-3<`,#(T-S<R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81X`#P#$``#^[>KY5AG_84?_>B3_@V[_/!MN."#]S<7^M*?5M*F+8TO%
M/`RZHIBIBW[\EH+2DH+_F3/___\`````````````````````````````````
M```````````````````````A^00``````"P`````'@`/```%F6`DCF1IGFBJ
MKJ8CF,C+GD<A(H<H(.Q!D#E`(2?((0H`%B`@2$9V3\<S&9#.ELA(+))X`![:
M+'0%$#0CCX;"P%8T$A'".0+@I>0)PZ(0Z`<6!@Q6``0%,B4(!$D-!GT#CX]]
M!G!'!58F/@1Y`9`0GA"1"@\%BC`'3@`*G)^LH`,+#2-.(P(%A@0."@.MK0,!
M"@<NAS/$Q<8B(0`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]I;6%G97,O<W5N<FES92YG:68`````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-#0Q`#$P-3$U-#,Q,#4W`#`R-3$S-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$<``T`Q```
M[+"=_8]U7%0D__GX\,,*_UDT_W-/__0H_,:W_>/:_^$6GY*`_SH6D'Y!_^[K
MOI!Y__\S____````````````````````````````````````````````````
M````````(?D$```````L`````!P`#0``!9Y@)(YD:9[H&!0F4`QI!)<(XT0!
M(A=`C!BS@<[!T!5T`$8BYB@4EA%>Q!"(.@:,ZF!V:BHCOPC@X7B(;5%=RF%X
M1AZ+AF`N:)C;MTA";5H!!`0$"H,$<@L!,&P,!B4`!DL+@(,'!X,*!`(]`0P,
M`%PB"0$!?X*4!Q"4A`(/67DB``A7,@T-DQ"WMY68#2(#KFU.H@*VN+FJ""M`
M,<LH(0`[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U-E<G9I
M8V5S7U=E871H97(O8G5I;&1-971A<D1"+G!H<```````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S
M-S0W,@`Q,#4Q-30S,3`U-P`P,C0U-#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R$O=7-R+VQO8V%L+V)I;B]P:'`*/#]P
M:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@
M*B!4:&ES('-C<FEP="!D;W=N;&]A9',L('-A=F5S(&%N9"!P<F]C97-S97,@
M=&AE('1E>'1F:6QE<R!N965D960@9F]R"B`J('1H92!B=6EL9&EN9R!T:&4@
M9&%T86)A<V5S('1O(&5N86)L92!S96%R8VAI;F<@9F]R($U%5$%2('-T871I
M;VYS+@H@*@H@*B!9;W4@8V%N(&1O=VYL;V%D('1H92!L;V-A=&EO;G,L('=H
M:6-H(&ES(&$@9&%T86)A<V4@;V8@86)O=70@,3(P,#`@=V]R;&0M"B`J('=I
M9&4@;&]C871I;VYS+"!W:&EC:"!C86X@8F4@=7-E9"!T;R!D971E<FUI;F4@
M=&AE(&-O;W)D:6YA=&5S(&]F('EO=7(*("H@8VET>2!O<B!Y;W4@8V%N(&1O
M=VYL;V%D(&$@9FEL92!W:71H(#8U,#`@86ER<&]R=',@<')O=FED:6YG('1H
M92!M971A<@H@*B!D871A+B!4:&ES(&1A=&%B87-E(&ES('5S960@9F]R('1H
M92!N97AT+4U%5$%2+7-T871I;VX@<V5A<F-H+B!0;&5A<V4@<V5E"B`J('1H
M92!A<')O<')I871E(&1O8W5M96YT871I;VX@:6X@=&AE(%-E<G9I8V5S7U=E
M871H97)?365T87(@8VQA<W,N"B`J"B`J($9O<B!U<V%G92!O9B!T:&ES('-C
M<FEP="P@:6YV;VME('=I=&@@)RUH)RX*("H*("H@4$A0('9E<G-I;VYS(#0@
M86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@,C`P-2P@
M06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J"B`J
M(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@
M9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P
M97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO
M;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E
M(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L
M"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y
M(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I
M8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@*B`@(&%N
M9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I
M8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O9G1W87)E
M(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@(&UA>2!B
M92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D
M(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3
M(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))
M0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@
M5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(
M10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.
M1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@*B!!4D4@1$E3
M0TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"!/5TY%
M4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@1$E214-4
M+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/
M4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/
M5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)35$E4551%($=/
M3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE4
M4SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%5D52($-!55-%
M1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X*
M("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ5
M1$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))4TE.1R!)3B!!
M3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@
M248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!
M1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V
M:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`<W5B
M<&%C:V%G92`@8G5I;&1-971A<D1""B`J($!A=71H;W(@("`@("!!;&5X86YD
M97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U
M($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO
M<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,
M:6-E;G-E"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@8G5I;&1-971A<D1"
M+G!H<"QV(#$N,C,@,C`P-2\Q,2\Q,R`R,3HU-CHQ-2!E<G4@17AP("0*("H@
M0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V
M:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H='1P.B\O=V5A=&AE<BYN
M;V%A+F=O=B]T9R]S:71E+G-H=&UL"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q
M=6ER95]O;F-E(")$0BYP:'`B.PH*+R\@>WM[(&-O;G-T86YT<PHO+R![>WL@
M;F%T=7)A;"!C;VYS=&%N=',@86YD(&UE87-U<F5S"F1E9FEN92@B4T525DE#
M15-?5T5!5$A%4E]2041)55-?14%25$@B+"`V,S<X+C$U*3L*+R\@?7U]"B\O
M('U]?0H*+R\@>WM[(%-E<G9I8V5S7U=E871H97)?8VAE8VM$871A*"D*+RHJ
M"B`J(%-E<G9I8V5S7U=E871H97)?8VAE8VM$871A"B`J"B`J($-H96-K<R!T
M:&4@9&%T82!F;W(@82!C97)T86EN('-T<FEN9RUL96YG=&@@86YD(&EF(&ET
M(&5I=&AE<B!C;VYS:7-T<R!O9@H@*B!A(&-E<G1A:6X@8VAA<BUT>7!E(&]R
M(&$@<W1R:6YG(&]F("(M(B!A<R!R97!L86-E;65N="X*("H*("H@0'!A<F%M
M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T82`@("`@
M("`@("`@5&AE(&1A=&$@=&\@8F4@8VAE8VME9`H@*B!`<&%R86T@("!A<G)A
M>2`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A3W)D97(@("`@("!"
M96-A=7-E('1H92!D871A(&ES(&EN(&1I9F9E<F5N="!L;V-A=&EO;G,L('=E
M('!R;W9I9&4@=&AI<PH@*B!`<F5T=7)N("!B;V]L"B`J+PIF=6YC=&EO;B!3
M97)V:6-E<U]796%T:&5R7V-H96-K1&%T82@D9&%T82P@)&1A=&%/<F1E<BD*
M>PH@("`@)')E='5R;B`]('1R=64["B`@("!F;W)E86-H("@D9&%T84]R9&5R
M(&%S("1T>7!E(#T^("1I9'@I('L*("`@("`@("!S=VET8V@@*'-T<G1O;&]W
M97(H)'1Y<&4I*2!["B`@("`@("`@("`@(&-A<V4@(F(B.@H@("`@("`@("`@
M("`@("`@)&QE;B`@/2`R.PH@("`@("`@("`@("`@("`@)&9U;F,@/2`B8W1Y
M<&5?9&EG:70B.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@(G,B.@H@("`@("`@("`@("`@("`@)&QE;B`@/2`S.PH@("`@("`@
M("`@("`@("`@)&9U;F,@/2`B8W1Y<&5?9&EG:70B.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(FDB.@H@("`@("`@("`@("`@
M("`@)&QE;B`@/2`T.PH@("`@("`@("`@("`@("`@)&9U;F,@/2`B8W1Y<&5?
M86QN=6TB.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("`@
M("`@:68@*"AS=')L96XH)&1A=&%;)&ED>%TI("$]("1L96XI('Q\("@A)&9U
M;F,H)&1A=&%;)&ED>%TI("8F("@D9&%T85LD:61X72`A/2!S=')?<F5P96%T
M*"(M(BP@)&QE;BDI*2D@>PH@("`@("`@("`@("`D<F5T=7)N(#T@9F%L<V4[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@(')E='5R
M;B`D<F5T=7)N.PI]"B\O('U]?0H*+R\@>WM[(%-E<G9I8V5S7U=E871H97)?
M9V5T3F5X=$%R9R@I"B\J*@H@*B!397)V:6-E<U]796%T:&5R7V=E=$YE>'1!
M<F<*("H*("H@0VAE8VMS+"!I9B!T:&4@;F5X="!A<F=U;65N="!I<R!A('!A
M<F%M971E<B!T;R!A('!R961E8V5S<VEN9R!O<'1I;VXN"B`J(%)E='5R;G,@
M96ET:&5R('1H870@<&%R86UE=&5R(&]R(&9A;'-E+"!I9B!T:&4@;F5X="!A
M<F=U;65N="!I<R!A;B!O<'1I;VX*("H*("H@0'!A<F%M("`@:6YT("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8R`@("`@("`@("`@("`@26YT97)N
M86P@87)G=6UE;G0@8V]U;G1E<@H@*B!`<F5T=7)N("!S=')I;F=\8F]O;`H@
M*B\*9G5N8W1I;VX@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"8D8RD*
M>PH@("`@:68@*"@H)&,@*R`Q*2`\("1?4T525D526R)A<F=C(ETI("8F("@D
M7U-%4E9%4ELB87)G=B)=6R1C("L@,5U[,'T@(3T@(BTB*2D@>PH@("`@("`@
M("1C*RL["B`@("`@("`@<F5T=7)N("1?4T525D526R)A<F=V(EU;)&-=.PH@
M("`@?2!E;'-E('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"GT*+R\@
M?7U]"@HO+R!&:7)S="!S970@82!F97<@=F%R:6%B;&5S(&9O<B!P<F]C97-S
M:6YG('1H92!O<'1I;VYS"B1M;V1E4V5T("`@/2!F86QS93L*)'-A=F5&:6QE
M("`](&9A;'-E.PHD<')I;G1(96QP(#T@9F%L<V4["B1I;G9/<'0@("`@/2!F
M86QS93L*)'9E<F)O<V4@("`](#`["B1D8E1Y<&4@("`@/2`B;7ES<6PB.PHD
M9&)0<F]T("`@(#T@(G5N:7@B.PHD9&).86UE("`@(#T@(G-E<G9I8V5S5V5A
M=&AE<D1"(CL*)&1B57-E<B`@("`](")R;V]T(CL*)&1B4&%S<R`@("`]("(B
M.PHD9&)(;W-T("`@(#T@(FQO8V%L:&]S="(["B1D8D]P=&EO;G,@/2!A<G)A
M>2@I.PHD=7-E<D9I;&4@(#T@(B(["@HO+R!)=&5R871E('1H<F]U9V@@=&AE
M(&%R9W5M96YT<R!A;F0@8VAE8VL@=&AE:7(@=F%L:61I='D*9F]R("@D8R`]
M(#$[("1C(#P@)%]315)615);(F%R9V,B73L@)&,K*RD@>PH@("`@<W=I=&-H
M("@D7U-%4E9%4ELB87)G=B)=6R1C77LQ?2D@>PH@("`@("`@(&-A<V4@(FPB
M.@H@("`@("`@("`@("`O+R!L;V-A=&EO;BUM;V1E+"!I9B!A;F]T:&5R(&UO
M9&4@:7,@<V5T+"!B86EL(&]U=`H@("`@("`@("`@("!I9B`H)&UO9&53970I
M('L*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UO9&53970@("`]('1R
M=64["B`@("`@("`@("`@("`@("`D9FEL95!A<G0@(#T@(F)B<W-S(CL*("`@
M("`@("`@("`@("`@("1T86)L94YA;64@/2`B;65T87),;V-A=&EO;G,B.PH@
M("`@("`@("`@("`@("`@)&1A=&%/<F1E<B`](&%R<F%Y*")B(B`]/B`P+"`B
M<R(@/3X@,2P@(FDB(#T^(#(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@(&-A<V4@(F$B.@H@("`@("`@("`@("`O+R!D:71O
M(&9O<B!A:7)P;W)T+6UO9&4*("`@("`@("`@("`@:68@*"1M;V1E4V5T*2![
M"B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M;V1E4V5T("`@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@)&9I;&5087)T("`](")C8V-C(CL*("`@("`@
M("`@("`@("`@("1T86)L94YA;64@/2`B;65T87)!:7)P;W)T<R(["B`@("`@
M("`@("`@("`@("`D9&%T84]R9&5R(#T@87)R87DH(F(B(#T^(#$L(")S(B`]
M/B`R+"`B:2(@/3X@,"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@8V%S92`B9B(Z"B`@("`@("`@("`@("\O(&9I;&4M9FQA
M9R!W87,@<')O=FED960L(&-H96-K(&EF(&YE>'0@87)G=6UE;G0@:7,@82!S
M=')I;F<*("`@("`@("`@("`@:68@*"@D=7-E<D9I;&4@/2!397)V:6-E<U]7
M96%T:&5R7V=E=$YE>'1!<F<H)&,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(G,B.@H@("`@("`@("`@("`O
M+R!)9B!Y;W4@9&]W;FQO860@=&AE(&9I;&4L(&ET('=I;&P@8F4@<V%V960@
M=&\@9&ES:PH@("`@("`@("`@("`D<V%V949I;&4@("`@("`]('1R=64["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(G0B.@H@("`@("`@("`@
M("`O+R!4:&4@='EP92!O9B!T:&4@1$(@=&\@8F4@=7-E9`H@("`@("`@("`@
M("!I9B`H*"1D8E1Y<&4@/2!397)V:6-E<U]796%T:&5R7V=E=$YE>'1!<F<H
M)&,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@
M/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@(&-A<V4@(G(B.@H@("`@("`@("`@("`O+R!4:&4@<')O=&]C;VP@;V8@
M=&AE($1"('1O(&)E('5S960*("`@("`@("`@("`@:68@*"@D9&)0<F]T(#T@
M4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E(")D(CH*("`@
M("`@("`@("`@+R\@5&AE(&YA;64@;V8@=&AE($1"('1O(&)E('5S960*("`@
M("`@("`@("`@:68@*"@D9&).86UE(#T@4V5R=FEC97-?5V5A=&AE<E]G971.
M97AT07)G*"1C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<')I
M;G1(96QP(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!C87-E(")U(CH*("`@("`@("`@("`@+R\@5&AE('5S97(@
M;V8@=&AE($1"('1O(&)E('5S960*("`@("`@("`@("`@:68@*"@D9&)5<V5R
M(#T@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@/3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E(")P(CH*
M("`@("`@("`@("`@+R\@5&AE('!A<W-W;W)D(&]F('1H92!$0B!T;R!B92!U
M<V5D"B`@("`@("`@("`@(&EF("@H)&1B4&%S<R`](%-E<G9I8V5S7U=E871H
M97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@)'!R:6YT2&5L<"`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@8V%S92`B:"(Z"B`@("`@("`@("`@("\O(%1H
M92!H;W-T(&]F('1H92!$0B!T;R!B92!U<V5D"B`@("`@("`@("`@(&EF("@H
M)&1B2&]S="`](%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R9R@D8RDI(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92`B;R(Z"B`@("`@("`@("`@("\O($]P=&EO;G,@9F]R('1H92!$0@H@("`@
M("`@("`@("!I9B`H*"1O<'1I;VYS(#T@4V5R=FEC97-?5V5A=&AE<E]G971.
M97AT07)G*"1C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<')I
M;G1(96QP(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1O<'1I;VYS("`@/2!E>'!L;V1E*"(L(BP@)&]P=&EO;G,I.PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&]P=&EO;BD@
M>PH@("`@("`@("`@("`@("`@("`@("1O<'1086ER(#T@97AP;&]D92@B/2(L
M("1O<'1I;VXI.PH@("`@("`@("`@("`@("`@("`@("1D8D]P=&EO;G-;)&]P
M=%!A:7);,%U=(#T@)&]P=%!A:7);,5T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`B
M=B(Z"B`@("`@("`@("`@("\O(&EN8W)E87-E('9E<F)O<VET>0H@("`@("`@
M("`@("!F;W(@*"1I(#T@,3L@)&D@/"!S=')L96XH)%]315)615);(F%R9W8B
M75LD8UTI.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)%]315)615);
M(F%R9W8B75LD8UU[)&E](#T](")V(BD@>PH@("`@("`@("`@("`@("`@("`@
M("1V97)B;W-E*RL["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1I;G9/<'0@("`@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("\O(&%R9W5M96YT(&YO="!V86QI9"P@8F%I;"!O=70*("`@("`@("`@
M("`@)&EN=D]P="`@("`]('1R=64["B`@("`@("`@("`@(&)R96%K.PH@("`@
M?0H@("`@:68@*"1I;G9/<'0I('L*("`@("`@("`O+R!S964@86)O=F4*("`@
M("`@("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("!E8VAO("));G9A;&ED
M(&]P=&EO;CH@)R(N)%]315)615);(F%R9W8B75LD8UTN(B=<;B(["B`@("`@
M("`@8G)E86L["B`@("!]"GT*"B\O(&AE;'`M;65S<V%G90II9B`H(21M;V1E
M4V5T('Q\("1P<FEN=$AE;'`I('L*("`@(&5C:&\@(E5S86=E.B`B+F)A<V5N
M86UE*"1?4T525D526R)A<F=V(EU;,%TL("(N<&AP(BDN(B`M;'PM82!;;W!T
M:6]N<UU<;B(["B`@("!E8VAO(")/<'1I;VYS.EQN(CL*("`@(&5C:&\@(B`@
M+6P@("`@("`@("`@("`@(&)U:6QD(&QO8V%T:6]N<T1"7&XB.PH@("`@96-H
M;R`B("`M82`@("`@("`@("`@("`@8G5I;&0@86ER<&]R='-$0EQN(CL*("`@
M(&5C:&\@(B`@+68@/&9I;&4^("`@("`@('5S92`\9FEL93X@87,@:6YP=71<
M;B(["B`@("!E8VAO("(@("US("`@("`@("`@("`@("!S879E(&1O=VYL;V%D
M960@9FEL92!T;R!D:7-K7&XB.PH@("`@96-H;R`B("`M="`\9&)T>7!E/B`@
M("`@='EP92!O9B!T:&4@1$(@=&\@8F4@=7-E9%QN(CL*("`@(&5C:&\@(B`@
M+7(@/&1B<')O=&]C;VP^('!R;W1O8V]L("TM+2TM7"(M+2TM+2TM+2TM7&XB
M.PH@("`@96-H;R`B("`M9"`\9&)N86UE/B`@("`@;F%M92`M+2TM+2TM+2U<
M(BTM+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("UU(#QD8G5S97(^("`@("!U
M<V5R("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@(&5C:&\@(B`@+7`@
M/&1B<&%S<SX@("`@('!A<W,@+2TM+2TM+2TM7"(M+2TM+2TM+2TM7&XB.PH@
M("`@96-H;R`B("`M:"`\9&)H;W-T/B`@("`@:&]S="`M+2TM+2TM+2U<(BTM
M+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("UO(#QD8F]P=&EO;G,^("!O<'1I
M;VYS("TM+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@(&5C:&\@(B`@("`@("`@
M("`@("`@("`@(&EN('1H92!N;W1A=&EO;B!O<'1I;VX]=F%L=64L+BXN7&XB
M.PH@("`@96-H;R`B("`M=B`@("`@("`@("`@("`@9&ES<&QA>2!V97)B;W-E
M(&1E8G5G9VEN9R!M97-S86=E<UQN(CL*("`@(&5C:&\@(B`@("`@("`@("`@
M("`@("`@(&UU;'1I<&QE("UV(&EN8W)E87-E<R!V97)B;W-I='E<;B(["B`@
M("!E>&ET*#(U-2D["GT*"B\O(&-H96-K+"!I9B!Z;&EB(&ES(&%V86EL86)L
M90II9B`H97AT96YS:6]N7VQO861E9"@B>FQI8B(I*2!["B`@("`D;W!E;B`@
M/2`B9WIO<&5N(CL*("`@("1C;&]S92`](")G>F-L;W-E(CL*("`@("1F:6QE
M<R`](&%R<F%Y*`H@("`@("`@("1U<V5R1FEL92P@(FYS9%\B+B1F:6QE4&%R
M="P@(FYS9%\B+B1F:6QE4&%R="XB+G1X="(L"B`@("`@("`@(FYS9%\B+B1F
M:6QE4&%R="XB+F=Z(BP@(FAT='`Z+R]W96%T:&5R+FYO86$N9V]V+V1A=&$O
M;G-D7R(N)&9I;&5087)T+B(N9WHB"B`@("`I.PI](&5L<V4@>PH@("`@)&]P
M96X@(#T@(F9O<&5N(CL*("`@("1C;&]S92`](")F8VQO<V4B.PH@("`@)&9I
M;&5S(#T@87)R87DH"B`@("`@("`@)'5S97)&:6QE+"`B;G-D7R(N)&9I;&50
M87)T+"`B;G-D7R(N)&9I;&5087)T+B(N='AT(BP*("`@("`@("`B:'1T<#HO
M+W=E871H97(N;F]A82YG;W8O9&%T82]N<V1?(BXD9FEL95!A<G0N(BYT>'0B
M"B`@("`I.PI]"B\O('1H96X@=')Y('1O(&]P96X@82!S;W5R8V4@:6X@=&AE
M(&=I=F5N(&]R9&5R"F9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@>PH@("`@
M)&9P(#T@0"1O<&5N*"1F:6QE+"`B<F(B*3L*("`@(&EF("@D9G`I('L*("`@
M("`@("`O+R!F;W5N9"!A('9A;&ED('-O=7)C90H@("`@("`@(&EF("@D=F5R
M8F]S92`^(#`I('L*("`@("`@("`@("`@96-H;R`B4V5R=FEC97-?5V5A=&AE
M<CH@57-I;F<@)R(N)&9I;&4N(B<@87,@<V]U<F-E+EQN(CL*("`@("`@("!]
M"B`@("`@("`@:68@*"1S879E1FEL92`F)B`A9FEL95]E>&ES=',H)&9I;&4I
M*2!["B`@("`@("`@("`@("\O(&%P<&%R96YT;'D@=V4@=V%N="!T;R!S879E
M('1H92!F:6QE+"!A;F0@:70G<R!A(')E;6]T92!F:6QE"B`@("`@("`@("`@
M("1F:6QE(#T@8F%S96YA;64H)&9I;&4I.PH@("`@("`@("`@("`D9G!S(#T@
M0"1O<&5N*"1F:6QE+"`B=V(B*3L*("`@("`@("`@("`@:68@*"$D9G!S*2![
M"B`@("`@("`@("`@("`@("!E8VAO(")397)V:6-E<U]796%T:&5R.B!#;W5L
M9&XG="!S879E('1O("<B+B1F:6QE+B(G(5QN(CL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&EF("@D=F5R8F]S92`^(#`I('L*("`@
M("`@("`@("`@("`@("`@("!E8VAO(")397)V:6-E<U]796%T:&5R.B!3879I
M;F<@<V]U<F-E('1O("<B+B1F:6QE+B(G+EQN(CL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("\O(')E860@9G)O;2!F:6QE<&]I;G1E<B!A
M;F0@<V%V92!T;R!D:7-K"B`@("`@("`@("`@("`@("!W:&EL92`H)&QI;F4@
M/2!F<F5A9"@D9G`L(#$P,C0I*2!["B`@("`@("`@("`@("`@("`@("`@9G=R
M:71E*"1F<',L("1L:6YE+"!S=')L96XH)&QI;F4I*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("\O('5N9F]R='5N871E;'D@>FQI8B!D
M;V5S(&YO="!S=7!P;W)T('(O=R!O;B!A(')E<V]U<F-E+`H@("`@("`@("`@
M("`@("`@+R\@<V\@;F\@<F5W:6YD("T^(&UO=F4@)&9P('1O(&YE=R!F:6QE
M(&]N(&1I<VL*("`@("`@("`@("`@("`@("1C;&]S92@D9G`I.PH@("`@("`@
M("`@("`@("`@)&-L;W-E*"1F<',I.PH@("`@("`@("`@("`@("`@)&9P(#T@
M0"1O<&5N*"1F:6QE+"`B<F(B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!B<F5A:SL*("`@('T*?0II9B`H(21F<"D@>PH@("`@+R\@;F\@
M9FEL97,@9F]U;F0L(&]R(&-O;FYE8W1I;VX@;F]T(&%V86EL86)L92XN+B!B
M86EL(&]U=`H@("`@9&EE*")397)V:6-E<U]796%T:&5R.B!3;W5R8V5F:6QE
M(&YS9%\B+B1F:6QE4&%R="XB(&YO="!F;W5N9"%<;B(I.PI]"@HD9'-N("`@
M("`]("1D8E1Y<&4N(CHO+R(N)&1B57-E<BXB.B(N)&1B4&%S<RXB0"(N)&1B
M4')O="XB*R(N)&1B2&]S="XB+R(N)&1B3F%M93L*)&1S;FEN9F\@/2!A<G)A
M>2@*("`@(")P:'!T>7!E(B`@/3X@)&1B5'EP92P*("`@(")P<F]T;V-O;"(@
M/3X@)&1B4')O="P*("`@(")U<V5R;F%M92(@/3X@)&1B57-E<BP*("`@(")P
M87-S=V]R9"(@/3X@)&1B4&%S<RP*("`@(")H;W-T<W!E8R(@/3X@)&1B2&]S
M="P*("`@(")D871A8F%S92(@/3X@)&1B3F%M92P*("`@(")M;V1E(B`@("`@
M/3X@(C`V-#0B"BD["@HD9&(@(#T@1$(Z.F-O;FYE8W0H)&1S;FEN9F\L("1D
M8D]P=&EO;G,I.PII9B`H1$(Z.FES17)R;W(H)&1B*2D@>PH@("`@96-H;R`B
M4V5R=FEC97-?5V5A=&AE<CH@0V]N;F5C=&EO;B!T;R!$0B!W:71H("<B+B1D
M8E1Y<&4N(CHO+R(N)&1B57-E<BXB.E!!4U-`(BXD9&)(;W-T+B(O(BXD9&).
M86UE+B(G(&9A:6QE9"%<;B(["B`@("!D:64H)&1B+3YG971-97-S86=E*"DN
M(EQN(BD["GT@96QS92!["B`@("`O+R!497-T+"!I9B!W92!H879E('1O('-W
M:7!E(&]R(&-R96%T92!T:&4@=&%B;&4@9FER<W0*("`@("1S96QE8W0@/2`B
M4T5,14-4("H@1E)/32`B+B1T86)L94YA;64["B`@("`D<F5S=6QT(#T@)&1B
M+3YQ=65R>2@D<V5L96-T*3L*"B`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L
M="DI('L*("`@("`@("`O+R!#<F5A=&4@;F5W('1A8FQE"B`@("`@("`@)&-R
M96%T92`](")#4D5!5$4@5$%"3$4@(BXD=&%B;&5.86UE+B(H:60@:6YT+&)L
M;V-K(&EN="QS=&%T:6]N(&EN="QI8V%O('9A<F-H87(H-"DL;F%M92!V87)C
M:&%R*#@P*2QS=&%T92!V87)C:&%R*#(I+&-O=6YT<GD@=F%R8VAA<B@U,"DL
M=VUO(&EN="QL871I='5D92!F;&]A="QL;VYG:71U9&4@9FQO870L96QE=F%T
M:6]N(&9L;V%T+'@@9FQO870L>2!F;&]A="QZ(&9L;V%T*2(["B`@("`@("`@
M:68@*"1V97)B;W-E(#X@,"D@>PH@("`@("`@("`@("!E8VAO(")397)V:6-E
M<U]796%T:&5R.B!#<F5A=&EN9R!T86)L92`G(BXD=&%B;&5.86UE+B(G+EQN
M(CL*("`@("`@("!]"B`@("`@("`@)')E<W5L="`@/2`D9&(M/G%U97)Y*"1C
M<F5A=&4I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!D:64H)')E<W5L="T^9V5T365S<V%G92@I+B)<;B(I.PH@
M("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@+R\@1&5L971E('1H92!O
M;&0@<W1U9F8*("`@("`@("`D9&5L971E(#T@(D1%3$5412!&4D]-("(N)'1A
M8FQE3F%M93L*("`@("`@("!I9B`H)'9E<F)O<V4@/B`P*2!["B`@("`@("`@
M("`@(&5C:&\@(E-E<G9I8V5S7U=E871H97(Z($1E;&5T:6YG(&9R;VT@=&%B
M;&4@)R(N)'1A8FQE3F%M92XB)RY<;B(["B`@("`@("`@?0H@("`@("`@("1R
M97-U;'0@/2`D9&(M/G%U97)Y*"1D96QE=&4I.PH@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!D:64H)')E<W5L="T^
M9V5T365S<V%G92@I+B)<;B(I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!/
M:RP@1$(@<VAO=6QD(&)E('5P(&%N9"!R=6YN:6YG(&YO=RP@;&5T)W,@<VAO
M=F4@:6X@=&AE(&1A=&$*("`@("1L:6YE("`@/2`P.PH@("`@)&5R<F]R("`]
M(#`["B`@("`O+R!R96%D(&1A=&$@9G)O;2!F:6QE"B`@("!W:&EL92`H)&1A
M=&$@/2!F9V5T8W-V*"1F<"P@,3`P,"P@(CLB*2D@>PH@("`@("`@("\O($-H
M96-K(&9O<B!V86QI9"!D871A"B`@("`@("`@:68@*"AS:7IE;V8H)&1A=&$I
M(#P@.2D@?'P@(5-E<G9I8V5S7U=E871H97)?8VAE8VM$871A*"1D871A+"`D
M9&%T84]R9&5R*2D@>PH@("`@("`@("`@("`@("`@96-H;R`B4V5R=FEC97-?
M5V5A=&AE<CH@26YV86QI9"!D871A(&EN(&9I;&4A7&XB.PH@("`@("`@("`@
M("`@("`@96-H;R`B7'1,:6YE("(N*"1L:6YE("L@,2DN(CH@(BYI;7!L;V1E
M*"([(BP@)&1A=&$I+B)<;B(["B`@("`@("`@("`@("`@("`D97)R;W(K*SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!C86QC=6QA=&4@;&%T
M:71U9&4@86YD(&QO;F=I='5D90H@("`@("`@("`@("`O+R!I="!C;VUE<R!I
M;B!A(&1D9"UM;5LM<W-=3GQ3?$5\5R!F;W)M870*("`@("`@("`@("`@)&-O
M;W)D(#T@87)R87DH(")L871I='5D92(@/3X@-RP@(FQO;F=I='5D92(@/3X@
M."D["B`@("`@("`@("`@(&9O<F5A8V@@*"1C;V]R9"!A<R`D;&%T;&]N(#T^
M("1A260I('L*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H(B]>*%QD>S$L
M,WTI+2A<9'LQ+#)]*2@M*%QD>S$L,GTI*3\H6TY315==*20O(BP@)&1A=&%;
M)&%)9%TL("1R97-U;'0I.PH@("`@("`@("`@("`@("`@)'LD;&%T;&]N?2`]
M(#`[("1F86-T;W(@/2`Q.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E
M<W5L="!A<R`D=F%R*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"AS=')L
M96XH)'9A<BD@/B`P*2`F)B!C='EP95]D:6=I="@D=F%R*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D>R1L871L;VY]("L]("1V87(@+R`D9F%C=&]R
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F%C=&]R("H](#8P.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("AC='EP95]A;'!H82@D=F%R*2`F
M)B!I;E]A<G)A>2@D=F%R+"!A<G)A>2@B4R(L(")7(BDI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1[)&QA=&QO;GT@*CT@*"TQ*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O($-A;&-U;&%T92!T:&4@8V%R=&5S:6%N(&-O;W)D
M:6YA=&5S(&9O<B!L871I='5D92!A;F0@;&]N9VET=61E"B`@("`@("`@("`@
M("1T:&5T82`](&1E9S)R860H)&QA=&ET=61E*3L*("`@("`@("`@("`@)'!H
M:2`@(#T@9&5G,G)A9"@D;&]N9VET=61E*3L*"B`@("`@("`@("`@("1X(#T@
M4T525DE#15-?5T5!5$A%4E]2041)55-?14%25$@@*B!C;W,H)'!H:2D@*B!C
M;W,H)'1H971A*3L*("`@("`@("`@("`@)'D@/2!315)624-%4U]714%42$52
M7U)!1$E54U]%05)42"`J('-I;B@D<&AI*2`J(&-O<R@D=&AE=&$I.PH@("`@
M("`@("`@("`D>B`](%-%4E9)0T537U=%051(15)?4D%$25537T5!4E1(("`@
M("`@("`@("`@("H@<VEN*"1T:&5T82D["@H@("`@("`@("`@("`O+R!#:&5C
M:R!F;W(@96QE=F%T:6]N(&EN(&1A=&$*("`@("`@("`@("`@)&5L979A=&EO
M;B`](&ES7VYU;65R:6,H)&1A=&%;,3%=*2`_("1D871A6S$Q72`Z(#`["@H@
M("`@("`@("`@("`O+R!I;G1E9V5R<SH@8V]N=F5R="`B+2TB(&9I96QD<R!T
M;R!N=6QL+"!E;7!T>2!F:65L9',@=&\@,`H@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>2@D9&%T84]R9&5R6R)B(ETL("1D871A3W)D97);(G,B72P@-BD@
M87,@)&DI('L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&1A=&%;)&E=
M+"`B+2TB*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D9&%T
M85LD:5T@/2`B;G5L;"(["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&1A
M=&%;)&E=(#T]("(B*2!["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)&E=
M(#T@,#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@<W1R:6YG<SH@<75O=&4*("`@("`@("`@("`@9F]R96%C:"`H
M87)R87DH)&1A=&%/<F1E<ELB:2)=+"`S+"`T+"`U*2!A<R`D:2D@>PH@("`@
M("`@("`@("`@("`@)&1A=&%;)&E=(#T@)&1B+3YQ=6]T92@D9&%T85LD:5TI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!I;G-E<G0@9&%T80H@
M("`@("`@("`@("`D:6YS97)T("`]("))3E-%4E0@24Y43R`B+B1T86)L94YA
M;64N(B!604Q515,H(BXH)&QI;F4@+2`D97)R;W(I+B(L(CL*("`@("`@("`@
M("`@)&EN<V5R="`N/2`D9&%T85LD9&%T84]R9&5R6R)B(EU=+B(L(BXD9&%T
M85LD9&%T84]R9&5R6R)S(EU=+B(L(CL*("`@("`@("`@("`@)&EN<V5R="`N
M/2`D9&%T85LD9&%T84]R9&5R6R)I(EU=+B(L(BXD9&%T85LS72XB+"(N)&1A
M=&%;-%TN(BPB.PH@("`@("`@("`@("`D:6YS97)T("X]("1D871A6S5=+B(L
M(BXD9&%T85LV72XB+"(N<F]U;F0H)&QA=&ET=61E+"`T*2XB+"(["B`@("`@
M("`@("`@("1I;G-E<G0@+CT@<F]U;F0H)&QO;F=I='5D92P@-"DN(BPB+B1E
M;&5V871I;VXN(BPB+G)O=6YD*"1X+"`T*2XB+"(["B`@("`@("`@("`@("1I
M;G-E<G0@+CT@<F]U;F0H)'DL(#0I+B(L(BYR;W5N9"@D>BP@-"DN(BDB.PH*
M("`@("`@("`@("`@)')E<W5L="`]("1D8BT^<75E<GDH)&EN<V5R="D["B`@
M("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@96-H;R`B7'1,:6YE("(N*"1L:6YE("L@,2DN(CH@(BXD:6YS
M97)T+B)<;B(["B`@("`@("`@("`@("`@("!E8VAO("1R97-U;'0M/F=E=$UE
M<W-A9V4H*2XB7&XB.PH@("`@("`@("`@("`@("`@)&5R<F]R*RL["B`@("`@
M("`@("`@('T@96QS96EF*"1V97)B;W-E(#X@,BD@>PH@("`@("`@("`@("`@
M("`@96-H;R`D:6YS97)T+B)<;B(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@)&QI;F4K*SL*("`@('T*("`@("\O(&-O;6UI="!A;F0@8VQO
M<V4*("`@("1D8BT^9&ES8V]N;F5C="@I.PH@("`@:68@*"1V97)B;W-E(#X@
M,"!\?"`D97)R;W(@/B`P*2!["B`@("`@("`@96-H;R`B4V5R=FEC97-?5V5A
M=&AE<CH@(BXH)&QI;F4@+2`D97)R;W(I+B(@(BXD=&%B;&5.86UE+B(@861D
M960@(CL*("`@("`@("!E8VAO(")T;R!D871A8F%S92`G(BXD9&).86UE+B(G
M("@B+B1E<G)O<BXB(&5R<F]R*',I*2Y<;B(["B`@("!]"GT*)&-L;W-E*"1F
M<"D["C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D871A+UA-3%]397)I86QI>F5R+P``````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C$Q,#8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O6$U,7U-E<FEA;&EZ
M97(O9&]C+P``````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#4W`#`R,38U,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&%T82]834Q?4V5R:6%L:7IE<B]D;V,O=&]D;RYT>'0`````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P-C``,3`U,34T,S$P-3<`,#(S,S4S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````%1/1$\Z"BTM+2TM"BT@
M:6YT<F]D=6-E(&-O;G-T86YT<R!F;W(@;W!T:6]N<R!T;R!A=F]I9"!T>7!O
M<PH*5$]$3R!834Q?4V5R:6%L:7IE<CH*+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M+2!F:6YD(&$@=V%Y('1O(&1E=&5C="!R969E<F5N8V5S(&EN('1H92!S=')U
M8W1U<F4@86YD(&%D9"!I9"]I9')E9B!A='1R:6)U=&5S"BT@<V5R:6%L:7IE
M('-O;64@;W1H97(@<W1R=6-T=7)E<RP@97-P96-I86QL>2!84&%T:"!R971U
M<FX@=F%L=65S"BT@8W5S=&]M('-E<FEA;&EZ871I;VX@;V8@;V)J96-T<PH*
M5$]$3R!834Q?56YS97)I86QI>F5R.@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"BT@<W5P<&]R="!F;W(@>&UL.G-P86-E(&%T=')I8G5T90HM('-E="!T>7!E
M<R!F;W(@8V5R=&%I;B!T86=S("AL:6ME(&EN('!A=$-O;F9I9W5R871I;VXI
M"BT@;F%M97-P86-E('-U<'!O<G0*+2!C=7-T;VT@=6YS97)I86QI>F%T:6]N
M(&9O<B!O8FIE8W1S("AS=&%T:6,@=6YS97)I86QI>F4H*2!O<B!F<F]M6$U,
M*"D@;65T:&]D<RD*+2!U;G-E<FEA;&EZ92!R969E<F5N8V5S('5S:6YG(&ED
M+VED<F5F````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&%T82]#86-H92\`````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$W,C8P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+T-A8VAE+T-O;G1A:6YE<B\`
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`U-P`P,C$R,#(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O
M0V%C:&4O0V]N=&%I;F5R+VUD8E]C86-H95]S8VAE;6$N>&UL````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-3<U`#$P-3$U-#,Q,#4W`#`R-3$S-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B
M(&5N8V]D:6YG/2))4T\M.#@U.2TQ(B`_/@T*/&1A=&%B87-E/@T*#0H@/&YA
M;64^9&)N86UE/"]N86UE/@T*(#QC<F5A=&4^,3PO8W)E871E/@T*(#QD97-C
M<FEP=&EO;CX@/"]D97-C<FEP=&EO;CX-"@T*(#QT86)L93X-"B`@/&YA;64^
M8V%C:&4\+VYA;64^#0H@(#QD97-C<FEP=&EO;CX@/"]D97-C<FEP=&EO;CX-
M"@T*("`\9&5C;&%R871I;VX^#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN86UE
M/DE$/"]N86UE/@T*("`@("`@/'1Y<&4^=&5X=#PO='EP93X-"B`@("`@(#QL
M96YG=&@^,S(\+VQE;F=T:#X-"B`@("`@(#QD969A=6QT/CPO9&5F875L=#X-
M"B`@("`@(#QN;W1N=6QL/C$\+VYO=&YU;&P^#0H@("`\+V9I96QD/@T*#0H@
M("`\9FEE;&0^#0H@("`@("`\;F%M93YC86-H96=R;W5P/"]N86UE/@T*("`@
M("`@/'1Y<&4^=&5X=#PO='EP93X-"B`@("`@(#QL96YG=&@^,3(W/"]L96YG
M=&@^#0H@("`@("`\9&5F875L=#X\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L
M;#XQ/"]N;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*("`@
M("`@/&YA;64^8V%C:&5D871A/"]N86UE/@T*("`@("`@/'1Y<&4^8VQO8CPO
M='EP93X-"B`@("`@(#QD969A=6QT/CPO9&5F875L=#X-"B`@("`@(#QN;W1N
M=6QL/C$\+VYO=&YU;&P^#0H@("`\+V9I96QD/@T*#0H@("`\9FEE;&0^#0H@
M("`@("`\;F%M93YU<V5R9&%T83PO;F%M93X-"B`@("`@(#QT>7!E/G1E>'0\
M+W1Y<&4^#0H@("`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@T*("`@("`@/&1E
M9F%U;'0^/"]D969A=6QT/@T*("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*
M("`@("`@/&YA;64^97AP:7)E<SPO;F%M93X-"B`@("`@(#QT>7!E/FEN=&5G
M97(\+W1Y<&4^#0H@("`@("`\9&5F875L=#XP/"]D969A=6QT/@T*("`@("`@
M/&YO=&YU;&P^,3PO;F]T;G5L;#X-"B`@(#PO9FEE;&0^#0H-"B`@(#QF:65L
M9#X-"B`@("`@(#QN86UE/F-H86YG960\+VYA;64^#0H@("`@("`\='EP93YI
M;G1E9V5R/"]T>7!E/@T*("`@("`@/&1E9F%U;'0^,#PO9&5F875L=#X-"B`@
M("`@(#QN;W1N=6QL/C$\+VYO=&YU;&P^#0H@("`\+V9I96QD/@T*#0H-"B`@
M(#QI;F1E>#X-"B`@("`\;F%M93YI9%]I;F1E>#PO;F%M93X-"B`@("`\=6YI
M<75E/C$\+W5N:7%U93X-"B`@("`\9FEE;&0^(#QN86UE/FED/"]N86UE/B`\
M+V9I96QD/@T*("`@(#QF:65L9#X@/&YA;64^8V%C:&5G<F]U<#PO;F%M93X@
M/"]F:65L9#X-"B`@(#PO:6YD97@^#0H-"@T*("`@/&EN9&5X/@T*("`@(#QN
M86UE/F5X<&ER97-?:6YD97@\+VYA;64^#0H@("`@/&9I96QD/B`\;F%M93YE
M>'!I<F5S/"]N86UE/B`\+V9I96QD/@T*("`@/"]I;F1E>#X-"@T*("`\+V1E
M8VQA<F%T:6]N/@T*(#PO=&%B;&4^#0H-"CPO9&%T86)A<V4^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O6$U,+P``````````````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`
M,#$V,#`T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]834PO4E!#+P``
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,3`U-P`P,38T,S``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+UA-3"]24$,O4V5R=F5R+G!H<```````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#4R,S0W`#$P-3$U-#,Q,#4W`#`R,#0Q-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@
M<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!397)V97(@8V]M;6%N9',@9F]R
M(&]U<B!02%`@:6UP;&5M96YT871I;VX@;V8@=&AE(%A-3"U24$,@<')O=&]C
M;VP*("H*("H@5&AI<R!I<R!A(%!%05(M:69I960@=F5R<VEO;B!O9B!5<V5F
M=6P@:6YC)W,@6$U,+5)00R!F;W(@4$A0+@H@*B!)="!H87,@<W5P<&]R="!F
M;W(@2%144"!T<F%N<W!O<G0L('!R;WAI97,@86YD(&%U=&AE;G1I8V%T:6]N
M+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!,
M:6-E;G-E(&ES(&=R86YT960@=&\@=7-E(&]R(&UO9&EF>2!T:&ES('-O9G1W
M87)E"B`J("@B6$U,+5)00R!F;W(@4$A0(BD@9F]R(&-O;6UE<F-I86P@;W(@
M;F]N+6-O;6UE<F-I86P@=7-E('!R;W9I9&5D('1H90H@*B!C;W!Y<FEG:'0@
M;V8@=&AE(&%U=&AO<B!I<R!P<F5S97)V960@:6X@86YY(&1I<W1R:6)U=&5D
M(&]R(&1E<FEV871I=F4@=V]R:RX*("H*("H@5$A)4R!33T945T%212!)4R!0
M4D]6241%1"!"62!42$4@05542$]2(")!4R!)4R(@04Y$($%.62!%6%!215-3
M140@3U(*("H@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.
M3U0@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4PH@*B!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%($%212!$25-#3$%)345$+@H@*B!)3B!.3R!%5D5.5"!32$%,3"!4
M2$4@05542$]2($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L
M"B`J($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(@0T].4T51
M545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55`H@*B!.3U0@3$E-251%
M1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)6
M24-%4SL@3$]34R!/1B!54T4L"B`J($1!5$$L($]2(%!23T9)5%,[($]2($)5
M4TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.
M60H@*B!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4"B`J("A)3D-,541)3D<@3D5'
M3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@
M3T8@5$A%(%5312!/1@H@*B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3
M140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`
M8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)0
M0PH@*B!`875T:&]R("`@("!%9&0@1'5M8FEL;"`\961D0'5S969U;&EN8RYC
M;VT^"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG0'!H<"YN970^
M"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY.2TR,#`Q($5D9"!$=6UB:6QL+"`R,#`Q
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M4V5R=F5R+G!H<"QV(#$N,S,@,C`P-B\P,2\Q-"`R,CHS,#HS,2!D86YI96QC
M($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]834Q?4E!#"B`J+PH*"B\J*@H@*B!0=6QL(&EN('1H92!834Q?4E!#
M(&-L87-S"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]24$,N<&AP)SL*"@HO*BH*
M("H@<VEG;F%T=7)E(&9O<B!S>7-T96TN;&ES=$UE=&AO9',Z(')E='5R;B`]
M(&%R<F%Y+`H@*B!P87)A;65T97)S(#T@82!S=')I;F<@;W(@;F]T:&EN9PH@
M*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]L:7-T
M365T:&]D<U]S:6<G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VQI
M<W1-971H;V1S7W-I9R==(#T@87)R87DH"B`@("!A<G)A>2@D1TQ/0D%,4ULG
M6$U,7U)00U]!<G)A>2==+`H@("`@("`@("`@)$=,3T)!3%-;)UA-3%]24$-?
M4W1R:6YG)UT*("`@("DL"B`@("!A<G)A>2@D1TQ/0D%,4ULG6$U,7U)00U]!
M<G)A>2==*0HI.PH*+RHJ"B`J(&1O8W-T<FEN9R!F;W(@<WES=&5M+FQI<W1-
M971H;V1S"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7U-E
M<G9E<E]L:7-T365T:&]D<U]D;V,G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?
M4V5R=F5R7VQI<W1-971H;V1S7V1O8R==(#T@)U1H:7,@;65T:&]D(&QI<W1S
M(&%L;"!T:&4G"B`@("`@("`@+B`G(&UE=&AO9',@=&AA="!T:&4@6$U,+5)0
M0R!S97)V97(@:VYO=W,@:&]W('1O(&1I<W!A=&-H)SL*"B\J*@H@*B!S:6=N
M871U<F4@9F]R('-Y<W1E;2YM971H;V13:6=N871U<F4Z(')E='5R;B`](&%R
M<F%Y+`H@*B!P87)A;65T97)S(#T@<W1R:6YG"B`J($!G;&]B86P@87)R87D@
M)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9%-I9VYA='5R95]S:6<G
M70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9%-I9VYA='5R
M95]S:6<G72`](&%R<F%Y*`H@("`@87)R87DH)$=,3T)!3%-;)UA-3%]24$-?
M07)R87DG72P*("`@("`@("`@("1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R==
M"B`@("`I"BD["@HO*BH*("H@9&]C<W1R:6YG(&9O<B!S>7-T96TN;65T:&]D
M4VEG;F%T=7)E"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#
M7U-E<G9E<E]M971H;V13:6=N871U<F5?9&]C)UT*("HO"B1'3$]"04Q36R=8
M34Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?9&]C)UT@/2`G4F5T=7)N
M<R!A;B!A<G)A>2!O9B!K;F]W;B<*("`@("`@("`N("<@<VEG;F%T=7)E<R`H
M86X@87)R87D@;V8@87)R87ES*2!F;W(@=&AE(&UE=&AO9"!N86UE('!A<W-E
M9"X@268G"B`@("`@("`@+B`G(&YO('-I9VYA='5R97,@87)E(&MN;W=N+"!R
M971U<FYS(&$@;F]N92UA<G)A>2`H=&5S="!F;W(@='EP92`A/2<*("`@("`@
M("`N("<@87)R87D@=&\@9&5T96-T(&UI<W-I;F<@<VEG;F%T=7)E*2<["@HO
M*BH*("H@<VEG;F%T=7)E(&9O<B!S>7-T96TN;65T:&]D2&5L<#H@<F5T=7)N
M(#T@<W1R:6YG+`H@*B!P87)A;65T97)S(#T@<W1R:6YG"B`J($!G;&]B86P@
M87)R87D@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'!?<VEG
M)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V1(96QP7W-I
M9R==(#T@87)R87DH"B`@("!A<G)A>2@D1TQ/0D%,4ULG6$U,7U)00U]3=')I
M;F<G72P*("`@("`@("`@("1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R=="B`@
M("`I"BD["@HO*BH*("H@9&]C<W1R:6YG(&9O<B!M971H;V1(96QP"B`J($!G
M;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V1(
M96QP7V1O8R=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;65T:&]D
M2&5L<%]D;V,G72`]("=2971U<FYS(&AE;'`@=&5X="!I9B!D969I;F5D)PH@
M("`@("`@("X@)R!F;W(@=&AE(&UE=&AO9"!P87-S960L(&]T:&5R=VES92!R
M971U<FYS(&%N(&5M<'1Y('-T<FEN9R<["@HO*BH*("H@9&ES<&%T8V@@;6%P
M(&9O<B!T:&4@875T;VUA=&EC86QL>2!D96-L87)E9"!834PM4E!#(&UE=&AO
M9',N"B`J($!G;&]B86P@87)R87D@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R
M7V1M87`G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7V1M87`G72`]
M(&%R<F%Y*`H@("`@)W-Y<W1E;2YL:7-T365T:&]D<R<@/3X@87)R87DH"B`@
M("`@("`@)V9U;F-T:6]N)R`@/3X@)UA-3%]24$-?4V5R=F5R7VQI<W1-971H
M;V1S)RP*("`@("`@("`G<VEG;F%T=7)E)R`]/B`D1TQ/0D%,4ULG6$U,7U)0
M0U]397)V97)?;&ES=$UE=&AO9'-?<VEG)UTL"B`@("`@("`@)V1O8W-T<FEN
M9R<@/3X@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VQI<W1-971H;V1S7V1O
M8R=="B`@("`I+`H@("`@)W-Y<W1E;2YM971H;V1(96QP)R`]/B!A<G)A>2@*
M("`@("`@("`G9G5N8W1I;VXG("`]/B`G6$U,7U)00U]397)V97)?;65T:&]D
M2&5L<"<L"B`@("`@("`@)W-I9VYA='5R92<@/3X@)$=,3T)!3%-;)UA-3%]2
M4$-?4V5R=F5R7VUE=&AO9$AE;'!?<VEG)UTL"B`@("`@("`@)V1O8W-T<FEN
M9R<@/3X@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'!?9&]C
M)UT*("`@("DL"B`@("`G<WES=&5M+FUE=&AO9%-I9VYA='5R92<@/3X@87)R
M87DH"B`@("`@("`@)V9U;F-T:6]N)R`@/3X@)UA-3%]24$-?4V5R=F5R7VUE
M=&AO9%-I9VYA='5R92<L"B`@("`@("`@)W-I9VYA='5R92<@/3X@)$=,3T)!
M3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9%-I9VYA='5R95]S:6<G72P*("`@
M("`@("`G9&]C<W1R:6YG)R`]/B`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?
M;65T:&]D4VEG;F%T=7)E7V1O8R=="B`@("`I"BD["@HO*BH*("H@0&=L;V)A
M;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7V1E8G5G:6YF;R==
M"B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]397)V97)?9&5B=6=I;F9O)UT@/2`G
M)SL*"@HO*BH*("H@3&ES=',@86QL('1H92!M971H;V1S('1H870@=&AE(%A-
M3"U24$,@<V5R=F5R(&MN;W=S(&AO=R!T;R!D:7-P871C:`H@*@H@*B!`<F5T
M=7)N(&]B:F5C="`@82!N97<@6$U,7U)00U]297-P;VYS92!O8FIE8W0*("HO
M"F9U;F-T:6]N(%A-3%]24$-?4V5R=F5R7VQI<W1-971H;V1S*"1S97)V97(L
M("1M*0I["B`@("!G;&]B86P@)%A-3%]24$-?97)R+"`D6$U,7U)00U]S='(L
M("1834Q?4E!#7U-E<G9E<E]D;6%P.PH*("`@("1V(#T@;F5W(%A-3%]24$-?
M5F%L=64H*3L*("`@("1O=71!<B`](&%R<F%Y*"D["B`@("!F;W)E86-H("@D
M<V5R=F5R+3YD;6%P(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("1O=71!
M<EM=(#T@;F5W(%A-3%]24$-?5F%L=64H)&ME>2P@)W-T<FEN9R<I.PH@("`@
M?0H@("`@9F]R96%C:"`H)%A-3%]24$-?4V5R=F5R7V1M87`@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@)&]U=$%R6UT@/2!N97<@6$U,7U)00U]686QU
M92@D:V5Y+"`G<W1R:6YG)RD["B`@("!]"B`@("`D=BT^861D07)R87DH)&]U
M=$%R*3L*("`@(')E='5R;B!N97<@6$U,7U)00U]297-P;VYS92@D=BD["GT*
M"B\J*@H@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&MN;W=N('-I9VYA='5R97,@
M*&%N(&%R<F%Y(&]F(&%R<F%Y<RD*("H@9F]R('1H92!G:79E;B!M971H;V0*
M("H*("H@268@;F\@<VEG;F%T=7)E<R!A<F4@:VYO=VXL(')E='5R;G,@82!N
M;VYE+6%R<F%Y"B`J("AT97-T(&9O<B!T>7!E("$](&%R<F%Y('1O(&1E=&5C
M="!M:7-S:6YG('-I9VYA='5R92D*("H*("H@0')E='5R;B!O8FIE8W0@(&$@
M;F5W(%A-3%]24$-?4F5S<&]N<V4@;V)J96-T"B`J+PIF=6YC=&EO;B!834Q?
M4E!#7U-E<G9E<E]M971H;V13:6=N871U<F4H)'-E<G9E<BP@)&TI"GL*("`@
M(&=L;V)A;"`D6$U,7U)00U]E<G(L("1834Q?4E!#7W-T<BP@)%A-3%]24$-?
M4V5R=F5R7V1M87`["@H@("`@)&UE=&A.86UE(#T@)&TM/F=E=%!A<F%M*#`I
M.PH@("`@)&UE=&A.86UE(#T@)&UE=&A.86UE+3YS8V%L87)V86PH*3L*("`@
M(&EF("AS=')P;W,H)&UE=&A.86UE+"`G<WES=&5M+B<I(#T]/2`P*2!["B`@
M("`@("`@)&1M87`@/2`D6$U,7U)00U]397)V97)?9&UA<#L*("`@("`@("`D
M<WES0V%L;"`](#$["B`@("!](&5L<V4@>PH@("`@("`@("1D;6%P(#T@)'-E
M<G9E<BT^9&UA<#L*("`@("`@("`D<WES0V%L;"`](#`["B`@("!]"B`@("`O
M+R`@<')I;G0@(CPA+2T@)'MM971H3F%M97T@+2T^7&XB.PH@("`@:68@*&ES
M<V5T*"1D;6%P6R1M971H3F%M95TI*2!["B`@("`@("`@:68@*"1D;6%P6R1M
M971H3F%M95U;)W-I9VYA='5R92==*2!["B`@("`@("`@("`@("1S:6=S(#T@
M87)R87DH*3L*("`@("`@("`@("`@)'1H97-I9W,@/2`D9&UA<%LD;65T:$YA
M;65=6R=S:6=N871U<F4G73L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@<VEZ96]F*"1T:&5S:6=S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M)&-U<G-I9R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D:6Y3:6<@/2`D
M=&AE<VEG<ULD:5T["B`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@
M/"!S:7IE;V8H)&EN4VEG*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("1C=7)S:6=;72`](&YE=R!834Q?4E!#7U9A;'5E*"1I;E-I9ULD:ETL("=S
M=')I;F<G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S
M:6=S6UT@/2!N97<@6$U,7U)00U]686QU92@D8W5R<VEG+"`G87)R87DG*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E
M<W!O;G-E*&YE=R!834Q?4E!#7U9A;'5E*"1S:6=S+"`G87)R87DG*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]2
M97-P;VYS92AN97<@6$U,7U)00U]686QU92@G=6YD968G+"`G<W1R:6YG)RDI
M.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@)'(@/2!N97<@6$U,
M7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);)VEN=')O<W!E8W1?=6YK
M;F]W;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%A-
M3%]24$-?<W1R6R=I;G1R;W-P96-T7W5N:VYO=VXG72D["B`@("!]"B`@("!R
M971U<FX@)'(["GT*"B\J*@H@*B!2971U<FYS(&AE;'`@=&5X="!I9B!D969I
M;F5D(&9O<B!T:&4@;65T:&]D('!A<W-E9"P@;W1H97)W:7-E(')E='5R;G,*
M("H@86X@96UP='D@<W1R:6YG"B`J"B`J($!R971U<FX@;V)J96-T("!A(&YE
M=R!834Q?4E!#7U)E<W!O;G-E(&]B:F5C=`H@*B\*9G5N8W1I;VX@6$U,7U)0
M0U]397)V97)?;65T:&]D2&5L<"@D<V5R=F5R+"`D;2D*>PH@("`@9VQO8F%L
M("1834Q?4E!#7V5R<BP@)%A-3%]24$-?<W1R+"`D6$U,7U)00U]397)V97)?
M9&UA<#L*"B`@("`D;65T:$YA;64@/2`D;2T^9V5T4&%R86TH,"D["B`@("`D
M;65T:$YA;64@/2`D;65T:$YA;64M/G-C86QA<G9A;"@I.PH@("`@:68@*'-T
M<G!O<R@D;65T:$YA;64L("=S>7-T96TN)RD@/3T](#`I('L*("`@("`@("`D
M9&UA<"`]("1834Q?4E!#7U-E<G9E<E]D;6%P.PH@("`@("`@("1S>7-#86QL
M(#T@,3L*("`@('T@96QS92!["B`@("`@("`@)&1M87`@/2`D<V5R=F5R+3YD
M;6%P.PH@("`@("`@("1S>7-#86QL(#T@,#L*("`@('T*"B`@("!I9B`H:7-S
M970H)&1M87!;)&UE=&A.86UE72DI('L*("`@("`@("!I9B`H)&1M87!;)&UE
M=&A.86UE75LG9&]C<W1R:6YG)UTI('L*("`@("`@("`@("`@)'(@/2!N97<@
M6$U,7U)00U]297-P;VYS92AN97<@6$U,7U)00U]686QU92@D9&UA<%LD;65T
M:$YA;65=6R=D;V-S=')I;F<G72DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T<FEN9R<I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?
M4F5S<&]N<V4H;F5W(%A-3%]24$-?5F%L=64H)R<L("=S=')I;F<G*2D["B`@
M("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`D<B`](&YE=R!834Q?4E!#
M7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG:6YT<F]S<&5C=%]U;FMN;W=N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D6$U,
M7U)00U]S=');)VEN=')O<W!E8W1?=6YK;F]W;B==*3L*("`@('T*("`@(')E
M='5R;B`D<CL*?0H*+RHJ"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@
M6$U,7U)00U]397)V97)?9&5B=6=M<V<H)&TI"GL*("`@(&=L;V)A;"`D6$U,
M7U)00U]397)V97)?9&5B=6=I;F9O.PH@("`@)%A-3%]24$-?4V5R=F5R7V1E
M8G5G:6YF;R`]("1834Q?4E!#7U-E<G9E<E]D96)U9VEN9F\@+B`D;2`N(")<
M;B(["GT*"@HO*BH*("H@02!S97)V97(@9F]R(')E8V5I=FEN9R!A;F0@<F5P
M;'EI;F<@=&\@6$U,(%)00R!R97%U97-T<PH@*@H@*B`\8V]D93X*("H@)'-E
M<G9E<B`](&YE=R!834Q?4E!#7U-E<G9E<B@*("H@("`@(&%R<F%Y*`H@*B`@
M("`@("`@("=I<V%N."<@/3X*("H@("`@("`@("`@("`@87)R87DH"B`J("`@
M("`@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=I<U\X)RP*("H@("`@("`@
M("`@("`@("`@("=S:6=N871U<F4G(#T^"B`J("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V)O;VQE86XG+"`G:6YT)RDL"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G8F]O;&5A;B<L("=I;G0G+"`G8F]O;&5A;B<I+`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O;VQE86XG+"`G<W1R:6YG
M)RDL"B`J("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8F]O;&5A
M;B<L("=S=')I;F<G+"`G8F]O;&5A;B<I+`H@*B`@("`@("`@("`@("`@("`@
M("`@("`I+`H@*B`@("`@("`@("`@("`@("`@)V1O8W-T<FEN9R<@/3X@)TES
M('1H92!V86QU92!A;B`X/R<*("H@("`@("`@("`@("`@*2P*("H@("`@("DL
M"B`J("`@("`Q+`H@*B`@("`@,`H@*B`I.R`*("H@/"]C;V1E/@H@*@H@*B!`
M8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)0
M0PH@*B!`875T:&]R("`@("!%9&0@1'5M8FEL;"`\961D0'5S969U;&EN8RYC
M;VT^"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG0'!H<"YN970^
M"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY.2TR,#`Q($5D9"!$=6UB:6QL+"`R,#`Q
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C0N.`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O6$U,7U)00PH@*B\*8VQA<W,@6$U,7U)00U]397)V97(*>PH@("`@+RHJ
M"B`@("`@*B!4:&4@9&ES<&%T8V@@;6%P+"!L:7-T:6YG('1H92!M971H;V1S
M('1H:7,@<V5R=F5R('!R;W9I9&5S+@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&1M87`@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M5&AE('!R97-E;G0@<F5S<&]N<V4G<R!E;F-O9&EN9PH@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J($!S964@6$U,7U)00U]-97-S86=E.CIG971%;F-O9&EN
M9R@I"B`@("`@*B\*("`@('9A<B`D96YC;V1I;F<@/2`G)SL*"B`@("`O*BH*
M("`@("`J($1E8G5G(&UO9&4@*#`@/2!O9F8L(#$@/2!O;BD*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)&1E8G5G(#T@,#L*"B`@("`O
M*BH*("`@("`J(%1H92!R97-P;VYS92=S($A45%`@:&5A9&5R<PH@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1S97)V97)?:&5A9&5R<R`]
M("<G.PH*("`@("\J*@H@("`@("H@5&AE(')E<W!O;G-E)W,@6$U,('!A>6QO
M860*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<V5R=F5R
M7W!A>6QO860@/2`G)SL*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B!F
M;W(@=&AE(%A-3%]24$-?4V5R=F5R(&-L87-S"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1D:7-P36%P("`@=&AE(&1I<W!A=&-H(&UA<"X@06X@87-S
M;V-I871I=F4@87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!E>'!L86EN:6YG(&5A8V@@9G5N8W1I;VXN(%1H92!K97ES(&]F('1H92!M
M86EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87D@87)E
M('1H92!P<F]C961U<F4@;F%M97,@=7-E9"!B>2!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!C;&EE;G1S+B!4:&4@=F%L=64@:7,@86YO
M=&AE<B!A<W-O8VEA=&EV92!A<G)A>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H870@8V]N=&%I;G,@=7`@=&\@=&AR964@96QE;65N=',Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`K(%1H92`G9G5N
M8W1I;VXG(&5L96UE;G0G<R!V86QU92!I<R!T:&4@;F%M90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!O9B!T:&4@9G5N8W1I;VX@;W(@
M;65T:&]D('1H870@9V5T<R!C86QL960N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%1O(&1E9FEN92!A(&-L87-S)R!M971H;V0Z("=C
M;&%S<SHZ;65T:&]D)RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@5&AE("=S:6=N871U<F4G(&5L96UE;G0@*&]P=&EO;F%L*2!I<R!A
M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2!D
M97-C<FEB:6YG('1H92!R971U<FX@=F%L=65S(&%N9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K(%1H92`G9&]C<W1R:6YG)R!E;&5M
M96YT("AO<'1I;VYA;"D@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')I;F<@9&5S8W)I8FEN9R!W:&%T('1H92!M971H;V0@
M9&]E<PH@("`@("H@0'!A<F%M(&EN="`D<V5R=FEC94YO=R`@<VAO=6QD('1H
M92!(5%10(')E<W!O;G-E(&)E('-E;G0@;F]W/PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("@Q(#T@>65S+"`P(#T@;F\I"B`@("`@*B!`<&%R
M86T@:6YT("1D96)U9R`@("`@("!S:&]U;&0@9&5B=6<@;W5T<'5T(&)E(&1I
M<W!L87EE9#\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`H,2`]
M('EE<RP@,"`](&YO*0H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!834Q?4E!#7U-E<G9E<B@D9&ES<$UA<"P@)'-E
M<G9I8V5.;W<@/2`Q+"`D9&5B=6<@/2`P*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D2%144%]205=?4$]35%]$051!.PH*("`@("`@("!I9B`H)&1E8G5G*2![
M"B`@("`@("`@("`@("1T:&ES+3YD96)U9R`](#$["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/F1E8G5G(#T@,#L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YD;6%P(#T@)&1I<W!-87`["@H@("`@("`@(&EF("@D
M<V5R=FEC94YO=RD@>PH@("`@("`@("`@("`D=&AI<RT^<V5R=FEC92@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YC<F5A=&5397)V
M97)087EL;V%D*"D["B`@("`@("`@("`@("1T:&ES+3YC<F5A=&5397)V97)(
M96%D97)S*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!D96)U9R!I;F9O<FUA=&EO;B!I9B!D96)U9R!D
M96)U9R!M;V1E(&ES(&]N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ
M941E8G5G*"D*("`@('L*("`@("`@("!G;&]B86P@)%A-3%]24$-?4V5R=F5R
M7V1E8G5G:6YF;RP@)$A45%!?4D%77U!/4U1?1$%403L*"B`@("`@("`@:68@
M*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("!834Q?4E!#7U-E<G9E<E]D
M96)U9VUS9R@G=G9V(%!/4U0@1$%402!214-%259%1"!"62!315)615(@=G9V
M)R`N(")<;B(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`D2%144%]205=?4$]35%]$051!"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@(EQN(B`N("=>7EX@14Y$(%!/4U0@1$%402!>7EXG
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D6$U,7U)00U]397)V97)?9&5B
M=6=I;F9O("$]("<G*2!["B`@("`@("`@("`@(')E='5R;B`B/"$M+2!014%2
M(%A-3%]24$,@4T525D52($1%0E5'($E.1D\Z7&Y<;B(*("`@("`@("`@("`@
M("`@("`@("X@<')E9U]R97!L86-E*"<O+2@_/2TI+R<L("<M("<L("1834Q?
M4E!#7U-E<G9E<E]D96)U9VEN9F\I"B`@("`@("`@("`@("`@("`@("`N("(M
M+3Y<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F1S('1H92!R
M97-P;VYS90H@("`@("H*("`@("`J(%1H92!E;F-O9&EN9R!A;F0@8V]N=&5N
M="UT>7!E(&%R92!D971E<FUI;F5D(&)Y"B`@("`@*B!834Q?4E!#7TUE<W-A
M9V4Z.F=E=$5N8V]D:6YG*"D*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J"B`@("`@*B!`=7-E<R!834Q?4E!#7U-E<G9E<CHZ8W)E871E4V5R
M=F5R4&%Y;&]A9"@I+`H@("`@("H@("`@("`@6$U,7U)00U]397)V97(Z.F-R
M96%T95-E<G9E<DAE861E<G,H*0H@("`@("HO"B`@("!F=6YC=&EO;B!S97)V
M:6-E*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YS97)V97)?<&%Y;&]A
M9"D@>PH@("`@("`@("`@("`D=&AI<RT^8W)E871E4V5R=F5R4&%Y;&]A9"@I
M.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES+3YS97)V97)?:&5A9&5R
M<RD@>PH@("`@("`@("`@("`D=&AI<RT^8W)E871E4V5R=F5R2&5A9&5R<R@I
M.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B`D<V5R=F5R7VAE
M861E<G,@;F5E9',@=&\@<F5M86EN(&$@<W1R:6YG(&9O<B!C;VUP871I8FEL
M:71Y('=I=&@*("`@("`@("`@*B!O;&0@<V-R:7!T<R!U<VEN9R!T:&ES('!A
M8VMA9V4L(&)U="!02%`@-"XT+C(@;F\@;&]N9V5R(&%L;&]W<PH@("`@("`@
M("`J(&QI;F4@8G)E86MS(&EN(&AE861E<B@I(&-A;&QS+B`@4V\L('=E('-P
M;&ET(&5A8V@@:&5A9&5R(&EN=&\*("`@("`@("`@*B!A;B!I;F1I=FED=6%L
M(&-A;&PN("!4:&4@:6YI=&EA;"!R97!L86-E(&AA;F1L97,@=&AE(&]F9B!C
M:&%N8V4*("`@("`@("`@*B!T:&%T('-O;65O;F4@8V]M<&]S960@82!S:6YG
M;&4@:&5A9&5R('=I=&@@;75L=&EP;&4@;&EN97,L('=H:6-H"B`@("`@("`@
M("H@=&AE(%)&0W,@86QL;W<N"B`@("`@("`@("HO"B`@("`@("`@)'1H:7,M
M/G-E<G9E<E]H96%D97)S(#T@<')E9U]R97!L86-E*"(O6UQR7&Y=*UL@7'1=
M*R\B+"`G("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1R:6TH)'1H:7,M/G-E<G9E<E]H96%D97)S*2D["B`@("`@
M("`@)&AE861E<G,@/2!P<F5G7W-P;&ET*"(O6UQR7&Y=*R\B+"`D=&AI<RT^
M<V5R=F5R7VAE861E<G,I.PH@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S
M("1H96%D97(I"B`@("`@("`@>PH@("`@("`@("`@("!H96%D97(H)&AE861E
M<BD["B`@("`@("`@?0H*("`@("`@("!P<FEN="`D=&AI<RT^<V5R=F5R7W!A
M>6QO860["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE('!A
M>6QO860@86YD('!U=',@:70@:6X@=&AE("1S97)V97)?<&%Y;&]A9"!P<F]P
M97)T>0H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J
M($!U<V5S(%A-3%]24$-?4V5R=F5R.CIP87)S95)E<75E<W0H*2P@6$U,7U)0
M0U]397)V97(Z.B1E;F-O9&EN9RP*("`@("`J("`@("`@(%A-3%]24$-?4F5S
M<&]N<V4Z.G-E<FEA;&EZ92@I+"!834Q?4E!#7U-E<G9E<CHZ<V5R:6%L:7IE
M1&5B=6<H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397)V97)087EL
M;V%D*"D*("`@('L*("`@("`@("`D<B`]("1T:&ES+3YP87)S95)E<75E<W0H
M*3L*("`@("`@("`D=&AI<RT^<V5R=F5R7W!A>6QO860@/2`G/#]X;6P@=F5R
M<VEO;CTB,2XP(B!E;F-O9&EN9STB)PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("1T:&ES+3YE;F-O9&EN9R`N("<B/SXG("X@(EQN(@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YS97)I86QI>F5$
M96)U9R@I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'(M/G-E
M<FEA;&EZ92@I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T
M:&4@2%144"!H96%D97)S(&%N9"!P=71S('1H96T@:6X@=&AE("1S97)V97)?
M:&5A9&5R<PH@("`@("H@<')O<&5R='D*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%12544@:68@;VMA>2P@1D%,4T4@:68@)'-E<G9E<E]P87EL
M;V%D(&ES;B=T('-E="X*("`@("`J"B`@("`@*B!`=7-E<R!834Q?4E!#7U-E
M<G9E<CHZ8W)E871E4V5R=F5R4&%Y;&]A9"@I+`H@("`@("H@("`@("`@6$U,
M7U)00U]397)V97(Z.B1S97)V97)?:&5A9&5R<PH@("`@("HO"B`@("!F=6YC
M=&EO;B!C<F5A=&5397)V97)(96%D97)S*"D*("`@('L*("`@("`@("!I9B`H
M(21T:&ES+3YS97)V97)?<&%Y;&]A9"D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YS97)V97)?:&5A9&5R
M<R`]("=#;VYT96YT+4QE;F=T:#H@)PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N('-T<FQE;B@D=&AI<RT^<V5R=F5R7W!A>6QO860I("X@(EQR
M7&XB"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)T-O;G1E;G0M
M5'EP93H@=&5X="]X;6P[)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("<@8VAA<G-E=#TG("X@)'1H:7,M/F5N8V]D:6YG.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!A<G)A
M>0H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I9GE3:6=N871U<F4H)&EN+"`D
M<VEG*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D
M<VEG*3L@)&DK*RD@>PH@("`@("`@("`@("`O+R!C:&5C:R!E86-H('!O<W-I
M8FQE('-I9VYA='5R92!I;B!T=7)N"B`@("`@("`@("`@("1C=7)S:6<@/2`D
M<VEG6R1I73L*("`@("`@("`@("`@:68@*'-I>F5O9B@D8W5R<VEG*2`]/2`D
M:6XM/F=E=$YU;5!A<F%M<R@I("L@,2D@>PH@("`@("`@("`@("`@("`@)&ET
M<T]+(#T@,3L*("`@("`@("`@("`@("`@(&9O<B`H)&X@/2`P.R`D;B`\("1I
M;BT^9V5T3G5M4&%R86US*"D[("1N*RLI('L*("`@("`@("`@("`@("`@("`@
M("`D<"`]("1I;BT^9V5T4&%R86TH)&XI.PH@("`@("`@("`@("`@("`@("`@
M("\O('!R:6YT("(\(2TM("1P("TM/EQN(CL*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'`M/FMI;F1/9B@I(#T]("=S8V%L87(G*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1P="`]("1P+3YS8V%L87)T>7`H*3L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<'0@/2`D<"T^:VEN9$]F*"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("\O("1N*S$@87,@9FER<W0@='EP92!O9B!S:6<@
M:7,@<F5T=7)N('1Y<&4*("`@("`@("`@("`@("`@("`@("!I9B`H)'!T("$]
M("1C=7)S:6=;)&XK,5TI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ET
M<T]+(#T@,#L*("`@("`@("`@("`@("`@("`@("`@("`@)'!N;R`]("1N*S$[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1W86YT960@/2`D8W5R<VEG6R1N
M*S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`D9V]T(#T@)'!T.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&ET
M<T]+*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*#$I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("AI<W-E="@D=V%N=&5D*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH,"P@(E=A;G1E9"`D>W=A;G1E9'TL(&=O="`D>V=O='T@870@<&%R
M86T@)'MP;F]](BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%L
M;&]W960@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<VEG(&%S
M("1V86PI('L*("`@("`@("`@("`@("`@(&5N9"@D=F%L*3L*("`@("`@("`@
M("`@("`@("1A;&QO=V5D6UT@/2!K97DH)'9A;"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&%L;&]W960@/2!A<G)A>5]U;FEQ=64H)&%L;&]W960I
M.PH@("`@("`@("`@("`D;&%S="`](&-O=6YT*"1A;&QO=V5D*2`M(#$["B`@
M("`@("`@("`@(&EF("@D;&%S="`^(#`I('L*("`@("`@("`@("`@("`@("1A
M;&QO=V5D6R1L87-T72`]("=O<B`G("X@)&%L;&]W961;)&QA<W1=.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@P+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)U-I9VYA='5R92!P97)M:71S("<@+B!I;7!L
M;V1E*"<L("<L("1A;&QO=V5D*0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("X@)R!P87)A;65T97)S(&)U="!T:&4@<F5Q=65S="!H860@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)&EN+3YG971.=6U0
M87)A;7,H*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E
M='5R;B!O8FIE8W0@(&$@;F5W(%A-3%]24$-?4F5S<&]N<V4@;V)J96-T"B`@
M("`@*@H@("`@("H@0'5S97,@6$U,7U)00U]-97-S86=E.CIG971%;F-O9&EN
M9R@I+"!834Q?4E!#7U-E<G9E<CHZ)&5N8V]D:6YG"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!A<G-E4F5Q=65S="@D9&%T82`]("<G*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D6$U,7U)00U]X:"P@)$A45%!?4D%77U!/4U1?1$%402P*("`@
M("`@("`@("`@("`@("1834Q?4E!#7V5R<BP@)%A-3%]24$-?<W1R+"`D6$U,
M7U)00U]E<G)X;6PL"B`@("`@("`@("`@("`@("`D6$U,7U)00U]D969E;F-O
M9&EN9RP@)%A-3%]24$-?4V5R=F5R7V1M87`["@H@("`@("`@(&EF("@D9&%T
M82`]/2`G)RD@>PH@("`@("`@("`@("`D9&%T82`]("1(5%107U)!5U]03U-4
M7T1!5$$["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^96YC;V1I;F<@/2!8
M34Q?4E!#7TUE<W-A9V4Z.F=E=$5N8V]D:6YG*"1D871A*3L*("`@("`@("`D
M<&%R<V5R7W)E<V]U<F-E(#T@>&UL7W!A<G-E<E]C<F5A=&4H)'1H:7,M/F5N
M8V]D:6YG*3L*("`@("`@("`D<&%R<V5R(#T@*&EN="D@)'!A<G-E<E]R97-O
M=7)C93L*"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<ET@/2!A<G)A>2@I
M.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=C;2==("`@("`](#`[
M"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9B==("`@(#T@,#L*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<&%R86US)UT@/2!A<G)A
M>2@I.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=M971H;V0G72`]
M("<G.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=S=&%C:R==(#T@
M87)R87DH*3L)"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E
M<W1A8VLG72`](&%R<F%Y*"D["0H*("`@("`@("`D<&QI<W0@/2`G)SL*"B`@
M("`@("`@+R\@9&5C;VUP;W-E(&EN8V]M:6YG(%A-3"!I;G1O(')E<75E<W0@
M<W1R=6-T=7)E"@H@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D<&%R
M<V5R7W)E<V]U<F-E+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@=')U92D[
M"B`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'!A<G-E<E]R97-O
M=7)C92P@)UA-3%]24$-?<V4G+"`G6$U,7U)00U]E92<I.PH@("`@("`@('AM
M;%]S971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D<&%R<V5R7W)E<V]U<F-E
M+"`G6$U,7U)00U]C9"<I.PH@("`@("`@(&EF("@A>&UL7W!A<G-E*"1P87)S
M97)?<F5S;W5R8V4L("1D871A+"`Q*2D@>PH@("`@("`@("`@("`O+R!R971U
M<FX@6$U,(&5R<F]R(&%S(&$@9F%U;'1#;V1E"B`@("`@("`@("`@("1R(#T@
M;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D6$U,7U)00U]E<G)X;6PK>&UL7V=E=%]E<G)O
M<E]C;V1E*"1P87)S97)?<F5S;W5R8V4I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-P<FEN=&8H)UA-3"!E<G)O<CH@)7,@870@
M;&EN92`E9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!X;6Q?97)R;W)?<W1R:6YG*'AM;%]G971?97)R;W)?8V]D
M92@D<&%R<V5R7W)E<V]U<F-E*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?;&EN95]N
M=6UB97(H)'!A<G-E<E]R97-O=7)C92DI*3L*("`@("`@("`@("`@>&UL7W!A
M<G-E<E]F<F5E*"1P87)S97)?<F5S;W5R8V4I.PH@("`@("`@('T@96QS96EF
M("@D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F)UT^,2D@>PH@("`@("`@("`@
M("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)%A-3%]24$-?97)R6R=I;G9A;&ED
M7W)E<75E<W0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D6$U,7U)00U]S=');)VEN=F%L:61?<F5Q=65S="=="B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G.B`G"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D6$U,7U)00U]X:%LD
M<&%R<V5R75LG:7-F7W)E87-O;B==*3L*("`@("`@("`@("`@>&UL7W!A<G-E
M<E]F<F5E*"1P87)S97)?<F5S;W5R8V4I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R<V5R7W)E<V]U<F-E*3L*
M("`@("`@("`@("`@)&T@/2!N97<@6$U,7U)00U]-97-S86=E*"1834Q?4E!#
M7WAH6R1P87)S97)=6R=M971H;V0G72D["B`@("`@("`@("`@("\O(&YO=R!A
M9&0@<&%R86UE=&5R<R!I;@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!S:7IE;V8H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W!A<F%M<R==*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@+R\@<')I;G0@)SPA+2T@)R`N("1834Q?
M4E!#7WAH6R1P87)S97)=6R=P87)A;7,G75LD:5TN("(M+3Y<;B(["B`@("`@
M("`@("`@("`@("`D<&QI<W0@+CT@(B1I("T@(B`N('9A<E]E>'!O<G0H)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W!A<F%M<R==6R1I72P@=')U92D@+B`B(%QN
M(CL*("`@("`@("`@("`@("`@("1M+3YA9&1087)A;2@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG<&%R86US)UU;)&E=*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@("`@6$U,
M7U)00U]397)V97)?9&5B=6=M<V<H)'!L:7-T*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@;F]W('1O(&1E86P@=VET:"!T:&4@;65T:&]D"B`@
M("`@("`@("`@("1M971H3F%M92`]("1834Q?4E!#7WAH6R1P87)S97)=6R=M
M971H;V0G73L*("`@("`@("`@("`@:68@*'-T<G!O<R@D;65T:$YA;64L("=S
M>7-T96TN)RD@/3T](#`I('L*("`@("`@("`@("`@("`@("1D;6%P(#T@)%A-
M3%]24$-?4V5R=F5R7V1M87`["B`@("`@("`@("`@("`@("`D<WES0V%L;"`]
M(#$["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&UA
M<"`]("1T:&ES+3YD;6%P.PH@("`@("`@("`@("`@("`@)'-Y<T-A;&P@/2`P
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-S970H)&1M87!;
M)&UE=&A.86UE75LG9G5N8W1I;VXG72D*("`@("`@("`@("`@("`@("8F(&ES
M7W-T<FEN9R@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==*0H@("`@("`@
M("`@("`@("`@)B8@<W1R<&]S*"1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N
M)UTL("<Z.B<I("$]/2!F86QS92D*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@)&1M87!;)&UE=&A.86UE75LG9G5N8W1I;VXG72`]"B`@("`@("`@
M("`@("`@("`@("`@("`@(&5X<&QO9&4H)SHZ)RP@)&1M87!;)&UE=&A.86UE
M75LG9G5N8W1I;VXG72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("AI<W-E="@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==*0H@("`@("`@
M("`@("`@("`@)B8@:7-?8V%L;&%B;&4H)&1M87!;)&UE=&A.86UE75LG9G5N
M8W1I;VXG72DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("\O(&1I
M<W!A=&-H(&EF(&5X:7-T<PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M;6%P6R1M971H3F%M95U;)W-I9VYA='5R92==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1S<B`]("1T:&ES+3YV97)I9GE3:6=N871U<F4H)&TL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&UA<%LD;65T:$YA;65=6R=S:6=N871U<F4G72`I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&UA<%LD;65T:$YA
M;65=6R=S:6=N871U<F4G72D@?'P@)'-R6S!=*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@:68@;F\@<VEG;F%T=7)E(&]R(&-O<G)E8W0@<VEG;F%T=7)E
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1S>7-#86QL*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1R(#T@8V%L;%]U<V5R7V9U;F,H)&1M87!;)&UE
M=&A.86UE75LG9G5N8W1I;VXG72P@)'1H:7,L("1M*3L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<B`]
M(&-A;&Q?=7-E<E]F=6YC*"1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N)UTL
M("1M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<U]A*"1R+"`G6$U,7U)00U]297-P;VYS92<I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H
M,"P@)%A-3%]24$-?97)R6R=N;W1?<F5S<&]N<V5?;V)J96-T)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)%A-3%]24$-?<W1R6R=N;W1?<F5S<&]N<V5?;V)J96-T)UTI.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@P+"`D
M6$U,7U)00U]E<G);)VEN8V]R<F5C=%]P87)A;7,G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T
M<ELG:6YC;W)R96-T7W!A<F%M<R=="B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("<Z("<@+B`D<W);,5TI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@+R\@96QS92!P<F5P87)E(&5R<F]R(')E<W!O;G-E"B`@("`@("`@
M("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#
M7V5R<ELG=6YK;F]W;E]M971H;V0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)%A-3%]24$-?<W1R6R=U;FMN;W=N7VUE
M=&AO9"==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@)'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%8VAO<R!B86-K('1H92!I
M;G!U="!P86-K970@87,@82!S=')I;F<@=F%L=64*("`@("`J"B`@("`@*B!`
M<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!5<V5F=6P@9F]R(&1E8G5G9VEN
M9RX*("`@("`J+PH@("`@9G5N8W1I;VX@96-H;TEN<'5T*"D*("`@('L*("`@
M("`@("!G;&]B86P@)$A45%!?4D%77U!/4U1?1$%403L*"B`@("`@("`@)'(@
M/2!N97<@6$U,7U)00U]297-P;VYS92@P*3L*("`@("`@("`D<BT^>'8@/2!N
M97<@6$U,7U)00U]686QU92@B)T%H82!S86ED($DZ("<B("X@)$A45%!?4D%7
M7U!/4U1?1$%402P@)W-T<FEN9R<I.PH@("`@("`@('!R:6YT("1R+3YS97)I
M86QI>F4H*3L*("`@('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T
M86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG
M+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"@H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]834PO4E!#+T1U
M;7`N<&AP````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,C`W-``Q,#4Q-30S,3`U-P`P,C`P-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N
M9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO
M"@HO*BH*("H@1G5N8W1I;VX@86YD(&-L87-S('1O(&1U;7`@6$U,7U)00U]6
M86QU92!O8FIE8W1S(&EN(&$@;FEC92!W87D*("H*("H@4VAO=6QD(&)E(&AE
M;'!F=6P@87,@82!N;W)M86P@=F%R7V1U;7`H+BXI(&1I<W!L87ES(&%L;"!I
M;G1E<FYA;',@=VAI8V@*("H@9&]E<VXG="!R96%L;'D@9VEV92!Y;W4@86X@
M;W9E<G9I97<@9'5E('1O('1O;R!M=6-H(&EN9F]R;6%T:6]N+@H@*@H@*B!`
M8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)0
M0PH@*B!`875T:&]R("`@("!#:')I<W1I86X@5V5I<VME(#QC=V5I<VME0'!H
M<"YN970^"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!$=6UP+G!H<"QV(#$N
M-R`R,#`U+S`Q+S(T(#`S.C0W.C4U(&1A;FEE;&,@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO
M"@H*+RHJ"B`J(%!U;&P@:6X@=&AE(%A-3%]24$,@8VQA<W,*("HO"G)E<75I
M<F5?;VYC92`G6$U,+U)00RYP:'`G.PH*"B\J*@H@*B!'96YE<F%T97,@=&AE
M(&1U;7`@;V8@=&AE(%A-3%]24$-?5F%L=64@86YD(&5C:&]E<R!I=`H@*@H@
M*B!`<&%R86T@;V)J96-T("1V86QU92`@=&AE(%A-3%]24$-?5F%L=64@;V)J
M96-T('1O(&1U;7`*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC=&EO;B!8
M34Q?4E!#7T1U;7`H)'9A;'5E*0I["B`@("`D9'5M<&5R(#T@;F5W(%A-3%]2
M4$-?1'5M<"@I.PH@("`@96-H;R`D9'5M<&5R+3YG96YE<F%T941U;7`H)'9A
M;'5E*3L*?0H*"B\J*@H@*B!#;&%S<R!W:&EC:"!G96YE<F%T97,@82!D=6UP
M(&]F(&$@6$U,7U)00U]686QU92!O8FIE8W0*("H*("H@0&-A=&5G;W)Y("`@
M5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO
M<B`@("`@0VAR:7-T:6%N(%=E:7-K92`\8W=E:7-K94!P:'`N;F5T/@H@*B!`
M=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B\*8VQA<W,@6$U,
M7U)00U]$=6UP"GL*("`@("\J*@H@("`@("H@5&AE(&EN9&5N=&%T:6]N(&%R
M<F%Y(&-A8VAE"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M87));F1E;G0@("`@("`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<W!A8V5S('5S960@9F]R(&EN9&5N=&EN9R!T:&4@6$U,"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'-T<D)A<V5);F1E;G0@/2`G("`@
M("<["@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D=6UP(&EN(%A-3"!F
M;W)M870@=VET:&]U="!P<FEN=&EN9R!I="!O=70*("`@("`J"B`@("`@*B!`
M<&%R86T@;V)J96-T("1V86QU92`@('1H92!834Q?4E!#7U9A;'5E(&]B:F5C
M="!T;R!D=6UP"B`@("`@*B!`<&%R86T@:6YT("`@("1N3&5V96P@('1H92!L
M979E;"!O9B!I;F1E;G1A=&EO;@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!T:&4@9'5M<`H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T941U
M;7`H)'9A;'5E+"`D;DQE=F5L(#T@,"D*("`@('L*("`@("`@("!I9B`H(6ES
M7V]B:F5C="@D=F%L=64I("8F(&=E=%]C;&%S<R@D=F%L=64I("$]("=X;6Q?
M<G!C7W9A;'5E)RD@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*("`@("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@G5')I960@=&\@
M9'5M<"!N;VXM6$U,7U)00U]686QU92!V87)I86)L92<@+B`B7')<;B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@,"P@4$5!4E]%4E)/4E]04DE.
M5"D["B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@
M("`@("`@("`@("`@)'-T<E1Y<&4@/2!G971?8VQA<W,H)'9A;'5E*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S=')4>7!E(#T@
M9V5T='EP92@D=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T26YD96YT*"1N3&5V96PI("X@)TY/5"!!(%A-3%]2
M4$-?5F%L=64Z("<*("`@("`@("`@("`@("`@("`@("X@)'-T<E1Y<&4@+B`B
M7')<;B(["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1V86QU92T^:VEN
M9$]F*"DI('L*("`@("`@("!C87-E("=S=')U8W0G.@H@("`@("`@("`@("`D
M<F5T(#T@)'1H:7,M/F=E;E-T<G5C="@D=F%L=64L("1N3&5V96PI.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=A<G)A>2<Z"B`@("`@("`@
M("`@("1R970@/2`D=&AI<RT^9V5N07)R87DH)'9A;'5E+"`D;DQE=F5L*3L*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G<V-A;&%R)SH*("`@
M("`@("`@("`@)')E="`]("1T:&ES+3YG96Y38V%L87(H)'9A;'5E+3YS8V%L
M87)V86PH*2P@)&Y,979E;"D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G
M.PH@("`@("`@("`@("!014%2.CIR86ES945R<F]R*"=);&QE9V%L('1Y<&4@
M(B<@+B`D=F%L=64M/FMI;F1/9B@I"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G(B!I;B!834Q?4E!#7U9A;'5E)R`N(")<<EQN(BP@,"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T524D]27U!224Y4*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@<V-A;&%R('9A;'5E(&1U;7`*("`@("`J
M"B`@("`@*B!`<&%R86T@;V)J96-T("1V86QU92`@('1H92!S8V%L87(@6$U,
M7U)00U]686QU92!O8FIE8W0@=&\@9'5M<`H@("`@("H@0'!A<F%M(&EN="`@
M("`D;DQE=F5L("!T:&4@;&5V96P@;V8@:6YD96YT871I;VX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@1'5M<&5D('9E<G-I;VX@;V8@=&AE('-C
M86QA<B!V86QU90H@("`@("HO"B`@("!F=6YC=&EO;B!G96Y38V%L87(H)'9A
M;'5E+"`D;DQE=F5L*0H@("`@>PH@("`@("`@(&EF("AG971T>7!E*"1V86QU
M92D@/3T@)V]B:F5C="<I('L*("`@("`@("`@("`@)'-T<D-L87-S(#T@)R`G
M("X@9V5T7V-L87-S*"1V86QU92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'-T<D-L87-S(#T@)R<["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=&AI<RT^9V5T26YD96YT*"1N3&5V96PI("X@9V5T='EP92@D=F%L=64I
M("X@)'-T<D-L87-S"B`@("`@("`@("`@("`@("X@)R`G("X@)'9A;'5E("X@
M(EQR7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9'5M
M<"!O9B!A('-T<G5C=`H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)'9A
M;'5E("`@=&AE('-T<G5C="!834Q?4E!#7U9A;'5E(&]B:F5C="!T;R!D=6UP
M"B`@("`@*B!`<&%R86T@:6YT("`@("1N3&5V96P@('1H92!L979E;"!O9B!I
M;F1E;G1A=&EO;@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$=6UP
M960@=F5R<VEO;B!O9B!T:&4@<V-A;&%R('9A;'5E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E;E-T<G5C="@D=F%L=64L("1N3&5V96PI"B`@("!["B`@("`@
M("`@)'9A;'5E+3YS=')U8W1R97-E="@I.PH@("`@("`@("1S=')/=71P=70@
M/2`D=&AI<RT^9V5T26YD96YT*"1N3&5V96PI("X@)W-T<G5C="<@+B`B7')<
M;B(["B`@("`@("`@=VAI;&4@*&QI<W0H)&ME>2P@)&ME>79A;"D@/2`D=F%L
M=64M/G-T<G5C=&5A8V@H*2D@>PH@("`@("`@("`@("`D<W1R3W5T<'5T("X]
M("1T:&ES+3YG971);F1E;G0H)&Y,979E;"`K(#$I("X@)&ME>2`N(")<<EQN
M(CL*("`@("`@("`@("`@)'-T<D]U='!U="`N/2`D=&AI<RT^9V5N97)A=&5$
M=6UP*"1K97EV86PL("1N3&5V96P@*R`R*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1S=')/=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!D=6UP(&]F(&%N(&%R<F%Y"B`@("`@*@H@("`@("H@0'!A<F%M
M(&]B:F5C="`D=F%L=64@("!T:&4@87)R87D@6$U,7U)00U]686QU92!O8FIE
M8W0@=&\@9'5M<`H@("`@("H@0'!A<F%M(&EN="`@("`D;DQE=F5L("!T:&4@
M;&5V96P@;V8@:6YD96YT871I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@1'5M<&5D('9E<G-I;VX@;V8@=&AE('-C86QA<B!V86QU90H@("`@
M("HO"B`@("!F=6YC=&EO;B!G96Y!<G)A>2@D=F%L=64L("1N3&5V96PI"B`@
M("!["B`@("`@("`@)&Y3:7IE("`@("`]("1V86QU92T^87)R87ES:7IE*"D[
M"B`@("`@("`@)'-T<D]U='!U="`]("1T:&ES+3YG971);F1E;G0H)&Y,979E
M;"D@+B`G87)R87DG("X@(EQR7&XB.PH@("`@("`@(&9O<B@D;D$@/2`P.R`D
M;D$@/"`D;E-I>F4[("1N02LK*2!["B`@("`@("`@("`@("1S=')/=71P=70@
M+CT@)'1H:7,M/F=E=$EN9&5N="@D;DQE=F5L("L@,2D@+B`D;D$@+B`B7')<
M;B(["B`@("`@("`@("`@("1S=')/=71P=70@+CT@)'1H:7,M/F=E;F5R871E
M1'5M<"@D=F%L=64M/F%R<F%Y;65M*"1N02DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;DQE=F5L("L@,BD["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<W1R3W5T<'5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:6YD96YT(&9O<B!A('-P96-I9FEC
M(&QE=F5L(&%N9"!C86-H97,@:70@9F]R(&9A<W1E<B!U<V4*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT("1N3&5V96P@('1H92!L979E;`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@:6YD96YT960@<W1R:6YG"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$EN9&5N="@D;DQE=F5L*0H@("`@>PH@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/F%R26YD96YT6R1N3&5V96Q=*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^87));F1E;G1;)&Y,979E;%T@/2!S=')?<F5P
M96%T*"1T:&ES+3YS=')"87-E26YD96YT+"`D;DQE=F5L*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YA<DEN9&5N=%LD;DQE=F5L73L*("`@
M('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*
M("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD
M97(M<#H@;FEL"B`J($5N9#H*("HO"@H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]834PO4&%R<V5R+P``````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,3<R
M-#``(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+UA-3"]087)S97(O4VEM
M<&QE+G!H<```````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P,C`T
M`#$P-3$U-#,Q,#4W`#`R,3$W-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%-T97!H86X@
M4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z(%-I;7!L92YP:'`L=B`Q+C8@,C`P-2\P,R\R-2`Q-SHQ,SHQ,"!S
M8VAS="!%>'`@)`H*+RHJ"B`J(%-I;7!L92!834P@<&%R<V5R(&-L87-S+@H@
M*@H@*B!4:&ES(&-L87-S(&ES(&$@<VEM<&QI9FEE9"!V97)S:6]N(&]F(%A-
M3%]087)S97(N"B`J($EN(&UO<W0@6$U,(&%P<&QI8V%T:6]N<R!T:&4@<F5A
M;"!A8W1I;VX@:7,@97AE8W5T960L"B`J('=H96X@82!C;&]S:6YG('1A9R!I
M<R!F;W5N9"X*("H*("H@6$U,7U!A<G-E<E]3:6UP;&4@86QL;W=S('EO=2!T
M;R!J=7-T(&EM<&QE;65N="!O;F4@8V%L;&)A8VL*("H@9F]R(&5A8V@@=&%G
M('1H870@=VEL;"!R96-E:79E('1H92!T86<@=VET:"!I=',@871T<FEB=71E
M<PH@*B!A;F0@0T1A=&$*("H*("H@0&-A=&5G;W)Y(%A-3`H@*B!`<&%C:V%G
M92!834Q?4&%R<V5R"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H
M<W1`<&AP+71O;VQS+FYE=#X*("HO"@HO*BH*("H@8G5I;'0@;VX@6$U,7U!A
M<G-E<@H@*B\*<F5Q=6ER95]O;F-E("=834PO4&%R<V5R+G!H<"<["@HO*BH*
M("H@4VEM<&QE(%A-3"!P87)S97(@8VQA<W,N"B`J"B`J(%1H:7,@8VQA<W,@
M:7,@82!S:6UP;&EF:65D('9E<G-I;VX@;V8@6$U,7U!A<G-E<BX*("H@26X@
M;6]S="!834P@87!P;&EC871I;VYS('1H92!R96%L(&%C=&EO;B!I<R!E>&5C
M=71E9"P*("H@=VAE;B!A(&-L;W-I;F<@=&%G(&ES(&9O=6YD+@H@*@H@*B!8
M34Q?4&%R<V5R7U-I;7!L92!A;&QO=W,@>6]U('1O(&IU<W0@:6UP;&5M96YT
M(&]N92!C86QL8F%C:PH@*B!F;W(@96%C:"!T86<@=&AA="!W:6QL(')E8V5I
M=F4@=&AE('1A9R!W:71H(&ET<R!A='1R:6)U=&5S"B`J(&%N9"!#1&%T82X*
M("H*("H@/&-O9&4^"B`J(')E<75I<F5?;VYC92`G+BXO4&%R<V5R+U-I;7!L
M92YP:'`G.PH@*@H@*B!C;&%S<R!M>5!A<G-E<B!E>'1E;F1S(%A-3%]087)S
M97)?4VEM<&QE"B`J('L*("H@("`@(&9U;F-T:6]N(&UY4&%R<V5R*"D*("H@
M("`@('L*("H@("`@("`@("1T:&ES+3Y834Q?4&%R<V5R7U-I;7!L92@I.PH@
M*B`@("`@('T*("H@"B`J("`@(&9U;F-T:6]N(&AA;F1L945L96UE;G0H)&YA
M;64L("1A='1R:6)S+"`D9&%T82D*("H@("`@('L*("H@("`@("`@("!P<FEN
M=&8H)VAA;F1L92`E<SQB<CXG+"`D;F%M92D["B`J("`@("!]"B`J('T*("H@
M"B`J("1P(#T@)FYE=R!M>5!A<G-E<B@I.PH@*B`*("H@)')E<W5L="`]("1P
M+3YS971);G!U=$9I;&4H)VUY1&]C+GAM;"<I.PH@*B`D<F5S=6QT(#T@)'`M
M/G!A<G-E*"D["B`J(#PO8V]D93X*("H*("H@0&-A=&5G;W)Y(%A-3`H@*B!`
M<&%C:V%G92!834Q?4&%R<V5R"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED
M="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*("HO"F-L87-S(%A-3%]087)S97)?
M4VEM<&QE(&5X=&5N9',@6$U,7U!A<G-E<@I["B`@("\J*@H@("`@*B!E;&5M
M96YT('-T86-K"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J
M($!V87(@("`@("!A<G)A>0H@("`@*B\*("`@('9A<B`D7V5L4W1A8VL@/2!A
M<G)A>2@I.PH*("`@+RHJ"B`@("`J(&%L;"!C:&%R86-T97(@9&%T80H@("`@
M*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`=F%R("`@("`@87)R
M87D*("`@("HO"B`@("!V87(@)%]D871A(#T@87)R87DH*3L*"B`@("\J*@H@
M("`@*B!E;&5M96YT(&1E<'1H"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV
M871E"B`@("`J($!V87(@("`@("!I;G1E9V5R"B`@("`J+PH@("`@=F%R("1?
M9&5P=&@@/2`P.PH*("`@("\J*@H@("`@("H@36%P<&EN9R!F<F]M(&5X<&%T
M(&AA;F1L97(@9G5N8W1I;VX@=&\@8VQA<W,@;65T:&]D+@H@("`@("H*("`@
M("`J($!V87(@(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D:&%N9&QE<B`](&%R
M<F%Y*`H@("`@("`@("=D969A=6QT7VAA;F1L97(G("`@("`@("`@("`@("`@
M("`@(#T^("=D969A=6QT2&%N9&QE<B<L"B`@("`@("`@)W!R;V-E<W-I;F=?
M:6YS=')U8W1I;VY?:&%N9&QE<B<@("`@/3X@)W!I2&%N9&QE<B<L"B`@("`@
M("`@)W5N<&%R<V5D7V5N=&ET>5]D96-L7VAA;F1L97(G("`@("`@/3X@)W5N
M<&%R<V5D2&%N9&QE<B<L"B`@("`@("`@)VYO=&%T:6]N7V1E8VQ?:&%N9&QE
M<B<@("`@("`@("`@("`@/3X@)VYO=&%T:6]N2&%N9&QE<B<L"B`@("`@("`@
M)V5X=&5R;F%L7V5N=&ET>5]R969?:&%N9&QE<B<@("`@("`@/3X@)V5N=&ET
M>7)E9DAA;F1L97(G"B`@("`I.PH@("`@"B`@("`O*BH*("`@("`J($-R96%T
M97,@86X@6$U,('!A<G-E<BX*("`@("`J"B`@("`@*B!4:&ES(&ES(&YE961E
M9"!F;W(@4$A0-"!C;VUP871I8FEL:71Y+"!I="!W:6QL"B`@("`@*B!C86QL
M('1H92!C;VYS=')U8W1O<BP@=VAE;B!A(&YE=R!I;G-T86YC92!I<R!C<F5A
M=&5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-R8V5N8R!S;W5R
M8V4@8VAA<G-E="!E;F-O9&EN9RP@=7-E($Y53$P@*&1E9F%U;'0I('1O('5S
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('=H871E=F5R('1H92!D
M;V-U;65N="!S<&5C:69I97,*("`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@
M("!H;W<@=&AI<R!P87)S97(@;V)J96-T('-H;W5L9"!W;W)K+"`B979E;G0B
M(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&AA;F1L945L96UE
M;G0H*2P@(F9U;F,B('1O(&AA=F4@:70@8V%L;"!F=6YC=&EO;G,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!N86UE9"!A9G1E<B!E;&5M96YT<R`H
M:&%N9&QE16QE;65N=%\D;F%M92@I*0H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&=E;F,@(&$@=F%L:60@=&%R9V5T(&5N8V]D:6YG"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%A-3%]087)S97)?4VEM<&QE*"1S<F-E;F,@/2!N=6QL+"`D;6]D
M92`]("=E=F5N="<L("1T9W1E;F,@/2!N=6QL*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y834Q?4&%R<V5R*"1S<F-E;F,L("1M;V1E+"`D=&=T96YC*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(&EN:71S('1H92!H86YD;&5R<PH@("`@("H*
M("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VEN:71(86YD;&5R<R@I"B`@("!["B`@("`@("`@:68@*"%I<U]O8FIE8W0H
M)'1H:7,M/E]H86YD;&5R3V)J*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAA
M;F1L97)/8FH@/2`F)'1H:7,["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H
M:7,M/FUO9&4@(3T@)V9U;F,G("8F("1T:&ES+3YM;V1E("$]("=E=F5N="<I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;G-U
M<'!O<G1E9"!M;V1E(&=I=F5N)RP@6$U,7U!!4E-%4E]%4E)/4E]53E-54%!/
M4E1%1%]-3T1%*3L*("`@("`@("!]"B`@("`@("`@>&UL7W-E=%]O8FIE8W0H
M)'1H:7,M/G!A<G-E<BP@)'1H:7,M/E]H86YD;&5R3V)J*3L*"B`@("`@("`@
M>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H:7,M/G!A<G-E<BP@87)R87DH
M)B1T:&ES+"`G<W1A<G1(86YD;&5R)RDL(&%R<F%Y*"8D=&AI<RP@)V5N9$AA
M;F1L97(G*2D["B`@("`@("`@>&UL7W-E=%]C:&%R86-T97)?9&%T85]H86YD
M;&5R*"1T:&ES+3YP87)S97(L(&%R<F%Y*"8D=&AI<RP@)V-D871A2&%N9&QE
M<B<I*3L*("`@("`@("`*("`@("`@("`O*BH*("`@("`@("`@*B!S970@861D
M:71I;VYA;"!H86YD;&5R<R!F;W(@8VAA<F%C=&5R(&1A=&$L(&5N=&ET:65S
M+"!E=&,N"B`@("`@("`@("HO"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FAA
M;F1L97(@87,@)'AM;%]F=6YC(#T^("1M971H;V0I('L*("`@("`@("`@("`@
M:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/E]H86YD;&5R3V)J+"`D;65T:&]D
M*2D@>PH@("`@("`@("`@("`@("`@)'AM;%]F=6YC(#T@)WAM;%]S971?)R`N
M("1X;6Q?9G5N8SL*("`@("`@("`@("`@("`@("1X;6Q?9G5N8R@D=&AI<RT^
M<&%R<V5R+"`D;65T:&]D*3L*("`@("`@("`@("`@?0H)"7T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E<V5T('1H92!P87)S97(N"B`@("`@*@H@("`@("H@
M5&AI<R!A;&QO=W,@>6]U('1O('5S92!O;F4@<&%R<V5R(&EN<W1A;F-E"B`@
M("`@*B!T;R!P87)S92!M=6QT:7!L92!834P@9&]C=6UE;G1S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("`J($!R971U<FX@("!B;V]L
M96%N?&]B:F5C="`@("`@=')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]T
M:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]E;%-T86-K(#T@87)R87DH*3L*("`@("`@("`D=&AI
M<RT^7V1A=&$@("`@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?9&5P=&@@
M("`](#`["B`@("`@("`@"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8W)E
M871E*"D["B`@("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"`D<F5S=6QT("DI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@+RHJ"B`@("`J('-T87)T(&AA
M;F1L97(*("`@("H*("`@("H@4'5S:&5S(&%T=')I8G5T97,@86YD('1A9VYA
M;64@;VYT;R!A('-T86-K"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E
M"B`@("`J($!F:6YA;`H@("`@*B!`<&%R86T@("`@<F5S;W5R8V4@("`@>&UL
M('!A<G-E<B!R97-O=7)C90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@
M96QE;65N="!N86UE"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A='1R
M:6)U=&5S"B`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G1(86YD;&5R*"1X<"P@
M)&5L96TL("8D871T<FEB<RD*("`@('L*("`@("`@("!A<G)A>5]P=7-H*"1T
M:&ES+3Y?96Q3=&%C:RP@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@(#T^("1E;&5M+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R
M:6)S)R`]/B`D871T<FEB<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("1T
M:&ES+3Y?9&5P=&@K*SL*("`@("`@("`D=&AI<RT^7V1A=&%;)'1H:7,M/E]D
M97!T:%T@/2`G)SL*("`@('T*"B`@("\J*@H@("`@*B!E;F0@:&%N9&QE<@H@
M("`@*@H@("`@*B!0=6QL<R!A='1R:6)U=&5S(&%N9"!T86=N86UE(&9R;VT@
M82!S=&%C:PH@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`
M9FEN86P*("`@("H@0'!A<F%M("`@(')E<V]U<F-E("`@('AM;"!P87)S97(@
M<F5S;W5R8V4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&5L96UE;G0@
M;F%M90H@("`@*B\*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H)'AP+"`D96QE
M;2D*("`@('L*("`@("`@("`D96P@("`](&%R<F%Y7W!O<"@D=&AI<RT^7V5L
M4W1A8VLI.PH@("`@("`@("1D871A(#T@)'1H:7,M/E]D871A6R1T:&ES+3Y?
M9&5P=&A=.PH@("`@("`@("1T:&ES+3Y?9&5P=&@M+3L*"B`@("`@("`@<W=I
M=&-H("@D=&AI<RT^;6]D92D@>PH@("`@("`@("`@("!C87-E("=E=F5N="<Z
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VAA;F1L97)/8FHM/FAA;F1L945L
M96UE;G0H)&5L6R=N86UE)UTL("1E;%LG871T<FEB<R==+"`D9&%T82D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G9G5N8R<Z
M"B`@("`@("`@("`@("`@("`D9G5N8R`]("=H86YD;&5%;&5M96YT7R<@+B`D
M96QE;3L*("`@("`@("`@("`@("`@(&EF("AS=')C:'(H)&9U;F,L("<N)RDI
M('L*("`@("`@("`@("`@("`@("`@("`D9G5N8R`]('-T<E]R97!L86-E*"<N
M)RP@)U\G+"`D9G5N8RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RT^7VAA;F1L97)/8FHL("1F
M=6YC*2D@>PH@("`@("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*&%R
M<F%Y*"8D=&AI<RT^7VAA;F1L97)/8FHL("1F=6YC*2P@)&5L6R=N86UE)UTL
M("1E;%LG871T<FEB<R==+"`D9&%T82D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`O*BH*
M("`@("H@:&%N9&QE(&-H87)A8W1E<B!D871A"B`@("`J"B`@("`J($!A8V-E
M<W,@("!P<FEV871E"B`@("`J($!F:6YA;`H@("`@*B!`<&%R86T@("`@<F5S
M;W5R8V4@("`@>&UL('!A<G-E<B!R97-O=7)C90H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`@("`@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N(&-D871A2&%N
M9&QE<B@D>'`L("1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&%T85LD
M=&AI<RT^7V1E<'1H72`N/2`D9&%T83L*("`@('T*"B`@("\J*@H@("`@*B!H
M86YD;&4@82!T86<*("`@("H*("`@("H@26UP;&5M96YT('1H:7,@:6X@>6]U
M<B!P87)S97(@"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@
M0&%B<W1R86-T"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!E;&5M96YT
M(&YA;64*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T=')I8G5T97,*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&-H87)A8W1E<B!D871A"B`@
M("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE16QE;65N="@D;F%M92P@)&%T=')I
M8G,L("1D871A*0H@("`@>PH@("`@?0H*("`@+RHJ"B`@("`J(&=E="!T:&4@
M8W5R<F5N="!T86<@9&5P=&@*("`@("H*("`@("H@5&AE(')O;W0@=&%G(&ES
M(&EN(&1E<'1H(#`N"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("H@0')E='5R;B`@(&EN=&5G97(*("`@("HO"B`@("!F=6YC=&EO;B!G971#
M=7)R96YT1&5P=&@H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1E
M<'1H.PH@("`@?0H*("`@+RHJ"B`@("`J(&%D9"!S;VUE('-T<FEN9R!T;R!T
M:&4@8W5R<F5N="!D9&%T82X*("`@("H*("`@("H@5&AI<R!I<R!C;VUM;VYL
M>2!N965D960L('=H96X@82!D;V-U;65N="!I<R!P87)S960@<F5C=7)S:79E
M;'DN"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@("`@(&1A=&$@=&\@861D"B`@("`J($!R971U<FX@("!V
M;VED"B`@("`J+PH@("`@9G5N8W1I;VX@861D5&]$871A*"`D9&%T82`I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]D871A6R1T:&ES+3Y?9&5P=&A=("X]("1D
M871A.PH@("`@?0I]"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+UA-3"]087)S97(N<&AP````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0U,#4V`#$P-3$U-#,Q
M,#4W`#`Q-S<V,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%-T:6<@0F%K:V5N(#QS<V)`
M9F%S="YN;SX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@
M4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/B`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@4&%R<V5R+G!H<"QV(#$N,C8@,C`P-2\P.2\R,R`Q
M,3HU,3HQ,"!S8VAS="!%>'`@)`H*+RHJ"B`J(%A-3"!087)S97(@8VQA<W,N
M"B`J"B`J(%1H:7,@:7,@86X@6$U,('!A<G-E<B!B87-E9"!O;B!02%`G<R`B
M>&UL(B!E>'1E;G-I;VXL"B`J(&)A<V5D(&]N('1H92!B=6YD;&5D(&5X<&%T
M(&QI8G)A<GDN"B`J"B`J($!C871E9V]R>2!834P*("H@0'!A8VMA9V4@6$U,
M7U!A<G-E<@H@*B!`875T:&]R("!3=&EG($)A:VME;B`\<W-B0&9A<W0N;F\^
M"B`J($!A=71H;W(@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*
M("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N
M;F5T/@H@*B\*"B\J*@H@*B!U<V5S(%!%05(G<R!E<G)O<B!H86YD;&EN9PH@
M*B\*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@<F5S;W5R8V4@
M8V]U;&0@;F]T(&)E(&-R96%T960*("HO"F1E9FEN92@G6$U,7U!!4E-%4E]%
M4E)/4E].3U]215-/55)#12<L(#(P,"D["@HO*BH*("H@=6YS=7!P;W)T960@
M;6]D90H@*B\*9&5F:6YE*"=834Q?4$%24T527T524D]27U5.4U504$]25$5$
M7TU/1$4G+"`R,#$I.PH*+RHJ"B`J(&EN=F%L:60@96YC;V1I;F<@=V%S(&=I
M=F5N"B`J+PID969I;F4H)UA-3%]005)315)?15)23U)?24Y604Q)1%]%3D-/
M1$E.1R<L(#(P,BD["@HO*BH*("H@<W!E8VEF:65D(&9I;&4@8V]U;&0@;F]T
M(&)E(')E860*("HO"F1E9FEN92@G6$U,7U!!4E-%4E]%4E)/4E]&24Q%7TY/
M5%]214%$04),12<L(#(P,RD["@HO*BH*("H@:6YV86QI9"!I;G!U=`H@*B\*
M9&5F:6YE*"=834Q?4$%24T527T524D]27TE.5D%,241?24Y0550G+"`R,#0I
M.PH*+RHJ"B`J(')E;6]T92!F:6QE(&-A;FYO="!B92!R971R:65V960@:6X@
M<V%F92!M;V1E"B`J+PID969I;F4H)UA-3%]005)315)?15)23U)?4D5-3U1%
M)RP@,C`U*3L*"B\J*@H@*B!834P@4&%R<V5R(&-L87-S+@H@*@H@*B!4:&ES
M(&ES(&%N(%A-3"!P87)S97(@8F%S960@;VX@4$A0)W,@(GAM;"(@97AT96YS
M:6]N+`H@*B!B87-E9"!O;B!T:&4@8G5N9&QE9"!E>'!A="!L:6)R87)Y+@H@
M*@H@*B!.;W1E<SH*("H@+2!)="!R97%U:7)E<R!02%`@-"XP+C1P;#$@;W(@
M9W)E871E<@H@*B`M($9R;VT@<F5V:7-I;VX@,2XQ-RP@=&AE(&9U;F-T:6]N
M(&YA;65S('5S960@8GD@=&AE("=F=6YC)R!M;V1E"B`J("`@87)E(&EN('1H
M92!F;W)M870@(GAM;'1A9U\D96QE;2(L(&9O<B!E>&%M<&QE.B!U<V4@(GAM
M;'1A9U]N86UE(@H@*B`@('1O(&AA;F1L92!T:&4@/&YA;64^/"]N86UE/B!T
M86=S(&]F('EO=7(@>&UL(&9I;&4N"B`J"B`J($!C871E9V]R>2!834P*("H@
M0'!A8VMA9V4@6$U,7U!A<G-E<@H@*B!`875T:&]R("!3=&EG($)A:VME;B`\
M<W-B0&9A<W0N;F\^"B`J($!A=71H;W(@(%1O;6%S(%8N5BY#;W@@/&-O>$!I
M9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS
M=$!P:'`M=&]O;',N;F5T/@H@*B!`=&]D;R`@("!C<F5A=&4@6$U,7U!A<G-E
M<E].86UE<W!A8V4@=&\@<&%R<V4@9&]C=6UE;G1S('=I=&@@;F%M97-P86-E
M<PH@*B!`=&]D;R`@("!C<F5A=&4@6$U,7U!A<G-E<E]0=6QL"B`J($!T;V1O
M("`@(%1E<W1S('1H870@;F5E9"!T;R!B92!M861E.@H@*B`@("`@("`@("`M
M(&UI>&EN9R!C:&%R86-T97(@96YC;V1I;F=S"B`J("`@("`@("`@("T@82!T
M97-T('5S:6YG(&%L;"!E>'!A="!H86YD;&5R<PH@*B`@("`@("`@("`M(&]P
M=&EO;G,@*&9O;&1I;F<L(&]U='!U="!C:&%R<V5T*0H@*B`@("`@("`@("`M
M(&1I9F9E<F5N="!P87)S:6YG(&UO9&5S"B`J+PIC;&%S<R!834Q?4&%R<V5R
M(&5X=&5N9',@4$5!4@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@+RHJ
M"B`@("`@*B!834P@<&%R<V5R(&AA;F1L90H@("`@("H*("`@("`J($!V87(@
M(')E<V]U<F-E"B`@("`@*B!`<V5E("!X;6Q?<&%R<V5R7V-R96%T92@I"B`@
M("`@*B\*("`@('9A<B`D<&%R<V5R.PH*("`@("\J*@H@("`@("H@1FEL92!H
M86YD;&4@:68@<&%R<VEN9R!F<F]M(&$@9FEL90H@("`@("H*("`@("`J($!V
M87(@(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D9G`["@H@("`@+RHJ"B`@
M("`@*B!7:&5T:&5R('1O(&1O(&-A<V4@9F]L9&EN9PH@("`@("H*("`@("`J
M($EF('-E="!T;R!T<G5E+"!A;&P@=&%G(&%N9"!A='1R:6)U=&4@;F%M97,@
M=VEL;`H@("`@("H@8F4@8V]N=F5R=&5D('1O(%504$52($-!4T4N"B`@("`@
M*@H@("`@("H@0'9A<B`@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)&9O;&1I
M;F<@/2!T<G5E.PH*("`@("\J*@H@("`@("H@36]D92!O9B!O<&5R871I;VXL
M(&]N92!O9B`B979E;G0B(&]R(")F=6YC(@H@("`@("H*("`@("`J($!V87(@
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)&UO9&4["@H@("`@+RHJ"B`@("`@
M*B!-87!P:6YG(&9R;VT@97AP870@:&%N9&QE<B!F=6YC=&EO;B!T;R!C;&%S
M<R!M971H;V0N"B`@("`@*@H@("`@("H@0'9A<B`@87)R87D*("`@("`J+PH@
M("`@=F%R("1H86YD;&5R(#T@87)R87DH"B`@("`@("`@)V-H87)A8W1E<E]D
M871A7VAA;F1L97(G("`@("`@("`@("`@/3X@)V-D871A2&%N9&QE<B<L"B`@
M("`@("`@)V1E9F%U;'1?:&%N9&QE<B<@("`@("`@("`@("`@("`@("`@/3X@
M)V1E9F%U;'1(86YD;&5R)RP*("`@("`@("`G<')O8V5S<VEN9U]I;G-T<G5C
M=&EO;E]H86YD;&5R)R`@("`]/B`G<&E(86YD;&5R)RP*("`@("`@("`G=6YP
M87)S961?96YT:71Y7V1E8VQ?:&%N9&QE<B<@("`@("`]/B`G=6YP87)S961(
M86YD;&5R)RP*("`@("`@("`G;F]T871I;VY?9&5C;%]H86YD;&5R)R`@("`@
M("`@("`@("`]/B`G;F]T871I;VY(86YD;&5R)RP*("`@("`@("`G97AT97)N
M86Q?96YT:71Y7W)E9E]H86YD;&5R)R`@("`@("`]/B`G96YT:71Y<F5F2&%N
M9&QE<B<*("`@("D["@H@("`@+RHJ"B`@("`@*B!S;W5R8V4@96YC;V1I;F<*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'-R
M8V5N8SL*"B`@("`O*BH*("`@("`J('1A<F=E="!E;F-O9&EN9PH@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D=&=T96YC.PH*
M("`@("\J*@H@("`@("H@:&%N9&QE<B!O8FIE8W0*("`@("`J"B`@("`@*B!`
M=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)%]H86YD;&5R3V)J.PH*("`@
M("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&5S(&%N(%A-3"!P87)S97(N"B`@("`@*@H@("`@("H@5&AI<R!I
M<R!N965D960@9F]R(%!(4#0@8V]M<&%T:6)I;&ET>2P@:70@=VEL;`H@("`@
M("H@8V%L;"!T:&4@8V]N<W1R=6-T;W(L('=H96X@82!N97<@:6YS=&%N8V4@
M:7,@8W)E871E9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S<F-E
M;F,@<V]U<F-E(&-H87)S970@96YC;V1I;F<L('5S92!.54Q,("AD969A=6QT
M*2!T;R!U<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!W:&%T979E
M<B!T:&4@9&]C=6UE;G0@<W!E8VEF:65S"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M;V1E("`@:&]W('1H:7,@<&%R<V5R(&]B:F5C="!S:&]U;&0@=V]R:RP@
M(F5V96YT(B!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S=&%R
M=&5L96UE;G0O96YD96QE;65N="UT>7!E(&5V96YT<RP@(F9U;F,B"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&\@:&%V92!I="!C86QL(&9U;F-T
M:6]N<R!N86UE9"!A9G1E<B!E;&5M96YT<PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&=E;F,@(&$@=F%L:60@=&%R9V5T(&5N8V]D:6YG"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%A-3%]087)S97(H)'-R8V5N8R`](&YU;&PL("1M;V1E(#T@
M)V5V96YT)RP@)'1G=&5N8R`](&YU;&PI"B`@("!["B`@("`@("`@6$U,7U!A
M<G-E<CHZ7U]C;VYS=')U8W0H)'-R8V5N8RP@)&UO9&4L("1T9W1E;F,I.PH@
M("`@?0H@("`@+R\@?7U]"@H@("`@+RHJ"B`@("`@*B!02%`U(&-O;G-T<G5C
M=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W)C96YC('-O=7)C
M92!C:&%R<V5T(&5N8V]D:6YG+"!U<V4@3E5,3"`H9&5F875L="D@=&\@=7-E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=VAA=&5V97(@=&AE(&1O
M8W5M96YT('-P96-I9FEE<PH@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D92`@
M(&AO=R!T:&ES('!A<G-E<B!O8FIE8W0@<VAO=6QD('=O<FLL(")E=F5N="(@
M9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W1A<G1E;&5M96YT
M+V5N9&5L96UE;G0M='EP92!E=F5N=',L(")F=6YC(@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@('1O(&AA=F4@:70@8V%L;"!F=6YC=&EO;G,@;F%M
M960@869T97(@96QE;65N=',*("`@("`J($!P87)A;2!S=')I;F<@)'1G96YC
M("!A('9A;&ED('1A<F=E="!E;F-O9&EN9PH@("`@("HO"B`@("!F=6YC=&EO
M;B!?7V-O;G-T<G5C="@D<W)C96YC(#T@;G5L;"P@)&UO9&4@/2`G979E;G0G
M+"`D=&=T96YC(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^4$5!4B@G
M6$U,7U!A<G-E<E]%<G)O<B<I.PH*("`@("`@("`D=&AI<RT^;6]D92`@(#T@
M)&UO9&4["B`@("`@("`@)'1H:7,M/G-R8V5N8R`]("1S<F-E;F,["B`@("`@
M("`@)'1H:7,M/G1G=&5N8R`]("1T9W1E;F,["B`@("!]"B`@("`O+R!]?7T*
M"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&UO9&4@;V8@=&AE('!A<G-E<BX*
M("`@("`J"B`@("`@*B!0;W-S:6)L92!M;V1E<R!A<F4Z"B`@("`@*B`M(&9U
M;F,*("`@("`J("T@979E;G0*("`@("`J"B`@("`@*B!9;W4@8V%N('-E="!T
M:&4@;6]D92!U<VEN9R!T:&4@<V5C;VYD('!A<F%M971E<@H@("`@("H@:6X@
M=&AE(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES
M(&]N;'D@;F5E9&5D+"!W:&5N('-W:71C:&EN9R!T;R!A(&YE=PH@("`@("H@
M;6]D92!A="!A(&QA=&5R('!O:6YT+@H@("`@("H*("`@("`J($!A8V-E<W,@
M('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@(&UO9&4L
M(&5I=&AE<B`G9G5N8R<@;W(@)V5V96YT)PH@("`@("H@0')E='5R;B`@8F]O
M;&5A;GQO8FIE8W0@('1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O=&AE
M<G=I<V4@("`*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T36]D92@D;6]D92D*
M("`@('L*("`@("`@("!I9B`H)&UO9&4@(3T@)V9U;F,G("8F("1M;V1E("$]
M("=E=F5N="<I('L*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)U5N
M<W5P<&]R=&5D(&UO9&4@9VEV96XG+"!834Q?4$%24T527T524D]27U5.4U50
M4$]25$5$7TU/1$4I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FUO9&4@
M/2`D;6]D93L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E=',@=&AE(&]B:F5C="P@=&AA="!W:6QL(&AA;F1L92!T:&4@
M6$U,(&5V96YT<PH@("`@("H*("`@("`J(%1H:7,@86QL;W=S('EO=2!T;R!C
M<F5A=&4@82!H86YD;&5R(&]B:F5C="!I;F1E<&5N9&5N="!O9B!T:&4*("`@
M("`J('!A<G-E<B!O8FIE8W0@=&AA="!Y;W4@87)E('5S:6YG(&%N9"!E87-I
M;'D@<W=I=&-H('1H92!U;F1E<FQY:6YG"B`@("`@*B!P87)S97(N"B`@("`@
M*@H@("`@("H@268@;F\@;V)J96-T('=I;&P@8F4@<V5T+"!834Q?4&%R<V5R
M(&%S<W5M97,@=&AA="!Y;W4*("`@("`J(&5X=&5N9"!T:&ES(&-L87-S(&%N
M9"!H86YD;&4@=&AE(&5V96YT<R!I;B`D=&AI<RX*("`@("`J"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@(&]B:F5C="`@("`@(&]B
M:F5C="!T;R!H86YD;&4@=&AE(&5V96YT<PH@("`@("H@0')E='5R;B`@8F]O
M;&5A;B`@("`@=VEL;"!A;'=A>7,@<F5T=7)N('1R=64*("`@("`J($!S:6YC
M92`@('8Q+C(N,&)E=&$S"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$AA;F1L
M97)/8FHH)B1O8FHI"B`@("!["B`@("`@("`@)'1H:7,M/E]H86YD;&5R3V)J
M(#T@)B1O8FH["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!);FET('1H92!E;&5M96YT(&AA;F1L97)S"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI
M=$AA;F1L97)S*"D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T
M:&ES+3YP87)S97(I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A:7-?;V)J96-T*"1T:&ES+3Y?:&%N9&QE
M<D]B:BDI('L*("`@("`@("`@("`@)'1H:7,M/E]H86YD;&5R3V)J(#T@)B1T
M:&ES.PH@("`@("`@('T*("`@("`@("!S=VET8V@@*"1T:&ES+3YM;V1E*2![
M"@H@("`@("`@("`@("!C87-E("=F=6YC)SH*("`@("`@("`@("`@("`@('AM
M;%]S971?;V)J96-T*"1T:&ES+3YP87)S97(L("1T:&ES+3Y?:&%N9&QE<D]B
M:BD["B`@("`@("`@("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D
M=&AI<RT^<&%R<V5R+"!A<G)A>2@F)'1H:7,L("=F=6YC4W1A<G1(86YD;&5R
M)RDL(&%R<F%Y*"8D=&AI<RP@)V9U;F-%;F1(86YD;&5R)RDI.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=E=F5N="<Z"B`@
M("`@("`@("`@("`@("!X;6Q?<V5T7V]B:F5C="@D=&AI<RT^<&%R<V5R+"`D
M=&AI<RT^7VAA;F1L97)/8FHI.PH@("`@("`@("`@("`@("`@>&UL7W-E=%]E
M;&5M96YT7VAA;F1L97(H)'1H:7,M/G!A<G-E<BP@)W-T87)T2&%N9&QE<B<L
M("=E;F1(86YD;&5R)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G56YS=7!P;W)T960@;6]D92!G:79E;B<L(%A-3%]005)3
M15)?15)23U)?54Y355!03U)4141?34]$12D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H*("`@("`@("`O*BH*("`@("`@("`@*B!S970@
M861D:71I;VYA;"!H86YD;&5R<R!F;W(@8VAA<F%C=&5R(&1A=&$L(&5N=&ET
M:65S+"!E=&,N"B`@("`@("`@("HO"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/FAA;F1L97(@87,@)'AM;%]F=6YC(#T^("1M971H;V0I('L*("`@("`@("`@
M("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/E]H86YD;&5R3V)J+"`D;65T
M:&]D*2D@>PH@("`@("`@("`@("`@("`@)'AM;%]F=6YC(#T@)WAM;%]S971?
M)R`N("1X;6Q?9G5N8SL*("`@("`@("`@("`@("`@("1X;6Q?9G5N8R@D=&AI
M<RT^<&%R<V5R+"`D;65T:&]D*3L*("`@("`@("`@("`@?0H)"7T*("`@('T*
M"B`@("`O+R![>WL@7V-R96%T92@I"@H@("`@+RHJ"B`@("`@*B!C<F5A=&4@
M=&AE(%A-3"!P87)S97(@<F5S;W5R8V4*("`@("`J"B`@("`@*B!(87,@8F5E
M;B!M;W9E9"!F<F]M('1H92!C;VYS=')U8W1O<B!T;R!A=F]I9`H@("`@("H@
M<')O8FQE;7,@=VET:"!O8FIE8W0@<F5F97)E;F-E<RX*("`@("`J"B`@("`@
M*B!&=7)T:&5R;6]R92!I="!A;&QO=W,@=7,@<F5T=7)N:6YG(&%N(&5R<F]R
M"B`@("`@*B!I9B!S;VUE=&AI;F<@9F%I;',N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@('!R:79A=&4*("`@("`J($!R971U<FX@("!B;V]L96%N?&]B:F5C
M="`@("`@=')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]T:&5R=VES90H@
M("`@("H*("`@("`J($!S964@>&UL7W!A<G-E<E]C<F5A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-R96%T92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YS<F-E;F,@/3T](&YU;&PI('L*("`@("`@("`@("`@)'AP(#T@0'AM;%]P
M87)S97)?8W)E871E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'AP(#T@0'AM;%]P87)S97)?8W)E871E*"1T:&ES+3YS<F-E;F,I.PH@("`@
M("`@('T*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'AP*2D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/G1G=&5N8R`A/3T@;G5L;"D@>PH@("`@("`@("`@
M("`@("`@:68@*"%`>&UL7W!A<G-E<E]S971?;W!T:6]N*"1X<"P@6$U,7T]0
M5$E/3E]405)'151?14Y#3T1)3D<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1G=&5N8RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VEN=F%L
M:60@=&%R9V5T(&5N8V]D:6YG)RP@6$U,7U!!4E-%4E]%4E)/4E])3E9!3$E$
M7T5.0T]$24Y'*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^<&%R<V5R(#T@)'AP.PH@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]I;FET2&%N9&QE<G,H)'1H:7,M/FUO9&4I.PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D>'`L(%A-3%]/4%1)
M3TY?0T%315]&3TQ$24Y'+"`D=&AI<RT^9F]L9&EN9RD["@H@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=5;F%B;&4@=&\@8W)E871E(%A-3"!P87)S97(@<F5S
M;W5R8V4N)RP@6$U,7U!!4E-%4E]%4E)/4E].3U]215-/55)#12D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F5S970H*0H*("`@("\J*@H@("`@
M("H@4F5S970@=&AE('!A<G-E<BX*("`@("`J"B`@("`@*B!4:&ES(&%L;&]W
M<R!Y;W4@=&\@=7-E(&]N92!P87)S97(@:6YS=&%N8V4*("`@("`J('1O('!A
M<G-E(&UU;'1I<&QE(%A-3"!D;V-U;65N=',N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@("H@0')E='5R;B`@(&)O;VQE86Y\;V)J96-T
M("`@("!T<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;W1H97)W:7-E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E<V5T*"D*("`@('L*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]C<F5A=&4H*3L*("`@("`@("!I9B`H)'1H:7,M/FES
M17)R;W(H("1R97-U;'0@*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<V5T26YP=71&:6QE*"D*"B`@("`O*BH*("`@
M("`J(%-E=',@=&AE(&EN<'5T('AM;"!F:6QE('1O(&)E('!A<G-E9`H@("`@
M("H*("`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!&:6QE;F%M92`H9G5L
M;"!P871H*0H@("`@("H@0')E='5R;B`@(')E<V]U<F-E("`@(&9O<&5N(&AA
M;F1L92!O9B!T:&4@9VEV96X@9FEL90H@("`@("H@0'1H<F]W<R`@(%A-3%]0
M87)S97)?17)R;W(*("`@("`J($!S964@("`@("!S971);G!U="@I+"!S971)
M;G!U=%-T<FEN9R@I+"!P87)S92@I"B`@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$EN<'5T1FEL92@D9FEL92D*("`@
M('L*("`@("`@("`O*BH*("`@("`@("`@*B!C:&5C:RP@:68@9FEL92!I<R!A
M(')E;6]T92!F:6QE"B`@("`@("`@("HO"B`@("`@("`@:68@*&5R96=I*"=>
M*&AT='!\9G1P*3HO+R<L('-U8G-T<B@D9FEL92P@,"P@,3`I*2D@>PH@("`@
M("`@("`@("!I9B`H(6EN:5]G970H)V%L;&]W7W5R;%]F;W!E;B<I*2!["B`@
M("`@("`@("`@(`ER971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U)E;6]T92!F
M:6QE<R!C86YN;W0@8F4@<&%R<V5D+"!A<R!S869E(&UO9&4@:7,@96YA8FQE
M9"XG+"!834Q?4$%24T527T524D]27U)%34]412D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE
M+"`G<F(G*3L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^9G`@/2`D9G`["B`@("`@("`@("`@(')E='5R;B`D
M9G`["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G1FEL92!C;W5L9"!N;W0@8F4@;W!E;F5D+B<L(%A-3%]005)315)?15)2
M3U)?1DE,15].3U1?4D5!1$%"3$4I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[('-E=$EN<'5T4W1R:6YG*"D*("`@(`H@("`@+RHJ"B`@("`@*B!8
M34Q?4&%R<V5R.CIS971);G!U=%-T<FEN9R@I"B`@("`@*B`*("`@("`J(%-E
M=',@=&AE('AM;"!I;G!U="!F<F]M(&$@<W1R:6YG"B`@("`@*B`*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&$@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@
M6$U,(&1O8W5M96YT"B`@("`@*B!`<F5T=7)N(&YU;&P*("`@("`J*B\*("`@
M(&9U;F-T:6]N('-E=$EN<'5T4W1R:6YG*"1D871A*0H@("`@>PH@("`@("`@
M("1T:&ES+3YF<"`]("1D871A.PH@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M?0H@("`@"B`@("`O+R!]?7T*("`@("\O('M[>R!S971);G!U="@I"@H@("`@
M+RHJ"B`@("`@*B!3971S('1H92!F:6QE(&AA;F1L92!T;R!U<V4@=VET:"!P
M87)S92@I+@H@("`@("H*("`@("`J(%EO=2!S:&]U;&0@=7-E('-E=$EN<'5T
M1FEL92@I(&]R('-E=$EN<'5T4W1R:6YG*"D@:68@>6]U"B`@("`@*B!P87-S
M(&$@<W1R:6YG(`H@("`@("H*("`@("`J($!P87)A;2`@("!M:7AE9"`@)&9P
M("!#86X@8F4@96ET:&5R(&$@<F5S;W5R8V4@<F5T=7)N960@9G)O;2!F;W!E
M;B@I+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&$@55),+"!A(&QO
M8V%L(&9I;&5N86UE(&]R(&$@<W1R:6YG+@H@("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@("H@0'-E92`@("`@('!A<G-E*"D*("`@("`J($!U<V5S("`@
M("!S971);G!U=%-T<FEN9R@I+"!S971);G!U=$9I;&4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971);G!U="@D9G`I"B`@("!["B`@("`@("`@:68@*&ES
M7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@("`@)'1H:7,M/F9P(#T@)&9P
M.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@
M+R\@<V5E(&EF(&ET)W,@86X@86)S;VQU=&4@55),("AH87,@82!S8VAE;64@
M870@=&AE(&)E9VEN;FEN9RD*("`@("`@("!E;'-E:68@*&5R96=I*"=>6V$M
M>ETK.B\O)RP@<W5B<W1R*"1F<"P@,"P@,3`I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G-E=$EN<'5T1FEL92@D9G`I.PH@("`@("`@('T*("`@
M("`@("`O+R!S964@:68@:70G<R!A(&QO8V%L(&9I;&4*("`@("`@("!E;'-E
M:68@*&9I;&5?97AI<W1S*"1F<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS971);G!U=$9I;&4H)&9P*3L*("`@("`@("!]"B`@("`@("`@+R\@
M:70@;75S="!B92!A('-T<FEN9PH@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^9G`@/2`D9G`["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=)
M;&QE9V%L(&EN<'5T(&9O<FUA="<L(%A-3%]005)315)?15)23U)?24Y604Q)
M1%])3E!55"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<&%R<V4H
M*0H*("`@("\J*@H@("`@("H@0V5N=')A;"!P87)S:6YG(&9U;F-T:6]N+@H@
M("`@("H*("`@("`J($!R971U<FX@("!T<G5E?&]B:F5C="!014%2(&5R<F]R
M("`@("!R971U<FYS('1R=64@;VX@<W5C8V5S<RP@;W(@82!014%27T5R<F]R
M(&]T:&5R=VES90H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!P87)S92@I"B`@("!["B`@("`@("`@+RHJ"B`@("`@("`@
M("H@<F5S970@=&AE('!A<G-E<@H@("`@("`@("`J+PH@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^<F5S970H*3L*("`@("`@("!I9B`H)'1H:7,M/FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H@("`@("`@("\O(&EF("1T:&ES+3YF<"!W87,@9F]P96YE9"!P
M<F5V:6]U<VQY"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI
M('L*("`@("`@("`*("`@("`@("`@("`@=VAI;&4@*"1D871A(#T@9G)E860H
M)'1H:7,M/F9P+"`T,#DV*2D@>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7W!A<G-E4W1R:6YG*"1D871A+"!F96]F*"1T:&ES+3YF<"DI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&5R<F]R(#T@)B1T:&ES+3YR86ES945R<F]R
M*"D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@+R\@;W1H97)W:7-E+"`D=&AI<RT^
M9G`@;75S="!B92!A('-T<FEN9PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/E]P87)S95-T<FEN9R@D=&AI<RT^9G`L('1R=64I
M*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2`F)'1H:7,M/G)A:7-E17)R
M;W(H*3L*("`@("`@("`@("`@("`@("1T:&ES+3YF<F5E*"D["B`@("`@("`@
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3YF<F5E*"D["@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@6$U,7U!A<G-E<CHZ7W!A<G-E4W1R
M:6YG*"D*("`@("`J(`H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T80H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&5O9@H@("`@("H@0')E='5R;B!B;V]L"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S964@<&%R<V53=')I;F<H
M*0H@("`@("HJ+PH@("`@9G5N8W1I;VX@7W!A<G-E4W1R:6YG*"1D871A+"`D
M96]F(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T=7)N('AM;%]P87)S92@D
M=&AI<RT^<&%R<V5R+"`D9&%T82P@)&5O9BD["B`@("!]"B`@("`*("`@("\O
M('U]?0H@("`@+R\@>WM[('!A<G-E4W1R:6YG*"D*"B`@("`O*BH*("`@("`J
M(%A-3%]087)S97(Z.G!A<G-E4W1R:6YG*"D*("`@("`J(`H@("`@("H@4&%R
M<V5S(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2`@("!S=')I;F<@
M("1D871A(%A-3"!D871A"B`@("`@*B!`<&%R86T@("`@8F]O;&5A;B`D96]F
M("!)9B!S970@86YD(%12544L(&1A=&$@:7,@=&AE(&QA<W0@<&EE8V4@;V8@
M9&%T82!S96YT(&EN('1H:7,@<&%R<V5R"B`@("`@*B!`=&AR;W=S("`@6$U,
M7U!A<G-E<E]%<G)O<@H@("`@("H@0')E='5R;B`@(%!E87(@17)R;W)\=')U
M92`@('1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05(@17)R;W(*("`@("`J($!S
M964@("`@("!?<&%R<V53=')I;F<H*0H@("`@("HO"B`@("!F=6YC=&EO;B!P
M87)S95-T<FEN9R@D9&%T82P@)&5O9B`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/G!A<G-E<BD@?'P@(6ES7W)E<V]U<F-E*"1T
M:&ES+3YP87)S97(I*2!["B`@("`@("`@("`@("1T:&ES+3YR97-E="@I.PH@
M("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R<V53
M=')I;F<H)&1A=&$L("1E;V8I*2!["B`@("`@("`@("`@)&5R<F]R(#T@)B1T
M:&ES+3YR86ES945R<F]R*"D["B`@("`@("`@("`@)'1H:7,M/F9R964H*3L*
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1E;V8@/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/F9R964H
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`*
M("`@("\J*@H@("`@("H@6$U,7U!A<G-E<CHZ9G)E92@I"B`@("`@*B`*("`@
M("`J($9R964@=&AE(&EN=&5R;F%L(')E<V]U<F-E<R!A<W-O8VEA=&5D('=I
M=&@@=&AE('!A<G-E<@H@("`@("H@"B`@("`@*B!`<F5T=7)N(&YU;&P*("`@
M("`J*B\*("`@(&9U;F-T:6]N(&9R964H*0H@("`@>PH@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^<&%R<V5R*2`F)B!I<U]R97-O=7)C92@D=&AI<RT^<&%R
M<V5R*2D@>PH@("`@("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'1H:7,M/G!A
M<G-E<BD["B`@("`@("`@("`@('5N<V5T*"`D=&AI<RT^<&%R<V5R("D["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9G`I("8F(&ES7W)E
M<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@9F-L;W-E*"1T:&ES
M+3YF<"D["B`@("`@("`@?0H@("`@("`@('5N<V5T*"1T:&ES+3YF<"D["B`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@
M6$U,7U!A<G-E<CHZ<F%I<V5%<G)O<B@I"B`@("`@*B`*("`@("`J(%1H<F]W
M<R!A(%A-3%]087)S97)?17)R;W(*("`@("`J(`H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&US9R`@('1H92!E<G)O<B!M97-S86=E"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D96-O9&4@=&AE(&5R<F]R(&UE<W-A9V4@8V]D90H@("`@("H@
M0')E='5R;B!834Q?4&%R<V5R7T5R<F]R(`H@("`@("HJ+PH@("`@9G5N8W1I
M;VX@<F%I<V5%<G)O<B@D;7-G(#T@;G5L;"P@)&5C;V1E(#T@,"D*("`@('L*
M("`@("`@("`D;7-G(#T@(6ES7VYU;&PH)&US9RD@/R`D;7-G(#H@)'1H:7,M
M/G!A<G-E<CL*("`@("`@("`D97)R(#T@)FYE=R!834Q?4&%R<V5R7T5R<F]R
M*"1M<V<L("1E8V]D92D["B`@("`@("`@<F5T=7)N('!A<F5N=#HZ<F%I<V5%
M<G)O<B@D97)R*3L*("`@('T*("`@(`H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9G5N8U-T87)T2&%N9&QE<B@I"@H@("`@9G5N8W1I;VX@9G5N8U-T87)T2&%N
M9&QE<B@D>'`L("1E;&5M+"`D871T<FEB<RD*("`@('L*("`@("`@("`D9G5N
M8R`]("=X;6QT86=?)R`N("1E;&5M.PH@("`@("`@(&EF("AS=')C:'(H)&9U
M;F,L("<N)RDI('L*("`@("`@("`@("`@)&9U;F,@/2!S=')?<F5P;&%C92@G
M+B<L("=?)RP@)&9U;F,I.PH@("`@("`@('T*("`@("`@("!I9B`H;65T:&]D
M7V5X:7-T<R@D=&AI<RT^7VAA;F1L97)/8FHL("1F=6YC*2D@>PH@("`@("`@
M("`@("!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,M/E]H86YD;&5R3V)J
M+"`D9G5N8RDL("1X<"P@)&5L96TL("1A='1R:6)S*3L*("`@("`@("!](&5L
M<V5I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RT^7VAA;F1L97)/8FHL("=X;6QT
M86<G*2D@>PH@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H
M:7,M/E]H86YD;&5R3V)J+"`G>&UL=&%G)RDL("1X<"P@)&5L96TL("1A='1R
M:6)S*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9G5N8T5N9$AA;F1L97(H*0H*("`@(&9U;F-T:6]N(&9U;F-%;F1(86YD;&5R
M*"1X<"P@)&5L96TI"B`@("!["B`@("`@("`@)&9U;F,@/2`G>&UL=&%G7R<@
M+B`D96QE;2`N("=?)SL*("`@("`@("!I9B`H<W1R8VAR*"1F=6YC+"`G+B<I
M*2!["B`@("`@("`@("`@("1F=6YC(#T@<W1R7W)E<&QA8V4H)RXG+"`G7R<L
M("1F=6YC*3L*("`@("`@("!]"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H
M)'1H:7,M/E]H86YD;&5R3V)J+"`D9G5N8RDI('L*("`@("`@("`@("`@8V%L
M;%]U<V5R7V9U;F,H87)R87DH)B1T:&ES+3Y?:&%N9&QE<D]B:BP@)&9U;F,I
M+"`D>'`L("1E;&5M*3L*("`@("`@("!](&5L<V5I9B`H;65T:&]D7V5X:7-T
M<R@D=&AI<RT^7VAA;F1L97)/8FHL("=X;6QT86=?)RDI('L*("`@("`@("`@
M("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)B1T:&ES+3Y?:&%N9&QE<D]B:BP@
M)WAM;'1A9U\G*2P@)'AP+"`D96QE;2D["B`@("`@("`@?0H@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[('-T87)T2&%N9&QE<B@I"@H@("`@+RHJ"B`@
M("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('-T
M87)T2&%N9&QE<B@D>'`L("1E;&5M+"`F)&%T=')I8G,I"B`@("!["B`@("`@
M("`@<F5T=7)N($Y53$P["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M96YD2&%N9&QE<B@I"@H@("`@+RHJ"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H)'AP+"`D96QE;2D*
M("`@('L*("`@("`@("!R971U<FX@3E5,3#L*("`@('T*"@H@("`@+R\@?7U]
M;64*?0H*+RHJ"B`J(&5R<F]R(&-L87-S+"!R97!L86-E<R!014%27T5R<F]R
M"B`J"B`J($%N(&EN<W1A;F-E(&]F('1H:7,@8VQA<W,@=VEL;"!B92!R971U
M<FYE9`H@*B!I9B!A;B!E<G)O<B!O8V-U<G,@:6YS:61E(%A-3%]087)S97(N
M"B`J"B`J(%1H97)E(&%R92!T:')E92!A9'9A;G1A9V5S(&]V97(@=7-I;F<@
M=&AE('-T86YD87)D(%!%05)?17)R;W(Z"B`J("T@06QL(&UE<W-A9V5S('=I
M;&P@8F4@<')E9FEX960*("H@+2!C:&5C:R!F;W(@6$U,7U!A<G-E<B!E<G)O
M<BP@=7-I;F<@:7-?82@@)&5R<F]R+"`G6$U,7U!A<G-E<E]%<G)O<B<@*0H@
M*B`M(&UE<W-A9V5S(&-A;B!B92!G96YE<F%T960@9G)O;2!T:&4@>&UL7W!A
M<G-E<B!R97-O=7)C90H@*@H@*B!`<&%C:V%G92!834Q?4&%R<V5R"B`J($!A
M8V-E<W,@('!U8FQI8PH@*B!`<V5E("`@("!014%27T5R<F]R"B`J+PIC;&%S
M<R!834Q?4&%R<V5R7T5R<F]R(&5X=&5N9',@4$5!4E]%<G)O<@I["B`@("`O
M+R![>WL@<')O<&5R=&EE<PH*("`@+RHJ"B`@("`J('!R969I>"!F;W(@86QL
M(&UE<W-A9V5S"B`@("`J"B`@("`J($!V87(@("`@("!S=')I;F<*("`@("HO
M("`@(`H@("`@=F%R("1E<G)O<E]M97-S86=E7W!R969I>"`]("=834Q?4&%R
M<V5R.B`G.PH*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R*"D*
M("`@+RHJ"B`@("`J(&-O;G-T<G5C="!A(&YE=R!E<G)O<B!I;G-T86YC90H@
M("`@*@H@("`@*B!9;W4@;6%Y(&5I=&AE<B!P87-S(&$@;65S<V%G92!O<B!A
M;B!X;6Q?<&%R<V5R(')E<V]U<F-E(&%S(&9I<G-T"B`@("`J('!A<F%M971E
M<BX@268@82!R97-O=7)C92!H87,@8F5E;B!P87-S960L('1H92!L87-T(&5R
M<F]R('1H870*("`@("H@:&%P<&5N960@=VEL;"!B92!R971R:65V960@86YD
M(')E='5R;F5D+@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J
M($!P87)A;2`@("!S=')I;F=\<F5S;W5R8V4@("`@(&UE<W-A9V4@;W(@<&%R
M<V5R(')E<V]U<F-E"B`@("`J($!P87)A;2`@("!I;G1E9V5R("`@("`@("`@
M("`@(&5R<F]R(&-O9&4*("`@("H@0'!A<F%M("`@(&EN=&5G97(@("`@("`@
M("`@("`@97)R;W(@:&%N9&QI;F<*("`@("H@0'!A<F%M("`@(&EN=&5G97(@
M("`@("`@("`@("`@97)R;W(@;&5V96P*("`@("HO("`@(`H@("`@9G5N8W1I
M;VX@6$U,7U!A<G-E<E]%<G)O<B@D;7-G;W)P87)S97(@/2`G=6YK;F]W;B!E
M<G)O<B<L("1C;V1E(#T@,"P@)&UO9&4@/2!014%27T524D]27U)%5%523BP@
M)&QE=F5L(#T@15]54T527TY/5$E#12D*("`@('L*("`@("`@("!I9B`H:7-?
M<F5S;W5R8V4H)&US9V]R<&%R<V5R*2D@>PH@("`@("`@("`@("`D8V]D92`]
M('AM;%]G971?97)R;W)?8V]D92@D;7-G;W)P87)S97(I.PH@("`@("`@("`@
M("`D;7-G;W)P87)S97(@/2!S<')I;G1F*"<E<R!A="!834P@:6YP=70@;&EN
M92`E9#HE9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M>&UL7V5R<F]R7W-T<FEN9R@D8V]D92DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1M
M<V=O<G!A<G-E<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@>&UL7V=E=%]C=7)R96YT7V-O;'5M;E]N=6UB97(H)&US9V]R<&%R<V5R
M*2D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y014%27T5R<F]R*"1M<V=O
M<G!A<G-E<BP@)&-O9&4L("1M;V1E+"`D;&5V96PI.PH@("`@?0H@("`@+R\@
M?7U]"GT*/SX`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+UA-3"]5=&EL+G!H<```````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#8U,S8S`#$P-3$U-#,Q,#4W`#`Q-S0T-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/U!(
M4`T*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30Z("HO#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`R(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H
M('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@
M("`@('P-"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*
M+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R<SH@4W1E<&AA;B!38VAM
M:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/B`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@
M("`@)$ED.B!5=&EL+G!H<"QV(#$N,C0@,C`P-"\Q,B\R,R`Q,SHR,3HU.2!S
M8VAS="!%>'`@)`T*#0HO*BH-"B`J(&5R<F]R(&-O9&4@9F]R(&EN=F%L:60@
M8VAA<G,@:6X@6$U,(&YA;64-"B`J+PT*9&5F:6YE*")834Q?551)3%]%4E)/
M4E])3E9!3$E$7T-(05)3(BP@-3$I.PT*#0HO*BH-"B`J(&5R<F]R(&-O9&4@
M9F]R(&EN=F%L:60@8VAA<G,@:6X@6$U,(&YA;64-"B`J+PT*9&5F:6YE*")8
M34Q?551)3%]%4E)/4E])3E9!3$E$7U-405)4(BP@-3(I.PT*#0HO*BH-"B`J
M(&5R<F]R(&-O9&4@9F]R(&YO;BUS8V%L87(@=&%G(&-O;G1E;G0-"B`J+PT*
M9&5F:6YE*")834Q?551)3%]%4E)/4E].3TY?4T-!3$%27T-/3E1%3E0B+"`V
M,"D[#0H@("`@#0HO*BH-"B`J(&5R<F]R(&-O9&4@9F]R(&UI<W-I;F<@=&%G
M(&YA;64-"B`J+PT*9&5F:6YE*")834Q?551)3%]%4E)/4E].3U]404=?3D%-
M12(L(#8Q*3L-"B`@("`-"B\J*@T*("H@<F5P;&%C92!834P@96YT:71I97,-
M"B`J+PT*9&5F:6YE*")834Q?551)3%]215!,04-%7T5.5$E42453(BP@,2D[
M#0H-"B\J*@T*("H@96UB961D(&-O;G1E;G0@:6X@82!#1&%T82!396-T:6]N
M#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?0T1!5$%?4T5#5$E/3B(L(#4I.PT*
M#0HO*BH-"B`J(&1O(&YO="!R97!L86-E(&5N=&ET:71E<PT*("HO#0ID969I
M;F4H(EA-3%]55$E,7T5.5$E424537TY/3D4B+"`P*3L-"@T*+RHJ#0H@*B!R
M97!L86-E(&%L;"!834P@96YT:71I=&5S#0H@*B!4:&ES('-E='1I;F<@=VEL
M;"!R97!L86-E(#PL(#XL("(L("<@86YD("8-"B`J+PT*9&5F:6YE*")834Q?
M551)3%]%3E1)5$E%4U]834PB+"`Q*3L-"@T*+RHJ#0H@*B!R97!L86-E(&]N
M;'D@<F5Q=6ER960@6$U,(&5N=&ET:71E<PT*("H@5&AI<R!S971T:6YG('=I
M;&P@<F5P;&%C92`\+"`B(&%N9"`F#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?
M14Y4251)15-?6$U,7U)%455)4D5$(BP@,BD[#0H-"B\J*@T*("H@<F5P;&%C
M92!(5$U,(&5N=&ET:71E<PT*("H@0&QI;FL@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VAT;6QE;G1I=&EE<PT*("HO#0ID969I;F4H(EA-3%]55$E,7T5.5$E4
M24537TA434PB+"`S*3L-"@T*+RHJ#0H@*B!#;VQL87!S92!A;&P@96UP='D@
M=&%G<RX-"B`J+PT*9&5F:6YE*")834Q?551)3%]#3TQ,05!315]!3$PB+"`Q
M*3L-"@T*+RHJ#0H@*B!#;VQL87!S92!O;FQY(&5M<'1Y(%A(5$U,('1A9W,@
M=&AA="!H879E(&YO(&5N9"!T86<N#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?
M0T],3$%04T5?6$A434Q?3TY,62(L(#(I.PT*#0HO*BH-"B`J('5T:6QI='D@
M8VQA<W,@9F]R('=O<FMI;F<@=VET:"!834P@9&]C=6UE;G1S#0H@*@T*("H@
M0&-A=&5G;W)Y(%A-3`T*("H@0'!A8VMA9V4@(%A-3%]5=&EL#0H@*B!`=F5R
M<VEO;B`@,2XQ+C`-"B`J($!A=71H;W(@("!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"YN970^#0H@*B\-"F-L87-S(%A-3%]5=&EL('L-"@T*("`@+RHJ
M#0H@("`@*B!R971U<FX@05!)('9E<G-I;VX-"B`@("`J#0H@("`@*B!`86-C
M97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<F5T=7)N("`@
M<W1R:6YG("`D=F5R<VEO;B!!4$D@=F5R<VEO;@T*("`@("HO#0H@("`@9G5N
M8W1I;VX@87!I5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!R971U<FX@)S$N
M,2<[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(')E<&QA8V4@6$U,(&5N=&ET
M:65S#0H@("`@*@T*("`@("H@5VET:"!T:&4@;W!T:6]N86P@<V5C;VYD('!A
M<F%M971E<BP@>6]U(&UA>2!S96QE8W0L('=H:6-H#0H@("`@*B!E;G1I=&EE
M<R!S:&]U;&0@8F4@<F5P;&%C960N#0H@("`@*@T*("`@("H@/&-O9&4^#0H@
M("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@
M("`J("\O(')E<&QA8V4@6$U,(&5N=&ET97,Z#0H@("`@*B`D<W1R:6YG(#T@
M6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@B5&AI<R!S=')I;F<@8V]N=&%I
M;G,@/"`F(#XN(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@<W1R:6YG('=H97)E(%A-3"!S<&5C:6%L(&-H87)S('-H;W5L
M9"!B92!R97!L86-E9`T*("`@("H@0'!A<F%M("`@(&EN=&5G97(@<V5T=&EN
M9R!F;W(@96YT:71I97,@:6X@871T<FEB=71E('9A;'5E<R`H;VYE(&]F(%A-
M3%]55$E,7T5.5$E424537UA-3"P@6$U,7U5424Q?14Y4251)15-?6$U,7U)%
M455)4D5$+"!834Q?551)3%]%3E1)5$E%4U](5$U,*0T*("`@("H@0')E='5R
M;B`@('-T<FEN9R`@<W1R:6YG('=I=&@@<F5P;&%C960@8VAA<G,-"B`@("`J
M($!S964@("`@("!R979E<G-E16YT:71I97,H*0T*("`@("HO#0H@("`@9G5N
M8W1I;VX@<F5P;&%C945N=&ET:65S*"1S=')I;F<L("1R97!L86-E16YT:71I
M97,@/2!834Q?551)3%]%3E1)5$E%4U]834PI#0H@("`@>PT*("`@("`@("!S
M=VET8V@@*"1R97!L86-E16YT:71I97,I('L-"B`@("`@("`@("`@(&-A<V4@
M6$U,7U5424Q?14Y4251)15-?6$U,.@T*("`@("`@("`@("`@("`@(')E='5R
M;B!S=')T<B@D<W1R:6YG+&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R8G("`]/B`G)F%M<#LG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SXG("`]/B`G
M)F=T.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/"<@(#T^("<F;'0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B)R`@/3X@)R9Q=6]T.R<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7"<G(#T^("<F
M87!O<SLG("DI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92!834Q?551)3%]%3E1)5$E%4U]834Q?4D5154E2140Z#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('-T<G1R*"1S=')I;F<L87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)B<@(#T^
M("<F86UP.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G/"<@(#T^("<F;'0[)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<B)R`@/3X@)R9Q=6]T.R<@*2D[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E(%A-3%]5
M5$E,7T5.5$E424537TA434PZ#0H@("`@("`@("`@("`@("`@<F5T=7)N(&AT
M;6QE;G1I=&EE<R@D<W1R:6YG*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'-T<FEN9SL-"B`@("!]#0H-
M"B`@("\J*@T*("`@("H@<F5V97)S92!834P@96YT:71I97,-"B`@("`J#0H@
M("`@*B!7:71H('1H92!O<'1I;VYA;"!S96-O;F0@<&%R86UE=&5R+"!Y;W4@
M;6%Y('-E;&5C="P@=VAI8V@-"B`@("`J(&5N=&ET:65S('-H;W5L9"!B92!R
M979E<G-E9"X-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?
M;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@<F5V97)S
M92!834P@96YT:71E<SH-"B`@("`J("1S=')I;F<@/2!834Q?571I;#HZ<F5V
M97)S945N=&ET:65S*")4:&ES('-T<FEN9R!C;VYT86EN<R`F;'0[("9A;7`[
M("9G=#LN(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@<W1R:6YG('=H97)E(%A-3"!S<&5C:6%L(&-H87)S('-H;W5L9"!B
M92!R97!L86-E9`T*("`@("H@0'!A<F%M("`@(&EN=&5G97(@<V5T=&EN9R!F
M;W(@96YT:71I97,@:6X@871T<FEB=71E('9A;'5E<R`H;VYE(&]F(%A-3%]5
M5$E,7T5.5$E424537UA-3"P@6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)
M4D5$+"!834Q?551)3%]%3E1)5$E%4U](5$U,*0T*("`@("H@0')E='5R;B`@
M('-T<FEN9R`@<W1R:6YG('=I=&@@<F5P;&%C960@8VAA<G,-"B`@("`J($!S
M964@("`@("!R97!L86-E16YT:71I97,H*0T*("`@("HO#0H@("`@9G5N8W1I
M;VX@<F5V97)S945N=&ET:65S*"1S=')I;F<L("1R97!L86-E16YT:71I97,@
M/2!834Q?551)3%]%3E1)5$E%4U]834PI#0H@("`@>PT*("`@("`@("!S=VET
M8V@@*"1R97!L86-E16YT:71I97,I('L-"B`@("`@("`@("`@(&-A<V4@6$U,
M7U5424Q?14Y4251)15-?6$U,.@T*("`@("`@("`@("`@("`@(')E='5R;B!S
M=')T<B@D<W1R:6YG+&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R9A;7`[)R`@/3X@)R8G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R9G=#LG("`@/3X@
M)SXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R9L=#LG("`@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R9Q=6]T.R<@/3X@)R(G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R9A<&]S.R<@/3X@
M)UPG)R`I*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)4D5$.@T*("`@("`@
M("`@("`@("`@(')E='5R;B!S=')T<B@D<W1R:6YG+&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R9A;7`[)R`@
M/3X@)R8G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R9L=#LG("`@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R9Q=6]T.R<@/3X@)R(G("DI.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!834Q?551)
M3%]%3E1)5$E%4U](5$U,.@T*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A
M>5]F;&EP*&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A8FQE*$A434Q?14Y4251)
M15,I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@<W1R='(H)'-T<FEN9RP@
M)&%R<BD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1S=')I;F<[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J
M(&)U:6QD(&%N('AM;"!D96-L87)A=&EO;@T*("`@("H-"B`@("`J(#QC;V1E
M/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@
M#0H@("`@*B`O+R!G970@86X@6$U,(&1E8VQA<F%T:6]N.@T*("`@("H@)'AM
M;$1E8VP@/2!834Q?571I;#HZ9V5T6$U,1&5C;&%R871I;VXH(C$N,"(L(")5
M5$8M."(L('1R=64I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1V97)S:6]N("`@("!X;6P@=F5R<VEO;@T*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@)&5N8V]D:6YG("`@(&-H87)A8W1E<B!E;F-O9&EN
M9PT*("`@("H@0'!A<F%M("`@(&)O;VQE86X@)'-T86YD06QO;F4@(&1O8W5M
M96YT(&ES('-T86YD86QO;F4@*&]R(&YO="D-"B`@("`J($!R971U<FX@("!S
M=')I;F<@("1D96-L('AM;"!D96-L87)A=&EO;@T*("`@("H@0'5S97,@("`@
M(%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H*2!T;R!S97)I86QI>F4@
M=&AE(&%T=')I8G5T97,@;V8@=&AE(%A-3"!D96-L87)A=&EO;@T*("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T6$U,1&5C;&%R871I;VXH)'9E<G-I;VX@/2`B
M,2XP(BP@)&5N8V]D:6YG(#T@;G5L;"P@)'-T86YD86QO;F4@/2!N=6QL*0T*
M("`@('L-"B`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`B=F5R<VEO;B(@/3X@)'9E<G-I;VXL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`O+R!A9&0@
M96YC;V1I;F<-"B`@("`@("`@:68@*"1E;F-O9&EN9R`A/3T@;G5L;"D@>PT*
M("`@("`@("`@("`@)&%T=')I8G5T97-;(F5N8V]D:6YG(ET@/2`D96YC;V1I
M;F<[#0H@("`@("`@('T-"B`@("`@("`@+R\@861D('-T86YD86QO;F4L(&EF
M('-P96-I9FEE9`T*("`@("`@("!I9B`H)'-T86YD86QO;F4@(3T](&YU;&PI
M('L-"B`@("`@("`@("`@("1A='1R:6)U=&5S6R)S=&%N9&%L;VYE(ET@/2`D
M<W1A;F1A;&]N92`_(")Y97,B(#H@(FYO(CL-"B`@("`@("`@?0T*("`@("`@
M("`-"B`@("`@("`@<F5T=7)N('-P<FEN=&8H(CP_>&UL)7,_/B(L(%A-3%]5
M=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H)&%T=')I8G5T97,L(&9A;'-E*2D[
M#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&)U:6QD(&$@9&]C=6UE;G0@='EP
M92!D96-L87)A=&EO;@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q
M=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!G
M970@82!D;V-T>7!E(&1E8VQA<F%T:6]N.@T*("`@("H@)'AM;$1E8VP@/2!8
M34Q?571I;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*")R;V]T5&%G(BPB;7E$
M;V-4>7!E+F1T9"(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1R;V]T("`@("`@("`@;F%M92!O9B!T:&4@<F]O="!T86<-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1U<FD@("`@("`@("`@=7)I(&]F
M('1H92!D;V-T>7!E(&1E9FEN:71I;VX@*&]R(&%R<F%Y('=I=&@@=7)I(&%N
M9"!P=6)L:6,@:60I#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D:6YT97)N
M86Q$=&0@(&EN=&5R;F%L(&1T9"!E;G1R:65S("`@#0H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("`D9&5C;"`@("`@("`@(&1O8W1Y<&4@9&5C;&%R871I;VX-
M"B`@("`J($!S:6YC92`@("`P+C(-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=$1O8U1Y<&5$96-L87)A=&EO;B@D<F]O="P@)'5R:2`](&YU;&PL("1I;G1E
M<FYA;$1T9"`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H:7-?87)R87DH
M)'5R:2DI('L-"B`@("`@("`@("`@("1R968@/2!S<')I;G1F*"`G(%!50DQ)
M0R`B)7,B("(E<R(G+"`D=7)I6R)I9")=+"`D=7)I6R)U<FDB72`I.PT*("`@
M("`@("!](&5L<V5I9B`H(65M<'1Y*"1U<FDI*2![#0H@("`@("`@("`@("`D
M<F5F(#T@<W!R:6YT9B@@)R!365-414T@(B5S(B<L("1U<FD@*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R968@/2`B(CL-"B`@("`@("`@
M?0T*#0H@("`@("`@(&EF("AE;7!T>2@D:6YT97)N86Q$=&0I*2![#0H@("`@
M("`@("`@("!R971U<FX@<W!R:6YT9B@B/"%$3T-465!%("5S)7,^(BP@)')O
M;W0L("1R968I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T
M=7)N('-P<FEN=&8H(CPA1$]#5%E012`E<R5S(%M<;B5S7&Y=/B(L("1R;V]T
M+"`D<F5F+"`D:6YT97)N86Q$=&0I.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`O*BH-"B`@("`J(&-R96%T92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@
M86X@871T<FEB=71E(&QI<W0-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J
M(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@
M+R\@8G5I;&0@86X@871T<FEB=71E('-T<FEN9PT*("`@("H@)&%T="`](&%R
M<F%Y*`T*("`@("H@("`@("`@("`@("`@(")F;V\B("`@/3X@(")B87(B+`T*
M("`@("H@("`@("`@("`@("`@(")A<F=H(B`@/3X@(")T;VUA=&\B#0H@("`@
M*B`@("`@("`@("`@("D[#0H@("`@*@T*("`@("H@)&%T=$QI<W0@/2!834Q?
M571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='0I.R`@("`-"B`@("`J(#PO
M8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`
M<W1A=&EC#0H@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@("`D871T<FEB
M=71E<R`@("`@("`@871T<FEB=71E(&%R<F%Y#0H@("`@*B!`<&%R86T@("`@
M8F]O;&5A;GQA<G)A>2`D<V]R="`@("`@("`@("`@("`@<V]R="!A='1R:6)U
M=&4@;&ES="!A;'!H86)E=&EC86QL>2P@;6%Y(&%L<V\@8F4@86X@87-S;V,@
M87)R87D@8V]N=&%I;FEN9R!T:&4@:V5Y<R`G<V]R="<L("=M=6QT:6QI;F4G
M+"`G:6YD96YT)RP@)VQI;F5B<F5A:R<@86YD("=E;G1I=&EE<R<-"B`@("`J
M($!P87)A;2`@("!B;V]L96%N("`@("`@("1M=6QT:6QI;F4@("`@("`@("!U
M<V4@;&EN96)R96%K<RP@:68@;6]R92!T:&%N(&]N92!A='1R:6)U=&4@:7,@
M9VEV96X-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("1I;F1E;G0@
M("`@("`@("`@("!S=')I;F<@=7-E9"!F;W(@:6YD96YT871I;VX@;V8@;75L
M=&EL:6YE(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@
M("`@("1L:6YE8G)E86L@("`@("`@("!S=')I;F<@=7-E9"!F;W(@;&EN96)R
M96%K<R!O9B!M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@
M(&EN=&5G97(@("`@("`@)&5N=&ET:65S("`@("`@("`@('-E='1I;F<@9F]R
M(&5N=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,@*&]N92!O9B!834Q?551)
M3%]%3E1)5$E%4U].3TY%+"!834Q?551)3%]%3E1)5$E%4U]834PL(%A-3%]5
M5$E,7T5.5$E424537UA-3%]215%525)%1"P@6$U,7U5424Q?14Y4251)15-?
M2%1-3"D-"B`@("`J($!R971U<FX@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&%T=')I
M8G5T97,-"B`@("`J($!U<V5S("`@("!834Q?571I;#HZ<F5P;&%C945N=&ET
M:65S*"D@=&\@<F5P;&%C92!834P@96YT:71I97,@:6X@871T<FEB=71E('9A
M;'5E<PT*("`@("H@0'1O9&\@("`@(&%L;&]W('-O<G0@86QS;R!T;R!B92!A
M;B!O<'1I;VYS(&%R<F%Y#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A='1R:6)U
M=&5S5&]3=')I;F<H)&%T=')I8G5T97,L("1S;W)T(#T@=')U92P@)&UU;'1I
M;&EN92`](&9A;'-E+"`D:6YD96YT(#T@)R`@("`G+"`D;&EN96)R96%K(#T@
M(EQN(BP@)&5N=&ET:65S(#T@6$U,7U5424Q?14Y4251)15-?6$U,*0T*("`@
M('L-"B`@("`@("`@+RHJ#0H@("`@("`@("`J('-E8V]N9"!P87)A;65T97(@
M;6%Y(&)E(&%N(&%R<F%Y#0H@("`@("`@("`J+PT*("`@("`@("!I9B`H:7-?
M87)R87DH)'-O<G0I*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;
M)VUU;'1I;&EN92==*2D@>PT*("`@("`@("`@("`@("`@("1M=6QT:6QI;F4@
M/2`D<V]R=%LG;75L=&EL:6YE)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'-O<G1;)VEN9&5N="==*2D@>PT*("`@("`@("`@
M("`@("`@("1I;F1E;G0@/2`D<V]R=%LG:6YD96YT)UT[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;)VQI;F5B<F5A:R==
M*2D@>PT*("`@("`@("`@("`@("`@("1M=6QT:6QI;F4@/2`D<V]R=%LG;&EN
M96)R96%K)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'-O<G1;)V5N=&ET:65S)UTI*2![#0H@("`@("`@("`@("`@("`@)&5N
M=&ET:65S(#T@)'-O<G1;)V5N=&ET:65S)UT[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;)W-O<G0G72DI('L-"B`@("`@
M("`@("`@("`@("`D<V]R="`]("1S;W)T6R=S;W)T)UT[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1S;W)T(#T@=')U93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<W1R:6YG(#T@)R<[
M#0H@("`@("`@(&EF("AI<U]A<G)A>2@D871T<FEB=71E<RD@)B8@(65M<'1Y
M*"1A='1R:6)U=&5S*2D@>PT*("`@("`@("`@("`@:68@*"1S;W)T*2![#0H@
M("`@("`@("`@("`@("`@:W-O<G0H)&%T=')I8G5T97,I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68H("$D;75L=&EL:6YE('Q\(&-O=6YT*"1A
M='1R:6)U=&5S*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1E;G1I=&EE<R`A/2!834Q?551)3%]%3E1)5$E%4U].
M3TY%*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&5N=&ET:65S
M(#T]/2!834Q?551)3%]#1$%405]314-424].*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`))&5N=&ET:65S(#T@6$U,7U5424Q?14Y4251)15-?6$U,
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E(#T@6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D
M=F%L=64L("1E;G1I=&EE<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`G("<N)&ME>2XG/2(G+B1V
M86QU92XG(B<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D9FER<W0@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A
M;'5E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D96YT:71I97,@(3T@
M6$U,7U5424Q?14Y4251)15-?3D].12D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A;'5E(#T@6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=F%L
M=64L("1E;G1I=&EE<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1F:7)S="D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'-T<FEN9R`N/2`B("(N)&ME>2XG/2(G+B1V86QU92XG(B<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D9FER<W0@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S=')I;F<@+CT@)&QI;F5B<F5A:RXD:6YD96YT+B1K97DN)STB
M)RXD=F%L=64N)R(G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D<W1R:6YG.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!#;VQL
M87!S97,@96UP='D@=&%G<RX-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B
M;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D
M>&UL("!834P-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("1M;V1E(%=H971H
M97(@=&\@8V]L;&%P<V4@86QL(&5M<'1Y('1A9W,@*%A-3%]55$E,7T-/3$Q!
M4%-%7T%,3"D@;W(@;VYL>2!82%1-3"`H6$U,7U5424Q?0T],3$%04T5?6$A4
M34Q?3TY,62D@;VYE<RX-"B`@("`J($!R971U<FX@("!S=')I;F<@("1X;6P@
M(%A-3`T*("`@("HO#0H@("`@9G5N8W1I;VX@8V]L;&%P<V5%;7!T>51A9W,H
M)'AM;"P@)&UO9&4@/2!834Q?551)3%]#3TQ,05!315]!3$PI('L-"B`@("`@
M("`@:68@*"1M;V1E(#T](%A-3%]55$E,7T-/3$Q!4%-%7UA(5$U,7T].3%DI
M('L-"B`@("`@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H#0H@("`@("`@
M("`@("`@("<O/"AA<F5A?&)A<V5\8G)\8V]L?&AR?&EM9WQI;G!U='QL:6YK
M?&UE=&%\<&%R86TI*%M>/ETJ*3X\7"]<7#$^+W,G+`T*("`@("`@("`@("`@
M("`G/%Q<,5Q<,B`O/B<L#0H@("`@("`@("`@("`@("1X;6P-"B`@("`@("`@
M("`@("D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@
M<')E9U]R97!L86-E*`T*("`@("`@("`@("`@("`G+SPH7'<K*2A;7CY=*BD^
M/%PO7%PQ/B]S)RP-"B`@("`@("`@("`@("`@)SQ<7#%<7#(@+SXG+`T*("`@
M("`@("`@("`@("`D>&UL#0H@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`O*BH-"B`@("`J(&-R96%T92!A('1A9PT*("`@("H-"B`@
M("`J(%1H:7,@;65T:&]D('=I;&P@8V%L;"!834Q?571I;#HZ8W)E871E5&%G
M1G)O;4%R<F%Y*"DL('=H:6-H#0H@("`@*B!I<R!M;W)E(&9L97AI8FQE+@T*
M("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO
M571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,('1A
M9SH-"B`@("`J("1T86<@/2!834Q?571I;#HZ8W)E871E5&%G*")M>4YS.FUY
M5&%G(BP@87)R87DH(F9O;R(@/3X@(F)A<B(I+"`B5&AI<R!I<R!I;G-I9&4@
M=&AE('1A9R(L(")H='1P.B\O=W=W+G<S8RYO<F<O;7E.<R,B*3L-"B`@("`J
M(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<6YA;64@("`@
M("`@("`@("`@<75A;&EF:65D('1A9VYA;64@*&EN8VQU9&EN9R!N86UE<W!A
M8V4I#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@("`@
M("`@87)R87D@8V]N=&%I;F<@871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@
M(&UI>&5D("`@)&-O;G1E;G0-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1N
M86UE<W!A8V55<FD@("`@("!54DD@;V8@=&AE(&YA;65S<&%C90T*("`@("H@
M0'!A<F%M("`@(&EN=&5G97(@)')E<&QA8V5%;G1I=&EE<R`@('=H971H97(@
M=&\@<F5P;&%C92!834P@<W!E8VEA;"!C:&%R<R!I;B!C;VYT96YT+"!E;6)E
M9&0@:70@:6X@82!#1&%T82!S96-T:6]N(&]R(&YO;F4@;V8@8F]T:`T*("`@
M("H@0'!A<F%M("`@(&)O;VQE86X@)&UU;'1I;&EN92`@("`@("`@('=H971H
M97(@=&\@8W)E871E(&$@;75L=&EL:6YE('1A9R!W:&5R92!E86-H(&%T=')I
M8G5T92!G971S('=R:71T96X@=&\@82!S:6YG;&4@;&EN90T*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@)&EN9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D
M('1O(&EN9&5N="!A='1R:6)U=&5S("A?875T;R!I;F1E;G1S(&%T=')I8G5T
M97,@<V\@=&AE>2!S=&%R="!A="!T:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S
M960@9F]R(&QI;F5B<F5A:W,-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S
M=')I;F<@("`@("`@("`@("!834P@=&%G#0H@("`@*B!`<V5E("`@("`@6$U,
M7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@I#0H@("`@*B!`=7-E<R`@("`@
M6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@I('1O(&-R96%T92!T:&4@
M=&%G#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5486<H)'%N86UE+"`D
M871T<FEB=71E<R`](&%R<F%Y*"DL("1C;VYT96YT(#T@;G5L;"P@)&YA;65S
M<&%C955R:2`](&YU;&PL("1R97!L86-E16YT:71I97,@/2!834Q?551)3%]2
M15!,04-%7T5.5$E42453+"`D;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@
M/2`B7V%U=&\B+"`D;&EN96)R96%K(#T@(EQN(BD-"B`@("![#0H@("`@("`@
M("1T86<@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@(")Q;F%M92(@
M("`@("`]/B`D<6YA;64L#0H@("`@("`@("`@("`@("`@("`@("`B871T<FEB
M=71E<R(@/3X@)&%T=')I8G5T97,-"B`@("`@("`@("`@("`@("`@("`@*3L-
M"@T*("`@("`@("`O+R!A9&0@=&%G(&-O;G1E;G0-"B`@("`@("`@:68@*"1C
M;VYT96YT("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D=&%G6R)C;VYT96YT
M(ET@/2`D8V]N=&5N=#L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@
M+R\@861D(&YA;65S<&%C92!5<FD-"B`@("`@("`@:68@*"1N86UE<W!A8V55
M<FD@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1T86=;(FYA;65S<&%C955R
M:2)=(#T@)&YA;65S<&%C955R:3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E
M='5R;B!834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L
M86-E16YT:71I97,L("1M=6QT:6QI;F4L("1I;F1E;G0L("1L:6YE8G)E86LI
M.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@82!T86<@9G)O;2!A
M;B!A<G)A>0T*("`@("H@=&AI<R!M971H;V0@87=A:71S(&%N(&%R<F%Y(&EN
M('1H92!F;VQL;W=I;F<@9F]R;6%T#0H@("`@*B`\<')E/@T*("`@("H@87)R
M87DH#0H@("`@*B`@(G%N86UE(B`@("`@("`@/3X@)'%N86UE("`@("`@("`@
M+R\@<75A;&EF:65D(&YA;64@;V8@=&AE('1A9PT*("`@("H@(")N86UE<W!A
M8V4B("`@(#T^("1N86UE<W!A8V4@("`@("\O(&YA;65S<&%C92!P<F5F:7@@
M*&]P=&EO;F%L+"!I9B!Q;F%M92!I<R!S<&5C:69I960@;W(@;F\@;F%M97-P
M86-E*0T*("`@("H@(")L;V-A;'!A<G0B("`@(#T^("1L;V-A;'!A<G0L("`@
M("\O(&QO8V%L('!A<G0@;V8@=&AE('1A9VYA;64@*&]P=&EO;F%L+"!I9B!Q
M;F%M92!I<R!S<&5C:69I960I#0H@("`@*B`@(F%T=')I8G5T97,B("`@/3X@
M87)R87DH*2P@("`@("`@+R\@87)R87D@8V]N=&%I;FEN9R!A;&P@871T<FEB
M=71E<R`H;W!T:6]N86PI#0H@("`@*B`@(F-O;G1E;G0B("`@("`@/3X@)&-O
M;G1E;G0L("`@("`@+R\@=&%G(&-O;G1E;G0@*&]P=&EO;F%L*0T*("`@("H@
M(")N86UE<W!A8V55<FDB(#T^("1N86UE<W!A8V55<FD@("\O(&YA;65S<&%C
M955R:2!F;W(@=&AE(&=I=F5N(&YA;65S<&%C92`H;W!T:6]N86PI#0H@("`@
M*B`@("D-"B`@("`J(#PO<')E/@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@
M("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@
M*B`D=&%G(#T@87)R87DH#0H@("`@*B`@("`@("`@("`@(G%N86UE(B`@("`@
M("`@/3X@(F9O;SIB87(B+`T*("`@("H@("`@("`@("`@(")N86UE<W!A8V55
M<FDB(#T^(")H='1P.B\O9F]O+F-O;2(L#0H@("`@*B`@("`@("`@("`@(F%T
M=')I8G5T97,B("`@/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A<F=H
M(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`T*("`@("H@("`@("`@("`@(")C
M;VYT96YT(B`@("`@(#T^(")))VT@:6YS:61E('1H92!T86<B+`T*("`@("H@
M("`@("`@("`@("`I.PT*("`@("H@+R\@8W)E871I;F<@82!T86<@=VET:"!Q
M=6%L:69I960@;F%M92!A;F0@;F%M97-P86-E57)I#0H@("`@*B`D<W1R:6YG
M(#T@6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*3L-"B`@("`J
M(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D=&%G("`@("`@
M("`@("`@("`@=&%G(&1E9FEN:71I;VX-"B`@("`J($!P87)A;2`@("!I;G1E
M9V5R("1R97!L86-E16YT:71I97,@("!W:&5T:&5R('1O(')E<&QA8V4@6$U,
M('-P96-I86P@8VAA<G,@:6X@8V]N=&5N="P@96UB961D(&ET(&EN(&$@0T1A
M=&$@<V5C=&EO;B!O<B!N;VYE(&]F(&)O=&@-"B`@("`J($!P87)A;2`@("!B
M;V]L96%N("1M=6QT:6QI;F4@("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A
M(&UU;'1I;&EN92!T86<@=VAE<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET
M=&5N('1O(&$@<VEN9VQE(&QI;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("1I;F1E;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T
M<FEB=71E<R`H7V%U=&\@:6YD96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A
M<G0@870@=&AE('-A;64@8V]L=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)&QI;F5B<F5A:R`@("`@("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E
M86MS#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@("`@("`@
M("`@6$U,('1A9PT*("`@("H@0'-E92`@("`@(%A-3%]5=&EL.CIC<F5A=&54
M86<H*0T*("`@("H@0'5S97,@("`@(%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3
M=')I;F<H*2!T;R!S97)I86QI>F4@=&AE(&%T=')I8G5T97,@;V8@=&AE('1A
M9PT*("`@("H@0'5S97,@("`@(%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA
M;64H*2!T;R!G970@;&]C86P@<&%R="!A;F0@;F%M97-P86-E(&]F(&$@<75A
M;&EF:65D(&YA;64-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T951A9T9R
M;VU!<G)A>2@D=&%G+"`D<F5P;&%C945N=&ET:65S(#T@6$U,7U5424Q?4D50
M3$%#15]%3E1)5$E%4RP@)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@
M(E]A=71O(BP@)&QI;F5B<F5A:R`](")<;B(@*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T86=;)V-O;G1E;G0G72D@)B8@(6ES7W-C86QA<B@D=&%G
M6R=C;VYT96YT)UTI*2![#0H@("`@("`@("`@("!R971U<FX@6$U,7U5T:6PZ
M.G)A:7-E17)R;W(H("=3=7!P;&EE9"!N;VXM<V-A;&%R('9A;'5E(&%S('1A
M9R!C;VYT96YT)RP@6$U,7U5424Q?15)23U)?3D].7U-#04Q!4E]#3TY414Y4
M("D[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H(6ES<V5T*"1T86=;)W%N
M86UE)UTI("8F("%I<W-E="@D=&%G6R=L;V-A;%!A<G0G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B!834Q?571I;#HZ<F%I<V5%<G)O<B@@)UEO=2!M=7-T
M(&5I=&AE<B!S=7!P;'D@82!Q=6%L:69I960@;F%M92`H<6YA;64I(&]R(&QO
M8V%L('1A9R!N86UE("AL;V-A;%!A<G0I+B<L(%A-3%]55$E,7T524D]27TY/
M7U1!1U].04U%("D[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!I9B!N;R!A
M='1R:6)U=&5S(&AA=B!B965N('-E="P@=7-E(&5M<'1Y(&%T=')I8G5T97,-
M"B`@("`@("`@:68@*"%I<W-E="@D=&%G6R)A='1R:6)U=&5S(ETI('Q\("%I
M<U]A<G)A>2@D=&%G6R)A='1R:6)U=&5S(ETI*2![#0H@("`@("`@("`@("`D
M=&%G6R)A='1R:6)U=&5S(ET@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@
M("`@(`T*("`@("`@("`O+R!Q=6%L:69I960@;F%M92!I<R!N;W0@9VEV96X-
M"B`@("`@("`@:68@*"%I<W-E="@D=&%G6R)Q;F%M92)=*2D@>PT*("`@("`@
M("`@("`@+R\@8VAE8VL@9F]R(&YA;65S<&%C90T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T86=;(FYA;65S<&%C92)=*2`F)B`A96UP='DH)'1A9ULB;F%M
M97-P86-E(ETI*2![#0H@("`@("`@("`@("`@("`@)'1A9ULB<6YA;64B72`]
M("1T86=;(FYA;65S<&%C92)=+B(Z(BXD=&%G6R)L;V-A;%!A<G0B73L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1A9ULB<6YA
M;64B72`]("1T86=;(FQO8V%L4&%R=")=.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`O+R!N86UE<W!A8V4@55))(&ES('-E="P@8G5T(&YO(&YA;65S<&%C
M90T*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1A9ULB;F%M97-P86-E57)I
M(ETI("8F("%I<W-E="@D=&%G6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@
M("`@("1P87)T<R`](%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H)'1A
M9ULB<6YA;64B72D[#0H@("`@("`@("`@("`D=&%G6R)L;V-A;%!A<G0B72`]
M("1P87)T<ULB;&]C86Q087)T(ET[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'!A<G1S6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@("`@("`@("`D=&%G
M6R)N86UE<W!A8V4B72`]("1P87)T<ULB;F%M97-P86-E(ET[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S970H)'1A9ULB
M;F%M97-P86-E57)I(ETI("8F("%E;7!T>2@D=&%G6R)N86UE<W!A8V55<FDB
M72DI('L-"B`@("`@("`@("`@("\O(&ES(&$@;F%M97-P86-E(&=I=F5N#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'1A9ULB;F%M97-P86-E(ETI("8F("%E
M;7!T>2@D=&%G6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@("`@("`@("`D
M=&%G6R)A='1R:6)U=&5S(EU;(GAM;&YS.B(N)'1A9ULB;F%M97-P86-E(EU=
M(#T@)'1A9ULB;F%M97-P86-E57)I(ET[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("\O(&1E9FEN92!T:&ES(%5R:2!A<R!T:&4@
M9&5F875L="!N86UE<W!A8V4-"B`@("`@("`@("`@("`@("`D=&%G6R)A='1R
M:6)U=&5S(EU;(GAM;&YS(ET@/2`D=&%G6R)N86UE<W!A8V55<FDB73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O(&-H96-K(&9O
M<B!M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("`@("!I9B`H)&UU;'1I;&EN
M92`]/3T@=')U92D@>PT*("`@("`@("`@("`@:68@*"1I;F1E;G0@/3T](")?
M875T;R(I('L-"B`@("`@("`@("`@("`@("`D:6YD96YT(#T@<W1R7W)E<&5A
M="@B("(L("AS=')L96XH)'1A9ULB<6YA;64B72DK,BDI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`O+R!C<F5A=&4@
M871T<FEB=71E(&QI<W0-"B`@("`@("`@)&%T=$QI<W0@("`@/2`@(%A-3%]5
M=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H)'1A9ULG871T<FEB=71E<R==+"!T
M<G5E+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R96%K+"`D<F5P;&%C
M945N=&ET:65S("D[#0H@("`@("`@(&EF("@A:7-S970H)'1A9ULG8V]N=&5N
M="==*2!\?"`H<W1R:6YG*21T86=;)V-O;G1E;G0G72`]/2`G)RD@>PT*("`@
M("`@("`@("`@)'1A9R`@("`]("`@<W!R:6YT9B@G/"5S)7,@+SXG+"`D=&%G
M6R=Q;F%M92==+"`D871T3&ES="D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!S=VET8V@@*"1R97!L86-E16YT:71I97,I('L-"B`@("`@("`@
M("`@("`@("!C87-E(%A-3%]55$E,7T5.5$E424537TY/3D4Z#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@6$U,
M7U5424Q?0T1!5$%?4T5#5$E/3CH-"B`@("`@("`@("`@("`@("`@("`@)'1A
M9ULG8V]N=&5N="==(#T@6$U,7U5T:6PZ.F-R96%T94-$871A4V5C=&EO;B@D
M=&%G6R=C;VYT96YT)UTI.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@("`@("`@
M("`D=&%G6R=C;VYT96YT)UT@/2!834Q?571I;#HZ<F5P;&%C945N=&ET:65S
M*"1T86=;)V-O;G1E;G0G72P@)')E<&QA8V5%;G1I=&EE<RD[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1A9R`@("`]("`@<W!R:6YT9B@G/"5S)7,^)7,\+R5S/B<L("1T86=;
M)W%N86UE)UTL("1A='1,:7-T+"`D=&%G6R=C;VYT96YT)UTL("1T86=;)W%N
M86UE)UT@*3L-"B`@("`@("`@?2`@("`@("`@#0H@("`@("`@(')E='5R;B`@
M)'1A9SL-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8W)E871E(&$@<W1A<G0@
M96QE;65N=`T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O
M;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C<F5A=&4@
M86X@6$U,('-T87)T(&5L96UE;G0Z#0H@("`@*B`D=&%G(#T@6$U,7U5T:6PZ
M.F-R96%T95-T87)T16QE;65N="@B;7E.<SIM>51A9R(L(&%R<F%Y*")F;V\B
M(#T^(")B87(B*2`L(FAT='`Z+R]W=W<N=S-C+F]R9R]M>4YS(R(I.PT*("`@
M("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1Q;F%M92`@
M("`@("`@("`@("!Q=6%L:69I960@=&%G;F%M92`H:6YC;'5D:6YG(&YA;65S
M<&%C92D-"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1A='1R:6)U=&5S("`@
M("`@("!A<G)A>2!C;VYT86EN9R!A='1R:6)U=&5S#0H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`D;F%M97-P86-E57)I("`@("`@55))(&]F('1H92!N86UE
M<W!A8V4-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1M=6QT:6QI;F4@("`@
M("`@("!W:&5T:&5R('1O(&-R96%T92!A(&UU;'1I;&EN92!T86<@=VAE<F4@
M96%C:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N('1O(&$@<VEN9VQE(&QI;F4-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1I;F1E;G0@("`@("`@("`@("!S
M=')I;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB=71E<R`H7V%U=&\@:6YD96YT
M<R!A='1R:6)U=&5S('-O('1H97D@<W1A<G0@870@=&AE('-A;64@8V]L=6UN
M*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@("`@("`@
M('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS#0H@("`@*B!`<F5T=7)N("`@
M<W1R:6YG("`D<W1R:6YG("`@("`@("`@("`@6$U,('-T87)T(&5L96UE;G0-
M"B`@("`J($!S964@("`@("!834Q?571I;#HZ8W)E871E16YD16QE;65N="@I
M+"!834Q?571I;#HZ8W)E871E5&%G*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(&-R96%T95-T87)T16QE;65N="@D<6YA;64L("1A='1R:6)U=&5S(#T@87)R
M87DH*2P@)&YA;65S<&%C955R:2`](&YU;&PL("1M=6QT:6QI;F4@/2!F86QS
M92P@)&EN9&5N="`]("=?875T;R<L("1L:6YE8G)E86L@/2`B7&XB*0T*("`@
M('L-"B`@("`@("`@+R\@:68@;F\@871T<FEB=71E<R!H878@8F5E;B!S970L
M('5S92!E;7!T>2!A='1R:6)U=&5S#0H@("`@("`@(&EF("@A:7-S970H)&%T
M=')I8G5T97,I('Q\("%I<U]A<G)A>2@D871T<FEB=71E<RDI('L-"B`@("`@
M("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@
M("`@("`-"B`@("`@("`@:68@*"1N86UE<W!A8V55<FD@(3T@;G5L;"D@>PT*
M("`@("`@("`@("`@)'!A<G1S(#T@6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D
M3F%M92@D<6YA;64I.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@8VAE8VL@
M9F]R(&UU;'1I;&EN92!A='1R:6)U=&5S#0H@("`@("`@(&EF("@D;75L=&EL
M:6YE(#T]/2!T<G5E*2![#0H@("`@("`@("`@("!I9B`H)&EN9&5N="`]/3T@
M(E]A=71O(BD@>PT*("`@("`@("`@("`@("`@("1I;F1E;G0@/2!S=')?<F5P
M96%T*"(@(BP@*'-T<FQE;B@D<6YA;64I*S(I*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D;F%M97-P86-E57)I("$](&YU
M;&PI('L-"B`@("`@("`@("`@("\O(&ES(&$@;F%M97-P86-E(&=I=F5N#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'!A<G1S6R)N86UE<W!A8V4B72D@)B8@
M(65M<'1Y*"1P87)T<ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@("`@
M("`@)&%T=')I8G5T97-;(GAM;&YS.B(N)'!A<G1S6R)N86UE<W!A8V4B75T@
M/2`D;F%M97-P86-E57)I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`O+R!D969I;F4@=&AI<R!5<FD@87,@=&AE(&1E9F%U;'0@
M;F%M97-P86-E#0H@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;(GAM;&YS
M(ET@/2`D;F%M97-P86-E57)I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@8W)E871E(&%T=')I8G5T92!L:7-T#0H@("`@("`@
M("1A='1,:7-T("`@(#T@("!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG
M*"1A='1R:6)U=&5S+"!T<G5E+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN
M96)R96%K*3L-"B`@("`@("`@)&5L96UE;G0@("`@/2`@('-P<FEN=&8H(CPE
M<R5S/B(L("1Q;F%M92P@)&%T=$QI<W0I.PT*("`@("`@("!R971U<FX@("1E
M;&5M96YT.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@96YD
M(&5L96UE;G0-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?
M;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E
M(&%N(%A-3"!S=&%R="!E;&5M96YT.@T*("`@("H@)'1A9R`](%A-3%]5=&EL
M.CIC<F5A=&5%;F1%;&5M96YT*")M>4YS.FUY5&%G(BD[#0H@("`@*B`\+V-O
M9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T
M871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'%N86UE("`@("`@("`@
M("`@('%U86QI9FEE9"!T86=N86UE("AI;F-L=61I;F<@;F%M97-P86-E*0T*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-
M3"!E;F0@96QE;65N=`T*("`@("H@0'-E92`@("`@(%A-3%]5=&EL.CIC<F5A
M=&53=&%R=$5L96UE;G0H*2P@6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5%;F1%;&5M96YT*"1Q;F%M92D-"B`@
M("![#0H@("`@("`@("1E;&5M96YT("`@(#T@("!S<')I;G1F*"(\+R5S/B(L
M("1Q;F%M92D[#0H@("`@("`@(')E='5R;B`@)&5L96UE;G0[#0H@("`@?0T*
M("`@(`T*("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@6$U,(&-O;6UE;G0-"B`@
M("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T
M:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!S=&%R
M="!E;&5M96YT.@T*("`@("H@)'1A9R`](%A-3%]5=&EL.CIC<F5A=&5#;VUM
M96YT*"))(&%M(&$@8V]M;65N="(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("1C;VYT96YT("`@("`@("`@("!C;VYT96YT
M(&]F('1H92!C;VUM96YT#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D8V]M
M;65N="`@("`@("`@("`@6$U,(&-O;6UE;G0-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(&-R96%T94-O;6UE;G0H)&-O;G1E;G0I#0H@("`@>PT*("`@("`@("`D
M8V]M;65N="`@("`]("`@<W!R:6YT9B@B/"$M+2`E<R`M+3XB+"`D8V]N=&5N
M="D[#0H@("`@("`@(')E='5R;B`@)&-O;6UE;G0[#0H@("`@?0T*("`@(`T*
M("`@+RHJ#0H@("`@*B!C<F5A=&4@82!#1&%T82!S96-T:6]N#0H@("`@*@T*
M("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H
M<"<[#0H@("`@*B`-"B`@("`J("\O(&-R96%T92!A($-$871A('-E8W1I;VX-
M"B`@("`J("1T86<@/2!834Q?571I;#HZ8W)E871E0T1A=&%396-T:6]N*"))
M(&%M(&-O;G1E;G0N(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@)&1A=&$@("`@("`@("`@("`@(&1A=&$@;V8@=&AE($-$
M871A('-E8W1I;VX-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@
M("`@("`@("`@("!#1&%T82!S96-T:6]N('=I=&@@8V]N=&5N=`T*("`@("HO
M#0H@("`@9G5N8W1I;VX@8W)E871E0T1A=&%396-T:6]N*"1D871A*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N("!S<')I;G1F*"(\(5M#1$%405LE<UU=/B(L
M("1D871A*3L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@<W!L:70@<75A;&EF
M:65D(&YA;64@86YD(')E='5R;B!N86UE<W!A8V4@86YD(&QO8V%L('!A<G0-
M"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,
M+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@<W!L:70@<75A;&EF:65D
M('1A9PT*("`@("H@)'!A<G1S(#T@6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D
M3F%M92@B>'-L=#IS='EL97-H965T(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@
M*B!T:&4@<F5T=7)N960@87)R87D@=VEL;"!C;VYT86EN('1W;R!E;&5M96YT
M<SH-"B`@("`J(#QP<F4^#0H@("`@*B!A<G)A>2@-"B`@("`J("`@("`@(")N
M86UE<W!A8V4B(#T^(")X<VQT(BP-"B`@("`J("`@("`@(")L;V-A;%!A<G0B
M(#T^(")S='EL97-H965T(@T*("`@("H@("`@("`I.PT*("`@("H@/"]P<F4^
M#0H@("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J($!S=&%T:6,-
M"B`@("`J($!P87)A;2`@<W1R:6YG("`@("1Q;F%M92`@("`@('%U86QI9FEE
M9"!T86<@;F%M90T*("`@("H@0'!A<F%M("!S=')I;F<@("`@)&1E9F%U;'1.
M<R`@9&5F875L="!N86UE<W!A8V4@*&]P=&EO;F%L*0T*("`@("H@0')E='5R
M;B!A<G)A>2`@("`@)'!A<G1S("`@("`@87)R87D@8V]N=&%I;FEN9R!N86UE
M<W!A8V4@86YD(&QO8V%L('!A<G0-"B`@("`J+PT*("`@(&9U;F-T:6]N('-P
M;&ET475A;&EF:65D3F%M92@D<6YA;64L("1D969A=6QT3G,@/2!N=6QL*0T*
M("`@('L-"B`@("`@("`@:68@*'-T<G-T<B@D<6YA;64L("<Z)RDI('L-"B`@
M("`@("`@("`@("1T;7`@/2!E>'!L;V1E*"(Z(BP@)'%N86UE*3L-"B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(FYA;65S<&%C92(@/3X@)'1M<%LP72P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(FQO8V%L4&%R="(@/3X@)'1M<%LQ70T*("`@("`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("`@(FYA;65S<&%C92(@/3X@)&1E
M9F%U;'1.<RP-"B`@("`@("`@("`@("`@("`@("`@("`B;&]C86Q087)T(B`]
M/B`D<6YA;64-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@
M("\J*@T*("`@("H@8VAE8VLL('=H971H97(@<W1R:6YG(&ES('9A;&ED(%A-
M3"!N86UE#0H@("`@*@T*("`@("H@/'`^6$U,(&YA;65S(&%R92!U<V5D(&9O
M<B!T86=N86UE+"!A='1R:6)U=&4@;F%M97,@86YD('9A<FEO=7,-"B`@("`J
M(&]T:&5R+"!L97-S97(@:VYO=VX@96YT:71I97,N/"]P/@T*("`@("H@/'`^
M06X@6$U,(&YA;64@;6%Y(&]N;'D@8V]N<VES="!O9B!A;'!H86YU;65R:6,@
M8VAA<F%C=&5R<RP-"B`@("`J(&1A<VAE<RP@=6YD97-C;W)E<R!A;F0@<&5R
M:6]D<RP@86YD(&AA<R!T;R!S=&%R="!W:71H(&$@;&5T=&5R#0H@("`@*B!O
M<B!A;B!U;F1E<G-C;W)E+@T*("`@("H@/"]P/@T*("`@("H-"B`@("`J(#QC
M;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@
M("H@#0H@("`@*B`O+R!V97)I9GD@=&%G(&YA;64-"B`@("`J("1R97-U;'0@
M/2!834Q?571I;#HZ:7-686QI9$YA;64H(FEN=F%L:61486<_(BD[#0H@("`@
M*B!I9B`H6$U,7U5T:6PZ.FES17)R;W(H)')E<W5L="DI('L-"B`@("`J("`@
M('!R:6YT("));G9A;&ED(%A-3"!N86UE.B`B("X@)')E<W5L="T^9V5T365S
M<V%G92@I.PT*("`@("H@?0T*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J
M($!A8V-E<W,@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M
M("`@<W1R:6YG("`D<W1R:6YG('-T<FEN9R!T:&%T('-H;W5L9"!B92!C:&5C
M:V5D#0H@("`@*B!`<F5T=7)N("!M:7AE9"`@("1V86QI9"`@=')U92P@:68@
M<W1R:6YG(&ES(&$@=F%L:60@6$U,(&YA;64L(%!%05(@97)R;W(@;W1H97)W
M:7-E#0H@("`@*B!`=&]D;R`@("!S=7!P;W)T(&9O<B!O=&AE<B!C:&%R<V5T
M<PT*("`@("HO#0H@("`@9G5N8W1I;VX@:7-686QI9$YA;64H)'-T<FEN9RD-
M"B`@("![#0H@("`@("`@("\O(&-H96-K(&9O<B!I;G9A;&ED(&-H87)S#0H@
M("`@("`@(&EF("@A<')E9U]M871C:"@B+UY;6SIA;&YU;3I=7UPM+ETD+R(L
M("1S=')I;F=[,'TI*2![#0H@("`@("`@("`@("!R971U<FX@6$U,7U5T:6PZ
M.G)A:7-E17)R;W(H(")834P@;F%M97,@;6%Y(&]N;'D@<W1A<G0@=VET:"!L
M971T97(@;W(@=6YD97)S8V]R92(L(%A-3%]55$E,7T524D]27TE.5D%,241?
M4U1!4E0@*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@8VAE
M8VL@9F]R(&EN=F%L:60@8VAA<G,-"B`@("`@("`@:68@*"%P<F5G7VUA=&-H
M*"(O7BA;82UZ02U:7UTH6V$M>D$M6C`M.5]<+5PN72HI/SHI/UMA+7I!+5I?
M72A;82UZ02U:,"TY7UPM7"Y=*RD_)"\B+"`D<W1R:6YG*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(%A-3%]5=&EL.CIR86ES945R<F]R*"`B6$U,(&YA;65S
M(&UA>2!O;FQY(&-O;G1A:6X@86QP:&%N=6UE<FEC(&-H87)S+"!P97)I;V0L
M(&AY<&AE;BP@8V]L;VX@86YD('5N9&5R<V-O<F5S(BP@6$U,7U5424Q?15)2
M3U)?24Y604Q)1%]#2$%24R`I.PT*("`@("`@("`@?0T*("`@("`@("`O+R!8
M34P@;F%M92!I<R!V86QI9`T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("\J*@T*("`@("H@<F5P;&%C96UE;G0@9F]R(%A-3%]5=&EL.CIR
M86ES945R<F]R#0H@("`@*@T*("`@("H@079O:61S('1H92!N96-E<W-I='D@
M=&\@86QW87ES(')E<75I<F4-"B`@("`J(%!%05(N<&AP#0H@("`@*@T*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@(&5R<F]R(&UE<W-A9V4-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("`@
M("!E<G)O<B!C;V1E#0H@("`@*B!`<F5T=7)N("`@;V)J96-T(%!%05)?17)R
M;W(-"B`@("`J+PT*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&US9RP@)&-O
M9&4I#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&US9RP@)&-O9&4I
M.PT*("`@('T-"GT-"C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M6$U,+U5N<V5R:6%L:7IE<BYP:'``````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-C<T,S$`,3`U,34T,S$P-3<`,#(Q,C`Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_4$A0"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S
M=&]P/30Z("HO"@HO*BH*("H@6$U,7U5N<V5R:6%L:7IE<@H@*@H@*B!087)S
M97,@86YY(%A-3"!D;V-U;65N="!I;G1O(%!(4"!D871A('-T<G5C='5R97,N
M"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE
M87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O
M<GD@("!834P*("H@0'!A8VMA9V4@("`@6$U,7U-E<FEA;&EZ97(*("H@0&%U
M=&AO<B`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%5N<V5R:6%L
M:7IE<BYP:'`L=B`Q+C,Y(#(P,#4O,#DO,C@@,3$Z,3DZ-38@<V-H<W0@17AP
M("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+UA-3%]397)I86QI>F5R"B`J($!S964@("`@("`@(%A-3%]5;G-E<FEA;&EZ
M97(*("HO"@HO*BH*("H@=7-E<R!014%2(&5R<F]R(&UA;F%G96UT"B`J+PIR
M97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@H@*B!U<V5S(%A-3%]087)S
M97(@=&\@=6YS97)I86QI>F4@9&]C=6UE;G0*("HO"G)E<75I<F5?;VYC92`G
M6$U,+U!A<G-E<BYP:'`G.PH*+RHJ"B`J(&]P=&EO;CH@0V]N=F5R="!N97-T
M960@=&%G<R!T;R!A<G)A>2!O<B!O8FIE8W0*("H*("H@4&]S<VEB;&4@=F%L
M=65S.@H@*B`M(&%R<F%Y"B`J("T@;V)J96-T"B`J("T@87-S;V-I871I=F4@
M87)R87D@=&\@9&5F:6YE('1H:7,@;W!T:6]N('!E<B!T86<@;F%M90H@*B\*
M9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E012<L
M("=C;VUP;&5X5'EP92<I.PH*+RHJ"B`J(&]P=&EO;CH@3F%M92!O9B!T:&4@
M871T<FEB=71E('1H870@<W1O<F5S('1H92!O<FEG:6YA;"!K97D*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN92@G
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%62<L("=K97E!
M='1R:6)U=&4G*3L*"B\J*@H@*B!O<'1I;VXZ($YA;64@;V8@=&AE(&%T=')I
M8G5T92!T:&%T('-T;W)E<R!T:&4@='EP90H@*@H@*B!0;W-S:6)L92!V86QU
M97,Z"B`J("T@86YY('-T<FEN9PH@*B\*9&5F:6YE*"=834Q?54Y315))04Q)
M6D527T]05$E/3E]!5%1224)55$5?5%E012<L("=T>7!E071T<FEB=71E)RD[
M"@HO*BH*("H@;W!T:6]N.B!.86UE(&]F('1H92!A='1R:6)U=&4@=&AA="!S
M=&]R97,@=&AE(&-L87-S(&YA;64*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@
M*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7T-,05-3)RP@)V-L87-S071T<FEB=71E)RD["@HO
M*BH*("H@;W!T:6]N.B!7:&5T:&5R('1O('5S92!T:&4@=&%G(&YA;64@87,@
M82!C;&%S<R!N86UE"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E
M(&]R(&9A;'-E"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].
M7U1!1U]!4U]#3$%34TY!344G+"`G=&%G07-#;&%S<R<I.PH*+RHJ"B`J(&]P
M=&EO;CH@3F%M92!O9B!T:&4@9&5F875L="!C;&%S<PH@*@H@*B!0;W-S:6)L
M92!V86QU97,Z"B`J("T@86YY('-T<FEN9PH@*B\*9&5F:6YE*"=834Q?54Y3
M15))04Q)6D527T]05$E/3E]$149!54Q47T-,05-3)RP@)V1E9F%U;'1#;&%S
M<R<I.PH*+RHJ"B`J(&]P=&EO;CH@5VAE=&AE<B!T;R!P87)S92!A='1R:6)U
M=&5S"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E(&]R(&9A;'-E
M"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E54
M15-?4$%24T4G+"`G<&%R<V5!='1R:6)U=&5S)RD["@HO*BH*("H@;W!T:6]N
M.B!+97D@;V8@=&AE(&%R<F%Y('1O('-T;W)E(&%T=')I8G5T97,@*&EF(&%N
M>2D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<*("H@
M+2!F86QS92`H9&ES86)L960I"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:
M15)?3U!424].7T%45%))0E5415-?05)205E+15DG+"`G871T<FEB=71E<T%R
M<F%Y)RD["@HO*BH*("H@;W!T:6]N.B!S=')I;F<@=&\@<')E<&5N9"!A='1R
M:6)U=&4@;F%M92`H:68@86YY*0H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J
M("T@86YY('-T<FEN9PH@*B`M(&9A;'-E("AD:7-A8FQE9"D*("HO"F1E9FEN
M92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]04D5014Y$
M)RP@)W!R97!E;F1!='1R:6)U=&5S)RD["@HO*BH*("H@;W!T:6]N.B!K97D@
M=&\@<W1O<F4@=&AE(&-O;G1E;G0L(&EF(%A-3%]53E-%4DE!3$E:15)?3U!4
M24].7T%45%))0E5415-?4$%24T4@:7,@=7-E9`H@*@H@*B!0;W-S:6)L92!V
M86QU97,Z"B`J("T@86YY('-T<FEN9PH@*B\*9&5F:6YE*"=834Q?54Y315))
M04Q)6D527T]05$E/3E]#3TY414Y47TM%62<L("=C;VYT96YT3F%M92<I.PH*
M+RHJ"B`J(&]P=&EO;CH@;6%P('1A9R!N86UE<PH@*@H@*B!0;W-S:6)L92!V
M86QU97,Z"B`J("T@87-S;V-I871I=F4@87)R87D*("HO"F1E9FEN92@G6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!4"<L("=T86=-87`G*3L*"B\J
M*@H@*B!O<'1I;VXZ(&QI<W0@;V8@=&%G<R!T:&%T('=I;&P@86QW87ES(&)E
M(&5N=6UE<F%T960*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&EN9&5X
M960@87)R87D*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M1D]20T5?14Y532<L("=F;W)C945N=6TG*3L*"B\J*@H@*B!O<'1I;VXZ($5N
M8V]D:6YG(&]F('1H92!834P@9&]C=6UE;G0*("H*("H@4&]S<VEB;&4@=F%L
M=65S.@H@*B`M(%541BTX"B`J("T@25-/+3@X-3DM,0H@*B\*9&5F:6YE*"=8
M34Q?54Y315))04Q)6D527T]05$E/3E]%3D-/1$E.1U]33U520T4G+"`G96YC
M;V1I;F<G*3L*"B\J*@H@*B!O<'1I;VXZ($1E<VER960@=&%R9V5T(&5N8V]D
M:6YG(&]F('1H92!D871A"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!5
M5$8M.`H@*B`M($E33RTX.#4Y+3$*("HO"F1E9FEN92@G6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T54)RP@)W1A<F=E=$5N8V]D:6YG
M)RD["@HO*BH*("H@;W!T:6]N.B!#86QL8F%C:R!T:&%T('=I;&P@8F4@87!P
M;&EE9"!T;R!T97AT=6%L(&1A=&$*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@
M*B`M(&%N>2!V86QI9"!02%`@8V%L;&)A8VL*("HO"F1E9FEN92@G6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?1$5#3T1%7T953D,G+"`G9&5C;V1E1G5N8W1I
M;VXG*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@=&\@<F5T=7)N('1H92!R
M97-U;'0@;V8@=&AE('5N<V5R:6%L:7IA=&EO;B!F<F]M('5N<V5R:6%L:7IE
M*"D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS
M92`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?4D5455).7U)%4U5,5"<L("=R971U<FY297-U;'0G*3L*"B\J*@H@*B!O
M<'1I;VXZ('-E="!T:&4@=VAI=&5S<&%C92!B96AA=FEO=7(*("H*("H@4&]S
M<VEB;&4@=F%L=65S.@H@*B`M(%A-3%]53E-%4DE!3$E:15)?5TA)5$534$%#
M15]+1450"B`J("T@6$U,7U5.4T5224%,25I%4E]72$E415-004-%7U1224T*
M("H@+2!834Q?54Y315))04Q)6D527U=(251%4U!!0T5?3D]234%,25I%"B`J
M+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7U=(251%4U!!0T4G
M+"`G=VAI=&5S<&%C92<I.PH*+RHJ"B`J($ME97`@86QL('=H:71E<W!A8V4*
M("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]72$E415-004-%7TM%15`G
M+"`G:V5E<"<I.PH*+RHJ"B`J(')E;6]V92!W:&ET97-P86-E(&9R;VT@<W1A
M<G0@86YD(&5N9"!O9B!T:&4@9&%T80H@*B\*9&5F:6YE*"=834Q?54Y315))
M04Q)6D527U=(251%4U!!0T5?5%))32<L("=T<FEM)RD["@HO*BH*("H@;F]R
M;6%L:7IE('=H:71E<W!A8V4*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%
M4E]72$E415-004-%7TY/4DU!3$E:12<L("=N;W)M86QI>F4G*3L*"B\J*@H@
M*B!O<'1I;VXZ('=H971H97(@=&\@;W9V97)R:61E(&%L;"!O<'1I;VYS('1H
M870@:&%V92!B965N('-E="!B969O<F4*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*("HO"F1E9FEN92@G
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?3U9%4E))1$5?3U!424].4R<L("=O
M=F5R<FED94]P=&EO;G,G*3L*"B\J*@H@*B!O<'1I;VXZ(&QI<W0@;V8@=&%G
M<RP@=&AA="!W:6QL(&YO="!B92!U<V5D(&%S(&ME>7,*("HO"F1E9FEN92@G
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?24=.3U)%7TM%65,G+"`G:6=N;W)E
M2V5Y<R<I.PH*+RHJ"B`J(&]P=&EO;CH@=VAE=&AE<B!T;R!U<V4@='EP92!G
M=65S<VEN9R!F;W(@<V-A;&%R('9A;'5E<PH@*B\*9&5F:6YE*"=834Q?54Y3
M15))04Q)6D527T]05$E/3E]'54534U]465!%4R<L("=G=65S<U1Y<&5S)RD[
M"@HO*BH*("H@97)R;W(@8V]D92!F;W(@;F\@<V5R:6%L:7IA=&EO;B!D;VYE
M"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?15)23U)?3D]?54Y315))
M04Q)6D%424].)RP@,34Q*3L*"B\J*@H@*B!834Q?56YS97)I86QI>F5R"B`J
M"B`J(&-L87-S('1O('5N<V5R:6%L:7IE(%A-3"!D;V-U;65N=',@=&AA="!H
M879E(&)E96X@8W)E871E9"!W:71H"B`J(%A-3%]397)I86QI>F5R+B!4;R!U
M;G-E<FEA;&EZ92!A;B!834P@9&]C=6UE;G0@>6]U(&AA=F4@=&\@861D"B`J
M('1Y<&4@:&EN=',@=&\@=&AE(%A-3%]397)I86QI>F5R(&]P=&EO;G,N"B`J
M"B`J($EF(&YO('1Y<&4@:&EN=',@87)E(&%V86EL86)L92P@6$U,7U5N<V5R
M:6%L:7IE<B!W:6QL(&=U97-S(&AO=PH@*B!T:&4@=&%G<R!S:&]U;&0@8F4@
M=')E871E9"P@=&AA="!M96%N<R!C;VUP;&5X('-T<G5C='5R97,@=VEL;"!B
M90H@*B!A<G)A>7,@86YD('1A9W,@=VET:"!O;FQY($-$871A(&EN('1H96T@
M=VEL;"!B92!S=')I;F=S+@H@*@H@*B`\8V]D93X*("H@<F5Q=6ER95]O;F-E
M("=834PO56YS97)I86QI>F5R+G!H<"<["B`J"B`J("\O("!B92!C87)E9G5L
M('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T:&4@
M;F5W(&]P97)A=&]R"B`J("1U;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E
M<FEA;&EZ97(H*3L*("H*("H@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H
M)'AM;"D["B`J"B`J("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I
M86QI>F5D1&%T82@I.PH@*B`\8V]D93X*("H*("H*("H@0&-A=&5G;W)Y("`@
M6$U,"B`J($!P86-K86=E("`@(%A-3%]397)I86QI>F5R"B`J($!A=71H;W(@
M("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#`N,3@N,`H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U-E<FEA
M;&EZ97(*("H@0'-E92`@("`@("`@6$U,7U-E<FEA;&EZ97(*("HO"F-L87-S
M(%A-3%]5;G-E<FEA;&EZ97(@97AT96YD<R!014%2"GL*("`@+RHJ"B`@("`J
M(&QI<W0@;V8@86QL(&%V86EL86)L92!O<'1I;VYS"B`@("`J"B`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@
M=F%R("1?:VYO=VY/<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%
M6%194$4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%62P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!
M5%1224)55$5?5%E012P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U,L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?5$%'7T%37T-,05-33D%-12P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]$149!54Q4
M7T-,05-3+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?4$%24T4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?05144DE"551%4U]!4E)!64M%62P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$53
M7U!215!%3D0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M5$%'7TU!4"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M54Y315))04Q)6D527T]05$E/3E]&3U)#15]%3E5-+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T5.
M0T]$24Y'7U-/55)#12P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?54Y315))04Q)6D527T]05$E/3E]%3D-/1$E.1U]405)'150L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?1$5#3T1%7T953D,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,
M5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))
M04Q)6D527T]05$E/3E]72$E415-004-%+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7TE'3D]215]+
M15E3+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%
M4DE!3$E:15)?3U!424].7T=515-37U194$53"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D["B`@("\J*@H@("`@*B!D969A=6QT(&]P=&EO;G,@
M9F]R('1H92!S97)I86QI>F%T:6]N"B`@("`J"B`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?9&5F
M875L=$]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]53E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%("`@("`@("`@
M/3X@)V%R<F%Y)RP@("`@("`@("`@("`@("`@+R\@8V]M<&QE>"!T>7!E<R!W
M:6QL(&)E(&-O;G9E<G1E9"!T;R!A<G)A>7,L(&EF(&YO('1Y<&4@:&EN="!I
M<R!G:79E;@H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?05144DE"551%7TM%62`@("`@("`]/B`G7V]R:6=I;F%L
M2V5Y)RP@("`@("`@("`O+R!G970@87)R87D@:V5Y+W!R;W!E<G1Y(&YA;64@
M9G)O;2!T:&ES(&%T=')I8G5T90H@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7U194$4@("`@("`]
M/B`G7W1Y<&4G+"`@("`@("`@("`@("`@("`O+R!G970@='EP92!F<F]M('1H
M:7,@871T<FEB=71E"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y3
M15))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U,@("`@(#T^("=?8VQA
M<W,G+"`@("`@("`@("`@("`@("\O(&=E="!C;&%S<R!F<F]M('1H:7,@871T
M<FEB=71E("AI9B!N;W0@9VEV96XL('5S92!T86<@;F%M92D*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]!
M4U]#3$%34TY!344@("`@/3X@=')U92P@("`@("`@("`@("`@("`@("`@+R\@
M=7-E('1H92!T86=N86UE(&%S('1H92!C;&%S<VYA;64*("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T1%1D%53%1?
M0TQ!4U,@("`@("`@/3X@)W-T9$-L87-S)RP@("`@("`@("`@("`@+R\@;F%M
M92!O9B!T:&4@8VQA<W,@=&AA="!I<R!U<V5D('1O(&-R96%T92!O8FIE8W1S
M"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]0
M5$E/3E]!5%1224)55$537U!!4E-%("`@(#T^(&9A;'-E+"`@("`@("`@("`@
M("`@("`@("\O('!A<G-E('1H92!A='1R:6)U=&5S(&]F('1H92!T86<@:6YT
M;R!A;B!A<G)A>0H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%4U]!4E)!64M%62`]/B!F86QS92P@
M("`@("`@("`@("`@("`@("`O+R!P87)S92!T:&5M(&EN=&\@<W!E<F%T92!A
M<G)A>2`H<W!E8VEF>2!N86UE(&]F(&%R<F%Y(&AE<F4I"B`@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)5
M5$537U!215!%3D0@(#T^("<G+"`@("`@("`@("`@("`@("`@("`@("\O('!R
M97!E;F0@871T<FEB=71E(&YA;65S('=I=&@@=&AI<R!S=')I;F<*("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T-/
M3E1%3E1?2T59("`@("`@("`@/3X@)U]C;VYT96YT)RP@("`@("`@("`@("`@
M+R\@<'5T(&-D871A(&9O=6YD(&EN(&$@=&%G('1H870@:&%S(&)E96X@8V]N
M=F5R=&5D('1O(&$@8V]M<&QE>"!T>7!E(&EN('1H:7,@:V5Y"B`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]404=?
M34%0("`@("`@("`@("`@(#T^(&%R<F%Y*"DL("`@("`@("`@("`@("`@("\O
M('5S92!T:&ES('1O(&UA<"!T86=N86UE<PH@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1D]20T5?14Y532`@("`@
M("`@("`]/B!A<G)A>2@I+"`@("`@("`@("`@("`@("`O+R!T:&5S92!T86=S
M('=I;&P@86QW87ES(&)E(&%N(&EN9&5X960@87)R87D*("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T5.0T]$24Y'
M7U-/55)#12`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`@+R\@<W!E
M8VEF>2!T:&4@96YC;V1I;F<@8VAA<F%C=&5R(&]F('1H92!D;V-U;65N="!T
M;R!P87)S90H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T54("`@("`]/B!N=6QL+"`@("`@
M("`@("`@("`@("`@("`O+R!S<&5C:69Y('1H92!T87)G970@96YC;V1I;F<*
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!4
M24].7T1%0T]$15]&54Y#("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@
M("`@("`@+R\@9G5N8W1I;VX@=7-E9"!T;R!D96-O9&4@9&%T80H@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D54
M55).7U)%4U5,5"`@("`@("`]/B!F86QS92P@("`@("`@("`@("`@("`@("`O
M+R!U;G-E<FEA;&EZ92@I(')E='5R;G,@=&AE(')E<W5L="!O9B!T:&4@=6YS
M97)I86QI>F%T:6]N(&EN<W1E860@;V8@=')U90H@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5TA)5$534$%#12`@
M("`@("`@("`]/B!834Q?54Y315))04Q)6D527U=(251%4U!!0T5?5%))32P@
M+R\@<F5M;W9E('=H:71E<W!A8V4@87)O=6YD(&1A=&$*("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7TE'3D]215]+
M15E3("`@("`@("`@/3X@87)R87DH*2P@("`@("`@("`@("`@("`@+R\@3&ES
M="!O9B!T86=S('1H870@=VEL;"!A=71O;6%T:6-A;&QY(&)E(&%D9&5D('1O
M('1H92!P87)E;G0L(&EN<W1E860@;V8@861D:6YG(&$@;F5W(&ME>0H@("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M1U5%4U-?5%E015,@("`@("`@("`]/B!F86QS92`@("`@("`@("`@("`@("`@
M("`O+R!7:&5T:&5R('1O('5S92!T>7!E(&=U97-S:6YG"B`@("`@("`@("`@
M("`@("`@("`@("`@("D["@H@("`O*BH*("`@("H@8W5R<F5N="!O<'1I;VYS
M(&9O<B!T:&4@<V5R:6%L:7IA=&EO;@H@("`@*@H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@=F%R("1O<'1I
M;VYS(#T@87)R87DH*3L*"B`@("\J*@H@("`@*B!U;G-E<FEA;&EZ960@9&%T
M80H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'9A<B`@("!S
M=')I;F<*("`@("HO"B`@("!V87(@)%]U;G-E<FEA;&EZ961$871A(#T@;G5L
M;#L*"B`@("\J*@H@("`@*B!N86UE(&]F('1H92!R;V]T('1A9PH@("`@*@H@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'9A<B`@("!S=')I;F<*("`@
M("HO"B`@("!V87(@)%]R;V]T(#T@;G5L;#L*"B`@("\J*@H@("`@*B!S=&%C
M:R!F;W(@86QL(&1A=&$@=&AA="!I<R!F;W5N9`H@("`@*@H@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("H@0'9A<B`@("!A<G)A>0H@("`@*B\*("`@('9A
M<B`D7V1A=&%3=&%C:R`@/2`@(&%R<F%Y*"D["@H@("`O*BH*("`@("H@<W1A
M8VL@9F]R(&%L;"!V86QU97,@=&AA="!A<F4@9V5N97)A=&5D"B`@("`J"B`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J
M+PH@("`@=F%R("1?=F%L4W1A8VL@(#T@("!A<G)A>2@I.PH*("`@+RHJ"B`@
M("`J(&-U<G)E;G0@=&%G(&1E<'1H"B`@("`J"B`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@*B!`=F%R("`@(&EN=`H@("`@*B\*("`@('9A<B`D7V1E<'1H
M(#T@,#L*"B`@("\J*@H@("`@*B!834Q?4&%R<V5R(&EN<W1A;F-E"B`@("`J
M"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!V87(@("`@("!O8FIE
M8W0@6$U,7U!A<G-E<@H@("`@*B\*("`@('9A<B`D7W!A<G-E<B`](&YU;&P[
M"B`@("`*("`@+RHJ"B`@("`J(&-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,*("`@("H@0'!A<F%M("`@(&UI>&5D("`@)&]P=&EO
M;G,@("`@87)R87D@8V]N=&%I;FEN9R!O<'1I;VYS(&9O<B!T:&4@=6YS97)I
M86QI>F%T:6]N"B`@("`J+PH@("`@9G5N8W1I;VX@6$U,7U5N<V5R:6%L:7IE
M<B@D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1O<'1I;VYS*2D@>PH@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R
M<F%Y7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O<'1I;VYS*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`]
M("1T:&ES+3Y?9&5F875L=$]P=&EO;G,["B`@("`@("`@?0H@("`@?0H*("`@
M+RHJ"B`@("`J(')E='5R;B!!4$D@=F5R<VEO;@H@("`@*@H@("`@*B!`86-C
M97-S("`@<'5B;&EC"B`@("`J($!S=&%T:6,*("`@("H@0')E='5R;B`@('-T
M<FEN9R`@)'9E<G-I;VX@05!)('9E<G-I;VX*("`@("HO"B`@("!F=6YC=&EO
M;B!A<&E697)S:6]N*"D*("`@('L*("`@("`@("!R971U<FX@)S`N,3@N,"<[
M"B`@("!]"@H@("`O*BH*("`@("H@<F5S970@86QL(&]P=&EO;G,@=&\@9&5F
M875L="!O<'1I;VYS"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("H@0'-E92`@("`@('-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R*"DL
M('-E=$]P=&EO;G,H*0H@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T3W!T:6]N
M<R@I"B`@("!["B`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^7V1E
M9F%U;'1/<'1I;VYS.PH@("`@?0H*("`@+RHJ"B`@("`J('-E="!A;B!O<'1I
M;VX*("`@("H*("`@("H@66]U(&-A;B!U<V4@=&AI<R!M971H;V0@:68@>6]U
M(&1O(&YO="!W86YT('1O('-E="!A;&P@;W!T:6]N<R!I;B!T:&4@8V]N<W1R
M=6-T;W(*("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E
M("`@("`@<F5S971/<'1I;VXH*2P@6$U,7U5N<V5R:6%L:7IE<B@I+"!S971/
M<'1I;VYS*"D*("`@("HO"B`@("!F=6YC=&EO;B!S971/<'1I;VXH)&YA;64L
M("1V86QU92D*("`@('L*("`@("`@("`D=&AI<RT^;W!T:6]N<ULD;F%M95T@
M/2`D=F%L=64["B`@("!]"@H@("`O*BH*("`@("H@<V5T<R!S979E<F%L(&]P
M=&EO;G,@870@;VYC90H@("`@*@H@("`@*B!9;W4@8V%N('5S92!T:&ES(&UE
M=&AO9"!I9B!Y;W4@9&\@;F]T('=A;G0@=&\@<V5T(&%L;"!O<'1I;VYS(&EN
M('1H92!C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`J($!S964@("`@("!R97-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI
M>F5R*"DL('-E=$]P=&EO;B@I"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T
M:6]N<R@D;W!T:6]N<RD*("`@('L*("`@("`@("`D=&AI<RT^;W!T:6]N<R`]
M(&%R<F%Y7VUE<F=E*"1T:&ES+3YO<'1I;VYS+"`D;W!T:6]N<RD["B`@("!]
M"@H@("`O*BH*("`@("H@=6YS97)I86QI>F4@9&%T80H@("`@*@H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!M:7AE9"`@("`D9&%T
M82`@("`@9&%T82!T;R!U;G-E<FEA;&EZ92`H<W1R:6YG+"!F:6QE;F%M92!O
M<B!R97-O=7)C92D*("`@("H@0'!A<F%M("`@(&)O;VQE86X@("1I<T9I;&4@
M("!D871A('-H;W5L9"!B92!T<F5A=&5D(&%S(&$@9FEL90H@("`@*B!`<&%R
M86T@("`@87)R87D@("`@)&]P=&EO;G,@(&]P=&EO;G,@=&AA="!W:6QL(&]V
M97)R:61E('1H92!G;&]B86P@;W!T:6]N<R!F;W(@=&AI<R!C86QL"B`@("`J
M($!R971U<FX@("!B;V]L96%N("`D<W5C8V5S<PH@("`@*B\*("`@(&9U;F-T
M:6]N('5N<V5R:6%L:7IE*"1D871A+"`D:7-&:6QE(#T@9F%L<V4L("1O<'1I
M;VYS(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W5N<V5R:6%L:7IE
M9$1A=&$@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?<F]O="`](&YU;&P["@H@
M("`@("`@("\O(&EF(&]P=&EO;G,@:&%V92!B965N('-P96-I9FEE9"P@=7-E
M('1H96T@:6YS=&5A9`H@("`@("`@("\O(&]F('1H92!P<F5V:6]U<VQY(&1E
M9FEN960@;VYE<PH@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI('L*
M("`@("`@("`@("`@)&]P=&EO;G-"86L@/2`D=&AI<RT^;W!T:6]N<SL*("`@
M("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?
M3U!424].7T]615)2241%7T]05$E/3E-=*2`F)B`D;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E]/5D524DE$15]/4%1)3TY372`]/2!T<G5E*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E
M*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O<'1I;VYS*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@
M87)R87E?;65R9V4H)'1H:7,M/F]P=&EO;G,L("1O<'1I;VYS*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O<'1I;VYS
M0F%K(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?=F%L4W1A
M8VL@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?9&%T85-T86-K(#T@87)R
M87DH*3L*("`@("`@("`D=&AI<RT^7V1E<'1H(#T@,#L*"B`@("`@("`@)'1H
M:7,M/E]C<F5A=&5087)S97(H*3L*("`@("`@("`*("`@("`@("!I9B`H:7-?
M<W1R:6YG*"1D871A*2D@>PH@("`@("`@("`@("!I9B`H)&ES1FEL92D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<&%R<V5R+3YS971)
M;G!U=$9I;&4H)&1A=&$I.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7W!A<G-E<BT^<&%R<V4H*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W!A
M<G-E<BT^<&%R<V53=')I;F<H)&1A=&$L=')U92D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("1T:&ES+3Y?<&%R<V5R+3YS
M971);G!U="@D9&%T82D["B`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M<&%R<V5R+3YP87)S92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7U)%5%523E]215-5
M3%1=(#T]/2!T<G5E*2!["B`@("`@("`@"21R971U<FX@/2`D=&AI<RT^7W5N
M<V5R:6%L:7IE9$1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)')E='5R;B`]('1R=64["B`@("`@("`@?0H*("`@("`@("!I9B`H)&]P=&EO
M;G-"86L@(3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@
M/2`D;W!T:6]N<T)A:SL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@
M("`O*BH*("`@("H@9V5T('1H92!R97-U;'0@;V8@=&AE('-E<FEA;&EZ871I
M;VX*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0')E='5R;B!S
M=')I;F<@("1S97)I86QI>F5D1&%T80H@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%5N<V5R:6%L:7IE9$1A=&$H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M7W)O;W0@/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=.;R!U;G-E<FEA;&EZ960@9&%T82!A=F%I;&%B;&4N(%5S
M92!834Q?56YS97)I86QI>F5R.CIU;G-E<FEA;&EZ92@I(&9I<G-T+B<L(%A-
M3%]53E-%4DE!3$E:15)?15)23U)?3D]?54Y315))04Q)6D%424].*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=6YS97)I86QI>F5D1&%T
M83L*("`@('T*"B`@("\J*@H@("`@*B!G970@=&AE(&YA;64@;V8@=&AE(')O
M;W0@=&%G"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U
M<FX@<W1R:6YG("`D<F]O=$YA;64*("`@("HO"B`@("!F=6YC=&EO;B!G9712
M;V]T3F%M92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<F]O="`]/3T@
M;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)TYO('5N<V5R:6%L:7IE9"!D871A(&%V86EL86)L92X@57-E(%A-3%]5;G-E
M<FEA;&EZ97(Z.G5N<V5R:6%L:7IE*"D@9FER<W0N)RP@6$U,7U5.4T5224%,
M25I%4E]%4E)/4E].3U]53E-%4DE!3$E:051)3TXI.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'1H:7,M/E]R;V]T.PH@("`@?0H*("`@+RHJ"B`@("`J
M(%-T87)T(&5L96UE;G0@:&%N9&QE<B!F;W(@6$U,('!A<G-E<@H@("`@*@H@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'!A<F%M("!O8FIE8W0@)'!A
M<G-E<B`@6$U,('!A<G-E<B!O8FIE8W0*("`@("H@0'!A<F%M("!S=')I;F<@
M)&5L96UE;G0@6$U,(&5L96UE;G0*("`@("H@0'!A<F%M("!A<G)A>2`@)&%T
M=')I8G,@871T<FEB=71E<R!O9B!834P@=&%G"B`@("`J($!R971U<FX@=F]I
M9`H@("`@*B\*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D<&%R<V5R+"`D
M96QE;65N="P@)&%T=')I8G,I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1A
M='1R:6)S6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415]465!%75TI*2!["B`@("`@("`@("`@("1T>7!E(#T@)&%T
M=')I8G-;)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M05144DE"551%7U194$5=73L*("`@("`@("`@("`@)&=U97-S5'EP92`](&9A
M;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T>7!E(#T@)W-T
M<FEN9R<["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E]'54534U]465!%4UT@/3T]('1R=64I('L*("`@
M("`@("`@("`@("`@("1G=65S<U1Y<&4@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&=U97-S5'EP92`](&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5#3T1%7T953D-=("$]
M/2!N=6QL*2!["B`@("`@("`@("`@("1A='1R:6)S(#T@87)R87E?;6%P*"1T
M:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T1%0T]$15]&
M54Y#72P@)&%T=')I8G,I.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D
M=&AI<RT^7V1E<'1H*RL["B`@("`@("`@)'1H:7,M/E]D871A4W1A8VM;)'1H
M:7,M/E]D97!T:%T@/2!N=6QL.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1H
M:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!4%TI
M("8F(&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7U1!1U]-05!=6R1E;&5M96YT72DI('L*("`@("`@("`@("`@)&5L96UE
M;G0@/2`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]4
M04=?34%075LD96QE;65N=%T["B`@("`@("`@?0H*("`@("`@("`D=F%L(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@("`@("`@(#T^
M("1E;&5M96YT+`H@("`@("`@("`@("`@("`@("`@("`G=F%L=64G("`@("`@
M("`]/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`G='EP92<@("`@("`@
M("`]/B`D='EP92P*("`@("`@("`@("`@("`@("`@("`@)V=U97-S5'EP92<@
M("`@/3X@)&=U97-S5'EP92P*("`@("`@("`@("`@("`@("`@("`@)V-H:6QD
M<F5N2V5Y<R<@/3X@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@)V%G
M9W)E9TME>7,G("`@/3X@87)R87DH*0H@("`@("`@("`@("`@("`@("`@("D[
M"@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D52
M7T]05$E/3E]!5%1224)55$537U!!4E-%72`]/2!T<G5E("8F("AC;W5N="@D
M871T<FEB<RD@/B`P*2D@>PH@("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==
M(#T@87)R87DH*3L*("`@("`@("`@("`@)'9A;%LG='EP92==("`]("1T:&ES
M+3Y?9V5T0V]M<&QE>%1Y<&4H)&5L96UE;G0I.PH@("`@("`@("`@("`D=F%L
M6R=C;&%S<R==(#T@)&5L96UE;G0["@H@("`@("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1U5%4U-?5%E015-=
M(#T]/2!T<G5E*2!["B`@("`@("`@("`@(`DD871T<FEB<R`]("1T:&ES+3Y?
M9W5E<W-!;F139714>7!E<R@D871T<FEB<RD["B`@("`@("`@("`@('T@("`@
M("`@("`@("`*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?05)205E+15E=("$](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==6R1T:&ES
M+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?
M05)205E+15E=72`]("1A='1R:6)S.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G,@87,@)&%T=')I8B`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("`D=F%L6R=C:&EL9')E
M;B==6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%4
M5%))0E5415-?4%)%4$5.1%TN)&%T=')I8ET@/2`D=F%L=64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1K
M97E!='1R(#T@9F%L<V4["B`@("`@("`@"B`@("`@("`@:68@*&ES7W-T<FEN
M9R@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%12
M24)55$5?2T5972DI('L*("`@("`@("`@("`@)&ME>4%T='(@/2`D=&AI<RT^
M;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?2T59
M73L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)'1H:7,M/F]P=&EO;G-;
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%65TI*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))
M04Q)6D527T]05$E/3E]!5%1224)55$5?2T5975LD96QE;65N=%TI*2!["B`@
M("`@("`@("`@("`@("`D:V5Y071T<B`]("1T:&ES+3YO<'1I;VYS6UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15E=6R1E;&5M96YT73L*
M("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-
M3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15E=6R<C9&5F875L
M="==*2D@>PH@("`@("`@("`@("`@("`@)&ME>4%T='(@/2`D=&AI<RT^;W!T
M:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?2T5975LG
M(V1E9F%U;'0G73L*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES
M+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+
M15E=6R=?7V1E9F%U;'0G72DI('L*("`@("`@("`@("`@("`@("\O(&ME97`@
M=&AI<R!F;W(@0D,*("`@("`@("`@("`@("`@("1K97E!='1R(#T@)'1H:7,M
M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%
M65U;)U]?9&5F875L="==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(`H@("`@("`@(&EF("@D:V5Y071T<B`A/3T@9F%L<V4@)B8@:7-S970H
M)&%T=')I8G-;)&ME>4%T=')=*2D@>PH@("`@("`@("`@("`D=F%L6R=N86UE
M)UT@/2`D871T<FEB<ULD:V5Y071T<ET["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)&%T=')I8G-;)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?05144DE"551%7T-,05-375TI*2!["B`@("`@("`@("`@
M("1V86Q;)V-L87-S)UT@/2`D871T<FEB<ULD=&AI<RT^;W!T:6]N<UM834Q?
M54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U-=73L*("`@("`@
M("!]"@H@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@)'9A
M;"D["B`@("!]"@H@("`O*BH*("`@("H@5')Y('1O(&=U97-S('1H92!T>7!E
M(&]F('-E=F5R86P@=F%L=65S(&%N9`H@("`@*B!S970@=&AE;2!A8V-O<F1I
M;F=L>0H@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R
M86T@("`@87)R87D@("`@("!A<G)A>2P@8V]N=&%I;FEN9R!T:&4@=F%L=65S
M"B`@("`J($!R971U<FX@("!A<G)A>2`@("`@(&%R<F%Y+"!C;VYT86EN:6YG
M('1H92!V86QU97,@=VET:"!T:&5I<B!C;W)R96-T('1Y<&5S(`H@("`@*B\*
M("`@(&9U;F-T:6]N(%]G=65S<T%N9%-E=%1Y<&5S*"1A<G)A>2D*("`@('L*
M("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`))&%R<F%Y6R1K97E=(#T@)'1H:7,M/E]G=65S<T%N9%-E=%1Y
M<&4H)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1A<G)A>3L*
M("`@('T*("`@(`H@("`O*BH*("`@("H@5')Y('1O(&=U97-S('1H92!T>7!E
M(&]F(&$@=F%L=64@86YD"B`@("`J('-E="!I="!A8V-O<F1I;F=L>0H@("`@
M*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`@("`@8VAA<F%C=&5R(&1A=&$*("`@("H@0')E='5R;B`@(&UI>&5D
M("`@("`@('9A;'5E('=I=&@@=&AE(&)E<W0@;6%T8VAI;F<@='EP90H@("`@
M*B\*("`@(&9U;F-T:6]N(%]G=65S<T%N9%-E=%1Y<&4H)'9A;'5E*0H@("`@
M>PH@("`@("`@(&EF("@D=F%L=64@/3T]("=T<G5E)RD@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@:68@*"1V86QU92`]
M/3T@)V9A;'-E)RD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@(&EF("@D=F%L=64@/3T]("=.54Q,)RD@>PH@("`@("`@
M("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R]>6RTK73];,"TY77LQ+'TD+R<L("1V86QU92DI('L*("`@("`@
M("`)<F5T=7)N(&EN='9A;"@D=F%L=64I.PH@("`@("`@('T*("`@("`@("!I
M9B`H<')E9U]M871C:"@G+UY;+2M=/ULP+3E=>S$L?5PN6S`M.5U[,2Q])"\G
M+"`D=F%L=64I*2!["B`@("`@("`@"7)E='5R;B!D;W5B;&5V86PH)'9A;'5E
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("AS=')I;F<I)'9A;'5E.PH@
M("`@?0H@("`@"B`@("\J*@H@("`@*B!%;F0@96QE;65N="!H86YD;&5R(&9O
M<B!834P@<&%R<V5R"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M*B!`<&%R86T@(&]B:F5C="!834P@<&%R<V5R(&]B:F5C=`H@("`@*B!`<&%R
M86T@('-T<FEN9PH@("`@*B!`<F5T=7)N('9O:60*("`@("HO"B`@("!F=6YC
M=&EO;B!E;F1(86YD;&5R*"1P87)S97(L("1E;&5M96YT*0H@("`@>PH@("`@
M("`@("1V86QU92`](&%R<F%Y7W!O<"@D=&AI<RT^7W9A;%-T86-K*3L*("`@
M("`@("!S=VET8V@@*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?
M3U!424].7U=(251%4U!!0T5=*2!["B`@("`@("`@("`@(&-A<V4@6$U,7U5.
M4T5224%,25I%4E]72$E415-004-%7TM%15`Z"B`@("`@("`@("`@("`@("`D
M9&%T82`]("1T:&ES+3Y?9&%T85-T86-K6R1T:&ES+3Y?9&5P=&A=.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@6$U,7U5.4T52
M24%,25I%4E]72$E415-004-%7TY/4DU!3$E:13H*("`@("`@("`@("`@("`@
M("1D871A(#T@=')I;2AP<F5G7W)E<&QA8V4H)R]<<UQS*R]M)RP@)R`G+"`D
M=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^7V1E<'1H72DI.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@6$U,7U5.4T5224%,25I%
M4E]72$E415-004-%7U1224TZ"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`D9&%T82`@/2!T<FEM*"1T:&ES+3Y?9&%T85-T86-K6R1T
M:&ES+3Y?9&5P=&A=*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@+R\@861J=7-T('1Y<&4@;V8@=&AE('9A;'5E"B`@("`@
M("`@<W=I=&-H*'-T<G1O;&]W97(H)'9A;'5E6R=T>7!E)UTI*2!["@H@("`@
M("`@("`@("`O+R!U;G-E<FEA;&EZ92!A;B!O8FIE8W0*("`@("`@("`@("`@
M8V%S92`G;V)J96-T)SH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L
M=65;)V-L87-S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&-L87-S;F%M
M92`@/2`D=F%L=65;)V-L87-S)UT["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O(&EN<W1A;G1I871E('1H
M92!C;&%S<PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-
M3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]!4U]#3$%34TY!345=(#T]/2!T
M<G5E("8F(&-L87-S7V5X:7-T<R@D8VQA<W-N86UE*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1V86QU95LG=F%L=64G72`]("9N97<@)&-L87-S;F%M93L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E6R=V86QU92==(#T@)FYE=R`D=&AI<RT^;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E]$149!54Q47T-,05-373L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AT<FEM*"1D871A*2`A/3T@)R<I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6R=G=65S<U1Y<&4G
M72`]/3T@=')U92D@>PH@("`@("`@("`@("`@("`@("`@(`DD9&%T82`]("1T
M:&ES+3Y?9W5E<W-!;F139714>7!E*"1D871A*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=C:&EL9')E;B==
M6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T-/3E1%
M3E1?2T5975T@/2`D9&%T83L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`O+R!S970@<')O<&5R=&EE<PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'9A;'5E6R=C:&EL9')E;B==(&%S("1P<F]P(#T^("1P<F]P5F%L
M*2!["B`@("`@("`@("`@("`@("`@("`@+R\@8VAE8VL@=VAE=&AE<B!T:&5R
M92!I<R!A('-P96-I86P@;65T:&]D('1O('-E="!T:&ES('!R;W!E<G1Y"B`@
M("`@("`@("`@("`@("`@("`@)'-E=$UE=&AO9"`]("=S970G+B1P<F]P.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1V86QU95LG
M=F%L=64G72P@)'-E=$UE=&AO9"DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)B1V86QU95LG=F%L=64G72P@)'-E
M=$UE=&AO9"DL("1P<F]P5F%L*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E)UTM
M/B1P<F]P(#T@)'!R;W!686P["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@(&-H96-K(&9O<B!M
M86=I8R!F=6YC=&EO;@H@("`@("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES
M=',H)'9A;'5E6R=V86QU92==+"`G7U]W86ME=7`G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1V86QU95LG=F%L=64G72T^7U]W86ME=7`H*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@+R\@=6YS97)I86QI>F4@86X@87)R87D*("`@("`@("`@("`@8V%S92`G
M87)R87DG.@H@("`@("`@("`@("`@("`@:68@*'1R:6TH)&1A=&$I("$]/2`G
M)RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=65;)V=U97-S5'EP
M92==(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`@("`@"21D871A(#T@
M)'1H:7,M/E]G=65S<T%N9%-E=%1Y<&4H)&1A=&$I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=F%L=65;)V-H:6QD<F5N
M)UU;)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T].
M5$5.5%]+15E=72`]("1D871A.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1V86QU95LG8VAI;&1R96XG72DI('L*("`@
M("`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E)UT@/2`D=F%L=65;)V-H
M:6QD<F5N)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1V86QU95LG=F%L=64G72`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("\O('5N<V5R:6%L:7IE(&$@;G5L;"!V86QU90H@("`@("`@("`@("!C87-E
M("=N=6QL)SH*("`@("`@("`@("`@("`@("1D871A(#T@;G5L;#L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@=6YS97)I86QI>F4@
M82!R97-O=7)C92`]/B!T:&ES(&ES(&YO="!P;W-S:6)L92`Z+2@*("`@("`@
M("`@("`@8V%S92`G<F5S;W5R8V4G.@H@("`@("`@("`@("`@("`@)'9A;'5E
M6R=V86QU92==(#T@)&1A=&$["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("\O('5N<V5R:6%L:7IE(&%N>2!S8V%L87(@=F%L=64*("`@
M("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(&EF("@D=F%L=65;
M)V=U97-S5'EP92==(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`@("`@
M)&1A=&$@/2`D=&AI<RT^7V=U97-S06YD4V5T5'EP92@D9&%T82D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@('-E='1Y
M<&4H)&1A=&$L("1V86QU95LG='EP92==*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E)UT@
M/2`D9&%T83L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@
M("`@("`D<&%R96YT(#T@87)R87E?<&]P*"1T:&ES+3Y?=F%L4W1A8VLI.PH@
M("`@("`@(&EF("@D<&%R96YT(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?=6YS97)I86QI>F5D1&%T82`]("8D=F%L=65;)W9A;'5E)UT["B`@
M("`@("`@("`@("1T:&ES+3Y?<F]O="`]("8D=F%L=65;)VYA;64G73L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@<&%R96YT(&AA<R!T;R!B92!A;B!A<G)A>0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1P87)E;G1;)V-H:6QD<F5N)UTI('Q\("%I<U]A<G)A
M>2@D<&%R96YT6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`@("`@)'!A
M<F5N=%LG8VAI;&1R96XG72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!I
M9B`H(6EN7V%R<F%Y*"1P87)E;G1;)W1Y<&4G72P@87)R87DH)V%R<F%Y)RP@
M)V]B:F5C="<I*2D@>PH@("`@("`@("`@("`@("`@("`@("1P87)E;G1;)W1Y
M<&4G72`]("1T:&ES+3Y?9V5T0V]M<&QE>%1Y<&4H)'!A<F5N=%LG;F%M92==
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F5N=%LG='EP92==(#T]
M("=O8FIE8W0G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P87)E;G1;
M)V-L87-S)UT@/2`D<&%R96YT6R=N86UE)UT["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H:6Y?87)R87DH)&5L96UE;G0L("1T:&ES+3YO<'1I;VYS6UA-
M3%]53E-%4DE!3$E:15)?3U!424].7TE'3D]215]+15E372DI('L*("`@("`@
M("`@("`@("`@("1I9VYO<F5+97D@/2!T<G5E.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`))&EG;F]R94ME>2`](&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(`H@("`@("`@("`@("!I9B`H(65M<'1Y*"1V
M86QU95LG;F%M92==*2`F)B`D:6=N;W)E2V5Y(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@+R\@=&AE<F4@86QR96%D>2!H87,@8F5E;B!A('1A9R!W
M:71H('1H:7,@;F%M90H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1V
M86QU95LG;F%M92==+"`D<&%R96YT6R=C:&EL9')E;DME>7,G72D@?'P@:6Y?
M87)R87DH)'9A;'5E6R=N86UE)UTL("1T:&ES+3YO<'1I;VYS6UA-3%]53E-%
M4DE!3$E:15)?3U!424].7T9/4D-%7T5.54U=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("\O(&YO(&%G9W)E9V%T92!H87,@8F5E;B!C<F5A=&5D(&9O<B!T
M:&ES('1A9PH@("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)'9A
M;'5E6R=N86UE)UTL("1P87)E;G1;)V%G9W)E9TME>7,G72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)E;G1;)V-H:6QD<F5N
M)UU;)'9A;'5E6R=N86UE)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75T@/2!A
M<G)A>2@D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M
M92==72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D<&%R96YT6R=A9V=R
M96=+97ES)UTL("1V86QU95LG;F%M92==*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D<&%R96YT6R=C
M:&EL9')E;B==6R1V86QU95LG;F%M92==72P@)'9A;'5E6R=V86QU92==*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75T@/2`F)'9A;'5E
M6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A
M<F5N=%LG8VAI;&1R96Y+97ES)UTL("1V86QU95LG;F%M92==*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG8VAI;&1R96XG72P@)'9A;'5E6R=V
M86QU92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G)A>5]P=7-H
M*"1T:&ES+3Y?=F%L4W1A8VLL("1P87)E;G0I.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]D97!T:"TM.PH@("`@?0H*("`@+RHJ"B`@("`J($AA;F1L
M97(@9F]R(&-H87)A8W1E<B!D871A"B`@("`J"B`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@*B!`<&%R86T@(&]B:F5C="!834P@<&%R<V5R(&]B:F5C=`H@
M("`@*B!`<&%R86T@('-T<FEN9R!#1$%400H@("`@*B!`<F5T=7)N('9O:60*
M("`@("HO"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'!A<G-E<BP@)&-D
M871A*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E]$14-/1$5?1E5.0UT@(3T](&YU;&PI('L*("`@
M("`@("`@("`@)&-D871A(#T@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F]P=&EO
M;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5#3T1%7T953D-=+"`D8V1A
M=&$I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V1A=&%3=&%C:ULD=&AI
M<RT^7V1E<'1H72`N/2`D8V1A=&$["B`@("!]"@H@("`O*BH*("`@("H@9V5T
M('1H92!C;VUP;&5X('1Y<&4L('1H870@<VAO=6QD(&)E('5S960@9F]R(&$@
M<W!E8VEF:65D('1A9PH@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@;F%M92!O9B!T:&4@=&%G"B`@
M("`J($!R971U<FX@("!S=')I;F<@("`@("!C;VUP;&5X('1Y<&4@*"=A<G)A
M>2<@;W(@)V]B:F5C="<I"B`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$-O;7!L
M97A4>7!E*"1T86=N86UE*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H
M)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%
M6%194$5=*2D@>PH@("`@("`@(`ER971U<FX@)'1H:7,M/F]P=&EO;G-;6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$5=.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?0T]-4$Q%6%194$5=6R1T86=N86UE72DI('L*("`@("`@
M("`)<F5T=7)N("1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7T-/35!,15A465!%75LD=&%G;F%M95T["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]0
M5$E/3E]#3TU03$585%E015U;)R-D969A=6QT)UTI*2!["B`@("`@("`@"7)E
M='5R;B`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]#
M3TU03$585%E015U;)R-D969A=6QT)UT["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`G87)R87DG.PH@("`@?0H@("`@"B`@("\J*@H@("`@*B!C<F5A=&4@
M=&AE(%A-3%]087)S97(@:6YS=&%N8V4*("`@("H*("`@("H@0&%C8V5S<R`@
M("!P<FEV871E"B`@("`J($!R971U<FX@("`@8F]O;&5A;@H@("`@*B\*("`@
M(&9U;F-T:6]N(%]C<F5A=&5087)S97(H*0H@("`@>PH@("`@("`@(&EF("AI
M<U]O8FIE8W0H)'1H:7,M/E]P87)S97(I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%R<V5R+3YF<F5E*"D["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<&%R<V5R*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]P87)S97(@/2`F
M;F5W(%A-3%]087)S97(H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?14Y#3T1)3D=?4T]54D-%72P@)V5V96YT)RP@)'1H:7,M/F]P
M=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T54
M72D["B`@("`@("`@)'1H:7,M/E]P87)S97(M/F9O;&1I;F<@/2!F86QS93L*
M("`@("`@("`D=&AI<RT^7W!A<G-E<BT^<V5T2&%N9&QE<D]B:B@D=&AI<RD[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U-E<FEA;&EZ97(N<&AP````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3(T-S(`,3`U,34T
M,S$P-3<`,#(P-C,R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_4$A0"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@6$U,
M7U-E<FEA;&EZ97(*("H*("H@0W)E871E<R!834P@9&]C=6UE;G1S(&9R;VT@
M4$A0(&1A=&$@<W1R=6-T=7)E<R!L:6ME(&%R<F%Y<RP@;V)J96-T<R!O<B!S
M8V%L87)S+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@6$U,"B`J($!P86-K86=E("`@(%A-3%]397)I86QI>F5R
M"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!3
M97)I86QI>F5R+G!H<"QV(#$N-#<@,C`P-2\P.2\S,"`Q,SHT,#HS,"!S8VAS
M="!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O6$U,7U-E<FEA;&EZ97(*("H@0'-E92`@("`@("`@6$U,7U5N<V5R
M:6%L:7IE<@H@*B\*"B\J*@H@*B!U<V5S(%!%05(@97)R;W(@;6%N86=E;65N
M=`H@*B\*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@=7-E<R!8
M34Q?571I;"!T;R!C<F5A=&4@6$U,('1A9W,*("HO"G)E<75I<F5?;VYC92`G
M6$U,+U5T:6PN<&AP)SL*"B\J*@H@*B!O<'1I;VXZ('-T<FEN9R!U<V5D(&9O
M<B!I;F1E;G1A=&EO;@H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY
M('-T<FEN9R`H9&5F875L="!I<R!A;GD@<W1R:6YG*0H@*B\*9&5F:6YE*"=8
M34Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y4)RP@)VEN9&5N="<I.PH*+RHJ
M"B`J(&]P=&EO;CH@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A:W,*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<@*&1E9F%U;'0@:7,@
M7&XI"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%
M04M3)RP@)VQI;F5B<F5A:R<I.PH*+RHJ"B`J(&]P=&EO;CH@96YA8FQE('1Y
M<&4@:&EN=',*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@
M+2!F86QS90H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?5%E0
M14A)3E13)RP@)W1Y<&5(:6YT<R<I.PH*+RHJ"B`J(&]P=&EO;CH@861D(&%N
M(%A-3"!D96-L87)A=&EO;@H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@
M=')U90H@*B`M(&9A;'-E"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]0
M5$E/3E]834Q?1$5#3%]%3D%"3$5$)RP@)V%D9$1E8VPG*3L*"B\J*@H@*B!O
M<'1I;VXZ(&5N8V]D:6YG(&]F('1H92!D;V-U;65N=`H@*@H@*B!0;W-S:6)L
M92!V86QU97,Z"B`J("T@86YY('9A;&ED(&5N8V]D:6YG"B`J("T@;G5L;"`H
M9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7UA-
M3%]%3D-/1$E.1R<L("=E;F-O9&EN9R<I.PH*+RHJ"B`J(&]P=&EO;CH@9&5F
M875L="!N86UE(&9O<B!T86=S"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@
M+2!A;GD@<W1R:6YG("A834Q?4V5R:6%L:7IE<E]486<@:7,@9&5F875L="D*
M("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'
M)RP@)V1E9F%U;'1486=.86UE)RD["@HO*BH*("H@;W!T:6]N.B!U<V4@8VQA
M<W-N86UE(&9O<B!O8FIE8W1S(&EN(&EN9&5X960@87)R87ES"B`J"B`J(%!O
M<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E("AD969A=6QT*0H@*B`M(&9A;'-E
M"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]#3$%34TY!345?
M05-?5$%'3D%-12<L("=C;&%S<T%S5&%G3F%M92<I.PH*+RHJ"B`J(&]P=&EO
M;CH@871T<FEB=71E('=H97)E(&]R:6=I;F%L(&ME>2!I<R!S=&]R960*("H*
M("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<@*&1E9F%U;'0@
M:7,@7V]R:6=I;F%L2V5Y*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7TM%62<L("=K97E!='1R:6)U=&4G*3L*"B\J*@H@
M*B!O<'1I;VXZ(&%T=')I8G5T92!F;W(@='EP92`H;VYL>2!I9B!T>7!E2&EN
M=',@/3X@=')U92D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S
M=')I;F<@*&1E9F%U;'0@:7,@7W1Y<&4I"B`J+PID969I;F4H)UA-3%]315))
M04Q)6D527T]05$E/3E]!5%1224)55$5?5%E012<L("=T>7!E071T<FEB=71E
M)RD["@HO*BH*("H@;W!T:6]N.B!A='1R:6)U=&4@9F]R(&-L87-S("AO;FQY
M(&EF('1Y<&5(:6YT<R`]/B!T<G5E*0H@*@H@*B!0;W-S:6)L92!V86QU97,Z
M"B`J("T@86YY('-T<FEN9R`H9&5F875L="!I<R!?8VQA<W,I"B`J+PID969I
M;F4H)UA-3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U,G+"`G
M8VQA<W-!='1R:6)U=&4G*3L*"B\J*@H@*B!O<'1I;VXZ('-C86QA<B!V86QU
M97,@*'-T<FEN9W,L(&EN=',L+BXI('=I;&P@8F4@<V5R:6%L:7IE9"!A<R!A
M='1R:6)U=&4*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@
M+2!F86QS92`H9&5F875L="D*("H@+2!A<G)A>2!W:&EC:"!S971S('1H:7,@
M;W!T:6]N(&]N(&$@<&5R+71A9R!B87-I<PH@*B\*9&5F:6YE*"=834Q?4T52
M24%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415,G+"`G<V-A;&%R
M07-!='1R:6)U=&5S)RD["@HO*BH*("H@;W!T:6]N.B!P<F5P96YD('-T<FEN
M9R!F;W(@871T<FEB=71E<PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@
M86YY('-T<FEN9R`H9&5F875L="!I<R!A;GD@<W1R:6YG*0H@*B\*9&5F:6YE
M*"=834Q?4T5224%,25I%4E]/4%1)3TY?4%)%4$5.1%]!5%1224)55$53)RP@
M)W!R97!E;F1!='1R:6)U=&5S)RD["@HO*BH*("H@;W!T:6]N.B!I;F1E;G0@
M=&AE(&%T=')I8G5T97,L(&EF('-E="!T;R`G7V%U=&\G+"!I="!W:6QL(&EN
M9&5N="!A='1R:6)U=&5S('-O('1H97D@86QL('-T87)T(&%T('1H92!S86UE
M(&-O;'5M;@H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@=')U90H@*B`M
M(&9A;'-E("AD969A=6QT*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/
M4%1)3TY?24Y$14Y47T%45%))0E5415,G+"`G:6YD96YT071T<FEB=71E<R<I
M.PH*+RHJ"B`J(&]P=&EO;CH@=7-E("=S:6UP;&5X;6PG('1O('5S92!P87)E
M;G0@;F%M92!A<R!T86=N86UE(&EF('1R86YS9F]R;6EN9R!A;B!I;F1E>&5D
M(&%R<F%Y"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!834Q?4T5224%,
M25I%4E]-3T1%7T1%1D%53%0@*&1E9F%U;'0I"B`J("T@6$U,7U-%4DE!3$E:
M15)?34]$15]324U03$5834P*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?
M3U!424].7TU/1$4G+"`G;6]D92<I.PH*+RHJ"B`J(&]P=&EO;CH@861D(&$@
M9&]C='EP92!D96-L87)A=&EO;@H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J
M("T@=')U90H@*B`M(&9A;'-E("AD969A=6QT*0H@*B\*9&5F:6YE*"=834Q?
M4T5224%,25I%4E]/4%1)3TY?1$]#5%E015]%3D%"3$5$)RP@)V%D9$1O8W1Y
M<&4G*3L*"B\J*@H@*B!O<'1I;VXZ('-U<'!L>2!A('-T<FEN9R!O<B!A;B!A
M<G)A>2!W:71H(&ED(&%N9"!U<FD@*'M`<V5E(%A-3%]5=&EL.CIG971$;V-T
M>7!E1&5C;&%R871I;VXH*7T*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M
M('-T<FEN9PH@*B`M(&%R<F%Y"B`J+PID969I;F4H)UA-3%]315))04Q)6D52
M7T]05$E/3E]$3T-465!%)RP@)V1O8W1Y<&4G*3L*"B\J*@H@*B!O<'1I;VXZ
M(&YA;64@;V8@=&AE(')O;W0@=&%G"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*
M("H@+2!S=')I;F<*("H@+2!N=6QL("AD969A=6QT*0H@*B\*9&5F:6YE*"=8
M34Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%)RP@)W)O;W1.86UE)RD[
M"@HO*BH*("H@;W!T:6]N.B!A='1R:6)U=&5S(&]F('1H92!R;V]T('1A9PH@
M*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@87)R87D*("HO"F1E9FEN92@G
M6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?05144DE"4R<L("=R;V]T071T
M<FEB=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@86QL('9A;'5E<R!I;B!T:&ES
M(&ME>2!W:6QL(&)E('1R96%T960@87,@871T<FEB=71E<PH@*@H@*B!0;W-S
M:6)L92!V86QU97,Z"B`J("T@87)R87D*("HO"F1E9FEN92@G6$U,7U-%4DE!
M3$E:15)?3U!424].7T%45%))0E5415-?2T59)RP@)V%T=')I8G5T97-!<G)A
M>2<I.PH*+RHJ"B`J(&]P=&EO;CH@=&AI<R!V86QU92!W:6QL(&)E('5S960@
M9&ER96-T;'D@87,@8V]N=&5N="P@:6YS=&5A9"!O9B!C<F5A=&EN9R!A(&YE
M=R!T86<L(&UA>2!O;FQY(&)E('5S960@:6X@8V]N:G5C=&EO;B!W:71H(&%T
M=')I8G5T97-!<G)A>0H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@<W1R
M:6YG"B`J("T@;G5L;"`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!
M3$E:15)?3U!424].7T-/3E1%3E1?2T59)RP@)V-O;G1E;G1.86UE)RD["@HO
M*BH*("H@;W!T:6]N.B!T:&ES('9A;'5E('=I;&P@8F4@=7-E9"!I;B!A(&-O
M;6UE;G0L(&EN<W1E860@;V8@8W)E871I;F<@82!N97<@=&%G"B`J"B`J(%!O
M<W-I8FQE('9A;'5E<SH*("H@+2!S=')I;F<*("H@+2!N=6QL("AD969A=6QT
M*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?0T]-345.5%]+
M15DG+"`G8V]M;65N=$YA;64G*3L*"B\J*@H@*B!O<'1I;VXZ('1A9R!N86UE
M<R!T:&%T('=I;&P@8F4@8VAA;F=E9`H@*@H@*B!0;W-S:6)L92!V86QU97,Z
M"B`J("T@87)R87D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].
M7U1!1TU!4"<L("=T86=-87`G*3L*"B\J*@H@*B!O<'1I;VXZ(&9U;F-T:6]N
M('1H870@=VEL;"!B92!A<'!L:65D(&)E9F]R92!S97)I86QI>FEN9PH@*@H@
M*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('9A;&ED(%!(4"!C86QL8F%C
M:PH@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?14Y#3T1%7T95
M3D,G+"`G96YC;V1E1G5N8W1I;VXG*3L*"B\J*@H@*B!O<'1I;VXZ(&9U;F-T
M:6]N('1H870@=VEL;"!B92!A<'!L:65D(&)E9F]R92!S97)I86QI>FEN9PH@
M*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@<W1R:6YG"B`J("T@;G5L;"`H
M9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7TY!
M34534$%#12<L("=N86UE<W!A8V4G*3L*"B\J*@H@*B!O<'1I;VXZ('1Y<&4@
M;V8@96YT:71I97,@=&\@<F5P;&%C90H@*@H@*B!0;W-S:6)L92!V86QU97,Z
M"B`J("T@6$U,7U-%4DE!3$E:15)?14Y4251)15-?3D].10H@*B`M(%A-3%]3
M15))04Q)6D527T5.5$E424537UA-3"`H9&5F875L="D*("H@+2!834Q?4T52
M24%,25I%4E]%3E1)5$E%4U]834Q?4D5154E2140*("H@+2!834Q?4T5224%,
M25I%4E]%3E1)5$E%4U](5$U,"B`J+PID969I;F4H)UA-3%]315))04Q)6D52
M7T]05$E/3E]%3E1)5$E%4R<L("=R97!L86-E16YT:71I97,G*3L*"B\J*@H@
M*B!O<'1I;VXZ('=H971H97(@=&\@<F5T=7)N('1H92!R97-U;'0@;V8@=&AE
M('-E<FEA;&EZ871I;VX@9G)O;2!S97)I86QI>F4H*0H@*@H@*B!0;W-S:6)L
M92!V86QU97,Z"B`J("T@=')U90H@*B`M(&9A;'-E("AD969A=6QT*0H@*B\*
M9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"<L
M("=R971U<FY297-U;'0G*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@=&\@
M:6=N;W)E('!R;W!E<G1I97,@=&AA="!A<F4@<V5T('1O(&YU;&P*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L
M="D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7TE'3D]215].
M54Q,)RP@)VEG;F]R94YU;&PG*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@
M=&\@=7-E(&-D871A('-E8W1I;VYS(&9O<B!C:&%R86-T97(@9&%T80H@*@H@
M*B!0;W-S:6)L92!V86QU97,Z"B`J("T@=')U90H@*B`M(&9A;'-E("AD969A
M=6QT*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?0T1!5$%?
M4T5#5$E/3E,G+"`G8V1A=&$G*3L*"@HO*BH*("H@9&5F875L="!M;V1E"B`J
M+PID969I;F4H)UA-3%]315))04Q)6D527TU/1$5?1$5&055,5"<L("=D969A
M=6QT)RD["@HO*BH*("H@4VEM<&QE6$U,(&UO9&4*("H*("H@5VAE;B!S97)I
M86QI>FEN9R!I;F1E>&5D(&%R<F%Y<RP@=&AE(&ME>2!O9B!T:&4@<&%R96YT
M('9A;'5E(&ES('5S960@87,@82!T86=N86UE+@H@*B\*9&5F:6YE*"=834Q?
M4T5224%,25I%4E]-3T1%7U-)35!,15A-3"<L("=S:6UP;&5X;6PG*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@(`HO*BH*("H@97)R;W(@8V]D92!F;W(@
M;F\@<V5R:6%L:7IA=&EO;B!D;VYE"B`J+PID969I;F4H)UA-3%]315))04Q)
M6D527T524D]27TY/7U-%4DE!3$E:051)3TXG+"`U,2D["@HO*BH*("H@9&\@
M;F]T(')E<&QA8V4@96YT:71I=&5S"B`J+PID969I;F4H)UA-3%]315))04Q)
M6D527T5.5$E424537TY/3D4G+"!834Q?551)3%]%3E1)5$E%4U].3TY%*3L*
M"B\J*@H@*B!R97!L86-E(&%L;"!834P@96YT:71I=&5S"B`J(%1H:7,@<V5T
M=&EN9R!W:6QL(')E<&QA8V4@/"P@/BP@(BP@)R!A;F0@)@H@*B\*9&5F:6YE
M*"=834Q?4T5224%,25I%4E]%3E1)5$E%4U]834PG+"!834Q?551)3%]%3E1)
M5$E%4U]834PI.PH*+RHJ"B`J(')E<&QA8V4@;VYL>2!R97%U:7)E9"!834P@
M96YT:71I=&5S"B`J(%1H:7,@<V5T=&EN9R!W:6QL(')E<&QA8V4@/"P@(B!A
M;F0@)@H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]%3E1)5$E%4U]834Q?
M4D5154E2140G+"!834Q?551)3%]%3E1)5$E%4U]834Q?4D5154E2140I.PH*
M+RHJ"B`J(')E<&QA8V4@2%1-3"!E;G1I=&ET97,*("H@0&QI;FL@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VAT;6QE;G1I=&EE<PH@*B\*9&5F:6YE*"=834Q?
M4T5224%,25I%4E]%3E1)5$E%4U](5$U,)RP@6$U,7U5424Q?14Y4251)15-?
M2%1-3"D["@HO*BH*("H@0W)E871E<R!834P@9&]C=6UE;G1S(&9R;VT@4$A0
M(&1A=&$@<W1R=6-T=7)E<R!L:6ME(&%R<F%Y<RP@;V)J96-T<R!O<B!S8V%L
M87)S+@H@*@H@*B!T:&ES(&-L87-S(&-A;B!B92!U<V5D(&EN('1W;R!M;V1E
M<SH*("H*("H@(#$N(&-R96%T92!A;B!834P@9&]C=6UE;G0@9G)O;2!A;B!A
M<G)A>2!O<B!O8FIE8W0@=&AA="!I<R!P<F]C97-S960@8GD@;W1H97(*("H@
M("`@87!P;&EC871I;VYS+B!4:&%T(&UE86YS+"!Y;W4@8V%N(&-R96%T92!A
M(%)$1B!D;V-U;65N="!F<F]M(&%N(&%R<F%Y(&EN('1H90H@*B`@("!F;VQL
M;W=I;F<@9F]R;6%T.@H@*@H@*B`@("`D9&%T82`](&%R<F%Y*`H@*B`@("`@
M("`@("`@("`@)V-H86YN96PG(#T^(&%R<F%Y*`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=&ET;&4G(#T^("=%>&%M<&QE(%)$1B!C:&%N;F5L
M)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG("`]/B`G
M:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4G+`H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:6UA9V4G(#T^(&%R<F%Y*`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=&ET;&4G(#T^("=%>&%M<&QE
M(&EM86=E)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W5R;"<@("`]/B`G:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4O:6UA
M9V4N9VEF)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI;FLG("`]/B`G:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4G"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T:71L92<@/3X@)T5X86UP
M;&4@:71E;2<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VQI;FLG("`]/B`G:'1T<#HO+V5X86UP;&4N8V]M)PH@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("DL"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T:71L92<@/3X@)T%N;W1H97(@17AA;7!L92!I=&5M)RP*("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&EN:R<@(#T^("=H
M='1P.B\O97AA;7!L92YO<F<G"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*0H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*
M("H@("`@("`@("`@("`@*3L*("H*("H@("!T;R!C<F5A=&4@82!21$8@9&]C
M=6UE;G0@9G)O;2!T:&ES(&%R<F%Y(&1O('1H92!F;VQL;W=I;F<Z"B`J"B`J
M("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH@*@H@*B`@
M("1O<'1I;VYS(#T@87)R87DH"B`J("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7TE.1$5.5"`@("`@(#T^(")<="(L("`@("`@
M("`O+R!I;F1E;G0@=VET:"!T86)S"B`J("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U,@(#T^(")<;B(L("`@
M("`@("`O+R!U<V4@54Y)6"!L:6YE(&)R96%K<PH@*B`@("`@("`@("`@("`@
M("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]23T]47TY!344@("`]/B`G
M<F1F.E)$1B<L("`@+R\@<F]O="!T86<*("H@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404<@/3X@)VET96TG
M("`@("`@("\O('1A9R!F;W(@=F%L=65S('=I=&@@;G5M97)I8R!K97ES"B`J
M("`@*3L*("H*("H@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE
M<B@D;W!T:6]N<RD["B`J("`@)')D9B`@("`@("`@/2`D<V5R:6%L:7IE<BT^
M<V5R:6%L:7IE*"1D871A*3L*("H*("H@66]U('=I;&P@9V5T(&$@8V]M<&QE
M=&4@6$U,(&1O8W5M96YT('1H870@8V%N(&)E('!R;V-E<W-E9"!L:6ME(&%N
M>2!21$8@9&]C=6UE;G0N"B`J"B`J(#(N('1H:7,@8VQA<W-E<R!C86X@8F4@
M=7-E9"!T;R!S97)I86QI>F4@86YY(&1A=&$@<W1R=6-T=7)E(&EN(&$@=V%Y
M('1H870@:70@8V%N"B`J("`@(&QA=&5R(&)E('5N<V5R:6%L:7IE9"!A9V%I
M;BX*("H@("`@6$U,7U-E<FEA;&EZ97(@=VEL;"!S=&]R92!T:&4@='EP92!O
M9B!T:&4@=F%L=64@86YD(&%D9&ET:6]N86P@;65T82!I;F9O<FUA=&EO;@H@
M*B`@("!I;B!A='1R:6)U=&5S(&]F('1H92!S=7)R;W5N9&EN9R!T86<N(%1H
M:7,@;65A="!I;F9O<FUA=&EO;B!C86X@;&%T97(@8F4@=7-E9`H@*B`@("!T
M;R!R97-T;W)E('1H92!O<FEG:6YA;"!D871A('-T<G5C='5R92!I;B!02%`N
M($EF('EO=2!W86YT(%A-3%]397)I86QI>F5R"B`J("`@('1O(&%D9"!M971A
M(&EN9F]R;6%T:6]N('1O('1H92!T86=S+"!A9&0*("H*("H@("`@("!834Q?
M4T5224%,25I%4E]/4%1)3TY?5%E014A)3E13(#T^('1R=64*("H*("H@("`@
M=&\@=&AE(&]P=&EO;G,@87)R87D@:6X@=&AE(&-O;G-T<G5C=&]R+@H@*@H@
M*B!`8V%T96=O<GD@("!834P*("H@0'!A8VMA9V4@("`@6$U,7U-E<FEA;&EZ
M97(*("H@0&%U=&AO<B`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,"XQ."XP"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]834Q?4V5R:6%L:7IE<@H@*B!`<V5E("`@("`@("!834Q?56YS97)I
M86QI>F5R"B`J+PIC;&%S<R!834Q?4V5R:6%L:7IE<B!E>'1E;F1S(%!%05(*
M>PH@("`O*BH*("`@("H@;&ES="!O9B!A;&P@879A:6QA8FQE(&]P=&EO;G,*
M("`@("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!V87(@("`@87)R
M87D*("`@("HO"B`@("!V87(@)%]K;F]W;D]P=&EO;G,@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?
M3U!424].7TE.1$5.5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U,L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E]465!%2$E.5%,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]315))04Q)6D527T]05$E/3E]834Q?1$5#3%]%3D%"3$5$+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?6$U,7T5.0T]$24Y'+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D52
M7T]05$E/3E]#3$%34TY!345?05-?5$%'3D%-12P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))
M0E5415]+15DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?5%E012P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415]#3$%34RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U-#04Q!4E]!4U]!5%1224)5
M5$53+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?4%)%4$5.1%]!5%1224)55$53+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M24Y$14Y47T%45%))0E5415,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]-3T1%+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M1$]#5%E015]%3D%"3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$]#5%E012P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7U)/3U1?3D%-12P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?05144DE"4RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415-?2T59+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E]#3TU-14Y47TM%62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U1!1TU!4"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7T5.0T]$15]&54Y#+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?3D%-15-004-%+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M14Y4251)15,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E]215154DY?4D5354Q4+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M24=.3U)%7TY53$PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]315))04Q)6D527T]05$E/3E]#1$%405]314-424].4PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@+RHJ"B`@("`J
M(&1E9F%U;'0@;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I;VX*("`@("H*
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!V87(@("`@87)R87D*("`@
M("HO"B`@("!V87(@)%]D969A=6QT3W!T:6]N<R`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.
M5"`@("`@("`@("`@("`@(#T^("<G+"`@("`@("`@("`@("`@("`@("`@+R\@
M<W1R:6YG('5S960@9F]R(&EN9&5N=&%T:6]N"B`@("`@("`@("`@("`@("`@
M("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4R`@("`@
M("`@("`@/3X@(EQN(BP@("`@("`@("`@("`@("`@("`O+R!S=')I;F<@=7-E
M9"!F;W(@;F5W;&EN97,*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]3
M15))04Q)6D527T]05$E/3E]465!%2$E.5%,@("`@("`@("`@("`]/B!F86QS
M92P@("`@("`@("`@("`@("`@("\O(&%U=&]M871I8V%L;'D@861D('1Y<&4@
M:&EN(&%T=')I8G5T97,*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]3
M15))04Q)6D527T]05$E/3E]834Q?1$5#3%]%3D%"3$5$("`@("`]/B!F86QS
M92P@("`@("`@("`@("`@("`@("\O(&%D9"!A;B!834P@9&5C;&%R871I;VX*
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E]834Q?14Y#3T1)3D<@("`@("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@
M("`@("\O(&5N8V]D:6YG('-P96-I9FEE9"!I;B!T:&4@6$U,(&1E8VQA<F%T
M:6]N"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?1$5&055,5%]404<@("`@("`@("`@/3X@)UA-3%]397)I86QI>F5R
M7U1A9R<L("`O+R!T86<@=7-E9"!F;W(@:6YD97AE9"!A<G)A>7,@;W(@:6YV
M86QI9"!N86UE<PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!
M3$E:15)?3U!424].7T-,05-33D%-15]!4U]404=.04U%(#T^(&9A;'-E+"`@
M("`@("`@("`@("`@("`@+R\@=7-E(&-L87-S;F%M92!F;W(@;V)J96-T<R!I
M;B!I;F1E>&5D(&%R<F%Y<PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15D@("`@("`@(#T^("=?
M;W)I9VEN86Q+97DG+"`@("`@("`@+R\@871T<FEB=71E('=H97)E(&]R:6=I
M;F%L(&ME>2!I<R!S=&]R960*("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?5%E012`@("`@("`]/B`G
M7W1Y<&4G+"`@("`@("`@("`@("`@("\O(&%T=')I8G5T92!F;W(@='EP92`H
M;VYL>2!I9B!T>7!E2&EN=',@/3X@=')U92D*("`@("`@("`@("`@("`@("`@
M("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U,@
M("`@("`]/B`G7V-L87-S)RP@("`@("`@("`@("`@("\O(&%T=')I8G5T92!F
M;W(@8VQA<W,@;V8@;V)J96-T<R`H;VYL>2!I9B!T>7!E2&EN=',@/3X@=')U
M92D*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E]30T%,05)?05-?05144DE"551%4R`]/B!F86QS92P@("`@("`@("`@
M("`@("`@("\O('-C86QA<B!V86QU97,@*'-T<FEN9W,L(&EN=',L+BXI('=I
M;&P@8F4@<V5R:6%L:7IE9"!A<R!A='1R:6)U=&4*("`@("`@("`@("`@("`@
M("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]04D5014Y$7T%45%))
M0E5415,@("`]/B`G)RP@("`@("`@("`@("`@("`@("`@("\O('!R97!E;F0@
M<W1R:6YG(&9O<B!A='1R:6)U=&5S"B`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y47T%45%))0E5415,@("`@
M/3X@9F%L<V4L("`@("`@("`@("`@("`@("`O+R!I;F1E;G0@=&AE(&%T=')I
M8G5T97,L(&EF('-E="!T;R`G7V%U=&\G+"!I="!W:6QL(&EN9&5N="!A='1R
M:6)U=&5S('-O('1H97D@86QL('-T87)T(&%T('1H92!S86UE(&-O;'5M;@H@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7TU/1$4@("`@("`@("`@("`@("`@(#T^(%A-3%]315))04Q)6D527TU/1$5?
M1$5&055,5"P@("`@("`@("`@("`@+R\@=7-E(%A-3%]315))04Q)6D527TU/
M1$5?4TE-4$Q%6$U,('1O('5S92!P87)E;G0@;F%M92!A<R!T86=N86UE(&EF
M('1R86YS9F]R;6EN9R!A;B!I;F1E>&5D(&%R<F%Y"B`@("`@("`@("`@("`@
M("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$]#5%E015]%3D%"
M3$5$("`@("`@/3X@9F%L<V4L("`@("`@("`@("`@("`@("`O+R!A9&0@82!D
M;V-T>7!E(&1E8VQA<F%T:6]N"B`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?1$]#5%E012`@("`@("`@("`@("`@/3X@
M;G5L;"P@("`@("`@("`@("`@("`@("`O+R!S=7!P;'D@82!S=')I;F<@;W(@
M86X@87)R87D@=VET:"!I9"!A;F0@=7)I("A[0'-E92!834Q?571I;#HZ9V5T
M1&]C='EP941E8VQA<F%T:6]N*"E]"B`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%("`@("`@("`@("`@
M/3X@;G5L;"P@("`@("`@("`@("`@("`@("`O+R!N86UE(&]F('1H92!R;V]T
M('1A9PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?
M3U!424].7U)/3U1?05144DE"4R`@("`@("`@(#T^(&%R<F%Y*"DL("`@("`@
M("`@("`@("`@+R\@871T<FEB=71E<R!O9B!T:&4@<F]O="!T86<*("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%12
M24)55$537TM%62`@("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@("\O
M(&%L;"!V86QU97,@:6X@=&AI<R!K97D@=VEL;"!B92!T<F5A=&5D(&%S(&%T
M=')I8G5T97,*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E]#3TY414Y47TM%62`@("`@("`@("`]/B!N=6QL+"`@("`@
M("`@("`@("`@("`@("\O('1H:7,@=F%L=64@=VEL;"!B92!U<V5D(&1I<F5C
M=&QY(&%S(&-O;G1E;G0L(&EN<W1E860@;V8@8W)E871I;F<@82!N97<@=&%G
M+"!M87D@;VYL>2!B92!U<V5D(&EN(&-O;FIU8W1I;VX@=VET:"!A='1R:6)U
M=&5S07)R87D*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E]#3TU-14Y47TM%62`@("`@("`@("`]/B!N=6QL+"`@("`@
M("`@("`@("`@("`@("\O('1H:7,@=F%L=64@=VEL;"!B92!U<V5D(&1I<F5C
M=&QY(&%S(&-O;6UE;G0L(&EN<W1E860@;V8@8W)E871I;F<@82!N97<@=&%G
M+"!M87D@;VYL>2!B92!U<V5D(&EN(&-O;FIU8W1I;VX@=VET:"!A='1R:6)U
M=&5S07)R87D*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E]404=-05`@("`@("`@("`@("`@("`]/B!A<G)A>2@I+"`@
M("`@("`@("`@("`@("\O('1A9R!N86UE<R!T:&%T('=I;&P@8F4@8VAA;F=E
M9`H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!4
M24].7T5.0T]$15]&54Y#("`@("`@("`@(#T^(&YU;&PL("`@("`@("`@("`@
M("`@("`@+R\@9G5N8W1I;VX@=&AA="!W:6QL(&)E(&%P<&QI960@8F5F;W)E
M('-E<FEA;&EZ:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?3D%-15-004-%("`@("`@("`@("`@/3X@;G5L;"P@
M("`@("`@("`@("`@("`@("`O+R!N86UE<W!A8V4@=&\@=7-E"B`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?14Y4251)
M15,@("`@("`@("`@("`@/3X@6$U,7U-%4DE!3$E:15)?14Y4251)15-?6$U,
M+"`O+R!T>7!E(&]F(&5N=&ET:65S('1O(')E<&QA8V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%
M4U5,5"`@("`@("`@/3X@9F%L<V4L("`@("`@("`@("`@("`@("`O+R!S97)I
M86QI>F4H*2!R971U<FYS('1H92!R97-U;'0@;V8@=&AE('-E<FEA;&EZ871I
M;VX@:6YS=&5A9"!O9B!T<G5E"B`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?24=.3U)%7TY53$P@("`@("`@("`@/3X@
M9F%L<V4L("`@("`@("`@("`@("`@("`O+R!I9VYO<F4@<')O<&5R=&EE<R!T
M:&%T(&%R92!S970@=&\@;G5L;`H@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7T-$051!7U-%0U1)3TY3("`@("`@(#T^
M(&9A;'-E("`@("`@("`@("`@("`@("`@+R\@5VAE=&AE<B!T;R!U<V4@8V1A
M=&$@<V5C=&EO;G,@9F]R('!L86EN(&-H87)A8W1E<B!D871A"B`@("`@("`@
M("`@("`@("`@("`@("`@("D["@H@("`O*BH*("`@("H@;W!T:6]N<R!F;W(@
M=&AE('-E<FEA;&EZ871I;VX*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("H@0'9A<B`@("!A<G)A>0H@("`@*B\*("`@('9A<B`D;W!T:6]N<R`]
M(&%R<F%Y*"D["@H@("`O*BH*("`@("H@8W5R<F5N="!T86<@9&5P=&@*("`@
M("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!V87(@("`@:6YT96=E
M<@H@("`@*B\*("`@('9A<B`D7W1A9T1E<'1H(#T@,#L*"B`@("\J*@H@("`@
M*B!S97)I;&EA;&EZ960@<F5P<F5S96YT871I;VX@;V8@=&AE(&1A=&$*("`@
M("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!V87(@("`@<W1R:6YG
M"B`@("`J+PH@("`@=F%R("1?<V5R:6%L:7IE9$1A=&$@/2!N=6QL.PH@("`@
M"B`@("\J*@H@("`@*B!C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`86-C97-S
M("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!M:7AE9"`@("1O<'1I;VYS("`@
M(&%R<F%Y(&-O;G1A:6YI;F<@;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I
M;VX*("`@("HO"B`@("!F=6YC=&EO;B!834Q?4V5R:6%L:7IE<B@@)&]P=&EO
M;G,@/2!N=6QL("D*("`@('L*("`@("`@("`D=&AI<RT^4$5!4B@I.PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI('L*("`@("`@("`@("`@)'1H
M:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI<RT^7V1E9F%U;'1/<'1I
M;VYS+"`D;W!T:6]N<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U;'1/<'1I;VYS.PH@("`@
M("`@('T*("`@('T*"B`@("\J*@H@("`@*B!R971U<FX@05!)('9E<G-I;VX*
M("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<W1A=&EC"B`@
M("`J($!R971U<FX@("!S=')I;F<@("1V97)S:6]N($%022!V97)S:6]N"B`@
M("`J+PH@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("<P+C$X+C`G.PH@("`@?0H*("`@+RHJ"B`@("`J(')E<V5T(&%L
M;"!O<'1I;VYS('1O(&1E9F%U;'0@;W!T:6]N<PH@("`@*@H@("`@*B!`86-C
M97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!S971/<'1I;VXH*2P@6$U,
M7U-E<FEA;&EZ97(H*0H@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T3W!T:6]N
M<R@I"B`@("!["B`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^7V1E
M9F%U;'1/<'1I;VYS.PH@("`@?0H*("`@+RHJ"B`@("`J('-E="!A;B!O<'1I
M;VX*("`@("H*("`@("H@66]U(&-A;B!U<V4@=&AI<R!M971H;V0@:68@>6]U
M(&1O(&YO="!W86YT('1O('-E="!A;&P@;W!T:6]N<R!I;B!T:&4@8V]N<W1R
M=6-T;W(*("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E
M("`@("`@<F5S971/<'1I;VXH*2P@6$U,7U-E<FEA;&EZ97(H*0H@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$]P=&EO;B@D;F%M92P@)'9A;'5E*0H@("`@>PH@
M("`@("`@("1T:&ES+3YO<'1I;VYS6R1N86UE72`]("1V86QU93L*("`@('T*
M("`@(`H@("`O*BH*("`@("H@<V5T<R!S979E<F%L(&]P=&EO;G,@870@;VYC
M90H@("`@*@H@("`@*B!9;W4@8V%N('5S92!T:&ES(&UE=&AO9"!I9B!Y;W4@
M9&\@;F]T('=A;G0@=&\@<V5T(&%L;"!O<'1I;VYS(&EN('1H92!C;VYS=')U
M8W1O<@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@
M("`@("!R97-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R*"DL('-E=$]P
M=&EO;B@I"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N<R@D;W!T:6]N
M<RD*("`@('L*("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E
M*"1T:&ES+3YO<'1I;VYS+"`D;W!T:6]N<RD["B`@("!]"@H@("`O*BH*("`@
M("H@<V5R:6%L:7IE(&1A=&$*("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PH@("`@*B!`<&%R86T@("`@;6EX960@("`@)&1A=&$@9&%T82!T;R!S97)I
M86QI>F4*("`@("H@0')E='5R;B`@(&)O;VQE86X@('1R=64@;VX@<W5C8V5S
M<RP@<&5A<B!E<G)O<B!O;B!F86EL=7)E"B`@("`J+PH@("`@9G5N8W1I;VX@
M<V5R:6%L:7IE*"1D871A+"`D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@
M("`@+R\@:68@;W!T:6]N<R!H879E(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE
M;2!I;G-T96%D"B`@("`@("`@+R\@;V8@=&AE('!R979I;W5S;'D@9&5F:6YE
M9"!O;F5S"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D@>PH@("`@
M("`@("`@("`D;W!T:6]N<T)A:R`]("1T:&ES+3YO<'1I;VYS.PH@("`@("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V]V97)R:61E3W!T:6]N<R==*2`F
M)B`D;W!T:6]N<ULG;W9E<G)I9&5/<'1I;VYS)UT@/3T@=')U92D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI
M<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N<RD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y
M7VUE<F=E*"1T:&ES+3YO<'1I;VYS+"`D;W!T:6]N<RD["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;W!T:6]N<T)A:R`]
M(&YU;&P["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O("!S=&%R="!D
M97!T:"!I<R!Z97)O"B`@("`@("`@)'1H:7,M/E]T86=$97!T:"`](#`["@H@
M("`@("`@("1R;V]T071T<FEB=71E<R`]("1T:&ES+3YO<'1I;VYS6UA-3%]3
M15))04Q)6D527T]05$E/3E]23T]47T%45%))0E-=.PH@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3D%-
M15-004-%72D@)B8@:7-?87)R87DH)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7TY!34534$%#15TI*2!["B`@("`@("`@"21R;V]T071T
M<FEB=71E<ULG>&UL;G,Z)RXD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?3D%-15-004-%75LP75T@/2`D=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?3D%-15-004-%75LQ73L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`]("<G.PH@
M("`@("`@("\O('-E<FEA;&EZ92!A;B!A<G)A>0H@("`@("`@(&EF("AI<U]A
M<G)A>2@D9&%T82DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]23T]47TY!345=*2D@>PH@
M("`@("`@("`@("`@("`@)'1A9TYA;64@/2`D=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%73L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T86=.86UE(#T@)V%R<F%Y)SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T
M82`N/2`D=&AI<RT^7W-E<FEA;&EZ94%R<F%Y*"1D871A+"`D=&%G3F%M92P@
M)')O;W1!='1R:6)U=&5S*3L*("`@("`@("!](&5L<V5I9B`H:7-?;V)J96-T
M*"1D871A*2D@>PH@("`@("`@("`@("`O+R!S97)I86QI>F4@86X@;V)J96-T
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T52
M24%,25I%4E]/4%1)3TY?4D]/5%].04U%72DI('L*("`@("`@("`@("`@("`@
M("1T86=.86UE(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7U)/3U1?3D%-15T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&%G3F%M92`](&=E=%]C;&%S<R@D9&%T82D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`N/2`D
M=&AI<RT^7W-E<FEA;&EZ94]B:F5C="@D9&%T82P@)'1A9TYA;64L("1R;V]T
M071T<FEB=71E<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1A
M9R`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%72DI('L*("`@
M("`@("`@("`@("`@("1T86=;)W%N86UE)UT@/2`D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%73L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T86=;)W%N86UE)UT@/2!G971T
M>7!E*"1D871A*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7U194$5(24Y44UT@
M/3T]('1R=64I('L*("`@("`@("`@("`@("`@("1R;V]T071T<FEB=71E<ULD
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%
M7U194$5=72`](&=E='1Y<&4H)&1A=&$I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@($!S971T>7!E*"1D871A+"`G<W1R:6YG)RD["B`@("`@("`@("`@
M("1T86=;)V-O;G1E;G0G72`@("`]("1D871A.PH@("`@("`@("`@("`D=&%G
M6R=A='1R:6)U=&5S)UT@/2`D<F]O=$%T=')I8G5T97,["B`@("`@("`@("`@
M("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2`D=&AI<RT^7V-R96%T95A-3%1A
M9R@D=&%G*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@861D(&1O
M8W1Y<&4@9&5C;&%R871I;VX*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T1/0U194$5?14Y!0DQ%1%T@/3T]('1R
M=64I('L*("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`](%A-
M3%]5=&EL.CIG971$;V-T>7!E1&5C;&%R871I;VXH)'1A9TYA;64L("1T:&ES
M+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]$3T-465!%72D*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M370H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/E]S97)I86QI
M>F5D1&%T83L*("`@("`@("!]"@H@("`@("`@("\O("!B=6EL9"!X;6P@9&5C
M;&%R871I;VX*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7UA-3%]$14-,7T5.04),141=*2!["B`@("`@("`@("`@
M("1A='1S(#T@87)R87DH*3L*("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI
M>F5D1&%T82`](%A-3%]5=&EL.CIG971834Q$96-L87)A=&EO;B@G,2XP)RP@
M)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7UA-3%]%3D-/
M1$E.1UTI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+
M4UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES
M+3Y?<V5R:6%L:7IE9$1A=&$["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7U)%5%523E]215-5
M3%1=(#T]/2!T<G5E*2!["B`@("`@("`@"21R97-U;'0@/2`D=&AI<RT^7W-E
M<FEA;&EZ961$871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M97-U;'0@/2!T<G5E.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H
M)&]P=&EO;G-"86L@(3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/F]P
M=&EO;G,@/2`D;W!T:6]N<T)A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@+RHJ"B`@("`J(&=E="!T:&4@<F5S=6QT
M(&]F('1H92!S97)I86QI>F%T:6]N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`J($!R971U<FX@<W1R:6YG('-E<FEA;&EZ960@6$U,"B`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4V5R:6%L:7IE9$1A=&$H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7W-E<FEA;&EZ961$871A(#T](&YU;&PI('L*("`@
M("`@("`@("`@<F5T=7)N("`D=&AI<RT^<F%I<V5%<G)O<B@G3F\@<V5R:6%L
M:7IE9"!D871A(&%V86EL86)L92X@57-E(%A-3%]397)I86QI>F5R.CIS97)I
M86QI>F4H*2!F:7)S="XG+"!834Q?4T5224%,25I%4E]%4E)/4E].3U]315))
M04Q)6D%424].*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<V5R:6%L:7IE9$1A=&$["B`@("!]"B`@("`*("`@+RHJ"B`@("`J('-E<FEA
M;&EZ92!A;GD@=F%L=64*("`@("H*("`@("H@5&AI<R!M971H;V0@8VAE8VMS
M(&9O<B!T:&4@='EP92!O9B!T:&4@=F%L=64@86YD(&-A;&QS('1H92!A<'!R
M;W!R:6%T92!M971H;V0*("`@("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`J($!P87)A;2`@;6EX960@("`@("1V86QU90H@("`@*B!`<&%R86T@('-T
M<FEN9R`@("`D=&%G3F%M90H@("`@*B!`<&%R86T@(&%R<F%Y("`@("`D871T
M<FEB=71E<PH@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@*B\*("`@(&9U;F-T
M:6]N(%]S97)I86QI>F5686QU92@D=F%L=64L("1T86=.86UE(#T@;G5L;"P@
M)&%T=')I8G5T97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("1X;6P@/2`D=&AI<RT^7W-E
M<FEA;&EZ94%R<F%Y*"1V86QU92P@)'1A9TYA;64L("1A='1R:6)U=&5S*3L*
M("`@("`@("!](&5L<V5I9B`H:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@
M("`@("`@)'AM;"`]("1T:&ES+3Y?<V5R:6%L:7IE3V)J96-T*"1V86QU92P@
M)'1A9TYA;64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T86<@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`G<6YA;64G("`@
M("`@/3X@)'1A9TYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T
M=')I8G5T97,G(#T^("1A='1R:6)U=&5S+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C;VYT96YT)R`@("`]/B`D=F%L=64*("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@)'AM;"`]("1T:&ES+3Y?8W)E871E
M6$U,5&%G*"1T86<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'AM;#L*
M("`@('T*("`@(`H@("`O*BH*("`@("H@<V5R:6%L:7IE(&%N(&%R<F%Y"B`@
M("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@("!A
M<G)A>2`@("1A<G)A>2`@("`@("!A<G)A>2!T;R!S97)I86QI>F4*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)'1A9TYA;64@("`@(&YA;64@;V8@=&AE(')O
M;W0@=&%G"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1A='1R:6)U=&5S("!A
M='1R:6)U=&5S(&9O<B!T:&4@<F]O="!T86<*("`@("H@0')E='5R;B`@('-T
M<FEN9R`@)'-T<FEN9R`@("`@('-E<FEA;&EZ960@9&%T80H@("`@*B!`=7-E
M<R`@("`@6$U,7U5T:6PZ.FES5F%L:61.86UE*"D@=&\@8VAE8VLL('=H971H
M97(@:V5Y(&AA<R!T;R!B92!S=6)S=&ET=71E9`H@("`@*B\*("`@(&9U;F-T
M:6]N(%]S97)I86QI>F5!<G)A>2@F)&%R<F%Y+"`D=&%G3F%M92`](&YU;&PL
M("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D7V-O;G1E
M;G0@/2!N=6QL.PH@("`@("`@("1?8V]M;65N="`](&YU;&P["@H@("`@("`@
M("\O(&-H96-K(&9O<B!C;VUM96YT"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E]#3TU-14Y47TM%65T@(3T](&YU
M;&PI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1A<G)A>5LD=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?0T]-345.5%]+15E=72DI('L*
M("`@("`@("`@("`@("`@("1?8V]M;65N="`]("1A<G)A>5LD=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?0T]-345.5%]+15E=73L*("`@
M("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?0T]-345.5%]+15E=72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@("H@
M8VAE8VL@9F]R('-P96-I86P@871T<FEB=71E<PH@("`@("`@("`J+PH@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?
M05144DE"551%4U]+15E=("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7T%45%))0E5415-?2T5975TI*2!["B`@("`@("`@("`@("`@("`D871T
M<FEB=71E<R`]("1A<G)A>5LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?05144DE"551%4U]+15E=73L*("`@("`@("`@("`@("`@('5N
M<V5T*"1A<G)A>5LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?05144DE"551%4U]+15E=72D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@+RHJ"B`@("`@("`@("`@("`J(&-H96-K(&9O<B!S<&5C:6%L(&-O;G1E
M;G0*("`@("`@("`@("`@("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15E=("$]/2!N
M=6QL*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1T:&ES
M+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]#3TY414Y47TM%65U=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1?8V]N=&5N="`]("1A<G)A>5LD
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+
M15E=73L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D87)R87E;)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T5975TI
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7TE'3D]215].54Q,72`]/3T@=')U92D@>PH@("`@("`@(`EF;W)E86-H
M("AA<G)A>5]K97ES*"1A<G)A>2D@87,@)&ME>2D@>PH@("`@("`@(`D):68@
M*&ES7VYU;&PH)&%R<F%Y6R1K97E=*2D@>PH@("`@("`@(`D)"75N<V5T*"1A
M<G)A>5LD:V5Y72D["B`@("`@("`@"0E]"B`@("`@("`@"7T*("`@("`@("!]
M"@H@("`@("`@("\J"B`@("`@("`@*B!I9B!M;V1E(&ES('-E="!T;R!S:6UP
M;&5834PL(&-H96-K('=H971H97(*("`@("`@("`J('1H92!A<G)A>2!I<R!A
M<W-O8VEA=&EV92!O<B!I;F1E>&5D"B`@("`@("`@*B\*("`@("`@("!I9B`H
M:7-?87)R87DH)&%R<F%Y*2`F)B`A96UP='DH)&%R<F%Y*2`F)B`D=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?34]$15T@/3T@6$U,7U-%
M4DE!3$E:15)?34]$15]324U03$5834PI('L*("`@("`@("`@("`@)&EN9&5X
M960@/2!T<G5E.PH@("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES7VEN="@D:V5Y
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;F1E>&5D(#T@9F%L<V4["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D:6YD97AE9"`F)B`D=&AI
M<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?34]$15T@/3T@6$U,
M7U-%4DE!3$E:15)?34]$15]324U03$5834PI('L*("`@("`@("`@("`@("`@
M("1S=')I;F<@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A
M>2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D<W1R
M:6YG("X]("1T:&ES+3Y?<V5R:6%L:7IE5F%L=64H("1V86PL("1T86=.86UE
M+"`D871T<FEB=71E<RD["B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@
M("`@("`@("`@("`@)'-T<FEN9R`N/2`D=&AI<RT^;W!T:6]N<UM834Q?4T52
M24%,25I%4E]/4%1)3TY?3$E.14)214%+4UT["B`@("`@("`@("`@("`@("`@
M("`@+R\@9&\@:6YD96YT871I;VX*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TA
M/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P=&@^,"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1R:6YG("X]('-T<E]R97!E870H)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TL("1T:&ES+3Y?=&%G
M1&5P=&@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(')E='5R;B!R=')I;2@D<W1R:6YG*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`*("`@("`@("`D<V-A;&%R
M07-!='1R:6)U=&5S(#T@9F%L<V4["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?
M05144DE"551%4UTI("8F(&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"551%4UU;)'1A9TYA;65=
M*2D@>PH@("`@("`@("`@("`D<V-A;&%R07-!='1R:6)U=&5S(#T@)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7U-#04Q!4E]!4U]!5%12
M24)55$5375LD=&%G3F%M95T["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"
M551%4UT@/3T]('1R=64I('L*("`@("`@("`@("`@)'-C86QA<D%S071T<FEB
M=71E<R`]('1R=64["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D
M<V-A;&%R07-!='1R:6)U=&5S(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1T
M:&ES+3YE>'!E8W1%<G)O<B@G*B<I.PH@("`@("`@("`@("!F;W)E86-H("@D
M87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF
M("AI<U]S8V%L87(H)'9A;'5E*2`F)B`H6$U,7U5T:6PZ.FES5F%L:61.86UE
M*"1K97DI(#T]/2!T<G5E*2D@>PH@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1A<G)A>5LD:V5Y72D["B`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T
M97-;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7U!215!%
M3D1?05144DE"551%4UTN)&ME>5T@/2`D=F%L=64["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/G!O<$5X<&5C
M="@I.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D<V-A;&%R07-!='1R
M:6)U=&5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^97AP96-T17)R;W(H)RHG
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)'-C86QA<D%S071T<FEB=71E<R!A
M<R`D:V5Y*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1A<G)A>5LD
M:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V86QU92`]("1A<G)A>5LD
M:V5Y73L*("`@("`@("`@("`@("`@(&EF("AI<U]S8V%L87(H)'9A;'5E*2`F
M)B`H6$U,7U5T:6PZ.FES5F%L:61.86UE*"1K97DI(#T]/2!T<G5E*2D@>PH@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD:V5Y72D["B`@("`@
M("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7U!215!%3D1?05144DE"551%4UTN)&ME>5T@
M/2`D=F%L=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/G!O<$5X<&5C="@I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@8VAE8VL@9F]R(&5M<'1Y(&%R<F%Y(#T^(&-R96%T92!E;7!T>2!T
M86<*("`@("`@("!I9B`H96UP='DH)&%R<F%Y*2D@>PH@("`@("`@("`@("`D
M=&%G(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<6YA
M;64G("`@("`@/3X@)'1A9TYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8V]N=&5N="<@("`@/3X@)%]C;VYT96YT+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1R:6)U=&5S"B`@
M("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/E]T86=$97!T:"LK.PH@("`@("`@("`@("`D=&UP
M(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"
M4D5!2U-=.PH@("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("\O(&1O(&EN9&5N=&%T:6]N
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7TE.1$5.5%TA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P
M=&@^,"D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@+CT@<W1R7W)E<&5A
M="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y4
M72P@)'1H:7,M/E]T86=$97!T:"D["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E]404=-05!=6R1K97E=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1K97D@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/
M4%1)3TY?5$%'34%075LD:V5Y73L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O+R!C;W!Y(&ME>0H@("`@("`@("`@("`@("`@)&]R:6=+
M97D@/2`D:V5Y.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5X<&5C=$5R<F]R
M*"<J)RD["B`@("`@("`@("`@("`@("`O+R!K97D@8V%N;F]T(&)E('5S960@
M87,@=&%G;F%M92`]/B!U<V4@9&5F875L="!T86<*("`@("`@("`@("`@("`@
M("1V86QI9"`](%A-3%]5=&EL.CII<U9A;&ED3F%M92@D:V5Y*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YP;W!%>'!E8W0H*3L*("`@("`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1V86QI9"DI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7T-,05-33D%-15]!4U]404=.04U%72`F)B!I<U]O8FIE8W0H)'9A;'5E*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@9V5T7V-L87-S*"1V
M86QU92D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&ME>2`]("1T:&ES+3Y?9V5T1&5F875L=%1A9VYA
M;64H)'1A9TYA;64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1A='1S(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?5%E014A)3E1372`]/3T@=')U92D@>PH@("`@("`@("`@("`@
M("`@("`@("1A='1S6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E]!5%1224)55$5?5%E015U=(#T@9V5T='EP92@D=F%L=64I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D:V5Y("$]/2`D;W)I9TME>2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D871T<ULD=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%65U=(#T@*'-T<FEN9RDD
M;W)I9TME>3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)'1M<"`N/2`D=&AI<RT^7V-R96%T95A-
M3%1A9RAA<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=Q;F%M92<@("`@("`]/B`D:V5Y+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V%T=')I8G5T97,G(#T^("1A='1S+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G1E;G0G("`@
M(#T^("1V86QU92`I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("1T;7`@+CT@)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U-=.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(`H@("`@("`@("`@("`D=&AI<RT^
M7W1A9T1E<'1H+2T["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y472$]/6YU;&P@)B8@)'1H:7,M
M/E]T86=$97!T:#XP*2!["B`@("`@("`@("`@("`@("`D=&UP("X]('-T<E]R
M97!E870H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.
M1$5.5%TL("1T:&ES+3Y?=&%G1&5P=&@I.PH@("`@("`@("`@("!]"B`@("`*
M("`@("`@("`@("`@:68@*'1R:6TH)'1M<"D@/3T]("<G*2!["B`@("`@("`@
M("`@("`@("`D=&UP(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`*("`@("`@("`@("`@)'1A9R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("=Q;F%M92<@("`@("`]/B`D=&%G3F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8V]N=&5N="<@("`@/3X@)'1M<"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E<R<@/3X@)&%T=')I8G5T
M97,*("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]4
M65!%2$E.5%-=(#T]/2!T<G5E*2!["B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1A9ULG871T<FEB=71E<R==6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)
M6D527T]05$E/3E]!5%1224)55$5?5%E015U=*2D@>PH@("`@("`@("`@("`@
M("`@)'1A9ULG871T<FEB=71E<R==6R1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E]!5%1224)55$5?5%E015U=(#T@)V%R<F%Y)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-T<FEN9R`]("<G.PH@
M("`@("`@(&EF("@A:7-?;G5L;"@D7V-O;6UE;G0I*2!["B`@("`@("`@"21S
M=')I;F<@+CT@6$U,7U5T:6PZ.F-R96%T94-O;6UE;G0H)%]C;VUM96YT*3L*
M("`@("`@("`))'-T<FEN9R`N/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,
M25I%4E]/4%1)3TY?3$E.14)214%+4UT["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y472$]/6YU
M;&P@)B8@)'1H:7,M/E]T86=$97!T:#XP*2!["B`@("`@("`@("`@("`@("`D
M<W1R:6YG("X]('-T<E]R97!E870H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7TE.1$5.5%TL("1T:&ES+3Y?=&%G1&5P=&@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1S=')I;F<@+CT@)'1H:7,M
M/E]C<F5A=&5834Q486<H)'1A9RP@9F%L<V4I.PH@("`@("`@(')E='5R;B`D
M<W1R:6YG.PH@("`@?0H*("`@+RHJ"B`@("`J(&=E="!T:&4@;F%M92!O9B!T
M:&4@9&5F875L="!T86<N"B`@("`J"B`@("`J(%1H92!N86UE(&]F('1H92!P
M87)E;G0@=&%G(&YE961S('1O(&)E('!A<W-E9"!A<R!T:&4*("`@("H@9&5F
M875L="!N86UE(&-A;B!D97!E;F0@;VX@=&AE(&-O;G1E>'0N"B`@("`J"B`@
M("`J($!P87)A;2`@<W1R:6YG("`@("!N86UE(&]F('1H92!P87)E;G0@=&%G
M"B`@("`J($!R971U<FX@<W1R:6YG("`@("!D969A=6QT('1A9R!N86UE"B`@
M("`J+PH@("`@9G5N8W1I;VX@7V=E=$1E9F%U;'1486=N86UE*"1P87)E;G0I
M"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404==*2D@>PH@("`@("`@
M(`ER971U<FX@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7T1%1D%53%1?5$%'73L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]$149!54Q47U1!
M1UU;)'!A<F5N=%TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404==6R1P87)E
M;G1=.PH@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404==6R<C9&5F875L="==
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'75LG(V1E9F%U;'0G73L*("`@
M("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7T1%1D%53%1?5$%'75LG7U]D969A=6QT)UTI*2!["B`@
M("`@("`@("`@("\O(&ME97`@=&AI<R!F;W(@0D,*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]$149!
M54Q47U1!1UU;)U]?9&5F875L="==.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)UA-3%]397)I86QI>F5R7U1A9R<["B`@("!]"B`@("`*("`@+RHJ"B`@
M("`J('-E<FEA;&EZ92!A;B!O8FIE8W0*("`@("H*("`@("H@0&%C8V5S<R`@
M('!R:79A=&4*("`@("H@0'!A<F%M("`@(&]B:F5C="`@)&]B:F5C="!O8FIE
M8W0@=&\@<V5R:6%L:7IE"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I
M;F<@<V5R:6%L:7IE9"!D871A"B`@("`J+PH@("`@9G5N8W1I;VX@7W-E<FEA
M;&EZ94]B:F5C="@F)&]B:F5C="P@)'1A9TYA;64@/2!N=6QL+"`D871T<FEB
M=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+R\@8VAE8VL@9F]R(&UA
M9VEC(&9U;F-T:6]N"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&]B:F5C
M="P@)U]?<VQE97`G*2D@>PH@("`@("`@("`@("`D<')O<$YA;65S(#T@)&]B
M:F5C="T^7U]S;&5E<"@I.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!R
M;W!.86UE<RDI('L*("`@("`@("`@("`@"21P<F]P97)T:65S(#T@87)R87DH
M*3L*("`@("`@("`@("`@"69O<F5A8V@@*"1P<F]P3F%M97,@87,@)'!R;W!.
M86UE*2!["B`@("`@("`@("`@(`D))'!R;W!E<G1I97-;)'!R;W!.86UE72`]
M("1O8FIE8W0M/B1P<F]P3F%M93L*("`@("`@("`@("`@"7T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P<F]P97)T:65S(#T@9V5T
M7V]B:F5C=%]V87)S*"1O8FIE8W0I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'!R;W!E<G1I97,@/2!G971?;V)J96-T
M7W9A<G,H)&]B:F5C="D["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH
M)'1A9TYA;64I*2!["B`@("`@("`@("`@("1T86=.86UE(#T@9V5T7V-L87-S
M*"1O8FIE8W0I.PH@("`@("`@('T*"B`@("`@("`@+R\@='EP96AI;G1S(&%C
M=&EV871E9#\*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7U194$5(24Y44UT@/3T]('1R=64I('L*("`@("`@("`@
M("`@)&%T=')I8G5T97-;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?
M3U!424].7T%45%))0E5415]465!%75T@(#T@)V]B:F5C="<["B`@("`@("`@
M("`@("1A='1R:6)U=&5S6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E]!5%1224)55$5?0TQ!4U-=72`]("!G971?8VQA<W,H)&]B:F5C
M="D["B`@("`@("`@?0H@("`@("`@("1S=')I;F<@/2`D=&AI<RT^7W-E<FEA
M;&EZ94%R<F%Y*"1P<F]P97)T:65S+"`D=&%G3F%M92P@)&%T=')I8G5T97,I
M.PH@("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H@(`H@("`O*BH*("`@
M("H@8W)E871E(&$@=&%G(&9R;VT@86X@87)R87D*("`@("H@=&AI<R!M971H
M;V0@87=A:71S(&%N(&%R<F%Y(&EN('1H92!F;VQL;W=I;F<@9F]R;6%T"B`@
M("`J(&%R<F%Y*`H@("`@*B`@("`@("`G<6YA;64G("`@("`@("`]/B`D=&%G
M3F%M92P*("`@("H@("`@("`@)V%T=')I8G5T97,G("`@/3X@87)R87DH*2P*
M("`@("H@("`@("`@)V-O;G1E;G0G("`@("`@/3X@)&-O;G1E;G0L("`@("`@
M+R\@;W!T:6]N86P*("`@("H@("`@("`@)VYA;65S<&%C92<@("`@/3X@)&YA
M;65S<&%C92`@("`@+R\@;W!T:6]N86P*("`@("H@("`@("`@)VYA;65S<&%C
M955R:2<@/3X@)&YA;65S<&%C955R:2`@+R\@;W!T:6]N86P*("`@("H@("`I
M"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@
M("!A<G)A>2`@("1T86<@=&%G(&1E9FEN:71I;VX*("`@("H@0'!A<F%M("`@
M(&)O;VQE86X@)')E<&QA8V5%;G1I=&EE<R!W:&5T:&5R('1O(')E<&QA8V4@
M6$U,(&5N=&ET:65S(&EN(&-O;G1E;G0@;W(@;F]T"B`@("`J($!R971U<FX@
M("!S=')I;F<@("1S=')I;F<@6$U,('1A9PH@("`@*B\*("`@(&9U;F-T:6]N
M(%]C<F5A=&5834Q486<H)'1A9RP@)&9I<G-T0V%L;"`]('1R=64I"B`@("![
M"B`@("`@("`@+R\@8G5I;&0@9G5L;'D@<75A;&EF:65D('1A9R!N86UE"B`@
M("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/
M3E].04U%4U!!0T5=("$]/2!N=6QL*2!["B`@("`@("`@"6EF("AI<U]A<G)A
M>2@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3D%-15-0
M04-%72DI('L*("`@("`@("`)"21T86=;)W%N86UE)UT@/2`D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3D%-15-004-%75LP72`N("<Z
M)R`N("1T86=;)W%N86UE)UT["B`@("`@("`@"7T@96QS92!["B`@("`@("`@
M"0DD=&%G6R=Q;F%M92==(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:
M15)?3U!424].7TY!34534$%#15T@+B`G.B<@+B`D=&%G6R=Q;F%M92==.PH@
M("`@("`@(`E]"B`@("`@("`@?0H*("`@("`@("`O+R!A='1R:6)U=&4@:6YD
M96YT871I;VX*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7TE.1$5.5%]!5%1224)55$5372`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)&UU;'1I;&EN92`]('1R=64["B`@("`@("`@("`@("1I
M;F1E;G0@("`@/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E])3D1%3E1=+"`D=&AI<RT^7W1A9T1E<'1H*3L*"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/
M4%1)3TY?24Y$14Y47T%45%))0E5415-=(#T]("=?875T;R<I('L*("`@("`@
M("`@("`@("`@("1I;F1E;G0@+CT@<W1R7W)E<&5A="@G("<L("AS=')L96XH
M)'1A9ULG<6YA;64G72DK,BDI.PH*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1I;F1E;G0@+CT@)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7TE.1$5.5%]!5%1224)55$5373L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M=6QT:6QI;F4@
M/2!F86QS93L*("`@("`@("`@("`@)&EN9&5N="`@("`](&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T86=;)V-O;G1E;G0G72DI
M('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T86=;)V-O;G1E;G0G72DI('L*
M("`@("`@("`@("`@("`@("1T86=;)V-O;G1E;G0G72`]("`@)R<["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V5I9BAI<U]S8V%L87(H)'1A9ULG8V]N
M=&5N="==*2`F)B`H<W1R:6YG*21T86=;)V-O;G1E;G0G72`]/2`G)RD@>PH@
M("`@("`@("`@("`D=&%G6R=C;VYT96YT)UT@/2`@("<G.PH@("`@("`@('T*
M"B`@("`@("`@+R\@<F5P;&%C92!834P@96YT:71I97,@*&]N;'D@;F5E9&5D
M+"!I9B!T:&ES(&ES(&YO="!A(&YE<W1E9"!C86QL*0H@("`@("`@(&EF("@D
M9FER<W1#86QL(#T]/2!T<G5E*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?0T1!5$%?4T5#5$E/3E-=
M(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D<F5P;&%C945N=&ET:65S
M(#T@6$U,7U5424Q?0T1!5$%?4T5#5$E/3CL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`)("`@("1R97!L86-E16YT:71I97,@/2`D=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?14Y4251)15-=.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<&QA
M8V5%;G1I=&EE<R`](%A-3%]315))04Q)6D527T5.5$E424537TY/3D4["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]S8V%L87(H)'1A9ULG8V]N=&5N="==
M*2!\?"!I<U]N=6QL*"1T86=;)V-O;G1E;G0G72DI('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]%3D-/
M1$5?1E5.0UTI('L*("`@("`@("`@("`@("`@(&EF("@D9FER<W1#86QL(#T]
M/2!T<G5E*2!["B`@("`@("`@("`@("`@("`))'1A9ULG8V]N=&5N="==(#T@
M8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?
M3U!424].7T5.0T]$15]&54Y#72P@)'1A9ULG8V]N=&5N="==*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@"21T86=;)V%T=')I8G5T97,G72`]
M(&%R<F%Y7VUA<"@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?14Y#3T1%7T953D-=+"`D=&%G6R=A='1R:6)U=&5S)UTI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T86<@/2!834Q?571I;#HZ8W)E871E5&%G
M1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,L("1M=6QT:6QI;F4L
M("1I;F1E;G0L("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/
M3E],24Y%0E)%04M372D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T
M86=;)V-O;G1E;G0G72DI('L*("`@("`@("`@("`@)'1A9R`@("`]("`@)'1H
M:7,M/E]S97)I86QI>F5!<G)A>2@D=&%G6R=C;VYT96YT)UTL("1T86=;)W%N
M86UE)UTL("1T86=;)V%T=')I8G5T97,G72D["B`@("`@("`@?2!E;'-E:68@
M*&ES7V]B:F5C="@D=&%G6R=C;VYT96YT)UTI*2!["B`@("`@("`@("`@("1T
M86<@("`@/2`@("1T:&ES+3Y?<V5R:6%L:7IE3V)J96-T*"1T86=;)V-O;G1E
M;G0G72P@)'1A9ULG<6YA;64G72P@)'1A9ULG871T<FEB=71E<R==*3L*("`@
M("`@("!](&5L<V5I9B`H:7-?<F5S;W5R8V4H)'1A9ULG8V]N=&5N="==*2D@
M>PH@("`@("`@("`@("!S971T>7!E*"1T86=;)V-O;G1E;G0G72P@)W-T<FEN
M9R<I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7T5.0T]$15]&54Y#72D@>PH@("`@("`@("`@("`):68@
M*"1R97!L86-E16YT:71I97,@/3T]('1R=64I('L*("`@("`@("`@("`@("`@
M("`@("`D=&%G6R=C;VYT96YT)UT@/2!C86QL7W5S97)?9G5N8R@D=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?14Y#3T1%7T953D-=+"`D
M=&%G6R=C;VYT96YT)UTI.PH@("`@("`@("`@("`)?0H@("`@("`@("`@("`)
M)'1A9ULG871T<FEB=71E<R==(#T@87)R87E?;6%P*"1T:&ES+3YO<'1I;VYS
M6UA-3%]315))04Q)6D527T]05$E/3E]%3D-/1$5?1E5.0UTL("1T86=;)V%T
M=')I8G5T97,G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1A9R`]
M(%A-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RP@)')E<&QA8V5%
M;G1I=&EE<RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`@)'1A9SL*("`@
M('T*?0H_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]834PO4E!#+G!H<```````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#$V,#,S,@`Q,#4Q-30S,3`U-P`P,3<Q-#,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!834PM4E!#('!R;W1O8V]L"B`J"B`J(%1H:7,@:7,@82!0
M14%2+6EF:65D('9E<G-I;VX@;V8@57-E9G5L(&EN8R=S(%A-3"U24$,@9F]R
M(%!(4"X*("H@270@:&%S('-U<'!O<G0@9F]R($A45%`@=')A;G-P;W)T+"!P
M<F]X:65S(&%N9"!A=71H96YT:6-A=&EO;BX*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@3$E#14Y313H@3&EC96YS92!I<R!G<F%N=&5D('1O
M('5S92!O<B!M;V1I9GD@=&AI<R!S;V9T=V%R90H@*B`H(EA-3"U24$,@9F]R
M(%!(4"(I(&9O<B!C;VUM97)C:6%L(&]R(&YO;BUC;VUM97)C:6%L('5S92!P
M<F]V:61E9"!T:&4*("H@8V]P>7)I9VAT(&]F('1H92!A=71H;W(@:7,@<')E
M<V5R=F5D(&EN(&%N>2!D:7-T<FEB=71E9"!O<B!D97)I=F%T:79E('=O<FLN
M"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($%55$A/
M4B`B05,@25,B($%.1"!!3ED@15A04D534T5$($]2"B`J($E-4$Q)140@5T%2
M4D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,*("H@3T8@34520TA!3E1!0DE,2519($%.1"!&
M251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%
M1"X*("H@24X@3D\@159%3E0@4TA!3$P@5$A%($%55$A/4B!"12!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+"!"550*("H@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+`H@
M*B!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED*("H@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@
M3U(@5$]25`H@*B`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8*("H@5$A)
M4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E4
M62!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I
M8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@161D
M($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@*B!`875T:&]R("`@("!3
M=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!-87)T
M:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U(%1H92!02%`@1W)O=7`*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)00RYP:'`L=B`Q+CDU(#(P,#8O
M,#0O,38@,34Z,#0Z-3,@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B\*"@II9B`H
M(69U;F-T:6]N7V5X:7-T<R@G>&UL7W!A<G-E<E]C<F5A=&4G*2D@>PH@("`@
M:6YC;'5D95]O;F-E("=014%2+G!H<"<["B`@("!014%2.CIL;V%D17AT96YS
M:6]N*"=X;6PG*3L*?0H*+RHJ(T`K"B`J($5R<F]R(&-O;G-T86YT<PH@*B\*
M+RHJ"B`J(%!A<F%M971E<B!V86QU97,@9&]N)W0@;6%T8V@@<&%R86UE=&5R
M('1Y<&5S"B`J+PID969I;F4H)UA-3%]24$-?15)23U)?24Y604Q)1%]465!%
M)RP@,3`Q*3L*+RHJ"B`J(%!A<F%M971E<B!D96-L87)E9"!T;R!B92!N=6UE
M<FEC(&)U="!T:&4@=F%L=65S(&%R92!N;W0*("HO"F1E9FEN92@G6$U,7U)0
M0U]%4E)/4E].3TY?3E5-15))0U]&3U5.1"<L(#$P,BD["B\J*@H@*B!#;VUM
M=6YI8V%T:6]N(&5R<F]R"B`J+PID969I;F4H)UA-3%]24$-?15)23U)?0T].
M3D5#5$E/3E]&04E,140G+"`Q,#,I.PHO*BH*("H@5&AE(&%R<F%Y(&]R('-T
M<G5C="!H87,@86QR96%D>2!B965N('-T87)T960*("HO"F1E9FEN92@G6$U,
M7U)00U]%4E)/4E]!3%)%04197TE.251)04Q)6D5$)RP@,3`T*3L*+RHJ"B`J
M($EN8V]R<F5C="!P87)A;65T97)S('-U8FUI='1E9`H@*B\*9&5F:6YE*"=8
M34Q?4E!#7T524D]27TE.0T]24D5#5%]005)!35,G+"`Q,#4I.PHO*BH*("H@
M4')O9W)A;6UI;F<@97)R;W(@8GD@9&5V96QO<&5R"B`J+PID969I;F4H)UA-
M3%]24$-?15)23U)?4%)/1U)!34U)3D<G+"`Q,#8I.PHO*BHC0"TJ+PH*"B\J
M*@H@*B!$871A('1Y<&5S"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=8
M34Q?4E!#7TDT)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7TDT)UT@/2`G:30G
M.PH*+RHJ"B`J($1A=&$@='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!
M3%-;)UA-3%]24$-?26YT)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7TEN="==
M(#T@)VEN="<["@HO*BH*("H@1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN
M9R`D1TQ/0D%,4ULG6$U,7U)00U]";V]L96%N)UT*("HO"B1'3$]"04Q36R=8
M34Q?4E!#7T)O;VQE86XG72`]("=B;V]L96%N)SL*"B\J*@H@*B!$871A('1Y
M<&5S"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7T1O=6)L
M92=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]$;W5B;&4G72`]("=D;W5B;&4G
M.PH*+RHJ"B`J($1A=&$@='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!
M3%-;)UA-3%]24$-?4W1R:6YG)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-T
M<FEN9R==(#T@)W-T<FEN9R<["@HO*BH*("H@1&%T82!T>7!E<PH@*B!`9VQO
M8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]$871E5&EM92=="B`J+PHD
M1TQ/0D%,4ULG6$U,7U)00U]$871E5&EM92==(#T@)V1A=&54:6UE+FES;S@V
M,#$G.PH*+RHJ"B`J($1A=&$@='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,
M3T)!3%-;)UA-3%]24$-?0F%S938T)UT*("HO"B1'3$]"04Q36R=834Q?4E!#
M7T)A<V4V-"==(#T@)V)A<V4V-"<["@HO*BH*("H@1&%T82!T>7!E<PH@*B!`
M9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]!<G)A>2=="B`J+PHD
M1TQ/0D%,4ULG6$U,7U)00U]!<G)A>2==(#T@)V%R<F%Y)SL*"B\J*@H@*B!$
M871A('1Y<&5S"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#
M7U-T<G5C="=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]3=')U8W0G72`]("=S
M=')U8W0G.PH*"B\J*@H@*B!$871A('1Y<&4@;65T82UT>7!E<PH@*B!`9VQO
M8F%L(&%R<F%Y("1'3$]"04Q36R=834Q?4E!#7U1Y<&5S)UT*("HO"B1'3$]"
M04Q36R=834Q?4E!#7U1Y<&5S)UT@/2!A<G)A>2@*("`@("1'3$]"04Q36R=8
M34Q?4E!#7TDT)UT@("`@("`@/3X@,2P*("`@("1'3$]"04Q36R=834Q?4E!#
M7TEN="==("`@("`@/3X@,2P*("`@("1'3$]"04Q36R=834Q?4E!#7T)O;VQE
M86XG72`@/3X@,2P*("`@("1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R==("`@
M/3X@,2P*("`@("1'3$]"04Q36R=834Q?4E!#7T1O=6)L92==("`@/3X@,2P*
M("`@("1'3$]"04Q36R=834Q?4E!#7T1A=&54:6UE)UT@/3X@,2P*("`@("1'
M3$]"04Q36R=834Q?4E!#7T)A<V4V-"==("`@/3X@,2P*("`@("1'3$]"04Q3
M6R=834Q?4E!#7T%R<F%Y)UT@("`@/3X@,BP*("`@("1'3$]"04Q36R=834Q?
M4E!#7U-T<G5C="==("`@/3X@,RP**3L*"@HO*BH*("H@17)R;W(@;65S<V%G
M92!N=6UB97)S"B`J($!G;&]B86P@87)R87D@)$=,3T)!3%-;)UA-3%]24$-?
M97)R)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7V5R<B==(#T@87)R87DH"B`@
M("`G=6YK;F]W;E]M971H;V0G("`@("`@/3X@,2P*("`@("=I;G9A;&ED7W)E
M='5R;B<@("`@("`]/B`R+`H@("`@)VEN8V]R<F5C=%]P87)A;7,G("`@(#T^
M(#,L"B`@("`G:6YT<F]S<&5C=%]U;FMN;W=N)R`@/3X@-"P*("`@("=H='1P
M7V5R<F]R)R`@("`@("`@("`]/B`U+`H@("`@)VYO=%]R97-P;VYS95]O8FIE
M8W0G(#T^(#8L"B`@("`G:6YV86QI9%]R97%U97-T)R`@("`@/3X@-RP**3L*
M"B\J*@H@*B!%<G)O<B!M97-S86=E('-T<FEN9W,*("H@0&=L;V)A;"!A<G)A
M>2`D1TQ/0D%,4ULG6$U,7U)00U]S='(G70H@*B\*)$=,3T)!3%-;)UA-3%]2
M4$-?<W1R)UT@/2!A<G)A>2@*("`@("=U;FMN;W=N7VUE=&AO9"<@("`@("`]
M/B`G56YK;F]W;B!M971H;V0G+`H@("`@)VEN=F%L:61?<F5T=7)N)R`@("`@
M(#T^("=);G9A;&ED(')E='5R;B!P87EL;V%D.B!E;F%B;&4@9&5B=6=G:6YG
M('1O(&5X86UI;F4@:6YC;VUI;F<@<&%Y;&]A9"<L"B`@("`G:6YC;W)R96-T
M7W!A<F%M<R<@("`@/3X@)TEN8V]R<F5C="!P87)A;65T97)S('!A<W-E9"!T
M;R!M971H;V0G+`H@("`@)VEN=')O<W!E8W1?=6YK;F]W;B<@(#T^("=#86Y<
M)W0@:6YT<F]S<&5C=#H@;65T:&]D('5N:VYO=VXG+`H@("`@)VAT='!?97)R
M;W(G("`@("`@("`@(#T^("=$:61N7"=T(')E8V5I=F4@,C`P($]+(&9R;VT@
M<F5M;W1E('-E<G9E<BXG+`H@("`@)VYO=%]R97-P;VYS95]O8FIE8W0G(#T^
M("=4:&4@<F5Q=65S=&5D(&UE=&AO9"!D:61N7"=T(')E='5R;B!A;B!834Q?
M4E!#7U)E<W!O;G-E(&]B:F5C="XG+`H@("`@)VEN=F%L:61?<F5Q=65S="<@
M("`@(#T^("=);G9A;&ED(')E<75E<W0@<&%Y;&]A9"<L"BD["@H*+RHJ"B`J
M($1E9F%U;'0@6$U,(&5N8V]D:6YG("A)4T\M.#@U.2TQ+"!55$8M."!O<B!5
M4RU!4T-)22D*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?
M9&5F96YC;V1I;F<G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?9&5F96YC;V1I
M;F<G72`]("=55$8M."<["@HO*BH*("H@57-E<B!E<G)O<B!C;V1E<R!S=&%R
M="!A="`X,#`*("H@0&=L;V)A;"!I;G0@)$=,3T)!3%-;)UA-3%]24$-?97)R
M=7-E<B=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]E<G)U<V5R)UT@/2`X,#`[
M"@HO*BH*("H@6$U,('!A<G-E(&5R<F]R(&-O9&5S('-T87)T(&%T(#$P,`H@
M*B!`9VQO8F%L(&EN="`D1TQ/0D%,4ULG6$U,7U)00U]E<G)X;6PG70H@*B\*
M)$=,3T)!3%-;)UA-3%]24$-?97)R>&UL)UT@/2`Q,#`["@H*+RHJ"B`J($-O
M;7!O<V4@8F%C:W-L87-H97,@9F]R(&5S8V%P:6YG(')E9V5X<`H@*B!`9VQO
M8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]B86-K<VQA<V@G70H@*B\*
M)$=,3T)!3%-;)UA-3%]24$-?8F%C:W-L87-H)UT@/2!C:'(H.3(I("X@8VAR
M*#DR*3L*"@HO*BH*("H@5F%L:60@<&%R96YT<R!O9B!834P@96QE;65N=',*
M("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG6$U,7U)00U]V86QI9%]P87)E
M;G1S)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7W9A;&ED7W!A<F5N=',G72`]
M(&%R<F%Y*`H@("`@)T)/3TQ%04XG(#T^(&%R<F%Y*"=604Q512<I+`H@("`@
M)TDT)R`]/B!A<G)A>2@G5D%,544G*2P*("`@("=)3E0G(#T^(&%R<F%Y*"=6
M04Q512<I+`H@("`@)U-44DE.1R<@/3X@87)R87DH)U9!3%5%)RDL"B`@("`G
M1$]50DQ%)R`]/B!A<G)A>2@G5D%,544G*2P*("`@("=$051%5$E-12Y)4T\X
M-C`Q)R`]/B!A<G)A>2@G5D%,544G*2P*("`@("="05-%-C0G(#T^(&%R<F%Y
M*"=604Q512<I+`H@("`@)T%24D%9)R`]/B!A<G)A>2@G5D%,544G*2P*("`@
M("=35%)50U0G(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)U!!4D%-)R`]/B!A
M<G)A>2@G4$%204U3)RDL"B`@("`G34542$]$3D%-12<@/3X@87)R87DH)TU%
M5$A/1$-!3$PG*2P*("`@("=005)!35,G(#T^(&%R<F%Y*"=-151(3T1#04Q,
M)RP@)TU%5$A/1%)%4U!/3E-%)RDL"B`@("`G345-0D52)R`]/B!A<G)A>2@G
M4U1254-4)RDL"B`@("`G3D%-12<@/3X@87)R87DH)TU%34)%4B<I+`H@("`@
M)T1!5$$G(#T^(&%R<F%Y*"=!4E)!62<I+`H@("`@)T9!54Q4)R`]/B!A<G)A
M>2@G34542$]$4D534$].4T4G*2P*("`@("=604Q512<@/3X@87)R87DH)TU%
M34)%4B<L("=$051!)RP@)U!!4D%-)RP@)T9!54Q4)RDL"BD["@H*+RHJ"B`J
M(%-T;W)E<R!S=&%T92!D=7)I;F<@<&%R<VEN9PH@*@H@*B!Q=6EC:R!E>'!L
M86YA=&EO;B!O9B!C;VUP;VYE;G1S.@H@*B`@("L@86,@("`@(#T@86-C=6UU
M;&%T97,@=F%L=65S"B`J("`@*R!Q="`@("`@/2!D96-I9&5S(&EF('%U;W1E
M<R!A<F4@;F5E9&5D(&9O<B!E=F%L=6%T:6]N"B`J("`@*R!C;2`@("`@/2!D
M96YO=&5S('-T<G5C="!O<B!A<G)A>2`H8V]M;6$@;F5E9&5D*0H@*B`@("L@
M:7-F("`@(#T@:6YD:6-A=&5S(&$@9F%U;'0*("H@("`K(&QV("`@("`](&EN
M9&EC871E<R`B;&]O:VEN9R!F;W(@82!V86QU92(Z(&EM<&QE;65N=',@=&AE
M(&QO9VEC"B`J("`@("`@("`@("`@("`@=&\@86QL;W<@=F%L=65S('=I=&@@
M;F\@='EP97,@=&\@8F4@<W1R:6YG<PH@*B`@("L@<&%R86US(#T@<W1O<F5S
M('!A<F%M971E<G,@:6X@;65T:&]D(&-A;&QS"B`J("`@*R!M971H;V0@/2!S
M=&]R97,@;65T:&]D(&YA;64*("H*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,
M4ULG6$U,7U)00U]X:"=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]X:"==(#T@
M87)R87DH*3L*"@HO*BH*("H@4W1A<G0@96QE;65N="!H86YD;&5R(&9O<B!T
M:&4@6$U,('!A<G-E<@H@*@H@*B!`<F5T=7)N('9O:60*("HO"F9U;F-T:6]N
M(%A-3%]24$-?<V4H)'!A<G-E<E]R97-O=7)C92P@)&YA;64L("1A='1R<RD*
M>PH@("`@9VQO8F%L("1834Q?4E!#7WAH+"`D6$U,7U)00U]V86QI9%]P87)E
M;G1S.PH*("`@("1P87)S97(@/2`H:6YT*2`D<&%R<V5R7W)E<V]U<F-E.PH*
M("`@("\O(&EF(&EN=F%L:60@>&UL<G!C(&%L<F5A9'D@9&5T96-T960L('-K
M:7`@86QL('!R;V-E<W-I;F<*("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R
M75LG:7-F)UT@/CT@,BD@>PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("`O
M+R!C:&5C:R!F;W(@8V]R<F5C="!E;&5M96YT(&YE<W1I;F<*("`@("\O('1O
M<"!L979E;"!E;&5M96YT(&-A;B!O;FQY(&)E(&]F(#(@='EP97,*("`@(&EF
M("AC;W5N="@D6$U,7U)00U]X:%LD<&%R<V5R75LG<W1A8VLG72D@/3T@,"D@
M>PH@("`@("`@(&EF("@D;F%M92`A/2`G34542$]$4D534$].4T4G("8F("1N
M86UE("$]("=-151(3T1#04Q,)RD@>PH@("`@("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG:7-F)UT@/2`R.PH@("`@("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG:7-F7W)E87-O;B==(#T@)VUI<W-I;F<@=&]P(&QE=F5L
M('AM;')P8R!E;&5M96YT)SL*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@+R\@;F]T('1O<"!L979E;"!E;&5M
M96YT.B!S964@:68@<&%R96YT(&ES($]+"B`@("`@("`@:68@*"%I;E]A<G)A
M>2@D6$U,7U)00U]X:%LD<&%R<V5R75LG<W1A8VLG75LP72P@)%A-3%]24$-?
M=F%L:61?<&%R96YT<ULD;F%M95TI*2!["B`@("`@("`@("`@("1N86UE(#T@
M<')E9U]R97!L86-E*"=;7F$M>D$M6C`M.2Y?+5TG+"`G)RP@)&YA;64I.PH@
M("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F)UT@/2`R.PH@
M("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F7W)E87-O;B==
M(#T@(GAM;')P8R!E;&5M96YT("1N86UE(&-A;FYO="!B92!C:&EL9"!O9B![
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T86-K)UU;,%U](CL*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!S=VET8V@@*"1N86UE
M*2!["B`@("!C87-E("=35%)50U0G.@H@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=C;2==*RL["@H@("`@("`@("\O('1U<FX@<75O=&EN9R!O9F8*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`](#`["@H@("`@
M("`@("1C=7)?=F%L(#T@87)R87DH*3L*("`@("`@("`D8W5R7W9A;%LG=F%L
M=64G72`](&%R<F%Y*"D["B`@("`@("`@)&-U<E]V86Q;)VUE;6)E<G,G72`]
M(#$["B`@("`@("`@87)R87E?=6YS:&EF="@D6$U,7U)00U]X:%LD<&%R<V5R
M75LG=F%L=65S=&%C:R==+"`D8W5R7W9A;"D["B`@("`@("`@8G)E86L["@H@
M("`@8V%S92`G05)205DG.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=
M6R=C;2==*RL["@H@("`@("`@("\O('1U<FX@<75O=&EN9R!O9F8*("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`](#`["@H@("`@("`@("1C
M=7)?=F%L(#T@87)R87DH*3L*("`@("`@("`D8W5R7W9A;%LG=F%L=64G72`]
M(&%R<F%Y*"D["B`@("`@("`@)&-U<E]V86Q;)VUE;6)E<G,G72`](#`["B`@
M("`@("`@87)R87E?=6YS:&EF="@D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L
M=65S=&%C:R==+"`D8W5R7W9A;"D["B`@("`@("`@8G)E86L["@H@("`@8V%S
M92`G3D%-12<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@
M/2`G)SL*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=&055,5"<Z"B`@("`@
M("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9B==(#T@,3L*("`@("`@("!B
M<F5A:SL*"B`@("!C87-E("=005)!32<Z"B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W9A;'5E<W1A8VLG72`](&%R<F%Y*"D["B`@("`@("`@8G)E
M86L["@H@("`@8V%S92`G5D%,544G.@H@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=L=B==(#T@,3L*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG=G0G72`]("1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R==.PH@("`@("`@
M("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<["B`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH@("`@("`@("\O(&QO;VL@
M9F]R(&$@=F%L=64Z(&EF('1H:7,@:7,@<W1I;&P@,2!B>2!T:&4*("`@("`@
M("`O+R!T:6UE('=E(')E86-H('1H92!F:7)S="!D871A('-E9VUE;G0@=&AE
M;B!T:&4@='EP92!I<R!S=')I;F<*("`@("`@("`O+R!B>2!I;7!L:6-A=&EO
M;B!A;F0@=V4@;F5E9"!T;R!A9&0@:6X@82!Q=6]T90H@("`@("`@(&)R96%K
M.PH*("`@(&-A<V4@)TDT)SH*("`@(&-A<V4@)TE.5"<Z"B`@("!C87-E("=3
M5%))3D<G.@H@("`@8V%S92`G0D]/3$5!3B<Z"B`@("!C87-E("=$3U5"3$4G
M.@H@("`@8V%S92`G1$%4151)344N25-/.#8P,2<Z"B`@("!C87-E("="05-%
M-C0G.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<[
M("\O(')E<V5T('1H92!A8V-U;75L871O<@H*("`@("`@("!I9B`H)&YA;64@
M/3T@)T1!5$5424U%+DE33S@V,#$G('Q\("1N86UE(#T]("=35%))3D<G*2![
M"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,3L*
M"B`@("`@("`@("`@(&EF("@D;F%M92`]/2`G1$%4151)344N25-/.#8P,2<I
M('L*("`@("`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V="==
M(#T@)$=,3T)!3%-;)UA-3%]24$-?1&%T951I;64G73L*("`@("`@("`@("`@
M?0H*("`@("`@("!](&5L<V5I9B`H)&YA;64@/3T@)T)!4T4V-"<I('L*("`@
M("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`R.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\O($YO('%U;W1I;F<@:7,@<F5Q
M=6ER960@:&5R92`M+2!B=70*("`@("`@("`@("`@+R\@870@=&AE(&5N9"!O
M9B!T:&4@96QE;65N="!W92!M=7-T(&-H96-K"B`@("`@("`@("`@("\O(&9O
M<B!D871A(&9O<FUA="!E<G)O<G,N"B`@("`@("`@("`@("1834Q?4E!#7WAH
M6R1P87)S97)=6R=Q="==(#T@,#L*("`@("`@("!]"B`@("`@("`@8G)E86L[
M"@H@("`@8V%S92`G345-0D52)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG86,G72`]("<G.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)T1!
M5$$G.@H@("`@8V%S92`G34542$]$0T%,3"<Z"B`@("!C87-E("=-151(3T1.
M04U%)SH*("`@(&-A<V4@)TU%5$A/1%)%4U!/3E-%)SH*("`@(&-A<V4@)U!!
M4D%-4R<Z"B`@("`@("`@+R\@=F%L:60@96QE;65N=',@=&AA="!A9&0@;&ET
M=&QE('1O('!R;V-E<W-I;F<*("`@("`@("!B<F5A:SL*("`@('T*"@H@("`@
M+R\@4V%V92!C=7)R96YT(&5L96UE;G0@=&\@<W1A8VL*("`@(&%R<F%Y7W5N
M<VAI9G0H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T86-K)UTL("1N86UE*3L*
M"B`@("!I9B`H)&YA;64@(3T@)U9!3%5%)RD@>PH@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=L=B==(#T@,#L*("`@('T*?0H*+RHJ"B`J($5N9"!E
M;&5M96YT(&AA;F1L97(@9F]R('1H92!834P@<&%R<V5R"B`J"B`J($!R971U
M<FX@=F]I9`H@*B\*9G5N8W1I;VX@6$U,7U)00U]E92@D<&%R<V5R7W)E<V]U
M<F-E+"`D;F%M92D*>PH@("`@9VQO8F%L("1834Q?4E!#7WAH.PH*("`@("1P
M87)S97(@/2`H:6YT*2`D<&%R<V5R7W)E<V]U<F-E.PH*("`@(&EF("@D6$U,
M7U)00U]X:%LD<&%R<V5R75LG:7-F)UT@/CT@,BD@>PH@("`@("`@(')E='5R
M;CL*("`@('T*"B`@("`O+R!P=7-H('1H:7,@96QE;65N="!F<F]M('-T86-K
M"B`@("`O+R!.0CH@:68@6$U,('9A;&ED871E<RP@8V]R<F5C="!O<&5N:6YG
M+V-L;W-I;F<@:7,@9W5A<F%N=&5E9"!A;F0*("`@("\O('=E(&1O(&YO="!H
M879E('1O(&-H96-K(&9O<B`D;F%M92`]/2`D8W5R<E]E;&5M+@H@("`@+R\@
M=V4@86QS;R!C:&5C:V5D(&9O<B!P<F]P97(@;F5S=&EN9R!A="!S=&%R="!O
M9B!E;&5M96YT<RXN+@H@("`@)&-U<G)?96QE;2`](&%R<F%Y7W-H:69T*"18
M34Q?4E!#7WAH6R1P87)S97)=6R=S=&%C:R==*3L*"B`@("!S=VET8V@@*"1N
M86UE*2!["B`@("!C87-E("=35%)50U0G.@H@("`@8V%S92`G05)205DG.@H@
M("`@)&-U<E]V86P@/2!A<G)A>5]S:&EF="@D6$U,7U)00U]X:%LD<&%R<V5R
M75LG=F%L=65S=&%C:R==*3L*("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V
M86QU92==(#T@)&-U<E]V86Q;)W9A;'5E)UT["B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W9T)UT@/2!S=')T;VQO=V5R*"1N86UE*3L*("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG8VTG72TM.PH@("`@("`@(&)R96%K
M.PH*("`@(&-A<V4@)TY!344G.@H@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)W9A;'5E<W1A8VLG75LP75LG;F%M92==(#T@)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)V%C)UT["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G0D]/3$5!3B<Z
M"B`@("`@("`@+R\@<W!E8VEA;"!C87-E(&AE<F4Z('=E('1R86YS;&%T92!B
M;V]L96%N(#$@;W(@,"!I;G1O(%!(4`H@("`@("`@("\O(&-O;G-T86YT<R!T
M<G5E(&]R(&9A;'-E"B`@("`@("`@:68@*"1834Q?4E!#7WAH6R1P87)S97)=
M6R=A8R==(#T]("<Q)RD@>PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG86,G72`]("=T<G5E)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("=F86QS92<["B`@
M("`@("`@?0H*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=G0G72`]
M('-T<G1O;&]W97(H)&YA;64I.PH@("`@("`@("\O($1R;W`@=&AR;W5G:"!I
M;G1E;G1I;VYA;&QY+@H*("`@(&-A<V4@)TDT)SH*("`@(&-A<V4@)TE.5"<Z
M"B`@("!C87-E("=35%))3D<G.@H@("`@8V%S92`G1$]50DQ%)SH*("`@(&-A
M<V4@)T1!5$5424U%+DE33S@V,#$G.@H@("`@8V%S92`G0D%3138T)SH*("`@
M("`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/3T@,2D@>PH@
M("`@("`@("`@("`O+R!W92!U<V4@9&]U8FQE('%U;W1E<R!R871H97(@=&AA
M;B!S:6YG;&4@<V\@8F%C:W-L87-H:69I8V%T:6]N('=O<FMS($]+"B`@("`@
M("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==(#T@)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)V%C)UT["B`@("`@("`@?2!E;'-E:68@*"1834Q?
M4E!#7WAH6R1P87)S97)=6R=Q="==(#T](#(I('L*("`@("`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT@/2!B87-E-C1?9&5C;V1E*"18
M34Q?4E!#7WAH6R1P87)S97)=6R=A8R==*3L*("`@("`@("!](&5L<V5I9B`H
M)&YA;64@/3T@)T)/3TQ%04XG*2!["B`@("`@("`@("`@("1834Q?4E!#7WAH
M6R1P87)S97)=6R=V86QU92==(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C
M)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@=V4@:&%V92!A
M;B!)-"P@24Y4(&]R(&$@1$]50DQ%"B`@("`@("`@("`@("\O('=E(&UU<W0@
M8VAE8VL@=&AA="!O;FQY(#`Q,C,T-38W.#DM+CQS<&%C93X@87)E(&-H87)A
M8W1E<G,@:&5R90H@("`@("`@("`@("!I9B`H(65R96<H(EY;*RU=/ULP,3(S
M-#4V-S@Y(%QT7"Y=*R0B+"`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72DI
M('L*("`@("`@("`@("`@("`@(%A-3%]24$-?0F%S93HZ<F%I<V5%<G)O<B@G
M3F]N+6YU;65R:6,@=F%L=64@<F5C96EV960@:6X@24Y4(&]R($1/54),12<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U)00U]%4E)/4E].3TY?3E5-15))0U]&3U5.1"D["B`@("`@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`](%A-3%]24$-?15)2
M3U)?3D].7TY5345224-?1D]53D0["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`O+R!I="=S(&]K+"!A9&0@:70@;VX*("`@("`@("`@
M("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==(#T@)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)V%C)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<["B`@
M("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH@("`@("`@
M("1834Q?4E!#7WAH6R1P87)S97)=6R=L=B==(#T@,SL@+R\@:6YD:6-A=&4@
M=V4G=F4@9F]U;F0@82!V86QU90H@("`@("`@(&)R96%K.PH*("`@(&-A<V4@
M)U9!3%5%)SH*("`@("`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T
M)UT@/3T@)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG)UTI('L*("`@("`@("`@
M("`@:68@*'-T<FQE;B@D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72D@/B`P
M*2!["B`@("`@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L
M=64G72`]("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==.PH@("`@("`@("`@
M("!](&5L<V5I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)VQV)UT@/3T@,2D@
M>PH@("`@("`@("`@("`@("`@+R\@5&AE(#QV86QU93X@96QE;65N="!W87,@
M96UP='DN"B`@("`@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG
M=F%L=64G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D=&5M<"`](&YE=R!834Q?4E!#7U9A;'5E*"1834Q?4E!#7WAH6R1P87)S
M97)=6R=V86QU92==+"`D6$U,7U)00U]X:%LD<&%R<V5R75LG=G0G72D["@H@
M("`@("`@("1C=7)?=F%L(#T@87)R87E?<VAI9G0H)%A-3%]24$-?>&A;)'!A
M<G-E<EU;)W9A;'5E<W1A8VLG72D["B`@("`@("`@:68@*&ES7V%R<F%Y*"1C
M=7)?=F%L*2D@>PH@("`@("`@("`@("!I9B`H)&-U<E]V86Q;)VUE;6)E<G,G
M73T],"D@>PH@("`@("`@("`@("`@("`@)&-U<E]V86Q;)W9A;'5E)UU;72`]
M("1T96UP.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT@/2`D=&5M<#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1834Q?4E!#7WAH
M6R1P87)S97)=6R=V86QU97-T86-K)UTL("1C=7)?=F%L*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L
M=64G72`]("1T96UP.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*"B`@("!C
M87-E("=-14U"15(G.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A
M8R==(#T@)R<["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@
M/2`P.PH*("`@("`@("`D8W5R7W9A;"`](&%R<F%Y7W-H:69T*"1834Q?4E!#
M7WAH6R1P87)S97)=6R=V86QU97-T86-K)UTI.PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D8W5R7W9A;"DI('L*("`@("`@("`@("`@:68@*"1C=7)?=F%L6R=M
M96UB97)S)UT]/3$I('L*("`@("`@("`@("`@("`@("1C=7)?=F%L6R=V86QU
M92==6R1C=7)?=F%L6R=N86UE)UU=(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)W9A;'5E)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@87)R87E?=6YS
M:&EF="@D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=65S=&%C:R==+"`D8W5R
M7W9A;"D["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)T1!
M5$$G.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<[
M"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH@("`@
M("`@(&)R96%K.PH*("`@(&-A<V4@)U!!4D%-)SH*("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG<&%R86US)UU;72`]("1834Q?4E!#7WAH6R1P87)S
M97)=6R=V86QU92==.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)TU%5$A/
M1$Y!344G.@H@("`@8V%S92`G4E!#34542$]$3D%-12<Z"B`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)VUE=&AO9"==(#T@97)E9U]R97!L86-E*")>
M6UQN7')<="!=*R(L("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG86,G72D["B`@("`@("`@8G)E86L["B`@("!]"@H@("`@+R\@:68@:70G
M<R!A('9A;&ED('1Y<&4@;F%M92P@<V5T('1H92!T>7!E"B`@("!I9B`H:7-S
M970H)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G75MS=')T;VQO=V5R*"1N86UE
M*5TI*2!["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T)UT@/2!S
M=')T;VQO=V5R*"1N86UE*3L*("`@('T*?0H*+RHJ"B`J($-H87)A8W1E<B!D
M871A(&AA;F1L97(@9F]R('1H92!834P@<&%R<V5R"B`J"B`J($!R971U<FX@
M=F]I9`H@*B\*9G5N8W1I;VX@6$U,7U)00U]C9"@D<&%R<V5R7W)E<V]U<F-E
M+"`D9&%T82D*>PH@("`@9VQO8F%L("1834Q?4E!#7WAH+"`D6$U,7U)00U]B
M86-K<VQA<V@["@H@("`@)'!A<G-E<B`]("AI;G0I("1P87)S97)?<F5S;W5R
M8V4["@H@("`@:68@*"1834Q?4E!#7WAH6R1P87)S97)=6R=L=B==("$](#,I
M('L*("`@("`@("`O+R`B;&]O:V9O<G9A;'5E/3TS(B!M96%N<R!T:&%T('=E
M)W9E(&9O=6YD(&%N(&5N=&ER92!V86QU90H@("`@("`@("\O(&%N9"!S:&]U
M;&0@9&ES8V%R9"!A;GD@9G5R=&AE<B!C:&%R86-T97(@9&%T80H*("`@("`@
M("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)VQV)UT@/3T@,2D@>PH@("`@
M("`@("`@("`O+R!I9B!W92=V92!F;W5N9"!T97AT(&%N9"!W92=R92!J=7-T
M(&EN(&$@/'9A;'5E/B!T:&5N"B`@("`@("`@("`@("\O('1U<FX@<75O=&EN
M9R!O;BP@87,@=&AI<R!W:6QL(&)E(&$@<W1R:6YG"B`@("`@("`@("`@("18
M34Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,3L*("`@("`@("`@("`@+R\@
M86YD('-A>2!W92=V92!F;W5N9"!A('9A;'5E"B`@("`@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=L=B==(#T@,CL*("`@("`@("!]"@H@("`@("`@
M("\O(')E<&QA8V4@8VAA<F%C=&5R<R!T:&%T(&5V86P@=V]U;&0*("`@("`@
M("`O+R!D;R!S<&5C:6%L('1H:6YG<R!W:71H"B`@("`@("`@:68@*"%I<W-E
M="@D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72DI('L*("`@("`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G)SL*("`@("`@("!]"B`@
M("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@+CT@)&1A=&$["B`@
M("!]"GT*"B\J*@H@*B!4:&4@8V]M;6]N(&UE=&AO9',@86YD('!R;W!E<G1I
M97,@9F]R(&%L;"!O9B!T:&4@6$U,7U)00R!C;&%S<V5S"B`J"B`J($!C871E
M9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J
M($!A=71H;W(@("`@($5D9"!$=6UB:6QL(#QE9&1`=7-E9G5L:6YC+F-O;3X*
M("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-T:6=`<&AP+FYE=#X*("H@
M0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X*("H@0&%U
M=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@
M*B!`8V]P>7)I9VAT("`Q.3DY+3(P,#$@161D($1U;6)I;&PL(#(P,#$M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XX
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]8
M34Q?4E!#"B`J+PIC;&%S<R!834Q?4E!#7T)A<V4@>PH*("`@("\J*@H@("`@
M("H@4$5!4B!%<G)O<B!H86YD;&EN9PH@("`@("H*("`@("`J($!R971U<FX@
M;V)J96-T("!014%27T5R<F]R(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO
M;B!R86ES945R<F]R*"1M<V<L("1C;V1E*0H@("`@>PH@("`@("`@(&EN8VQU
M9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@(&EF("AI<U]O8FIE8W0H0"1T
M:&ES*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAG
M971?8VQA<W,H)'1H:7,I("X@)SH@)R`N("1M<V<L("1C;V1E*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G6$U,7U)00SH@)R`N("1M<V<L("1C;V1E*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!496QL('=H971H97(@<V]M971H:6YG(&ES(&$@
M4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)'9A;'5E("!T:&4@:71E;2!T;R!C:&5C:PH@("`@("H*("`@("`J($!R971U
M<FX@8F]O;"`@=VAE=&AE<B`D=F%L=64@:7,@82!014%27T5R<F]R(&]B:F5C
M="!O<B!N;W0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!I<T5R<F]R*"1V86QU92D*("`@('L*("`@("`@("!R
M971U<FX@:7-?82@D=F%L=64L("=014%27T5R<F]R)RD["B`@("!]"GT*"B\J
M*@H@*B!4:&4@;65T:&]D<R!A;F0@<')O<&5R=&EE<R!F;W(@<W5B;6ET=&EN
M9R!834P@4E!#(')E<75E<W1S"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V
M:6-E<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D
M9"!$=6UB:6QL(#QE9&1`=7-E9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@
M4W1I9R!"86MK96X@/'-T:6=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R
M=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DY+3(P,#$@161D($1U;6)I;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S
M<R!834Q?4E!#7T-L:65N="!E>'1E;F1S(%A-3%]24$-?0F%S92!["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<&%T:"!A;F0@;F%M92!O9B!T:&4@4E!#('-E<G9E
M<B!S8W)I<'0@>6]U('=A;G0@=&AE(')E<75E<W0@=&\@9V\@=&\*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&%T:"`]("<G.PH*("`@
M("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE(')E;6]T92!S97)V97(@=&\@
M8V]N;F5C="!T;PH@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1S97)V97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!P<F]T;V-O;"!T
M;R!U<V4@:6X@8V]N=&%C=&EN9R!T:&4@<F5M;W1E('-E<G9E<@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P<F]T;V-O;"`]("=H='1P
M.B\O)SL*"B`@("`O*BH*("`@("`J(%1H92!P;W)T(&9O<B!C;VYN96-T:6YG
M('1O('1H92!R96UO=&4@<V5R=F5R"B`@("`@*@H@("`@("H@5&AE(&1E9F%U
M;'0@:7,@.#`@9F]R(&AT='`Z+R\@8V]N;F5C=&EO;G,*("`@("`J(&%N9"`T
M-#,@9F]R(&AT='!S.B\O(&%N9"!S<VPZ+R\@8V]N;F5C=&EO;G,N"B`@("`@
M*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D<&]R="`]
M(#@P.PH*("`@("\J*@H@("`@("H@02!U<V5R(&YA;64@9F]R(&%C8V5S<VEN
M9R!T:&4@4E!#('-E<G9E<@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!S
M964@6$U,7U)00U]#;&EE;G0Z.G-E=$-R961E;G1I86QS*"D*("`@("`J+PH@
M("`@=F%R("1U<V5R;F%M92`]("<G.PH*("`@("\J*@H@("`@("H@02!P87-S
M=V]R9"!F;W(@86-C97-S:6YG('1H92!24$,@<V5R=F5R"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("H@0'-E92!834Q?4E!#7T-L:65N=#HZ<V5T0W)E9&5N
M=&EA;',H*0H@("`@("HO"B`@("!V87(@)'!A<W-W;W)D(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@<')O>'D@<V5R=F5R('1O('5S
M92P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)'!R;WAY(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@<')O=&]C;VP@=&\@
M=7-E(&EN(&-O;G1A8W1I;F<@=&AE('!R;WAY('-E<G9E<BP@:68@86YY"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!R;WAY7W!R;W1O
M8V]L(#T@)VAT='`Z+R\G.PH*("`@("\J*@H@("`@("H@5&AE('!O<G0@9F]R
M(&-O;FYE8W1I;F<@=&\@=&AE('!R;WAY('-E<G9E<@H@("`@("H*("`@("`J
M(%1H92!D969A=6QT(&ES(#@P.#`@9F]R(&AT='`Z+R\@8V]N;F5C=&EO;G,*
M("`@("`J(&%N9"`T-#,@9F]R(&AT='!S.B\O(&%N9"!S<VPZ+R\@8V]N;F5C
M=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@
M('9A<B`D<')O>'E?<&]R="`](#@P.#`["@H@("`@+RHJ"B`@("`@*B!!('5S
M97(@;F%M92!F;W(@86-C97-S:6YG('1H92!P<F]X>2!S97)V97(*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<')O>'E?=7-E<B`]("<G
M.PH*("`@("\J*@H@("`@("H@02!P87-S=V]R9"!F;W(@86-C97-S:6YG('1H
M92!P<F]X>2!S97)V97(*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D<')O>'E?<&%S<R`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&5R
M<F]R(&YU;6)E<BP@:68@86YY"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M+PH@("`@=F%R("1E<G)N;R`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@97)R
M;W(@;65S<V%G92P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)&5R<G-T<B`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&-U
M<G)E;G0@9&5B=6<@;6]D92`H,2`](&]N+"`P(#T@;V9F*0H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D9&5B=6<@/2`P.PH*("`@("\J
M*@H@("`@("H@5&AE($A45%`@:&5A9&5R<R!F;W(@=&AE(&-U<G)E;G0@<F5Q
M=65S="X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:&5A
M9&5R<R`]("<G.PH*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&]B:F5C="=S
M('!R;W!E<G1I97,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%T
M:"`@("`@("`@=&AE('!A=&@@86YD(&YA;64@;V8@=&AE(%)00R!S97)V97(@
M<V-R:7!T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('EO
M=2!W86YT('1H92!R97%U97-T('1O(&=O('1O"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<V5R=F5R("`@("`@=&AE(%523"!O9B!T:&4@<F5M;W1E('-E<G9E
M<B!T;R!C;VYN96-T('1O+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!)9B!T:&ES('!A<F%M971E<B!D;V5S;B=T('-P96-I9GD@80H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P<F]T;V-O;"!A
M;F0@)'!O<G0@:7,@-#0S+"!S<VPZ+R\@:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87-S=6UE9"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1P;W)T("`@("`@("!A('!O<G0@9F]R(&-O;FYE8W1I;F<@=&\@=&AE
M(')E;6]T92!S97)V97(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($1E9F%U;'1S('1O(#@P(&9O<B!H='1P.B\O(&-O;FYE8W1I;VYS
M(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`T-#,@
M9F]R(&AT='!S.B\O(&%N9"!S<VPZ+R\@8V]N;F5C=&EO;G,N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<')O>'D@("`@("`@=&AE(%523"!O9B!T:&4@<')O
M>'D@<V5R=F5R('1O('5S92P@:68@86YY+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!)9B!T:&ES('!A<F%M971E<B!D;V5S;B=T('-P
M96-I9GD@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P
M<F]T;V-O;"!A;F0@)'!O<G0@:7,@-#0S+"!S<VPZ+R\@:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87-S=6UE9"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1P<F]X>5]P;W)T("!A('!O<G0@9F]R(&-O;FYE8W1I
M;F<@=&\@=&AE(')E;6]T92!S97)V97(N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(#@P.#`@9F]R(&AT='`Z+R\@
M8V]N;F5C=&EO;G,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#0T,R!F;W(@:'1T<',Z+R\@86YD('-S;#HO+R!C;VYN96-T:6]N
M<RX*("`@("`J($!P87)A;2!S=')I;F<@("1P<F]X>5]U<V5R("!A('5S97(@
M;F%M92!F;W(@86-C97-S:6YG('1H92!P<F]X>2!S97)V97(*("`@("`J($!P
M87)A;2!S=')I;F<@("1P<F]X>5]P87-S("!A('!A<W-W;W)D(&9O<B!A8V-E
M<W-I;F<@=&AE('!R;WAY('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?4E!#7T-L:65N="@D<&%T
M:"P@)'-E<G9E<BP@)'!O<G0@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!R;WAY(#T@)R<L("1P<F]X>5]P;W)T(#T@,"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P<F]X>5]U<V5R(#T@)R<L("1P<F]X>5]P
M87-S(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/G!A=&@@("`@("`@/2`D
M<&%T:#L*("`@("`@("`D=&AI<RT^<')O>'E?=7-E<B`]("1P<F]X>5]U<V5R
M.PH@("`@("`@("1T:&ES+3YP<F]X>5]P87-S(#T@)'!R;WAY7W!A<W,["@H@
M("`@("`@('!R96=?;6%T8V@H)T!>*&AT='`Z+R]\:'1T<',Z+R]\<W-L.B\O
M*3\H+BHI)$`G+"`D<V5R=F5R+"`D;6%T8V@I.PH@("`@("`@(&EF("@D;6%T
M8VA;,5T@/3T@)R<I('L*("`@("`@("`@("`@:68@*"1P;W)T(#T](#0T,RD@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E<G9E<B`@(#T@)&UA=&-H6S)=
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G!R;W1O8V]L(#T@)W-S;#HO+R<[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]R="`@("`@/2`T-#,["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5R=F5R
M(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`@("`@:68@*"1P;W)T*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G!O<G0@/2`D<&]R=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D
M;6%T8VA;,5T@/3T@)VAT='`Z+R\G*2!["B`@("`@("`@("`@("1T:&ES+3YS
M97)V97(@/2`D;6%T8VA;,ET["B`@("`@("`@("`@(&EF("@D<&]R="D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G!O<G0@/2`D<&]R=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS97)V
M97(@("`]("1M871C:%LR73L*("`@("`@("`@("`@)'1H:7,M/G!R;W1O8V]L
M(#T@)W-S;#HO+R<["B`@("`@("`@("`@(&EF("@D<&]R="D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G!O<G0@/2`D<&]R=#L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YP;W)T(#T@-#0S.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'!R;WAY*2!["B`@
M("`@("`@("`@('!R96=?;6%T8V@H)T!>*&AT='`Z+R]\:'1T<',Z+R]\<W-L
M.B\O*3\H+BHI)$`G+"`D<')O>'DL("1M871C:"D["B`@("`@("`@("`@(&EF
M("@D;6%T8VA;,5T@/3T@)R<I('L*("`@("`@("`@("`@("`@(&EF("@D<')O
M>'E?<&]R="`]/2`T-#,I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<')O>'D@("`@("`@("`@/2`D;6%T8VA;,ET["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G!R;WAY7W!R;W1O8V]L(#T@)W-S;#HO+R<["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G!R;WAY7W!O<G0@("`@(#T@-#0S.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<')O>'D@/2`D;6%T8VA;,ET["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1P<F]X>5]P;W)T*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YP<F]X>5]P;W)T(#T@)'!R;WAY7W!O<G0["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H
M)&UA=&-H6S%=(#T]("=H='1P.B\O)RD@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G!R;WAY(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`@("`@:68@*"1P
M<F]X>5]P;W)T*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY
M7W!O<G0@/2`D<')O>'E?<&]R=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F]X>2`@
M("`@("`@("`]("1M871C:%LR73L*("`@("`@("`@("`@("`@("1T:&ES+3YP
M<F]X>5]P<F]T;V-O;"`]("=S<VPZ+R\G.PH@("`@("`@("`@("`@("`@:68@
M*"1P<F]X>5]P;W)T*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R
M;WAY7W!O<G0@/2`D<')O>'E?<&]R=#L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY7W!O<G0@/2`T
M-#,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE(&-U<G)E;G0@9&5B
M=6<@;6]D90H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&EN("!W:&5R92`Q
M(#T@;VXL(#`@/2!O9F8*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T1&5B=6<H)&EN*0H@("`@>PH@("`@("`@
M(&EF("@D:6XI('L*("`@("`@("`@("`@)'1H:7,M/F1E8G5G(#T@,3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&5B=6<@/2`P.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0@<')O<&5R=&EE<R!F;W(@8V]N;F5C=&EN9R!T;R!T:&4@
M4E!#('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'4@('1H
M92!U<V5R(&YA;64*("`@("`J($!P87)A;2!S=')I;F<@)'`@('1H92!P87-S
M=V]R9`H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J
M($!S964@6$U,7U)00U]#;&EE;G0Z.B1U<V5R;F%M92P@6$U,7U)00U]#;&EE
M;G0Z.B1P87-S=V]R9`H@("`@("HO"B`@("!F=6YC=&EO;B!S971#<F5D96YT
M:6%L<R@D=2P@)'`I"B`@("!["B`@("`@("`@)'1H:7,M/G5S97)N86UE(#T@
M)'4["B`@("`@("`@)'1H:7,M/G!A<W-W;W)D(#T@)'`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4<F%N<VUI="!T:&4@4E!#(')E<75E<W0@=FEA($A45%`@
M,2XP('!R;W1O8V]L"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D;7-G
M("`@("`@('1H92!834Q?4E!#7TUE<W-A9V4@;V)J96-T"B`@("`@*B!`<&%R
M86T@:6YT("`@("1T:6UE;W5T("`@:&]W(&UA;GD@<V5C;VYD<R!T;R!W86ET
M(&9O<B!T:&4@<F5Q=65S=`H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T
M("!A;B!834Q?4E!#7U)E<W!O;G-E(&]B:F5C="X@(#`@:7,@<F5T=7)N960@
M:68@86YY"B`@("`@*B`@("`@("`@("`@("`@("`@('!R;V)L96US(&AA<'!E
M;BX*("`@("`J"B`@("`@*B!`<V5E(%A-3%]24$-?365S<V%G92P@6$U,7U)0
M0U]#;&EE;G0Z.EA-3%]24$-?0VQI96YT*"DL"B`@("`@*B`@("`@(%A-3%]2
M4$-?0VQI96YT.CIS971#<F5D96YT:6%L<R@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E;F0H)&US9RP@)'1I;65O=70@/2`P*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?82@D;7-G+"`G6$U,7U)00U]-97-S86=E)RDI('L*("`@("`@("`@
M("`@)'1H:7,M/F5R<G-T<B`]("=S96YD*"E<)W,@)&US9R!P87)A;65T97(@
M;75S="!B92!A;B<*("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@6$U,
M7U)00U]-97-S86=E(&]B:F5C="XG.PH@("`@("`@("`@("`D=&AI<RT^<F%I
M<V5%<G)O<B@D=&AI<RT^97)R<W1R+"!834Q?4E!#7T524D]27U!23T=204U-
M24Y'*3L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@("`@
M("1M<V<M/F1E8G5G(#T@)'1H:7,M/F1E8G5G.PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<V5N9%!A>6QO861(5%10,3`H)&US9RP@)'1H:7,M/G-E<G9E<BP@
M)'1H:7,M/G!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&EM96]U="P@)'1H:7,M/G5S97)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!A<W-W;W)D
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1R86YS;6ET('1H92!24$,@<F5Q
M=65S="!V:6$@2%144"`Q+C`@<')O=&]C;VP*("`@("`J"B`@("`@*B!297%U
M97-T<R!S:&]U;&0@8F4@<V5N="!U<VEN9R!834Q?4E!#7T-L:65N="!S96YD
M*"D@<F%T:&5R('1H86X*("`@("`J(&-A;&QI;F<@=&AI<R!M971H;V0@9&ER
M96-T;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D;7-G("`@("`@
M('1H92!834Q?4E!#7TUE<W-A9V4@;V)J96-T"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97)V97(@("`@=&AE('-E<G9E<B!T;R!S96YD('1H92!R97%U97-T
M('1O"B`@("`@*B!`<&%R86T@:6YT("`@("1P;W)T("`@("`@=&AE('-E<G9E
M<B!P;W)T('-E;F0@=&AE(')E<75E<W0@=&\*("`@("`J($!P87)A;2!I;G0@
M("`@)'1I;65O=70@("!H;W<@;6%N>2!S96-O;F1S('1O('=A:70@9F]R('1H
M92!R97%U97-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&)E
M9F]R92!G:79I;F<@=7`*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE
M("!A('5S97(@;F%M92!F;W(@86-C97-S:6YG('1H92!24$,@<V5R=F5R"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@82!P87-S=V]R9"!F;W(@
M86-C97-S:6YG('1H92!24$,@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R
M;B!O8FIE8W0@(&%N(%A-3%]24$-?4F5S<&]N<V4@;V)J96-T+B`@,"!I<R!R
M971U<FYE9"!I9B!A;GD*("`@("`J("`@("`@("`@("`@("`@("`@<')O8FQE
M;7,@:&%P<&5N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*B!`<V5E(%A-3%]24$-?0VQI96YT.CIS96YD*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5N9%!A>6QO861(5%10,3`H)&US9RP@)'-E<G9E<BP@)'!O
M<G0L("1T:6UE;W5T(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1U<V5R;F%M92`]("<G+"`D<&%S<W=O<F0@/2`G)RD*("`@('L*("`@
M("`@("`O*@H@("`@("`@("`J($EF('=E)W)E('5S:6YG(&$@<')O>'D@;W!E
M;B!A('-O8VME="!T;R!T:&4@<')O>'D@<V5R=F5R"B`@("`@("`@("H@:6YS
M=&5A9"!T;R!T:&4@>&UL+7)P8R!S97)V97(*("`@("`@("`@*B\*("`@("`@
M("!I9B`H)'1H:7,M/G!R;WAY*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M<')O>'E?<')O=&]C;VP@/3T@)VAT='`Z+R\G*2!["B`@("`@("`@("`@("`@
M("`D<')O=&]C;VP@/2`G)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1P<F]T;V-O;"`]("1T:&ES+3YP<F]X>5]P<F]T;V-O;#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1I;65O=70@/B`P*2![
M"B`@("`@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1P<F]T;V-O;"`N
M("1T:&ES+3YP<F]X>2P@)'1H:7,M/G!R;WAY7W!O<G0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)N;RP@)'1H:7,M/F5R
M<G-T<BP@)'1I;65O=70I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D<')O=&]C;VP@+B`D=&AI<RT^
M<')O>'DL("1T:&ES+3YP<F]X>5]P;W)T+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^97)R;F\L("1T:&ES+3YE<G)S='(I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YP<F]T;V-O;"`]/2`G:'1T<#HO+R<I('L*("`@("`@("`@("`@
M("`@("1P<F]T;V-O;"`]("<G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'!R;W1O8V]L(#T@)'1H:7,M/G!R;W1O8V]L.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&EM96]U="`^(#`I('L*("`@
M("`@("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH)'!R;W1O8V]L("X@)'-E
M<G9E<BP@)'!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YE<G)N;RP@)'1H:7,M/F5R<G-T<BP@)'1I;65O=70I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9P(#T@0&9S;V-K
M;W!E;B@D<')O=&]C;VP@+B`D<V5R=F5R+"`D<&]R="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R
M<W1R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH*("`@
M("`@("`@*B!*=7-T(')A:7-I;F<@=&AE(&5R<F]R('=I=&AO=70@<F5T=7)N
M:6YG(&ET(&ES('-T<F%N9V4L"B`@("`@("`@("H@8G5T(&ME97`@:70@:&5R
M92!F;W(@8F%C:W=A<F1S(&-O;7!A=&EB:6QI='DN"B`@("`@("`@("HO"B`@
M("`@("`@:68@*"$D9G`@)B8@)'1H:7,M/G!R;WAY*2!["B`@("`@("`@("`@
M("1T:&ES+3YR86ES945R<F]R*"=#;VYN96-T:6]N('1O('!R;WAY('-E<G9E
M<B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/G!R
M;WAY("X@)SHG("X@)'1H:7,M/G!R;WAY7W!O<G0*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G(&9A:6QE9"X@)R`N("1T:&ES+3YE<G)S='(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?15)23U)?
M0T].3D5#5$E/3E]&04E,140I.PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!](&5L<V5I9B`H(21F<"D@>PH@("`@("`@("`@("`D=&AI<RT^<F%I
M<V5%<G)O<B@G0V]N;F5C=&EO;B!T;R!24$,@<V5R=F5R("<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B`D<V5R=F5R("X@)SHG("X@)'!O<G0*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&9A:6QE9"X@)R`N
M("1T:&ES+3YE<G)S='(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]24$-?15)23U)?0T].3D5#5$E/3E]&04E,140I.PH@("`@("`@("`@
M("!R971U<FX@,#L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&EM96]U="D@
M>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!5<VEN9R!S;V-K971?
M<V5T7W1I;65O=70H*2!B96-A=7-E('-T<F5A;5]S971?=&EM96]U="@I"B`@
M("`@("`@("`@("`J('=A<R!I;G1R;V1U8V5D(&EN(#0N,RXP+"!B=70@=V4@
M;F5E9"!T;R!S=7!P;W)T(#0N,BXP+@H@("`@("`@("`@("`@*B\*("`@("`@
M("`@("`@<V]C:V5T7W-E=%]T:6UE;W5T*"1F<"P@)'1I;65O=70I.PH@("`@
M("`@('T*"B`@("`@("`@+R\@4')E+65M<'1I=F4@0D,@:&%C:W,@9F]R(&9O
M;VQS(&-A;&QI;F<@<V5N9%!A>6QO861(5%10,3`H*2!D:7)E8W1L>0H@("`@
M("`@(&EF("@D=7-E<FYA;64@(3T@)'1H:7,M/G5S97)N86UE*2!["B`@("`@
M("`@("`@("1T:&ES+3YS971#<F5D96YT:6%L<R@D=7-E<FYA;64L("1P87-S
M=V]R9"D["B`@("`@("`@?0H*("`@("`@("`O+R!/;FQY(&-R96%T92!T:&4@
M<&%Y;&]A9"!I9B!I="!W87,@;F]T(&-R96%T960@<')E=FEO=7-L>0H@("`@
M("`@(&EF("AE;7!T>2@D;7-G+3YP87EL;V%D*2D@>PH@("`@("`@("`@("`D
M;7-G+3YC<F5A=&5087EL;V%D*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3YC<F5A=&5(96%D97)S*"1M<V<I.PH*("`@("`@("`D;W`@(#T@)'1H:7,M
M/FAE861E<G,@+B`B7')<;EQR7&XB.PH@("`@("`@("1O<"`N/2`D;7-G+3YP
M87EL;V%D.PH*("`@("`@("!I9B`H(69P=71S*"1F<"P@)&]P+"!S=')L96XH
M)&]P*2DI('L*("`@("`@("`@("`@)'1H:7,M/F5R<G-T<B`]("=7<FET92!E
M<G)O<B<["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@
M("`D<F5S<"`]("1M<V<M/G!A<G-E4F5S<&]N<V5&:6QE*"1F<"D["@H@("`@
M("`@("1M971A(#T@<V]C:V5T7V=E=%]S=&%T=7,H)&9P*3L*("`@("`@("!I
M9B`H)&UE=&%;)W1I;65D7V]U="==*2!["B`@("`@("`@("`@(&9C;&]S92@D
M9G`I.PH@("`@("`@("`@("`D=&AI<RT^97)R<W1R(#T@)U)00R!S97)V97(@
M9&ED(&YO="!S96YD(')E<W!O;G-E(&)E9F]R92!T:6UE;W5T+B<["B`@("`@
M("`@("`@("1T:&ES+3YR86ES945R<F]R*"1T:&ES+3YE<G)S='(L(%A-3%]2
M4$-?15)23U)?0T].3D5#5$E/3E]&04E,140I.PH@("`@("`@("`@("!R971U
M<FX@,#L*("`@("`@("!]"@H@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@
M(')E='5R;B`D<F5S<#L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@=&AE($A45%`@:&5A9&5R<R!A;F0@<'5T<R!I="!I;B!T:&4@)&AE861E
M<G,@<')O<&5R='D*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1M<V<@
M("`@("`@=&AE(%A-3%]24$-?365S<V%G92!O8FIE8W0*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%12544@:68@;VMA>2P@1D%,4T4@:68@=&AE
M(&UE<W-A9V4@<&%Y;&]A9"!I<VXG="!S970N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E2&5A
M9&5R<R@D;7-G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D;7-G+3YP87EL
M;V%D*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^<')O>'DI('L*("`@("`@("`@("`@)'1H:7,M
M/FAE861E<G,@/2`G4$]35"`G("X@)'1H:7,M/G!R;W1O8V]L("X@)'1H:7,M
M/G-E<G9E<CL*("`@("`@("`@("`@:68@*"1T:&ES+3YP<F]X>5]P;W)T*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<R`N/2`G.B<@+B`D=&AI
M<RT^<&]R=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@)'1H:7,M/FAE861E<G,@/2`G4$]35"`G.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^:&5A9&5R<R`N/2`D=&AI<RT^<&%T:"X@(B!(5%10+S$N
M,%QR7&XB.PH*("`@("`@("`D=&AI<RT^:&5A9&5R<R`N/2`B57-E<BU!9V5N
M=#H@4$5!4B!834Q?4E!#7')<;B(["B`@("`@("`@)'1H:7,M/FAE861E<G,@
M+CT@)TAO<W0Z("<@+B`D=&AI<RT^<V5R=F5R("X@(EQR7&XB.PH*("`@("`@
M("!I9B`H)'1H:7,M/G!R;WAY("8F("1T:&ES+3YP<F]X>5]U<V5R*2!["B`@
M("`@("`@("`@("1T:&ES+3YH96%D97)S("X]("=0<F]X>2U!=71H;W)I>F%T
M:6]N.B!"87-I8R`G"B`@("`@("`@("`@("`@("`@("`@("X@8F%S938T7V5N
M8V]D92@B)'1H:7,M/G!R;WAY7W5S97(Z)'1H:7,M/G!R;WAY7W!A<W,B*0H@
M("`@("`@("`@("`@("`@("`@("`N(")<<EQN(CL*("`@("`@("!]"@H@("`@
M("`@("\O('1H86YK<R!T;R!'<F%N="!2875S8VAE<B`\9W)A;G0W0&9I<G-T
M=V]R;&0N;F5T/B!F;W(@=&AI<PH@("`@("`@(&EF("@D=&AI<RT^=7-E<FYA
M;64I('L*("`@("`@("`@("`@)'1H:7,M/FAE861E<G,@+CT@)T%U=&AO<FEZ
M871I;VXZ($)A<VEC("<*("`@("`@("`@("`@("`@("`@("`@+B!B87-E-C1?
M96YC;V1E*"(D=&AI<RT^=7-E<FYA;64Z)'1H:7,M/G!A<W-W;W)D(BD*("`@
M("`@("`@("`@("`@("`@("`@+B`B7')<;B(["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^:&5A9&5R<R`N/2`B0V]N=&5N="U4>7!E.B!T97AT+WAM;%QR
M7&XB.PH@("`@("`@("1T:&ES+3YH96%D97)S("X]("=#;VYT96YT+4QE;F=T
M:#H@)R`N('-T<FQE;B@D;7-G+3YP87EL;V%D*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*?0H*+RHJ"B`J(%1H92!M971H;V1S(&%N9"!P<F]P97)T
M:65S(&9O<B!I;G1E<G!R971I;F<@<F5S<&]N<V5S('1O(%A-3"!24$,@<F5Q
M=65S=',*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K
M86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@161D($1U;6)I;&P@/&5D
M9$!U<V5F=6QI;F,N8V]M/@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\
M<W1I9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM
M:D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD
M86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3DM,C`P,2!%9&0@
M1'5M8FEL;"P@,C`P,2TR,#`U(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+C@*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO"F-L87-S(%A-3%]24$-?4F5S
M<&]N<V4@97AT96YD<R!834Q?4E!#7T)A<V4*>PH@("`@=F%R("1X=CL*("`@
M('9A<B`D9FX["B`@("!V87(@)&9S.PH@("`@=F%R("1H9')S.PH*("`@("\J
M*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-
M3%]24$-?4F5S<&]N<V4H)'9A;"P@)&9C;V1E(#T@,"P@)&9S='(@/2`G)RD*
M("`@('L*("`@("`@("!I9B`H)&9C;V1E("$](#`I('L*("`@("`@("`@("`@
M)'1H:7,M/F9N(#T@)&9C;V1E.PH@("`@("`@("`@("`D=&AI<RT^9G,@/2!H
M=&UL<W!E8VEA;&-H87)S*"1F<W1R*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^>'8@/2`D=F%L.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($!R971U<FX@:6YT("!T:&4@97)R;W(@8V]D90H@("`@
M("HO"B`@("!F=6YC=&EO;B!F875L=$-O9&4H*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^9FXI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^9FX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(#`[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!E<G)O<B!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@9F%U
M;'13=')I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9G,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T:&4@=F%L=64*
M("`@("`J+PH@("`@9G5N8W1I;VX@=F%L=64H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^>'8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&5R<F]R(&UE<W-A9V4@:6X@6$U,(&9O<FUA=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F4H*0H@("`@>PH@("`@("`@("1R
M<R`]("(\;65T:&]D4F5S<&]N<V4^7&XB.PH@("`@("`@(&EF("@D=&AI<RT^
M9FXI('L*("`@("`@("`@("`@)')S("X]("(\9F%U;'0^"B`@/'9A;'5E/@H@
M("`@/'-T<G5C=#X*("`@("`@/&UE;6)E<CX*("`@("`@("`\;F%M93YF875L
M=$-O9&4\+VYA;64^"B`@("`@("`@/'9A;'5E/CQI;G0^(B`N("1T:&ES+3YF
M;B`N("(\+VEN=#X\+W9A;'5E/@H@("`@("`\+VUE;6)E<CX*("`@("`@/&UE
M;6)E<CX*("`@("`@("`\;F%M93YF875L=%-T<FEN9SPO;F%M93X*("`@("`@
M("`\=F%L=64^/'-T<FEN9SXB("X@)'1H:7,M/F9S("X@(CPO<W1R:6YG/CPO
M=F%L=64^"B`@("`@(#PO;65M8F5R/@H@("`@/"]S=')U8W0^"B`@/"]V86QU
M93X*/"]F875L=#XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M<R`N/2`B/'!A<F%M<SY<;CQP87)A;3Y<;B(@+B`D=&AI<RT^>'8M/G-E<FEA
M;&EZ92@I("X*("`@("`@("`B/"]P87)A;3Y<;CPO<&%R86US/B(["B`@("`@
M("`@?0H@("`@("`@("1R<R`N/2`B7&X\+VUE=&AO9%)E<W!O;G-E/B(["B`@
M("`@("`@<F5T=7)N("1R<SL*("`@('T*?0H*+RHJ"B`J(%1H92!M971H;V1S
M(&%N9"!P<F]P97)T:65S(&9O<B!C;VUP;W-I;F<@6$U,(%)00R!M97-S86=E
M<PH@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@
M("`@6$U,7U)00PH@*B!`875T:&]R("`@("!%9&0@1'5M8FEL;"`\961D0'5S
M969U;&EN8RYC;VT^"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG
M0'!H<"YN970^"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H
M<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE
M;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY.2TR,#`Q($5D9"!$=6UB
M:6QL+"`R,#`Q+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O6$U,7U)00PH@*B\*8VQA<W,@6$U,7U)00U]-97-S86=E
M(&5X=&5N9',@6$U,7U)00U]"87-E"GL*("`@("\J*@H@("`@("H@5&AE(&-U
M<G)E;G0@9&5B=6<@;6]D92`H,2`](&]N+"`P(#T@;V9F*0H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D9&5B=6<@/2`P.PH*("`@("\J
M*@H@("`@("H@5&AE(&5N8V]D:6YG('1O(&)E('5S960@9F]R(&]U=&=O:6YG
M(&UE<W-A9V5S"B`@("`@*@H@("`@("H@1&5F875L=',@=&\@=&AE('9A;'5E
M(&]F(#QV87(^)$=,3T)!3%-;)UA-3%]24$-?9&5F96YC;V1I;F<G73PO=F%R
M/@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`<V5E(%A-3%]2
M4$-?365S<V%G93HZ<V5T4V5N9$5N8V]D:6YG*"DL"B`@("`@*B`@("`@("1'
M3$]"04Q36R=834Q?4E!#7V1E9F5N8V]D:6YG)UTL(%A-3%]24$-?365S<V%G
M93HZ>&UL7VAE861E<B@I"B`@("`@*B\*("`@('9A<B`D<V5N9%]E;F-O9&EN
M9R`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&UE=&AO9"!P<F5S96YT;'D@
M8F5I;F<@979A;'5A=&5D"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)&UE=&AO9&YA;64@/2`G)SL*"B`@("`O*BH*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1P87)A;7,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@5&AE(%A-3"!M97-S86=E(&)E:6YG(&=E;F5R871E9`H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P87EL;V%D(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@97AT<F$@;&EN92!B<F5A:W,@
M8F4@<F5M;W9E9"!F<F]M('1H92!P87EL;V%D/PH@("`@("H@0'-I;F-E(%!R
M;W!E<G1Y(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XV"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1R96UO=F5?97AT<F%?;&EN
M97,@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE(%A-3"!R97-P;VYS92!F
M<F]M('1H92!R96UO=&4@<V5R=F5R"B`@("`@*B!`<VEN8V4@4')O<&5R='D@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C8*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D<F5S<&]N<V5?<&%Y;&]A9"`]("<G.PH*
M"B`@("`O*BH*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!834Q?4E!#7TUE<W-A9V4H)&UE=&@L("1P87)S(#T@,"D*("`@('L*
M("`@("`@("`D=&AI<RT^;65T:&]D;F%M92`]("1M971H.PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D<&%R<RD@)B8@<VEZ96]F*"1P87)S*2`^(#`I('L*("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1P87)S*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9%!A<F%M*"1P87)S6R1I
M72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!0<F]D=6-E<R!T:&4@6$U,(&1E8VQA<F%T:6]N(&EN8VQU9&EN9R!T
M:&4@96YC;V1I;F<@871T<FEB=71E"B`@("`@*@H@("`@("H@5&AE(&5N8V]D
M:6YG(&ES(&1E=&5R;6EN960@8GD@=&AI<R!C;&%S<R<@/'9A<CXD<V5N9%]E
M;F-O9&EN9SPO=F%R/@H@("`@("H@<')O<&5R='DN("!)9B!T:&4@/'9A<CXD
M<V5N9%]E;F-O9&EN9SPO=F%R/B!P<F]P97)T>2!I<R!N;W0@<V5T+"!U<V4*
M("`@("`J(#QV87(^)$=,3T)!3%-;)UA-3%]24$-?9&5F96YC;V1I;F<G73PO
M=F%R/BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%A-3"!D
M96-L87)A=&EO;B!A;F0@/&UE=&AO9$-A;&P^(&5L96UE;G0*("`@("`J"B`@
M("`@*B!`<V5E(%A-3%]24$-?365S<V%G93HZ<V5T4V5N9$5N8V]D:6YG*"DL
M"B`@("`@*B`@("`@(%A-3%]24$-?365S<V%G93HZ)'-E;F1?96YC;V1I;F<L
M("1'3$]"04Q36R=834Q?4E!#7V1E9F5N8V]D:6YG)UT*("`@("`J+PH@("`@
M9G5N8W1I;VX@>&UL7VAE861E<B@I"B`@("!["B`@("`@("`@9VQO8F%L("18
M34Q?4E!#7V1E9F5N8V]D:6YG.PH*("`@("`@("!I9B`H(21T:&ES+3YS96YD
M7V5N8V]D:6YG*2!["B`@("`@("`@("`@("1T:&ES+3YS96YD7V5N8V]D:6YG
M(#T@)%A-3%]24$-?9&5F96YC;V1I;F<["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`G/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB)R`N("1T:&ES
M+3YS96YD7V5N8V]D:6YG("X@)R(_/B<*("`@("`@("`@("`@("`@+B`B7&X\
M;65T:&]D0V%L;#Y<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&-L;W-I;F<@/"]M971H;V1#86QL/B!T86<*("`@("`J
M+PH@("`@9G5N8W1I;VX@>&UL7V9O;W1E<B@I"B`@("!["B`@("`@("`@<F5T
M=7)N("(\+VUE=&AO9$-A;&P^7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEL;',@=&AE(%A-3%]24$-?365S<V%G93HZ)'!A>6QO860@<')O<&5R='D*
M("`@("`J"B`@("`@*B!087)T(&]F('1H92!P<F]C97-S(&UA:V5S('-U<F4@
M86QL(&QI;F4@96YD:6YG<R!A<F4@:6X@1$]3(&9O<FUA=`H@("`@("H@*$-2
M3$8I+"!W:&EC:"!I<R!P<F]B86)L>2!R97%U:7)E9"!B>2!S<&5C:69I8V%T
M:6]N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J"B`@("`@
M*B!`=7-E<R!834Q?4E!#7TUE<W-A9V4Z.GAM;%]H96%D97(H*2P@6$U,7U)0
M0U]-97-S86=E.CIX;6Q?9F]O=&5R*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M8W)E871E4&%Y;&]A9"@I"B`@("!["B`@("`@("`@)'1H:7,M/G!A>6QO860@
M/2`D=&AI<RT^>&UL7VAE861E<B@I.PH@("`@("`@("1T:&ES+3YP87EL;V%D
M("X]("<\;65T:&]D3F%M93XG("X@)'1H:7,M/FUE=&AO9&YA;64@+B`B/"]M
M971H;V1.86UE/EQN(CL*("`@("`@("`D=&AI<RT^<&%Y;&]A9"`N/2`B/'!A
M<F%M<SY<;B(["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T
M:&ES+3YP87)A;7,I.R`D:2LK*2!["B`@("`@("`@("`@("1P(#T@)'1H:7,M
M/G!A<F%M<ULD:5T["B`@("`@("`@("`@("1T:&ES+3YP87EL;V%D("X]("(\
M<&%R86T^7&XB("X@)'`M/G-E<FEA;&EZ92@I("X@(CPO<&%R86T^7&XB.PH@
M("`@("`@('T*("`@("`@("`D=&AI<RT^<&%Y;&]A9"`N/2`B/"]P87)A;7,^
M7&XB.PH@("`@("`@("1T:&ES+3YP87EL;V%D("X]("1T:&ES+3YX;6Q?9F]O
M=&5R*"D["B`@("`@("`@:68@*"1T:&ES+3YR96UO=F5?97AT<F%?;&EN97,I
M('L*("`@("`@("`@("`@)'1H:7,M/G!A>6QO860@/2!E<F5G7W)E<&QA8V4H
M(EM<<EQN72LB+"`B7')<;B(L("1T:&ES+3YP87EL;V%D*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<&%Y;&]A9"`](&5R96=?<F5P
M;&%C92@B7')<;GQ<;GQ<<GQ<;EQR(BP@(EQR7&XB+"`D=&AI<RT^<&%Y;&]A
M9"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!N86UE(&]F('1H92!M971H;V0*("`@("`J+PH@("`@9G5N
M8W1I;VX@;65T:&]D*"1M971H(#T@)R<I"B`@("!["B`@("`@("`@:68@*"1M
M971H("$]("<G*2!["B`@("`@("`@("`@("1T:&ES+3YM971H;V1N86UE(#T@
M)&UE=&@["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^;65T:&]D
M;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@<&%Y;&]A9`H@("`@("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F4H*0H@
M("`@>PH@("`@("`@("1T:&ES+3YC<F5A=&5087EL;V%D*"D["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YP87EL;V%D.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%!A<F%M*"1P
M87(I"B`@("!["B`@("`@("`@)'1H:7,M/G!A<F%M<UM=(#T@)'!A<CL*("`@
M('T*"B`@("`O*BH*("`@("`J($]B=&%I;G,@86X@6$U,7U)00U]686QU92!O
M8FIE8W0@9F]R('1H92!G:79E;B!P87)A;65T97(*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT("1I("!T:&4@:6YD97@@;G5M8F5R(&]F('1H92!P87)A;65T
M97(@=&\@;V)T86EN"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H
M92!834Q?4E!#7U9A;'5E(&]B:F5C="X*("`@("`J("`@("`@("`@("`@("`@
M("`@268@=&AE('!A<F%M971E<B!D;V5S;B=T(&5X:7-T+"!A;B!834Q?4E!#
M7U)E<W!O;G-E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<VEN8V4@4F5T=7)N
M<R!834Q?4E!#7U)E<W!O;G-E(&]B:F5C="!O;B!E<G)O<B!S:6YC92!296QE
M87-E(#$N,RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1I*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D6$U,7U)00U]E<G(L("1834Q?4E!#7W-T
M<CL*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP87)A;7-;)&E=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G!A<F%M<ULD:5T["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)U1H92!S
M=6)M:71T960@<F5Q=65S="!D:60@;F]T(&-O;G1A:6X@=&AI<R!P87)A;65T
M97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4E!#7T52
M4D]27TE.0T]24D5#5%]005)!35,I.PH@("`@("`@("`@("!R971U<FX@;F5W
M(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-3%]24$-?97)R6R=I;F-O<G)E8W1?
M<&%R86US)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D6$U,7U)00U]S=');)VEN8V]R<F5C=%]P87)A;7,G72D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N
M=6UB97(@;V8@<&%R86UE=&5R<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971.
M=6U087)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!S:7IE;V8H)'1H:7,M
M/G!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!834P@
M9&5C;&%R871I;VXG<R!E;F-O9&EN9R!A='1R:6)U=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@96YC;V1I;F<@='EP92`H25-/
M+3@X-3DM,2P@551&+3@@;W(@55,M05-#24DI"B`@("`@*@H@("`@("H@0')E
M='5R;B!V;VED"B`@("`@*@H@("`@("H@0'-E92!834Q?4E!#7TUE<W-A9V4Z
M.B1S96YD7V5N8V]D:6YG+"!834Q?4E!#7TUE<W-A9V4Z.GAM;%]H96%D97(H
M*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C(N,`H@("`@("HO"B`@("!F=6YC=&EO;B!S971396YD16YC;V1I;F<H
M)'1Y<&4I"B`@("!["B`@("`@("`@)'1H:7,M/G-E;F1?96YC;V1I;F<@/2`D
M='EP93L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T:&4@6$U,
M)W,@96YC;V1I;F<@=FEA('1H92!E;F-O9&EN9R!A='1R:6)U=&4*("`@("`J
M(&EN('1H92!834P@9&5C;&%R871I;VX*("`@("`J"B`@("`@*B!)9B!T:&4@
M96YC;V1I;F<@<&%R86UE=&5R(&ES(&YO="!S970@;W(@:7,@;F]T($E33RTX
M.#4Y+3$L(%541BTX"B`@("`@*B!O<B!54RU!4T-)22P@)%A-3%]24$-?9&5F
M96YC;V1I;F<@=VEL;"!B92!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A("!T:&4@6$U,('1H870@=VEL;"!B92!P87)S960*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5N8V]D:6YG('1O
M(&)E('5S960*("`@("`J"B`@("`@*B!`;&EN:R`@(&AT='`Z+R]P:'`N;F5T
M+WAM;%]P87)S97)?8W)E871E"B`@("`@*B!`<VEN8V4@($UE=&AO9"!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971%;F-O9&EN9R@D9&%T82D*("`@('L*("`@("`@("!G;&]B86P@)%A-
M3%]24$-?9&5F96YC;V1I;F<["@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M/%P_>&UL6UX^72I<<RIE;F-O9&EN9UQS*CU<<RI;7"<B72A;7B)<)UTJ*5M<
M)R)=+VDG+`H@("`@("`@("`@("`@("`@("`@("`@("1D871A+"`D;6%T8V@I
M*0H@("`@("`@('L*("`@("`@("`@("`@)&UA=&-H6S%=(#T@=')I;2AS=')T
M;W5P<&5R*"1M871C:%LQ72DI.PH@("`@("`@("`@("!S=VET8V@@*"1M871C
M:%LQ72D@>PH@("`@("`@("`@("`@("`@8V%S92`G25-/+3@X-3DM,2<Z"B`@
M("`@("`@("`@("`@("!C87-E("=55$8M."<Z"B`@("`@("`@("`@("`@("!C
M87-E("=54RU!4T-)22<Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1M
M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M6$U,7U)00U]D969E;F-O9&EN9SL*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D6$U,7U)00U]D969E;F-O9&EN
M9SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="`@82!N97<@6$U,7U)00U]297-P;VYS92!O8FIE8W0*("`@("`J+PH@
M("`@9G5N8W1I;VX@<&%R<V5297-P;VYS949I;&4H)&9P*0H@("`@>PH@("`@
M("`@("1I<&0@/2`G)SL*("`@("`@("!W:&EL92`H)&1A=&$@/2!`9G)E860H
M)&9P+"`X,3DR*2D@>PH@("`@("`@("`@("`D:7!D("X]("1D871A.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G!A<G-E4F5S<&]N<V4H)&EP
M9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@82!N
M97<@6$U,7U)00U]297-P;VYS92!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I
M;VX@<&%R<V5297-P;VYS92@D9&%T82`]("<G*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D6$U,7U)00U]X:"P@)%A-3%]24$-?97)R+"`D6$U,7U)00U]S='(L
M("1834Q?4E!#7V1E9F5N8V]D:6YG.PH*("`@("`@("`D96YC;V1I;F<@/2`D
M=&AI<RT^9V5T16YC;V1I;F<H)&1A=&$I.PH@("`@("`@("1P87)S97)?<F5S
M;W5R8V4@/2!X;6Q?<&%R<V5R7V-R96%T92@D96YC;V1I;F<I.PH@("`@("`@
M("1P87)S97(@/2`H:6YT*2`D<&%R<V5R7W)E<V]U<F-E.PH*("`@("`@("`D
M6$U,7U)00U]X:"`](&%R<F%Y*"D["B`@("`@("`@)%A-3%]24$-?>&A;)'!A
M<G-E<ET@/2!A<G)A>2@I.PH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG8VTG72`](#`["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES
M9B==(#T@,#L*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]
M("<G.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@)R<[
M"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T86-K)UT@/2!A<G)A
M>2@I.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU97-T86-K
M)UT@/2!A<G)A>2@I.PH*("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH
M)'!A<G-E<E]R97-O=7)C92P@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L('1R
M=64I.PH@("`@("`@('AM;%]S971?96QE;65N=%]H86YD;&5R*"1P87)S97)?
M<F5S;W5R8V4L("=834Q?4E!#7W-E)RP@)UA-3%]24$-?964G*3L*("`@("`@
M("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'!A<G-E<E]R97-O
M=7)C92P@)UA-3%]24$-?8V0G*3L*"B`@("`@("`@)&AD<F9N9"`](#`["B`@
M("`@("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("!P<FEN="`B
M7&X\<')E/BTM+4=/5"TM+5QN(CL*("`@("`@("`@("`@<')I;G0@:7-S970H
M)%]315)615);)U-%4E9%4E]04D]43T-/3"==*2`_(&AT;6QS<&5C:6%L8VAA
M<G,H)&1A=&$I(#H@)&1A=&$["B`@("`@("`@("`@('!R:6YT(")<;BTM+45.
M1"TM+3PO<')E/EQN(CL*("`@("`@("!]"@H@("`@("`@("\O(%-E92!I9B!R
M97-P;VYS92!I<R!A(#(P,"!O<B!A(#$P,"!T:&5N(&$@,C`P+"!E;'-E(')A
M:7-E(&5R<F]R+@H@("`@("`@("\O($)U="!O;FQY(&1O('1H:7,@:68@=V4G
M<F4@=7-I;F<@=&AE($A45%`@<')O=&]C;VPN"B`@("`@("`@:68@*&5R96<H
M)UY(5%10)RP@)&1A=&$I("8F"B`@("`@("`@("`@("%E<F5G*"=>2%144"];
M,"TY7"Y=*R`R,#`@)RP@)&1A=&$I("8F"B`@("`@("`@("`@("%P<F5G7VUA
M=&-H*"=`7DA45%`O6S`M.5PN72L@,3!;,"TY72A;02U:82UZ(%TK*3];7')<
M;ETK2%144"];,"TY7"Y=*R`R,#!`)RP@)&1A=&$I*0H@("`@("`@('L*("`@
M("`@("`@("`@("`@("1E<G)S='(@/2!S=6)S='(H)&1A=&$L(#`L('-T<G!O
M<R@D9&%T82P@(EQN(BD@+2`Q*3L*("`@("`@("`@("`@("`@(&5R<F]R7VQO
M9R@G2%144"!E<G)O<BP@9V]T(')E<W!O;G-E.B`G("X@)&5R<G-T<BD["B`@
M("`@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L("18
M34Q?4E!#7V5R<ELG:'1T<%]E<G)O<B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]S=');)VAT='!?97)R
M;W(G72`N("<@*"<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97)R<W1R("X@)RDG*3L*("`@("`@("`@("`@("`@('AM
M;%]P87)S97)?9G)E92@D<&%R<V5R7W)E<V]U<F-E*3L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<CL*("`@("`@("!]"@H@("`@("`@("\O(&=O='1A(&=E
M="!R:60@;V8@:&5A9&5R<R!H97)E"B`@("`@("`@:68@*"$D:&1R9FYD("8F
M("@D8G)P;W,@/2!S=')P;W,H)&1A=&$L(EQR7&Y<<EQN(BDI*2!["B`@("`@
M("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=H82==(#T@<W5B<W1R*"1D
M871A+"`P+"`D8G)P;W,I.PH@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D
M9&%T82P@)&)R<&]S("L@-"D["B`@("`@("`@("`@("1H9')F;F0@/2`Q.PH@
M("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B!B92!T;VQE<F%N="!O
M9B!J=6YK(&%F=&5R(&UE=&AO9%)E<W!O;G-E"B`@("`@("`@("H@*&4N9RX@
M:F%V87-C<FEP="!A=71O;6%T:6-A;&QY(&EN<V5R=&5D(&)Y(&9R964@:&]S
M=',I"B`@("`@("`@("H@=&AA;FMS('1O($QU8V$@36%R:6%N;R`\;'5C82YM
M87)I86YO0&5M86EL+FET/@H@("`@("`@("`J+PH@("`@("`@("1D871A(#T@
M<W5B<W1R*"1D871A+"`P+"!S=')P;W,H)&1A=&$L("(\+VUE=&AO9%)E<W!O
M;G-E/B(I("L@,3<I.PH@("`@("`@("1T:&ES+3YR97-P;VYS95]P87EL;V%D
M(#T@)&1A=&$["@H@("`@("`@(&EF("@A>&UL7W!A<G-E*"1P87)S97)?<F5S
M;W5R8V4L("1D871A+"!S:7IE;V8H)&1A=&$I*2D@>PH@("`@("`@("`@("`O
M+R!T:&%N:W,@=&\@4&5T97(@2V]C:W,@/'!E=&5R+FMO8VMS0&)A>6=A=&4N
M8V]M/@H@("`@("`@("`@("!I9B`H>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M
M8F5R*"1P87)S97)?<F5S;W5R8V4I(#T](#$I('L*("`@("`@("`@("`@("`@
M("1E<G)S='(@/2`G6$U,(&5R<F]R(&%T(&QI;F4@,2P@8VAE8VL@55),)SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1E<G)S='(@
M/2!S<')I;G1F*"=834P@97)R;W(Z("5S(&%T(&QI;F4@)60G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX
M;6Q?9V5T7V5R<F]R7V-O9&4H)'!A<G-E<E]R97-O=7)C92DI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT7VQI
M;F5?;G5M8F5R*"1P87)S97)?<F5S;W5R8V4I*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E<G)O<E]L;V<H)&5R<G-T<BD["B`@("`@("`@("`@("1R
M(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-3%]24$-?97)R6R=I;G9A
M;&ED7W)E='5R;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1834Q?4E!#7W-T<ELG:6YV86QI9%]R971U<FXG72D["B`@("`@
M("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R<V5R7W)E<V]U<F-E*3L*("`@
M("`@("`@("`@<F5T=7)N("1R.PH@("`@("`@('T*"B`@("`@("`@>&UL7W!A
M<G-E<E]F<F5E*"1P87)S97)?<F5S;W5R8V4I.PH*("`@("`@("!I9B`H)'1H
M:7,M/F1E8G5G*2!["B`@("`@("`@("`@('!R:6YT(")<;CQP<F4^+2TM4$%2
M4T5$+2TM7&XB.PH@("`@("`@("`@("!V87)?9'5M<"@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG=F%L=64G72D["B`@("`@("`@("`@('!R:6YT("(M+2U%3D0M
M+2T\+W!R93Y<;B(["B`@("`@("`@?0H*("`@("`@("!I9B`H)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)VES9B==(#X@,2D@>PH@("`@("`@("`@("`D<B`](&YE
M=R!834Q?4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG:6YV86QI9%]R
M971U<FXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D6$U,7U)00U]S=');)VEN=F%L:61?<F5T=7)N)UTN)R`G+B1834Q?4E!#
M7WAH6R1P87)S97)=6R=I<V9?<F5A<V]N)UTI.PH@("`@("`@('T@96QS96EF
M("@A:7-?;V)J96-T*"1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==*2D@
M>PH@("`@("`@("`@("`O+R!T:&5N('-O;65T:&EN9R!O9&0@:&%S(&AA<'!E
M;F5D"B`@("`@("`@("`@("\O(&%N9"!I="=S('1I;64@=&\@9V5N97)A=&4@
M82!C;&EE;G0@<VED92!E<G)O<@H@("`@("`@("`@("`O+R!I;F1I8V%T:6YG
M('-O;65T:&EN9R!O9&0@=V5N="!O;@H@("`@("`@("`@("`D<B`](&YE=R!8
M34Q?4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG:6YV86QI9%]R971U
M<FXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M6$U,7U)00U]S=');)VEN=F%L:61?<F5T=7)N)UTI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1V(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A
M;'5E)UT["B`@("`@("`@("`@("1A;&Q/2STQ.PH@("`@("`@("`@("!I9B`H
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9B==*2!["B`@("`@("`@("`@("`@
M("`D9B`]("1V+3YS=')U8W1M96TH)V9A=6QT0V]D92<I.PH@("`@("`@("`@
M("`@("`@)&9S(#T@)'8M/G-T<G5C=&UE;2@G9F%U;'13=')I;F<G*3L*("`@
M("`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H)'8L("1F
M+3YS8V%L87)V86PH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9S+3YS8V%L87)V86PH*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O
M;G-E*"1V*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<BT^
M:&1R<R`]('-P;&ET*")<<C]<;B(L("1834Q?4E!#7WAH6R1P87)S97)=6R=H
M82==6S%=*3L*("`@("`@("!R971U<FX@)'(["B`@("!]"GT*"B\J*@H@*B!4
M:&4@;65T:&]D<R!A;F0@<')O<&5R=&EE<R!T:&%T(')E<')E<V5N="!D871A
M(&EN(%A-3"!24$,@9F]R;6%T"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V
M:6-E<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D
M9"!$=6UB:6QL(#QE9&1`=7-E9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@
M4W1I9R!"86MK96X@/'-T:6=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R
M=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DY+3(P,#$@161D($1U;6)I;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S
M<R!834Q?4E!#7U9A;'5E(&5X=&5N9',@6$U,7U)00U]"87-E"GL*("`@('9A
M<B`D;64@/2!A<G)A>2@I.PH@("`@=F%R("1M>71Y<&4@/2`P.PH*("`@("\J
M*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-
M3%]24$-?5F%L=64H)'9A;"`]("TQ+"`D='EP92`]("<G*0H@("`@>PH@("`@
M("`@("1T:&ES+3YM92`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/FUY='EP
M92`](#`["B`@("`@("`@:68@*"1V86P@(3T@+3$@?'P@)'1Y<&4@(3T@)R<I
M('L*("`@("`@("`@("`@:68@*"1T>7!E(#T]("<G*2!["B`@("`@("`@("`@
M("`@("`D='EP92`]("=S=')I;F<G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D='EP92P@)$=,3T)!3%-;)UA-
M3%]24$-?5'EP97,G72DI('L*("`@("`@("`@("`@("`@("\O(%A86`H@("`@
M("`@("`@("`@("`@+R\@;F5E9"!S;VUE('=A>2!T;R!R97!O<G0@=&AI<R!E
M<G)O<@H@("`@("`@("`@("!](&5L<V5I9B`H)$=,3T)!3%-;)UA-3%]24$-?
M5'EP97,G75LD='EP95T@/3T@,2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F%D9%-C86QA<B@D=F%L+"`D='EP92D["B`@("`@("`@("`@('T@96QS96EF
M("@D1TQ/0D%,4ULG6$U,7U)00U]4>7!E<R==6R1T>7!E72`]/2`R*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^861D07)R87DH)'9A;"D["B`@("`@("`@
M("`@('T@96QS96EF("@D1TQ/0D%,4ULG6$U,7U)00U]4>7!E<R==6R1T>7!E
M72`]/2`S*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^861D4W1R=6-T*"1V
M86PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@0')E='5R;B!I;G0@(')E='5R;G,@,2!I9B!S=6-C97-S9G5L(&]R
M(#`@:68@=&AE<F4@87)E('!R;V)L96US"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9%-C86QA<B@D=F%L+"`D='EP92`]("=S=')I;F<G*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^;7ET>7!E(#T](#$I('L*("`@("`@("`@("`@)'1H
M:7,M/G)A:7-E17)R;W(H)U-C86QA<B!C86X@:&%V92!O;FQY(&]N92!V86QU
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?15)2
M3U)?24Y604Q)1%]465!%*3L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@
M("`@?0H@("`@("`@("1T>7!E;V8@/2`D1TQ/0D%,4ULG6$U,7U)00U]4>7!E
M<R==6R1T>7!E73L*("`@("`@("!I9B`H)'1Y<&5O9B`A/2`Q*2!["B`@("`@
M("`@("`@("1T:&ES+3YR86ES945R<F]R*").;W0@82!S8V%L87(@='EP92`H
M)'MT>7!E;V9]*2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]24$-?15)23U)?24Y604Q)1%]465!%*3L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1Y<&4@/3T@)$=,3T)!3%-;
M)UA-3%]24$-?0F]O;&5A;B==*2!["B`@("`@("`@("`@(&EF("AS=')C87-E
M8VUP*"1V86PL("=T<G5E)RD@/3T@,`H@("`@("`@("`@("`@("`@?'P@)'9A
M;"`]/2`Q"B`@("`@("`@("`@("`@("!\?"`H)'9A;"`]/2!T<G5E("8F('-T
M<F-A<V5C;7`H)'9A;"P@)V9A;'-E)RDI*0H@("`@("`@("`@("!["B`@("`@
M("`@("`@("`@("`D=F%L(#T@,3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1V86P@/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/FUY='EP92`]/2`R*2!["B`@("`@("`@
M("`@("\O('=E)W)E(&%D9&EN9R!T;R!A;B!A<G)A>2!H97)E"B`@("`@("`@
M("`@("1A<B`]("1T:&ES+3YM95LG87)R87DG73L*("`@("`@("`@("`@)&%R
M6UT@/2!N97<@6$U,7U)00U]686QU92@D=F%L+"`D='EP92D["B`@("`@("`@
M("`@("1T:&ES+3YM95LG87)R87DG72`]("1A<CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!A('-C86QA<BP@<V\@<V5T('1H92!V86QU92!A
M;F0@<F5M96UB97(@=V4G<F4@<V-A;&%R"B`@("`@("`@("`@("1T:&ES+3YM
M95LD='EP95T@/2`D=F%L.PH@("`@("`@("`@("`D=&AI<RT^;7ET>7!E(#T@
M)'1Y<&5O9CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N(#$["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!`<F5T=7)N(&EN="`@<F5T=7)N<R`Q(&EF('-U8V-E
M<W-F=6P@;W(@,"!I9B!T:&5R92!A<F4@<')O8FQE;7,*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D07)R87DH)'9A;',I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YM>71Y<&4@(3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<F%I<V5%
M<G)O<B@*("`@("`@("`@("`@("`@("`@("`G06QR96%D>2!I;FET:6%L:7IE
M9"!A<R!A(%LG("X@)'1H:7,M/FMI;F1/9B@I("X@)UTG+`H@("`@("`@("`@
M("`@("`@("`@(%A-3%]24$-?15)23U)?04Q214%$65])3DE424%,25I%1"D[
M"B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^;7ET>7!E(#T@)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G75LG87)R87DG
M73L*("`@("`@("`D=&AI<RT^;65;)V%R<F%Y)UT@/2`D=F%L<SL*("`@("`@
M("!R971U<FX@,3L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@:6YT
M("!R971U<FYS(#$@:68@<W5C8V5S<V9U;"!O<B`P(&EF('1H97)E(&%R92!P
M<F]B;&5M<PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&13=')U8W0H)'9A;',I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM>71Y<&4@(3T@,"D@>PH@("`@
M("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@*("`@("`@("`@("`@("`@("`@
M("`G06QR96%D>2!I;FET:6%L:7IE9"!A<R!A(%LG("X@)'1H:7,M/FMI;F1/
M9B@I("X@)UTG+`H@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?15)23U)?
M04Q214%$65])3DE424%,25I%1"D["B`@("`@("`@("`@(')E='5R;B`P.PH@
M("`@("`@('T*("`@("`@("`D=&AI<RT^;7ET>7!E(#T@)$=,3T)!3%-;)UA-
M3%]24$-?5'EP97,G75LG<W1R=6-T)UT["B`@("`@("`@)'1H:7,M/FUE6R=S
M=')U8W0G72`]("1V86QS.PH@("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1U;7`H)&%R*0H@("`@>PH@("`@("`@(')E<V5T*"1A<BD["B`@("`@("`@
M9F]R96%C:"`H)&%R(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!E
M8VAO("(D:V5Y(#T^("1V86P\8G(@+SXB.PH@("`@("`@("`@("!I9B`H)&ME
M>2`]/2`G87)R87DG*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L
M(&%S("1K97DR(#T^("1V86PR*2!["B`@("`@("`@("`@("`@("`@("`@96-H
M;R`B+2T@)&ME>3(@/3X@)'9A;#(\8G(@+SXB.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!D871A('1Y<&4@;V8@=&AE(&-U<G)E
M;G0@=F%L=64*("`@("`J+PH@("`@9G5N8W1I;VX@:VEN9$]F*"D*("`@('L*
M("`@("`@("!S=VET8V@@*"1T:&ES+3YM>71Y<&4I('L*("`@("`@("!C87-E
M(#,Z"B`@("`@("`@("`@(')E='5R;B`G<W1R=6-T)SL*"B`@("`@("`@8V%S
M92`R.@H@("`@("`@("`@("!R971U<FX@)V%R<F%Y)SL*"B`@("`@("`@8V%S
M92`Q.@H@("`@("`@("`@("!R971U<FX@)W-C86QA<B<["@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G=6YD968G.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T
M82!I;B!834P@9F]R;6%T"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ
M961A=&$H)'1Y<"P@)'9A;"D*("`@('L*("`@("`@("`D<G,@/2`G)SL*("`@
M("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)'1Y<"P@)$=,3T)!3%-;)UA-
M3%]24$-?5'EP97,G72DI('L*("`@("`@("`@("`@+R\@6%A8"B`@("`@("`@
M("`@("\O(&YE960@<V]M92!W87D@=&\@<F5P;W)T('1H:7,@97)R;W(*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@("`@("!S=VET8V@@*"1'
M3$]"04Q36R=834Q?4E!#7U1Y<&5S)UU;)'1Y<%TI('L*("`@("`@("!C87-E
M(#,Z"B`@("`@("`@("`@("\O('-T<G5C=`H@("`@("`@("`@("`D<G,@+CT@
M(CQS=')U8W0^7&XB.PH@("`@("`@("`@("!R97-E="@D=F%L*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)'9A;"!A<R`D:V5Y,B`]/B`D=F%L,BD@>PH@("`@
M("`@("`@("`@("`@)')S("X]("(\;65M8F5R/CQN86UE/B1[:V5Y,GT\+VYA
M;64^7&XB.PH@("`@("`@("`@("`@("`@)')S("X]("1T:&ES+3YS97)I86QI
M>F5V86PH)'9A;#(I.PH@("`@("`@("`@("`@("`@)')S("X]("(\+VUE;6)E
M<CY<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')S("X]("<\+W-T
M<G5C=#XG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`R.@H@
M("`@("`@("`@("`O+R!A<G)A>0H@("`@("`@("`@("`D<G,@+CT@(CQA<G)A
M>3Y<;CQD871A/EQN(CL*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M<VEZ96]F*"1V86PI.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<G,@+CT@
M)'1H:7,M/G-E<FEA;&EZ979A;"@D=F%L6R1I72D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')S("X]("(\+V1A=&$^7&X\+V%R<F%Y/B(["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@('-W
M:71C:"`H)'1Y<"D@>PH@("`@("`@("`@("!C87-E("1'3$]"04Q36R=834Q?
M4E!#7T)A<V4V-"==.@H@("`@("`@("`@("`@("`@)')S("X]("(\)'MT>7!]
M/B(@+B!B87-E-C1?96YC;V1E*"1V86PI("X@(CPO)'MT>7!]/B(["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`D1TQ/0D%,4ULG
M6$U,7U)00U]";V]L96%N)UTZ"B`@("`@("`@("`@("`@("`D<G,@+CT@(CPD
M>W1Y<'T^(B`N("@D=F%L(#\@)S$G(#H@)S`G*2`N("(\+R1[='EP?3XB.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)$=,3T)!
M3%-;)UA-3%]24$-?4W1R:6YG)UTZ"B`@("`@("`@("`@("`@("`D<G,@+CT@
M(CPD>W1Y<'T^(B`N(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"DN("(\+R1[='EP
M?3XB.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`D<G,@+CT@(CPD>W1Y<'T^)'MV86Q]/"\D
M>W1Y<'T^(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@)')S.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!D871A(&EN(%A-3"!F;W)M870*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5R:6%L:7IE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G-E<FEA
M;&EZ979A;"@D=&AI<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&1A=&$@:6X@6$U,(&9O<FUA=`H@("`@("HO"B`@("!F
M=6YC=&EO;B!S97)I86QI>F5V86PH)&\I"B`@("!["B`@("`@("`@:68@*"%I
M<U]O8FIE8W0H)&\I('Q\(&5M<'1Y*"1O+3YM92D@?'P@(6ES7V%R<F%Y*"1O
M+3YM92DI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@
M("`@("`D87(@/2`D;RT^;64["B`@("`@("`@<F5S970H)&%R*3L*("`@("`@
M("!L:7-T*"1T>7`L("1V86PI(#T@96%C:"@D87(I.PH@("`@("`@(')E='5R
M;B`G/'9A;'5E/B<@+B`@)'1H:7,M/G-E<FEA;&EZ961A=&$H)'1Y<"P@)'9A
M;"D@+B`@(CPO=F%L=64^7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@=&AE(&-O;G1E;G1S(&]F('1H92!E;&5M96YT(')E<75E
M<W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!S=')U8W1M96TH)&TI"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YM95LG<W1R=6-T)UU;)&U=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-T<G5C=')E<V5T*"D*("`@('L*("`@("`@("!R97-E="@D=&AI
M<RT^;65;)W-T<G5C="==*3L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U
M<FX@('1H92!K97DO=F%L=64@<&%I<B!O9B!T:&4@<W1R=6-T)W,@8W5R<F5N
M="!E;&5M96YT"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<G5C=&5A8V@H*0H@
M("`@>PH@("`@("`@(')E='5R;B!E86-H*"1T:&ES+3YM95LG<W1R=6-T)UTI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!M:7AE9"`@=&AE(&-U
M<G)E;G0@=F%L=64*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T=F%L*"D*("`@
M('L*("`@("`@("`O+R!53E-404),10H*("`@("`@("!R97-E="@D=&AI<RT^
M;64I.PH@("`@("`@("1B(#T@8W5R<F5N="@D=&AI<RT^;64I.PH*("`@("`@
M("`O+R!C;VYT<FEB=71E9"!B>2!)(%-O9F5R+"`R,#`Q+3`S+3(T"B`@("`@
M("`@+R\@861D('-U<'!O<G0@9F]R(&YE<W1E9"!A<G)A>7,@=&\@<V-A;&%R
M=F%L"B`@("`@("`@+R\@:2=V92!C<F5A=&5D(&$@;F5W(&UE=&AO9"!H97)E
M+"!S;R!A<R!T;PH@("`@("`@("\O('!R97-E<G9E(&)A8VL@8V]M<&%T:6)I
M;&ET>0H*("`@("`@("!I9B`H:7-?87)R87DH)&(I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1B(&%S("1I9"`]/B`D8V]N="D@>PH@("`@("`@("`@("`@
M("`@)&);)&ED72`]("1C;VYT+3YS8V%L87)V86PH*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+R\@861D('-U<'!O<G0@9F]R('-T<G5C
M='5R97,@9&ER96-T;'D@96YC;V1I;F<@<&AP(&]B:F5C=',*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1B*2D@>PH@("`@("`@("`@("`D="`](&=E=%]O8FIE
M8W1?=F%R<R@D8BD["B`@("`@("`@("`@(&9O<F5A8V@@*"1T(&%S("1I9"`]
M/B`D8V]N="D@>PH@("`@("`@("`@("`@("`@)'1;)&ED72`]("1C;VYT+3YS
M8V%L87)V86PH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H
M("@D="!A<R`D:60@/3X@)&-O;G0I('L*("`@("`@("`@("`@("`@("1B+3XD
M:60@/2`D8V]N=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@96YD(&-O;G1R:6(*("`@("`@("!R971U<FX@)&(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!`<F5T=7)N(&UI>&5D"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-C86QA<G9A;"@I"B`@("!["B`@("`@("`@<F5S970H)'1H:7,M/FUE*3L*
M("`@("`@("!R971U<FX@8W5R<F5N="@D=&AI<RT^;64I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V-A;&%R='EP*"D*("`@('L*("`@("`@("!R97-E="@D=&AI<RT^;64I
M.PH@("`@("`@("1A(#T@:V5Y*"1T:&ES+3YM92D["B`@("`@("`@:68@*"1A
M(#T]("1'3$]"04Q36R=834Q?4E!#7TDT)UTI('L*("`@("`@("`@("`@)&$@
M/2`D1TQ/0D%,4ULG6$U,7U)00U]);G0G73L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1A.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@=&AE('-T<G5C="=S(&-U<G)E;G0@96QE;65N=`H@("`@("HO"B`@("!F
M=6YC=&EO;B!A<G)A>6UE;2@D;2D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/FUE6R=A<G)A>2==6R1M73L*("`@('T*"B`@("`O*BH*("`@("`J($!R
M971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&5L96UE;G1S(&EN('1H92!A<G)A
M>0H@("`@("HO"B`@("!F=6YC=&EO;B!A<G)A>7-I>F4H*0H@("`@>PH@("`@
M("`@(')E<V5T*"1T:&ES+3YM92D["B`@("`@("`@;&ES="@D82P@)&(I(#T@
M96%C:"@D=&AI<RT^;64I.PH@("`@("`@(')E='5R;B!S:7IE;V8H)&(I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!T:&4@:71E;2!S
M=6)M:71T960@:7,@86X@6$U,7U)00U]686QU92!O8FIE8W0*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)'9A;"`@=&AE('9A<FEA8FQE('1O(&)E(&5V
M86QU871E9`H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!I9B!T
M:&4@:71E;2!I<R!A;B!834Q?4E!#7U9A;'5E(&]B:F5C=`H@("`@("H*("`@
M("`J($!S=&%T:6,*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XS+C`*("`@("`J+PH@("`@9G5N8W1I;VX@:7-686QU
M92@D=F%L*0H@("`@>PH@("`@("`@(')E='5R;B`H<W1R=&]L;W=E<BAG971?
M8VQA<W,H)'9A;"DI(#T]("=X;6Q?<G!C7W9A;'5E)RD["B`@("!]"GT*"B\J
M*@H@*B!2971U<FX@86X@25-/.#8P,2!E;F-O9&5D('-T<FEN9PH@*@H@*B!7
M:&EL92!T:6UE>F]N97,@;W5G:'0@=&\@8F4@<W5P<&]R=&5D+"!T:&4@6$U,
M+5)00R!S<&5C('-A>7,Z"B`J"B`J(")$;VXG="!A<W-U;64@82!T:6UE>F]N
M92X@270@<VAO=6QD(&)E('-P96-I9FEE9"!B>2!T:&4@<V5R=F5R(&EN(&ET
M<PH@*B!D;V-U;65N=&%T:6]N('=H870@87-S=6UP=&EO;G,@:70@;6%K97,@
M86)O=70@=&EM97IO;F5S+B(*("H*("H@5&AI<R!R;W5T:6YE(&%L=V%Y<R!A
M<W-U;65S(&QO8V%L=&EM92!U;FQE<W,@)'5T8R!I<R!S970@=&\@,2P@:6X@
M=VAI8V@*("H@8V%S92!55$,@:7,@87-S=6UE9"!A;F0@86X@861J=7-T;65N
M="!F;W(@;&]C86QE(&ES(&UA9&4@=VAE;B!E;F-O9&EN9RX*("H*("H@0')E
M='5R;B!S=')I;F<@('1H92!F;W)M871T960@9&%T90H@*B\*9G5N8W1I;VX@
M6$U,7U)00U]I<V\X-C`Q7V5N8V]D92@D=&EM970L("1U=&,@/2`P*0I["B`@
M("!I9B`H(21U=&,I('L*("`@("`@("`D="`]('-T<F9T:6UE*"<E625M)614
M)4@Z)4TZ)5,G+"`D=&EM970I.PH@("`@?2!E;'-E('L*("`@("`@("!I9B`H
M9G5N8W1I;VY?97AI<W1S*"=G;7-T<F9T:6UE)RDI('L*("`@("`@("`@("`@
M+R\@9VUS=')F=&EM92!D;V5S;B=T(&5X:7-T(&EN('-O;64@=F5R<VEO;G,*
M("`@("`@("`@("`@+R\@;V8@4$A0"B`@("`@("`@("`@("1T(#T@9VUS=')F
M=&EM92@G)5DE;25D5"5(.B5-.B53)RP@)'1I;65T*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D="`]('-T<F9T:6UE*"<E625M)614)4@Z)4TZ
M)5,G+"`D=&EM970@+2!D871E*"=:)RDI.PH@("`@("`@('T*("`@('T*("`@
M(')E='5R;B`D=#L*?0H*+RHJ"B`J($-O;G9E<G0@82!D871E=&EM92!S=')I
M;F<@:6YT;R!A(%5N:7@@=&EM97-T86UP"B`J"B`J(%=H:6QE('1I;65Z;VYE
M<R!O=6=H="!T;R!B92!S=7!P;W)T960L('1H92!834PM4E!#('-P96,@<V%Y
M<SH*("H*("H@(D1O;B=T(&%S<W5M92!A('1I;65Z;VYE+B!)="!S:&]U;&0@
M8F4@<W!E8VEF:65D(&)Y('1H92!S97)V97(@:6X@:71S"B`J(&1O8W5M96YT
M871I;VX@=VAA="!A<W-U;7!T:6]N<R!I="!M86ME<R!A8F]U="!T:6UE>F]N
M97,N(@H@*@H@*B!4:&ES(')O=71I;F4@86QW87ES(&%S<W5M97,@;&]C86QT
M:6UE('5N;&5S<R`D=71C(&ES('-E="!T;R`Q+"!I;B!W:&EC:`H@*B!C87-E
M(%540R!I<R!A<W-U;65D(&%N9"!A;B!A9&IU<W1M96YT(&9O<B!L;V-A;&4@
M:7,@;6%D92!W:&5N(&5N8V]D:6YG+@H@*@H@*B!`<F5T=7)N(&EN="`@=&AE
M('5N:7@@=&EM97-T86UP(&]F('1H92!D871E('-U8FUI='1E9`H@*B\*9G5N
M8W1I;VX@6$U,7U)00U]I<V\X-C`Q7V1E8V]D92@D:61A=&4L("1U=&,@/2`P
M*0I["B`@("`D="`](#`["B`@("!I9B`H97)E9R@G*%LP+3E=>S1]*2A;,"TY
M77LR?2DH6S`M.5U[,GTI5"A;,"TY77LR?2DZ*%LP+3E=>S)]*3HH6S`M.5U[
M,GTI)RP@)&ED871E+"`D<F5G<RDI('L*("`@("`@("!I9B`H)'5T8RD@>PH@
M("`@("`@("`@("`D="`](&=M;6MT:6UE*"1R96=S6S1=+"`D<F5G<ULU72P@
M)')E9W-;-ETL("1R96=S6S)=+"`D<F5G<ULS72P@)')E9W-;,5TI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T(#T@;6MT:6UE*"1R96=S6S1=
M+"`D<F5G<ULU72P@)')E9W-;-ETL("1R96=S6S)=+"`D<F5G<ULS72P@)')E
M9W-;,5TI.PH@("`@("`@('T*("`@('T*("`@(')E='5R;B`D=#L*?0H*+RHJ
M"B`J($-O;G9E<G1S(&%N(%A-3%]24$-?5F%L=64@;V)J96-T(&EN=&\@;F%T
M:79E(%!(4"!T>7!E<PH@*@H@*B!`<&%R86T@;V)J96-T("1834Q?4E!#7W9A
M;"`@=&AE(%A-3%]24$-?5F%L=64@;V)J96-T('1O(&1E8V]D90H@*@H@*B!`
M<F5T=7)N(&UI>&5D("!T:&4@4$A0('9A;'5E<PH@*B\*9G5N8W1I;VX@6$U,
M7U)00U]D96-O9&4H)%A-3%]24$-?=F%L*0I["B`@("`D:VEN9"`]("1834Q?
M4E!#7W9A;"T^:VEN9$]F*"D["@H@("`@:68@*"1K:6YD(#T]("=S8V%L87(G
M*2!["B`@("`@("`@<F5T=7)N("1834Q?4E!#7W9A;"T^<V-A;&%R=F%L*"D[
M"@H@("`@?2!E;'-E:68@*"1K:6YD(#T]("=A<G)A>2<I('L*("`@("`@("`D
M<VEZ92`]("1834Q?4E!#7W9A;"T^87)R87ES:7IE*"D["B`@("`@("`@)&%R
M<B`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'-I>F4[
M("1I*RLI('L*("`@("`@("`@("`@)&%R<EM=(#T@6$U,7U)00U]D96-O9&4H
M)%A-3%]24$-?=F%L+3YA<G)A>6UE;2@D:2DI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&%R<CL*"B`@("!](&5L<V5I9B`H)&MI;F0@/3T@)W-T<G5C
M="<I('L*("`@("`@("`D6$U,7U)00U]V86PM/G-T<G5C=')E<V5T*"D["B`@
M("`@("`@)&%R<B`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*&QI<W0H)&ME
M>2P@)'9A;'5E*2`]("1834Q?4E!#7W9A;"T^<W1R=6-T96%C:"@I*2!["B`@
M("`@("`@("`@("1A<G);)&ME>5T@/2!834Q?4E!#7V1E8V]D92@D=F%L=64I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&%R<CL*("`@('T*?0H*+RHJ
M"B`J($-O;G9E<G1S(&YA=&EV92!02%`@='EP97,@:6YT;R!A;B!834Q?4E!#
M7U9A;'5E(&]B:F5C=`H@*@H@*B!`<&%R86T@;6EX960@)'!H<%]V86P@('1H
M92!02%`@=F%L=64@;W(@=F%R:6%B;&4@>6]U('=A;G0@96YC;V1E9`H@*@H@
M*B!`<F5T=7)N(&]B:F5C="`@=&AE(%A-3%]24$-?5F%L=64@;V)J96-T"B`J
M+PIF=6YC=&EO;B!834Q?4E!#7V5N8V]D92@D<&AP7W9A;"D*>PH@("`@)'1Y
M<&4@/2!G971T>7!E*"1P:'!?=F%L*3L*("`@("1834Q?4E!#7W9A;"`](&YE
M=R!834Q?4E!#7U9A;'5E.PH*("`@('-W:71C:"`H)'1Y<&4I('L*("`@(&-A
M<V4@)V%R<F%Y)SH*("`@("`@("!I9B`H96UP='DH)'!H<%]V86PI*2!["B`@
M("`@("`@("`@("1834Q?4E!#7W9A;"T^861D07)R87DH)'!H<%]V86PI.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("`@("`@)'1M<"`](&%R
M<F%Y7V1I9F8H87)R87E?:V5Y<R@D<&AP7W9A;"DL(')A;F=E*#`L(&-O=6YT
M*"1P:'!?=F%L*2TQ*2D["B`@("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@
M("`@("`@("`@)&%R<B`](&%R<F%Y*"D["B`@("`@("`@("`@9F]R96%C:"`H
M)'!H<%]V86P@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@)&%R<ELD
M:UT@/2!834Q?4E!#7V5N8V]D92@D=BD["B`@("`@("`@("`@?0H@("`@("`@
M("`@("1834Q?4E!#7W9A;"T^861D07)R87DH)&%R<BD["B`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H@("`@("`@("\O(&9A;&P@=&AO=6=H(&EF(&ET
M)W,@;F]T(&%N(&5N=6UE<F%T960@87)R87D*"B`@("!C87-E("=O8FIE8W0G
M.@H@("`@("`@("1A<G(@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1P
M:'!?=F%L(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("1A<G);)&M=(#T@
M6$U,7U)00U]E;F-O9&4H)'8I.PH@("`@("`@('T*("`@("`@("`D6$U,7U)0
M0U]V86PM/F%D9%-T<G5C="@D87)R*3L*("`@("`@("!B<F5A:SL*"B`@("!C
M87-E("=I;G1E9V5R)SH*("`@("`@("`D6$U,7U)00U]V86PM/F%D9%-C86QA
M<B@D<&AP7W9A;"P@)$=,3T)!3%-;)UA-3%]24$-?26YT)UTI.PH@("`@("`@
M(&)R96%K.PH*("`@(&-A<V4@)V1O=6)L92<Z"B`@("`@("`@)%A-3%]24$-?
M=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1'3$]"04Q36R=834Q?4E!#7T1O
M=6)L92==*3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=S=')I;F<G.@H@
M("`@8V%S92`G3E5,3"<Z"B`@("`@("`@:68@*&5R96<H)UY;,"TY77LX?5Q4
M>S%]6S`M.5U[,GU<.ELP+3E=>S)]7#I;,"TY77LR?20G+"`D<&AP7W9A;"DI
M('L*("`@("`@("`@("`@)%A-3%]24$-?=F%L+3YA9&138V%L87(H)'!H<%]V
M86PL("1'3$]"04Q36R=834Q?4E!#7T1A=&54:6UE)UTI.PH@("`@("`@('T@
M96QS96EF("AP<F5G7VUA=&-H*"<O6UY<>#(P+5QX-T5<>#`Y7'@P05QX,$1=
M+R<L("1P:'!?=F%L*2D@>PH@("`@("`@("`@("`O+R!#:&%R86-T97)S(&]T
M:&5R('1H86X@86QP:&$M;G5M97)I8RP@<'5N8W1U871I;VXL(%-0+"!404(L
M"B`@("`@("`@("`@("\O($Q&(&%N9"!#4B!B<F5A:R!T:&4@6$U,('!A<G-E
M<BP@96YC;V1E('9A;'5E('9I82!"87-E(#8T+@H@("`@("`@("`@("`D6$U,
M7U)00U]V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@)$=,3T)!3%-;)UA-3%]2
M4$-?0F%S938T)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("18
M34Q?4E!#7W9A;"T^861D4V-A;&%R*"1P:'!?=F%L+"`D1TQ/0D%,4ULG6$U,
M7U)00U]3=')I;F<G72D["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@
M(&-A<V4@)V)O;VQE86XG.@H@("`@("`@("\O($%D9"!S=7!P;W)T(&9O<B!E
M;F-O9&EN9R]D96-O9&EN9R!O9B!B;V]L96%N<RP@<VEN8V4@=&AE>0H@("`@
M("`@("\O(&%R92!S=7!P;W)T960@:6X@4$A0"B`@("`@("`@+R\@8GD@/$=?
M1VEU;G1A7S(P,#$M,#(M,CD^"B`@("`@("`@)%A-3%]24$-?=F%L+3YA9&13
M8V%L87(H)'!H<%]V86PL("1'3$]"04Q36R=834Q?4E!#7T)O;VQE86XG72D[
M"B`@("`@("`@8G)E86L["@H@("`@8V%S92`G=6YK;F]W;B!T>7!E)SH*("`@
M(&1E9F%U;'0Z"B`@("`@("`@)%A-3%]24$-?=F%L(#T@9F%L<V4["B`@("!]
M"B`@("!R971U<FX@)%A-3%]24$-?=F%L.PI]"@HO*@H@*B!,;V-A;"!V87)I
M86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@
M*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]$0B\`````````````````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,34V
M,S$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+V-O;6UO;BYP:'``
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,C`W-38W
M`#$P-3$U-#,Q,#4W`#`Q-S8U,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B
M('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J
M*@H@*B!#;VYT86EN<R!T:&4@1$)?8V]M;6]N(&)A<V4@8VQA<W,*("H*("H@
M4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A
M=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6
M+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&-O;6UO;BYP:'`L=B`Q+C$S-R`R
M,#`U+S`T+S`W(#$T.C(W.C,U(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J
M($]B=&%I;B!T:&4@4$5!4B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@
M9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@1$)?
M8V]M;6]N(&ES('1H92!B87-E(&-L87-S(&9R;VT@=VAI8V@@96%C:"!D871A
M8F%S92!D<FEV97(@8VQA<W,@97AT96YD<PH@*@H@*B!!;&P@8V]M;6]N(&UE
M=&AO9',@87)E(&1E8VQA<F5D(&AE<F4N("!)9B!A(&=I=F5N($1"35,@9')I
M=F5R(&-O;G1A:6YS"B`J(&$@<&%R=&EC=6QA<B!M971H;V0L('1H870@;65T
M:&]D('=I;&P@;W9E<FQO860@=&AE(&]N92!H97)E+@H@*@H@*B!`8V%T96=O
M<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J($!A=71H;W(@("`@(%1O
M;6%S(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@
M($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA
M<W,@1$)?8V]M;6]N(&5X=&5N9',@4$5!4@I["B`@("`O+R![>WL@<')O<&5R
M=&EE<PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@9&5F875L="!F971C
M:"!M;V1E"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1F
M971C:&UO9&4@/2!$0E]&151#2$U/1$5?3U)$15)%1#L*"B`@("`O*BH*("`@
M("`J(%1H92!N86UE(&]F('1H92!C;&%S<R!I;G1O('=H:6-H(')E<W5L=',@
M<VAO=6QD(&)E(&9E=&-H960@=VAE;@H@("`@("H@1$)?1D540TA-3T1%7T]"
M2D5#5"!I<R!I;B!E9F9E8W0*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&9E=&-H;6]D95]O8FIE8W1?8VQA<W,@/2`G<W1D
M0VQA<W,G.PH*("`@("\J*@H@("`@("H@5V%S(&$@8V]N;F5C=&EO;B!P<F5S
M96YT('=H96X@=&AE(&]B:F5C="!W87,@<V5R:6%L:7IE9"@I/PH@("`@("H@
M0'9A<B!B;V]L"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ7U]S;&5E<"@I+"!$
M0E]C;VUM;VXZ.E]?=V%K92@I"B`@("`@*B\*("`@('9A<B`D=V%S7V-O;FYE
M8W1E9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@;6]S="!R96-E;G1L
M>2!E>&5C=71E9"!Q=65R>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1L87-T7W%U97)Y(#T@)R<["@H@("`@+RHJ"B`@("`@*B!2=6XM
M=&EM92!C;VYF:6=U<F%T:6]N(&]P=&EO;G,*("`@("`J"B`@("`@*B!4:&4@
M)V]P=&EM:7IE)R!O<'1I;VX@:&%S(&)E96X@9&5P<F5C871E9"X@(%5S92!T
M:&4@)W!O<G1A8FEL:71Y)PH@("`@("H@;W!T:6]N(&EN<W1E860N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G-E
M=$]P=&EO;B@I"B`@("`@*B\*("`@('9A<B`D;W!T:6]N<R`](&%R<F%Y*`H@
M("`@("`@("=R97-U;'1?8G5F9F5R:6YG)R`]/B`U,#`L"B`@("`@("`@)W!E
M<G-I<W1E;G0G(#T^(&9A;'-E+`H@("`@("`@("=S<VPG(#T^(&9A;'-E+`H@
M("`@("`@("=D96)U9R<@/3X@,"P*("`@("`@("`G<V5Q;F%M95]F;W)M870G
M(#T^("<E<U]S97$G+`H@("`@("`@("=A=71O9G)E92<@/3X@9F%L<V4L"B`@
M("`@("`@)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465].3TY%+`H@
M("`@("`@("=O<'1I;6EZ92<@/3X@)W!E<F9O<FUA;F-E)RP@("\O($1E<')E
M8V%T960N("!5<V4@)W!O<G1A8FEL:71Y)RX*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!4:&4@<&%R86UE=&5R<R!F<F]M('1H92!M;W-T(')E8V5N=&QY(&5X
M96-U=&5D('%U97)Y"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`<VEN8V4@
M4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J
M+PH@("`@=F%R("1L87-T7W!A<F%M971E<G,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@5&AE(&5L96UE;G1S(&9R;VT@96%C:"!P<F5P87)E9"!S=&%T
M96UE;G0*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1P<F5P
M87)E7W1O:V5N<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T
M82!T>7!E<R!O9B!T:&4@=F%R:6]U<R!E;&5M96YT<R!I;B!E86-H('!R97!A
M<F5D('-T871E;65N=`H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)'!R97!A<F5?='EP97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M5&AE('!R97!A<F5D('%U97)I97,*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1P<F5P87)E9%]Q=65R:65S(#T@87)R87DH*3L*"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@1$)?8V]M;6]N"@H@("`@+RHJ"B`@("`@*B!4
M:&ES(&-O;G-T<G5C=&]R(&-A;&QS(#QK8F0^)'1H:7,M/E!%05(H)T1"7T5R
M<F]R)RD\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J
M+PH@("`@9G5N8W1I;VX@1$)?8V]M;6]N*"D*("`@('L*("`@("`@("`D=&AI
M<RT^4$5!4B@G1$)?17)R;W(G*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!?7W-L965P*"D*"B`@("`O*BH*("`@("`J($%U=&]M871I8V%L;'D@
M:6YD:6-A=&5S('=H:6-H('!R;W!E<G1I97,@<VAO=6QD(&)E('-A=F5D"B`@
M("`@*B!W:&5N(%!(4"=S('-E<FEA;&EZ92@I(&9U;F-T:6]N(&ES(&-A;&QE
M9`H@("`@("H*("`@("`J($!R971U<FX@87)R87D@('1H92!A<G)A>2!O9B!P
M<F]P97)T:65S(&YA;65S('1H870@<VAO=6QD(&)E('-A=F5D"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]?<VQE97`H*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@("`O+R!$;VXG="!D:7-C;VYN
M96-T*"DL('!E;W!L92!U<V4@<V5R:6%L:7IE*"D@9F]R(&UA;GD@<F5A<V]N
M<PH@("`@("`@("`@("`D=&AI<RT^=V%S7V-O;FYE8W1E9"`]('1R=64["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G=A<U]C;VYN96-T
M960@/2!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YA=71O8V]M;6ET*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)V%U
M=&]C;VUM:70G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V1B<WEN=&%X
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=D<VXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)V9E871U<F5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("=F971C:&UO9&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)V9E=&-H;6]D95]O8FIE8W1?8VQA<W,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)V]P=&EO;G,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W=A
M<U]C;VYN96-T960G+`H@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)V1B<WEN=&%X)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("=D<VXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9E871U<F5S)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("=F971C:&UO9&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V9E
M=&-H;6]D95]O8FIE8W1?8VQA<W,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)V]P=&EO;G,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W=A<U]C
M;VYN96-T960G+`H@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7U]W86ME=7`H*0H*("`@("\J
M*@H@("`@("H@075T;VUA=&EC86QL>2!R96-O;FYE8W1S('1O('1H92!D871A
M8F%S92!W:&5N(%!(4"=S('5N<V5R:6%L:7IE*"D*("`@("`J(&9U;F-T:6]N
M(&ES(&-A;&QE9`H@("`@("H*("`@("`J(%1H92!R96-O;FYE8W1I;VX@871T
M96UP="!I<R!O;FQY('!E<F9O<FUE9"!I9B!T:&4@;V)J96-T('=A<R!C;VYN
M96-T960*("`@("`J(&%T('1H92!T:6UE(%!(4"=S('-E<FEA;&EZ92@I(&9U
M;F-T:6]N('=A<R!R=6XN"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]?=V%K975P*"D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/G=A<U]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H:7,M
M/F-O;FYE8W0H)'1H:7,M/F1S;BP@)'1H:7,M/F]P=&EO;G,I.PH@("`@("`@
M('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?7W1O4W1R:6YG*"D*
M"B`@("`O*BH*("`@("`J($%U=&]M871I8R!S=')I;F<@8V]N=F5R<VEO;B!F
M;W(@4$A0(#4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@82!S=')I
M;F<@9&5S8W)I8FEN9R!T:&4@8W5R<F5N="!014%2($1"(&]B:F5C=`H@("`@
M("H*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7U]T;U-T<FEN9R@I"B`@
M("!["B`@("`@("`@)&EN9F\@/2!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI
M<RDI.PH@("`@("`@("1I;F9O("X]("`G.B`H<&AP='EP93TG("X@)'1H:7,M
M/G!H<'1Y<&4@+@H@("`@("`@("`@("`@("`@("`G+"!D8G-Y;G1A>#TG("X@
M)'1H:7,M/F1B<WEN=&%X("X*("`@("`@("`@("`@("`@("`@)RDG.PH@("`@
M("`@(&EF("@D=&AI<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@("`D:6YF
M;R`N/2`G(%MC;VYN96-T961=)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1I;F9O.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1O4W1R:6YG
M*"D*"B`@("`O*BH*("`@("`J($1%4%)%0T%4140Z("!3=')I;F<@8V]N=F5R
M<VEO;B!M971H;V0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@82!S
M=')I;F<@9&5S8W)I8FEN9R!T:&4@8W5R<F5N="!014%2($1"(&]B:F5C=`H@
M("`@("H*("`@("`J($!D97!R96-A=&5D($UE=&AO9"!D97!R96-A=&5D(&EN
M(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7U]T;U-T<FEN9R@I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E4W1R:6YG*"D*"B`@
M("`O*BH*("`@("`J($1%4%)%0T%4140Z(%%U;W1E<R!A('-T<FEN9R!S;R!I
M="!C86X@8F4@<V%F96QY('5S960@=VET:&EN('-T<FEN9PH@("`@("H@9&5L
M:6UI=&5R<R!I;B!A('%U97)Y"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<W1R:6YG("!T:&4@<W1R:6YG('1O(&)E('%U;W1E9`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@<75O=&5D('-T<FEN9PH@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIQ=6]T95-M87)T*"DL($1"7V-O;6UO
M;CHZ97-C87!E4VEM<&QE*"D*("`@("`J($!D97!R96-A=&5D($UE=&AO9"!D
M97!R96-A=&5D('-O;64@=&EM92!B969O<F4@4F5L96%S92`Q+C(*("`@("`J
M+PH@("`@9G5N8W1I;VX@<75O=&53=')I;F<H)'-T<FEN9RD*("`@('L*("`@
M("`@("`D<W1R:6YG(#T@)'1H:7,M/G%U;W1E*"1S=')I;F<I.PH@("`@("`@
M(&EF("@D<W1R:6YG>S!](#T]("(G(BD@>PH@("`@("`@("`@("!R971U<FX@
M<W5B<W1R*"1S=')I;F<L(#$L("TQ*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1S=')I;F<["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O
M=&4H*0H*("`@("\J*@H@("`@("H@1$504D5#051%1#H@475O=&5S(&$@<W1R
M:6YG('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!I;B!A('%U97)Y"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG("!T:&4@<W1R:6YG('1O
M('%U;W1E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!Q=6]T
M960@<W1R:6YG(&]R('1H92!S=')I;F<@/'-A;7`^3E5,3#PO<V%M<#X*("`@
M("`J("`@("`@("`@("`@("`@("`@:68@=&AE('9A;'5E('-U8FUI='1E9"!I
M<R`\:V)D/FYU;&P\+VMB9#XN"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G%U;W1E4VUA<G0H*2P@1$)?8V]M;6]N.CIE<V-A<&53:6UP;&4H*0H@
M("`@("H@0&1E<')E8V%T960@1&5P<F5C871E9"!I;B!R96QE87-E(#$N-BXP
M"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E*"1S=')I;F<@/2!N=6QL*0H@
M("`@>PH@("`@("`@(')E='5R;B`H)'-T<FEN9R`]/3T@;G5L;"D@/R`G3E5,
M3"<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(B<B("X@
M<W1R7W)E<&QA8V4H(B<B+"`B)R<B+"`D<W1R:6YG*2`N("(G(CL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T94ED96YT:69I97(H*0H*("`@
M("\J*@H@("`@("H@475O=&5S(&$@<W1R:6YG('-O(&ET(&-A;B!B92!S869E
M;'D@=7-E9"!A<R!A('1A8FQE(&]R(&-O;'5M;B!N86UE"B`@("`@*@H@("`@
M("H@1&5L:6UI=&EN9R!S='EL92!D97!E;F1S(&]N('=H:6-H(&1A=&%B87-E
M(&1R:79E<B!I<R!B96EN9R!U<V5D+@H@("`@("H*("`@("`J($Y/5$4Z(&IU
M<W0@8F5C875S92!Y;W4@0T%.('5S92!D96QI;6ET960@:61E;G1I9FEE<G,@
M9&]E<VXG="!M96%N"B`@("`@*B!Y;W4@4TA/54Q$('5S92!T:&5M+B`@26X@
M9V5N97)A;"P@=&AE>2!E;F0@=7`@8V%U<VEN9R!W87D@;6]R90H@("`@("H@
M<')O8FQE;7,@=&AA;B!T:&5Y('-O;'9E+@H@("`@("H*("`@("`J(%!O<G1A
M8FEL:71Y(&ES(&)R;VME;B!B>2!U<VEN9R!T:&4@9F]L;&]W:6YG(&-H87)A
M8W1E<G,@:6YS:61E"B`@("`@*B!D96QI;6ET960@:61E;G1I9FEE<G,Z"B`@
M("`@*B`@("L@8F%C:W1I8VL@*#QK8F0^8#PO:V)D/BD@+2T@9'5E('1O($UY
M4U%,"B`@("`@*B`@("L@9&]U8FQE('%U;W1E("@\:V)D/B(\+VMB9#XI("TM
M(&1U92!T;R!/<F%C;&4*("`@("`J("`@*R!B<F%C:V5T<R`H/&MB9#Y;/"]K
M8F0^(&]R(#QK8F0^73PO:V)D/BD@+2T@9'5E('1O($%C8V5S<PH@("`@("H*
M("`@("`J($1E;&EM:71E9"!I9&5N=&EF:65R<R!A<F4@:VYO=VX@=&\@9V5N
M97)A;&QY('=O<FL@8V]R<F5C=&QY('5N9&5R"B`@("`@*B!T:&4@9F]L;&]W
M:6YG(&1R:79E<G,Z"B`@("`@*B`@("L@;7-S<6P*("`@("`J("`@*R!M>7-Q
M;`H@("`@("H@("`K(&UY<W%L:0H@("`@("H@("`K(&]C:3@*("`@("`J("`@
M*R!O9&)C*&%C8V5S<RD*("`@("`J("`@*R!O9&)C*&1B,BD*("`@("`J("`@
M*R!P9W-Q;`H@("`@("H@("`K('-Q;&ET90H@("`@("H@("`K('-Y8F%S92`H
M;75S="!E>&5C=71E(#QK8F0^<V5T('%U;W1E9%]I9&5N=&EF:65R(&]N/"]K
M8F0^('-O;65T:6UE"B`@("`@*B`@("`@<')I;W(@=&\@=7-E*0H@("`@("H*
M("`@("`J($EN=&5R0F%S92!D;V5S;B=T('-E96T@=&\@8F4@86)L92!T;R!U
M<V4@9&5L:6UI=&5D(&ED96YT:69I97)S"B`@("`@*B!V:6$@4$A0(#0N("!4
M:&5Y('=O<FL@9FEN92!U;F1E<B!02%`@-2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S='(@('1H92!I9&5N=&EF:65R(&YA;64@=&\@8F4@<75O
M=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!Q=6]T960@
M:61E;G1I9FEE<@H@("`@("H*("`@("`J($!S:6YC92!-971H;V0@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M<75O=&5)9&5N=&EF:65R*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N("<B
M)R`N('-T<E]R97!L86-E*"<B)RP@)R(B)RP@)'-T<BD@+B`G(B<["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&53;6%R="@I"@H@("`@+RHJ
M"B`@("`@*B!&;W)M871S(&EN<'5T('-O(&ET(&-A;B!B92!S869E;'D@=7-E
M9"!I;B!A('%U97)Y"B`@("`@*@H@("`@("H@5&AE(&]U='!U="!D97!E;F1S
M(&]N('1H92!02%`@9&%T82!T>7!E(&]F(&EN<'5T(&%N9"!T:&4@9&%T86)A
M<V4*("`@("`J('1Y<&4@8F5I;F<@=7-E9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&EN("!T:&4@9&%T82!T;R!B92!F;W)M871T960*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T:&4@9F]R;6%T=&5D(&1A=&$N("!4
M:&4@9F]R;6%T(&1E<&5N9',@;VX@=&AE(&EN<'5T)W,*("`@("`J("`@("`@
M("`@("`@("`@("!02%`@='EP93H*("`@("`J(#QU;#X*("`@("`J("`\;&D^
M"B`@("`@*B`@("`\:V)D/FEN<'5T/"]K8F0^("T^(#QS86UP/G)E='5R;G,\
M+W-A;7`^"B`@("`@*B`@/"]L:3X*("`@("`J("`\;&D^"B`@("`@*B`@("`\
M:V)D/FYU;&P\+VMB9#X@+3X@=&AE('-T<FEN9R`\<V%M<#Y.54Q,/"]S86UP
M/@H@("`@("H@(#PO;&D^"B`@("`@*B`@/&QI/@H@("`@("H@("`@/&MB9#YI
M;G1E9V5R/"]K8F0^(&]R(#QK8F0^9&]U8FQE/"]K8F0^("T^('1H92!U;G%U
M;W1E9"!N=6UB97(*("`@("`J("`\+VQI/@H@("`@("H@(#QL:3X*("`@("`J
M("`@(#QK8F0^8F]O;#PO:V)D/B`M/B!O=71P=70@9&5P96YD<R!O;B!T:&4@
M9')I=F5R(&EN('5S90H@("`@("H@("`@36]S="!D<FEV97)S(')E='5R;B!I
M;G1E9V5R<SH@/'-A;7`^,3PO<V%M<#X@:68*("`@("`J("`@(#QK8F0^=')U
M93PO:V)D/B!O<B`\<V%M<#XP/"]S86UP/B!I9@H@("`@("H@("`@/&MB9#YF
M86QS93PO:V)D/BX*("`@("`J("`@(%-O;64@<F5T=7)N('-T<FEN9W,Z(#QS
M86UP/E12544\+W-A;7`^(&EF"B`@("`@*B`@("`\:V)D/G1R=64\+VMB9#X@
M;W(@/'-A;7`^1D%,4T4\+W-A;7`^(&EF"B`@("`@*B`@("`\:V)D/F9A;'-E
M/"]K8F0^+@H@("`@("H@("`@1FEN86QL>2!O;F4@<F5T=7)N<R!S=')I;F=S
M.B`\<V%M<#Y4/"]S86UP/B!I9@H@("`@("H@("`@/&MB9#YT<G5E/"]K8F0^
M(&]R(#QS86UP/D8\+W-A;7`^(&EF"B`@("`@*B`@("`\:V)D/F9A;'-E/"]K
M8F0^+B!(97)E(&ES(&$@;&ES="!O9B!E86-H($1"35,L"B`@("`@*B`@("!T
M:&4@=F%L=65S(')E='5R;F5D(&%N9"!T:&4@<W5G9V5S=&5D(&-O;'5M;B!T
M>7!E.@H@("`@("H@("`@/'5L/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@
M("`@("`@/&MB9#YD8F%S93PO:V)D/B`M/B`\<V%M<#Y4+T8\+W-A;7`^"B`@
M("`@*B`@("`@("`@*#QK8F0^3&]G:6-A;#PO:V)D/BD*("`@("`J("`@("`@
M/"]L:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^9F)A
M<V4\+VMB9#X@+3X@/'-A;7`^5%)512]&04Q313PO<V%M<#X*("`@("`J("`@
M("`@("`H/&MB9#Y"3T],14%./"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@
M("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YI8F%S93PO:V)D
M/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^4TU!
M3$Q)3E0\+VMB9#XI(%LQ70H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@
M("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YI9G@\+VMB9#X@+3X@/'-A;7`^
M,2\P/"]S86UP/@H@("`@("H@("`@("`@("@\:V)D/E--04Q,24Y4/"]K8F0^
M*2!;,5T*("`@("`J("`@("`@/"]L:3X*("`@("`J("`@("`@/&QI/@H@("`@
M("H@("`@("`@(#QK8F0^;7-Q;#PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^
M"B`@("`@*B`@("`@("`@*#QK8F0^24Y414=%4CPO:V)D/BD*("`@("`J("`@
M("`@/"]L:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^
M;7-S<6P\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@("H@("`@("`@
M("@\:V)D/D))5#PO:V)D/BD*("`@("`J("`@("`@/"]L:3X*("`@("`J("`@
M("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^;7ES<6P\+VMB9#X@+3X@/'-A
M;7`^,2\P/"]S86UP/@H@("`@("H@("`@("`@("@\:V)D/E1)3EE)3E0H,2D\
M+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@
M("`J("`@("`@("`\:V)D/FUY<W%L:3PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A
M;7`^"B`@("`@*B`@("`@("`@*#QK8F0^5$E.64E.5"@Q*3PO:V)D/BD*("`@
M("`J("`@("`@/"]L:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@
M(#QK8F0^;V-I.#PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@
M("`@("`@*#QK8F0^3E5-0D52*#$I/"]K8F0^*0H@("`@("H@("`@("`\+VQI
M/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YO9&)C/"]K
M8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y3
M34%,3$E.5#PO:V)D/BD@6S%="B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@
M("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D/G!G<W%L/"]K8F0^("T^(#QS
M86UP/E12544O1D%,4T4\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^0D]/
M3$5!3CPO:V)D/BD*("`@("`J("`@("`@/"]L:3X*("`@("`J("`@("`@/&QI
M/@H@("`@("H@("`@("`@(#QK8F0^<W%L:71E/"]K8F0^("T^(#QS86UP/C$O
M,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y)3E1%1T52/"]K8F0^*0H@
M("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@
M("`@/&MB9#YS>6)A<V4\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@
M("H@("`@("`@("@\:V)D/E1)3EE)3E0H,2D\+VMB9#XI"B`@("`@*B`@("`@
M(#PO;&D^"B`@("`@*B`@("`\+W5L/@H@("`@("H@("`@6S%=($%C8V]M;6]D
M871E('1H92!L;W=E<W0@8V]M;6]N(&1E;F]M:6YA=&]R(&)E8V%U<V4@;F]T
M(&%L;`H@("`@("H@("`@=F5R<VEO;G,@;V8@:&%V92`\:V)D/D)/3TQ%04X\
M+VMB9#XN"B`@("`@*B`@/"]L:3X*("`@("`J("`\;&D^"B`@("`@*B`@("!O
M=&AE<B`H:6YC;'5D:6YG('-T<FEN9W,@86YD(&YU;65R:6,@<W1R:6YG<RD@
M+3X*("`@("`J("`@('1H92!D871A('=I=&@@<VEN9VQE('%U;W1E<R!E<V-A
M<&5D(&)Y('!R96-E961I;F<*("`@("`J("`@('-I;F=L92!Q=6]T97,L(&)A
M8VMS;&%S:&5S(&%R92!E<V-A<&5D(&)Y('!R96-E961I;F<*("`@("`J("`@
M(&)A8VMS;&%S:&5S+"!T:&5N('1H92!W:&]L92!S=')I;F<@:7,@96YC87!S
M=6QA=&5D"B`@("`@*B`@("!B971W965N('-I;F=L92!Q=6]T97,*("`@("`J
M("`\+VQI/@H@("`@("H@/"]U;#X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ97-C87!E4VEM<&QE*"D*("`@("`J($!S:6YC92!-971H;V0@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@<75O=&53;6%R="@D:6XI"B`@("!["B`@("`@("`@:68@*&ES7VEN="@D
M:6XI('Q\(&ES7V1O=6)L92@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`D
M:6X["B`@("`@("`@?2!E;'-E:68@*&ES7V)O;VPH)&EN*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&EN(#\@,2`Z(#`["B`@("`@("`@?2!E;'-E:68@*&ES
M7VYU;&PH)&EN*2D@>PH@("`@("`@("`@("!R971U<FX@)TY53$PG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`B)R(@+B`D=&AI<RT^
M97-C87!E4VEM<&QE*"1I;BD@+B`B)R(["B`@("`@("`@?0H@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&5S8V%P95-I;7!L92@I"@H@("`@+RHJ"B`@
M("`@*B!%<V-A<&5S(&$@<W1R:6YG(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N
M="!$0DU3)W,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@26X@4U%,:71E+"!T
M:&ES(&UA:V5S('1H:6YG<R!S869E(&9O<B!I;G-E<G1S+W5P9&%T97,L(&)U
M="!M87D*("`@("`J(&-A=7-E('!R;V)L96US('=H96X@<&5R9F]R;6EN9R!T
M97AT(&-O;7!A<FES;VYS(&%G86EN<W0@8V]L=6UN<PH@("`@("H@8V]N=&%I
M;FEN9R!B:6YA<GD@9&%T82X@4V5E('1H90H@("`@("H@>T!L:6YK(&AT='`Z
M+R]P:'`N;F5T+W-Q;&ET95]E<V-A<&5?<W1R:6YG(%!(4"!M86YU86Q](&9O
M<B!M;W)E(&EN9F\N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R
M("!T:&4@<W1R:6YG('1O(&)E(&5S8V%P960*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@=&AE(&5S8V%P960@<W1R:6YG"B`@("`@*@H@("`@("H@
M0'-E92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@0'-I;F-E($UE
M=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!E<V-A<&53:6UP;&4H)'-T<BD*("`@('L*("`@("`@("!R
M971U<FX@<W1R7W)E<&QA8V4H(B<B+"`B)R<B+"`D<W1R*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!P<F]V:61E<R@I"@H@("`@+RHJ"B`@("`@
M*B!496QL<R!W:&5T:&5R('1H92!P<F5S96YT(&1R:79E<B!S=7!P;W)T<R!A
M(&=I=F5N(&9E871U<F4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M96%T=7)E("!T:&4@9F5A='5R92!Y;W4G<F4@8W5R:6]U<R!A8F]U=`H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;"`@=VAE=&AE<B!T:&ES(&1R:79E<B!S
M=7!P;W)T<R`D9F5A='5R90H@("`@("HO"B`@("!F=6YC=&EO;B!P<F]V:61E
M<R@D9F5A='5R92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F9E871U
M<F5S6R1F96%T=7)E73L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S
M971&971C:$UO9&4H*0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@9F5T8V@@
M;6]D92!T:&%T('-H;W5L9"!B92!U<V5D(&)Y(&1E9F%U;'0@9F]R('%U97)Y
M(')E<W5L=',*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9F5T8VAM
M;V1E("`@($1"7T9%5$-(34]$15]/4D1%4D5$+"!$0E]&151#2$U/1$5?05-3
M3T,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]R($1"
M7T9%5$-(34]$15]/0DI%0U0*("`@("`J($!P87)A;2!S=')I;F<@)&]B:F5C
M=%]C;&%S<R`@=&AE(&-L87-S(&YA;64@;V8@=&AE(&]B:F5C="!T;R!B92!R
M971U<FYE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8GD@=&AE(&9E=&-H(&UE=&AO9',@=VAE;B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($1"7T9%5$-(34]$15]/0DI%0U0@;6]D
M92!I<R!S96QE8W1E9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($EF(&YO(&-L87-S(&ES('-P96-I9FEE9"!B>2!D969A=6QT(&$@
M8V%S=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@
M;V)J96-T(&9R;VT@=&AE(&%S<V]C(&%R<F%Y(')O=R!W:6QL(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D;VYE+B`@5&AE<F4@
M:7,@86QS;R!T:&4@<&]S:6)I;&ET>2!T;R!U<V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%N9"!E>'1E;F0@=&AE("=$0E]R;W<G
M(&-L87-S+@H@("`@("H*("`@("`J($!S964@1$)?1D540TA-3T1%7T]21$52
M140L($1"7T9%5$-(34]$15]!4U-/0RP@1$)?1D540TA-3T1%7T]"2D5#5`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971&971C:$UO9&4H)&9E=&-H;6]D92P@
M)&]B:F5C=%]C;&%S<R`]("=S=&1#;&%S<R<I"B`@("!["B`@("`@("`@<W=I
M=&-H("@D9F5T8VAM;V1E*2!["B`@("`@("`@("`@(&-A<V4@1$)?1D540TA-
M3T1%7T]"2D5#5#H*("`@("`@("`@("`@("`@("1T:&ES+3YF971C:&UO9&5?
M;V)J96-T7V-L87-S(#T@)&]B:F5C=%]C;&%S<SL*("`@("`@("`@("`@8V%S
M92!$0E]&151#2$U/1$5?3U)$15)%1#H*("`@("`@("`@("`@8V%S92!$0E]&
M151#2$U/1$5?05-33T,Z"B`@("`@("`@("`@("`@("`D=&AI<RT^9F5T8VAM
M;V1E(#T@)&9E=&-H;6]D93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=I;G9A;&ED(&9E=&-H;6]D92!M;V1E)RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-E=$]P=&EO;B@I
M"@H@("`@+RHJ"B`@("`@*B!3971S(')U;BUT:6UE(&-O;F9I9W5R871I;VX@
M;W!T:6]N<R!F;W(@4$5!4B!$0@H@("`@("H*("`@("`J($]P=&EO;G,L('1H
M96ER(&1A=&$@='EP97,L(&1E9F%U;'0@=F%L=65S(&%N9"!D97-C<FEP=&EO
M;CH*("`@("`J(#QU;#X*("`@("`J(#QL:3X*("`@("`J(#QV87(^875T;V9R
M964\+W9A<CX@/&MB9#YB;V]L96%N/"]K8F0^(#T@/'-A;7`^9F%L<V4\+W-A
M;7`^"B`@("`@*B`@("`@(#QB<B`O/G-H;W5L9"!R97-U;'1S(&)E(&9R965D
M(&%U=&]M871I8V%L;'D@=VAE;B!T:&5R92!A<F4@;F\*("`@("`J("`@("`@
M("`@("`@;6]R92!R;W=S/PH@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R
M/G)E<W5L=%]B=69F97)I;F<\+W9A<CX@/&MB9#YI;G1E9V5R/"]K8F0^(#T@
M/'-A;7`^-3`P/"]S86UP/@H@("`@("H@("`@("`\8G(@+SYH;W<@;6%N>2!R
M;W=S(&]F('1H92!R97-U;'0@<V5T('-H;W5L9"!B92!B=69F97)E9#\*("`@
M("`J("`@("`@/&)R("\^26X@;7ES<6PZ(&UY<W%L7W5N8G5F9F5R961?<75E
M<GDH*2!I<R!U<V5D(&EN<W1E860@;V8*("`@("`J("`@("`@("`@("`@;7ES
M<6Q?<75E<GDH*2!I9B!T:&ES('9A;'5E(&ES(#`N("`H4F5L96%S92`Q+C<N
M,"D*("`@("`J("`@("`@/&)R("\^26X@;V-I.#H@=&AI<R!V86QU92!I<R!P
M87-S960@=&\@;V-I<V5T<')E9F5T8V@H*2X*("`@("`J("`@("`@("`@("`@
M*%)E;&5A<V4@,2XW+C`I"B`@("`@*B`\+VQI/CQL:3X*("`@("`J(#QV87(^
M9&5B=6<\+W9A<CX@/&MB9#YI;G1E9V5R/"]K8F0^(#T@/'-A;7`^,#PO<V%M
M<#X*("`@("`J("`@("`@/&)R("\^9&5B=6<@;&5V96P*("`@("`J(#PO;&D^
M/&QI/@H@("`@("H@/'9A<CYP97)S:7-T96YT/"]V87(^(#QK8F0^8F]O;&5A
M;CPO:V)D/B`](#QS86UP/F9A;'-E/"]S86UP/@H@("`@("H@("`@("`\8G(@
M+SYS:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@("`J
M(#PO;&D^/&QI/@H@("`@("H@/'9A<CYP;W)T86)I;&ET>3PO=F%R/B`\:V)D
M/FEN=&5G97(\+VMB9#X@/2`\<V%M<#Y$0E]03U)404))3$E465].3TY%/"]S
M86UP/@H@("`@("H@("`@("`\8G(@+SYP;W)T86)I;&ET>2!M;V1E(&-O;G-T
M86YT("AS964@8F5L;W<I"B`@("`@*B`\+VQI/CQL:3X*("`@("`J(#QV87(^
M<V5Q;F%M95]F;W)M870\+W9A<CX@/&MB9#YS=')I;F<\+VMB9#X@/2`\<V%M
M<#XE<U]S97$\+W-A;7`^"B`@("`@*B`@("`@(#QB<B`O/G1H92!S<')I;G1F
M*"D@9F]R;6%T('-T<FEN9R!U<V5D(&]N('-E<75E;F-E(&YA;65S+B`@5&AI
M<PH@("`@("H@("`@("`@("`@("!F;W)M870@:7,@87!P;&EE9"!T;R!S97%U
M96YC92!N86UE<R!P87-S960@=&\*("`@("`J("`@("`@("`@("`@8W)E871E
M4V5Q=65N8V4H*2P@;F5X=$E$*"D@86YD(&1R;W!397%U96YC92@I+@H@("`@
M("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/G-S;#PO=F%R/B`\:V)D/F)O;VQE
M86X\+VMB9#X@/2`\<V%M<#YF86QS93PO<V%M<#X*("`@("`J("`@("`@/&)R
M("\^=7-E('-S;"!T;R!C;VYN96-T/PH@("`@("H@/"]L:3X*("`@("`J(#PO
M=6P^"B`@("`@*@H@("`@("H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T*("`@("`J"B`@("`@*B!03U)404))3$E462!-3T1%
M4PH@("`@("H*("`@("`J(%1H97-E(&UO9&5S(&%R92!B:71W:7-E9"P@<V\@
M=&AE>2!C86X@8F4@8V]M8FEN960@=7-I;F<@/&MB9#Y\/"]K8F0^"B`@("`@
M*B!A;F0@<F5M;W9E9"!U<VEN9R`\:V)D/EX\+VMB9#XN("!3964@=&AE(&5X
M86UP;&5S('-E8W1I;VX@8F5L;W<@;VX@:&]W"B`@("`@*B!T;R!D;R!T:&ES
M+@H@("`@("H*("`@("`J(#QS86UP/D1"7U!/4E1!0DE,25197TY/3D4\+W-A
M;7`^"B`@("`@*B!T=7)N(&]F9B!A;&P@<&]R=&%B:6QI='D@9F5A='5R97,*
M("`@("`J"B`@("`@*B!4:&ES(&UO9&4@9V5T<R!A=71O;6%T:6-A;&QY('1U
M<FYE9"!O;B!I9B!T:&4@9&5P<F5C871E9`H@("`@("H@/'9A<CYO<'1I;6EZ
M93PO=F%R/B!O<'1I;VX@9V5T<R!S970@=&\@/'-A;7`^<&5R9F]R;6%N8V4\
M+W-A;7`^+@H@("`@("H*("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))
M3$E465],3U=%4D-!4T4\+W-A;7`^"B`@("`@*B!C;VYV97)T(&YA;65S(&]F
M('1A8FQE<R!A;F0@9FEE;&1S('1O(&QO=V5R(&-A<V4@=VAE;B!U<VEN9PH@
M("`@("H@/&MB9#YG970J*"D\+VMB9#XL(#QK8F0^9F5T8V@J*"D\+VMB9#X@
M86YD(#QK8F0^=&%B;&5);F9O*"D\+VMB9#X*("`@("`J"B`@("`@*B!4:&ES
M(&UO9&4@9V5T<R!A=71O;6%T:6-A;&QY('1U<FYE9"!O;B!I;B!T:&4@9F]L
M;&]W:6YG(&1A=&%B87-E<PH@("`@("H@:68@=&AE(&1E<')E8V%T960@;W!T
M:6]N(#QV87(^;W!T:6UI>F4\+W9A<CX@9V5T<R!S970@=&\*("`@("`J(#QS
M86UP/G!O<G1A8FEL:71Y/"]S86UP/CH*("`@("`J("L@;V-I.`H@("`@("H*
M("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))3$E465]25%))33PO<V%M
M<#X*("`@("`J(')I9VAT('1R:6T@=&AE(&1A=&$@;W5T<'5T(&)Y(#QK8F0^
M9V5T*B@I/"]K8F0^(#QK8F0^9F5T8V@J*"D\+VMB9#X*("`@("`J"B`@("`@
M*@H@("`@("H@/'-A;7`^1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4/"]S
M86UP/@H@("`@("H@9F]R8V4@<F5P;W)T:6YG('1H92!N=6UB97(@;V8@<F]W
M<R!D96QE=&5D"B`@("`@*@H@("`@("H@4V]M92!$0DU3)W,@9&]N)W0@8V]U
M;G0@=&AE(&YU;6)E<B!O9B!R;W=S(&1E;&5T960@=VAE;B!P97)F;W)M:6YG
M"B`@("`@*B!S:6UP;&4@/&MB9#Y$14Q%5$4@1E)/32!T86)L96YA;64\+VMB
M9#X@<75E<FEE<RX@(%1H:7,@<&]R=&%B:6QI='D*("`@("`J(&UO9&4@=')I
M8VMS('-U8V@@1$)-4R=S(&EN=&\@=&5L;&EN9R!T:&4@8V]U;G0@8GD@861D
M:6YG"B`@("`@*B`\<V%M<#Y72$5212`Q/3$\+W-A;7`^('1O('1H92!E;F0@
M;V8@/&MB9#Y$14Q%5$4\+VMB9#X@<75E<FEE<RX*("`@("`J"B`@("`@*B!4
M:&ES(&UO9&4@9V5T<R!A=71O;6%T:6-A;&QY('1U<FYE9"!O;B!I;B!T:&4@
M9F]L;&]W:6YG(&1A=&%B87-E<PH@("`@("H@:68@=&AE(&1E<')E8V%T960@
M;W!T:6]N(#QV87(^;W!T:6UI>F4\+W9A<CX@9V5T<R!S970@=&\*("`@("`J
M(#QS86UP/G!O<G1A8FEL:71Y/"]S86UP/CH*("`@("`J("L@9F)S<6P*("`@
M("`J("L@;7ES<6P*("`@("`J("L@;7ES<6QI"B`@("`@*B`K('-Q;&ET90H@
M("`@("H*("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))3$E465].54U2
M3U=3/"]S86UP/@H@("`@("H@96YA8FQE(&AA8VL@=&AA="!M86ME<R`\:V)D
M/FYU;5)O=W,H*3PO:V)D/B!W;W)K(&EN($]R86-L90H@("`@("H*("`@("`J
M(%1H:7,@;6]D92!G971S(&%U=&]M871I8V%L;'D@='5R;F5D(&]N(&EN('1H
M92!F;VQL;W=I;F<@9&%T86)A<V5S"B`@("`@*B!I9B!T:&4@9&5P<F5C871E
M9"!O<'1I;VX@/'9A<CYO<'1I;6EZ93PO=F%R/B!G971S('-E="!T;PH@("`@
M("H@/'-A;7`^<&]R=&%B:6QI='D\+W-A;7`^.@H@("`@("H@*R!O8VDX"B`@
M("`@*@H@("`@("H*("`@("`J(#QS86UP/D1"7U!/4E1!0DE,25197T524D]2
M4SPO<V%M<#X*("`@("`J(&UA:V5S(&-E<G1A:6X@97)R;W(@;65S<V%G97,@
M:6X@8V5R=&%I;B!D<FEV97)S(&-O;7!A=&EB;&4*("`@("`J('=I=&@@=&AO
M<V4@9G)O;2!O=&AE<B!$0DU3)W,*("`@("`J"B`@("`@*B`K(&UY<W%L+"!M
M>7-Q;&DZ("!C:&%N9V4@=6YI<75E+W!R:6UA<GD@:V5Y(&-O;G-T<F%I;G1S
M"B`@("`@*B`@($1"7T524D]27T%,4D5!1%E?15A)4U13("T^($1"7T524D]2
M7T-/3E-44D%)3E0*("`@("`J"B`@("`@*B`K(&]D8F,H86-C97-S*3H@($U3
M)W,@3T1"0R!D<FEV97(@<F5P;W)T<R`G;F\@<W5C:"!F:65L9"<@87,@8V]D
M90H@("`@("H@("`P-S`P,2P@=VAI8V@@;65A;G,@)W1O;R!F97<@<&%R86UE
M=&5R<RXG("!7:&5N('1H:7,@;W!T:6]N(&ES(&]N"B`@("`@*B`@('1H870@
M8V]D92!G971S(&UA<'!E9"!T;R!$0E]%4E)/4E].3U-50TA&245,1"X*("`@
M("`J("`@1$)?15)23U)?34E334%40T@@+3X@1$)?15)23U)?3D]354-(1DE%
M3$0*("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))3$E465].54Q,7U1/
M7T5-4%19/"]S86UP/@H@("`@("H@8V]N=F5R="!N=6QL('9A;'5E<R!T;R!E
M;7!T>2!S=')I;F=S(&EN(&1A=&$@;W5T<'5T(&)Y(&=E="HH*2!A;F0*("`@
M("`J(&9E=&-H*B@I+B`@3F5E9&5D(&)E8V%U<V4@3W)A8VQE(&-O;G-I9&5R
M<R!E;7!T>2!S=')I;F=S('1O(&)E(&YU;&PL"B`@("`@*B!W:&EL92!M;W-T
M(&]T:&5R($1"35,G<R!K;F]W('1H92!D:69F97)E;F-E(&)E='=E96X@96UP
M='D@86YD(&YU;&PN"B`@("`@*@H@("`@("H*("`@("`J(#QS86UP/D1"7U!/
M4E1!0DE,25197T%,3#PO<V%M<#X*("`@("`J('1U<FX@;VX@86QL('!O<G1A
M8FEL:71Y(&9E871U<F5S"B`@("`@*@H@("`@("H@+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*("`@("`J"B`@("`@*B!%>&%M
M<&QE(#$N(%-I;7!L92!S971/<'1I;VXH*2!E>&%M<&QE"B`@("`@*B`\8V]D
M93X*("`@("`J("1D8BT^<V5T3W!T:6]N*"=A=71O9G)E92<L('1R=64I.PH@
M("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($5X86UP;&4@,BX@4&]R=&%B
M:6QI='D@9F]R(&QO=V5R8V%S:6YG(&%N9"!T<FEM;6EN9PH@("`@("H@/&-O
M9&4^"B`@("`@*B`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+`H@("`@
M("H@("`@("`@("`@("`@("`@($1"7U!/4E1!0DE,25197TQ/5T520T%312!\
M($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`J(#PO8V]D93X*("`@("`J
M"B`@("`@*B!%>&%M<&QE(#,N($%L;"!P;W)T86)I;&ET>2!O<'1I;VYS(&5X
M8V5P="!T<FEM;6EN9PH@("`@("H@/&-O9&4^"B`@("`@*B`D9&(M/G-E=$]P
M=&EO;B@G<&]R=&%B:6QI='DG+`H@("`@("H@("`@("`@("`@("`@("`@($1"
M7U!/4E1!0DE,25197T%,3"!>($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@
M("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I
M;VX@;W!T:6]N(&YA;64*("`@("`J($!P87)A;2!M:7AE9"`@)'9A;'5E('9A
M;'5E(&9O<B!T:&4@;W!T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CHD;W!T:6]N<PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S971/<'1I;VXH)&]P=&EO;BP@)'9A;'5E
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<ULD;W!T
M:6]N72DI('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G-;)&]P=&EO;ET@
M/2`D=F%L=64["@H@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!"86-K
M=V%R9',@8V]M<&%T:6)I;&ET>2!C:&5C:R!F;W(@=&AE(&1E<')E8V%T960@
M)V]P=&EM:7IE)PH@("`@("`@("`@("`@*B!O<'1I;VXN("!$;VYE(&AE<F4@
M:6X@8V%S92!S971T:6YG<R!C:&%N9V4@869T97(@8V]N;F5C=&EN9RX*("`@
M("`@("`@("`@("HO"B`@("`@("`@("`@(&EF("@D;W!T:6]N(#T]("=O<'1I
M;6EZ92<I('L*("`@("`@("`@("`@("`@(&EF("@D=F%L=64@/3T@)W!O<G1A
M8FEL:71Y)RD@>PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M
M/G!H<'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G;V-I
M."<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N
M<ULG<&]R=&%B:6QI='DG72`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($1"7U!/4E1!0DE,25197TQ/5T520T%312!\"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($1"7U!/4E1!0DE,25197TY5
M35)/5U,["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`G9F)S<6PG.@H@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("=M>7-Q;"<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)VUY<W%L:2<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W-Q;&ET92<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($1"7U!/4E1!0DE,25197T1%3$5415]#
M3U5.5#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y
M)UT@/2!$0E]03U)404))3$E465].3TY%.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W
M;B!O<'1I;VX@)&]P=&EO;B(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&=E=$]P=&EO;B@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!V
M86QU92!O9B!A;B!O<'1I;VX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1O<'1I;VX@('1H92!O<'1I;VX@;F%M92!Y;W4G<F4@8W5R:6]U<R!A8F]U
M=`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@('1H92!O<'1I;VXG<R!V
M86QU90H@("`@("HO"B`@("!F=6YC=&EO;B!G971/<'1I;VXH)&]P=&EO;BD*
M("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;)&]P=&EO
M;ETI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;W!T:6]N<ULD;W!T
M:6]N73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")U;FMN;W=N(&]P=&EO;B`D;W!T:6]N(BD["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<')E<&%R92@I"@H@("`@+RHJ"B`@("`@*B!0<F5P
M87)E<R!A('%U97)Y(&9O<B!M=6QT:7!L92!E>&5C=71I;VX@=VET:"!E>&5C
M=71E*"D*("`@("`J"B`@("`@*B!#<F5A=&5S(&$@<75E<GD@=&AA="!C86X@
M8F4@<G5N(&UU;'1I<&QE('1I;65S+B`@16%C:"!T:6UE(&ET(&ES(')U;BP*
M("`@("`J('1H92!P;&%C96AO;&1E<G,L(&EF(&%N>2P@=VEL;"!B92!R97!L
M86-E9"!B>2!T:&4@8V]N=&5N=',@;V8*("`@("`J(&5X96-U=&4H*2=S("1D
M871A(&%R9W5M96YT+@H@("`@("H*("`@("`J(%1H<F5E('1Y<&5S(&]F('!L
M86-E:&]L9&5R<R!C86X@8F4@=7-E9#H*("`@("`J("`@*R`\:V)D/C\\+VMB
M9#X@('-C86QA<B!V86QU92`H:2YE+B!S=')I;F=S+"!I;G1E9V5R<RDN("!4
M:&4@<WES=&5M"B`@("`@*B`@("`@("`@("`@("`@("`@("!W:6QL(&%U=&]M
M871I8V%L;'D@<75O=&4@86YD(&5S8V%P92!T:&4@9&%T82X*("`@("`J("`@
M*R`\:V)D/B$\+VMB9#X@('9A;'5E(&ES(&EN<V5R=&5D("=A<R!I<R<*("`@
M("`J("`@*R`\:V)D/B8\+VMB9#X@(')E<75I<F5S(&$@9FEL92!N86UE+B`@
M5&AE(&9I;&4G<R!C;VYT96YT<R!G970*("`@("`J("`@("`@("`@("`@("`@
M("`@(&EN<V5R=&5D(&EN=&\@=&AE('%U97)Y("AI+F4N('-A=FEN9R!B:6YA
M<GD*("`@("`J("`@("`@("`@("`@("`@("`@(&1A=&$@:6X@82!D8BD*("`@
M("`J"B`@("`@*B!%>&%M<&QE(#$N"B`@("`@*B`\8V]D93X*("`@("`J("1S
M=&@@/2`D9&(M/G!R97!A<F4H)TE.4T525"!)3E1/('1B;"`H82P@8BP@8RD@
M5D%,5453("@_+"`A+"`F*2<I.PH@("`@("H@)&1A=&$@/2!A<G)A>2@*("`@
M("`J("`@("`B2F]H;B=S('1E>'0B+`H@("`@("H@("`@("(G:70G)W,@9V]O
M9"<B+`H@("`@("H@("`@("=F:6QE;F%M92YT>'0G"B`@("`@*B`I.PH@("`@
M("H@)')E<R`]("1D8BT^97AE8W5T92@D<W1H+"`D9&%T82D["B`@("`@*B`\
M+V-O9&4^"B`@("`@*@H@("`@("H@57-E(&)A8VMS;&%S:&5S('1O(&5S8V%P
M92!P;&%C96AO;&1E<B!C:&%R86-T97)S(&EF('EO=2!D;VXG="!W86YT"B`@
M("`@*B!T:&5M('1O(&)E(&EN=&5R<')E=&5D(&%S('!L86-E:&]L9&5R<SH*
M("`@("`J(#QP<F4^"B`@("`@*B`@("`B55!$051%(&9O;R!3150@8V]L/3\@
M5TA%4D4@8V]L/2=O=F5R(%PF('5N9&5R)R(*("`@("`J(#PO<')E/@H@("`@
M("H*("`@("`J(%=I=&@@<V]M92!D871A8F%S92!B86-K96YD<RP@=&AI<R!I
M<R!E;75L871E9"X*("`@("`J"B`@("`@*B![0&EN=&5R;F%L(&EB87-E(&%N
M9"!O8VDX(&AA=F4@=&AE:7(@;W=N('!R97!A<F4H*2!M971H;V1S+GU]"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@('1H92!Q=65R>2!T
M;R!B92!P<F5P87)E9`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($1"
M('-T871E;65N="!R97-O=7)C92!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B
M:F5C=`H@("`@("H@("`@("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F5X96-U=&4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!P<F5P87)E*"1Q=65R>2D*("`@('L*("`@("`@("`D=&]K
M96YS("`@/2!P<F5G7W-P;&ET*"<O*"@_/"%<7%PI6R8_(5TI+R<L("1Q=65R
M>2P@+3$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!04D5'7U-0
M3$E47T1%3$E-7T-!4%154D4I.PH@("`@("`@("1T;VME;B`@("`@/2`P.PH@
M("`@("`@("1T>7!E<R`@("`@/2!A<G)A>2@I.PH@("`@("`@("1N97=T;VME
M;G,@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D=&]K96YS(&%S("1V
M86PI('L*("`@("`@("`@("`@<W=I=&-H("@D=F%L*2!["B`@("`@("`@("`@
M("`@("!C87-E("<_)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O
M:V5N*RM=(#T@1$)?4$%204U?4T-!3$%2.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G)B<Z"B`@("`@("`@("`@
M("`@("`@("`@)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-7T]005%513L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@)R$G.@H@("`@("`@("`@("`@("`@("`@("1T>7!E<ULD=&]K96XK*UT@
M/2!$0E]005)!35]-25-#.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`D
M;F5W=&]K96YS6UT@/2!P<F5G7W)E<&QA8V4H)R]<7%PH6R8_(5TI+R<L(")<
M7#$B+"`D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/G!R97!A<F5?=&]K96YS6UT@/2`F)&YE=W1O:V5N<SL*("`@("`@
M("!E;F0H)'1H:7,M/G!R97!A<F5?=&]K96YS*3L*"B`@("`@("`@)&L@/2!K
M97DH)'1H:7,M/G!R97!A<F5?=&]K96YS*3L*("`@("`@("`D=&AI<RT^<')E
M<&%R95]T>7!E<ULD:UT@/2`D='EP97,["B`@("`@("`@)'1H:7,M/G!R97!A
M<F5D7W%U97)I97-;)&M=(#T@:6UP;&]D92@G("<L("1N97=T;VME;G,I.PH*
M("`@("`@("!R971U<FX@)&L["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@875T;U!R97!A<F4H*0H*("`@("\J*@H@("`@("H@075T;VUA=&EC86QY
M(&=E;F5R871E<R!A;B!I;G-E<G0@;W(@=7!D871E('%U97)Y(&%N9"!P87-S
M(&ET('1O('!R97!A<F4H*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1A8FQE("`@("`@("`@=&AE('1A8FQE(&YA;64*("`@("`J($!P87)A;2!A
M<G)A>2`@)'1A8FQE7V9I96QD<R`@=&AE(&%R<F%Y(&]F(&9I96QD(&YA;65S
M"B`@("`@*B!`<&%R86T@:6YT("`@("1M;V1E("`@("`@("`@(&$@='EP92!O
M9B!Q=65R>2!T;R!M86ME.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@1$)?05543U%515)97TE.4T525"!O<B!$0E]!551/455%4EE?
M55!$051%"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:&5R92`@("`@("`@(&9O
M<B!U<&1A=&4@<75E<FEE<SH@=&AE(%=(15)%(&-L875S92!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P96YD('1O('1H92!3
M44P@<W1A=&5M96YT+B`@1&]N)W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@=&AE(")72$5212(@:V5Y=V]R9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(')E<V]U<F-E("!T:&4@<75E<GD@:&%N9&QE
M"B`@("`@*@H@("`@("H@0'5S97,@1$)?8V]M;6]N.CIP<F5P87)E*"DL($1"
M7V-O;6UO;CHZ8G5I;&1-86YI<%-13"@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%U=&]0<F5P87)E*"1T86)L92P@)'1A8FQE7V9I96QD<RP@)&UO9&4@/2!$
M0E]!551/455%4EE?24Y315)4+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'=H97)E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M
M/F)U:6QD36%N:7!344PH)'1A8FQE+"`D=&%B;&5?9FEE;&1S+"`D;6]D92P@
M)'=H97)E*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'%U97)Y*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1H:7,M/G!R97!A<F4H)'%U97)Y*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!A=71O17AE8W5T92@I"@H@("`@+RHJ"B`@("`@*B!!
M=71O;6%T:6-A;'D@9V5N97)A=&5S(&%N(&EN<V5R="!O<B!U<&1A=&4@<75E
M<GD@86YD(&-A;&P@<')E<&%R92@I"B`@("`@*B!A;F0@97AE8W5T92@I('=I
M=&@@:70*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@
M("`@('1H92!T86)L92!N86UE"B`@("`@*B!`<&%R86T@87)R87D@("1F:65L
M9'-?=F%L=65S('1H92!A<W-O8VEA=&EV92!A<G)A>2!W:&5R92`D:V5Y(&ES
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I96QD
M(&YA;64@86YD("1V86QU92!I=',@=F%L=64*("`@("`J($!P87)A;2!I;G0@
M("`@)&UO9&4@("`@("`@("`@82!T>7!E(&]F('%U97)Y('1O(&UA:V4Z"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$0E]!551/455%
M4EE?24Y315)4(&]R($1"7T%55$]1545265]54$1!5$4*("`@("`J($!P87)A
M;2!S=')I;F<@)'=H97)E("`@("`@("`@9F]R('5P9&%T92!Q=65R:65S.B!T
M:&4@5TA%4D4@8VQA=7-E('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<'!E;F0@=&\@=&AE(%-13"!S=&%T96UE;G0N("!$;VXG
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5D
M92!T:&4@(E=(15)%(B!K97EW;W)D+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(&$@;F5W($1"7W)E<W5L="!O8FIE8W0@9F]R('-U8V-E<W-F=6P@
M4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("!O<B!$0E]/
M2R!F;W(@<W5C8V5S<W5L(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`=7-E<R!$0E]C;VUM;VXZ.F%U=&]0<F5P
M87)E*"DL($1"7V-O;6UO;CHZ97AE8W5T92@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%U=&]%>&5C=71E*"1T86)L92P@)&9I96QD<U]V86QU97,L("1M;V1E
M(#T@1$)?05543U%515)97TE.4T525"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1W:&5R92`](&9A;'-E*0H@("`@>PH@("`@("`@("1S=&@@/2`D=&AI
M<RT^875T;U!R97!A<F4H)'1A8FQE+"!A<G)A>5]K97ES*"1F:65L9'-?=F%L
M=65S*2P@)&UO9&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=VAE<F4I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<W1H*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'-T:#L*("`@("`@("!]"B`@("`@("`@)')E
M="`])B`D=&AI<RT^97AE8W5T92@D<W1H+"!A<G)A>5]V86QU97,H)&9I96QD
M<U]V86QU97,I*3L*("`@("`@("`D=&AI<RT^9G)E95!R97!A<F5D*"1S=&@I
M.PH@("`@("`@(')E='5R;B`D<F5T.PH*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!B=6EL9$UA;FEP4U%,*"D*"B`@("`O*BH*("`@("`J(%!R;V1U
M8V5S(&%N(%-13"!Q=65R>2!S=')I;F<@9F]R(&%U=&]0<F5P87)E*"D*("`@
M("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H@/'!R93X*("`@("`J(&)U:6QD
M36%N:7!344PH)W1A8FQE7W-Q;"<L(&%R<F%Y*"=F:65L9#$G+"`G9FEE;&0R
M)RP@)V9I96QD,R<I+`H@("`@("H@("`@("`@("`@("`@("!$0E]!551/455%
M4EE?24Y315)4*3L*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J(%1H870@
M<F5T=7)N<PH@("`@("H@/'-A;7`^"B`@("`@*B!)3E-%4E0@24Y43R!T86)L
M95]S<6P@*&9I96QD,2QF:65L9#(L9FEE;&0S*2!604Q515,@*#\L/RP_*0H@
M("`@("H@/"]S86UP/@H@("`@("H*("`@("`J($Y/5$53.@H@("`@("H@("`M
M(%1H:7,@8F5L;VYG<R!M;W)E('1O(&$@4U%,($)U:6QD97(@8VQA<W,L(&)U
M="!T:&ES(&ES(&$@<VEM<&QE"B`@("`@*B`@("`@9F%C:6QI='DN"B`@("`@
M*B`@("T@0F4@8V%R969U;&PA($EF('EO=2!D;VXG="!G:79E(&$@)'=H97)E
M('!A<F%M('=I=&@@86X@55!$051%"B`@("`@*B`@("`@<75E<GDL(&%L;"!T
M:&4@<F5C;W)D<R!O9B!T:&4@=&%B;&4@=VEL;"!B92!U<&1A=&5D(0H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A8FQE("`@("`@("`@=&AE('1A
M8FQE(&YA;64*("`@("`J($!P87)A;2!A<G)A>2`@)'1A8FQE7V9I96QD<R`@
M=&AE(&%R<F%Y(&]F(&9I96QD(&YA;65S"B`@("`@*B!`<&%R86T@:6YT("`@
M("1M;V1E("`@("`@("`@(&$@='EP92!O9B!Q=65R>2!T;R!M86ME.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$)?05543U%515)9
M7TE.4T525"!O<B!$0E]!551/455%4EE?55!$051%"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1W:&5R92`@("`@("`@(&9O<B!U<&1A=&4@<75E<FEE<SH@=&AE
M(%=(15)%(&-L875S92!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87!P96YD('1O('1H92!344P@<W1A=&5M96YT+B`@1&]N)W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&4@
M=&AE(")72$5212(@:V5Y=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@=&AE('-Q;"!Q=65R>2!F;W(@875T;U!R97!A<F4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!B=6EL9$UA;FEP4U%,*"1T86)L92P@)'1A8FQE7V9I
M96QD<RP@)&UO9&4L("1W:&5R92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("AC;W5N="@D=&%B;&5?9FEE;&1S*2`]/2`P*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%4
M02D["B`@("`@("`@?0H@("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@
M<W=I=&-H("@D;6]D92D@>PH@("`@("`@("`@("!C87-E($1"7T%55$]15452
M65])3E-%4E0Z"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@)R<["B`@("`@
M("`@("`@("`@("`D;F%M97,@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1T86)L95]F:65L9',@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1F:7)S="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M9FER<W0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;F%M97,@+CT@)RPG.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=65S("X]("<L)SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&YA;65S("X]("1V86QU
M93L*("`@("`@("`@("`@("`@("`@("`D=F%L=65S("X]("<_)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`B24Y315)4($E.
M5$\@)'1A8FQE("@D;F%M97,I(%9!3%5%4R`H)'9A;'5E<RDB.PH@("`@("`@
M("`@("!C87-E($1"7T%55$]1545265]54$1!5$4Z"B`@("`@("`@("`@("`@
M("`D<V5T(#T@)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&%B;&5?
M9FEE;&1S(&%S("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M9FER<W0I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L
M<V4["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-E="`N/2`G+"<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1S970@+CT@(B1V86QU92`](#\B.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-Q;"`](")54$1!
M5$4@)'1A8FQE(%-%5"`D<V5T(CL*("`@("`@("`@("`@("`@(&EF("@D=VAE
M<F4I('L*("`@("`@("`@("`@("`@("`@("`D<W%L("X]("(@5TA%4D4@)'=H
M97)E(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R
M;B`D<W%L.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27U-93E1!6"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5X96-U=&4H
M*0H*("`@("\J*@H@("`@("H@17AE8W5T97,@82!$0B!S=&%T96UE;G0@<')E
M<&%R960@=VET:"!P<F5P87)E*"D*("`@("`J"B`@("`@*B!%>&%M<&QE(#$N
M"B`@("`@*B`\8V]D93X*("`@("`J("1S=&@@/2`D9&(M/G!R97!A<F4H)TE.
M4T525"!)3E1/('1B;"`H82P@8BP@8RD@5D%,5453("@_+"`A+"`F*2<I.PH@
M("`@("H@)&1A=&$@/2!A<G)A>2@*("`@("`J("`@("`B2F]H;B=S('1E>'0B
M+`H@("`@("H@("`@("(G:70G)W,@9V]O9"<B+`H@("`@("H@("`@("=F:6QE
M;F%M92YT>'0G"B`@("`@*B`I.PH@("`@("H@)')E<R`])B`D9&(M/F5X96-U
M=&4H)'-T:"P@)&1A=&$I.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<W1M="`@82!$0B!S=&%T96UE;G0@<F5S;W5R
M8V4@<F5T=7)N960@9G)O;2!P<F5P87)E*"D*("`@("`J($!P87)A;2!M:7AE
M9"`@("`D9&%T82`@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@
M8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@97AE
M8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T
M8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E
M<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE
M;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@82!N97<@1$)?<F5S
M=6QT(&]B:F5C="!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@
M("H@("`@("`@("`@("`@("`@(&]R($1"7T]+(&9O<B!S=6-C97-S=6P@9&%T
M82!M86YI<'5L871I;VX@<75E<FEE<RX*("`@("`J("`@("`@("`@("`@("`@
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J
M('M`:6YT97)N86P@:6)A<V4@86YD(&]C:3@@:&%V92!T:&5I<B!O=VX@97AE
M8W5T92@I(&UE=&AO9',N?7T*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ<')E<&%R92@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9E>&5C=71E*"1S
M=&UT+"`D9&%T82`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)')E86QQ=65R
M>2`]("1T:&ES+3YE>&5C=71E16UU;&%T95%U97)Y*"1S=&UT+"`D9&%T82D[
M"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R96%L<75E<GDI*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5A;'%U97)Y.PH@("`@("`@('T*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/G-I;7!L95%U97)Y*"1R96%L<75E<GDI.PH*("`@
M("`@("!I9B`H)')E<W5L="`]/3T@1$)?3TL@?'P@1$(Z.FES17)R;W(H)')E
M<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1M<"`])B!N97<@1$)?<F5S=6QT*"1T
M:&ES+"`D<F5S=6QT*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@
M("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5X96-U=&5%;75L
M871E475E<GDH*0H*("`@("\J*@H@("`@("H@16UU;&%T97,@97AE8W5T:6YG
M('!R97!A<F5D('-T871E;65N=',@:68@=&AE($1"35,@;F]T('-U<'!O<G0@
M=&AE;0H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<W1M="`@82!$
M0B!S=&%T96UE;G0@<F5S;W5R8V4@<F5T=7)N960@9G)O;2!E>&5C=71E*"D*
M("`@("`J($!P87)A;2!M:7AE9"`@("`D9&%T82`@87)R87DL('-T<FEN9R!O
M<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1
M=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE
M86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD
M97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@<F5A;"!Q=65R>2!R=6X@
M=VAE;B!E;75L871I;F<*("`@("`J("`@("`@("`@("`@("`@("!P<F5P87)E
M+V5X96-U=&4N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ97AE8W5T92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X96-U=&5%
M;75L871E475E<GDH)'-T;70L("1D871A(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D<W1M="`]("AI;G0I)'-T;70["B`@("`@("`@)&1A=&$@/2`H87)R
M87DI)&1A=&$["B`@("`@("`@)'1H:7,M/FQA<W1?<&%R86UE=&5R<R`]("1D
M871A.PH*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/G!R97!A<F5?='EP97-;
M)'-T;71=*2`A/2!C;W5N="@D9&%T82DI('L*("`@("`@("`@("`@)'1H:7,M
M/FQA<W1?<75E<GD@/2`D=&AI<RT^<')E<&%R961?<75E<FEE<ULD<W1M=%T[
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E]-25--051#2"D["B`@("`@("`@?0H*("`@("`@("`D<F5A;'%U97)Y(#T@
M)'1H:7,M/G!R97!A<F5?=&]K96YS6R1S=&UT75LP73L*"B`@("`@("`@)&D@
M/2`P.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1V86QU92D@>PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/G!R97!A<F5?='EP97-;)'-T;71=6R1I72`]
M/2!$0E]005)!35]30T%,05(I('L*("`@("`@("`@("`@("`@("1R96%L<75E
M<GD@+CT@)'1H:7,M/G%U;W1E4VUA<G0H)'9A;'5E*3L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3YP<F5P87)E7W1Y<&5S6R1S=&UT75LD:5T@/3T@
M1$)?4$%204U?3U!!455%*2!["B`@("`@("`@("`@("`@("`D9G`@/2!`9F]P
M96XH)'9A;'5E+"`G<F(G*3L*("`@("`@("`@("`@("`@(&EF("@A)&9P*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*$1"7T524D]27T%#0T534U]624],051)3TXI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)')E86QQ=65R>2`N/2`D=&AI<RT^<75O=&53
M;6%R="AF<F5A9"@D9G`L(&9I;&5S:7IE*"1V86QU92DI*3L*("`@("`@("`@
M("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)')E86QQ=65R>2`N/2`D=F%L=64["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1R96%L<75E<GD@+CT@)'1H:7,M/G!R97!A<F5?
M=&]K96YS6R1S=&UT75LK*R1I73L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5A;'%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5X
M96-U=&5-=6QT:7!L92@I"@H@("`@+RHJ"B`@("`@*B!097)F;W)M<R!S979E
M<F%L(&5X96-U=&4H*2!C86QL<R!O;B!T:&4@<V%M92!S=&%T96UE;G0@:&%N
M9&QE"B`@("`@*@H@("`@("H@)&1A=&$@;75S="!B92!A;B!A<G)A>2!I;F1E
M>&5D(&YU;65R:6-A;&QY"B`@("`@*B!F<F]M(#`L(&]N92!E>&5C=71E(&-A
M;&P@:7,@9&]N92!F;W(@979E<GD@(G)O=R(@:6X@=&AE(&%R<F%Y+@H@("`@
M("H*("`@("`J($EF(&%N(&5R<F]R(&]C8W5R<R!D=7)I;F<@97AE8W5T92@I
M+"!E>&5C=71E375L=&EP;&4H*2!D;V5S(&YO=`H@("`@("H@97AE8W5T92!T
M:&4@=6YF:6YI<VAE9"!R;W=S+"!B=70@<F%T:&5R(')E='5R;G,@=&AA="!E
M<G)O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)'-T;70@('%U
M97)Y(&AA;F1L92!F<F]M('!R97!A<F4H*0H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@("1D871A("!N=6UE<FEC(&%R<F%Y(&-O;G1A:6YI;F<@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!D871A('1O(&EN<V5R="!I;G1O
M('1H92!Q=65R>0H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O
M;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<')E<&%R92@I+"!$0E]C;VUM
M;VXZ.F5X96-U=&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!E>&5C=71E375L
M=&EP;&4H)'-T;70L("1D871A*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1D
M871A(&%S("1V86QU92D@>PH@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YE
M>&5C=71E*"1S=&UT+"`D=F%L=64I.PH@("`@("`@("`@("!I9B`H1$(Z.FES
M17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4')E<&%R960H*0H*
M("`@("\J*@H@("`@("H@1G)E97,@=&AE(&EN=&5R;F%L(')E<V]U<F-E<R!A
M<W-O8VEA=&5D('=I=&@@82!P<F5P87)E9"!Q=65R>0H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<W1M="`@("`@("`@("`@=&AE('!R97!A<F5D
M('-T871E;65N="=S(%!(4"!R97-O=7)C90H@("`@("H@0'!A<F%M(&)O;VP@
M("`@("1F<F5E7W)E<V]U<F-E("!S:&]U;&0@=&AE(%!(4"!R97-O=7)C92!B
M92!F<F5E9"!T;V\_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!5<V4@9F%L<V4@:68@>6]U(&YE960@=&\@9V5T(&1A=&$*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9R;VT@=&AE
M(')E<W5L="!S970@;&%T97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI
M9`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIP<F5P87)E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9G)E95!R97!A<F5D*"1S=&UT+"`D9G)E95]R
M97-O=7)C92`]('1R=64I"B`@("!["B`@("`@("`@)'-T;70@/2`H:6YT*21S
M=&UT.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<')E<&%R95]T;VME;G-;
M)'-T;71=*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^<')E<&%R95]T
M;VME;G-;)'-T;71=*3L*("`@("`@("`@("`@=6YS970H)'1H:7,M/G!R97!A
M<F5?='EP97-;)'-T;71=*3L*("`@("`@("`@("`@=6YS970H)'1H:7,M/G!R
M97!A<F5D7W%U97)I97-;)'-T;71=*3L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE1=65R>2@I"@H@("`@+RHJ"B`@
M("`@*B!#:&%N9V5S(&$@<75E<GD@<W1R:6YG(&9O<B!V87)I;W5S($1"35,@
M<W!E8VEF:6,@<F5A<V]N<PH@("`@("H*("`@("`J($ET(&ES(&1E9FEN960@
M:&5R92!T;R!E;G-U<F4@86QL(&1R:79E<G,@:&%V92!T:&ES(&UE=&AO9"!A
M=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@
M('1H92!Q=65R>2!S=')I;F<@=&\@;6]D:69Y"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!M;V1I9FEE9"!Q=65R>2!S=')I;F<*("`@("`J
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]M>7-Q
M;#HZ;6]D:69Y475E<GDH*2P@1$)?;V-I.#HZ;6]D:69Y475E<GDH*2P*("`@
M("`J("`@("`@1$)?<W%L:71E.CIM;V1I9GE1=65R>2@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&UO9&EF>5%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("!R
M971U<FX@)'%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO
M9&EF>4QI;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C
M;&%U<V5S('1O(&$@<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT
M($1"35,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@270@:7,@9&5F:6YE9"!H
M97)E('1O(&%S<W5R92!T:&%T(&%L;"!I;7!L96UE;G1A=&EO;G,*("`@("`J
M(&AA=F4@=&AI<R!M971H;V0@9&5F:6YE9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M;V1I9GD*("`@("`J
M($!P87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R="!T;R!F
M971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`<&%R86T@:6YT
M("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*("`@
M("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O<B!N
M=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N
M=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI
M;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD97(@
M<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C;&%U<V5S(&%D9&5D
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@
M9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U
M;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E='5R;B`D
M<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75E<GDH*0H*
M("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@
M<V5R=F5R"B`@("`@*@H@("`@("H@5&AE('%U97)Y('-T<FEN9R!C86X@8F4@
M96ET:&5R(&$@;F]R;6%L('-T871E;65N="!T;R!B92!S96YT(&1I<F5C=&QY
M"B`@("`@*B!T;R!T:&4@<V5R=F5R($]2(&EF(#QV87(^)'!A<F%M<SPO=F%R
M/B!A<F4@<&%S<V5D('1H92!Q=65R>2!C86X@:&%V90H@("`@("H@<&QA8V5H
M;VQD97)S(&%N9"!I="!W:6QL(&)E('!A<W-E9"!T:')O=6=H('!R97!A<F4H
M*2!A;F0@97AE8W5T92@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'%U97)Y("`@=&AE(%-13"!Q=65R>2!O<B!T:&4@<W1A=&5M96YT('1O('!R
M97!A<F4*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T
M<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE
M;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H
M;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R
M>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA
M8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@82!N97<@1$)?<F5S=6QT(&]B:F5C="!F;W(@<W5C8V5S
M<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@(&]R
M($1"7T]+(&9O<B!S=6-C97-S=6P@9&%T82!M86YI<'5L871I;VX@<75E<FEE
M<RX*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT+"!$0E]C
M;VUM;VXZ.G!R97!A<F4H*2P@1$)?8V]M;6]N.CIE>&5C=71E*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G%U97)Y*"1Q=65R>2P@)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`^(#`I('L*
M("`@("`@("`@("`@)'-T:"`]("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["B`@
M("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1S=&@["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)')E="`])B`D=&AI<RT^97AE8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@
M("`@("`@)'1H:7,M/F9R9650<F5P87)E9"@D<W1H+"!F86QS92D["B`@("`@
M("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YL87-T7W!A<F%M971E<G,@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/G-I;7!L95%U97)Y*"1Q=65R>2D["B`@
M("`@("`@("`@(&EF("@D<F5S=6QT(#T]/2!$0E]/2R!\?"!$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&UP(#TF
M(&YE=R!$0E]R97-U;'0H)'1H:7,L("1R97-U;'0I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T;7`["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;&EM:711=65R>2@I"@H@("`@+RHJ
M"B`@("`@*B!'96YE<F%T97,@86YD(&5X96-U=&5S(&$@3$E-250@<75E<GD*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R
M>0H@("`@("H@0'!A<F%M(&EN='(@("`D9G)O;2`@("!T:&4@<F]W('1O('-T
M87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T(')O=RD*("`@("`J($!P
M87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E<G,@;V8@<F]W<R!T;R!F
M971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A<G)A>2P@<W1R
M:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N
M="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO
M;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('%U97)Y
M.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C
M96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!A(&YE=R!$0E]R97-U;'0@;V)J96-T(&9O<B!S=6-C97-S
M9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`@;W(@
M1$)?3TL@9F]R('-U8V-E<W-U;"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S
M+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9L:6UI=%%U97)Y*"1Q
M=65R>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>4QI;6ET475E<GDH)'%U
M97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US*3L*("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)'%U97)Y*2E["B`@("`@("`@("`@(')E='5R;B`D<75E<GD[
M"B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y*"1Q
M=65R>2P@)'!A<F%M<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)T1"
M7W)E<W5L="<I*2!["B`@("`@("`@("`@("1R97-U;'0M/G-E=$]P=&EO;B@G
M;&EM:71?9G)O;2<L("1F<F]M*3L*("`@("`@("`@("`@)')E<W5L="T^<V5T
M3W!T:6]N*"=L:6UI=%]C;W5N="<L("1C;W5N="D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&=E=$]N92@I"@H@("`@+RHJ"B`@("`@*B!&971C:&5S('1H92!F:7)S
M="!C;VQU;6X@;V8@=&AE(&9I<G-T(')O=R!F<F]M(&$@<75E<GD@<F5S=6QT
M"B`@("`@*@H@("`@("H@5&%K97,@8V%R92!O9B!D;VEN9R!T:&4@<75E<GD@
M86YD(&9R965I;F<@=&AE(')E<W5L=',@=VAE;B!F:6YI<VAE9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H92!344P@<75E<GD*
M("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O
M<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1
M=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE
M86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD
M97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@=&AE(')E='5R;F5D('9A;'5E(&]F('1H92!Q=65R>2X*("`@("`J
M("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T3VYE*"1Q=65R>2P@)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'!A<F%M<R`]("AA<G)A>2DD
M<&%R86US.PH@("`@("`@("\O(&UO9&EF>4QI;6ET475E<GDH*2!W;W5L9"!B
M92!N:6-E(&AE<F4L(&)U="!I="!C875S97,@0D,@:7-S=65S"B`@("`@("`@
M:68@*'-I>F5O9B@D<&%R86US*2`^(#`I('L*("`@("`@("`@("`@)'-T:"`]
M("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["B`@("`@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&@[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^97AE
M8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@("`@("`@)'1H:7,M/F9R9650
M<F5P87)E9"@D<W1H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<F5S(#TF("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&5R<B`]("1R97,M/F9E=&-H
M26YT;R@D<F]W+"!$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@)')E
M<RT^9G)E92@I.PH*("`@("`@("!I9B`H)&5R<B`A/3T@1$)?3TLI('L*("`@
M("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)')O=ULP73L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9712
M;W<H*0H*("`@("\J*@H@("`@("H@1F5T8VAE<R!T:&4@9FER<W0@<F]W(&]F
M(&1A=&$@<F5T=7)N960@9G)O;2!A('%U97)Y(')E<W5L=`H@("`@("H*("`@
M("`J(%1A:V5S(&-A<F4@;V8@9&]I;F<@=&AE('%U97)Y(&%N9"!F<F5E:6YG
M('1H92!R97-U;'1S('=H96X@9FEN:7-H960N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<75E<GD@("!T:&4@4U%,('%U97)Y"B`@("`@*B!`<&%R
M86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D
M871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@
M:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M
M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA
M8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A
M>2!E;&5M96YT+@H@("`@("H@0'!A<F%M(&EN="`D9F5T8VAM;V1E("!T:&4@
M9F5T8V@@;6]D92!T;R!U<V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!T:&4@9FER<W0@<F]W(&]F(')E<W5L=',@87,@86X@87)R87DN"B`@("`@
M*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%)O=R@D<75E<GDL("1P87)A
M;7,@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`D9F5T8VAM;V1E
M(#T@1$)?1D540TA-3T1%7T1%1D%53%0I"B`@("!["B`@("`@("`@+R\@8V]M
M<&%T(&-H96-K+"!T:&4@<&%R86US(&%N9"!F971C:&UO9&4@<&%R86UE=&5R
M<R!U<V5D('1O"B`@("`@("`@+R\@:&%V92!T:&4@;W!P;W-I=&4@;W)D97(*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D9F5T8VAM;V1E*2D@>PH@("`@("`@("`@("`@("`@
M:68@*"1P87)A;7,@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("`D
M=&UP(#T@1$)?1D540TA-3T1%7T1%1D%53%0["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2`D<&%R86US.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!A<F%M<R`]("1F
M971C:&UO9&4["B`@("`@("`@("`@("`@("`D9F5T8VAM;V1E(#T@)'1M<#L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;7,@(3T](&YU;&PI('L*("`@
M("`@("`@("`@("`@("1F971C:&UO9&4@/2`D<&%R86US.PH@("`@("`@("`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@+R\@;6]D:69Y3&EM:711=65R>2@I('=O=6QD(&)E(&YI
M8V4@:&5R92P@8G5T(&ET(&-A=7-E<R!"0R!I<W-U97,*("`@("`@("!I9B`H
M<VEZ96]F*"1P87)A;7,I(#X@,"D@>PH@("`@("`@("`@("`D<W1H(#T@)'1H
M:7,M/G!R97!A<F4H)'%U97)Y*3L*("`@("`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1S=&@I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-T:#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YE>&5C=71E
M*"1S=&@L("1P87)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A
M<F5D*"1S=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97,@
M/28@)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97,["B`@("`@("`@?0H*("`@("`@("`D97)R(#T@)')E<RT^9F5T8VA);G1O
M*"1R;W<L("1F971C:&UO9&4I.PH*("`@("`@("`D<F5S+3YF<F5E*"D["@H@
M("`@("`@(&EF("@D97)R("$]/2!$0E]/2RD@>PH@("`@("`@("`@("!R971U
M<FX@)&5R<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F]W.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$-O;"@I"@H@("`@+RHJ"B`@
M("`@*B!&971C:&5S(&$@<VEN9VQE(&-O;'5M;B!F<F]M(&$@<75E<GD@<F5S
M=6QT(&%N9"!R971U<FYS(&ET(&%S(&%N"B`@("`@*B!I;F1E>&5D(&%R<F%Y
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@4U%,
M('%U97)Y"B`@("`@*B!`<&%R86T@;6EX960@("1C;VP@("`@('=H:6-H(&-O
M;'5M;B!T;R!R971U<FX@*&EN=&5G97(@6V-O;'5M;B!N=6UB97(L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R=&EN9R!A="`P72!O<B!S
M=')I;F<@6V-O;'5M;B!N86UE72D*("`@("`J($!P87)A;2!M:7AE9"`@)'!A
M<F%M<R`@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E
M9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N
M(&]F('1H92!S=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A
M;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@
M;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A
M;65T97)S(&]R(#$@<&QA8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@=&AE(')E<W5L=',@87,@86X@
M87)R87DN("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIQ=65R>2@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9G971#;VPH)'%U97)Y+"`D8V]L(#T@,"P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'!A<F%M<R`]("AA<G)A>2DD<&%R86US
M.PH@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@("`@("`@
M("`@("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH*("`@("`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'-T:#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<R`]
M)B`D=&AI<RT^97AE8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@("`@("`@
M)'1H:7,M/F9R9650<F5P87)E9"@D<W1H*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&9E=&-H
M;6]D92`](&ES7VEN="@D8V]L*2`_($1"7T9%5$-(34]$15]/4D1%4D5$(#H@
M1$)?1D540TA-3T1%7T%34T]#.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R
M;W<@/2`D<F5S+3YF971C:%)O=R@D9F5T8VAM;V1E*2DI('L*("`@("`@("`@
M("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1C;VPL("1R;W<I*2!["B`@("`@
M("`@("`@("`@("`D<F5T(#TF("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7TY/4U5#2$9)14Q$*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1R970@/2!A<G)A>2@D<F]W6R1C;VQ=*3L*("`@("`@("`@("`@
M("`@('=H:6QE("AI<U]A<G)A>2@D<F]W(#T@)')E<RT^9F5T8VA2;W<H)&9E
M=&-H;6]D92DI*2!["B`@("`@("`@("`@("`@("`@("`@)')E=%M=(#T@)')O
M=ULD8V]L73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)')E<RT^9G)E92@I.PH*("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')O=RDI('L*("`@("`@("`@("`@)')E="`]("1R;W<["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!G971!<W-O8R@I"@H@("`@+RHJ"B`@("`@*B!&971C
M:&5S(&%N(&5N=&ER92!Q=65R>2!R97-U;'0@86YD(')E='5R;G,@:70@87,@
M86X*("`@("`J(&%S<V]C:6%T:79E(&%R<F%Y('5S:6YG('1H92!F:7)S="!C
M;VQU;6X@87,@=&AE(&ME>0H@("`@("H*("`@("`J($EF('1H92!R97-U;'0@
M<V5T(&-O;G1A:6YS(&UO<F4@=&AA;B!T=V\@8V]L=6UN<RP@=&AE('9A;'5E
M"B`@("`@*B!W:6QL(&)E(&%N(&%R<F%Y(&]F('1H92!V86QU97,@9G)O;2!C
M;VQU;6X@,BUN+B`@268@=&AE(')E<W5L=`H@("`@("H@<V5T(&-O;G1A:6YS
M(&]N;'D@='=O(&-O;'5M;G,L('1H92!R971U<FYE9"!V86QU92!W:6QL(&)E
M(&$*("`@("`J('-C86QA<B!W:71H('1H92!V86QU92!O9B!T:&4@<V5C;VYD
M(&-O;'5M;B`H=6YL97-S(&9O<F-E9"!T;R!A;@H@("`@("H@87)R87D@=VET
M:"!T:&4@)&9O<F-E7V%R<F%Y('!A<F%M971E<BDN("!!($1"(&5R<F]R(&-O
M9&4@:7,*("`@("`J(')E='5R;F5D(&]N(&5R<F]R<RX@($EF('1H92!R97-U
M;'0@<V5T(&-O;G1A:6YS(&9E=V5R('1H86X@='=O"B`@("`@*B!C;VQU;6YS
M+"!A($1"7T524D]27U1254Y#051%1"!E<G)O<B!I<R!R971U<FYE9"X*("`@
M("`J"B`@("`@*B!&;W(@97AA;7!L92P@:68@=&AE('1A8FQE(")M>71A8FQE
M(B!C;VYT86EN<SH*("`@("`J"B`@("`@*B`\<')E/@H@("`@("H@($E$("`@
M("`@5$585"`@("`@("!$051%"B`@("`@*B`M+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H@("`@("H@(#$@("`@("`@)V]N92<@("`@("`Y-#0V
M-SDT,#@*("`@("`J("`R("`@("`@("=T=V\G("`@("`@.30T-C<Y-#`X"B`@
M("`@*B`@,R`@("`@("`G=&AR964G("`@(#DT-#8W.30P.`H@("`@("H@/"]P
M<F4^"B`@("`@*@H@("`@("H@5&AE;B!T:&4@8V%L;"!G971!<W-O8R@G4T5,
M14-4(&ED+'1E>'0@1E)/32!M>71A8FQE)RD@<F5T=7)N<SH*("`@("`J(#QP
M<F4^"B`@("`@*B`@(&%R<F%Y*`H@("`@("H@("`@("<Q)R`]/B`G;VYE)RP*
M("`@("`J("`@("`G,B<@/3X@)W1W;R<L"B`@("`@*B`@("`@)S,G(#T^("=T
M:')E92<L"B`@("`@*B`@("D*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J
M("XN+G=H:6QE('1H92!C86QL(&=E=$%S<V]C*"=314Q%0U0@:60L=&5X="QD
M871E($923TT@;7ET86)L92<I(')E='5R;G,Z"B`@("`@*B`\<')E/@H@("`@
M("H@("!A<G)A>2@*("`@("`J("`@("`G,2<@/3X@87)R87DH)V]N92<L("<Y
M-#0V-SDT,#@G*2P*("`@("`J("`@("`G,B<@/3X@87)R87DH)W1W;R<L("<Y
M-#0V-SDT,#@G*2P*("`@("`J("`@("`G,R<@/3X@87)R87DH)W1H<F5E)RP@
M)SDT-#8W.30P."<I"B`@("`@*B`@("D*("`@("`J(#PO<')E/@H@("`@("H*
M("`@("`J($EF('1H92!M;W)E('1H86X@;VYE(')O=R!O8V-U<G,@=VET:"!T
M:&4@<V%M92!V86QU92!I;B!T:&4*("`@("`J(&9I<G-T(&-O;'5M;BP@=&AE
M(&QA<W0@<F]W(&]V97)W<FET97,@86QL('!R979I;W5S(&]N97,@8GD*("`@
M("`J(&1E9F%U;'0N("!5<V4@=&AE("1G<F]U<"!P87)A;65T97(@:68@>6]U
M(&1O;B=T('=A;G0@=&\*("`@("`J(&]V97)W<FET92!L:6ME('1H:7,N("!%
M>&%M<&QE.@H@("`@("H*("`@("`J(#QP<F4^"B`@("`@*B!G971!<W-O8R@G
M4T5,14-4(&-A=&5G;W)Y+&ED+&YA;64@1E)/32!M>71A8FQE)RP@9F%L<V4L
M(&YU;&PL"B`@("`@*B`@("`@("`@("!$0E]&151#2$U/1$5?05-33T,L('1R
M=64I(')E='5R;G,Z"B`@("`@*@H@("`@("H@("!A<G)A>2@*("`@("`J("`@
M("`G,2<@/3X@87)R87DH87)R87DH)VED)R`]/B`G-"<L("=N86UE)R`]/B`G
M;G5M8F5R(&9O=7(G*2P*("`@("`J("`@("`@("`@("`@("`@("`@87)R87DH
M)VED)R`]/B`G-B<L("=N86UE)R`]/B`G;G5M8F5R('-I>"<I"B`@("`@*B`@
M("`@("`@("`@("DL"B`@("`@*B`@("`@)SDG(#T^(&%R<F%Y*&%R<F%Y*"=I
M9"<@/3X@)S0G+"`G;F%M92<@/3X@)VYU;6)E<B!F;W5R)RDL"B`@("`@*B`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=I9"<@/3X@)S8G+"`G;F%M92<@/3X@
M)VYU;6)E<B!S:7@G*0H@("`@("H@("`@("`@("`@("`I"B`@("`@*B`@("D*
M("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($ME97`@:6X@;6EN9"!T:&%T
M(&1A=&%B87-E(&9U;F-T:6]N<R!I;B!02%`@=7-U86QL>2!R971U<FX@<W1R
M:6YG"B`@("`@*B!V86QU97,@9F]R(')E<W5L=',@<F5G87)D;&5S<R!O9B!T
M:&4@9&%T86)A<V4G<R!I;G1E<FYA;"!T>7!E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'%U97)Y("`@("`@("!T:&4@4U%,('%U97)Y"B`@("`@
M*B!`<&%R86T@8F]O;"`@("1F;W)C95]A<G)A>2`@=7-E9"!O;FQY('=H96X@
M=&AE('%U97)Y(')E='5R;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@97AA8W1L>2!T=V\@8V]L=6UN<RX@($EF('1R=64L('1H92!V
M86QU97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V8@
M=&AE(')E='5R;F5D(&%R<F%Y('=I;&P@8F4@;VYE+65L96UE;G0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87ES(&EN<W1E860@
M;V8@<V-A;&%R<RX*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@("`@
M("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO
M;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:71E;7,@<&%S<V5D(&UU<W0@;6%T
M8V@@<75A;G1I='D@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<&QA8V5H;VQD97)S(&EN('%U97)Y.B`@;65A;FEN9R`Q"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!L86-E:&]L9&5R(&9O
M<B!N;VXM87)R87D@<&%R86UE=&5R<R!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M
M96YT+@H@("`@("H@0'!A<F%M(&EN="`@("1F971C:&UO9&4@("`@('1H92!F
M971C:"!M;V1E('1O('5S90H@("`@("H@0'!A<F%M(&)O;VP@("1G<F]U<"`@
M("`@("`@(&EF('1R=64L('1H92!V86QU97,@;V8@=&AE(')E='5R;F5D(&%R
M<F%Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES('=R
M87!P960@:6X@86YO=&AE<B!A<G)A>2X@($EF('1H92!S86UE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ME>2!V86QU92`H:6X@=&AE
M(&9I<G-T(&-O;'5M;BD@<F5P96%T<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I='-E;&8L('1H92!V86QU97,@=VEL;"!B92!A<'!E
M;F1E9"!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&ES(&%R<F%Y(&EN<W1E860@;V8@;W9E<G=R:71I;F<@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5X:7-T:6YG('9A;'5E<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!T:&4@87-S;V-I871I=F4@
M87)R87D@8V]N=&%I;FEN9R!T:&4@<75E<GD@<F5S=6QT<RX*("`@("`J("`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971!<W-O8R@D<75E<GDL("1F;W)C95]A
M<G)A>2`](&9A;'-E+"`D<&%R86US(#T@87)R87DH*2P*("`@("`@("`@("`@
M("`@("`@("`@("`D9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%7T1%1D%53%0L
M("1G<F]U<"`](&9A;'-E*0H@("`@>PH@("`@("`@("1P87)A;7,@/2`H87)R
M87DI)'!A<F%M<SL*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I(#X@,"D@
M>PH@("`@("`@("`@("`D<W1H(#T@)'1H:7,M/G!R97!A<F4H)'%U97)Y*3L*
M"B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1S=&@["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1R97,@/28@)'1H:7,M/F5X96-U=&4H)'-T:"P@)'!A<F%M<RD["B`@
M("`@("`@("`@("1T:&ES+3YF<F5E4')E<&%R960H)'-T:"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^<75E<GDH)'%U
M97)Y*3L*("`@("`@("!]"@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"B`@("`@
M("`@:68@*"1F971C:&UO9&4@/3T@1$)?1D540TA-3T1%7T1%1D%53%0I('L*
M("`@("`@("`@("`@)&9E=&-H;6]D92`]("1T:&ES+3YF971C:&UO9&4["B`@
M("`@("`@?0H@("`@("`@("1C;VQS(#T@)')E<RT^;G5M0V]L<R@I.PH*("`@
M("`@("!I9B`H)&-O;',@/"`R*2!["B`@("`@("`@("`@("1T;7`@/28@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?5%)53D-!5$5$*3L*("`@("`@("`@
M("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT<R`]
M(&%R<F%Y*"D["@H@("`@("`@(&EF("@D8V]L<R`^(#(@?'P@)&9O<F-E7V%R
M<F%Y*2!["B`@("`@("`@("`@("\O(')E='5R;B!A<G)A>2!V86QU97,*("`@
M("`@("`@("`@+R\@6%A8('1H:7,@<&%R="!C86X@8F4@;W!T:6UI>F5D"B`@
M("`@("`@("`@(&EF("@D9F5T8VAM;V1E(#T]($1"7T9%5$-(34]$15]!4U-/
M0RD@>PH@("`@("`@("`@("`@("`@=VAI;&4@*&ES7V%R<F%Y*"1R;W<@/2`D
M<F5S+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E<V5T*"1R;W<I.PH@("`@("`@("`@("`@("`@("`@
M("1K97D@/2!C=7)R96YT*"1R;W<I.PH@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1R;W=;:V5Y*"1R;W<I72D["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1G<F]U<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT<ULD
M:V5Y75M=(#T@)')O=SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT<ULD:V5Y72`]("1R;W<[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V5I9B`H)&9E=&-H;6]D92`]/2!$0E]&151#2$U/1$5?
M3T)*14-4*2!["B`@("`@("`@("`@("`@("!W:&EL92`H)')O=R`]("1R97,M
M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/0DI%0U0I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&%R<B`](&=E=%]O8FIE8W1?=F%R<R@D<F]W*3L*("`@("`@
M("`@("`@("`@("`@("`D:V5Y(#T@8W5R<F5N="@D87)R*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&=R;W5P*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1R97-U;'1S6R1K97E=6UT@/2`D<F]W.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S
M6R1K97E=(#T@)')O=SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!W:&EL92`H:7-?87)R87DH)')O=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%
M5$-(34]$15]/4D1%4D5$*2DI('L*("`@("`@("`@("`@("`@("`@("`O+R!W
M92!S:&EF="!A=V%Y('1H92!F:7)S="!E;&5M96YT('1O(&=E=`H@("`@("`@
M("`@("`@("`@("`@("\O(&EN9&EC97,@<G5N;FEN9R!F<F]M(#`@86=A:6X*
M("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@87)R87E?<VAI9G0H)')O=RD[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1G<F]U<"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT<ULD:V5Y75M=(#T@)')O=SL*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT<ULD:V5Y72`]("1R;W<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F]W*2D@>PH@("`@("`@("`@("`@("`@)')E
M<W5L=',@/2`D<F]W.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@<F5T=7)N('-C86QA<B!V86QU97,*("`@("`@("`@
M("`@=VAI;&4@*&ES7V%R<F%Y*"1R;W<@/2`D<F5S+3YF971C:%)O=RA$0E]&
M151#2$U/1$5?3U)$15)%1"DI*2!["B`@("`@("`@("`@("`@("!I9B`H)&=R
M;W5P*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;)')O=ULP75U;
M72`]("1R;W=;,5T["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1R97-U;'1S6R1R;W=;,%U=(#T@)')O=ULQ73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')O=RDI('L*("`@("`@("`@("`@("`@("1R97-U;'1S
M(#T@)')O=SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)')E
M<RT^9G)E92@I.PH*("`@("`@("!R971U<FX@)')E<W5L=',["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9V5T06QL*"D*"B`@("`O*BH*("`@("`J
M($9E=&-H97,@86QL(&]F('1H92!R;W=S(&9R;VT@82!Q=65R>2!R97-U;'0*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@("`@('1H92!3
M44P@<75E<GD*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@("`@87)R
M87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H
M92!S=&%T96UE;G0N("!1=6%N=&ET>2!O9@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:71E;7,@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I
M='D@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('!L86-E
M:&]L9&5R<R!I;B!Q=65R>3H@(&UE86YI;F<@,0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>2!P
M87)A;65T97)S(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H@0'!A
M<F%M(&EN="`@("`D9F5T8VAM;V1E("!T:&4@9F5T8V@@;6]D92!T;R!U<V4Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`K($1"7T9%5$-(
M34]$15]/4D1%4D5$"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K($1"7T9%5$-(34]$15]!4U-/0PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*R!$0E]&151#2$U/1$5?3U)$15)%1"!\($1"7T9%5$-(
M34]$15]&3$E04$5$"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K($1"7T9%5$-(34]$15]!4U-/0R!\($1"7T9%5$-(34]$15]&3$E04$5$
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@=&AE(&YE<W1E9"!A<G)A
M>2X@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9G971!;&PH)'%U97)Y+"`D<&%R86US(#T@87)R87DH*2P*
M("`@("`@("`@("`@("`@("`@("`@)&9E=&-H;6]D92`]($1"7T9%5$-(34]$
M15]$149!54Q4*0H@("`@>PH@("`@("`@("\O(&-O;7!A="!C:&5C:RP@=&AE
M('!A<F%M<R!A;F0@9F5T8VAM;V1E('!A<F%M971E<G,@=7-E9"!T;PH@("`@
M("`@("\O(&AA=F4@=&AE(&]P<&]S:71E(&]R9&5R"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)&9E=&-H;6]D92DI('L*("`@("`@("`@("`@("`@(&EF("@D<&%R86US(#T]
M/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]($1"7T9%5$-(
M34]$15]$149!54Q4.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D=&UP(#T@)'!A<F%M<SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D9F5T8VAM;V1E.PH@("`@
M("`@("`@("`@("`@)&9E=&-H;6]D92`]("1T;7`["B`@("`@("`@("`@('T@
M96QS96EF("@D<&%R86US("$]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D
M9F5T8VAM;V1E(#T@)'!A<F%M<SL*("`@("`@("`@("`@("`@("1P87)A;7,@
M/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H<VEZ96]F*"1P87)A;7,I(#X@,"D@>PH@("`@("`@("`@("`D<W1H(#T@
M)'1H:7,M/G!R97!A<F4H)'%U97)Y*3L*"B`@("`@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&@[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97,@/28@)'1H:7,M/F5X
M96-U=&4H)'-T:"P@)'!A<F%M<RD["B`@("`@("`@("`@("1T:&ES+3YF<F5E
M4')E<&%R960H)'-T:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)')E<R`])B`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D<F5S(#T]/2!$0E]/2R!\?"!$0CHZ:7-%<G)O<B@D<F5S*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'1S(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H1$)?3TL@/3T]
M("1R97,M/F9E=&-H26YT;R@D<F]W+"`D9F5T8VAM;V1E*2D@>PH@("`@("`@
M("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]&3$E04$5$*2![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F]W(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6UT@/2`D
M=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)')E<W5L='-;72`]("1R;W<["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1R97,M/F9R964H*3L*"B`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R;W<I*2!["B`@("`@("`@("`@("1T;7`@/28@
M)'1H:7,M/G)A:7-E17)R;W(H)')O=RD["B`@("`@("`@("`@(')E='5R;B`D
M=&UP.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=',["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ
M"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S(&%U=&]M871I8R!C;VUM:71S
M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VP@)&]N;V9F("!T<G5E('1U<FYS
M(&ET(&]N+"!F86QS92!T=7)N<R!I="!O9F8*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&EF('1H92!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@9&]E<VXG="!S
M=7!P;W)T(&%U=&\M8V]M;6ET=&EN9R!T<F%N<V%C=&EO;G,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/
M5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM
M:70H*0H*("`@("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N
M<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S
M=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*
M("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')O;&QB86-K*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@82!Q=65R>2!R97-U;'0*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@=&AE('%U97)Y
M(')E<W5L="!I9&5N:69I97(@<')O9'5C960@8GD@4$A0"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU
M;5)O=W,H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A
M(&1A=&$@;6%N:75P;&%T:6]N('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R
M971U<FYE9"!F;W(@<75E<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R
M;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@869F96-T9612;W=S*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-E<75E;F-E3F%M92@I
M"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE(&YA;64@=7-E9"!I;G-I
M9&4@=&AE(&1A=&%B87-E(&9O<B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@
M5&AE(&-R96%T95-E<75E;F-E*"D@9&]C8FQO8VL@8V]N=&%I;G,@;F]T97,@
M86)O=70@<W1O<FEN9R!S97%U96YC90H@("`@("H@;F%M97,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<W%N("!T:&4@<V5Q=65N8V4G<R!P=6)L
M:6,@;F%M90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<V5Q
M=65N8V4G<R!N86UE(&EN('1H92!B86-K96YD"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&53
M97%U96YC92@I+"!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+`H@("`@("H@
M("`@("!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.G-E=$]P=&EO
M;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<75E;F-E3F%M92@D<W%N
M*0H@("`@>PH@("`@("`@(')E='5R;B!S<')I;G1F*"1T:&ES+3YG971/<'1I
M;VXH)W-E<6YA;65?9F]R;6%T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M<')E9U]R97!L86-E*"<O6UYA+7HP+3E?+ETO:2<L("=?)RP@)'-Q;BDI.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M
M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E
M;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF
M(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL
M($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL"B`@("`@*B`@("`@($1"7V-O
M;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!
M4$%"3$4I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-R96%T95-E
M<75E;F-E*"D*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N
M8V4*("`@("`J"B`@("`@*B!4:&4@;F%M92!O9B!A(&=I=F5N('-E<75E;F-E
M(&ES(&1E=&5R;6EN960@8GD@<&%S<VEN9R!T:&4@<W1R:6YG"B`@("`@*B!P
M<F]V:61E9"!I;B!T:&4@/'9A<CXD<V5Q7VYA;64\+W9A<CX@87)G=6UE;G0@
M=&AR;W5G:"!02%`G<R!S<')I;G1F*"D*("`@("`J(&9U;F-T:6]N('5S:6YG
M('1H92!V86QU92!F<F]M('1H92`\=F%R/G-E<6YA;65?9F]R;6%T/"]V87(^
M(&]P=&EO;B!A<PH@("`@("H@=&AE('-P<FEN=&8H*2=S(&9O<FUA="!A<F=U
M;65N="X*("`@("`J"B`@("`@*B`\=F%R/G-E<6YA;65?9F]R;6%T/"]V87(^
M(&ES('-E="!V:6$@<V5T3W!T:6]N*"DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T
M4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V-O;6UO;CHZ;F5X=$E$
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N
M86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9')O<%-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@
M82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N
M86UE("!N86UE(&]F('1H92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E
M<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]C;VUM;VXZ.FYE>'1)1"@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!R86ES945R<F]R*"D*"B`@("`O*BH*("`@("`J($-O;6UU;FEC871E<R!A
M;B!E<G)O<B!A;F0@:6YV;VME(&5R<F]R(&-A;&QB86-K<RP@971C"B`@("`@
M*@H@("`@("H@0F%S:6-A;&QY(&$@=W)A<'!E<B!F;W(@4$5!4CHZ<F%I<V5%
M<G)O<B!W:71H;W5T('1H92!M97-S86=E('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@("!I;G1E9V5R(&5R<F]R(&-O9&4L(&]R(&$@4$5!
M4B!E<G)O<B!O8FIE8W0@*&%L;`H@("`@("H@("`@("`@("`@("`@("`@(&]T
M:&5R('!A<F%M971E<G,@87)E(&EG;F]R960@:68@=&AI<R!P87)A;65T97(@
M:7,*("`@("`J("`@("`@("`@("`@("`@("!A;B!O8FIE8W0*("`@("`J($!P
M87)A;2!I;G0@("`@(&5R<F]R(&UO9&4L('-E92!014%27T5R<F]R(&1O8W,*
M("`@("`J($!P87)A;2!M:7AE9"`@(&EF(&5R<F]R(&UO9&4@:7,@4$5!4E]%
M4E)/4E]44DE'1T52+"!T:&ES(&ES('1H90H@("`@("H@("`@("`@("`@("`@
M("`@(&5R<F]R(&QE=F5L("A%7U5315)?3D]424-%(&5T8RDN("!)9B!E<G)O
M<B!M;V1E(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@4$5!4E]%4E)/4E]#
M04Q,0D%#2RP@=&AI<R!I<R!T:&4@8V%L;&)A8VL@9G5N8W1I;VXL"B`@("`@
M*B`@("`@("`@("`@("`@("`@96ET:&5R(&%S(&$@9G5N8W1I;VX@;F%M92P@
M;W(@87,@86X@87)R87D@;V8@86X*("`@("`J("`@("`@("`@("`@("`@("!O
M8FIE8W0@86YD(&UE=&AO9"!N86UE+B`@1F]R(&]T:&5R(&5R<F]R(&UO9&5S
M('1H:7,*("`@("`J("`@("`@("`@("`@("`@("!P87)A;65T97(@:7,@:6=N
M;W)E9"X*("`@("`J($!P87)A;2!S=')I;F<@(&5X=')A(&1E8G5G(&EN9F]R
M;6%T:6]N+B`@1&5F875L=',@=&\@=&AE(&QA<W0*("`@("`J("`@("`@("`@
M("`@("`@("!Q=65R>2!A;F0@;F%T:79E(&5R<F]R(&-O9&4N"B`@("`@*B!`
M<&%R86T@;6EX960@("!N871I=F4@97)R;W(@8V]D92P@:6YT96=E<B!O<B!S
M=')I;F<@9&5P96YD:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@(&)A
M8VME;F0*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE(%!%05)?
M17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!014%27T5R<F]R"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9R86ES945R<F]R*"1C;V1E(#T@1$)?15)2
M3U(L("1M;V1E(#T@;G5L;"P@)&]P=&EO;G,@/2!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)'5S97)I;F9O(#T@;G5L;"P@)&YA=&EV96-O9&4@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\O(%1H92!E<G)O<B!I<R!Y970@82!$
M0B!E<G)O<B!O8FIE8W0*("`@("`@("!I9B`H:7-?;V)J96-T*"1C;V1E*2D@
M>PH@("`@("`@("`@("`O+R!B96-A=7-E('=E('1H92!S=&%T:6,@4$5!4CHZ
M<F%I<V5%<G)O<BP@;W5R(&=L;V)A;`H@("`@("`@("`@("`O+R!H86YD;&5R
M('-H;W5L9"!B92!U<V5D(&EF(&ET(&ES('-E=`H@("`@("`@("`@("!I9B`H
M)&UO9&4@/3T](&YU;&P@)B8@(65M<'1Y*"1T:&ES+3Y?9&5F875L=%]E<G)O
M<E]M;V1E*2D@>PH@("`@("`@("`@("`@("`@)&UO9&4@("`@/2`D=&AI<RT^
M7V1E9F%U;'1?97)R;W)?;6]D93L*("`@("`@("`@("`@("`@("1O<'1I;VYS
M(#T@)'1H:7,M/E]D969A=6QT7V5R<F]R7V]P=&EO;G,["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1M<"`](%!%05(Z.G)A:7-E17)R;W(H)&-O9&4L
M(&YU;&PL("1M;V1E+"`D;W!T:6]N<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@=')U92D["B`@("`@("`@("`@
M(')E='5R;B`D=&UP.PH@("`@("`@('T*"B`@("`@("`@:68@*"1U<V5R:6YF
M;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D=7-E<FEN9F\@/2`D=&AI<RT^
M;&%S=%]Q=65R>3L*("`@("`@("!]"@H@("`@("`@(&EF("@D;F%T:79E8V]D
M92D@>PH@("`@("`@("`@("`D=7-E<FEN9F\@+CT@)R!;;F%T:79E8V]D93TG
M("X@=')I;2@D;F%T:79E8V]D92D@+B`G72<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'5S97)I;F9O("X]("<@6T1"($5R<F]R.B`G("X@1$(Z
M.F5R<F]R365S<V%G92@D8V]D92D@+B`G72<["B`@("`@("`@?0H*("`@("`@
M("`D=&UP(#T@4$5!4CHZ<F%I<V5%<G)O<BAN=6QL+"`D8V]D92P@)&UO9&4L
M("1O<'1I;VYS+"`D=7-E<FEN9F\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)T1"7T5R<F]R)RP@=')U92D["B`@("`@("`@<F5T=7)N("1T
M;7`["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).871I=F4H
M*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R
M(&-O9&4@<')O9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!T:&4@1$)-4R<@97)R;W(@8V]D92X@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!-
M87!S(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$0B=S('!O<G1A8FQE(&]N97,*
M("`@("`J"B`@("`@*B!5<V5S('1H92`\=F%R/B1E<G)O<F-O9&5?;6%P/"]V
M87(^('!R;W!E<G1Y(&1E9FEN960@:6X@96%C:"!D<FEV97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9WQI;G0@)&YA=&EV96-O9&4@('1H92!E<G)O
M<B!C;V1E(')E='5R;F5D(&)Y('1H92!$0DU3"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@('1H92!P;W)T86)L92!$0B!E<G)O<B!C;V1E+B`@4F5T=7)N
M($1"7T524D]2(&EF('1H90H@("`@("H@("`@("`@("`@("`@("!C=7)R96YT
M(&1R:79E<B!D;V5S;B=T(&AA=F4@82!M87!P:6YG(&9O<B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@)&YA=&EV96-O9&4@<W5B;6ET=&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E<G)O<D-O9&4H)&YA=&EV96-O9&4I"B`@("!["B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YE<G)O<F-O9&5?;6%P6R1N871I=F5C
M;V1E72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YE<G)O<F-O9&5?
M;6%P6R1N871I=F5C;V1E73L*("`@("`@("!]"B`@("`@("`@+R\@1F%L;"!B
M86-K('1O($1"7T524D]2(&EF('1H97)E('=A<R!N;R!M87!P:6YG+@H@("`@
M("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!E<G)O<DUE<W-A9V4H*0H*("`@("\J*@H@("`@("H@36%P<R!A($1"
M(&5R<F]R(&-O9&4@=&\@82!T97AT=6%L(&UE<W-A9V4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D9&)C;V1E("!T:&4@1$(@97)R;W(@8V]D90H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@97)R;W(@;65S<V%G
M92!C;W)R97-P;VYD:6YG('1O('1H92!E<G)O<B!C;V1E"B`@("`@*B`@("`@
M("`@("`@("`@("`@('-U8FUI='1E9"X@($9!3%-%(&EF('1H92!E<G)O<B!C
M;V1E(&ES('5N:VYO=VXN"B`@("`@*@H@("`@("H@0'-E92!$0CHZ97)R;W)-
M97-S86=E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)-97-S86=E*"1D
M8F-O9&4I"B`@("!["B`@("`@("`@<F5T=7)N($1".CIE<G)O<DUE<W-A9V4H
M)'1H:7,M/F5R<F]R8V]D95]M87!;)&1B8V]D95TI.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@=&%B;&4@;W(@82!R97-U;'0@
M<V5T"B`@("`@*@H@("`@("H@5&AE(&9O<FUA="!O9B!T:&4@<F5S=6QT:6YG
M(&%R<F%Y(&1E<&5N9',@;VX@=VAI8V@@/'9A<CXD;6]D93PO=F%R/@H@("`@
M("H@>6]U('-E;&5C="X@(%1H92!S86UP;&4@;W5T<'5T(&)E;&]W(&ES(&)A
M<V5D(&]N('1H:7,@<75E<GDZ"B`@("`@*B`\<')E/@H@("`@("H@("`@4T5,
M14-4('1B;$9O;RYF;&1)1"P@=&)L1F]O+F9L9%!H;VYE+"!T8FQ"87(N9FQD
M260*("`@("`J("`@($923TT@=&)L1F]O"B`@("`@*B`@("!*3TE.('1B;$)A
M<B!/3B!T8FQ&;V\N9FQD260@/2!T8FQ"87(N9FQD260*("`@("`J(#PO<')E
M/@H@("`@("H*("`@("`J(#QU;#X*("`@("`J(#QL:3X*("`@("`J"B`@("`@
M*B`\:V)D/FYU;&P\+VMB9#X@*&1E9F%U;'0I"B`@("`@*B`@(#QP<F4^"B`@
M("`@*B`@(%LP72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("!;=&%B;&5=(#T^
M('1B;$9O;PH@("`@("H@("`@("`@6VYA;65=(#T^(&9L9$ED"B`@("`@*B`@
M("`@("!;='EP95T@/3X@:6YT"B`@("`@*B`@("`@("!;;&5N72`]/B`Q,0H@
M("`@("H@("`@("`@6V9L86=S72`]/B!P<FEM87)Y7VME>2!N;W1?;G5L;`H@
M("`@("H@("`I"B`@("`@*B`@(%LQ72`]/B!!<G)A>2`H"B`@("`@*B`@("`@
M("!;=&%B;&5=(#T^('1B;$9O;PH@("`@("H@("`@("`@6VYA;65=(#T^(&9L
M9%!H;VYE"B`@("`@*B`@("`@("!;='EP95T@/3X@<W1R:6YG"B`@("`@*B`@
M("`@("!;;&5N72`]/B`R,`H@("`@("H@("`@("`@6V9L86=S72`]/@H@("`@
M("H@("`I"B`@("`@*B`@(%LR72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("!;
M=&%B;&5=(#T^('1B;$)A<@H@("`@("H@("`@("`@6VYA;65=(#T^(&9L9$ED
M"B`@("`@*B`@("`@("!;='EP95T@/3X@:6YT"B`@("`@*B`@("`@("!;;&5N
M72`]/B`Q,0H@("`@("H@("`@("`@6V9L86=S72`]/B!P<FEM87)Y7VME>2!N
M;W1?;G5L;`H@("`@("H@("`I"B`@("`@*B`@(#PO<')E/@H@("`@("H*("`@
M("`J(#PO;&D^/&QI/@H@("`@("H*("`@("`J(#QK8F0^1$)?5$%"3$5)3D9/
M7T]21$52/"]K8F0^"B`@("`@*@H@("`@("H@("`\<#Y);B!A9&1I=&EO;B!T
M;R!T:&4@:6YF;W)M871I;VX@9F]U;F0@:6X@=&AE(&1E9F%U;'0@;W5T<'5T
M+`H@("`@("H@("!A(&YO=&%T:6]N(&]F('1H92!N=6UB97(@;V8@8V]L=6UN
M<R!I<R!P<F]V:61E9"!B>2!T:&4*("`@("`J("`@/'-A;7`^;G5M7V9I96QD
M<SPO<V%M<#X@96QE;65N="!W:&EL92!T:&4@/'-A;7`^;W)D97(\+W-A;7`^
M"B`@("`@*B`@(&5L96UE;G0@<')O=FED97,@86X@87)R87D@=VET:"!T:&4@
M8V]L=6UN(&YA;65S(&%S('1H92!K97ES(&%N9`H@("`@("H@("!T:&5I<B!L
M;V-A=&EO;B!I;F1E>"!N=6UB97(@*&-O<G)E<W!O;F1I;F<@=&\@=&AE(&ME
M>7,@:6X@=&AE"B`@("`@*B`@('1H92!D969A=6QT(&]U='!U="D@87,@=&AE
M('9A;'5E<RX\+W`^"B`@("`@*@H@("`@("H@("`\<#Y)9B!A(')E<W5L="!S
M970@:&%S(&ED96YT:6-A;"!F:65L9"!N86UE<RP@=&AE(&QA<W0@;VYE(&ES
M"B`@("`@*B`@('5S960N/"]P/@H@("`@("H*("`@("`J("`@/'!R93X*("`@
M("`J("`@6VYU;5]F:65L9'-=(#T^(#,*("`@("`J("`@6V]R9&5R72`]/B!!
M<G)A>2`H"B`@("`@*B`@("`@("!;9FQD261=(#T^(#(*("`@("`J("`@("`@
M(%MF;&14<F%N<UT@/3X@,0H@("`@("H@("`I"B`@("`@*B`@(#PO<')E/@H@
M("`@("H*("`@("`J(#PO;&D^/&QI/@H@("`@("H*("`@("`J(#QK8F0^1$)?
M5$%"3$5)3D9/7T]21$525$%"3$4\+VMB9#X*("`@("`J"B`@("`@*B`@(#QP
M/E-I;6EL87(@=&\@/&MB9#Y$0E]404),14E.1D]?3U)$15(\+VMB9#X@8G5T
M(&%D9',@;6]R90H@("`@("H@("!D:6UE;G-I;VYS('1O('1H92!A<G)A>2!I
M;B!W:&EC:"!T:&4@=&%B;&4@;F%M97,@87)E(&ME>7,@86YD"B`@("`@*B`@
M('1H92!F:65L9"!N86UE<R!A<F4@<W5B+6ME>7,N("!4:&ES(&ES(&AE;'!F
M=6P@9F]R('%U97)I97,@=&AA=`H@("`@("H@("!J;VEN('1A8FQE<R!W:&EC
M:"!H879E(&ED96YT:6-A;"!F:65L9"!N86UE<RX\+W`^"B`@("`@*@H@("`@
M("H@("`\<')E/@H@("`@("H@("!;;G5M7V9I96QD<UT@/3X@,PH@("`@("H@
M("!;;W)D97)T86)L95T@/3X@07)R87D@*`H@("`@("H@("`@("`@6W1B;$9O
M;UT@/3X@07)R87D@*`H@("`@("H@("`@("`@("`@(%MF;&1)9%T@/3X@,`H@
M("`@("H@("`@("`@("`@(%MF;&10:&]N95T@/3X@,0H@("`@("H@("`@("`@
M*0H@("`@("H@("`@("`@6W1B;$)A<ET@/3X@07)R87D@*`H@("`@("H@("`@
M("`@("`@(%MF;&1)9%T@/3X@,@H@("`@("H@("`@("`@*0H@("`@("H@("`I
M"B`@("`@*B`@(#PO<')E/@H@("`@("H*("`@("`J(#PO;&D^"B`@("`@*B`\
M+W5L/@H@("`@("H*("`@("`J(%1H92`\<V%M<#YF;&%G<SPO<V%M<#X@96QE
M;65N="!C;VYT86EN<R!A('-P86-E('-E<&%R871E9"!L:7-T"B`@("`@*B!O
M9B!E>'1R82!I;F9O<FUA=&EO;B!A8F]U="!T:&4@9FEE;&0N("!4:&ES(&1A
M=&$@:7,@:6YC;VYS:7-T96YT"B`@("`@*B!B971W965N($1"35,G<R!D=64@
M=&\@=&AE('=A>2!E86-H($1"35,@=V]R:W,N"B`@("`@*B`@("L@/'-A;7`^
M<')I;6%R>5]K97D\+W-A;7`^"B`@("`@*B`@("L@/'-A;7`^=6YI<75E7VME
M>3PO<V%M<#X*("`@("`J("`@*R`\<V%M<#YM=6QT:7!L95]K97D\+W-A;7`^
M"B`@("`@*B`@("L@/'-A;7`^;F]T7VYU;&P\+W-A;7`^"B`@("`@*@H@("`@
M("H@36]S="!$0DU3)W,@;VYL>2!P<F]V:61E('1H92`\<V%M<#YT86)L93PO
M<V%M<#X@86YD(#QS86UP/F9L86=S/"]S86UP/@H@("`@("H@96QE;65N=',@
M:68@/'9A<CXD<F5S=6QT/"]V87(^(&ES(&$@=&%B;&4@;F%M92X@(%1H92!F
M;VQL;W=I;F<@1$)-4R=S"B`@("`@*B!P<F]V:61E(&9U;&P@:6YF;W)M871I
M;VX@9G)O;2!Q=65R:65S.@H@("`@("H@("`K(&9B<W%L"B`@("`@*B`@("L@
M;7ES<6P*("`@("`J"B`@("`@*B!)9B!T:&4@)W!O<G1A8FEL:71Y)R!O<'1I
M;VX@:&%S(#QS86UP/D1"7U!/4E1!0DE,25197TQ/5T520T%313PO<V%M<#X*
M("`@("`J('1U<FYE9"!O;BP@=&AE(&YA;65S(&]F('1A8FQE<R!A;F0@9FEE
M;&1S('=I;&P@8F4@;&]W97)C87-E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M
M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5VAI;&4@
M=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R
M+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I;G0@("1M
M;V1E("`@96ET:&5R('5N=7-E9"!O<B!O;F4@;V8@=&AE('1A8FQE26YF;R!M
M;V1E<SH*("`@("`J("`@("`@("`@("`@("`@("`@("`@/&MB9#Y$0E]404),
M14E.1D]?3U)$15)404),13PO:V)D/BP*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@/&MB9#Y$0E]404),14E.1D]?3U)$15(\+VMB9#X@;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@/&MB9#Y$0E]404),14E.1D]?1E5,3#PO
M:V)D/B`H=VAI8V@@9&]E<R!B;W1H*2X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@5&AE<V4@87)E(&)I='=I<V4L('-O('1H92!F:7)S="!T=V\@8V%N
M(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&-O;6)I;F5D('5S:6YG
M(#QK8F0^?#PO:V)D/BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A
M;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R97%U
M97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M<V5T3W!T:6]N*"D*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R
M97-U;'0L("1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("`O*@H@("`@("`@
M("`J($EF('1H92!$0E\\9')I=F5R/B!C;&%S<R!H87,@82!T86)L94EN9F\H
M*2!M971H;V0L('1H870@;VYE"B`@("`@("`@("H@;W9E<G)I9&5S('1H:7,@
M;VYE+B`@0G5T+"!I9B!T:&4@9')I=F5R(&1O97-N)W0@:&%V92!O;F4L"B`@
M("`@("`@("H@=&AI<R!M971H;V0@<G5N<R!A;F0@=&5L;',@=7-E<G,@86)O
M=70@=&AA="!F86-T+@H@("`@("`@("`J+PH@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9V5T5&%B;&5S*"D*"B`@("`O*BH*("`@
M("`J($QI<W1S('1H92!T86)L97,@:6X@=&AE(&-U<G)E;G0@9&%T86)A<V4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!T:&4@;&ES="!O9B!T86)L
M97,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!D97!R96-A=&5D($UE=&AO9"!D97!R96-A=&5D('-O;64@=&EM92!B
M969O<F4@4F5L96%S92`Q+C(*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&%B
M;&5S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$QI<W1/9B@G
M=&%B;&5S)RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T3&ES
M=$]F*"D*"B`@("`O*BH*("`@("`J($QI<W1S(&EN=&5R;F%L(&1A=&%B87-E
M(&EN9F]R;6%T:6]N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@='EP92!O9B!I;F9O<FUA=&EO;B!B96EN9R!S;W5G:'0N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@0V]M;6]N(&ET96US(&)E:6YG('-O=6=H
M="!A<F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&%B;&5S+"!D
M871A8F%S97,L('5S97)S+"!V:65W<RP@9G5N8W1I;VYS"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@16%C:"!$0DU3)W,@:&%S(&ET<R!O=VX@8V%P
M86)I;&ET:65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%R
M<F%Y(&QI<W1I;F<@=&AE(&ET96US('-O=6=H="X*("`@("`J("`@("`@("`@
M("`@("`@("!!($1"($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971,:7-T3V8H)'1Y<&4I"B`@("!["B`@("`@
M("`@)'-Q;"`]("1T:&ES+3YG9713<&5C:6%L475E<GDH)'1Y<&4I.PH@("`@
M("`@(&EF("@D<W%L(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3YL
M87-T7W%U97)Y(#T@)R<["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E]53E-54%!/4E1%1"D["B`@("`@("`@?2!E;'-E
M:68@*&ES7VEN="@D<W%L*2!\?"!$0CHZ:7-%<G)O<B@D<W%L*2D@>PH@("`@
M("`@("`@("`O+R!0<F5V:6]U<R!E<G)O<@H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)'-Q;"D["B`@("`@("`@?2!E;'-E:68@*&ES
M7V%R<F%Y*"1S<6PI*2!["B`@("`@("`@("`@("\O($%L<F5A9'D@=&AE(')E
M<W5L=`H@("`@("`@("`@("!R971U<FX@)'-Q;#L*("`@("`@("!]"B`@("`@
M("`@+R\@3&%U;F-H('1H:7,@<75E<GD*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$-O;"@D<W%L*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@
M<75E<GD@<W1R:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@
M;V8@;V)J96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M('1H92!K:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I
M;F<@;W(@;G5L;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@
M("`@("`@("`@("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@
M1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27U5.4U504$]25$5$*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!?<G1R:6U!<G)A>59A;'5E<R@I"@H@
M("`@+RHJ"B`@("`@*B!2:6=H="UT<FEM<R!A;&P@<W1R:6YG<R!I;B!A;B!A
M<G)A>0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D87)R87D@('1H92!A
M<G)A>2!T;R!B92!T<FEM;65D("AP87-S960@8GD@<F5F97)E;F-E*0H@("`@
M("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R=')I;4%R<F%Y5F%L
M=65S*"8D87)R87DI"B`@("!["B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("AI<U]S=')I;F<H
M)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)&%R<F%Y6R1K97E=(#T@<G1R
M:6TH)'9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O
M16UP='DH*0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@86QL(&YU;&P@=F%L
M=65S(&EN(&%N(&%R<F%Y('1O(&5M<'1Y('-T<FEN9W,*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@("1A<G)A>2`@=&AE(&%R<F%Y('1O(&)E(&1E+6YU
M;&QI9FEE9"`H<&%S<V5D(&)Y(')E9F5R96YC92D*("`@("`J"B`@("`@*B!`
M<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O
M16UP='DH)B1A<G)A>2D*("`@('L*("`@("`@("!F;W)E86-H("@D87)R87D@
M87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)&%R<F%Y6R1K97E=(#T@)R<[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"GT*
M"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M
M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]F8G-Q;"YP:'``````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-34V-0`Q,#4Q-30S,3`U
M-P`P,3<T-C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%
M05(@1$(@9')I=F5R(&9O<B!02%`G<R!F8G-Q;"!E>'1E;G-I;VX*("H@9F]R
M(&EN=&5R86-T:6YG('=I=&@@1G)O;G1"87-E(&1A=&%B87-E<PH@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1G)A;FL@
M32X@2W)O;6%N;B`\9G)A;FM`9G)O;G1B87-E+F-O;3X*("H@0&%U=&AO<B`@
M("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&9B<W%L+G!H<"QV
M(#$N.#(@,C`P-2\P,R\P-"`R,SHQ,CHS-B!D86YI96QC($5X<"`D"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*
M"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C86X@
M8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN
M<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@:6YT
M97)A8W0@=VET:"!02%`G<R!F8G-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R
M86-T:6YG('=I=&@@1G)O;G1"87-E(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M
M971H;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO
M;BX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@
M1$(*("H@0&%U=&AO<B`@("`@1G)A;FL@32X@2W)O;6%N;B`\9G)A;FM`9G)O
M;G1B87-E+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+T1""B`J($!S:6YC92`@("`@($-L87-S(&9U;F-T
M:6]N86P@<VEN8V4@4F5L96%S92`Q+C<N,`H@*B\*8VQA<W,@1$)?9F)S<6P@
M97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@
M("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C:3@L
M(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)'!H<'1Y<&4@/2`G9F)S<6PG.PH*("`@("\J*@H@("`@("H@5&AE(&1A
M=&%B87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S
M+"!E=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)&1B<WEN=&%X(#T@)V9B<W%L)SL*"B`@("`O*BH*("`@("`J(%1H
M92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@
M("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE
M(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@("`J(&YE=U]L
M:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF
M(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T
M:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L871E)R`](&5M
M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L
M=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@
M(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@
M("`@("`@(#T^("=A;'1E<B<L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("=N=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@("`@
M("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@("`@("`@("=P<F5P87)E
M)R`@("`@("`]/B!F86QS92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^('1R=64L"B`@("`I
M.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV92!E<G)O<B!C
M;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@("`@("`@
M,C(@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`X-2`]/B!$0E]%4E)/
M4E]!3%)%04197T5825-44RP*("`@("`@("`Q,#@@/3X@1$)?15)23U)?4UE.
M5$%8+`H@("`@("`@(#$Q-B`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@
M("`@("`Q,C0@/3X@1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@
M("`@(#(Q-2`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`R,3<@
M/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@("`@("`@,C(V(#T^($1"
M7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@(#(S,2`]/B!$0E]%4E)/4E])
M3E9!3$E$+`H@("`@("`@(#(S.2`]/B!$0E]%4E)/4E]44E5.0T%4140L"B`@
M("`@("`@,C4Q(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`R-C8@/3X@
M1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@(#,U-R`]/B!$0E]%4E)/4E]#
M3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@(#,U."`]/B!$0E]%4E)/4E]#
M3TY35%)!24Y4+`H@("`@("`@(#,V,"`]/B!$0E]%4E)/4E]#3TY35%)!24Y4
M+`H@("`@("`@(#,V,2`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@*3L*
M"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C
M<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@
M("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN
M9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@
M("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C
M;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!$0E]F8G-Q;"@I"B`@("!["B`@("`@("`@)'1H
M:7,M/D1"7V-O;6UO;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4@<V5R=F5R+"!L;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@
M("`@*@H@("`@("H@1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@
M(%5S92!$0CHZ8V]N;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1D<VX@("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@
M("`@("H@0'!A<F%M(&)O;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O
M;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D
M<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ
M;&]A9$5X=&5N<VEO;B@G9F)S<6PG*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&3U5.
M1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@
M("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI
M<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@('T*"B`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`D9'-N6R=H;W-T
M<W!E8R==(#\@)&1S;ELG:&]S='-P96,G72`Z("=L;V-A;&AO<W0G+`H@("`@
M("`@("`@("`D9'-N6R=U<V5R;F%M92==(#\@)&1S;ELG=7-E<FYA;64G72`Z
M(&YU;&PL"B`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UT@/R`D9'-N6R=P
M87-S=V]R9"==(#H@;G5L;"P*("`@("`@("`I.PH*("`@("`@("`D8V]N;F5C
M=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)V9B<W%L7W!C;VYN96-T)R`Z
M("=F8G-Q;%]C;VYN96-T)SL*"B`@("`@("`@)&EN:2`](&EN:5]G970H)W1R
M86-K7V5R<F]R<R<I.PH@("`@("`@("1P:'!?97)R;W)M<V<@/2`G)SL*("`@
M("`@("!I9B`H)&EN:2D@>PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO
M;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO;BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@("`@("`@("1T
M:&ES+3YC;VYN96-T:6]N(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1C;VYN
M96-T7V9U;F-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US*3L*("`@("`@("`@("`@
M:6YI7W-E="@G=')A8VM?97)R;W)S)RP@)&EN:2D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%
M1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL
M(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&AP7V5R<F]R;7-G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M9'-N6R=D871A8F%S92==*2!["B`@("`@("`@("`@(&EF("@A0&9B<W%L7W-E
M;&5C=%]D8B@D9'-N6R=D871A8F%S92==+"`D=&AI<RT^8V]N;F5C=&EO;BDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F)S<6Q286ES945R
M<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C;VYN
M96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A
M=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`9F)S
M<6Q?8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC
M;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ
M"B`@("`@*B!396YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T
M<FEN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S
M=6QT(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@
M("`@*B`@("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@
M;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@
M("`K(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@
M9G5N8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1T
M:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T
M:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@("1R97-U;'0@/2!`
M9F)S<6Q?<75E<GDH(B1Q=65R>3LB+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^9F)S<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("\O($1E
M=&5R;6EN92!W:&EC:"!Q=65R:65S('1H870@<VAO=6QD(')E='5R;B!D871A
M+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R
M(&-O9&4@;VYL>2X*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@
M>PH@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N
M86P@9F)S<6P@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE
M(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A;&ED(&9B<W%L(')E
M<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL
M86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@
M0&9B<W%L7VYE>'1?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C
M97,@82!R;W<@9G)O;2!T:&4@<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A
M<G)A>0H@("`@("H*("`@("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD
M('1H92!D871A('1H97)E:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E
M92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B
M92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T
M8VA);G1O*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T
M96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L
M="`@("!T:&4@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@
M87)R87D@("`@)&%R<B`@("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P
M=70@=&AE(&1A=&$@:6X*("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM
M;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D
M"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU
M;6)E<B!T;R!F971C:"`H,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!$0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE
M(&5N9"!O9B!A(')E<W5L="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@
M("!R96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"
M7W)E<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T
M8VA);G1O*"1R97-U;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H)')O=VYU;2`A/3T@;G5L;"D@>PH@
M("`@("`@("`@("!I9B`H(4!F8G-Q;%]D871A7W-E96LH)')E<W5L="P@)')O
M=VYU;2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("8@1$)?
M1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1A<G(@/2!`9F)S<6Q?
M9F5T8VA?87)R87DH)')E<W5L="P@1D)344Q?05-33T,I.PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)4
M04))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@("`@("`@("`@
M)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/5T52
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1A<G(@/2!`9F)S<6Q?9F5T8VA?<F]W*"1R97-U;'0I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?
M4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!$96QE
M=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y(&]C8W5P
M:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@
M("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E
M(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L
M="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L
M($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E
M95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`9F)S<6Q?
M9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R
M(&1I<V%B;&5S(&%U=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VP@)&]N;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N
M<R!I="!O9F8*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@
M("`J("`@("`@("`@("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET
M=&EN9R!T<F%N<V%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#
M;VUM:70H)&]N;V9F/69A;'-E*0H@("`@>PH@("`@("`@(&EF("@D;VYO9F8I
M('L*("`@("`@("`@("`@)'1H:7,M/G%U97)Y*")3150@0T]-34E4(%12544B
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<75E<GDH
M(E-%5"!#3TU-250@1D%,4T4B*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@("`J($-O;6UI
M=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@
M("!["B`@("`@("`@0&9B<W%L7V-O;6UI="@I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J(%)E=F5R
M=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O;&QB86-K*"D*
M("`@('L*("`@("`@("!`9F)S<6Q?<F]L;&)A8VLH*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E
M=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL
M960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I
M(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@
M("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S
M('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@
M:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN
M=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT
M*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&9B<W%L7VYU;5]F:65L9',H)')E
M<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@
M<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@
M("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@
M8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S
M=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R
M8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R
M;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*("`@("`@("`D<F]W<R`]
M($!F8G-Q;%]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H)')O=W,@
M/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF8G-Q;%)A
M:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D4F]W<R@I"@H@
M("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!N=6UB97(@;V8@<F]W<R!A
M9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T:6]N('%U97)Y"B`@("`@*@H@
M("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E<FEE<R!T:&%T(&1O;B=T(&UA
M;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE
M(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F96-T9612;W=S*"D*("`@('L*
M("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'1H:7,M/FQA<W1?<75E<GDI*2![
M"B`@("`@("`@("`@("1R97-U;'0@/2!`9F)S<6Q?869F96-T961?<F]W<R@D
M=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E<W5L="`](#`["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA
M=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E
M871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@
M("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@
M1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?
M9F)S<6PZ.F-R96%T95-E<75E;F-E*"DL($1"7V9B<W%L.CID<F]P4V5Q=65N
M8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D
M;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H
M:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@(&1O('L*
M("`@("`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@("`@("1T:&ES+3YP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH)U-%3$5#5"!53DE1544@1E)/
M32`G("X@)'-E<6YA;64I.PH@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(
M86YD;&EN9R@I.PH@("`@("`@("`@("!I9B`H)&]N9&5M86YD("8F($1".CII
M<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@("`D<F5S=6QT+3YG
M971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I('L*("`@("`@("`@
M("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@
M("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@
M,#L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E870I.PH@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("`D<F5S=6QT+3YF971C:$EN=&\H)'1M<"P@1$)?1D540TA-3T1%
M7T]21$52140I.PH@("`@("`@(')E='5R;B`D=&UP6S!=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!N97<@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL($1"
M7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V9B
M<W%L.CIN97AT240H*2P@1$)?9F)S<6PZ.F1R;W!397%U96YC92@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@
M('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H
M)'-E<5]N86UE*3L*("`@("`@("`D<F5S(#T@)'1H:7,M/G%U97)Y*"=#4D5!
M5$4@5$%"3$4@)R`N("1S97%N86UE"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("<@*&ED($E.5$5'15(@3D]4($Y53$PL)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G(%!224U!4ED@2T59*&ED*2DG*3L*("`@("`@
M("!I9B`H)')E<RD@>PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/G%U97)Y
M*"=3150@54Y)455%(#T@,"!&3U(@)R`N("1S97%N86UE*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9')O<%-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@
M82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N
M86UE("!N86UE(&]F('1H92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U
M96YC94YA;64H*2P*("`@("`J("`@("`@1$)?9F)S<6PZ.FYE>'1)1"@I+"!$
M0E]F8G-Q;#HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N("1T:&ES+3YG971397%U
M96YC94YA;64H)'-E<5]N86UE*0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G(%)%4U1224-4)RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!!9&1S($Q)
M34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D:6YG('1O(&-U
M<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M;V1I9GD*("`@("`J($!P87)A
M;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R="!T;R!F971C:&EN
M9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`<&%R86T@:6YT("`@("1C
M;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*("`@("`J($!P
M87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC
M(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N=&ET>2!O
M9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%S<V5D
M(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@,2!P
M;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD97(@<&5R(&%R
M<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H
M92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C;&%U<V5S(&%D9&5D"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N8W1I
M;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U;G0L("1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI
M<"@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H
M)R]>*%M<<RA=*2I314Q%0U0O:2<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(EQ<,5-%3$5#5"!43U`H)&-O=6YT*2(L("1Q=65R>2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C
M92@G+RA;7',H72DJ4T5,14-4+VDG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(")<7#%314Q%0U0@5$]0*"1F<F]M+"`D8V]U;G0I(BP@)'%U
M97)Y*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<75O=&53;6%R="@I"@H@("`@+RHJ"B`@("`@*B!&;W)M871S(&EN<'5T('-O
M(&ET(&-A;B!B92!S869E;'D@=7-E9"!I;B!A('%U97)Y"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1I;B`@=&AE(&1A=&$@=&\@8F4@9F]R;6%T=&5D
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@=&AE(&9O<FUA='1E9"!D
M871A+B`@5&AE(&9O<FUA="!D97!E;F1S(&]N('1H92!I;G!U="=S"B`@("`@
M*B`@("`@("`@("`@("`@("`@4$A0('1Y<&4Z"B`@("`@*B`@("`@("`@("`@
M("`@("`@*R!N=6QL(#T@=&AE('-T<FEN9R`\<V%M<#Y.54Q,/"]S86UP/@H@
M("`@("H@("`@("`@("`@("`@("`@("L@8F]O;&5A;B`]('-T<FEN9R`\<V%M
M<#Y44E5%/"]S86UP/B!O<B`\<V%M<#Y&04Q313PO<V%M<#X*("`@("`J("`@
M("`@("`@("`@("`@("`K(&EN=&5G97(@;W(@9&]U8FQE(#T@=&AE('5N<75O
M=&5D(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("L@;W1H97(@*&EN
M8VQU9&EN9R!S=')I;F=S(&%N9"!N=6UE<FEC('-T<FEN9W,I(#T*("`@("`J
M("`@("`@("`@("`@("`@("`@('1H92!D871A(&5S8V%P960@86-C;W)D:6YG
M('1O($9R;VYT0F%S92=S('-E='1I;F=S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("!T:&5N(&5N8V%P<W5L871E9"!B971W965N('-I;F=L92!Q=6]T97,*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I"B`@
M("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E4VUA<G0H)&EN*0H@("`@
M>PH@("`@("`@(&EF("AI<U]I;G0H)&EN*2!\?"!I<U]D;W5B;&4H)&EN*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&EN.PH@("`@("`@('T@96QS96EF("AI
M<U]B;V]L*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I;B`_("=44E5%
M)R`Z("=&04Q312<["B`@("`@("`@?2!E;'-E:68@*&ES7VYU;&PH)&EN*2D@
M>PH@("`@("`@("`@("!R971U<FX@)TY53$PG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`B)R(@+B`D=&AI<RT^97-C87!E4VEM<&QE
M*"1I;BD@+B`B)R(["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&9B<W%L4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D
M=6-E<R!A($1"7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@
M<')O8FQE;0H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T
M:&4@97)R;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R
M92X@($EF('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H
M92!$0DU3+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?
M17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A
M:7-E17)R;W(H*2P*("`@("`J("`@("`@1$)?9F)S<6PZ.F5R<F]R3F%T:79E
M*"DL($1"7V-O;6UO;CHZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9F)S<6Q286ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D97)R;F\@
M/2`D=&AI<RT^97)R;W)#;V1E*&9B<W%L7V5R<FYO*"1T:&ES+3YC;VYN96-T
M:6]N*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($!F8G-Q;%]E<G)O<B@D=&AI<RT^8V]N;F5C
M=&EO;BDI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T
M:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E
M<G)O<B!C;V1E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!$0DU3)R!E<G)O<B!C;V1E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R
M971U<FX@0&9B<W%L7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG
M("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN
M9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A
M8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H
M879I;W(@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D
M;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@
M:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O
M*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA
M;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I
M9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@
M0&9B<W%L7VQI<W1?9FEE;&1S*"1T:&ES+3YD<VY;)V1A=&%B87-E)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT+"`D
M=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@
M=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S=6QT
M*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R
M96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X=')A
M8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@("`@
M("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I
M=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@
M("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')E8V%T960N("!(97)E
M(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN
M9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C
M92@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F)S<6Q286ES
M945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"
M7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F
M=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@
M("1C;W5N="`]($!F8G-Q;%]N=6U?9FEE;&1S*"1I9"D["B`@("`@("`@)')E
M<R`@(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@
M("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@
M("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A
M8FQE)R`]/B`D8V%S95]F=6YC*$!F8G-Q;%]F:65L9%]T86)L92@D:60L("1I
M*2DL"B`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1C87-E7V9U;F,H0&9B
M<W%L7V9I96QD7VYA;64H)&ED+"`D:2DI+`H@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B!`9F)S<6Q?9FEE;&1?='EP92@D:60L("1I*2P*("`@("`@("`@
M("`@("`@("=L96XG("`@/3X@0&9B<W%L7V9I96QD7VQE;B@D:60L("1I*2P*
M("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@0&9B<W%L7V9I96QD7V9L86=S
M*"1I9"P@)&DI+`H@("`@("`@("`@("`I.PH@("`@("`@("`@("!I9B`H)&UO
M9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("1R
M97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$
M15)404),12D@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97)T86)L92==
M6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R
M97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@
M("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@("`@($!F8G-Q;%]F<F5E
M7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L475E<GDH
M*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R:6YG(&YE
M961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T<PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD(&]F(&]B
M:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@;W(@;G5L;"!I9B!T
M:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@("`@<W5P
M<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIG971,
M:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L475E<GDH
M)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@
M("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=3
M14Q%0U0@(G1A8FQE7VYA;64B($923TT@:6YF;W)M871I;VY?<V-H96UA+G1A
M8FQE<R<*("`@("`@("`@("`@("`@("`@("`@("`N("<@=#`L(&EN9F]R;6%T
M:6]N7W-C:&5M82YS8VAE;6%T82!T,2<*("`@("`@("`@("`@("`@("`@("`@
M("`N("<@5TA%4D4@=#`N<V-H96UA7W!K/70Q+G-C:&5M85]P:R!!3D0G"B`@
M("`@("`@("`@("`@("`@("`@("`@+B`G(")T86)L95]T>7!E(B`](%PG0D%3
M12!404),15PG)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!!3D0@(G-C
M:&5M85]N86UE(B`](&-U<G)E;G1?<V-H96UA)SL*("`@("`@("`@("`@8V%S
M92`G=FEE=W,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@(G1A
M8FQE7VYA;64B($923TT@:6YF;W)M871I;VY?<V-H96UA+G1A8FQE<R<*("`@
M("`@("`@("`@("`@("`@("`@("`N("<@=#`L(&EN9F]R;6%T:6]N7W-C:&5M
M82YS8VAE;6%T82!T,2<*("`@("`@("`@("`@("`@("`@("`@("`N("<@5TA%
M4D4@=#`N<V-H96UA7W!K/70Q+G-C:&5M85]P:R!!3D0G"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`G(")T86)L95]T>7!E(B`](%PG5DE%5UPG)PH@("`@
M("`@("`@("`@("`@("`@("`@("X@)R!!3D0@(G-C:&5M85]N86UE(B`](&-U
M<G)E;G1?<V-H96UA)SL*("`@("`@("`@("`@8V%S92`G=7-E<G,G.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@(G5S97)?;F%M92(@9G)O;2!I
M;F9O<FUA=&EO;E]S8VAE;6$N=7-E<G,G.R`*("`@("`@("`@("`@8V%S92`G
M9G5N8W1I;VYS)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4(")R
M;W5T:6YE7VYA;64B($923TTG"B`@("`@("`@("`@("`@("`@("`@("`@+B`G
M(&EN9F]R;6%T:6]N7W-C:&5M82YP<VU?<F]U=&EN97,G"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`G('0P+"!I;F9O<FUA=&EO;E]S8VAE;6$N<V-H96UA
M=&$@=#$G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G(%=(15)%('0P+G-C
M:&5M85]P:SUT,2YS8VAE;6%?<&LG"B`@("`@("`@("`@("`@("`@("`@("`@
M+B`G($%.1"`B<F]U=&EN95]K:6YD(CU<)T953D-424].7"<G"B`@("`@("`@
M("`@("`@("`@("`@("`@+B`G($%.1"`B<V-H96UA7VYA;64B(#T@8W5R<F5N
M=%]S8VAE;6$G.PH@("`@("`@("`@("!C87-E("=P<F]C961U<F5S)SH*("`@
M("`@("`@("`@("`@(')E='5R;B`G4T5,14-4(")R;W5T:6YE7VYA;64B($92
M3TTG"B`@("`@("`@("`@("`@("`@("`@("`@+B`G(&EN9F]R;6%T:6]N7W-C
M:&5M82YP<VU?<F]U=&EN97,G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G
M('0P+"!I;F9O<FUA=&EO;E]S8VAE;6$N<V-H96UA=&$@=#$G"B`@("`@("`@
M("`@("`@("`@("`@("`@+B`G(%=(15)%('0P+G-C:&5M85]P:SUT,2YS8VAE
M;6%?<&LG"B`@("`@("`@("`@("`@("`@("`@("`@+B`G($%.1"`B<F]U=&EN
M95]K:6YD(CU<)U!23T-%1%5215PG)PH@("`@("`@("`@("`@("`@("`@("`@
M("X@)R!!3D0@(G-C:&5M85]N86UE(B`](&-U<G)E;G1?<V-H96UA)SL*("`@
M("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*?0H*+RH*("H@3&]C86P@
M=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z
M(#0*("H@16YD.@H@*B\*"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O1$(O:6)A<V4N<&AP````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q,#$U-#``,3`U,34T,S$P-3<`,#$W-#(S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R:79E
M<B!F;W(@4$A0)W,@:6YT97)B87-E(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A
M8W1I;F<@=VET:"!);G1E<F)A<V4@86YD($9I<F5B:7)D(&1A=&%B87-E<PH@
M*@H@*B!7:&EL92!T:&ES(&-L87-S('=O<FMS('=I=&@@4$A0(#0L(%!(4"=S
M($EN=&5R0F%S92!E>'1E;G-I;VX@:7,*("H@=6YS=&%B;&4@:6X@4$A0(#0N
M("!5<V4@4$A0(#4N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@
M*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@
M*B!`875T:&]R("`@("!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H<"YN
M970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!I8F%S92YP:'`L=B`Q+C$P.2`R,#`U+S`S+S`T(#(S.C$R.C,V(&1A
M;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?8V]M;6]N
M(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E
M7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H;V1S(%!%
M05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S(&EN=&5R8F%S92!E
M>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@26YT97)B87-E(&%N
M9"!&:7)E8FER9"!D871A8F%S97,*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R
M;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J(%=H
M:6QE('1H:7,@8VQA<W,@=V]R:W,@=VET:"!02%`@-"P@4$A0)W,@26YT97)"
M87-E(&5X=&5N<VEO;B!I<PH@*B!U;G-T86)L92!I;B!02%`@-"X@(%5S92!0
M2%`@-2X*("H*("H@3D]424-%.B`@;&EM:711=65R>2@I(&]N;'D@=V]R:W,@
M9F]R($9I<F5B:7)D+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`
M<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&5R;&EN9R!(=6=H97,@
M/'-T97)L:6YG0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B!`<VEN8V4@("`@("!#;&%S
M<R!B96-A;64@<W1A8FQE(&EN(%)E;&5A<V4@,2XW+C`*("HO"F-L87-S($1"
M7VEB87-E(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T
M:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L
M+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1P:'!T>7!E(#T@)VEB87-E)SL*"B`@("`O*BH*("`@("`J
M(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!B92!U<V5D("AD8C(L
M(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=I8F%S92<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I
M;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A
M:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@
M*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F
M86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI
M;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T
M92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@
M("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A
M;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@("`J($Y/5$4Z(&]N;'D@
M9FER96)I<F0@<W5P<&]R=',@;&EM:70N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@
M("`@)VQI;6ET)R`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N97=?;&EN
M:R<@("`@("`]/B!F86QS92P*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@
M)V5M=6QA=&4G+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@
M("`@("`@("=P<F5P87)E)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=S<VPG
M("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A8W1I;VYS)R`@
M/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA<'!I;F<@;V8@
M;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C;V1E7VUA<"`](&%R
M<F%Y*`H@("`@("`@("TQ,#0@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@
M("TQ-3`@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`M
M,34Q(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@+3$U
M-2`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`M,34W(#T^($1"
M7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("TQ-3@@/3X@1$)?15)23U)?
M5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("TQ-S`@/3X@1$)?15)23U)?
M34E334%40T@L"B`@("`@("`@+3$W,2`]/B!$0E]%4E)/4E]-25--051#2"P*
M("`@("`@("`M,3<R(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@+R\@
M+3(P-"`]/B`@+R\@0V]V97)S('1O;R!M86YY(&5R<F]R<RP@;F5E9"!T;R!U
M<V4@<F5G97@@;VX@;7-G"B`@("`@("`@+3(P-2`]/B!$0E]%4E)/4E].3U-5
M0TA&245,1"P*("`@("`@("`M,C`V(#T^($1"7T524D]27TY/4U5#2$9)14Q$
M+`H@("`@("`@("TR,#@@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`M
M,C$Y(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@("TR.3<@/3X@
M1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`M,S`S(#T^($1"7T524D]2
M7TE.5D%,240L"B`@("`@("`@+30Q,R`]/B!$0E]%4E)/4E])3E9!3$E$7TY5
M34)%4BP*("`@("`@("`M-3,P(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@
M("`@("`@+34U,2`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@
M("`@("TU-3(@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@
M("`O+R`M-C`W(#T^("`O+R!#;W9E<G,@=&]O(&UA;GD@97)R;W)S+"!N965D
M('1O('5S92!R96=E>"!O;B!M<V<*("`@("`@("`M-C(U(#T^($1"7T524D]2
M7T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@+3@P,R`]/B!$0E]%4E)/
M4E]#3TY35%)!24Y4+`H@("`@("`@("TX,#0@/3X@1$)?15)23U)?5D%,545?
M0T]53E1?3TY?4D]7+`H@("`@("`@("TY,#0@/3X@1$)?15)23U)?0T].3D5#
M5%]&04E,140L"B`@("`@("`@+3DR,B`]/B!$0E]%4E)/4E].3U-50TA$0BP*
M("`@("`@("`M.3(S(#T^($1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@
M("`@("TY,C0@/3X@1$)?15)23U)?0T].3D5#5%]&04E,140*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E
M871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@
M=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O
M<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@
M("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@
M82!D871A(&UA;FEP=6QA=&EO;B!Q=65R>0H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1A9F9E
M8W1E9"`](#`["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L
M871I;VX@<75E<FEE<R!B92!C;VUM:71T960@875T;VUA=&EC86QL>3\*("`@
M("`J($!V87(@8F]O;`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D875T;V-O;6UI="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<')E<&%R960@<W1A=&5M96YT(&AA;F1L92!F<F]M('1H92!M;W-T(')E
M8V5N=&QY(&5X96-U=&5D('-T871E;65N=`H@("`@("H*("`@("`J('M`:6YT
M97)N86P@($UA:6YL>2!H97)E(&)E8V%U<V4@=&AE($EN=&5R0F%S92]&:7)E
M8FER9"!!4$D@:7,@;VYL>0H@("`@("H@86)L92!T;R!R971R:65V92!D871A
M(&9R;VT@<F5S=6QT('-E=',@:68@=&AE('-T871E;6YT(&AA;F1L92!I<PH@
M("`@("H@<W1I;&P@:6X@<V-O<&4N?7T*("`@("`J"B`@("`@*B!`=F%R(')E
M<V]U<F-E"B`@("`@*B\*("`@('9A<B`D;&%S=%]S=&UT.PH*("`@("\J*@H@
M("`@("H@27,@=&AE(&=I=F5N('!R97!A<F5D('-T871E;65N="!A(&1A=&$@
M;6%N:7!U;&%T:6]N('%U97)Y/PH@("`@("H@0'9A<B!A<G)A>0H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D;6%N:7!?<75E<GD@
M/2!A<G)A>2@I.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O
M<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D
M/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U
M<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]I8F%S92@I"B`@("![
M"B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L;V<@:6X@86YD(&]P96X@=&AE
M(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N)W0@8V%L;"!T:&ES(&UE=&AO
M9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C="@I(&EN<W1E860N"B`@("`@
M*@H@("`@("H@4$5!4B!$0B=S(&EB87-E(&1R:79E<B!S=7!P;W)T<R!T:&4@
M9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@("H@("`K(&)U9F9E
M<G,@("`@5&AE(&YU;6)E<B!O9B!D871A8F%S92!B=69F97)S('1O(&%L;&]C
M871E(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("!S97)V97(M<VED
M92!C86-H92X*("`@("`J("`@*R!C:&%R<V5T("`@(%1H92!D969A=6QT(&-H
M87)A8W1E<B!S970@9F]R(&$@9&%T86)A<V4N"B`@("`@*B`@("L@9&EA;&5C
M="`@("!4:&4@9&5F875L="!344P@9&EA;&5C="!F;W(@86YY('-T871E;65N
M=`H@("`@("H@("`@("`@("`@("`@("`@(&5X96-U=&5D('=I=&AI;B!A(&-O
M;FYE8W1I;VXN("!$969A=6QT<R!T;R!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("!H:6=H97-T(&]N92!S=7!P;W)T960@8GD@8VQI96YT(&QI8G)A<FEE
M<RX*("`@("`J("`@("`@("`@("`@("`@("!&=6YC=&EO;F%L(&]N;'D@=VET
M:"!);G1E<D)A<V4@-B!A;F0@=7`N"B`@("`@*B`@("L@<F]L92`@("`@("!&
M=6YC=&EO;F%L(&]N;'D@=VET:"!);G1E<D)A<V4@-2!A;F0@=7`N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@("`@("!T:&4@9&%T82!S
M;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@("1P97)S:7-T96YT("!S
M:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N
M;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G:6YT97)B87-E)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T58
M5$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/F1S;B`]("1D<VX["B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*
M("`@("`@("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G
M73L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YD8G-Y;G1A>"`]/2`G
M9FER96)I<F0G*2!["B`@("`@("`@("`@("1T:&ES+3YF96%T=7)E<ULG;&EM
M:70G72`]("=A;'1E<B<["B`@("`@("`@?0H*("`@("`@("`D<&%R86US(#T@
M87)R87DH"B`@("`@("`@("`@("1D<VY;)VAO<W1S<&5C)UT*("`@("`@("`@
M("`@("`@("`@("`_("@D9'-N6R=H;W-T<W!E8R==("X@)SHG("X@)&1S;ELG
M9&%T86)A<V4G72D*("`@("`@("`@("`@("`@("`@("`Z("1D<VY;)V1A=&%B
M87-E)UTL"B`@("`@("`@("`@("1D<VY;)W5S97)N86UE)UT@/R`D9'-N6R=U
M<V5R;F%M92==(#H@;G5L;"P*("`@("`@("`@("`@)&1S;ELG<&%S<W=O<F0G
M72`_("1D<VY;)W!A<W-W;W)D)UT@.B!N=6QL+`H@("`@("`@("`@("!I<W-E
M="@D9'-N6R=C:&%R<V5T)UTI(#\@)&1S;ELG8VAA<G-E="==(#H@;G5L;"P*
M("`@("`@("`@("`@:7-S970H)&1S;ELG8G5F9F5R<R==*2`_("1D<VY;)V)U
M9F9E<G,G72`Z(&YU;&PL"B`@("`@("`@("`@(&ES<V5T*"1D<VY;)V1I86QE
M8W0G72D@/R`D9'-N6R=D:6%L96-T)UT@.B!N=6QL+`H@("`@("`@("`@("!I
M<W-E="@D9'-N6R=R;VQE)UTI("`@(#\@)&1S;ELG<F]L92==(#H@;G5L;"P*
M("`@("`@("`I.PH*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S
M:7-T96YT(#\@)VEB87-E7W!C;VYN96-T)R`Z("=I8F%S95]C;VYN96-T)SL*
M"B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?
M87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL("1P87)A;7,I.PH@("`@("`@(&EF
M("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YI8F%S95)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@
M*B!$:7-C;VYN96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@
M;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*
M("`@('L*("`@("`@("`D<F5T(#T@0&EB87-E7V-L;W-E*"1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@
M("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R
M>2!T;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C
M8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@
M*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E
M<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y
M*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP
M*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD[
M"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D[
M"B`@("`@("`@)')E<W5L="`]($!I8F%S95]Q=65R>2@D=&AI<RT^8V]N;F5C
M=&EO;BP@)'%U97)Y*3L*"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(&EF("@D=&AI<RT^875T;V-O;6UI="`F)B`D:7-M86YI
M<"D@>PH@("`@("`@("`@("!`:6)A<V5?8V]M;6ET*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("!]"B`@("`@("`@:68@*"1I<VUA;FEP*2!["B`@("`@
M("`@("`@("1T:&ES+3YA9F9E8W1E9"`]("1R97-U;'0["B`@("`@("`@("`@
M(')E='5R;B!$0E]/2SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^869F96-T960@/2`P.PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;6]D
M:69Y3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!!9&1S($Q)34E4(&-L
M875S97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D:6YG('1O(&-U<G)E;G0@
M1$)-4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!/;FQY('=O<FMS('=I=&@@
M1FER96)I<F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@
M("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT("`@("1F
M<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@/2!T:&4@
M9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@("!T:&4@
M;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@;6EX960@
M("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E
M('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U
M=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H
M('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@
M9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75E<GD@<W1R
M:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@("H*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>4QI
M;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F1S;ELG9&)S>6YT87@G
M72`]/2`G9FER96)I<F0G*2!["B`@("`@("`@("`@("1Q=65R>2`]('!R96=?
M<F5P;&%C92@G+UXH6UQS*%TI*E-%3$5#5"]I)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(")314Q%0U0@1DE24U0@)&-O=6YT(%-+25`@
M)&9R;VTB+"`D<75E<GDI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'%U
M97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H
M*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@:6)A<V4@<F5S
M=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@
M("H*("`@("`J($!P87)A;2!A('9A;&ED(&9B<W%L(')E<W5L="!R97-O=7)C
M90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@
M0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I
M<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U
M;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*
M("`@("`J(%!L86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@
M=&AE(&=I=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H
M92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE
M+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@
M:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T
M(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?
M<F5S=6QT.CIF971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C
M;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES
M(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O
M=7)C92`D<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@
M("`J($!P87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D
M(&%R<F%Y('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@
M("`@("1F971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD
M(&)E(&EN9&5X960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@
M('1H92!R;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y5
M3$P@=VAE;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@
M("`@("`@("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@
M("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L
M("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]
M/2!N=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES
M945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@
M("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G:6)A<V5?9F5T8VA?87-S
M;V,G*2D@>PH@("`@("`@("`@("`@("`@)&%R<B`]($!I8F%S95]F971C:%]A
M<W-O8R@D<F5S=6QT*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1A<G(@/2!G971?;V)J96-T7W9A<G,H:6)A<V5?9F5T8VA?;V)J
M96-T*"1R97-U;'0I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E4
M65],3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@("`@("`@("`@)&%R<B`]
M(&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/5T52*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A<G(@
M/2!`:6)A<V5?9F5T8VA?<F]W*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG
M72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"
M24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O
M;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H
M92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y
M('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@
M;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@
M1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA
M<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A
M('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%
M(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L
M="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`:6)A<V5?9G)E95]R
M97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9G)E95%U97)Y*"D*"B`@("!F=6YC=&EO;B!F<F5E475E<GDH)'%U97)Y*0H@
M("`@>PH@("`@("`@($!I8F%S95]F<F5E7W%U97)Y*"1Q=65R>2D["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE
M(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I
M;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R
M:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E
M8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("AI<U]I;G1E9V5R*"1T:&ES
M+3YA9F9E8W1E9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YA9F9E
M8W1E9#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YI8F%S95)A
M:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE
M9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@
M:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@
M("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@
M<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU
M;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I
M"B`@("!["B`@("`@("`@)&-O;',@/2!`:6)A<V5?;G5M7V9I96QD<R@D<F5S
M=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^:6)A<V5286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P
M<F5P87)E*"D*"B`@("`O*BH*("`@("`J(%!R97!A<F5S(&$@<75E<GD@9F]R
M(&UU;'1I<&QE(&5X96-U=&EO;B!W:71H(&5X96-U=&4H*2X*("`@("`J"B`@
M("`@*B!P<F5P87)E*"D@<F5Q=6ER97,@82!G96YE<FEC('%U97)Y(&%S('-T
M<FEN9R!L:6ME(#QC;V1E/@H@("`@("H@("`@24Y315)4($E.5$\@;G5M8F5R
M<R!604Q515,@*#\L(#\L(#\I"B`@("`@*B`\+V-O9&4^+B`@5&AE(#QK8F0^
M/SPO:V)D/B!C:&%R86-T97)S(&%R92!P;&%C96AO;&1E<G,N"B`@("`@*@H@
M("`@("H@5&AR964@='EP97,@;V8@<&QA8V5H;VQD97)S(&-A;B!B92!U<V5D
M.@H@("`@("H@("`K(#QK8F0^/SPO:V)D/B`@82!Q=6]T960@<V-A;&%R('9A
M;'5E+"!I+F4N('-T<FEN9W,L(&EN=&5G97)S"B`@("`@*B`@("L@/&MB9#XA
M/"]K8F0^("!V86QU92!I<R!I;G-E<G1E9"`G87,@:7,G"B`@("`@*B`@("L@
M/&MB9#XF/"]K8F0^("!R97%U:7)E<R!A(&9I;&4@;F%M92X@(%1H92!F:6QE
M)W,@8V]N=&5N=',@9V5T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&EN
M<V5R=&5D(&EN=&\@=&AE('%U97)Y("AI+F4N('-A=FEN9R!B:6YA<GD*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@9&%T82!I;B!A(&1B*0H@("`@("H*
M("`@("`J(%5S92!B86-K<VQA<VAE<R!T;R!E<V-A<&4@<&QA8V5H;VQD97(@
M8VAA<F%C=&5R<R!I9B!Y;W4@9&]N)W0@=V%N=`H@("`@("H@=&AE;2!T;R!B
M92!I;G1E<G!R971E9"!A<R!P;&%C96AO;&1E<G,N("!%>&%M<&QE.B`\8V]D
M93X*("`@("`J("`@(")54$1!5$4@9F]O(%-%5"!C;VP]/R!72$5212!C;VP]
M)V]V97(@7"8@=6YD97(G(@H@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'%U97)Y('%U97)Y('1O(&)E('!R97!A<F5D"B`@
M("`@*B!`<F5T=7)N(&UI>&5D($1"('-T871E;65N="!R97-O=7)C92!O;B!S
M=6-C97-S+B!$0E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P<F5P87)E*"1Q=65R>2D*("`@('L*("`@("`@("`D=&]K96YS("`@
M/2!P<F5G7W-P;&ET*"<O*"@_/"%<7%PI6R8_(5TI+R<L("1Q=65R>2P@+3$L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!04D5'7U-03$E47T1%
M3$E-7T-!4%154D4I.PH@("`@("`@("1T;VME;B`@("`](#`["B`@("`@("`@
M)'1Y<&5S("`@(#T@87)R87DH*3L*("`@("`@("`D;F5W<75E<GD@/2`G)SL*
M"B`@("`@("`@9F]R96%C:"`H)'1O:V5N<R!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@<W=I=&-H("@D=F%L*2!["B`@("`@("`@("`@("`@("!C
M87-E("<_)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=
M(#T@1$)?4$%204U?4T-!3$%2.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@8V%S92`G)B<Z"B`@("`@("`@("`@("`@("`@
M("`@)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-7T]005%513L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)R$G
M.@H@("`@("`@("`@("`@("`@("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]0
M05)!35]-25-#.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`D=&]K96YS
M6R1K97E=(#T@<')E9U]R97!L86-E*"<O7%Q<*%LF/R%=*2\G+"`B7%PQ(BP@
M)'9A;"D["B`@("`@("`@("`@("`@("`@("`@)&YE=W%U97)Y("X]("1T;VME
M;G-;)&ME>5T@+B`G/R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1N97=Q=65R>2`]('-U8G-T<B@D;F5W<75E<GDL(#`L("TQ*3L*("`@
M("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D;F5W
M<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)&YE=W%U97)Y*3L*("`@("`@
M("`D<W1M="`]($!I8F%S95]P<F5P87)E*"1T:&ES+3YC;VYN96-T:6]N+"`D
M;F5W<75E<GDI.PH@("`@("`@("1T:&ES+3YP<F5P87)E7W1Y<&5S6RAI;G0I
M)'-T;71=(#T@)'1Y<&5S.PH@("`@("`@("1T:&ES+3YM86YI<%]Q=65R>5LH
M:6YT*21S=&UT72`@(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("!R
M971U<FX@)'-T;70["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97AE
M8W5T92@I"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A($1"('-T871E;65N
M="!P<F5P87)E9"!W:71H('!R97!A<F4H*2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<F5S;W5R8V4@("1S=&UT("!A($1"('-T871E;65N="!R97-O=7)C92!R
M971U<FYE9"!F<F]M('!R97!A<F4H*0H@("`@("H@0'!A<F%M(&UI>&5D("`D
M9&%T82`@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E
M9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F
M('1H92!S=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@
M;V8@<&QA8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!Q=65R>3H@(&UE86YI;F<@,2!F;W(@;F]N+6%R<F%Y(&ET96US(&]R('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@<75A;G1I='D@;V8@96QE
M;65N=',@:6X@=&AE(&%R<F%Y+@H@("`@("H@0')E='5R;B!O8FIE8W0@(&$@
M;F5W($1"7U)E<W5L="!O<B!A($1"7T5R<F]R('=H96X@9F%I;`H@("`@("H@
M0'-E92!$0E]I8F%S93HZ<')E<&%R92@I"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B`F97AE8W5T92@D<W1M="P@)&1A=&$@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D871A(#T@*&%R<F%Y*21D871A
M.PH@("`@("`@("1T:&ES+3YL87-T7W!A<F%M971E<G,@/2`D9&%T83L*"B`@
M("`@("`@)'1Y<&5S(#TF("1T:&ES+3YP<F5P87)E7W1Y<&5S6RAI;G0I)'-T
M;71=.PH@("`@("`@(&EF("AC;W5N="@D='EP97,I("$](&-O=6YT*"1D871A
M*2D@>PH@("`@("`@("`@("`D=&UP(#TF("1T:&ES+3YR86ES945R<F]R*$1"
M7T524D]27TU)4TU!5$-(*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@
M("`@("`@?0H*("`@("`@("`D:2`](#`["B`@("`@("`@9F]R96%C:"`H)&1A
M=&$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*"1T>7!E
M<ULD:5T@/3T@1$)?4$%204U?34E30RD@>PH@("`@("`@("`@("`@("`@+RH*
M("`@("`@("`@("`@("`@("`J(&EB87-E(&1O97-N)W0@<V5E;2!T;R!H879E
M('1H92!A8FEL:71Y('1O('!A<W,@80H@("`@("`@("`@("`@("`@("H@<&%R
M86UE=&5R(&%L;VYG('5N8VAA;F=E9"P@<V\@<W1R:7`@;V9F('%U;W1E<R!F
M<F]M('-T87)T"B`@("`@("`@("`@("`@("`@*B!A;F0@96YD+"!P;'5S('1U
M<FX@='=O('-I;F=L92!Q=6]T97,@=&\@;VYE('-I;F=L92!Q=6]T92P*("`@
M("`@("`@("`@("`@("`J(&EN(&]R9&5R('1O(&%V;VED('1H92!Q=6]T97,@
M9V5T=&EN9R!E<V-A<&5D(&)Y"B`@("`@("`@("`@("`@("`@*B!I8F%S92!A
M;F0@96YD:6YG('5P(&EN('1H92!D871A8F%S92X*("`@("`@("`@("`@("`@
M("`J+PH@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!P<F5G7W)E<&QA
M8V4H(B]>)R@N*BDG)"\B+"`B7%PQ(BP@)&1A=&%;)&ME>5TI.PH@("`@("`@
M("`@("`@("`@)&1A=&%;)&ME>5T@/2!S=')?<F5P;&%C92@B)R<B+"`B)R(L
M("1D871A6R1K97E=*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E<ULD
M:5T@/3T@1$)?4$%204U?3U!!455%*2!["B`@("`@("`@("`@("`@("`D9G`@
M/2!`9F]P96XH)&1A=&%;)&ME>5TL("=R8B<I.PH@("`@("`@("`@("`@("`@
M:68@*"$D9G`I('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#TF("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27T%#0T534U]624],051)3TXI.PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!F<F5A9"@D9G`L(&9I
M;&5S:7IE*"1D871A6R1K97E=*2D["B`@("`@("`@("`@("`@("!F8VQO<V4H
M)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:2LK.PH@("`@("`@
M('T*"B`@("`@("`@87)R87E?=6YS:&EF="@D9&%T82P@)'-T;70I.PH*("`@
M("`@("`D<F5S(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH)VEB87-E7V5X96-U
M=&4G+"`D9&%T82D["B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@
M("1T;7`@/28@)'1H:7,M/FEB87-E4F%I<V5%<G)O<B@I.PH@("`@("`@("`@
M("!R971U<FX@)'1M<#L*("`@("`@("!]"B`@("`@("`@+RH@6%A8(&YE960@
M=&AI<S\*("`@("`@("!I9B`H)'1H:7,M/F%U=&]C;VUM:70@)B8@)'1H:7,M
M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=*2!["B`@("`@("`@("`@($!I8F%S
M95]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@('TJ+PH@("`@
M("`@("1T:&ES+3YL87-T7W-T;70@/2`D<W1M=#L*("`@("`@("!I9B`H)'1H
M:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=*2!["B`@("`@("`@("`@("1T
M;7`@/2!$0E]/2SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&UP
M(#TF(&YE=R!$0E]R97-U;'0H)'1H:7,L("1R97,I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O*BH*("`@("`J($9R965S
M('1H92!I;G1E<FYA;"!R97-O=7)C97,@87-S;V-I871E9"!W:71H(&$@<')E
M<&%R960@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)'-T
M;70@("`@("`@("`@('1H92!P<F5P87)E9"!S=&%T96UE;G0G<R!02%`@<F5S
M;W5R8V4*("`@("`J($!P87)A;2!B;V]L("`@("`D9G)E95]R97-O=7)C92`@
M<VAO=6QD('1H92!02%`@<F5S;W5R8V4@8F4@9G)E960@=&]O/PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@57-E(&9A;'-E(&EF
M('EO=2!N965D('1O(&=E="!D871A"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F<F]M('1H92!R97-U;'0@<V5T(&QA=&5R+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&
M04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E
M($1"7VEB87-E.CIP<F5P87)E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E
M95!R97!A<F5D*"1S=&UT+"`D9G)E95]R97-O=7)C92`]('1R=64I"B`@("![
M"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D<W1M="DI('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H)&9R965?
M<F5S;W5R8V4I('L*("`@("`@("`@("`@0&EB87-E7V9R965?<75E<GDH)'-T
M;70I.PH@("`@("`@('T*("`@("`@("!U;G-E="@D=&AI<RT^<')E<&%R95]T
M;VME;G-;*&EN="DD<W1M=%TI.PH@("`@("`@('5N<V5T*"1T:&ES+3YP<F5P
M87)E7W1Y<&5S6RAI;G0I)'-T;71=*3L*("`@("`@("!U;G-E="@D=&AI<RT^
M;6%N:7!?<75E<GE;*&EN="DD<W1M=%TI.PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*
M("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@
M8V]M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U
M92!T=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R
M(&]B:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O
M97-N)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E
M*0H@("`@>PH@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@)&]N;V9F(#\@
M,2`Z(#`["B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S
M('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@
M>PH@("`@("`@(')E='5R;B!`:6)A<V5?8V]M;6ET*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R;VQL8F%C:R@I
M"@H@("`@+RHJ"B`@("`@*B!2979E<G1S('1H92!C=7)R96YT('1R86YS86-T
M:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E
M<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@<F5T=7)N($!I
M8F%S95]R;VQL8F%C:R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@=')A;G-A8W1I;VY);FET*"D*"B`@("!F=6YC
M=&EO;B!T<F%N<V%C=&EO;DEN:70H)'1R86YS7V%R9W,@/2`P*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=')A;G-?87)G<PH@("`@("`@("`@("`@("`@/R!`
M:6)A<V5?=')A;G,H)'1R86YS7V%R9W,L("1T:&ES+3YC;VYN96-T:6]N*0H@
M("`@("`@("`@("`@("`@.B!`:6)A<V5?=')A;G,H*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E
M<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@
M=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO
M="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I
M9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@("`@
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J
M($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG971397%U
M96YC94YA;64H*2P*("`@("`J("`@("`@1$)?:6)A<V4Z.F-R96%T95-E<75E
M;F-E*"DL($1"7VEB87-E.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1S<6X@/2!S=')T;W5P<&5R*"1T:&ES+3YG971397%U
M96YC94YA;64H)'-E<5]N86UE*2D["B`@("`@("`@)')E<&5A="`](#`["B`@
M("`@("`@9&\@>PH@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`D<F5S=6QT(#TF
M("1T:&ES+3YQ=65R>2@B4T5,14-4($=%3E])1"@D>W-Q;GTL(#$I("(*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("=&4D]-(%)$0B1'
M14Y%4D%43U)3("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N(")72$5212!21$)<)$=%3D52051/4E].04U%/2<D>W-Q;GTG(BD["B`@
M("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@
M("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="DI('L*
M("`@("`@("`@("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@
M("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<F5P96%T(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R
M97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D[
M"B`@("`@("`@?0H@("`@("`@("1A<G(@/2`D<F5S=6QT+3YF971C:%)O=RA$
M0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@)')E<W5L="T^9G)E92@I
M.PH@("`@("`@(')E='5R;B`D87)R6S!=.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&-R96%T95-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($-R
M96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E;F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E
M<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]I8F%S93HZ;F5X=$E$*"DL
M($1"7VEB87-E.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@)'-Q
M;B`]('-T<G1O=7!P97(H)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA
M;64I*3L*("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH
M(D-214%412!'14Y%4D%43U(@)'MS<6Y](BD["B`@("`@("`@)'1H:7,M/G!O
M<$5R<F]R2&%N9&QI;F<H*3L*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@
M("`O*BH*("`@("`J($1E;&5T97,@82!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC
M92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"
M7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H
M*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@
M1$)?:6)A<V4Z.FYE>'1)1"@I+"!$0E]I8F%S93HZ8W)E871E4V5Q=65N8V4H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T1%3$5412!&
M4D]-(%)$0B1'14Y%4D%43U)3("<*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@(E=(15)%(%)$0EPD1T5.15)!5$]27TY!344])R(*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("X@<W1R=&]U<'!E<B@D=&AI<RT^9V5T4V5Q
M=65N8V5.86UE*"1S97%?;F%M92DI"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("(G(BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7VEB
M87-E1FEE;&1&;&%G<R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&-O;'5M
M;B=S(&9L86=S"B`@("`@*@H@("`@("H@4W5P<&]R=',@(G!R:6UA<GE?:V5Y
M(BP@(G5N:7%U95]K97DB+"`B;F]T7VYU;&PB+"`B9&5F875L="(L"B`@("`@
M*B`B8V]M<'5T960B(&%N9"`B8FQO8B(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEE;&1?;F%M92`@=&AE(&YA;64@;V8@=&AE(&9I96QD"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T86)L95]N86UE("!T:&4@;F%M92!O9B!T
M:&4@=&%B;&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&9L
M86=S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]I8F%S949I96QD1FQA9W,H)&9I96QD7VYA;64L("1T86)L
M95]N86UE*0H@("`@>PH@("`@("`@("1S<6P@/2`G4T5,14-4(%(N4D1")$-/
M3E-44D%)3E1?5%E012!#5%E012<*("`@("`@("`@("`@("`@+B<@1E)/32!2
M1$(D24Y$15A?4T5'345.5%,@22<*("`@("`@("`@("`@("`@+B<@($I/24X@
M4D1")%)%3$%424].7T-/3E-44D%)3E13(%(@3TX@22Y21$(D24Y$15A?3D%-
M13U2+E)$0B1)3D1%6%].04U%)PH@("`@("`@("`@("`@("`N)R!72$5212!)
M+E)$0B1&245,1%].04U%/5PG)R`N("1F:65L9%]N86UE("X@)UPG)PH@("`@
M("`@("`@("`@("`N)R`@04Y$(%504$52*%(N4D1")%)%3$%424].7TY!344I
M/5PG)R`N('-T<G1O=7!P97(H)'1A8FQE7VYA;64I("X@)UPG)SL*"B`@("`@
M("`@)')E<W5L="`]($!I8F%S95]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP@
M)'-Q;"D["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^:6)A<V5286ES945R<F]R*"D["B`@("`@("`@?0H*("`@
M("`@("`D9FQA9W,@/2`G)SL*("`@("`@("!I9B`H)&]B:B`]($!I8F%S95]F
M971C:%]O8FIE8W0H)')E<W5L="DI('L*("`@("`@("`@("`@0&EB87-E7V9R
M965?<F5S=6QT*"1R97-U;'0I.PH@("`@("`@("`@("!I9B`H:7-S970H)&]B
M:BT^0U194$4I("`F)B!T<FEM*"1O8FHM/D-465!%*2`]/2`G4%))34%262!+
M15DG*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)W!R:6UA<GE?:V5Y
M("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FHM
M/D-465!%*2`@)B8@=')I;2@D;V)J+3Y#5%E012D@/3T@)U5.25%512<I('L*
M("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G=6YI<75E7VME>2`G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W%L(#T@)U-%3$5#5"!2
M+E)$0B1.54Q,7T9,04<@05,@3D9,04<L)PH@("`@("`@("`@("`@("`N)R`@
M4BY21$(D1$5&055,5%]33U520T4@05,@1%-/55)#12PG"B`@("`@("`@("`@
M("`@("XG("!&+E)$0B1&245,1%]465!%($%3($9465!%+"<*("`@("`@("`@
M("`@("`@+B<@($8N4D1")$-/35!55$5$7U-/55)#12!!4R!#4T]54D-%)PH@
M("`@("`@("`@("`@("`N)R!&4D]-(%)$0B1214Q!5$E/3E]&245,1%,@4B`G
M"B`@("`@("`@("`@("`@("XG("!*3TE.(%)$0B1&245,1%,@1B!/3B!2+E)$
M0B1&245,1%]33U520T4]1BY21$(D1DE%3$1?3D%-12<*("`@("`@("`@("`@
M("`@+B<@5TA%4D4@55!015(H4BY21$(D4D5,051)3TY?3D%-12D]7"<G("X@
M<W1R=&]U<'!E<B@D=&%B;&5?;F%M92D@+B`G7"<G"B`@("`@("`@("`@("`@
M("XG("!!3D0@4BY21$(D1DE%3$1?3D%-13U<)R<@+B`D9FEE;&1?;F%M92`N
M("=<)R<["@H@("`@("`@("1R97-U;'0@/2!`:6)A<V5?<75E<GDH)'1H:7,M
M/F-O;FYE8W1I;VXL("1S<6PI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FEB87-E4F%I<V5%<G)O<B@I.PH@
M("`@("`@('T*("`@("`@("!I9B`H)&]B:B`]($!I8F%S95]F971C:%]O8FIE
M8W0H)')E<W5L="DI('L*("`@("`@("`@("`@0&EB87-E7V9R965?<F5S=6QT
M*"1R97-U;'0I.PH@("`@("`@("`@("!I9B`H:7-S970H)&]B:BT^3D9,04<I
M*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)VYO=%]N=6QL("<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FHM/D133U52
M0T4I*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)V1E9F%U;'0@)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&]B:BT^0U-/
M55)#12DI('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G8V]M<'5T960@
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&]B:BT^
M1E194$4I("`F)B`D;V)J+3Y&5%E012`]/2`R-C$I('L*("`@("`@("`@("`@
M("`@("1F;&%G<R`N/2`G8FQO8B`G.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')I;2@D9FQA9W,I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&EB87-E4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@
M("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE
M(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R
M<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A
M<W,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N
M<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E
M9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T
M("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J("`@("`@1$)?:6)A<V4Z.F5R
M<F]R3F%T:79E*"DL($1"7VEB87-E.CIE<G)O<D-O9&4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B`F:6)A<V5286ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*"1T:&ES+3YE<G)O<DYA=&EV
M92@I*3L*("`@("`@("!]"B`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I<V5%
M<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL($!I8F%S95]E<G)M<V<H
M*2D["B`@("`@("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T
M:&4@1$)-4R<@;F%T:79E(&5R<F]R(&-O9&4@<')O9'5C960@8GD@=&AE(&QA
M<W0@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE($1"35,G
M(&5R<F]R(&-O9&4N("!.54Q,(&EF('1H97)E(&ES(&YO(&5R<F]R(&-O9&4N
M"B`@("`@*@H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV
M92@I"B`@("!["B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G:6)A<V5?
M97)R8V]D92<I*2!["B`@("`@("`@("`@(')E='5R;B!`:6)A<V5?97)R8V]D
M92@I.PH@("`@("`@('T*("`@("`@("!I9B`H<')E9U]M871C:"@G+UY$>6YA
M;6EC(%-13"!%<G)O<B!344P@97)R;W(@8V]D92`]("A;,"TY+5TK*2]I)RP*
M("`@("`@("`@("`@("`@("`@("`@("!`:6)A<V5?97)R;7-G*"DL("1M*2D@
M>PH@("`@("`@("`@("!R971U<FX@*&EN="DD;5LQ73L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@97)R;W)#;V1E*"D*"B`@("`O*BH*("`@("`J($UA<',@;F%T:79E(&5R
M<F]R(&-O9&5S('1O($1")W,@<&]R=&%B;&4@;VYE<PH@("`@("H*("`@("`J
M($!P87)A;2!I;G0@)&YA=&EV96-O9&4@('1H92!E<G)O<B!C;V1E(')E='5R
M;F5D(&)Y('1H92!$0DU3"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H
M92!P;W)T86)L92!$0B!E<G)O<B!C;V1E+B`@4F5T=7)N($1"7T524D]2(&EF
M('1H90H@("`@("H@("`@("`@("`@("`@("!C=7)R96YT(&1R:79E<B!D;V5S
M;B=T(&AA=F4@82!M87!P:6YG(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@)&YA=&EV96-O9&4@<W5B;6ET=&5D+@H@("`@("H*("`@("`J($!S:6YC
M92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J
M+PH@("`@9G5N8W1I;VX@97)R;W)#;V1E*"1N871I=F5C;V1E(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F5R<F]R8V]D95]M87!;
M)&YA=&EV96-O9&5=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F5R
M<F]R8V]D95]M87!;)&YA=&EV96-O9&5=.PH@("`@("`@('T*"B`@("`@("`@
M<W1A=&EC("1E<G)O<E]R96=E>'!S.PH@("`@("`@(&EF("@A:7-S970H)&5R
M<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("1E<G)O<E]R96=E>'!S(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`G+V=E;F5R871O<B`N*B!I<R!N;W0@
M9&5F:6YE9"\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.
M5$%8+"`@+R\@9F]R(&-O;7!A="X@=R!I8F%S95]E<G)C;V1E*"D*("`@("`@
M("`@("`@("`@("<O=&%B;&4N*BAN;W0@97AI<W1\;F]T(&9O=6YD?'5N:VYO
M=VXI+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]354-(
M5$%"3$4L"B`@("`@("`@("`@("`@("`G+W1A8FQE("XJ(&%L<F5A9'D@97AI
M<W1S+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?04Q214%$
M65]%6$E35%,L"B`@("`@("`@("`@("`@("`G+W5N<W5C8V5S<V9U;"!M971A
M9&%T82!U<&1A=&4@+BH@9F%I;&5D(&%T=&5M<'0@=&\@<W1O<F4@9'5P;&EC
M871E('9A;'5E+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("`@("`G+W5N<W5C8V5S<V9U
M;"!M971A9&%T82!U<&1A=&4@+BH@;F]T(&9O=6YD+VDG"B`@("`@("`@("`@
M("`@("`@("`@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@("`@("`@
M("`@)R]V86QI9&%T:6]N(&5R<F]R(&9O<B!C;VQU;6X@+BH@=F%L=64@(EPJ
M7"I<*B!N=6QL+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`@("`@("`@("<O=FEO;&%T
M:6]N(&]F(%M<=R!=*R!C;VYS=')A:6YT+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@("<O
M8V]N=F5R<VEO;B!E<G)O<B!F<F]M('-T<FEN9R]I)PH@("`@("`@("`@("`@
M("`@("`@(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("`@
M("`@("`@)R]N;R!P97)M:7-S:6]N(&9O<B]I)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@("`@
M("`@("`G+V%R:71H;65T:6,@97AC97!T:6]N+"!N=6UE<FEC(&]V97)F;&]W
M+"!O<B!S=')I;F<@=')U;F-A=&EO;B]I)PH@("`@("`@("`@("`@("`@("`@
M(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@("`@("D["B`@("`@("`@
M?0H*("`@("`@("`D97)R;W)M<V<@/2!`:6)A<V5?97)R;7-G*"D["B`@("`@
M("`@9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@)')E9V5X<"`]/B`D8V]D
M92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G97AP+"`D97)R
M;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&-O9&4["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T524D]2.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@=&%B;&4@
M;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@3D]413H@;VYL>2!S=7!P
M;W)T<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF(#QV87(^)')E<W5L=#PO=F%R
M/@H@("`@("H@:7,@82!T86)L92!N86UE+@H@("`@("H*("`@("`J($!P87)A
M;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R
M;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B
M;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=H
M:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT
M:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I
M;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@
M87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@
M("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E
M:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E
M<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@
M("`@("`@("`@)&ED(#T@0&EB87-E7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(E-%3$5#5"`J($92
M3TT@)')E<W5L="!72$5212`Q/3`B*3L*("`@("`@("`@("`@)&=O=%]S=')I
M;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR
M97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A
M8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@
M17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@
M("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0[
M"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@
M("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@("H@1&5P<F5C871E9"X@
M($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?
M<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E
M<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI8F%S
M95)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==
M("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@("1C
M87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@
M("`@("`@)&-O=6YT(#T@0&EB87-E7VYU;5]F:65L9',H)&ED*3L*("`@("`@
M("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@
M("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@
M('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2![
M"B`@("`@("`@("`@("1I;F9O(#T@0&EB87-E7V9I96QD7VEN9F\H)&ED+"`D
M:2D["B`@("`@("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`G=&%B;&4G(#T^("1G;W1?<W1R:6YG(#\@)&-A<V5?9G5N8R@D<F5S
M=6QT*2`Z("<G+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F
M=6YC*"1I;F9O6R=N86UE)UTI+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`D:6YF;ULG='EP92==+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]/B`D
M:6YF;ULG;&5N9W1H)UTL"B`@("`@("`@("`@("`@("`G9FQA9W,G(#T^("@D
M9V]T7W-T<FEN9RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#\@)'1H
M:7,M/E]I8F%S949I96QD1FQA9W,H)&EN9F];)VYA;64G72P@)')E<W5L="D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@)R<L"B`@("`@("`@("`@
M("D["B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%
M4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG
M;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@
M("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R
M97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E<F4@
M8V%L;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I('L*
M("`@("`@("`@("`@0&EB87-E7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A
M:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV
M96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R
M:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U
M97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@
M("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R
M97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S
M=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@
M("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!$25-424Y#5"!2+E)$0B12
M14Q!5$E/3E].04U%($923TT@)PH@("`@("`@("`@("`@("`@("`@("`@("X@
M)U)$0B1214Q!5$E/3E]&245,1%,@4B!72$5212!2+E)$0B1365-414U?1DQ!
M1STP)SL*("`@("`@("`@("`@8V%S92`G=FEE=W,G.@H@("`@("`@("`@("`@
M("`@<F5T=7)N("=314Q%0U0@1$E35$E.0U0@4D1")%9)15=?3D%-12!F<F]M
M(%)$0B1624577U)%3$%424].4R<["B`@("`@("`@("`@(&-A<V4@)W5S97)S
M)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4($1)4U1)3D-4(%)$
M0B154T52($923TT@4D1")%5315)?4%))5DE,14=%4R<["B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,;V-A;"!V87)I86)L
M97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%
M;F0Z"B`J+PH*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]I9G@N<&AP````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-C<R,``Q,#4Q-30S
M,3`U-P`P,3<Q,S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@5&AE
M(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!I9G@@97AT96YS:6]N"B`J(&9O
M<B!I;G1E<F%C=&EN9R!W:71H($EN9F]R;6EX(&1A=&%B87-E<PH@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@5&]M87,@
M5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@:69X+G!H<"QV(#$N-S`@,C`P
M-2\P,B\R,"`P,#HT-#HT."!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/
M8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD
M960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J
M*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@:6YT97)A8W0@=VET
M:"!02%`G<R!I9G@@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H
M($EN9F]R;6EX(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L
M;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@36]R
M92!I;F9O(&]N($EN9F]R;6EX(&5R<F]R<R!C86X@8F4@9F]U;F0@870Z"B`J
M(&AT='`Z+R]W=W<N:6YF;W)M:7@N8V]M+V%N<W=E<G,O96YG;&ES:"]I97)R
M;W)S+FAT;0H@*@H@*B!43T1/.@H@*B`@("T@<V5T(&YE961E9"!E;G8@26YF
M;W)M:7@@=F%R<R!O;B!C;VYN96-T"B`J("`@+2!I;7!L96UE;G0@;F%T:79E
M('!R97!A<F4O97AE8W5T90H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@
M*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N0V]X
M(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?:69X(&5X
M=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@
M+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O
M9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1P:'!T>7!E(#T@)VEF>"<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A
M<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T
M8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D9&)S>6YT87@@/2`G:69X)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A
M8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@
M("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V
M97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@("`J(&YE=U]L:6YK('-U
M<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@
M=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI
M;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L871E)R`](&5M=6QA=&4@
M=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@
M(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI
M<"!R;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@
M(#T^("=E;75L871E)RP*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^("=E;75L871E)RP*("`@
M("`@("`G<&-O;FYE8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E<&%R
M92<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@
M*3L*"B`@("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@
M8V]D97,@=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@
M)RTR,#$G("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`G+3(P-B<@
M("`@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@)RTR,3<G("`@
M(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("<M,C,V)R`@("`]
M/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@)RTR,SDG
M("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@)RTR-3,G("`@
M(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`G+3(Y,B<@("`@/3X@1$)?
M15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`G+3,Q,"<@("`@
M/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@)RTS,38G("`@
M(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@("<M,S$Y)R`@
M("`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@)RTS,CDG("`@(#T^
M($1"7T524D]27TY/1$)314Q%0U1%1"P*("`@("`@("`G+3,T-B<@("`@/3X@
M1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`G+3,X-B<@("`@/3X@1$)?
M15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`G+3,Y,2<@("`@
M/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`G+34U
M-"<@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("<M-CDQ)R`@("`]
M/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("<M-CDR)R`@("`]/B!$
M0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("<M-S`S)R`@("`]/B!$0E]%
M4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@("<M,3(P-"<@("`]
M/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L"B`@("`@("`@)RTQ,C`U)R`@(#T^
M($1"7T524D]27TE.5D%,241?1$%412P*("`@("`@("`G+3$R,#8G("`@/3X@
M1$)?15)23U)?24Y604Q)1%]$051%+`H@("`@("`@("<M,3(P.2<@("`]/B!$
M0E]%4E)/4E])3E9!3$E$7T1!5$4L"B`@("`@("`@)RTQ,C$P)R`@(#T^($1"
M7T524D]27TE.5D%,241?1$%412P*("`@("`@("`G+3$R,3(G("`@/3X@1$)?
M15)23U)?24Y604Q)1%]$051%+`H@("`@("`@("<M,3(Q,R<@("`]/B!$0E]%
M4E)/4E])3E9!3$E$7TY534)%4BP*("`@("D["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@
M("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N
M.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N
M;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!3
M:&]U;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE<R!B92!C;VUM:71T960@
M875T;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O;`H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D875T;V-O;6UI="`]('1R=64[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@<75A;G1I='D@;V8@=')A;G-A8W1I;VYS
M(&)E9W5N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"`@5VAI;&4@=&AI<R!I
M<R!P<FEV871E+"!I="!C86XG="!A8W1U86QL>2!B92!D97-I9VYA=&5D"B`@
M("`@*B!P<FEV871E(&EN(%!(4"`U(&)E8V%U<V4@:70@:7,@9&ER96-T;'D@
M86-C97-S960@:6X@=&AE('1E<W0@<W5I=&4N?7T*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)'1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH*("`@("\J*@H@("`@
M("H@5&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI
M<'5L871I;VX@<75E<GD*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D869F96-T960@/2`P.PH*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@
M("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C
M;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!$0E]I9G@H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C
M;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B
M87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@
M("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5
M<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@
M("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H92!C;VYN
M96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E
M<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO
M861%>'1E;G-I;VXH)VEN9F]R;6EX)RD@)B8*("`@("`@("`@("`@(5!%05(Z
M.FQO861%>'1E;G-I;VXH)TEN9F]R;6EX)RDI"B`@("`@("`@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y3
M24].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N
M(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@
M("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@
M("`@("`@('T*"B`@("`@("`@)&1B:&]S="`]("1D<VY;)VAO<W1S<&5C)UT@
M/R`G0"<@+B`D9'-N6R=H;W-T<W!E8R==(#H@)R<["B`@("`@("`@)&1B;F%M
M92`]("1D<VY;)V1A=&%B87-E)UT@/R`D9'-N6R=D871A8F%S92==("X@)&1B
M:&]S="`Z("<G.PH@("`@("`@("1U<V5R(#T@)&1S;ELG=7-E<FYA;64G72`_
M("1D<VY;)W5S97)N86UE)UT@.B`G)SL*("`@("`@("`D<'<@/2`D9'-N6R=P
M87-S=V]R9"==(#\@)&1S;ELG<&%S<W=O<F0G72`Z("<G.PH*("`@("`@("`D
M8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)VEF>%]P8V]N;F5C
M="<@.B`G:69X7V-O;FYE8W0G.PH*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO
M;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9&)N86UE+"`D=7-E<BP@)'!W*3L*
M("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YC;VYN96-T:6]N*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEF>%)A:7-E17)R;W(H1$)?
M15)23U)?0T].3D5#5%]&04E,140I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N
M;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D
M871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12
M544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F
M=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0&EF
M>%]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O
M;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*
M("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H92!344P@<75E<GD@<W1R
M:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U
M;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@
M("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O
M=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@
M("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@("!F
M=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)&ES
M;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES+3YL
M87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1T:&ES+3YA9F9E8W1E9"`@
M(#T@;G5L;#L*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA314Q%0U0I+VDG
M+"`D<75E<GDI*2![("`@("\O5$535$U%.B!5<V4@(41".CII<TUA;FEP*"D_
M"B`@("`@("`@("`@("\O('1H92!S8W)O;&P@:7,@;F5E9&5D(&9O<B!F971C
M:&EN9R!A8G-O;'5T92!R;W<@;G5M8F5R<PH@("`@("`@("`@("`O+R!I;B!A
M('-E;&5C="!Q=65R>2!R97-U;'0*("`@("`@("`@("`@)')E<W5L="`]($!I
M9GA?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BP@24987U-#4D],
M3"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M875T;V-O;6UI="`F)B`D:7-M86YI<"D@>PH@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T](#`I('L*("`@("`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@0&EF>%]Q=65R>2@G0D5'24X@5T]22R<L
M("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YI9GA286ES945R<F]R*"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G1R86YS
M86-T:6]N7V]P8V]U;G0K*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<F5S=6QT(#T@0&EF>%]Q=65R>2@D<75E<GDL("1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^:69X4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^869F96-T960@/2!`:69X7V%F9F5C=&5D7W)O=W,H
M)')E<W5L="D["B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U97)I97,@
M<VAO=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U
M;&0@<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+RA314Q%0U0I+VDG+"`D<75E<GDI*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("`O+R!86%@@5&5S
M=&UE.B!F<F5E(')E<W5L=',@:6YS:61E(&$@=')A;G-A8W1I;VX*("`@("`@
M("`O+R!M87D@8V%U<V4@=&\@<W1O<"!I="!A;F0@8V]M;6ET('1H92!W;W)K
M/PH*("`@("`@("`O+R!297-U;'0@:&%S('1O(&)E(&9R965D(&5V96X@=VET
M:"!A(&EN<V5R="!O<B!U<&1A=&4*("`@("`@("!`:69X7V9R965?<F5S=6QT
M*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@
M*B!-;W9E('1H92!I;G1E<FYA;"!I9G@@<F5S=6QT('!O:6YT97(@=&\@=&AE
M(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A
M('9A;&ED(&9B<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@
M<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI
M=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O
M<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI
M<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YA9F9E8W1E9#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@,#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F
M<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@
M*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@
M=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L
M=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D
M:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I
M;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@
M("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H92!Q
M=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@("`D
M87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@9&%T
M82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H
M92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P
M87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E
M=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F(&$@
M<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@("`@(')E86-H960@
M;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF
M971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E
M<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@H)')O=VYU;2`A/3T@;G5L;"D@)B8@*"1R;W=N=6T@
M/"`P*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@
M("`@("`@:68@*"1R;W=N=6T@/3T](&YU;&PI('L*("`@("`@("`@("`@+RH*
M("`@("`@("`@("`@("H@179E;B!T:&]U9V@@9F5T8VA?<F]W*"D@<VAO=6QD
M(')E='5R;B!T:&4@;F5X="!R;W<@(&EF"B`@("`@("`@("`@("`J("1R;W=N
M=6T@:7,@;G5L;"P@:70@9&]E<VXG="!I;B!A;&P@8V%S97,N("!"=6<@-3DX
M+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)')O=VYU;2`]("=.15A4
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!);F1E>"!S=&%R
M=',@870@<F]W(#$L('5N;&EK92!M;W-T($1"35,G<R!S=&%R=&EN9R!A="`P
M+@H@("`@("`@("`@("`D<F]W;G5M*RL["B`@("`@("`@?0H@("`@("`@(&EF
M("@A)&%R<B`]($!I9GA?9F5T8VA?<F]W*"1R97-U;'0L("1R;W=N=6TI*2![
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&9E=&-H;6]D92`A/3T@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@
M("`@("`@("1I/3`["B`@("`@("`@("`@("1O<F1E<B`](&%R<F%Y*"D["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1A<G(@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@)&]R9&5R6R1I*RM=(#T@)'9A;#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D87)R(#T@)&]R9&5R.PH@("`@("`@('T@96QS96EF("@D9F5T
M8VAM;V1E(#T]($1"7T9%5$-(34]$15]!4U-/0R`F)@H@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TQ/5T520T%312D*("`@("`@("!["B`@("`@("`@("`@("1A<G(@
M/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI
M='DG72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N
M=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C
M=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D
M+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E
M8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R
M97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE
M(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*
M("`@("`@("!I9B`H(21C;VQS(#T@0&EF>%]N=6U?9FEE;&1S*"1R97-U;'0I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:69X4F%I<V5%<G)O<B@I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@("`@
M*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y
M(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A
M;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"
M7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E
M<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U
M8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@
M("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`
M:69X7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@("\J*@H@("`@("H@16YA8FQE
M<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M;6ET<PH@("`@("H*("`@("`J
M($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T=7)N<R!I="!O;BP@9F%L<V4@
M='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+
M(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!I9B!T:&4@9')I=F5R
M"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N)W0@<W5P<&]R="!A=71O+6-O
M;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M=71O0V]M;6ET*"1O;F]F9B`]('1R=64I"B`@("!["B`@("`@("`@+R\@6%A8
M(&EF("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"P@=V4@<VAO=6QD
M('!R;V)A8FQY"B`@("`@("`@+R\@:7-S=64@82!W87)N:6YG(&AE<F4N"B`@
M("`@("`@)'1H:7,M/F%U=&]C;VUM:70@/2`D;VYO9F8@/R!T<G5E(#H@9F%L
M<V4["B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H
M92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*
M("`@("`@("`@("`@)')E<W5L="`]($!I9GA?<75E<GDH)T-/34U)5"!73U)+
M)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D=&AI<RT^=')A
M;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L
M="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI9GA286ES945R
M<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K
M*"D*"B`@("`O*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A
M8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@("1R
M97-U;'0@/2!`:69X7W%U97)Y*"=23TQ,0D%#2R!73U)+)RP@)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C
M;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YI9GA286ES945R<F]R*"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&EF>%)A:7-E17)R;W(H*0H*("`@
M("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D
M:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A
M:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)2
M3U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@
M9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S
M964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7VEF
M>#HZ97)R;W).871I=F4H*2P@1$)?:69X.CIE<G)O<D-O9&4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!I9GA286ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*&EF>%]E<G)O<B@I*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)N
M;RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F5R<F]R3F%T:79E*"DI.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J
M($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C;V1E(&%N9"!M97-S86=E
M('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!$0DU3)R!E<G)O<B!C;V1E(&%N9"!M97-S86=E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@
M("`@("!R971U<FX@0&EF>%]E<G)O<B@I("X@)R`G("X@0&EF>%]E<G)O<FUS
M9R@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I
M"@H@("`@+RHJ"B`@("`@*B!-87!S(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$
M0B=S('!O<G1A8FQE(&]N97,N"B`@("`@*@H@("`@("H@4F5Q=6ER97,@=&AA
M="!T:&4@1$(@:6UP;&5M96YT871I;VXG<R!C;VYS=')U8W1O<B!F:6QL<PH@
M("`@("H@:6X@=&AE(#QV87(^)&5R<F]R8V]D95]M87`\+W9A<CX@<')O<&5R
M='DN"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@("1N871I=F5C;V1E
M("!E<G)O<B!C;V1E(')E='5R;F5D(&)Y('1H92!D871A8F%S90H@("`@("H@
M0')E='5R;B!I;G0@82!P;W)T86)L92!$0B!E<G)O<B!C;V1E+"!O<B!$0E]%
M4E)/4B!I9B!T:&ES($1""B`@("`@*B!I;7!L96UE;G1A=&EO;B!H87,@;F\@
M;6%P<&EN9R!F;W(@=&AE(&=I=F5N(&5R<F]R(&-O9&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5R<F]R0V]D92@D;F%T:79E8V]D92D*("`@('L*("`@("`@
M("!I9B`H97)E9R@G4U%,0T]$13TH+BHI72<L("1N871I=F5C;V1E+"`D;6%T
M8V@I*2!["B`@("`@("`@("`@("1C;V1E(#T@)&UA=&-H6S%=.PH@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/F5R<F]R8V]D95]M87!;)&-O9&5=*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YE<G)O<F-O9&5?;6%P
M6R1C;V1E73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B
M;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@
M86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!.
M3U1%.B!O;FQY('-U<'!O<G1S("=T86)L92<@:68@/'9A<CXD<F5S=6QT/"]V
M87(^(&ES(&$@=&%B;&4@;F%M92X*("`@("`J"B`@("`@*B!)9B!A;F%L>7II
M;F<@82!Q=65R>2!R97-U;'0@86YD('1H92!R97-U;'0@:&%S(&1U<&QI8V%T
M92!F:65L9"!N86UE<RP*("`@("`J(&%N(&5R<F]R('=I;&P@8F4@<F%I<V5D
M('-A>6EN9PH@("`@("H@/'-A;7`^8V%N)W0@9&ES=&EN9W5I<V@@9'5P;&EC
M871E(&9I96QD(&YA;65S/"]S86UP/BX*("`@("`J"B`@("`@*B!`<&%R86T@
M;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M
M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!7:&EL
M92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF
M:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R
M<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@
M("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@
M("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO
M9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L
M="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@
M82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1I9"`]($!I9GA?<75E<GDH(E-%3$5#5"`J($923TT@
M)')E<W5L="!72$5212`Q/3`B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)&=O=%]S=')I
M;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR
M97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A
M8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@
M17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@
M("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0[
M"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@
M("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@
M("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI9GA286ES945R<F]R*$1"
M7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"@H@("`@("`@("1F
M;&1S(#T@0&EF>%]F:65L9'!R;W!E<G1I97,H)&ED*3L*("`@("`@("`D8V]U
M;G0@/2!`:69X7VYU;5]F:65L9',H)&ED*3L*"B`@("`@("`@:68@*&-O=6YT
M*"1F;&1S*2`A/2`D8V]U;G0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")C86XG="!D:7-T:6YG=6ES:"!D=7!L:6-A=&4@9FEE
M;&0@;F%M97,B*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R
M=F%L)SL*("`@("`@("!]"@H@("`@("`@("1I("`@/2`P.PH@("`@("`@("1R
M97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@("`@
M("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)&9L9',@87,@)&ME>2`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@)'!R;W!S(#T@97AP;&]D92@G.R<L("1V86QU92D["B`@("`@
M("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G=&%B
M;&4G(#T^("1G;W1?<W1R:6YG(#\@)&-A<V5?9G5N8R@D<F5S=6QT*2`Z("<G
M+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*"1K97DI
M+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`D<')O<'-;,%TL"B`@("`@
M("`@("`@("`@("`G;&5N)R`@(#T^("1P<F]P<ULQ72P*("`@("`@("`@("`@
M("`@("=F;&%G<R<@/3X@)'!R;W!S6S1=(#T]("=.)R`_("=N;W1?;G5L;"<@
M.B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68@*"1M;V1E("8@
M1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O
M<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD<F5S
M6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D:2LK.PH@("`@("`@('T*"B`@("`@("`@
M+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@
M82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@
M("!`:69X7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P
M96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R
M>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O
M8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE
M(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9R!O
M<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@
M("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R97%U97-T960*("`@
M("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P
M96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@
M("!R971U<FX@)U-%3$5#5"!T86)N86UE($923TT@<WES=&%B;&5S(%=(15)%
M('1A8FED(#X](#$P,"<["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"@I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@
M-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+VUS<6PN<&AP````````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4V-34R`#$P
M-3$U-#,Q,#4W`#`Q-S,S,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@
M*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S(&US<6P@97AT96YS:6]N
M"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UI;FD@4U%,(&1A=&%B87-E<PH@
M*@H@*B!02%`G<R!M4U%,(&5X=&5N<VEO;B!D:60@=V5I<F0@=&AI;F=S('=I
M=&@@3E5,3"!V86QU97,@<')I;W(@=&\@4$A0"B`J(#0N,RXQ,2!A;F0@-2XP
M+C0N("!-86ME('-U<F4@>6]U<B!V97)S:6]N(&]F(%!(4"!M965T<R!O<B!E
M>&-E961S"B`J('1H;W-E('9E<G-I;VYS+@H@*@H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T
M;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A
M8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z(&US<6PN<&AP+'8@,2XU-R`R,#`U+S`R+S(R(#`W.C(V
M.C0V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?
M8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR
M97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H
M;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S(&US<6P@
M97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UI;FD@4U%,(&1A
M=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O;F5S
M(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@4$A0)W,@;5-13"!E>'1E
M;G-I;VX@9&ED('=E:7)D('1H:6YG<R!W:71H($Y53$P@=F%L=65S('!R:6]R
M('1O(%!(4`H@*B`T+C,N,3$@86YD(#4N,"XT+B`@36%K92!S=7)E('EO=7(@
M=F5R<VEO;B!O9B!02%`@;65E=',@;W(@97AC965D<PH@*B!T:&]S92!V97)S
M:6]N<RX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@
M("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'
M<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+T1""B`J($!S:6YC92`@("`@($-L87-S(&YO="!F=6YC=&EO
M;F%L('5N=&EL(%)E;&5A<V4@,2XW+C`*("HO"F-L87-S($1"7VUS<6P@97AT
M96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O
M*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C:3@L(&]D
M8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)'!H<'1Y<&4@/2`G;7-Q;"<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A
M<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T
M8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D9&)S>6YT87@@/2`G;7-Q;"<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P
M86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@
M("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@
M=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S
M=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S
M('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L
M:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L871E
M('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@
M("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K
M:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@
M("`]/B`G96UU;&%T92<L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("=N=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@("`@("`@
M("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@("`@("`@("=P<F5P87)E)R`@
M("`@("`]/B!F86QS92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^(&9A;'-E+`H@("`@*3L*
M"B`@("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D
M97,@=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`I.PH*("`@
M("\J*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T
M960@8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A
M<B`D8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M
M871I;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@
M("\J*@H@("`@("H@5&AE('%U97)Y(')E<W5L="!R97-O=7)C92!C<F5A=&5D
M(&)Y(%!(4`H@("`@("H*("`@("`J(%5S960@=&\@;6%K92!A9F9E8W1E9%)O
M=W,H*2!W;W)K+B`@3VYL>2!C;VYT86EN<R!T:&4@<F5S=6QT(&9O<@H@("`@
M("H@9&%T82!M86YI<'5L871I;VX@<75E<FEE<RX@($-O;G1A:6YS(&9A;'-E
M(&9O<B!O=&AE<B!Q=65R:65S+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R
M8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]R
M97-U;'0["@H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@
M("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R(&-A;&QS(#QK8F0^)'1H
M:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7VUS<6PH*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@
M=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D871A
M8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER
M96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*("`@
M("`J($5X86UP;&4@;V8@:&]W('1O(&-O;FYE8W0Z"B`@("`@*B`\8V]D93X*
M("`@("`J(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`J(`H@("`@("H@
M+R\@)&1S;B`]("=M<W%L.B\O:&]S=&YA;64O9&)N86UE)SL@("\O('5S92!A
M(%1#4"!C;VYN96-T:6]N"B`@("`@*B`D9'-N(#T@)VUS<6PZ+R\O9&)N86UE
M)SL@("`@("`@("`@("`@+R\@=7-E(&$@<V]C:V5T"B`@("`@*B`D;W!T:6]N
M<R`](&%R<F%Y*`H@("`@("H@("`@("=P;W)T86)I;&ET>2<@/3X@1$)?4$]2
M5$%"24Q)5%E?04Q,+`H@("`@("H@*3L*("`@("`J(`H@("`@("H@)&1B(#TF
M($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*("`@("`J(&EF("A014%2
M.CII<T5R<F]R*"1D8BDI('L*("`@("`J("`@("!D:64H)&1B+3YG971-97-S
M86=E*"DI.PH@("`@("H@?0H@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA
M;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H
M92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S
M;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%
M05(Z.FQO861%>'1E;G-I;VXH)VUS<6PG*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&
M3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*
M("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@("`D
M=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@('T*
M"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1D<VY;
M)VAO<W1S<&5C)UTI('L*("`@("`@("`@("`@)'!A<F%M<UM=(#T@)&1S;ELG
M<&]R="=="B`@("`@("`@("`@("`@("`@("`@("`@(#\@)&1S;ELG:&]S='-P
M96,G72`N("<L)R`N("1D<VY;)W!O<G0G70H@("`@("`@("`@("`@("`@("`@
M("`@("`Z("1D<VY;)VAO<W1S<&5C)UT["B`@("`@("`@?0H*("`@("`@("`D
M8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)VUS<6Q?<&-O;FYE
M8W0G(#H@)VUS<6Q?8V]N;F5C="<["@H@("`@("`@("1I;FD@/2!I;FE?9V5T
M*"=T<F%C:U]E<G)O<G,G*3L*("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<[
M"B`@("`@("`@:68@*"1I;FDI('L*("`@("`@("`@("`@)'1H:7,M/F-O;FYE
M8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N8W1I
M;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("`@
M("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D
M8V]N;F5C=%]F=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@
M("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L("1I;FDI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@
M("!I9B`H*"1E<G(@/2!`;7-Q;%]E<G)O<B@I*2`A/2`G)RD@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/
M3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&5R<BD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP7V5R
M<F]R;7-G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*"%`;7-Q;%]S96QE8W1?9&(H)&1S;ELG9&%T86)A<V4G72P@)'1H:7,M/F-O
M;FYE8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-Q;%)A
M:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@
M("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R
M=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E
M<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES
M8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!M<W%L7V-L;W-E*"1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]
M(&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N
M9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C
M92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@
M("`@("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E
M<W-F=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I
M;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D=&AI<RT^;&%S=%]Q
M=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y
M475E<GDH)'%U97)Y*3L*("`@("`@("`D<F5S=6QT(#T@0&US<6Q?<75E<GDH
M)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-Q;%)A:7-E17)R
M;W(H*3L*("`@("`@("!]"B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U
M97)I97,@=&AA="!S:&]U;&0@<F5T=7)N(&1A=&$L(&%N9"!W:&EC:`H@("`@
M("`@("\O('-H;W5L9"!R971U<FX@86X@97)R;W(@8V]D92!O;FQY+@H@("`@
M("`@(&EF("A$0CHZ:7--86YI<"@D<75E<GDI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<F5S=6QT(#T@)')E<W5L=#L*("`@("`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<F5S
M=6QT(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*("`@('T*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L
M="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!M<W%L(')E
M<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@
M("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!F8G-Q;"!R97-U;'0@<F5S;W5R
M8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J
M($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I;&%B;&4@;W1H97)W
M:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT4F5S
M=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@+RHJ
M"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@<F5S=6QT('-E="!I;G1O
M('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J($9O<FUA=&EN9R!O9B!T
M:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@87)E(&-O;F9I9W5R86)L
M92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M;W)E
M(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO
M="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"
M7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E
M8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I
M<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!02%`G<R!M4U%,
M(&5X=&5N<VEO;B!D:60@=V5I<F0@=&AI;F=S('=I=&@@3E5,3"!V86QU97,@
M<')I;W(@=&\@4$A0"B`@("`@*B`T+C,N,3$@86YD(#4N,"XT+B`@36%K92!S
M=7)E('EO=7(@=F5R<VEO;B!O9B!02%`@;65E=',@;W(@97AC965D<PH@("`@
M("H@=&AO<V4@=F5R<VEO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@
M("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@
M87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@
M("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@
M8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@
M=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,
M3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@
M("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@
M)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@(3T]
M(&YU;&PI('L*("`@("`@("`@("`@:68@*"%`;7-Q;%]D871A7W-E96LH)')E
M<W5L="P@)')O=VYU;2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM
M;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1A<G(@
M/2!`;7-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!-4U%,7T%34T]#*3L*("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F("1A<G(I('L*("`@("`@("`@
M("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%3
M15],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D87)R(#T@0&US<6Q?9F5T8VA?<F]W*"1R97-U;'0I.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T=7)N
M(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==
M("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@("`@
M*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y
M(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A
M;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"
M7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E
M<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U
M8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@
M("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`
M;7-Q;%]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE
M(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER
M96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I(&EN<W1E
M860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@
M8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y
M(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T
M:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U#;VQS
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT*0H@("`@
M>PH@("`@("`@("1C;VQS(#T@0&US<6Q?;G5M7V9I96QD<R@D<F5S=6QT*3L*
M("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H
M*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@
M82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T
M(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?
M<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA
M<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A
M('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N
M=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O=W,@/2!`;7-Q;%]N
M=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H)')O=W,@/3T](&9A;'-E
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-Q;%)A:7-E17)R;W(H
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D*"D*"B`@("`O*BH*("`@("`J
M($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@
M9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E
M='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O
M=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("@A
M)'1H:7,M/E]R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!M<W%L7V%F9F5C=&5D7W)O=W,H)'1H:7,M
M/E]R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)
M9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N97AT(&9R964@:60@
M:6X@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S
M97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B
M;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A
M=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N
M8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)
M1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@
M("!$0E]M<W%L.CIC<F5A=&5397%U96YC92@I+"!$0E]M<W%L.CID<F]P4V5Q
M=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE
M+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@
M)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R
M97!E870@/2!F86QS93L*("`@("`@("!D;R!["B`@("`@("`@("`@("1T:&ES
M+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@
M("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y*")314Q%0U0@7W-E<2!&
M4D]-("1[<V5Q;F%M97TB*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R
M2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@*"1O;F1E;6%N9"`F)B!$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@)')E<W5L="T^
M9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2!["B`@("`@("`@
M("`@("`@("`D<F5P96%T(#T@=')U93L*("`@("`@("`@("`@("`@("1T:&ES
M+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S
M97%?;F%M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD
M;&EN9R@I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U
M;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@
M("`@("`@)&%R<B`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/
M4D1%4D5$*3L*("`@("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@<F5T
M=7)N("1A<G);,%T["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8W)E
M871E4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S
M97%U96YC90H@("`@("H*("`@("`J($%L<V\@8W)E871E<R!A(&YE=R!T86)L
M92!T;R!A<W-O8VEA=&4@=&AE('-E<75E;F-E('=I=&@N("!5<V5S"B`@("`@
M*B!A('-E<&%R871E('1A8FQE('1O(&5N<W5R92!P;W)T86)I;&ET>2!W:71H
M(&]T:&5R(&1R:79E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC
M94YA;64H*2P*("`@("`J("`@("`@1$)?;7-Q;#HZ;F5X=$E$*"DL($1"7VUS
M<6PZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T
M95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]
M("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D
M<F5S(#T@)'1H:7,M/G%U97)Y*"=#4D5!5$4@5$%"3$4@)R`N("1S97%N86UE
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@*&ED($E.5$5'15(@
M3D]4($Y53$PI)RD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@("`D
M<F5S(#T@)'1H:7,M/G%U97)Y*")#4D5!5$4@4T51545.0T4@3TX@)'MS97%N
M86UE?2(I.PH@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E
M9`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S
M+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ
M9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VUS<6PZ.FYE>'1)
M1"@I+"!$0E]M<W%L.CIC<F5A=&5397%U96YC92@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!404),12`G("X@)'1H:7,M/F=E
M=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!Q=6]T94ED96YT:69I97(H*0H*("`@("\J*@H@("`@("H@
M;5-13"!D;V5S(&YO="!S=7!P;W)T(&1E;&EM:71E9"!I9&5N=&EF:65R<PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@=&AE(&ED96YT:69I
M97(@;F%M92!T;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="`@82!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ<75O=&5)9&5N=&EF:65R*"D*("`@("`J($!S:6YC92!-971H
M;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@<75O=&5)9&5N=&EF:65R*"1S='(I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27U5.4U504$]25$5$
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<V-A<&53:6UP;&4H
M*0H*("`@("\J*@H@("`@("H@17-C87!E<R!A('-T<FEN9R!A8V-O<F1I;F<@
M=&\@=&AE(&-U<G)E;G0@1$)-4R=S('-T86YD87)D<PH@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-T<B`@=&AE('-T<FEN9R!T;R!B92!E<V-A<&5D
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E<V-A<&5D('-T
M<FEN9PH@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ=6]T95-M87)T
M*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E4VEM<&QE*"1S
M='(I"B`@("!["B`@("`@("`@<F5T=7)N(&%D9'-L87-H97,H)'-T<BD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;7-Q;%)A:7-E17)R;W(H*0H*
M("`@("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G
M87)D:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY
M(')A:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?
M15)23U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I
M;VX@9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J
M($!S964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"
M7VUS<6PZ.F5R<F]R3F%T:79E*"DL($1"7VUS<6PZ.F5R<F]R0V]D92@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&US<6Q286ES945R<F]R*"1E<G)N;R`](&YU
M;&PI"B`@("!["B`@("`@("`@)&YA=&EV92`]("1T:&ES+3YE<G)O<DYA=&EV
M92@I.PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@
M("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92@D;F%T:79E*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@
M;G5L;"P@;G5L;"P@;G5L;"P@)&YA=&EV92D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R(&UE<W-A9V4@<')O9'5C960@8GD@
M=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE($1"35,G(&5R<F]R(&UE<W-A9V4*("`@("`J+PH@("`@9G5N8W1I;VX@
M97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(')E='5R;B!`;7-Q;%]E<G)O
M<B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I
M"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(%!%05(Z.D1"(&5R<F]R(&-O
M9&4@9G)O;2!T:&4@9&%T86)A<V4G<R!T97AT(&5R<F]R(&UE<W-A9V4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O<FUS9R`@=&AE(&5R<F]R
M(&UE<W-A9V4@<F5T=7)N960@9G)O;2!T:&4@9&%T86)A<V4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@('1H92!E<G)O<B!N=6UB97(@9G)O;2!A
M($1"7T524D]2*B!C;VYS=&%N=`H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O
M<D-O9&4H)&5R<F]R;7-G*0H@("`@>PH@("`@("`@('-T871I8R`D97)R;W)?
M<F5G97AP<SL*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<E]R96=E>'!S*2D@
M>PH@("`@("`@("`@("`D97)R;W)?<F5G97AP<R`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)R]>06-C97-S('1O(&1A=&%B87-E(&1E;FEE9"]I)PH@("`@
M("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]624],051)3TXL
M"B`@("`@("`@("`@("`@("`G+UY"860@:6YD97@@;F%M92]I)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@
M("`@("`@("`@("`@)R]>0F%D(&]R9&5R(&9I96QD+VDG"B`@("`@("`@("`@
M("`@("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@
M)R]>0F%D('1Y<&4@9F]R(&-O;7!A<FES;VXO:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@("`G+UY#
M86Y<)W0@<&5R9F]R;2!,24M%(&]N+VDG"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]>0V%N7"=T
M('5S92!415A4(&9I96QD<R!I;B!,24M%(&-O;7!A<FES;VXO:2<*("`@("`@
M("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@
M("`@("`G+UY#;W5L9&Y<)W0@8W)E871E('1E;7!O<F%R>2!T86)L92]I)PH@
M("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L
M"B`@("`@("`@("`@("`@("`G+UY%<G)O<B!C<F5A=&EN9R!T86)L92!F:6QE
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?0T%.3D]47T-2
M14%412P*("`@("`@("`@("`@("`@("<O7D9I96QD("XJ(&-A;FYO="!B92!N
M=6QL)"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-/3E-4
M4D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@("`G+UY);F1E>"`H9FEE
M;&1\8V]N9&ET:6]N*2`N*B!C86YN;W0@8F4@;G5L;"0O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@
M("`G+UY);G9A;&ED(&1A=&4@9F]R;6%T+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?24Y604Q)1%]$051%+`H@("`@("`@("`@("`@("`@
M)R]>26YV86QI9"!T:6UE(&9O<FUA="]I)PH@("`@("`@("`@("`@("`@("`@
M(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@("`@("`@("`G+UY,:71E
M<F%L('9A;'5E(&9O<B`N*B!I<R!W<F]N9R!T>7!E)"]I)PH@("`@("`@("`@
M("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@
M("`@("`@("`@)R]>3F\@1&%T86)A<V4@4V5L96-T960O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E].3T1"4T5,14-4140L"B`@("`@("`@
M("`@("`@("`G+UY.;R!V86QU92!S<&5C:69I960@9F]R(&9I96QD+VDG"B`@
M("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?5D%,545?0T]53E1?3TY?
M4D]7+`H@("`@("`@("`@("`@("`@)R]>3F]N('5N:7%U92!V86QU92!F;W(@
M=6YI<75E(&EN9&5X+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@("<O7D]U="!O9B!M96UO
M<GD@9F]R('1E;7!O<F%R>2!T86)L92]I)PH@("`@("`@("`@("`@("`@("`@
M(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L"B`@("`@("`@("`@("`@("`G
M+UY097)M:7-S:6]N(&1E;FEE9"]I)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@("`@("`@("`G
M+UY2969E<F5N8V4@=&\@=6XM<V5L96-T960@=&%B;&4O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@
M("`G+UYS>6YT87@@97)R;W(O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@("`G+UY486)L92`N*B!E
M>&ES=',D+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?04Q2
M14%$65]%6$E35%,L"B`@("`@("`@("`@("`@("`G+UY5;FMN;W=N(&1A=&%B
M87-E+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]354-(
M1$(L"B`@("`@("`@("`@("`@("`G+UY5;FMN;W=N(&9I96QD+VDG"B`@("`@
M("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@
M("`@("`@("`@("`G+UY5;FMN;W=N("AI;F1E>'QS>7-T96T@=F%R:6%B;&4I
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]47T9/54Y$
M+`H@("`@("`@("`@("`@("`@)R]>56YK;F]W;B!T86)L92]I)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@
M("`@("`@("`@)R]>56YQ=6%L:69I960@9FEE;&0O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("D["B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D97)R;W)?<F5G97AP<R!A<R`D
M<F5G97AP(#T^("1C;V1E*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"1R96=E>'`L("1E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D8V]D93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B
M;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@
M86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!`
M<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C
M="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A
M('1A8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I
M9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R
M86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@
M;6]D90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T
M:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@
M("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO
M9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L
M="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@
M82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1I9"`]($!M<W%L7W%U97)Y*")314Q%0U0@*B!&4D]-
M("1R97-U;'0B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U
M93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S=6QT*2D@
M>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E
M:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X=')A8W0@
M=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@
M*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@("`@("`@
M("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D
M(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J
M($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')E8V%T960N("!(97)E(&9O
M<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@("`@("`J+PH@("`@("`@
M("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D
M:60I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S
M=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S
M95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@
M/2!`;7-Q;%]N=6U?9FEE;&1S*"1I9"D["B`@("`@("`@)')E<R`@(#T@87)R
M87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R97-;
M)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D
M=&UP(#T@0&US<6Q?9F5T8VA?9FEE;&0H)&ED*3L*"B`@("`@("`@("`@("1F
M;&%G<R`]("<G.PH@("`@("`@("`@("!I9B`H)'1M<"T^;F]T7VYU;&PI('L*
M("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G;F]T7VYU;&P@)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)'1M<"T^=6YI<75E*2!["B`@("`@
M("`@("`@("`@("`D9FQA9W,@+CT@)W5N:7%U95]K97D@)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D9FQA9W,@/2!T<FEM*"1F;&%G<RD["@H@("`@
M("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A
M8FQE)R`]/B`D8V%S95]F=6YC*"1T;7`M/G1A8FQE*2P*("`@("`@("`@("`@
M("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8R@D=&UP+3YN86UE*2P*("`@("`@
M("`@("`@("`@("=T>7!E)R`@/3X@)'1M<"T^='EP92P*("`@("`@("`@("`@
M("`@("=L96XG("`@/3X@;7-Q;%]F:65L9%]L96XH)&ED+"`D:2DL"B`@("`@
M("`@("`@("`@("`G9FQA9W,G(#T^("1F;&%G<RP*("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@
M>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M
M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D;6]D
M92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@
M("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;
M)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E<F4@8V%L
M;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I('L*("`@
M("`@("`@("`@0&US<6Q?9G)E95]R97-U;'0H)&ED*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*("`@("`J($]B=&%I;B!A
M(&QI<W0@;V8@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO
M=2!W86YT('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@=&AE(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&QI<W0@;V8@;V)J96-T<R!R
M97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S
M=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)V1A=&%B87-E<R<Z
M"B`@("`@("`@("`@("`@("`D:60@/2!`;7-Q;%]L:7-T7V1B<R@D=&AI<RT^
M8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@("`@("1I9"`]($!M<W%L
M7VQI<W1?=&%B;&5S*"1T:&ES+3YD<VY;)V1A=&%B87-E)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V]N;F5C
M=&EO;BD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21I9"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUS<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("1O=70@/2!A
M<G)A>2@I.PH@("`@("`@('=H:6QE("@D<F]W(#T@0&US<6Q?9F5T8VA?<F]W
M*"1I9"DI('L*("`@("`@("`@("`@)&]U=%M=(#T@)')O=ULP73L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]"@H@("`@+R\@?7U]"@I]
M"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C
M+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+VUS<W%L+G!H
M<```````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8U
M-C0V`#$P-3$U-#,Q,#4W`#`Q-S4Q-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*
M"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S(&US<W%L(&5X
M=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!-:6-R;W-O9G0@4U%,
M(%-E<G9E<B!D871A8F%S97,*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*
M("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V
M86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L
M;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@
M($1""B`J($!A=71H;W(@("`@(%-T97)L:6YG($AU9VAE<R`\<W1E<FQI;F=`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N
M:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(&US<W%L+G!H<"QV(#$N.#,@,C`P-2\P,R\P-R`Q.#HR-#HU
M,2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O
M;6UO;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q
M=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D
M<R!014%2($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!02%`G<R!M<W-Q;"!E
M>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@36EC<F]S;V9T(%-1
M3"!397)V97(@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO
M860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@*@H@*B!`8V%T
M96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R
M("`@("!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H<"YN970^"B`J($!A
M=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$
M0@H@*B\*8VQA<W,@1$)?;7-S<6P@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@
M+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV
M97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G;7-S<6PG.PH*
M("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O
M(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@)VUS<W%L
M)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$
M0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG
M(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@
M<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-
M4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@
M*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@
M("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@
M;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y
M"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R
M87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=E;75L871E)RP*("`@
M("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VYU;7)O
M=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN96-T)R`@("`@(#T^
M('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("=S<VPG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A
M8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA
M<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@("\O(%A86"!!9&0@:&5R
M92!E<G)O<B!C;V1E<R!I93H@)U,Q,#!%)R`]/B!$0E]%4E)/4E]364Y405@*
M("`@('9A<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@("`@(#$Q,"`@
M(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*("`@("`@("`Q-34@
M("`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`Q-S`@("`]/B!$
M0E]%4E)/4E]364Y405@L"B`@("`@("`@,C`W("`@/3X@1$)?15)23U)?3D]3
M54-(1DE%3$0L"B`@("`@("`@,C`X("`@/3X@1$)?15)23U)?3D]354-(5$%"
M3$4L"B`@("`@("`@,C0U("`@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L
M"B`@("`@("`@-3$U("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,
M3"P*("`@("`@("`U-#<@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@
M("`@(#$Y,3,@(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@
M(#(V,C<@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@,C<Q-"`@
M/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@,S<P,2`@/3X@
M1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@.#$S-"`@/3X@1$)?15)2
M3U)?1$E66D523RP*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A
M=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@
M<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J
M*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T
M;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@9&%T
M82!M86YI<'5L871I;VX@<75E<FEE<R!B92!C;VUM:71T960@875T;VUA=&EC
M86QL>3\*("`@("`J($!V87(@8F]O;`H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D875T;V-O;6UI="`]('1R=64["@H@("`@+RHJ
M"B`@("`@*B!4:&4@<75A;G1I='D@;V8@=')A;G-A8W1I;VYS(&)E9W5N"B`@
M("`@*@H@("`@("H@>T!I;G1E<FYA;"`@5VAI;&4@=&AI<R!I<R!P<FEV871E
M+"!I="!C86XG="!A8W1U86QL>2!B92!D97-I9VYA=&5D"B`@("`@*B!P<FEV
M871E(&EN(%!(4"`U(&)E8V%U<V4@:70@:7,@9&ER96-T;'D@86-C97-S960@
M:6X@=&AE('1E<W0@<W5I=&4N?7T*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G
M97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)'1R
M86YS86-T:6]N7V]P8V]U;G0@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&1A
M=&%B87-E('-P96-I9FEE9"!I;B!T:&4@1%-."B`@("`@*@H@("`@("H@270G
M<R!A(&9I>"!T;R!A;&QO=R!C86QL<R!T;R!D:69F97)E;G0@9&%T86)A<V5S
M(&EN('1H92!S86UE('-C<FEP="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1B
M(#T@;G5L;#L*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*
M"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD
M=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?;7-S<6PH*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D
M871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@
M9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U
M<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO
M=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE
M8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)VUS<W%L)RD@)B8@(5!%05(Z.FQO
M861%>'1E;G-I;VXH)W-Y8F%S92<I"B`@("`@("`@("`@("8F("%014%2.CIL
M;V%D17AT96YS:6]N*"=S>6)A<V5?8W0G*2D*("`@("`@("!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)
M3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD<VX@
M/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y;G1A>"==*2!["B`@("`@
M("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;)V1B<WEN=&%X)UT["B`@
M("`@("`@?0H*("`@("`@("`D<&%R86US(#T@87)R87DH"B`@("`@("`@("`@
M("1D<VY;)VAO<W1S<&5C)UT@/R`D9'-N6R=H;W-T<W!E8R==(#H@)VQO8V%L
M:&]S="<L"B`@("`@("`@("`@("1D<VY;)W5S97)N86UE)UT@/R`D9'-N6R=U
M<V5R;F%M92==(#H@;G5L;"P*("`@("`@("`@("`@)&1S;ELG<&%S<W=O<F0G
M72`_("1D<VY;)W!A<W-W;W)D)UT@.B!N=6QL+`H@("`@("`@("D["B`@("`@
M("`@:68@*"1D<VY;)W!O<G0G72D@>PH@("`@("`@("`@("`D<&%R86US6S!=
M("X]("@H<W5B<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<I(#\@)RPG(#H@
M)SHG*0H@("`@("`@("`@("`@("`@("`@("`@("`N("1D<VY;)W!O<G0G73L*
M("`@("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I
M<W1E;G0@/R`G;7-S<6Q?<&-O;FYE8W0G(#H@)VUS<W%L7V-O;FYE8W0G.PH*
M("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N8U]A
M<G)A>2@D8V]N;F5C=%]F=6YC=&EO;BP@)'!A<F%M<RD["@H@("`@("`@(&EF
M("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!M
M<W-Q;%]G971?;&%S=%]M97-S86=E*"DI.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@("`@("`@("!I9B`H(4!M<W-Q
M;%]S96QE8W1?9&(H)&1S;ELG9&%T86)A<V4G72P@)'1H:7,M/F-O;FYE8W1I
M;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&US<W%L7V=E
M=%]L87-T7VUE<W-A9V4H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/E]D8B`]("1D<VY;)V1A=&%B87-E)UT["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R
M;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R
M970@/2!`;7-S<6Q?8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E
M=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I
M"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O('1H92!D871A8F%S
M92!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,
M('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@
M82!02%`@<F5S=6QT(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q
M=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS
M=&%N="!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@
M("`@("`@("`@("`K(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@
M("`@("`@("1I<VUA;FEP(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@
M("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("!I9B`H(4!M
M<W-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R
M*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@?0H@("`@("`@("1Q
M=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@(&EF
M("@A)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES;6%N:7`I('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T](#`I('L*("`@
M("`@("`@("`@("`@("1R97-U;'0@/2!`;7-S<6Q?<75E<GDH)T)%1TE.(%12
M04XG+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUS<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT
M*RL["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2!`;7-S<6Q?<75E<GDH
M)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@("\O($1E=&5R;6EN92!W:&EC:"!Q
M=65R:65S('1H870@<VAO=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@
M("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@
M("`@("!R971U<FX@)&ES;6%N:7`@/R!$0E]/2R`Z("1R97-U;'0["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ
M"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!M<W-Q;"!R97-U;'0@<&]I;G1E
M<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@
M0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('1R
M=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R=VES92!R971U<FX@
M9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT
M*0H@("`@>PH@("`@("`@(')E='5R;B!`;7-S<6Q?;F5X=%]R97-U;'0H)')E
M<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O
M*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F<F]M('1H92!R97-U
M;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R
M;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@
M8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O
M*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S
M90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I;G-T96%D+B`@270@
M8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@
M1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@
M<F5S;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H
M92!R969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@
M0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@
M87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P87)A;2!I;G0@("`@
M("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER
M<W0@<F]W*0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($1"7T]+(&]N
M('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I
M<PH@("`@("H@("`@("`@("`@("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R
M90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L
M("1F971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@A0&US<W%L
M7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@
M("`@("`@("`@)&%R<B`]($!M<W-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!-
M4U-13%]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D
M87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME
M>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!M<W-Q;%]F971C:%]R
M;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)
M5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L
M=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-
M4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A
M;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT
M*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S970@86YD
M(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L="!S970*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@
M8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R964H
M*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*
M("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G
M<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I
M;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R964H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@("![
M"B`@("`@("`@<F5T=7)N($!M<W-Q;%]F<F5E7W)E<W5L="@D<F5S=6QT*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O
M*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S
M=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N
M="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L
M=#HZ;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M
M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&US<W%L7VYU
M;5]F:65L9',H)')E<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<B@I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H
M92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C
M=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T96%D
M+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E
M8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R
M97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE
M(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*("`@
M("`@("`D<F]W<R`]($!M<W-Q;%]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@
M("!I9B`H)')O=W,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;7-S<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F]W<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O
M0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES86)L97,@
M875T;VUA=&EC(&-O;6UI=',*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;"`D
M;VYO9F8@('1R=64@='5R;G,@:70@;VXL(&9A;'-E('1U<FYS(&ET(&]F9@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E<@H@("`@("H@("`@("`@
M("`@("`@("!D;V5S;B=T('-U<'!O<G0@875T;RUC;VUM:71T:6YG('1R86YS
M86-T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O;6UI="@D;VYO
M9F8@/2!F86QS92D*("`@('L*("`@("`@("`O+R!86%@@:68@)'1H:7,M/G1R
M86YS86-T:6]N7V]P8V]U;G0@/B`P+"!W92!S:&]U;&0@<')O8F%B;'D*("`@
M("`@("`O+R!I<W-U92!A('=A<FYI;F<@:&5R92X*("`@("`@("`D=&AI<RT^
M875T;V-O;6UI="`]("1O;F]F9B`_('1R=64@.B!F86QS93L*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M
M;6ET*"D*"B`@("`O*BH*("`@("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A
M;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("!I
M9B`H(4!M<W-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE
M8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L
M4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`;7-S<6Q?<75E<GDH)T-/34U)
M5"!44D%.)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D=&AI
M<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A
M)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q
M;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N
M="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/
M2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@
M("`@("`@:68@*"%`;7-S<6Q?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES
M+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YM<W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT(#T@0&US<W%L7W%U97)Y
M*"=23TQ,0D%#2R!44D%.)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@
M("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YM<W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R
M;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M
M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D
M(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("A$0CHZ:7--
M86YI<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@("`@("`@("`@)')E<R`]
M($!M<W-Q;%]Q=65R>2@G<V5L96-T($!`<F]W8V]U;G0G+"`D=&AI<RT^8V]N
M;F5C=&EO;BD["B`@("`@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D87(@/2!`;7-S<6Q?9F5T8VA?<F]W*"1R
M97,I.PH@("`@("`@("`@("!I9B`H(21A<BD@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`](#`["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!`;7-S<6Q?9G)E95]R97-U;'0H)')E<RD["B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)&%R6S!=.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<W5L="`](#`["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N97AT
M(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J
M($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q
M96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU;6)E<B!I;B!T
M:&4@<V5Q=65N8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@
M("`@("H@("`@("!$0E]M<W-Q;#HZ8W)E871E4V5Q=65N8V4H*2P@1$)?;7-S
M<6PZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)
M9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@
M)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D[
M"B`@("`@("`@:68@*"%`;7-S<6Q?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T
M:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUS<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@
M("`@('T*("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("!D;R!["B`@("`@
M("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH(DE.
M4T525"!)3E1/("1S97%N86UE("AV87!O<BD@5D%,5453("@P*2(I.PH@("`@
M("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@
M("!I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@
M("`@("`@("`@("`@("`H)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]2
M('Q\("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U-50TA404),
M12DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1R97!E870@/2`Q
M.PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U
M96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V5I9B`H(41".CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#TF("1T:&ES+3YQ=65R>2@B4T5,
M14-4($!`241%3E1)5%D@1E)/32`D<V5Q;F%M92(I.PH@("`@("`@("`@("`@
M("`@)')E<&5A="`](#`["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<F5P96%T(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!]('=H:6QE("@D<F5P96%T*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)')E
M<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@
M(')E='5R;B`D<F5S=6QT6S!=.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E<R!A(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q
M=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VUS<W%L.CIN97AT240H*2P@
M1$)?;7-S<6PZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G%U97)Y*"=#4D5!5$4@5$%"3$4@)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?
M;F%M92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R`H6VED72!;
M:6YT72!)1$5.5$E462`H,2P@,2D@3D]4($Y53$PL)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G(%MV87!O<ET@6VEN=%T@3E5,3"DG*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E
M('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?
M3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I
M+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$
M0E]M<W-Q;#HZ;F5X=$E$*"DL($1"7VUS<W%L.CIC<F5A=&5397%U96YC92@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!404),
M12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T94ED96YT:69I97(H*0H*
M("`@("\J*@H@("`@("H@475O=&5S(&$@<W1R:6YG('-O(&ET(&-A;B!B92!S
M869E;'D@=7-E9"!A<R!A('1A8FQE(&]R(&-O;'5M;B!N86UE"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<W1R("!I9&5N=&EF:65R(&YA;64@=&\@
M8F4@<75O=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('%U;W1E
M9"!I9&5N=&EF:65R('-T<FEN9PH@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIQ=6]T94ED96YT:69I97(H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!Q=6]T94ED96YT:69I97(H)'-T<BD*("`@('L*("`@("`@("!R971U
M<FX@)ULG("X@<W1R7W)E<&QA8V4H)UTG+"`G75TG+"`D<W1R*2`N("==)SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M<W-Q;%)A:7-E17)R;W(H
M*0H*("`@("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@
M<F5G87)D:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A
M;&QY(')A:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M1$)?15)23U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M
M871I;VX@9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@
M($1"7VUS<W%L.CIE<G)O<DYA=&EV92@I+"!$0E]M<W-Q;#HZ97)R;W)#;V1E
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;7-S<6Q286ES945R<F]R*"1C;V1E
M(#T@;G5L;"D*("`@('L*("`@("`@("`D;65S<V%G92`]($!M<W-Q;%]G971?
M;&%S=%]M97-S86=E*"D["B`@("`@("`@:68@*"$D8V]D92D@>PH@("`@("`@
M("`@("`D8V]D92`]("1T:&ES+3YE<G)O<DYA=&EV92@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'1H:7,M/F5R<F]R
M0V]D92@D8V]D92P@)&UE<W-A9V4I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+"`B)&-O9&4@+2`D;65S<V%G
M92(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E
M*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O
M<B!C;V1E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@('1H92!$0DU3)R!E<G)O<B!C;V1E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("`D<F5S
M(#T@0&US<W%L7W%U97)Y*"=S96QE8W0@0$!%4E)/4B!A<R!%<G)O<D-O9&4G
M+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@:68@*"$D<F5S*2!["B`@
M("`@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@("`@("!]"B`@("`@("`@
M)')O=R`]($!M<W-Q;%]F971C:%]R;W<H)')E<RD["B`@("`@("`@<F5T=7)N
M("1R;W=;,%T["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)#
M;V1E*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@4$5!4CHZ1$(@97)R
M;W(@8V]D92!F<F]M(&US<W%L)W,@;F%T:79E(&-O9&5S+@H@("`@("H*("`@
M("`J($EF(#QV87(^)&YA=&EV96-O9&4\+W9A<CX@:7-N)W0@:VYO=VX@>65T
M+"!I="!W:6QL(&)E(&QO;VME9"!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&UI>&5D("`D;F%T:79E8V]D92`@;7-S<6P@97)R;W(@8V]D92P@:68@:VYO
M=VX*("`@("`J($!R971U<FX@:6YT96=E<B`@86X@97)R;W(@;G5M8F5R(&9R
M;VT@82!$0B!E<G)O<B!C;VYS=&%N=`H@("`@("H@0'-E92!E<G)O<DYA=&EV
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D;F%T:79E8V]D
M92`](&YU;&PL("1M<V<@/2`G)RD*("`@('L*("`@("`@("!I9B`H(21N871I
M=F5C;V1E*2!["B`@("`@("`@("`@("1N871I=F5C;V1E(#T@)'1H:7,M/F5R
M<F]R3F%T:79E*"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^97)R;W)C;V1E7VUA<%LD;F%T:79E8V]D95TI*2!["B`@("`@("`@("`@
M(&EF("@D;F%T:79E8V]D92`]/2`S-S`Q"B`@("`@("`@("`@("`@("`F)B!P
M<F5G7VUA=&-H*"<O0V%N;F]T(&1R;W`@=&AE(&EN9&5X+VDG+"`D;7-G*2D*
M("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@<F5T=7)N($1"7T524D]2
M7TY/5%]&3U5.1#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F5R<F]R8V]D95]M87!;)&YA=&EV96-O9&5=.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L
M92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!.3U1%.B!O;FQY('-U
M<'!O<G1S("=T86)L92<@86YD("=F;&%G<R<@:68@/'9A<CXD<F5S=6QT/"]V
M87(^"B`@("`@*B!I<R!A('1A8FQE(&YA;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&]B:F5C='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@
M9G)O;2!A('%U97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T
M86)L92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M5VAI;&4@=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E
M;G1I9FEE<BP@=&AI<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M
M(&EN="`@("`@("`@("`@("1M;V1E("`@(&$@=F%L:60@=&%B;&5);F9O(&UO
M9&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV
M92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@
M*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E
M8V5I=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@
M<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@
M("`@("`@("`@("!I9B`H(4!M<W-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@
M)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I9"`]($!M<W-Q;%]Q=65R
M>2@B4T5,14-4("H@1E)/32`D<F5S=6QT(%=(15)%(#$],"(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V5I
M9B`H:7-S970H)')E<W5L="T^<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!O8FIE
M8W0N"B`@("`@("`@("`@("`J($5X=')A8W0@=&AE(')E<W5L="!R97-O=7)C
M92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED
M(#T@)')E<W5L="T^<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]
M(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E
M(&ED96YT:69I97(N"B`@("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@
M("`@("`J($1E<')E8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N
M;'DN"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT
M.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D:60I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R*$1"7T524D]27TY%141?
M34]215]$051!*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R
M=F%L)SL*("`@("`@("!]"@H@("`@("`@("1C;W5N="`]($!M<W-Q;%]N=6U?
M9FEE;&1S*"1I9"D["B`@("`@("`@)')E<R`@(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G
M72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D<F5S6R1I72`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D9V]T7W-T<FEN9R`_
M("1C87-E7V9U;F,H)')E<W5L="D@.B`G)RP*("`@("`@("`@("`@("`@("=N
M86UE)R`@/3X@)&-A<V5?9G5N8RA`;7-S<6Q?9FEE;&1?;F%M92@D:60L("1I
M*2DL"B`@("`@("`@("`@("`@("`G='EP92<@(#T^($!M<W-Q;%]F:65L9%]T
M>7!E*"1I9"P@)&DI+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]/B!`;7-S
M<6Q?9FEE;&1?;&5N9W1H*"1I9"P@)&DI+`H@("`@("`@("`@("`@("`@+R\@
M5V4@;VYL>2!S=7!P;W)T(&9L86=S(&9O<B!T86)L90H@("`@("`@("`@("`@
M("`@)V9L86=S)R`]/B`D9V]T7W-T<FEN9PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`_("1T:&ES+3Y?;7-S<6Q?9FEE;&1?9FQA9W,H)')E<W5L="P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($!M<W-Q;%]F:65L9%]N86UE*"1I9"P@)&DI*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("<G+`H@("`@("`@("`@("`I.PH@("`@
M("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@
M("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$
M0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@)')E
M<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG
M;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O
M;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@
M("`@($!M<W-Q;%]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?
M;7-S<6Q?9FEE;&1?9FQA9W,H*0H*("`@("\J*@H@("`@("H@1V5T(&$@8V]L
M=6UN)W,@9FQA9W,*("`@("`J"B`@("`@*B!3=7!P;W)T<R`B;F]T7VYU;&PB
M+"`B<')I;6%R>5]K97DB+`H@("`@("H@(F%U=&]?:6YC<F5M96YT(B`H;7-S
M<6P@:61E;G1I='DI+"`B=&EM97-T86UP(B`H;7-S<6P@=&EM97-T86UP*2P*
M("`@("`J(")U;FEQ=65?:V5Y(B`H;7-S<6P@=6YI<75E(&EN9&5X+"!U;FEQ
M=64@8VAE8VL@;W(@<')I;6%R>5]K97DI(&%N9`H@("`@("H@(FUU;'1I<&QE
M7VME>2(@*&UU;'1I:V5Y(&EN9&5X*0H@("`@("H*("`@("`J(&US<W%L('1I
M;65S=&%M<"!I<R!.3U0@<VEM:6QA<B!T;R!T:&4@;7ES<6P@=&EM97-T86UP
M('-O('1H:7,@:7,@;6%Y8F4*("`@("`J(&YO="!U<V5F=6P@870@86QL("T@
M:7,@=&AE(&)E:&%V:6]U<B!O9B!M>7-Q;%]F:65L9%]F;&%G<R!T:&%T('!R
M:6UA<GD*("`@("`J(&ME>7,@87)E(&%L=V%Y('5N:7%U93\@:7,@=&AE(&EN
M=&5R<')E=&%T:6]N(&]F(&UU;'1I<&QE7VME>2!C;W)R96-T/PH@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1A8FQE("`@=&AE('1A8FQE(&YA;64*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;'5M;B`@=&AE(&9I96QD(&YA;64*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&9L86=S"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`875T:&]R($IO97)N
M($)A<G1H96P@/&I?8F%R=&AE;$!W96(N9&4^"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]M<W-Q;%]F:65L9%]F;&%G<R@D=&%B;&4L("1C;VQU;6XI"B`@("![
M"B`@("`@("`@<W1A=&EC("1T86)L94YA;64@/2!N=6QL.PH@("`@("`@('-T
M871I8R`D9FQA9W,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1A8FQE("$]
M("1T86)L94YA;64I('L*"B`@("`@("`@("`@("1F;&%G<R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1T86)L94YA;64@/2`D=&%B;&4["@H@("`@("`@("`@
M("`O+R!G970@=6YI<75E(&%N9"!P<FEM87)Y(&ME>7,*("`@("`@("`@("`@
M)')E<R`]("1T:&ES+3YG971!;&PH(D5814,@4U!?2$5,4$E.1$586R1T86)L
M95TB+"!$0E]&151#2$U/1$5?05-33T,I.PH*("`@("`@("`@("`@9F]R96%C
M:"`H)')E<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D:V5Y<R`](&5X
M<&QO9&4H)RP@)RP@)'9A;%LG:6YD97A?:V5Y<R==*3L*"B`@("`@("`@("`@
M("`@("!I9B`H<VEZ96]F*"1K97ES*2`^(#$I('L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S6R1K97E=+"`G;75L
M=&EP;&5?:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)'9A;%LG:6YD
M97A?9&5S8W)I<'1I;VXG72P@)W!R:6UA<GD@:V5Y)RDI('L*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S6R1K97E=
M+"`G<')I;6%R>5]K97DG*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1V86Q;)VEN9&5X7V1E<V-R
M:7!T:6]N)UTL("=U;FEQ=64G*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A9&1?9FQA9R@D9FQA9W-;)&ME>5TL("=U;FEQ=65?:V5Y
M)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!G970@875T;U]I;F-R96UE
M;G0L(&YO=%]N=6QL(&%N9"!T:6UE<W1A;7`*("`@("`@("`@("`@)')E<R`]
M("1T:&ES+3YG971!;&PH(D5814,@4U!?0T],54U.4ULD=&%B;&5=(BP@1$)?
M1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1R97,@
M87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'9A;"`](&%R<F%Y7V-H86YG
M95]K97E?8V%S92@D=F%L+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@("`@
M(&EF("@D=F%L6R=N=6QL86)L92==(#T]("<P)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S6R1V86Q;)V-O;'5M;E]N
M86UE)UU=+"`G;F]T7VYU;&PG*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("AS=')P;W,H)'9A;%LG='EP95]N86UE)UTL("=I9&5N
M=&ET>2<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1?9FQA
M9R@D9FQA9W-;)'9A;%LG8V]L=6UN7VYA;64G75TL("=A=71O7VEN8W)E;65N
M="<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*'-T
M<G!O<R@D=F%L6R=T>7!E7VYA;64G72P@)W1I;65S=&%M<"<I*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1?9FQA9R@D9FQA9W-;)'9A;%LG
M8V]L=6UN7VYA;64G75TL("=T:6UE<W1A;7`G*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&%R<F%Y
M7VME>5]E>&ES=',H)&-O;'5M;BP@)&9L86=S*2D@>PH@("`@("`@("`@("!R
M971U<FXH:6UP;&]D92@G("<L("1F;&%G<ULD8V]L=6UN72DI.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@7V%D9%]F;&%G*"D*"B`@("`O*BH*("`@("`J($%D9',@82!S=')I
M;F<@=&\@=&AE(&9L86=S(&%R<F%Y(&EF('1H92!F;&%G(&ES(&YO="!Y970@
M:6X@=&AE<F4*("`@("`J("T@:68@=&AE<F4@:7,@;F\@9FQA9R!P<F5S96YT
M('1H92!A<G)A>2!I<R!C<F5A=&5D"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("`F)&%R<F%Y("!T:&4@<F5F97)E;F-E('1O('1H92!F;&%G+6%R<F%Y
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@('1H92!F;&%G('9A;'5E
M"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`875T:&]R($IO97)N($)A<G1H96P@/&I?
M8F%R=&AE;$!W96(N9&4^"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1?9FQA
M9R@F)&%R<F%Y+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D87)R87DI*2!["B`@("`@("`@("`@("1A<G)A>2`](&%R<F%Y*"1V86QU
M92D["B`@("`@("`@?2!E;'-E:68@*"%I;E]A<G)A>2@D=F%L=64L("1A<G)A
M>2DI('L*("`@("`@("`@("`@87)R87E?<'5S:"@D87)R87DL("1V86QU92D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P
M96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R
M>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O
M8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE
M(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9R!O
M<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@
M("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R97%U97-T960*("`@
M("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P
M96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@
M("!R971U<FX@(E-%3$5#5"!N86UE($923TT@<WES;V)J96-T<R!72$5212!T
M>7!E(#T@)U4G(@H@("`@("`@("`@("`@("`@("`@("`@("X@)R!/4D1%4B!"
M62!N86UE)SL*("`@("`@("`@("`@8V%S92`G=FEE=W,G.@H@("`@("`@("`@
M("`@("`@<F5T=7)N(")314Q%0U0@;F%M92!&4D]-('-Y<V]B:F5C=',@5TA%
M4D4@='EP92`]("=6)R(["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T
M"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O;7ES<6PN<&AP````````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S<P-#<`,3`U,34T
M,S$P-3<`,#$W-3(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H
M92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@;7ES<6P@97AT96YS:6]N"B`J
M(&9O<B!I;G1E<F%C=&EN9R!W:71H($UY4U%,(&1A=&%B87-E<PH@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1I9R!"
M86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@;7ES<6PN<&AP+'8@,2XQ,3<@,C`P-2\P
M,R\R.2`Q-3HP,SHR-B!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A
M:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@
M9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@
M*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!0
M2%`G<R!M>7-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@
M37E344P@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@
M=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@*@H@*B!`8V%T96=O
M<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@
M1$)?;7ES<6P@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E
M<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES
M<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G;7ES<6PG.PH*("`@("\J*@H@("`@
M("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B
M,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@)VUY<W%L)SL*"B`@("`O*BH*
M("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A
M=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N
M=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@
M("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS
M(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A
M;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L
M871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@
M*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@
M9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@
M)VQI;6ET)R`@("`@("`@(#T^("=A;'1E<B<L"B`@("`@("`@)VYE=U]L:6YK
M)R`@("`@(#T^("<T+C(N,"<L"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^
M('1R=64L"B`@("`@("`@)W!C;VYN96-T)R`@("`@(#T^('1R=64L"B`@("`@
M("`@)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@
M("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A8W1I;VYS)R`@/3X@
M=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA<'!I;F<@;V8@;F%T
M:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y
M*`H@("`@("`@(#$P,#0@/3X@1$)?15)23U)?0T%.3D]47T-214%412P*("`@
M("`@("`Q,#`U(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L"B`@("`@("`@
M,3`P-B`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@("`@("`@(#$P,#<@
M/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@,3`P."`]/B!$
M0E]%4E)/4E]#04Y.3U1?1%)/4"P*("`@("`@("`Q,#(R(#T^($1"7T524D]2
M7T%,4D5!1%E?15A)4U13+`H@("`@("`@(#$P-#0@/3X@1$)?15)23U)?04-#
M15-37U9)3TQ!5$E/3BP*("`@("`@("`Q,#0V(#T^($1"7T524D]27TY/1$)3
M14Q%0U1%1"P*("`@("`@("`Q,#0X(#T^($1"7T524D]27T-/3E-44D%)3E0L
M"B`@("`@("`@,3`T.2`]/B!$0E]%4E)/4E].3U-50TA$0BP*("`@("`@("`Q
M,#4P(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@(#$P-3$@
M/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@,3`U-"`]/B!$0E]%
M4E)/4E].3U-50TA&245,1"P*("`@("`@("`Q,#8Q(#T^($1"7T524D]27T%,
M4D5!1%E?15A)4U13+`H@("`@("`@(#$P-C(@/3X@1$)?15)23U)?04Q214%$
M65]%6$E35%,L"B`@("`@("`@,3`V-"`]/B!$0E]%4E)/4E]364Y405@L"B`@
M("`@("`@,3`Y,2`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@,3$P
M,"`]/B!$0E]%4E)/4E].3U1?3$]#2T5$+`H@("`@("`@(#$Q,S8@/3X@1$)?
M15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@(#$Q-#(@/3X@1$)?
M15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`Q,30V(#T^($1"7T52
M4D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#$R,38@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`Q,C$W(#T^($1"7T524D]27T-/3E-44D%)3E0L
M"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN
M96-T:6]N(&-R96%T960@8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@
M("`@*B\*("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H
M92!$4TX@:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S
M90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R
M<F%Y*"D["@H*("`@("\J*@H@("`@("H@4VAO=6QD(&1A=&$@;6%N:7!U;&%T
M:6]N('%U97)I97,@8F4@8V]M;6ET=&5D(&%U=&]M871I8V%L;'D_"B`@("`@
M*B!`=F%R(&)O;VP*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)&%U=&]C;VUM:70@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE
M('%U86YT:71Y(&]F('1R86YS86-T:6]N<R!B96=U;@H@("`@("H*("`@("`J
M('M`:6YT97)N86P@(%=H:6QE('1H:7,@:7,@<')I=F%T92P@:70@8V%N)W0@
M86-T=6%L;'D@8F4@9&5S:6=N871E9`H@("`@("H@<')I=F%T92!I;B!02%`@
M-2!B96-A=7-E(&ET(&ES(&1I<F5C=&QY(&%C8V5S<V5D(&EN('1H92!T97-T
M('-U:71E+GU]"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1T<F%N<V%C=&EO;E]O
M<&-O=6YT(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S<&5C
M:69I960@:6X@=&AE($133@H@("`@("H*("`@("`J($ET)W,@82!F:7@@=&\@
M86QL;W<@8V%L;',@=&\@9&EF9F5R96YT(&1A=&%B87-E<R!I;B!T:&4@<V%M
M92!S8W)I<'0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D8B`]("<G.PH*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@
M("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C;VUM
M;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!$0E]M>7-Q;"@I"B`@("!["B`@("`@("`@)'1H:7,M
M/D1"7V-O;6UO;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O
M;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A
M<V4@<V5R=F5R+"!L;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@
M*@H@("`@("H@1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S
M92!$0CHZ8V]N;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@4$5!4B!$
M0B=S(&UY<W%L(&1R:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A
M($133B!O<'1I;VYS.@H@("`@("H@("`K(&YE=U]L:6YK("`@("`@268@<V5T
M('1O('1R=64L(&-A=7-E<R!S=6)S97%U96YT(&-A;&QS('1O(&-O;FYE8W0H
M*0H@("`@("H@("`@("`@("`@("`@("`@("`@('1O(')E='5R;B!A(&YE=R!C
M;VYN96-T:6]N(&QI;FL@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("!E>&ES=&EN9R!O;F4N("!705).24Y'.B!T:&ES(&ES(&YO
M="!P;W)T86)L92!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@(&]T:&5R
M($1"35,G<RX@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@("`@
M*B`@("L@8VQI96YT7V9L86=S("!!;GD@8V]M8FEN871I;VX@;V8@35E344Q?
M0TQ)14Y47RH@8V]N<W1A;G1S+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M($]N;'D@=7-E9"!I9B!02%`@:7,@870@=F5R<VEO;B`T+C,N,"!O<B!G<F5A
M=&5R+@H@("`@("H@("`@("`@("`@("`@("`@("`@($%V86EL86)L92!S:6YC
M92!014%2($1"(#$N-RXP+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@("`J($!P87)A
M;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H92!C;VYN96-T:6]N(&)E
M('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+
M(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%>'1E;G-I
M;VXH)VUY<W%L)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@("`@:68@*"1D
M<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN=&%X
M(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"@H@("`@("`@("1P87)A
M;7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D9'-N6R=P<F]T;V-O;"==("8F
M("1D<VY;)W!R;W1O8V]L)UT@/3T@)W5N:7@G*2!["B`@("`@("`@("`@("1P
M87)A;7-;,%T@/2`G.B<@+B`D9'-N6R=S;V-K970G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<&%R86US6S!=(#T@)&1S;ELG:&]S='-P96,G
M72`_("1D<VY;)VAO<W1S<&5C)UT*("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@)VQO8V%L:&]S="<["B`@("`@("`@("`@(&EF("@D9'-N6R=P;W)T)UTI
M('L*("`@("`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)SHG("X@)&1S;ELG
M<&]R="==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1P87)A
M;7-;72`]("1D<VY;)W5S97)N86UE)UT@/R`D9'-N6R=U<V5R;F%M92==(#H@
M;G5L;#L*("`@("`@("`D<&%R86US6UT@/2`D9'-N6R=P87-S=V]R9"==(#\@
M)&1S;ELG<&%S<W=O<F0G72`Z(&YU;&P["@H@("`@("`@(&EF("@A)'!E<G-I
M<W1E;G0I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1D<VY;)VYE=U]L:6YK
M)UTI"B`@("`@("`@("`@("`@("`F)B`H)&1S;ELG;F5W7VQI;FLG72`]/2`G
M=')U92<@?'P@)&1S;ELG;F5W7VQI;FLG72`]/3T@=')U92DI"B`@("`@("`@
M("`@('L*("`@("`@("`@("`@("`@("1P87)A;7-;72`]('1R=64["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&%R86US6UT@/2!F
M86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H=F5R
M<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,RXP)RP@)SX])RDI('L*
M("`@("`@("`@("`@)'!A<F%M<UM=(#T@:7-S970H)&1S;ELG8VQI96YT7V9L
M86=S)UTI"B`@("`@("`@("`@("`@("`@("`@("`@(#\@)&1S;ELG8VQI96YT
M7V9L86=S)UT@.B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)&-O;FYE8W1?
M9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=M>7-Q;%]P8V]N;F5C="<@.B`G
M;7ES<6Q?8V]N;F5C="<["@H@("`@("`@("1I;FD@/2!I;FE?9V5T*"=T<F%C
M:U]E<G)O<G,G*3L*("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["B`@("`@
M("`@:68@*"1I;FDI('L*("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@
M/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C
M=%]F=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@("`@(&EN
M:5]S970H)W1R86-K7V5R<F]R<R<L("1I;FDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@("!I9B`H
M*"1E<G(@/2!`;7ES<6Q?97)R;W(H*2D@(3T@)R<I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-4
M7T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!N=6QL+"!N=6QL+"!N=6QL+"`*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D97)R*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P:'!?97)R;W)M
M<V<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&1S
M;ELG9&%T86)A<V4G72D@>PH@("`@("`@("`@("!I9B`H(4!M>7-Q;%]S96QE
M8W1?9&(H)&1S;ELG9&%T86)A<V4G72P@)'1H:7,M/F-O;FYE8W1I;VXI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O
M<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`D
M9'-N6R=D871A8F%S92==.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H
M*0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A
M<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N
M('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!M>7-Q;%]C
M;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O;FYE
M8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*("`@
M("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@
M("H*("`@("`J($=E;F5R86QL>2!U<V5S(&UY<W%L7W%U97)Y*"DN("!)9B!Y
M;W4@=V%N="!T;R!U<V4*("`@("`J(&UY<W%L7W5N8G5F9F5R961?<75E<GDH
M*2!S970@=&AE(")R97-U;'1?8G5F9F5R:6YG(B!O<'1I;VX@=&\@,"!U<VEN
M9PH@("`@("H@<V5T3W!T:6]N<R@I+B`@5&AI<R!O<'1I;VX@=V%S(&%D9&5D
M(&EN(%)E;&5A<V4@,2XW+C`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S<V9U
M;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!T:&4@
M1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<PH@
M("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R
M>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP*"1Q=65R
M>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@
M("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@
M("`@:68@*"1T:&ES+3Y?9&(I('L*("`@("`@("`@("`@:68@*"%`;7ES<6Q?
M<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H
M1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H(21T:&ES+3YA=71O8V]M;6ET("8F("1I<VUA;FEP
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N
M="`]/2`P*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L7W%U
M97)Y*"=3150@05543T-/34U)5#TP)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G0D5'24XG
M+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY
M<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT*RL[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/F]P=&EO;G-;)W)E<W5L
M=%]B=69F97)I;F<G72D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L
M7W5N8G5F9F5R961?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q
M;%]Q=65R>2@D<75E<GDL("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;7ES<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<U]R97-O=7)C92@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J
M*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@;7ES<6P@<F5S=6QT('!O:6YT
M97(@=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&AA<R!N;W0@8F5E;B!I;7!L96UE;G1E9"!Y970N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@<W%L(')E<W5L="!R97-O=7)C
M90H@("`@("H*("`@("`J($!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN
M=&\H*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E
M<W5L="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&
M;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R
M92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN
M=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)
M="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S
M92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L
M="!R97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@
M=&AE(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@
M*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN
M9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@
M("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F
M:7)S="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@
M;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL
M=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R
M<BP@)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"%`;7ES
M<6Q?9&%T85]S965K*"1R97-U;'0L("1R;W=N=6TI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]!4U-/0RD@>PH@
M("`@("`@("`@("`D87)R(#T@0&UY<W%L7V9E=&-H7V%R<F%Y*"1R97-U;'0L
M($U94U%,7T%34T]#*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F
M("1A<G(I('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?
M:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0&UY<W%L7V9E=&-H
M7W)O=R@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D87)R*2![
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465]25%))32D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!%
M=F5N('1H;W5G:"!T:&ES($1"35,@86QR96%D>2!T<FEM<R!O=71P=70L('=E
M(&1O('1H:7,@8F5C875S90H@("`@("`@("`@("`@*B!A(&9I96QD(&UI9VAT
M(&AA=F4@:6YT96YT:6]N86P@=VAI=&5S<&%C92!A="!T:&4@96YD('1H870*
M("`@("`@("`@("`@("H@9V5T<R!R96UO=F5D(&)Y($1"7U!/4E1!0DE,2519
M7U)44DE-('5N9&5R(&%N;W1H97(@9')I=F5R+@H@("`@("`@("`@("`@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL
M:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH
M)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*
M("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S970@86YD(&9R965S('1H92!M
M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C
M=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R964H*2!I;G-T96%D+B`@
M270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U
M<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U
M;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@
M;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@
M*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R964H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T
M=7)N($!M>7-Q;%]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E
M=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL
M960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I
M(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@
M("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S
M('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@
M:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN
M=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT
M*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&UY<W%L7VYU;5]F:65L9',H)')E
M<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@
M<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@
M("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@
M8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S
M=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R
M8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R
M;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*("`@("`@("`D<F]W<R`]
M($!M>7-Q;%]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H)')O=W,@
M/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A
M:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@
M("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M
M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T
M=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B
M:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N
M)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@
M("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I;VY?;W!C
M;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O(&ES<W5E
M(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@
M)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@("\J
M*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T
M:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1B
M*2!["B`@("`@("`@("`@("`@("!I9B`H(4!M>7-Q;%]S96QE8W1?9&(H)'1H
M:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H1$)?15)23U)?
M3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L7W%U97)Y*"=#3TU-250G
M+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1R97-U;'0@/2!`
M;7ES<6Q?<75E<GDH)U-%5"!!551/0T]-34E4/3$G+"`D=&AI<RT^8V]N;F5C
M=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT
M(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@
M("`@*B!2979E<G1S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M;VQL8F%C:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]D8BD@
M>PH@("`@("`@("`@("`@("`@:68@*"%`;7ES<6Q?<V5L96-T7V1B*"1T:&ES
M+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T524D]27TY/
M1$)314Q%0U1%1"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G4D],3$)!0TLG
M+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1R97-U;'0@/2!`
M;7ES<6Q?<75E<GDH)U-%5"!!551/0T]-34E4/3$G+"`D=&AI<RT^8V]N;F5C
M=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT
M(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T
M960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J
M(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L
M871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB
M97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@
M("`@:68@*$1".CII<TUA;FEP*"1T:&ES+3YL87-T7W%U97)Y*2D@>PH@("`@
M("`@("`@("!R971U<FX@0&UY<W%L7V%F9F5C=&5D7W)O=W,H)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`P.PH@("`@("`@('T*("`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E
M92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E
M(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S
M97%U96YC92X*("`@("`J("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@
M*B`@("`@($1"7VUY<W%L.CIC<F5A=&5397%U96YC92@I+"!$0E]M>7-Q;#HZ
M9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S
M97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q
M;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@
M("`@("!D;R!["B`@("`@("`@("`@("1R97!E870@/2`P.PH@("`@("`@("`@
M("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*")54$1!5$4@
M)'MS97%N86UE?2`B+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=3150@:60]3$%35%])3E-%4E1?240H:60K,2DG*3L*("`@("`@("`@
M("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@
M*"1R97-U;'0@/3T]($1"7T]+*2!["B`@("`@("`@("`@("`@("`O+R!#3TU-
M3TX@0T%310H@("`@("`@("`@("`@("`@)&ED(#T@0&UY<W%L7VEN<V5R=%]I
M9"@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!I9B`H)&ED
M("$](#`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@14U05%D@4T51(%1!
M0DQ%"B`@("`@("`@("`@("`@("`O+R!397%U96YC92!T86)L92!M=7-T(&)E
M(&5M<'1Y(&9O<B!S;VUE(')E87-O;BP@<V\@9FEL;`H@("`@("`@("`@("`@
M("`@+R\@:70@86YD(')E='5R;B`Q(&%N9"!O8G1A:6X@82!U<V5R+6QE=F5L
M(&QO8VL*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T3VYE
M*")314Q%0U0@1T547TQ/0TLH)R1[<V5Q;F%M97U?;&]C:R<L,3`I(BD["B`@
M("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E
M<W5L="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M)')E<W5L="`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@+R\@1F%I;&5D
M('1O(&=E="!T:&4@;&]C:PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T524D]27TY/5%],3T-+140I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O(&%D9"!T:&4@
M9&5F875L="!V86QU90H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YQ=65R>2@B4D503$%#12!)3E1/("1[<V5Q;F%M97T@*&ED*2!604Q515,@
M*#`I(BD["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L
M="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@+R\@4F5L96%S92!T:&4@;&]C:PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YG971/;F4H)U-%3$5#5"!214Q%05-%7TQ/0TLH)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B)R1[
M<V5Q;F%M97U?;&]C:R<I(BD["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES
M17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`O+R!792!K;F]W('=H870@=&AE(')E<W5L="!W
M:6QL(&)E+"!S;R!N;R!N965D('1O('1R>2!A9V%I;@H@("`@("`@("`@("`@
M("`@<F5T=7)N(#$["@H@("`@("`@("`@("!](&5L<V5I9B`H)&]N9&5M86YD
M("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@("`D
M<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I"B`@
M("`@("`@("`@('L*("`@("`@("`@("`@("`@("\O($].1$5-04Y$(%1!0DQ%
M($-214%424]."B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R
M96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R97!E870@/2`Q
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@?2!E;'-E:68@*$1"
M.CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?04Q214%$65]%6$E35%,I
M"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("\O($)!0TM705)$4R!#
M3TU0050*("`@("`@("`@("`@("`@("\O('-E92!?0D-S97%U96YC92@I(&-O
M;6UE;G0*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7T)#<V5Q
M=65N8V4H)'-E<6YA;64I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)')E<&5A="`](#$["B`@("`@("`@("`@('T*("`@
M("`@("!]('=H:6QE("@D<F5P96%T*3L*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&-R96%T95-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($-R96%T
M97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E;F-E"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E
M;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]M>7-Q;#HZ;F5X=$E$*"DL($1"
M7VUY<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C
M<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@)'-E<6YA
M;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@
M("`@)')E<R`]("1T:&ES+3YQ=65R>2@G0U)%051%(%1!0DQ%("<@+B`D<V5Q
M;F%M90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G("AI9"!)3E1%
M1T52(%5.4TE'3D5$($%55$]?24Y#4D5-14Y4($Y/5"!.54Q,+"<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R!04DE-05)9($M%62AI9"DI)RD[
M"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@("`O+R!I;G-E<G0@>6EE
M;&1S('9A;'5E(#$L(&YE>'1)9"!C86QL('=I;&P@9V5N97)A=&4@240@,@H@
M("`@("`@("1R97,@/2`D=&AI<RT^<75E<GDH(DE.4T525"!)3E1/("1[<V5Q
M;F%M97T@*&ED*2!604Q515,@*#`I(BD["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M('T*("`@("`@("`O+R!S;R!R97-E="!T;R!Z97)O"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YQ=65R>2@B55!$051%("1[<V5Q;F%M97T@4T54(&ED(#T@,"(I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q
M=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E
M;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@
M("`@($1"7VUY<W%L.CIN97AT240H*2P@1$)?;7ES<6PZ.F-R96%T95-E<75E
M;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S97%?
M;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=$4D]0
M(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]"0W-E<75E;F-E*"D*
M"B`@("`O*BH*("`@("`J($)A8VMW87)D<R!C;VUP871I8FEL:71Y('=I=&@@
M;VQD('-E<75E;F-E(&5M=6QA=&EO;B!I;7!L96UE;G1A=&EO;@H@("`@("H@
M*&-L96%N('5P('1H92!D=7!E<RD*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97%N86UE("!T:&4@<V5Q=65N8V4@;F%M92!T;R!C;&5A;B!U<`H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=')U92!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7T)#<V5Q=65N
M8V4H)'-E<6YA;64I"B`@("!["B`@("`@("`@+R\@3V)T86EN(&$@=7-E<BUL
M979E;"!L;V-K+BXN('1H:7,@=VEL;"!R96QE87-E(&%N>2!P<F5V:6]U<PH@
M("`@("`@("\O(&%P<&QI8V%T:6]N(&QO8VMS+"!B=70@=6YL:6ME($Q/0TL@
M5$%"3$53+"!I="!D;V5S(&YO="!A8F]R=`H@("`@("`@("\O('1H92!C=7)R
M96YT('1R86YS86-T:6]N(&%N9"!I<R!M=6-H(&QE<W,@9G)E<75E;G1L>2!U
M<V5D+@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T3VYE*")314Q%0U0@
M1T547TQ/0TLH)R1[<V5Q;F%M97U?;&]C:R<L,3`I(BD["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H)')E<W5L="`]/2`P*2![
M"B`@("`@("`@("`@("\O($9A:6QE9"!T;R!G970@=&AE(&QO8VLL(&-A;B=T
M(&1O('1H92!C;VYV97)S:6]N+"!B86EL"B`@("`@("`@("`@("\O('=I=&@@
M82!$0E]%4E)/4E].3U1?3$]#2T5$(&5R<F]R"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T524D]27TY/5%],3T-+140I
M.PH@("`@("`@('T*"B`@("`@("`@)&AI9VAE<W1?:60@/2`D=&AI<RT^9V5T
M3VYE*")314Q%0U0@34%8*&ED*2!&4D]-("1[<V5Q;F%M97TB*3L*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)&AI9VAE<W1?:60I*2!["B`@("`@("`@("`@
M(')E='5R;B`D:&EG:&5S=%]I9#L*("`@("`@("!]"B`@("`@("`@+R\@5&AI
M<R!S:&]U;&0@:VEL;"!A;&P@<F]W<R!E>&-E<'0@=&AE(&AI9VAE<W0*("`@
M("`@("`O+R!792!S:&]U;&0@<')O8F%B;'D@9&\@<V]M971H:6YG(&EF("1H
M:6=H97-T7VED(&ES;B=T"B`@("`@("`@+R\@;G5M97)I8RP@8G5T($DG;2!A
M="!A(&QO<W,@87,@:&]W('1O(&AA;F1L92!T:&%T+BXN"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YQ=65R>2@G1$5,151%($923TT@)R`N("1S97%N86UE
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("(@5TA%4D4@:60@
M/#X@)&AI9VAE<W1?:60B*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`O+R!)9B!A;F]T:&5R('1H<F5A9"!H87,@8F5E;B!W86ET
M:6YG(&9O<B!T:&ES(&QO8VLL"B`@("`@("`@+R\@:70@=VEL;"!G;R!T:')U
M('1H92!A8F]V92!P<F]C961U<F4L(&)U="!W:6QL(&AA=F4@;F\*("`@("`@
M("`O+R!R96%L(&5F9F5C=`H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T
M3VYE*")314Q%0U0@4D5,14%315],3T-+*"<D>W-E<6YA;65]7VQO8VLG*2(I
M.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&5)9&5N
M=&EF:65R*"D*"B`@("`O*BH*("`@("`J(%%U;W1E<R!A('-T<FEN9R!S;R!I
M="!C86X@8F4@<V%F96QY('5S960@87,@82!T86)L92!O<B!C;VQU;6X@;F%M
M90H@("`@("H*("`@("`J($UY4U%,(&-A;B=T(&AA;F1L92!T:&4@8F%C:W1I
M8VL@8VAA<F%C=&5R("@\:V)D/F`\+VMB9#XI(&EN"B`@("`@*B!T86)L92!O
M<B!C;VQU;6X@;F%M97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<W1R("!I9&5N=&EF:65R(&YA;64@=&\@8F4@<75O=&5D"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('%U;W1E9"!I9&5N=&EF:65R('-T<FEN9PH@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ=6]T94ED96YT:69I97(H
M*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED96YT:69I97(H
M)'-T<BD*("`@('L*("`@("`@("!R971U<FX@)V`G("X@)'-T<B`N("=@)SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T92@I"@H@("`@+RHJ
M"B`@("`@*B!`9&5P<F5C871E9"`@1&5P<F5C871E9"!I;B!R96QE87-E(#$N
M-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E*"1S='(I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YQ=6]T95-M87)T*"1S='(I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&5S8V%P95-I;7!L92@I"@H@("`@+RHJ
M"B`@("`@*B!%<V-A<&5S(&$@<W1R:6YG(&%C8V]R9&EN9R!T;R!T:&4@8W5R
M<F5N="!$0DU3)W,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W1R("!T:&4@<W1R:6YG('1O(&)E(&5S8V%P960*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5S8V%P960@<W1R:6YG"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@
M0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&53:6UP;&4H)'-T<BD*("`@('L*
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=M>7-Q;%]R96%L7V5S8V%P
M95]S=')I;F<G*2D@>PH@("`@("`@("`@("!R971U<FX@0&UY<W%L7W)E86Q?
M97-C87!E7W-T<FEN9R@D<W1R+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N($!M>7-Q;%]E<V-A<&5?
M<W1R:6YG*"1S='(I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!M;V1I9GE1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S
M(&$@<75E<GD@<W1R:6YG(&9O<B!V87)I;W5S($1"35,@<W!E8VEF:6,@<F5A
M<V]N<PH@("`@("H*("`@("`J(%1H:7,@;&ET=&QE(&AA8VL@;&5T<R!Y;W4@
M:VYO=R!H;W<@;6%N>2!R;W=S('=E<F4@9&5L971E9`H@("`@("H@=VAE;B!R
M=6YN:6YG(&$@(D1%3$5412!&4D]-('1A8FQE(B!Q=65R>2X@($]N;'D@:6UP
M;&5M96YT960*("`@("`J(&EF('1H92!$0E]03U)404))3$E465]$14Q%5$5?
M0T]53E0@<&]R=&%B:6QI='D@;W!T:6]N(&ES(&]N+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@<75E<GD@<W1R:6YG('1O(&UO
M9&EF>0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@;6]D:69I
M960@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D<75E<GDI"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?1$5,151%7T-/54Y4*2!["B`@("`@("`@("`@("\O(")$14Q%
M5$4@1E)/32!T86)L92(@9VEV97,@,"!A9F9E8W1E9"!R;W=S(&EN($UY4U%,
M+@H@("`@("`@("`@("`O+R!4:&ES(&QI='1L92!H86-K(&QE=',@>6]U(&MN
M;W<@:&]W(&UA;GD@<F]W<R!W97)E(&1E;&5T960N"B`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O7EQS*D1%3$5415QS*T923TU<<RLH7%,K*5QS*B0O
M:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@("`@("1Q=65R>2`]('!R96=?
M<F5P;&%C92@G+UY<<RI$14Q%5$5<<RM&4D]-7',K*%Q3*RE<<RHD+R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T1%3$5412!&
M4D]-(%PQ(%=(15)%(#$],2<L("1Q=65R>2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y*"D*"B`@("`O*BH*("`@
M("`J($%D9',@3$E-250@8VQA=7-E<R!T;R!A('%U97)Y('-T<FEN9R!A8V-O
M<F1I;F<@=&\@8W5R<F5N="!$0DU3('-T86YD87)D<PH@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE('%U97)Y('1O(&UO9&EF>0H@
M("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@("!T:&4@<F]W('1O('-T87)T
M('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T(')O=RD*("`@("`J($!P87)A
M;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E<G,@;V8@<F]W<R!T;R!F971C
M:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A<G)A>2P@<W1R:6YG
M(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@
M(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E
M<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('%U97)Y.B`@
M;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO
M;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W:71H($Q)34E4(&-L875S97,@
M861D960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q=65R>2P@)&9R;VTL
M("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*$1".CII<TUA;FEP*"1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N("1Q
M=65R>2`N("(@3$E-250@)&-O=6YT(CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)'%U97)Y("X@(B!,24U)5"`D9G)O;2P@)&-O=6YT
M(CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;7ES
M<6Q286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?
M17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E<G)O<B!I
M<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@268@=&AI
M<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE
M(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE
M8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I
M+`H@("`@("H@("`@("!$0E]M>7-Q;#HZ97)R;W).871I=F4H*2P@1$)?8V]M
M;6]N.CIE<G)O<D-O9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!M>7-Q;%)A
M:7-E17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&5R
M<FYO(#T]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N
M<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197T524D]24RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`R,ET@/2!$
M0E]%4E)/4E]#3TY35%)!24Y4.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R
M<F]R8V]D95]M87!;,3`T.%T@/2!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].
M54Q,.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`V
M,ET@/2!$0E]%4E)/4E]#3TY35%)!24Y4.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+R\@1&]I;F<@=&AI<R!I;B!C87-E(&UO9&4@
M8VAA;F=E<R!D=7)I;F<@<G5N=&EM92X*("`@("`@("`@("`@("`@("1T:&ES
M+3YE<G)O<F-O9&5?;6%P6S$P,C)=(#T@1$)?15)23U)?04Q214%$65]%6$E3
M5%,["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#0X
M72`]($1"7T524D]27T-/3E-44D%)3E0["B`@("`@("`@("`@("`@("`D=&AI
M<RT^97)R;W)C;V1E7VUA<%LQ,#8R72`]($1"7T524D]27T%,4D5!1%E?15A)
M4U13.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E<G)N;R`]("1T:&ES
M+3YE<G)O<D-O9&4H;7ES<6Q?97)R;F\H)'1H:7,M/F-O;FYE8W1I;VXI*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E
M<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@0&UY<W%L7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*2`N
M("<@*BH@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!M
M>7-Q;%]E<G)O<B@D=&AI<RT^8V]N;F5C=&EO;BDI.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J
M($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C;V1E('!R;V1U8V5D(&)Y
M('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H
M92!$0DU3)R!E<G)O<B!C;V1E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R
M3F%T:79E*"D*("`@('L*("`@("`@("!R971U<FX@0&UY<W%L7V5R<FYO*"1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA
M=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT('-E=`H@("`@("H*("`@
M("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@
M;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE
M(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U
M<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P<F5C871E9"X*("`@("`J
M($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE
M26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S
M;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D
M+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE
M26YF;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT
M+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B
M86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R
M96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@)&ED(#T@0&UY<W%L7VQI<W1?9FEE;&1S*"1T
M:&ES+3YD<VY;)V1A=&%B87-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V5I
M9B`H:7-S970H)')E<W5L="T^<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!O8FIE
M8W0N"B`@("`@("`@("`@("`J($5X=')A8W0@=&AE(')E<W5L="!R97-O=7)C
M92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED
M(#T@)')E<W5L="T^<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]
M(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E
M(&ED96YT:69I97(N"B`@("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@
M("`@("`J($1E<')E8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N
M;'DN"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT
M.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D:60I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T524D]27TY%141?
M34]215]$051!*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R
M=F%L)SL*("`@("`@("!]"@H@("`@("`@("1C;W5N="`]($!M>7-Q;%]N=6U?
M9FEE;&1S*"1I9"D["B`@("`@("`@)')E<R`@(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G
M72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D<F5S6R1I72`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D8V%S95]F=6YC*$!M
M>7-Q;%]F:65L9%]T86)L92@D:60L("1I*2DL"B`@("`@("`@("`@("`@("`G
M;F%M92<@(#T^("1C87-E7V9U;F,H0&UY<W%L7V9I96QD7VYA;64H)&ED+"`D
M:2DI+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B!`;7ES<6Q?9FEE;&1?
M='EP92@D:60L("1I*2P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@0&UY
M<W%L7V9I96QD7VQE;B@D:60L("1I*2P*("`@("`@("`@("`@("`@("=F;&%G
M<R<@/3X@0&UY<W%L7V9I96QD7V9L86=S*"1I9"P@)&DI+`H@("`@("`@("`@
M("`I.PH@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$
M15(I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;
M)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@
M("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD
M<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E
M(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2![
M"B`@("`@("`@("`@($!M>7-Q;%]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!G9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T
M86EN<R!T:&4@<75E<GD@<W1R:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I
M=F5N('1Y<&4@;V8@;V)J96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1Y<&4@('1H92!K:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T
M<FEE=F4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q
M=65R>2!S=')I;F<@;W(@;G5L;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@
M("`J("`@("`@("`@("`@("`@("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@
M<F5Q=65S=&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J($!S964@1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9713<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@
M<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@
M("`@("`@("`@("`@("`@<F5T=7)N("=32$]7(%1!0DQ%4R<["B`@("`@("`@
M("`@(&-A<V4@)W5S97)S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,
M14-4($1)4U1)3D-4(%5S97(@1E)/32!M>7-Q;"YU<V5R)SL*("`@("`@("`@
M("`@8V%S92`G9&%T86)A<V5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G
M4TA/5R!$051!0D%315,G.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O
M('U]?0H*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z
M(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T1"+VUY<W%L:2YP:'``````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,3`R,3(R`#$P-3$U-#,Q,#4W`#`Q-S8U,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R
M(%!(4"=S(&UY<W%L:2!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I
M=&@@37E344P@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@
M("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z
M("1)9#H@;7ES<6QI+G!H<"QV(#$N-CD@,C`P-2\P,R\P-"`R,SHQ,CHS-B!D
M86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO
M;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER
M95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!0
M14%2($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!02%`G<R!M>7-Q;&D@97AT
M96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UY4U%,(&1A=&%B87-E
M<PH@*@H@*B!4:&ES(&ES(&9O<B!->5-13"!V97)S:6]N<R`T+C$@86YD(&%B
M;W9E+B`@4F5Q=6ER97,@4$A0(#4N"B`J"B`J($YO=&4@=&AA="!P97)S:7-T
M96YT(&-O;FYE8W1I;VYS(&YO(&QO;F=E<B!E>&ES="X*("H*("H@5&AE<V4@
M;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM
M;VXN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@
M($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$0@H@*B!`<VEN8V4@("`@("!#;&%S<R!F=6YC=&EO;F%L('-I
M;F-E(%)E;&5A<V4@,2XV+C,*("HO"F-L87-S($1"7VUY<W%L:2!E>'1E;F1S
M($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@
M("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@
M971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP
M='EP92`]("=M>7-Q;&DG.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E
M('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N
M*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)&1B<WEN=&%X(#T@)VUY<W%L:2<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P
M86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@
M("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@
M=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S
M=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S
M('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L
M:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L871E
M('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@
M("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K
M:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@
M("`]/B`G86QT97(G+`H@("`@("`@("=N97=?;&EN:R<@("`@("`]/B!F86QS
M92P*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@=')U92P*("`@("`@("`G
M<&-O;FYE8W0G("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W!R97!A<F4G("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@("`@("`@("`]/B!T<G5E
M+`H@("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@*3L*"B`@
M("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@
M=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@,3`P-"`]
M/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@("`@("`@(#$P,#4@/3X@1$)?
M15)23U)?0T%.3D]47T-214%412P*("`@("`@("`Q,#`V(#T^($1"7T524D]2
M7T-!3DY/5%]#4D5!5$4L"B`@("`@("`@,3`P-R`]/B!$0E]%4E)/4E]!3%)%
M04197T5825-44RP*("`@("`@("`Q,#`X(#T^($1"7T524D]27T-!3DY/5%]$
M4D]0+`H@("`@("`@(#$P,C(@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L
M"B`@("`@("`@,3`T-"`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@
M("`@("`@(#$P-#8@/3X@1$)?15)23U)?3D]$0E-%3$5#5$5$+`H@("`@("`@
M(#$P-#@@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`Q,#0Y(#T^
M($1"7T524D]27TY/4U5#2$1"+`H@("`@("`@(#$P-3`@/3X@1$)?15)23U)?
M04Q214%$65]%6$E35%,L"B`@("`@("`@,3`U,2`]/B!$0E]%4E)/4E].3U-5
M0TA404),12P*("`@("`@("`Q,#4T(#T^($1"7T524D]27TY/4U5#2$9)14Q$
M+`H@("`@("`@(#$P-C$@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@,3`V,B`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@
M("`Q,#8T(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`Q,#DQ(#T^($1"
M7T524D]27TY/5%]&3U5.1"P*("`@("`@("`Q,3`P(#T^($1"7T524D]27TY/
M5%],3T-+140L"B`@("`@("`@,3$S-B`]/B!$0E]%4E)/4E]604Q515]#3U5.
M5%]/3E]23U<L"B`@("`@("`@,3$T,B`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/
M3$%424].+`H@("`@("`@(#$Q-#8@/3X@1$)?15)23U)?3D]354-(5$%"3$4L
M"B`@("`@("`@,3(Q-B`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@
M(#$R,3<@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B
M>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C
M;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO
M;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ
M"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE<R!B92!C
M;VUM:71T960@875T;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O;`H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D875T;V-O;6UI
M="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@<75A;G1I='D@;V8@=')A
M;G-A8W1I;VYS(&)E9W5N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"`@5VAI
M;&4@=&AI<R!I<R!P<FEV871E+"!I="!C86XG="!A8W1U86QL>2!B92!D97-I
M9VYA=&5D"B`@("`@*B!P<FEV871E(&EN(%!(4"`U(&)E8V%U<V4@:70@:7,@
M9&ER96-T;'D@86-C97-S960@:6X@=&AE('1E<W0@<W5I=&4N?7T*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)'1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH*("`@
M("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-P96-I9FEE9"!I;B!T:&4@1%-.
M"B`@("`@*@H@("`@("H@270G<R!A(&9I>"!T;R!A;&QO=R!C86QL<R!T;R!D
M:69F97)E;G0@9&%T86)A<V5S(&EN('1H92!S86UE('-C<FEP="X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V1B(#T@)R<["@H@("`@+RHJ"B`@("`@*B!!<G)A
M>2!F;W(@8V]N=F5R=&EN9R!-65-13$E?*E]&3$%'(&-O;G-T86YT<R!T;R!T
M97AT('9A;'5E<PH@("`@("H@0'9A<B`@("!A<G)A>0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S:6YC92`@4')O<&5R='D@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XV+C4*("`@("`J+PH@("`@=F%R("1M>7-Q;&E?9FQA
M9W,@/2!A<G)A>2@*("`@("`@("!-65-13$E?3D]47TY53$Q?1DQ!1R`@("`@
M("`@/3X@)VYO=%]N=6QL)RP*("`@("`@("!-65-13$E?4%))7TM%65]&3$%'
M("`@("`@("`@/3X@)W!R:6UA<GE?:V5Y)RP*("`@("`@("!-65-13$E?54Y)
M455%7TM%65]&3$%'("`@("`@/3X@)W5N:7%U95]K97DG+`H@("`@("`@($U9
M4U%,25]-54Q425!,15]+15E?1DQ!1R`@("`]/B`G;75L=&EP;&5?:V5Y)RP*
M("`@("`@("!-65-13$E?0DQ/0E]&3$%'("`@("`@("`@("`@/3X@)V)L;V(G
M+`H@("`@("`@($U94U%,25]53E-)1TY%1%]&3$%'("`@("`@("`]/B`G=6YS
M:6=N960G+`H@("`@("`@($U94U%,25]:15)/1DE,3%]&3$%'("`@("`@("`]
M/B`G>F5R;V9I;&PG+`H@("`@("`@($U94U%,25]!551/7TE.0U)%345.5%]&
M3$%'("`]/B`G875T;U]I;F-R96UE;G0G+`H@("`@("`@($U94U%,25]424U%
M4U1!35!?1DQ!1R`@("`@("`]/B`G=&EM97-T86UP)RP*("`@("`@("!-65-1
M3$E?4T547T9,04<@("`@("`@("`@("`@/3X@)W-E="<L"B`@("`@("`@+R\@
M35E344Q)7TY535]&3$%'("`@("`@("`@("`@(#T^("=N=6UE<FEC)RP@("\O
M('5N;F5C97-S87)Y"B`@("`@("`@+R\@35E344Q)7U!!4E1?2T597T9,04<@
M("`@("`@(#T^("=M=6QT:7!L95]K97DG+"`@+R\@9'5P;&EC871V:64*("`@
M("`@("!-65-13$E?1U)/55!?1DQ!1R`@("`@("`@("`@/3X@)V=R;W5P7V)Y
M)PH@("`@*3L*"B`@("`O*BH*("`@("`J($%R<F%Y(&9O<B!C;VYV97)T:6YG
M($U94U%,25]465!%7RH@8V]N<W1A;G1S('1O('1E>'0@=F%L=65S"B`@("`@
M*B!`=F%R("`@(&%R<F%Y"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-I;F-E("!0<F]P97)T>2!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N
M-0H@("`@("HO"B`@("!V87(@)&UY<W%L:5]T>7!E<R`](&%R<F%Y*`H@("`@
M("`@($U94U%,25]465!%7T1%0TE-04P@("`@(#T^("=D96-I;6%L)RP*("`@
M("`@("!-65-13$E?5%E015]424Y9("`@("`@("`]/B`G=&EN>6EN="<L"B`@
M("`@("`@35E344Q)7U194$5?4TA/4E0@("`@("`@/3X@)VEN="<L"B`@("`@
M("`@35E344Q)7U194$5?3$].1R`@("`@("`@/3X@)VEN="<L"B`@("`@("`@
M35E344Q)7U194$5?1DQ/050@("`@("`@/3X@)V9L;V%T)RP*("`@("`@("!-
M65-13$E?5%E015]$3U5"3$4@("`@("`]/B`G9&]U8FQE)RP*("`@("`@("`O
M+R!-65-13$E?5%E015].54Q,("`@("`@("`]/B`G1$5&055,5"!.54Q,)RP@
M("\O(&QE="!F;&%G<R!H86YD;&4@:70*("`@("`@("!-65-13$E?5%E015]4
M24U%4U1!35`@("`]/B`G=&EM97-T86UP)RP*("`@("`@("!-65-13$E?5%E0
M15],3TY'3$].1R`@("`]/B`G8FEG:6YT)RP*("`@("`@("!-65-13$E?5%E0
M15])3E0R-"`@("`@("`]/B`G;65D:75M:6YT)RP*("`@("`@("!-65-13$E?
M5%E015]$051%("`@("`@("`]/B`G9&%T92<L"B`@("`@("`@35E344Q)7U19
M4$5?5$E-12`@("`@("`@/3X@)W1I;64G+`H@("`@("`@($U94U%,25]465!%
M7T1!5$5424U%("`@(#T^("=D871E=&EM92<L"B`@("`@("`@35E344Q)7U19
M4$5?645!4B`@("`@("`@/3X@)WEE87(G+`H@("`@("`@($U94U%,25]465!%
M7TY%5T1!5$4@("`@(#T^("=D871E)RP*("`@("`@("!-65-13$E?5%E015]%
M3E5-("`@("`@("`]/B`G96YU;2<L"B`@("`@("`@35E344Q)7U194$5?4T54
M("`@("`@("`@/3X@)W-E="<L"B`@("`@("`@35E344Q)7U194$5?5$E.65]"
M3$]"("`@/3X@)W1I;GEB;&]B)RP*("`@("`@("!-65-13$E?5%E015]-141)
M54U?0DQ/0B`]/B`G;65D:75M8FQO8B<L"B`@("`@("`@35E344Q)7U194$5?
M3$].1U]"3$]"("`@/3X@)VQO;F=B;&]B)RP*("`@("`@("!-65-13$E?5%E0
M15]"3$]"("`@("`@("`]/B`G8FQO8B<L"B`@("`@("`@35E344Q)7U194$5?
M5D%27U-44DE.1R`@/3X@)W9A<F-H87(G+`H@("`@("`@($U94U%,25]465!%
M7U-44DE.1R`@("`@(#T^("=C:&%R)RP*("`@("`@("!-65-13$E?5%E015]'
M14]-151262`@("`]/B`G9V5O;65T<GDG+`H@("`@*3L*"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@
M8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB
M9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N
M8W1I;VX@1$)?;7ES<6QI*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M
M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I
M"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V
M97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@
M*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC
M;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@*B!014%2($1")W,@;7ES
M<6QI(&1R:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($133B!O
M<'1I;VYS.@H@("`@("H@("`K(%=H96X@=&AE("=S<VPG("1O<'1I;VX@<&%S
M<V5D('1O($1".CIC;VYN96-T*"D@:7,@=')U93H*("`@("`J("`@("`K(&ME
M>2`@("`@(%1H92!P871H('1O('1H92!K97D@9FEL92X*("`@("`J("`@("`K
M(&-E<G0@("`@(%1H92!P871H('1O('1H92!C97)T:69I8V%T92!F:6QE+@H@
M("`@("H@("`@("L@8V$@("`@("`@5&AE('!A=&@@=&\@=&AE(&-E<G1I9FEC
M871E(&%U=&AO<FET>2!F:6QE+@H@("`@("H@("`@("L@8V%P871H("`@5&AE
M('!A=&@@=&\@82!D:7)E8W1O<GD@=&AA="!C;VYT86EN<R!T<G5S=&5D(%-3
M3`H@("`@("H@("`@("`@("`@("`@("`@($-!(&-E<G1I9FEC871E<R!I;B!P
M96T@9F]R;6%T+@H@("`@("H@("`@("L@8VEP:&5R("`@5&AE(&QI<W0@;V8@
M86QL;W=A8FQE(&-I<&AE<G,@9F]R(%-33"!E;F-R>7!T:6]N+@H@("`@("H*
M("`@("`J($5X86UP;&4@;V8@:&]W('1O(&-O;FYE8W0@=7-I;F<@4U-,.@H@
M("`@("H@/&-O9&4^"B`@("`@*B!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@
M("`@*B`*("`@("`J("1D<VX@/2!A<G)A>2@*("`@("`J("`@("`G<&AP='EP
M92<@(#T^("=M>7-Q;&DG+`H@("`@("H@("`@("=U<V5R;F%M92<@/3X@)W-O
M;65U<V5R)RP*("`@("`J("`@("`G<&%S<W=O<F0G(#T^("=A<&%S<W=D)RP*
M("`@("`J("`@("`G:&]S='-P96,G(#T^("=L;V-A;&AO<W0G+`H@("`@("H@
M("`@("=D871A8F%S92<@/3X@)W1H961B)RP*("`@("`J("`@("`G:V5Y)R`@
M("`@(#T^("=C;&EE;G0M:V5Y+G!E;2<L"B`@("`@*B`@("`@)V-E<G0G("`@
M("`]/B`G8VQI96YT+6-E<G0N<&5M)RP*("`@("`J("`@("`G8V$G("`@("`@
M(#T^("=C86-E<G0N<&5M)RP*("`@("`J("`@("`G8V%P871H)R`@(#T^("<O
M<&%T:"]T;R]C82]D:7(G+`H@("`@("H@("`@("=C:7!H97(G("`@/3X@)T%%
M4R<L"B`@("`@*B`I.PH@("`@("H@"B`@("`@*B`D;W!T:6]N<R`](&%R<F%Y
M*`H@("`@("H@("`@("=S<VPG(#T^('1R=64L"B`@("`@*B`I.PH@("`@("H@
M"B`@("`@*B`D9&(@/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@
M("`@("H@:68@*%!%05(Z.FES17)R;W(H)&1B*2D@>PH@("`@("H@("`@(&1I
M92@D9&(M/F=E=$UE<W-A9V4H*2D["B`@("`@*B!]"B`@("`@*B`\+V-O9&4^
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@("`@("!T:&4@
M9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@("1P97)S:7-T
M96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G;7ES<6QI)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/F1S;B`]("1D<VX["B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI
M('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT
M87@G73L*("`@("`@("!]"@H@("`@("`@("1I;FD@/2!I;FE?9V5T*"=T<F%C
M:U]E<G)O<G,G*3L*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q
M*3L*("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["@H@("`@("`@(&EF("@D
M=&AI<RT^9V5T3W!T:6]N*"=S<VPG*2`]/3T@=')U92D@>PH@("`@("`@("`@
M("`D:6YI="`](&UY<W%L:5]I;FET*"D["B`@("`@("`@("`@(&UY<W%L:5]S
M<VQ?<V5T*`H@("`@("`@("`@("`@("`@)&EN:70L"B`@("`@("`@("`@("`@
M("!E;7!T>2@D9'-N6R=K97DG72D@("`@/R!N=6QL(#H@)&1S;ELG:V5Y)UTL
M"B`@("`@("`@("`@("`@("!E;7!T>2@D9'-N6R=C97)T)UTI("`@/R!N=6QL
M(#H@)&1S;ELG8V5R="==+`H@("`@("`@("`@("`@("`@96UP='DH)&1S;ELG
M8V$G72D@("`@(#\@;G5L;"`Z("1D<VY;)V-A)UTL"B`@("`@("`@("`@("`@
M("!E;7!T>2@D9'-N6R=C87!A=&@G72D@/R!N=6QL(#H@)&1S;ELG8V%P871H
M)UTL"B`@("`@("`@("`@("`@("!E;7!T>2@D9'-N6R=C:7!H97(G72D@/R!N
M=6QL(#H@)&1S;ELG8VEP:&5R)UT*("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YC;VYN96-T:6]N(#T@0&UY<W%L:5]R96%L7V-O;FYE
M8W0H"B`@("`@("`@("`@("`@("`@("`@)&EN:70L"B`@("`@("`@("`@("`@
M("`@("`@)&1S;ELG:&]S='-P96,G72P*("`@("`@("`@("`@("`@("`@("`D
M9'-N6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@("`@("1D<VY;)W!A
M<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@)&1S;ELG9&%T86)A<V4G
M72P*("`@("`@("`@("`@("`@("`@("`D9'-N6R=P;W)T)UTL"B`@("`@("`@
M("`@("`@("`@("`@)&1S;ELG<V]C:V5T)UTI*0H@("`@("`@("`@("!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]("1I;FET.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/F-O;FYE8W1I;VX@/2!`;7ES<6QI7V-O;FYE8W0H"B`@("`@("`@("`@("`@
M("`D9'-N6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@("`@)&1S;ELG=7-E
M<FYA;64G72P*("`@("`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UTL"B`@
M("`@("`@("`@("`@("`D9'-N6R=D871A8F%S92==+`H@("`@("`@("`@("`@
M("`@)&1S;ELG<&]R="==+`H@("`@("`@("`@("`@("`@)&1S;ELG<V]C:V5T
M)UT*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&EN:5]S970H
M)W1R86-K7V5R<F]R<R<L("1I;FDI.PH*("`@("`@("!I9B`H(21T:&ES+3YC
M;VYN96-T:6]N*2!["B`@("`@("`@("`@(&EF("@H)&5R<B`]($!M>7-Q;&E?
M8V]N;F5C=%]E<G)O<B@I*2`A/2`G)RD@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5R<BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?
M0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1D<VY;)V1A=&%B
M87-E)UTI('L*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("1D<VY;)V1A=&%B
M87-E)UT["B`@("`@("`@?0H*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ
M"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@
M1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN
M96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0&UY<W%L:5]C;&]S92@D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N
M=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S
M(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@
M9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@
M("`@("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S
M9G5L('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@82!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP
M;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)&ES;6%N:7`@/2!$0CHZ
M:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@
M)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D
M<75E<GDI.PH@("`@("`@(&EF("@D=&AI<RT^7V1B*2!["B`@("`@("`@("`@
M(&EF("@A0&UY<W%L:5]S96QE8W1?9&(H)'1H:7,M/F-O;FYE8W1I;VXL("1T
M:&ES+3Y?9&(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY
M<W%L:5)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES+3YA=71O8V]M
M;6ET("8F("1I<VUA;FEP*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=')A
M;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@0&UY<W%L:5]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP@)U-%5"!!
M551/0T]-34E4/3`G*3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!`;7ES
M<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`G0D5'24XG*3L*("`@("`@
M("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<B@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YT<F%N
M<V%C=&EO;E]O<&-O=6YT*RL["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@
M/2!`;7ES<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`D<75E<GDI.PH@
M("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FUY<W%L:5)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@
M("`@("H@36]V92!T:&4@:6YT97)N86P@;7ES<6P@<F5S=6QT('!O:6YT97(@
M=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L="X*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!H87,@;F]T(&)E96X@:6UP;&5M96YT960@>65T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT(&$@=F%L:60@<W%L
M(')E<W5L="!R97-O=7)C90H@("`@("H@0')E='5R;B!F86QS90H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L
M="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@
M("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T
M:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE
M(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N
M"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@
M;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R
M97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L
M87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@
M82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@
M("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@
M87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@
M("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@
M8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@
M=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,
M3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@
M("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@
M)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@(3T]
M(&YU;&PI('L*("`@("`@("`@("`@:68@*"%`;7ES<6QI7V1A=&%?<V5E:R@D
M<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1F971C
M:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@("`@)&%R
M<B`]($!M>7-Q;&E?9F5T8VA?87)R87DH)')E<W5L="P@35E344Q)7T%34T]#
M*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET
M>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F("1A<G(I('L*("`@
M("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R
M<BP@0T%315],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D87)R(#T@0&UY<W%L:5]F971C:%]R;W<H)')E<W5L
M="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@("`@("`@("`@
M("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?4E1224TI
M('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@179E;B!T:&]U9V@@
M=&AI<R!$0DU3(&%L<F5A9'D@=')I;7,@;W5T<'5T+"!W92!D;R!T:&ES(&)E
M8V%U<V4*("`@("`@("`@("`@("H@82!F:65L9"!M:6=H="!H879E(&EN=&5N
M=&EO;F%L('=H:71E<W!A8V4@870@=&AE(&5N9"!T:&%T"B`@("`@("`@("`@
M("`J(&=E=',@<F5M;W9E9"!B>2!$0E]03U)404))3$E465]25%))32!U;F1E
M<B!A;F]T:&5R(&1R:79E<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@
M("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?
M4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!$96QE
M=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y(&]C8W5P
M:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@
M("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E
M(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L
M="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L
M($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E
M95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`;7ES<6QI
M7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L
M>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N
M=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@
M("`@("`@)&-O;',@/2!`;7ES<6QI7VYU;5]F:65L9',H)')E<W5L="D["B`@
M("`@("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUY<W%L:5)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H
M*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@
M82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T
M(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?
M<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA
M<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A
M('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N
M=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O=W,@/2!`;7ES<6QI
M7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@("`@(&EF("@D<F]W<R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R
M;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@("\J*@H@
M("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M;6ET<PH@
M("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T=7)N<R!I
M="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!I
M9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N)W0@<W5P
M<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@("`@>PH@
M("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^
M(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O(&ES<W5E(&$@=V%R
M;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@)&]N;V9F
M(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@("\J*@H@("`@
M("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M
M;6ET*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P
M8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1B*2!["B`@
M("`@("`@("`@("`@("!I9B`H(4!M>7-Q;&E?<V5L96-T7V1B*"1T:&ES+3YC
M;VYN96-T:6]N+"`D=&AI<RT^7V1B*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"
M4T5,14-4140I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1R97-U;'0@/2!`;7ES<6QI7W%U97)Y*"1T:&ES+3YC;VYN
M96-T:6]N+"`G0T]-34E4)RD["B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES
M<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`G4T54($%55$]#3TU-250]
M,2<I.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]
M(#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E286ES945R<F]R*"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@
M("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O
M;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N
M7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1B*2![
M"B`@("`@("`@("`@("`@("!I9B`H(4!M>7-Q;&E?<V5L96-T7V1B*"1T:&ES
M+3YC;VYN96-T:6]N+"`D=&AI<RT^7V1B*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<BA$0E]%4E)/4E].
M3T1"4T5,14-4140I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6QI7W%U97)Y*"1T:&ES+3YC
M;VYN96-T:6]N+"`G4D],3$)!0TLG*3L*("`@("`@("`@("`@)')E<W5L="`]
M($!M>7-Q;&E?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL("=3150@05543T-/
M34U)5#TQ)RD["B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O
M=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@
M("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F
M9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@
M("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N
M:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@
M("`@("`@(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*
M("`@("`@("`@("`@<F5T=7)N($!M>7-Q;&E?869F96-T961?<F]W<R@D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(#`["B`@("`@("`@?0H@("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X
M="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E
M<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@
M=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*
M("`@("`J("`@("`@1$)?;7ES<6QI.CIC<F5A=&5397%U96YC92@I+"!$0E]M
M>7-Q;&DZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE
M>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@
M("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M
M92D["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@
M("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@G
M55!$051%("<@+B`D<V5Q;F%M90H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!3150@:60@/2!,05-47TE.4T525%])1"AI9"`K(#$I
M)RD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@
M("`@("`@("`@(&EF("@D<F5S=6QT(#T]/2!$0E]/2RD@>PH@("`@("`@("`@
M("`@("`@+R\@0T]-34].($-!4T4*("`@("`@("`@("`@("`@("1I9"`]($!M
M>7-Q;&E?:6YS97)T7VED*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@
M("`@("`@(&EF("@D:60@(3T@,"D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D:60["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M+R\@14U05%D@4T51(%1!0DQ%"B`@("`@("`@("`@("`@("`O+R!397%U96YC
M92!T86)L92!M=7-T(&)E(&5M<'1Y(&9O<B!S;VUE(')E87-O;BP*("`@("`@
M("`@("`@("`@("\O('-O(&9I;&P@:70@86YD(')E='5R;B`Q"B`@("`@("`@
M("`@("`@("`O+R!/8G1A:6X@82!U<V5R+6QE=F5L(&QO8VL*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T3VYE*"=314Q%0U0@1T547TQ/
M0TLH)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`B)R1[<V5Q;F%M97U?;&]C:R<L(#$P*2(I.PH@("`@("`@("`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1R97-U;'0@/3T@,"D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I
M<V5%<G)O<BA$0E]%4E)/4E].3U1?3$]#2T5$*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`O+R!A9&0@=&AE(&1E9F%U;'0@=F%L=64*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH)U)%4$Q!
M0T4@24Y43R`G("X@)'-E<6YA;64*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G("AI9"D@5D%,5453("@P*2<I.PH@("`@("`@
M("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O(%)E;&5A
M<V4@=&AE(&QO8VL*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M9V5T3VYE*"=314Q%0U0@4D5,14%315],3T-+*"<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@(B<D>W-E<6YA;65]7VQO8VLG
M*2(I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@+R\@5V4@:VYO=R!W:&%T('1H92!R97-U;'0@=VEL;"!B92P@<V\@;F\@
M;F5E9"!T;R!T<GD@86=A:6X*("`@("`@("`@("`@("`@(')E='5R;B`Q.PH*
M("`@("`@("`@("`@?2!E;'-E:68@*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@)')E<W5L="T^9V5T0V]D
M92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*0H@("`@("`@("`@("!["B`@
M("`@("`@("`@("`@("`O+R!/3D1%34%.1"!404),12!#4D5!5$E/3@H@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D
M<V5Q7VYA;64I.PH*("`@("`@("`@("`@("`@("\O(%-I;F-E(&-R96%T95-E
M<75E;F-E(&EN:71I86QI>F5S('1H92!)1"!T;R!B92`Q+`H@("`@("`@("`@
M("`@("`@+R\@=V4@9&\@;F]T(&YE960@=&\@<F5T<FEE=F4@=&AE($E$(&%G
M86EN("AO<B!W92!W:6QL(&=E="`R*0H@("`@("`@("`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!&:7)S="!)1"!O
M9B!A(&YE=VQY(&-R96%T960@<V5Q=65N8V4@:7,@,0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`Q.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@?2!E;'-E:68@*$1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?
M04Q214%$65]%6$E35%,I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("\O($)!0TM705)$4R!#3TU0050*("`@("`@("`@("`@("`@("\O('-E92!?
M0D-S97%U96YC92@I(&-O;6UE;G0*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7T)#<V5Q=65N8V4H)'-E<6YA;64I.PH@("`@("`@("`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<&5A="`](#$["B`@
M("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T*3L*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!N
M97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL
M($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"
M7VUY<W%L:3HZ;F5X=$E$*"DL($1"7VUY<W%L:3HZ9')O<%-E<75E;F-E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N86UE
M*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E
M3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97,@/2`D=&AI<RT^<75E<GDH
M)T-214%412!404),12`G("X@)'-E<6YA;64*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R`H:60@24Y414=%4B!53E-)1TY%1"!!551/7TE.0U)%
M345.5"!.3U0@3E5,3"PG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N
M("<@4%))34%262!+15DH:60I*2<I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]
M"B`@("`@("`@+R\@:6YS97)T('EI96QD<R!V86QU92`Q+"!N97AT260@8V%L
M;"!W:6QL(&=E;F5R871E($E$(#(*("`@("`@("!R971U<FX@)'1H:7,M/G%U
M97)Y*"))3E-%4E0@24Y43R`D>W-E<6YA;65]("AI9"D@5D%,5453("@P*2(I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q
M=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E
M;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@
M("`@($1"7VUY<W%L.CIN97AT240H*2P@1$)?;7ES<6PZ.F-R96%T95-E<75E
M;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S97%?
M;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=$4D]0
M(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]"0W-E<75E;F-E*"D*
M"B`@("`O*BH*("`@("`J($)A8VMW87)D<R!C;VUP871I8FEL:71Y('=I=&@@
M;VQD('-E<75E;F-E(&5M=6QA=&EO;B!I;7!L96UE;G1A=&EO;@H@("`@("H@
M*&-L96%N('5P('1H92!D=7!E<RD*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97%N86UE("!T:&4@<V5Q=65N8V4@;F%M92!T;R!C;&5A;B!U<`H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=')U92!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7T)#<V5Q=65N
M8V4H)'-E<6YA;64I"B`@("!["B`@("`@("`@+R\@3V)T86EN(&$@=7-E<BUL
M979E;"!L;V-K+BXN('1H:7,@=VEL;"!R96QE87-E(&%N>2!P<F5V:6]U<PH@
M("`@("`@("\O(&%P<&QI8V%T:6]N(&QO8VMS+"!B=70@=6YL:6ME($Q/0TL@
M5$%"3$53+"!I="!D;V5S(&YO="!A8F]R=`H@("`@("`@("\O('1H92!C=7)R
M96YT('1R86YS86-T:6]N(&%N9"!I<R!M=6-H(&QE<W,@9G)E<75E;G1L>2!U
M<V5D+@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T3VYE*")314Q%0U0@
M1T547TQ/0TLH)R1[<V5Q;F%M97U?;&]C:R<L,3`I(BD["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H)')E<W5L="`]/2`P*2![
M"B`@("`@("`@("`@("\O($9A:6QE9"!T;R!G970@=&AE(&QO8VLL(&-A;B=T
M(&1O('1H92!C;VYV97)S:6]N+"!B86EL"B`@("`@("`@("`@("\O('=I=&@@
M82!$0E]%4E)/4E].3U1?3$]#2T5$(&5R<F]R"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?3$]#2T5$
M*3L*("`@("`@("!]"@H@("`@("`@("1H:6=H97-T7VED(#T@)'1H:7,M/F=E
M=$]N92@B4T5,14-4($U!6"AI9"D@1E)/32`D>W-E<6YA;65](BD["B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1H:6=H97-T7VED*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&AI9VAE<W1?:60["B`@("`@("`@?0H*("`@("`@("`O+R!4
M:&ES('-H;W5L9"!K:6QL(&%L;"!R;W=S(&5X8V5P="!T:&4@:&EG:&5S=`H@
M("`@("`@("\O(%=E('-H;W5L9"!P<F]B86)L>2!D;R!S;VUE=&AI;F<@:68@
M)&AI9VAE<W1?:60@:7-N)W0*("`@("`@("`O+R!N=6UE<FEC+"!B=70@22=M
M(&%T(&$@;&]S<R!A<R!H;W<@=&\@:&%N9&QE('1H870N+BX*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"=$14Q%5$4@1E)/32`G("X@)'-E<6YA
M;64*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(B!72$5212!I
M9"`\/B`D:&EG:&5S=%]I9"(I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\O($EF(&%N;W1H97(@=&AR96%D(&AA<R!B965N('=A
M:71I;F<@9F]R('1H:7,@;&]C:RP*("`@("`@("`O+R!I="!W:6QL(&=O('1H
M<G4@=&AE(&%B;W9E('!R;V-E9'5R92P@8G5T('=I;&P@:&%V92!N;PH@("`@
M("`@("\O(')E86P@969F96-T"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YG
M971/;F4H(E-%3$5#5"!214Q%05-%7TQ/0TLH)R1[<V5Q;F%M97U?;&]C:R<I
M(BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T94ED
M96YT:69I97(H*0H*("`@("\J*@H@("`@("H@475O=&5S(&$@<W1R:6YG('-O
M(&ET(&-A;B!B92!S869E;'D@=7-E9"!A<R!A('1A8FQE(&]R(&-O;'5M;B!N
M86UE"B`@("`@*@H@("`@("H@37E344P@8V%N)W0@:&%N9&QE('1H92!B86-K
M=&EC:R!C:&%R86-T97(@*#QK8F0^8#PO:V)D/BD@:6X*("`@("`J('1A8FQE
M(&]R(&-O;'5M;B!N86UE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S='(@(&ED96YT:69I97(@;F%M92!T;R!B92!Q=6]T960*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@<75O=&5D(&ED96YT:69I97(@<W1R:6YG
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E261E;G1I9FEE
M<B@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E261E;G1I9FEE
M<B@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B`G8"<@+B`D<W1R("X@)V`G
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5S8V%P95-I;7!L92@I
M"@H@("`@+RHJ"B`@("`@*B!%<V-A<&5S(&$@<W1R:6YG(&%C8V]R9&EN9R!T
M;R!T:&4@8W5R<F5N="!$0DU3)W,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W1R("!T:&4@<W1R:6YG('1O(&)E(&5S8V%P960*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5S8V%P960@<W1R
M:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H
M*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&53:6UP;&4H)'-T
M<BD*("`@('L*("`@("`@("!R971U<FX@0&UY<W%L:5]R96%L7V5S8V%P95]S
M=')I;F<H)'1H:7,M/F-O;FYE8W1I;VXL("1S='(I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI;6ET475E<GDH*0H*("`@("\J*@H@
M("`@("H@061D<R!,24U)5"!C;&%U<V5S('1O(&$@<75E<GD@<W1R:6YG(&%C
M8V]R9&EN9R!T;R!C=7)R96YT($1"35,@<W1A;F1A<F1S"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@<75E<GD@=&\@;6]D:69Y
M"B`@("`@*B!`<&%R86T@:6YT("`@("1F<F]M("`@('1H92!R;W<@=&\@<W1A
M<G0@=&\@9F5T8VAI;F<@*#`@/2!T:&4@9FER<W0@<F]W*0H@("`@("H@0'!A
M<F%M(&EN="`@("`D8V]U;G0@("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E
M=&-H"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I
M;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT
M+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L
M9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ
M("!M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E
M:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@<75E<GD@<W1R:6YG('=I=&@@3$E-250@8VQA=7-E
M<R!A9&1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&UO9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O
M;2P@)&-O=6YT+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'%U97)Y("X@(B!,24U)5"`D8V]U;G0B.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D<75E<GD@+B`B($Q)34E4("1F<F]M+"`D8V]U
M;G0B.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M
M>7-Q;&E286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S(&$@
M1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E<G)O
M<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@268@
M=&AI<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O
M8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O
M<B@I+`H@("`@("H@("`@("!$0E]M>7-Q;&DZ.F5R<F]R3F%T:79E*"DL($1"
M7V-O;6UO;CHZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;7ES
M<6QI4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?15)23U)3
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#(R
M72`]($1"7T524D]27T-/3E-44D%)3E0["B`@("`@("`@("`@("`@("`D=&AI
M<RT^97)R;W)C;V1E7VUA<%LQ,#0X72`]($1"7T524D]27T-/3E-44D%)3E1?
M3D]47TY53$P["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA
M<%LQ,#8R72`]($1"7T524D]27T-/3E-44D%)3E0["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O+R!$;VEN9R!T:&ES(&EN(&-A<V4@
M;6]D92!C:&%N9V5S(&1U<FEN9R!R=6YT:6UE+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/F5R<F]R8V]D95]M87!;,3`R,ET@/2!$0E]%4E)/4E]!3%)%0419
M7T5825-44SL*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P
M6S$P-#A=(#T@1$)?15)23U)?0T].4U1204E.5#L*("`@("`@("`@("`@("`@
M("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P-C)=(#T@1$)?15)23U)?04Q214%$
M65]%6$E35%,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5R<FYO(#T@
M)'1H:7,M/F5R<F]R0V]D92AM>7-Q;&E?97)R;F\H)'1H:7,M/F-O;FYE8W1I
M;VXI*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1E<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@0&UY<W%L:5]E<G)N;R@D=&AI<RT^8V]N;F5C
M=&EO;BD@+B`G("HJ("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!`;7ES<6QI7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*2D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J
M*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R(&-O9&4@<')O
M9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@=&AE($1"35,G(&5R<F]R(&-O9&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(')E='5R;B!`;7ES<6QI
M7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT('-E=`H@
M("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$
M0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG
M('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E
M<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P<F5C871E
M9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A('9A
M;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@
M<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G-E=$]P=&EO;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF
M;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@
M("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@
M("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@
M("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@0&UY<W%L:5]Q=65R
M>2@D=&AI<RT^8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B4T5,14-4("H@1E)/32`D<F5S=6QT($Q)34E4(#`B*3L*("`@
M("`@("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF
M("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@
M("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C
M="X*("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E
M(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@
M/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@
M9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@
M("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@
M:61E;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@
M("`@("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL
M>2X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0[
M"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES7V$H)&ED+"`G;7ES<6QI7W)E<W5L="<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<BA$0E]%
M4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E4
M65],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T
M;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F
M=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!`
M;7ES<6QI7VYU;5]F:65L9',H)&ED*3L*("`@("`@("`D<F5S("`@/2!A<G)A
M>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@("`@("`@)')E<ULG
M;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@('T*"B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1T
M;7`@/2!`;7ES<6QI7V9E=&-H7V9I96QD*"1I9"D["@H@("`@("`@("`@("`D
M9FQA9W,@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUY<W%L
M:5]F;&%G<R!A<R`D8V]N<W0@/3X@)&UE86YS*2!["B`@("`@("`@("`@("`@
M("!I9B`H)'1M<"T^9FQA9W,@)B`D8V]N<W0I('L*("`@("`@("`@("`@("`@
M("`@("`D9FQA9W,@+CT@)&UE86YS("X@)R`G.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&UP+3YD968I('L*
M("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G9&5F875L=%\G("X@<F%W=7)L
M96YC;V1E*"1T;7`M/F1E9BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&9L86=S(#T@=')I;2@D9FQA9W,I.PH*("`@("`@("`@("`@)')E<ULD:5T@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&-A<V5?9G5N
M8R@D=&UP+3YT86)L92DL"B`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1C
M87-E7V9U;F,H)'1M<"T^;F%M92DL"B`@("`@("`@("`@("`@("`G='EP92<@
M(#T^(&ES<V5T*"1T:&ES+3YM>7-Q;&E?='EP97-;)'1M<"T^='EP95TI"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#\@)'1H:7,M/FUY
M<W%L:5]T>7!E<ULD=&UP+3YT>7!E70H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("=U;FMN;W=N)RP*("`@("`@("`@("`@("`@("=L
M96XG("`@/3X@)'1M<"T^;6%X7VQE;F=T:"P*("`@("`@("`@("`@("`@("=F
M;&%G<R<@/3X@)&9L86=S+`H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@
M:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@
M("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)
M3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R
M=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E
M92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L
M90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`;7ES
M<6QI7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P96-I
M86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R>2!S
M=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O8FIE
M8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE(&MI
M;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9R!O<B!N
M=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@("`@
M("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R97%U97-T960*("`@("`J
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I
M86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E*2![
M"B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)U-(3U<@5$%"3$53)SL*("`@("`@("`@("`@8V%S92`G=7-E<G,G
M.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@1$E35$E.0U0@57-E
M<B!&4D]-(&UY<W%L+G5S97(G.PH@("`@("`@("`@("!C87-E("=D871A8F%S
M97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=32$]7($1!5$%"05-%4R<[
M"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,
M;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F
M9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]O8VDX+G!H
M<```````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P
M-C4V-@`Q,#4Q-30S,3`U-P`P,3<R,3<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N
M9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO
M"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!O8VDX(&5X
M=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!/<F%C;&4@9&%T86)A
M<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T
M96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R
M("`@("!*86UE<R!,+B!0:6YE(#QJ;'!`=F%L:6YU>"YC;VT^"B`J($!A=71H
M;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!O8VDX+G!H
M<"QV(#$N,3`S(#(P,#4O,#0O,3$@,34Z,3`Z,C(@9&%N:65L8R!%>'`@)`H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*
M("HO"@HO*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@
M8V%N(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M
M;6]N+G!H<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O
M(&EN=&5R86-T('=I=&@@4$A0)W,@;V-I."!E>'1E;G-I;VX*("H@9F]R(&EN
M=&5R86-T:6YG('=I=&@@3W)A8VQE(&1A=&%B87-E<PH@*@H@*B!$969I;FET
M96QY('=O<FMS('=I=&@@=F5R<VEO;G,@."!A;F0@.2!O9B!/<F%C;&4N"B`J
M"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@
M:6X@1$)?8V]M;6]N+@H@*@H@*B!"92!A=V%R92XN+B`@3T-)17)R;W(H*2!O
M;FQY(&%P<&5A<G,@=&\@<F5T=7)N(&%N>71H:6YG('=H96X@9VEV96X@80H@
M*B!S=&%T96UE;G0L('-O(&9U;F-T:6]N<R!R971U<FX@=&AE(&=E;F5R:6,@
M1$)?15)23U(@:6YS=&5A9"!O9B!M;W)E"B`J('5S969U;"!E<G)O<G,@=&AA
M="!H879E('1O(&1O('=I=&@@9F5E9&)A8VL@9G)O;2!T:&4@9&%T86)A<V4N
M"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1"
M"B`J($!A=71H;W(@("`@($IA;65S($PN(%!I;F4@/&IL<$!V86QI;G5X+F-O
M;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U
M<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+T1""B`J+PIC;&%S<R!$0E]O8VDX(&5X=&5N9',@1$)?8V]M;6]N
M"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@
M1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)V]C
M:3@G.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I
M86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@
M)V]C:3@G.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE<R!O9B!T
M:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@5&AE("=N97=?
M;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@=&AA="!F
M:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R="!F;W(@=&AI
M<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O<G1E9"X*
M("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G(&5L96UE;G0Z
M"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E=&-H(')O
M=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@/2!A;'1E<B!T:&4@
M<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O=W,*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R97,@
M/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@)V%L=&5R)RP*
M("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@)S4N,"XP)RP*("`@("`@("`G
M;G5M<F]W<R<@("`@("`@/3X@)W-U8G%U97)Y)RP*("`@("`@("`G<&-O;FYE
M8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E<&%R92<@("`@("`@/3X@
M=')U92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@)W1R86YS86-T:6]N<R<@(#T^('1R=64L"B`@("`I.PH*("`@("\J*@H@
M("`@("H@02!M87!P:6YG(&]F(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$0B!E
M<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@("`@("`Q("`@(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`@("`@.3`P("`]/B!$0E]%4E)/4E]364Y4
M05@L"B`@("`@("`@.3`T("`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@
M("`@("`Y,3,@(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*("`@
M("`@("`Y,C$@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`Y,C,@(#T^
M($1"7T524D]27U-93E1!6"P*("`@("`@("`Y-#(@(#T^($1"7T524D]27TY/
M4U5#2%1!0DQ%+`H@("`@("`@(#DU-2`@/3X@1$)?15)23U)?04Q214%$65]%
M6$E35%,L"B`@("`@("`@,30P,"`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/
M5%].54Q,+`H@("`@("`@(#$T,#$@/3X@1$)?15)23U)?24Y604Q)1"P*("`@
M("`@("`Q-#`W(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@
M("`@("`@,30Q."`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@,30W
M-B`]/B!$0E]%4E)/4E]$259:15)/+`H@("`@("`@(#$W,C(@/3X@1$)?15)2
M3U)?24Y604Q)1%].54U"15(L"B`@("`@("`@,C(X.2`]/B!$0E]%4E)/4E].
M3U-50TA404),12P*("`@("`@("`R,CDQ(#T^($1"7T524D]27T-/3E-44D%)
M3E0L"B`@("`@("`@,C(Y,B`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@
M("`@(#(T-#D@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E871E
M9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R
M("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O<FUA
M=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@("`@
M+RHJ"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE<R!B
M92!C;VUM:71T960@875T;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O;`H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D875T;V-O
M;6UI="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!3=&]R97,@=&AE("1D871A
M('!A<W-E9"!T;R!E>&5C=71E*"D@:6X@=&AE(&]C:3@@9')I=F5R"B`@("`@
M*@H@("`@("H@1V5T<R!R97-E="!T;R!A<G)A>2@I('=H96X@<VEM<&QE475E
M<GDH*2!I<R!R=6XN"B`@("`@*@H@("`@("H@3F5E9&5D(&EN(&-A<V4@=7-E
M<B!W86YT<R!T;R!C86QL(&YU;5)O=W,H*2!A9G1E<B!P<F5P87)E+V5X96-U
M=&4*("`@("`J('=A<R!U<V5D+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D871A
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!R97-U;'0@;W(@<W1A
M=&5M96YT(&AA;F1L92!F<F]M('1H92!M;W-T(')E8V5N=&QY(&5X96-U=&5D
M('%U97)Y"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M;&%S=%]S=&UT.PH*("`@("\J*@H@("`@("H@27,@=&AE(&=I=F5N('!R97!A
M<F5D('-T871E;65N="!A(&1A=&$@;6%N:7!U;&%T:6]N('%U97)Y/PH@("`@
M("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D;6%N:7!?<75E<GD@/2!A<G)A>2@I.PH*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C
M;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D
M/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!$0E]O8VDX*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N
M*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@
M("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V97(L
M(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!$
M;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC;VYN
M96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@*B!)9B!02%`@:7,@870@=F5R
M<VEO;B`U+C`N,"!O<B!G<F5A=&5R.@H@("`@("H@("`K($=E;F5R86QL>2P@
M;V-I7V-O;FYE8W0H*2!O<B!O8VE?<&-O;FYE8W0H*2!A<F4@=7-E9"X*("`@
M("`J("`@*R!"=70@:68@=&AE(&YE=U]L:6YK($133B!O<'1I;VX@:7,@<V5T
M('1O('1R=64L(&]C:5]N97=?8V]N;F5C="@I"B`@("`@*B`@("`@:7,@=7-E
M9"X*("`@("`J"B`@("`@*B!7:&5N('5S:6YG(%!(4"!V97)S:6]N(#0N>"P@
M3T-)3&]G;VXH*2!O<B!/0TE03&]G;VXH*2!A<F4@=7-E9"X*("`@("`J"B`@
M("`@*B!014%2($1")W,@;V-I."!D<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO
M=VEN9R!E>'1R82!$4TX@;W!T:6]N<SH*("`@("`J("`@*R!C:&%R<V5T("`@
M("`@(%1H92!C:&%R86-T97(@<V5T('1O(&)E('5S960@;VX@=&AE(&-O;FYE
M8W1I;VXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@3VYL>2!U<V5D(&EF
M(%!(4"!I<R!A="!V97)S:6]N(#4N,"XP(&]R(&=R96%T97(*("`@("`J("`@
M("`@("`@("`@("`@("`@("!A;F0@=&AE($]R86-L92!S97)V97(@:7,@870@
M.2XR(&]R(&=R96%T97(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@079A
M:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@("`@*B`@("L@;F5W7VQI
M;FL@("`@("!)9B!S970@=&\@=')U92P@8V%U<V5S('-U8G-E<75E;G0@8V%L
M;',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("!C;VYN96-T*"D@=&\@
M<F5T=7)N(&$@;F5W(&-O;FYE8W1I;VX@;&EN:PH@("`@("H@("`@("`@("`@
M("`@("`@("`@(&EN<W1E860@;V8@=&AE(&5X:7-T:6YG(&]N92X@(%=!4DY)
M3D<Z('1H:7,@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("!N;W0@<&]R
M=&%B;&4@=&\@;W1H97(@1$)-4R=S+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@($%V86EL86)L92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E
M(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD
M('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H
M)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M(5!%05(Z.FQO861%>'1E;G-I;VXH)V]C:3@G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/
M5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S
M;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@
M("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G;V-I7V-O;FYE8W0G
M*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&1S;ELG;F5W7VQI;FLG72D*
M("`@("`@("`@("`@("`@("8F("@D9'-N6R=N97=?;&EN:R==(#T]("=T<G5E
M)R!\?"`D9'-N6R=N97=?;&EN:R==(#T]/2!T<G5E*2D*("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`G;V-I7VYE
M=U]C;VYN96-T)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G;V-I7W!C
M;VYN96-T)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("=O8VE?8V]N;F5C="<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M($)A8VMW87)D<R!C;VUP871I8FEL:71Y('=I=&@@1$(@/"`Q+C<N,`H@("`@
M("`@("`@("!I9B`H96UP='DH)&1S;ELG9&%T86)A<V4G72D@)B8@(65M<'1Y
M*"1D<VY;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("`@("`D9&(@/2`D
M9'-N6R=H;W-T<W!E8R==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&1B(#T@)&1S;ELG9&%T86)A<V4G73L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&-H87(@/2!E;7!T>2@D9'-N6R=C:&%R<V5T)UTI
M(#\@;G5L;"`Z("1D<VY;)V-H87)S970G73L*("`@("`@("`@("`@)'1H:7,M
M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;ELG=7-E<FYA
M;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1S;ELG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1B+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8VAA<BD["B`@("`@("`@("`@("1E<G)O<B`]($]#245R<F]R*"D["B`@
M("`@("`@("`@(&EF("@A96UP='DH)&5R<F]R*2`F)B`D97)R;W);)V-O9&4G
M72`]/2`Q,C4T,2D@>PH@("`@("`@("`@("`@("`@+R\@0V]U;&1N)W0@9FEN
M9"!43E,@;&ES=&5N97(N("!4<GD@9&ER96-T(&-O;FYE8W1I;VXN"B`@("`@
M("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC
M=&EO;B@D9'-N6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG<&%S<W=O
M<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VAA<BD["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V]N;F5C
M=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)T]#25!,;V=O;B<@.B`G3T-)
M3&]G;VXG.PH@("`@("`@("`@("!I9B`H)&1S;ELG:&]S='-P96,G72D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?
M9G5N8W1I;VXH)&1S;ELG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VY;)W!A
M<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9'-N6R=H;W-T<W!E8R==*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1D<VY;)W5S97)N86UE)UT@?'P@)&1S;ELG<&%S
M<W=O<F0G72D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@
M/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;ELG=7-E<FYA;64G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D<VY;)W!A<W-W;W)D)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@
M("`@("1E<G)O<B`]($]#245R<F]R*"D["B`@("`@("`@("`@("1E<G)O<B`]
M("AI<U]A<G)A>2@D97)R;W(I*2`_("1E<G)O<ELG;65S<V%G92==(#H@;G5L
M;#L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G)O<BD["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R
M;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)V]C:5]C;&]S92<I*2!["B`@("`@("`@("`@
M("1R970@/2!`;V-I7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<F5T(#T@0$]#24QO9T]F9B@D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YC;VYN
M96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@
M("`@*B!396YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@
M("`J"B`@("`@*B!4;R!D971E<FUI;F4@:&]W(&UA;GD@<F]W<R!O9B!A(')E
M<W5L="!S970@9V5T(&)U9F9E<F5D('5S:6YG"B`@("`@*B!O8VES971P<F5F
M971C:"@I+"!S964@=&AE(")R97-U;'1?8G5F9F5R:6YG(B!O<'1I;VX@:6X@
M<V5T3W!T:6]N<R@I+@H@("`@("H@5&AI<R!O<'1I;VX@=V%S(&%D9&5D(&EN
M(%)E;&5A<V4@,2XW+C`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S<V9U;"!3
M14Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!T:&4@1$)?
M3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<PH@("`@
M("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*
M("`@('L*("`@("`@("`D=&AI<RT^7V1A=&$@/2!A<G)A>2@I.PH@("`@("`@
M("1T:&ES+3YL87-T7W!A<F%M971E<G,@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T
M:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@("1R97-U;'0@/2!`
M3T-)4&%R<V4H)'1H:7,M/F-O;FYE8W1I;VXL("1Q=65R>2D["B`@("`@("`@
M:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I
M.%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YA
M=71O8V]M;6ET*2!["B`@("`@("`@("`@("1S=6-C97-S(#T@0$]#245X96-U
M=&4H)')E<W5L="Q/0TE?0T]-34E47T].7U-50T-%4U,I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1S=6-C97-S(#T@0$]#245X96-U=&4H)')E
M<W5L="Q/0TE?1$5&055,5"D["B`@("`@("`@?0H@("`@("`@(&EF("@A)'-U
M8V-E<W,I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%
M<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/FQA<W1?
M<W1M="`]("1R97-U;'0["B`@("`@("`@:68@*$1".CII<TUA;FEP*"1Q=65R
M>2DI('L*("`@("`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($!O8VES971P<F5F971C:"@D<F5S=6QT+"`D=&AI
M<RT^;W!T:6]N<ULG<F5S=6QT7V)U9F9E<FEN9R==*3L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T
M:&4@:6YT97)N86P@;W)A8VQE(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT
M(&%V86EL86)L92!R97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI
M9"!O8VDX(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT
M(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F<F]M
M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@*@H@
M("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE
M<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ
M9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E
M8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H92!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@("`D87)R
M("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@9&%T82!I
M;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H92!R
M97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P87)A
M;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H
M("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F(&$@<F5S
M=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@("`@(')E86-H960@;W(@
M;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C
M:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E<W5L
M="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("8@1$)?1D540TA-
M3T1%7T%34T]#*2!["B`@("`@("`@("`@("1M;W)E9&%T82`]($!/0TE&971C
M:$EN=&\H)')E<W5L="PD87)R+$]#25]!4U-/0RM/0TE?4D5455).7TY53$Q3
M*T]#25]215154DY?3$]"4RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12`F)@H@("`@("`@("`@("`@("`@)&UO<F5D871A*0H@("`@("`@("`@("![
M"B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E
M*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UO<F5D871A(#T@3T-)1F5T8VA);G1O*"1R
M97-U;'0L)&%R<BQ/0TE?4D5455).7TY53$Q3*T]#25]215154DY?3$]"4RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A)&UO<F5D871A*2!["B`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))
M32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R
M<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R
M=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%
M;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@
M=&AE(&UE;6]R>2!O8V-U<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*
M("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@
M9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E
M860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@
M8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y
M(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@
M5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*
M("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@
M("!R971U<FX@0$]#249R9653=&%T96UE;G0H)')E<W5L="D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&<F5E<R!T:&4@:6YT97)N86P@<F5S;W5R8V5S(&%S
M<V]C:6%T960@=VET:"!A('!R97!A<F5D('%U97)Y"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1S=&UT("`@("`@("`@("!T:&4@<')E<&%R960@
M<W1A=&5M96YT)W,@<F5S;W5R8V4*("`@("`J($!P87)A;2!B;V]L("`@("`D
M9G)E95]R97-O=7)C92`@<VAO=6QD('1H92!02%`@<F5S;W5R8V4@8F4@9G)E
M960@=&]O/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@57-E(&9A;'-E(&EF('EO=2!N965D('1O(&=E="!D871A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F<F]M('1H92!R97-U
M;'0@<V5T(&QA=&5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@
M("`J"B`@("`@*B!`<V5E($1"7V]C:3@Z.G!R97!A<F4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!F<F5E4')E<&%R960H)'-T;70L("1F<F5E7W)E<V]U<F-E
M(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1S=&UT
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M("`@(&EF("@D9G)E95]R97-O=7)C92D@>PH@("`@("`@("`@("!`;V-I9G)E
M97-T871E;65N="@D<W1M="D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^<')E<&%R95]T>7!E<ULH:6YT*21S=&UT72DI('L*("`@("`@
M("`@("`@=6YS970H)'1H:7,M/G!R97!A<F5?='EP97-;*&EN="DD<W1M=%TI
M.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^;6%N:7!?<75E<GE;*&EN="DD
M<W1M=%TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@
M*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@
M("`J"B`@("`@*B!/;FQY('=O<FMS(&EF('1H92!$0E]03U)404))3$E465].
M54U23U=3('!O<G1A8FEL:71Y(&]P=&EO;@H@("`@("H@:7,@='5R;F5D(&]N
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B
M92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M
M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C
M=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@
M(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT
M.CIN=6U2;W=S*"DL($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("\O
M(&5M=6QA=&4@;G5M4F]W<R!F;W(@3W)A8VQE+B`@>75C:RX*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465].54U23U=3("8F"B`@("`@("`@("`@("1R97-U;'0@/3T]("1T:&ES
M+3YL87-T7W-T;70I"B`@("`@("`@>PH@("`@("`@("`@("`D8V]U;G1Q=65R
M>2`]("=314Q%0U0@0T]53E0H*BD@1E)/32`H)RXD=&AI<RT^;&%S=%]Q=65R
M>2XG*2<["B`@("`@("`@("`@("1S879E7W%U97)Y(#T@)'1H:7,M/FQA<W1?
M<75E<GD["B`@("`@("`@("`@("1S879E7W-T;70@/2`D=&AI<RT^;&%S=%]S
M=&UT.PH*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?9&%T82DI('L*
M("`@("`@("`@("`@("`@("1S;70@/2`D=&AI<RT^<')E<&%R92@G4T5,14-4
M($-/54Y4*"HI($923TT@*"<N)'1H:7,M/FQA<W1?<75E<GDN)RDG*3L*("`@
M("`@("`@("`@("`@("1C;W5N="`]("1T:&ES+3YE>&5C=71E*"1S;70L("1T
M:&ES+3Y?9&%T82D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D8V]U;G0@/28@)'1H:7,M/G%U97)Y*"1C;W5N='%U97)Y*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1C;W5N
M="D@?'P*("`@("`@("`@("`@("`@($1".CII<T5R<F]R*"1R;W<@/2`D8V]U
M;G0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*2DI"B`@("`@("`@
M("`@('L*("`@("`@("`@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'-A
M=F5?<75E<GD["B`@("`@("`@("`@("`@("`D=&AI<RT^;&%S=%]S=&UT(#T@
M)'-A=F5?<W1M=#L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1R;W=;,%T["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),
M12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@
M("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A
M(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@
M;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R
M97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R
M960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@
M<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C
M92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@("`D8V]L<R`]($!/0TE.
M=6U#;VQS*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D<F5S=6QT*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[('!R97!A<F4H*0H*("`@("\J*@H@("`@("H@4')E
M<&%R97,@82!Q=65R>2!F;W(@;75L=&EP;&4@97AE8W5T:6]N('=I=&@@97AE
M8W5T92@I+@H@("`@("H*("`@("`J(%=I=&@@;V-I."P@=&AI<R!I<R!E;75L
M871E9"X*("`@("`J"B`@("`@*B!P<F5P87)E*"D@<F5Q=6ER97,@82!G96YE
M<FEC('%U97)Y(&%S('-T<FEN9R!L:6ME(#QC;V1E/@H@("`@("H@("`@24Y3
M15)4($E.5$\@;G5M8F5R<R!604Q515,@*#\L(#\L(#\I"B`@("`@*B`\+V-O
M9&4^+B`@5&AE(#QK8F0^/SPO:V)D/B!C:&%R86-T97)S(&%R92!P;&%C96AO
M;&1E<G,N"B`@("`@*@H@("`@("H@5&AR964@='EP97,@;V8@<&QA8V5H;VQD
M97)S(&-A;B!B92!U<V5D.@H@("`@("H@("`K(#QK8F0^/SPO:V)D/B`@82!Q
M=6]T960@<V-A;&%R('9A;'5E+"!I+F4N('-T<FEN9W,L(&EN=&5G97)S"B`@
M("`@*B`@("L@/&MB9#XA/"]K8F0^("!V86QU92!I<R!I;G-E<G1E9"`G87,@
M:7,G"B`@("`@*B`@("L@/&MB9#XF/"]K8F0^("!R97%U:7)E<R!A(&9I;&4@
M;F%M92X@(%1H92!F:6QE)W,@8V]N=&5N=',@9V5T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@(&EN<V5R=&5D(&EN=&\@=&AE('%U97)Y("AI+F4N('-A
M=FEN9R!B:6YA<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@9&%T82!I
M;B!A(&1B*0H@("`@("H*("`@("`J(%5S92!B86-K<VQA<VAE<R!T;R!E<V-A
M<&4@<&QA8V5H;VQD97(@8VAA<F%C=&5R<R!I9B!Y;W4@9&]N)W0@=V%N=`H@
M("`@("H@=&AE;2!T;R!B92!I;G1E<G!R971E9"!A<R!P;&%C96AO;&1E<G,N
M("!%>&%M<&QE.B`\8V]D93X*("`@("`J("`@(")54$1!5$4@9F]O(%-%5"!C
M;VP]/R!72$5212!C;VP])V]V97(@7"8@=6YD97(G(@H@("`@("H@/"]C;V1E
M/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@<75E
M<GD@=&\@8F4@<')E<&%R960*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!$0B!S=&%T96UE;G0@<F5S;W5R8V4@;VX@<W5C8V5S<RX@1$)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V]C:3@Z.F5X96-U
M=&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!P<F5P87)E*"1Q=65R>2D*("`@
M('L*("`@("`@("`D=&]K96YS("`@/2!P<F5G7W-P;&ET*"<O*"@_/"%<7%PI
M6R8_(5TI+R<L("1Q=65R>2P@+3$L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!04D5'7U-03$E47T1%3$E-7T-!4%154D4I.PH@("`@("`@("1B
M:6YD<R`@("`](&-O=6YT*"1T;VME;G,I("T@,3L*("`@("`@("`D=&]K96X@
M("`@/2`P.PH@("`@("`@("1T>7!E<R`@("`](&%R<F%Y*"D["B`@("`@("`@
M)&YE=W%U97)Y(#T@)R<["@H@("`@("`@(&9O<F5A8V@@*"1T;VME;G,@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H)'9A;"D@>PH@
M("`@("`@("`@("`@("`@8V%S92`G/R<Z"B`@("`@("`@("`@("`@("`@("`@
M)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-7U-#04Q!4CL*("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D=&]K96YS6R1K97E=*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)R8G.@H@("`@
M("`@("`@("`@("`@("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]/
M4$%1544["B`@("`@("`@("`@("`@("`@("`@=6YS970H)'1O:V5N<ULD:V5Y
M72D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E("<A)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N
M*RM=(#T@1$)?4$%204U?34E30SL*("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D=&]K96YS6R1K97E=*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@
M)'1O:V5N<ULD:V5Y72`]('!R96=?<F5P;&%C92@G+UQ<7"A;)C\A72DO)RP@
M(EQ<,2(L("1V86PI.PH@("`@("`@("`@("`@("`@("`@(&EF("@D:V5Y("$]
M("1B:6YD<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5W<75E<GD@
M+CT@)'1O:V5N<ULD:V5Y72`N("<Z8FEN9"<@+B`D=&]K96X["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&YE=W%U97)Y("X]("1T;VME;G-;)&ME>5T["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D;F5W<75E<GD@/2`D=&AI
M<RT^;6]D:69Y475E<GDH)&YE=W%U97)Y*3L*("`@("`@("!I9B`H(21S=&UT
M(#T@0$]#25!A<G-E*"1T:&ES+3YC;VYN96-T:6]N+"`D;F5W<75E<GDI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H*3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/G!R97!A<F5?='EP97-;*&EN="DD
M<W1M=%T@/2`D='EP97,["B`@("`@("`@)'1H:7,M/FUA;FEP7W%U97)Y6RAI
M;G0I)'-T;71=(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("!R971U
M<FX@)'-T;70["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97AE8W5T
M92@I"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A($1"('-T871E;65N="!P
M<F5P87)E9"!W:71H('!R97!A<F4H*2X*("`@("`J"B`@("`@*B!4;R!D971E
M<FUI;F4@:&]W(&UA;GD@<F]W<R!O9B!A(')E<W5L="!S970@9V5T(&)U9F9E
M<F5D('5S:6YG"B`@("`@*B!O8VES971P<F5F971C:"@I+"!S964@=&AE(")R
M97-U;'1?8G5F9F5R:6YG(B!O<'1I;VX@:6X@<V5T3W!T:6]N<R@I+@H@("`@
M("H@5&AI<R!O<'1I;VX@=V%S(&%D9&5D(&EN(%)E;&5A<V4@,2XW+C`N"B`@
M("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("`D<W1M="`@82!$0B!S=&%T
M96UE;G0@<F5S;W5R8V4@<F5T=7)N960@9G)O;2!P<F5P87)E*"D*("`@("`J
M($!P87)A;2!M:7AE9"`@)&1A=&$@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I
M8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@
M:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T
M(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@9F]R(&YO;BUA
M<G)A>2!I=&5M<R!O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M('%U86YT:71Y(&]F(&5L96UE;G1S(&EN('1H92!A<G)A>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!R971U<FYS(&%N(&]I8S@@<F5S=6QT(')E
M<V]U<F-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5`H@("`@("H@("`@("`@("`@
M("`@("`@<75E<FEE<RP@1$)?3TL@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E
M<FEE<RX*("`@("`J("`@("`@("`@("`@("`@($$@1$(@97)R;W(@;V)J96-T
M(&ES(')E='5R;F5D(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]O8VDX.CIP<F5P87)E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@)F5X96-U
M=&4H)'-T;70L("1D871A(#T@87)R87DH*2D*("`@('L*("`@("`@("`D9&%T
M82`]("AA<G)A>2DD9&%T83L*("`@("`@("`D=&AI<RT^;&%S=%]P87)A;65T
M97)S(#T@)&1A=&$["B`@("`@("`@)'1H:7,M/E]D871A(#T@)&1A=&$["@H@
M("`@("`@("1T>7!E<R`])B`D=&AI<RT^<')E<&%R95]T>7!E<ULH:6YT*21S
M=&UT73L*("`@("`@("!I9B`H8V]U;G0H)'1Y<&5S*2`A/2!C;W5N="@D9&%T
M82DI('L*("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E]-25--051#2"D["B`@("`@("`@("`@(')E='5R;B`D=&UP.PH@
M("`@("`@('T*"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1D
M871A(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@D='EP
M97-;)&E=(#T]($1"7U!!4D%-7TU)4T,I('L*("`@("`@("`@("`@("`@("\J
M"B`@("`@("`@("`@("`@("`@*B!/<F%C;&4@9&]E<VXG="!S965M('1O(&AA
M=F4@=&AE(&%B:6QI='D@=&\@<&%S<R!A"B`@("`@("`@("`@("`@("`@*B!P
M87)A;65T97(@86QO;F<@=6YC:&%N9V5D+"!S;R!S=')I<"!O9F8@<75O=&5S
M(&9R;VT@<W1A<G0*("`@("`@("`@("`@("`@("`J(&%N9"!E;F0L('!L=7,@
M='5R;B!T=V\@<VEN9VQE('%U;W1E<R!T;R!O;F4@<VEN9VQE('%U;W1E+`H@
M("`@("`@("`@("`@("`@("H@:6X@;W)D97(@=&\@879O:60@=&AE('%U;W1E
M<R!G971T:6YG(&5S8V%P960@8GD*("`@("`@("`@("`@("`@("`J($]R86-L
M92!A;F0@96YD:6YG('5P(&EN('1H92!D871A8F%S92X*("`@("`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!P<F5G7W)E
M<&QA8V4H(B]>)R@N*BDG)"\B+"`B7%PQ(BP@)&1A=&%;)&ME>5TI.PH@("`@
M("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!S=')?<F5P;&%C92@B)R<B+"`B
M)R(L("1D871A6R1K97E=*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E
M<ULD:5T@/3T@1$)?4$%204U?3U!!455%*2!["B`@("`@("`@("`@("`@("`D
M9G`@/2!`9F]P96XH)&1A=&%;)&ME>5TL("=R8B<I.PH@("`@("`@("`@("`@
M("`@:68@*"$D9G`I('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#TF("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27T%#0T534U]624],051)3TXI.PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!F<F5A9"@D9G`L
M(&9I;&5S:7IE*"1D871A6R1K97E=*2D["B`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(4!/0TE"
M:6YD0GE.86UE*"1S=&UT+"`G.F)I;F0G("X@)&DL("1D871A6R1K97E=+"`M
M,2DI('L*("`@("`@("`@("`@("`@("1T;7`@/2`D=&AI<RT^;V-I.%)A:7-E
M17)R;W(H)'-T;70I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3YA=71O8V]M;6ET*2!["B`@("`@("`@("`@("1S=6-C
M97-S(#T@0$]#245X96-U=&4H)'-T;70L($]#25]#3TU-251?3TY?4U5#0T53
M4RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-U8V-E<W,@/2!`
M3T-)17AE8W5T92@D<W1M="P@3T-)7T1%1D%53%0I.PH@("`@("`@('T*("`@
M("`@("!I9B`H(21S=6-C97-S*2!["B`@("`@("`@("`@("1T;7`@/2`D=&AI
M<RT^;V-I.%)A:7-E17)R;W(H)'-T;70I.PH@("`@("`@("`@("!R971U<FX@
M)'1M<#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/FQA<W1?<W1M="`]("1S
M=&UT.PH@("`@("`@(&EF("@D=&AI<RT^;6%N:7!?<75E<GE;*&EN="DD<W1M
M=%TI('L*("`@("`@("`@("`@)'1M<"`]($1"7T]+.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($!O8VES971P<F5F971C:"@D<W1M="P@)'1H:7,M
M/F]P=&EO;G-;)W)E<W5L=%]B=69F97)I;F<G72D["B`@("`@("`@("`@("1T
M;7`@/28@;F5W($1"7W)E<W5L="@D=&AI<RP@)'-T;70I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@
M9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL(&9A;'-E('1U<FYS
M(&ET(&]F9@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S
M=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E<@H@("`@
M("H@("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@875T;RUC;VUM:71T
M:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O
M;6UI="@D;VYO9F8@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^875T
M;V-O;6UI="`]("AB;V]L*21O;F]F9CL["B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@("`@
M+RHJ"B`@("`@*B!#;VUM:71S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@("1R97-U;'0@/2!`3T-)0V]M
M;6ET*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!I9B`H(21R97-U;'0I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@
M4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A
M8VLH*0H@("`@>PH@("`@("`@("1R97-U;'0@/2!`3T-)4F]L;&)A8VLH)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@("H@1&5T
M97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@82!D871A
M(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J(#`@:7,@<F5T=7)N
M960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L871E(&1A=&$N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YL87-T7W-T;70@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;V-I.%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@)')E
M<W5L="`]($!/0TE2;W=#;W5N="@D=&AI<RT^;&%S=%]S=&UT*3L*("`@("`@
M("!I9B`H)')E<W5L="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D=&AI<RT^;&%S=%]S=&UT*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@;6]D:69Y475E<GDH*0H*("`@("\J*@H@("`@("H@
M0VAA;F=E<R!A('%U97)Y('-T<FEN9R!F;W(@=F%R:6]U<R!$0DU3('-P96-I
M9FEC(')E87-O;G,*("`@("`J"B`@("`@*B`B4T5,14-4(#(K,B(@;75S="!B
M92`B4T5,14-4(#(K,B!&4D]-(&1U86PB(&EN($]R86-L92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@=&AE('%U97)Y('-T<FEN9R!T
M;R!M;V1I9GD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&UO
M9&EF:65D('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>5%U97)Y*"1Q=65R
M>2D*("`@('L*("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<<RI314Q%0U0O
M:2<L("1Q=65R>2D@)B8*("`@("`@("`@("`@(7!R96=?;6%T8V@H)R]<<T92
M3TU<<R]I)RP@)'%U97)Y*2D@>PH@("`@("`@("`@("`D<75E<GD@+CT@)R!&
M4D]-(&1U86PG.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'%U97)Y.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI;6ET475E<GDH
M*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C;&%U<V5S('1O(&$@<75E
M<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT($1"35,@<W1A;F1A<F1S
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@<75E
M<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT("`@("1F<F]M("`@('1H
M92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@/2!T:&4@9FER<W0@<F]W
M*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@("!T:&4@;G5M8F5R<R!O
M9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@
M(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T
M:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y
M(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA
M<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R
M<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75E<GD@<W1R:6YG('=I=&@@
M3$E-250@8VQA=7-E<R!A9&1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>4QI;6ET475E<GDH
M)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`O+R!,970@3W)A8VQE(')E='5R;B!T:&4@;F%M92!O9B!T
M:&4@8V]L=6UN<R!I;G-T96%D(&]F"B`@("`@("`@+R\@8V]D:6YG(&$@(FAO
M;64B(%-13"!P87)S97(*"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I*2![
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<')E<&%R92@B4T5,14-4
M("H@1E)/32`H)'%U97)Y*2`B"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("=72$5212!.54Q,(#T@3E5,3"<I.PH@("`@("`@("`@
M("`D=&UP(#TF("1T:&ES+3YE>&5C=71E*"1R97-U;'0L("1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Q7V9I96QD<R`](")314Q%
M0U0@*B!&4D]-("@D<75E<GDI(%=(15)%($Y53$P@/2!.54Q,(CL*"B`@("`@
M("`@("`@(&EF("@A)')E<W5L="`]($!/0TE087)S92@D=&AI<RT^8V]N;F5C
M=&EO;BP@)'%?9FEE;&1S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQA
M<W1?<75E<GD@/2`D<5]F:65L9',["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F]C:3A286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%`3T-)17AE8W5T92@D<F5S=6QT+"!/0TE?1$5&055,5"DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%?9FEE
M;&1S.PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%
M<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&YC;VQS(#T@3T-)3G5M0V]L<R@D<F5S=6QT*3L*("`@("`@("`D8V]L
M<R`@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H("1I(#T@,3L@)&D@/#T@)&YC
M;VQS.R`D:2LK("D@>PH@("`@("`@("`@("`D8V]L<UM=(#T@)R(G("X@3T-)
M0V]L=6UN3F%M92@D<F5S=6QT+"`D:2D@+B`G(B<["B`@("`@("`@?0H@("`@
M("`@("1F:65L9',@/2!I;7!L;V1E*"<L("<L("1C;VQS*3L*("`@("`@("`O
M+R!86%@@5&5S="!T:&%T("AT:7`@8GD@2F]H;B!,:6TI"B`@("`@("`@+R]I
M9B`H<')E9U]M871C:"@G+UY<<RI314Q%0U1<<RLO:7,G+"`D<75E<GDL("1M
M871C:"DI('L*("`@("`@("`O+R`@("`O+R!);G1R;V1U8V4@=&AE($9)4E-4
M7U)/5U,@3W)A8VQE('%U97)Y(&]P=&EM:7IE<@H@("`@("`@("\O("`@("1Q
M=65R>2`]('-U8G-T<B@D<75E<GDL('-T<FQE;B@D;6%T8VA;,%TI+"!S=')L
M96XH)'%U97)Y*2D["B`@("`@("`@+R\@("`@)'%U97)Y(#T@(E-%3$5#5"`O
M*B`K1DE24U1?4D]74R`J+R`B("X@)'%U97)Y.PH@("`@("`@("\O?0H*("`@
M("`@("`O+R!#;VYS=')U8W0@=&AE('%U97)Y"B`@("`@("`@+R\@;6]R92!A
M=#H@:'1T<#HO+VUA<F,N=&AE86EM<V=R;W5P+F-O;2\_;#UP:'`M9&(F;3TY
M.3@S,3DU.#$P,3(Q,B9W/3(*("`@("`@("`O+R!097)H87!S('1H:7,@8V]U
M;&0@8F4@;W!T:6UI>F5D('=I=&@@=&AE('5S92!O9B!5;FEO;G,*("`@("`@
M("`D<75E<GD@/2`B4T5,14-4("1F:65L9',@1E)/32(N"B`@("`@("`@("`@
M("`@("`@(B`@*%-%3$5#5"!R;W=N=6T@87,@;&EN96YU;2P@)&9I96QD<R!&
M4D]-(BX*("`@("`@("`@("`@("`@("`B("`@("`@*"1Q=65R>2DB+@H@("`@
M("`@("`@("`@("`@("<@(%=(15)%(')O=VYU;2`\/2`G+B`H)&9R;VT@*R`D
M8V]U;G0I("X*("`@("`@("`@("`@("`@("`G*2!72$5212!L:6YE;G5M(#X]
M("<@+B`K*R1F<F]M.PH@("`@("`@(')E='5R;B`D<75E<GD["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H
M92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W
M:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E
M<R!N;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE
M>'0@:60@;G5M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J("`@("`@("`@
M("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T
M4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V]C:3@Z.F-R96%T95-E
M<75E;F-E*"DL($1"7V]C:3@Z.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I
M"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.
M86UE*"1S97%?;F%M92D["B`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@
M9&\@>PH@("`@("`@("`@("`D=&AI<RT^97AP96-T17)R;W(H1$)?15)23U)?
M3D]354-(5$%"3$4I.PH@("`@("`@("`@("`D<F5S=6QT(#TF("1T:&ES+3YQ
M=65R>2@B4T5,14-4("1[<V5Q;F%M97TN;F5X='9A;"!&4D]-(&1U86PB*3L*
M("`@("`@("`@("`@)'1H:7,M/G!O<$5X<&5C="@I.PH@("`@("`@("`@("!I
M9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@
M("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]3
M54-(5$%"3$4I('L*("`@("`@("`@("`@("`@("1R97!E870@/2`Q.PH@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D
M<V5Q7VYA;64I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R
M97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](#`["B`@
M("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T*3L*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@('T*("`@
M("`@("`D87)R(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]2
M1$52140I.PH@("`@("`@(')E='5R;B`D87)R6S!=.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!N97<@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL($1"7V-O
M;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V]C:3@Z
M.FYE>'1)1"@I+"!$0E]O8VDX.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G0U)%051%(%-%455%3D-%("<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F=E=%-E<75E
M;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E
M;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]O8VDX.CIN97AT240H*2P@1$)?
M;V-I.#HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!D
M<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<75E<GDH)T123U`@4T51545.0T4@)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M
M92DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&]C:3A286ES945R
M<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J
M96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E<G)O<B!I<R!B96EN9R!M
M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@268@=&AI<R!I<VXG="!P
M87-S960*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE(&5R<F]R(&EN
M9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE8W0*("`@("`J
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@
M("`@("!$0E]O8VDX.CIE<G)O<DYA=&EV92@I+"!$0E]O8VDX.CIE<G)O<D-O
M9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!O8VDX4F%I<V5%<G)O<B@D97)R
M;F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI
M('L*("`@("`@("`@("`@)&5R<F]R(#T@0$]#245R<F]R*"1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1T:&ES+3YE<G)O<D-O9&4H)&5R<F]R6R=C;V1E)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@
M)&5R<F]R6R=M97-S86=E)UTI.PH@("`@("`@('T@96QS96EF("AI<U]R97-O
M=7)C92@D97)R;F\I*2!["B`@("`@("`@("`@("1E<G)O<B`]($!/0TE%<G)O
M<B@D97)R;F\I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)'1H:7,M/F5R<F]R0V]D92@D97)R;W);)V-O9&4G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL
M+"`D97)R;W);)VUE<W-A9V4G72D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^97)R;W)#;V1E*"1E<G)N;RDI
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C
M;V1E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!$0DU3)R!E<G)O<B!C;V1E+B`@1D%,4T4@:68@
M=&AE(&-O9&4@8V]U;&0@;F]T(&)E"B`@("`@*B`@("`@("`@("`@("`@(&1E
M=&5R;6EN960*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@
M("`@>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^;&%S=%]S=&UT
M*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!`3T-)17)R;W(H)'1H:7,M/FQA
M<W1?<W1M="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5R<F]R
M(#T@0$]#245R<F]R*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1E<G)O<BDI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<ELG8V]D92==.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O
M*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@
M82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!.3U1%.B!O
M;FQY('-U<'!O<G1S("=T86)L92<@86YD("=F;&%G<R<@:68@/'9A<CXD<F5S
M=6QT/"]V87(^"B`@("`@*B!I<R!A('1A8FQE(&YA;64N"B`@("`@*@H@("`@
M("H@3D]413H@9FQA9W,@=V]N)W0@8V]N=&%I;B!I;F1E>"!I;F9O<FUA=&EO
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L
M="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I
M;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A
M('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E<')E
M8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@
M82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T
M:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L
M94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T
M<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E
M7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@("1R97,@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D
M(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT
M(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@
M("`@("`D<F5S=6QT(#T@<W1R=&]U<'!E<B@D<F5S=6QT*3L*("`@("`@("`@
M("`@)'%?9FEE;&1S(#T@)U-%3$5#5"!C;VQU;6Y?;F%M92P@9&%T85]T>7!E
M+"!D871A7VQE;F=T:"P@)PH@("`@("`@("`@("`@("`@("`@("`@("`N("=N
M=6QL86)L92`G"B`@("`@("`@("`@("`@("`@("`@("`@("X@)T923TT@=7-E
M<E]T86)?8V]L=6UN<R`G"B`@("`@("`@("`@("`@("`@("`@("`@("X@(E=(
M15)%('1A8FQE7VYA;64])R1R97-U;'0G($]21$52($)9(&-O;'5M;E]I9"([
M"@H@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q7V9I96QD<SL*
M"B`@("`@("`@("`@(&EF("@A)'-T;70@/2!`3T-)4&%R<V4H)'1H:7,M/F-O
M;FYE8W1I;VXL("1Q7V9I96QD<RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!
M5$$I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A0$]#245X96-U
M=&4H)'-T;70L($]#25]$149!54Q4*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D<W1M="D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@=VAI;&4@*$!/
M0TE&971C:"@D<W1M="DI('L*("`@("`@("`@("`@("`@("1R97-;)&E=(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D8V%S95]F
M=6YC*"1R97-U;'0I+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`@/3X@
M)&-A<V5?9G5N8RA`3T-)4F5S=6QT*"1S=&UT+"`Q*2DL"B`@("`@("`@("`@
M("`@("`@("`@)W1Y<&4G("`]/B!`3T-)4F5S=6QT*"1S=&UT+"`R*2P*("`@
M("`@("`@("`@("`@("`@("`G;&5N)R`@(#T^($!/0TE297-U;'0H)'-T;70L
M(#,I+`H@("`@("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@*$!/0TE297-U
M;'0H)'-T;70L(#0I(#T]("=.)RD@/R`G;F]T7VYU;&PG(#H@)R<L"B`@("`@
M("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?
M5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`@("`@)')E<ULG
M;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/
M7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E
M<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=
M(#T@)&D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:2LK
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&UO9&4I('L*("`@
M("`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@($!/0TE&<F5E4W1A=&5M96YT*"1S=&UT*3L*
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&ES<V5T*"1R97-U
M;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@("`@("\J"B`@("`@("`@("`@
M("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@
M("`@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R8V4@
M:61E;G1I9FEE<BX*("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)')E<R`](&%R<F%Y*"D["@H@("`@("`@("`@("!I9B`H
M)')E<W5L="`]/3T@)'1H:7,M/FQA<W1?<W1M="D@>PH@("`@("`@("`@("`@
M("`@)&-O=6YT(#T@0$]#24YU;4-O;',H)')E<W5L="D["B`@("`@("`@("`@
M("`@("!I9B`H)&UO9&4I('L*("`@("`@("`@("`@("`@("`@("`D<F5S6R=N
M=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*
M("`@("`@("`@("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G;F%M92<@(#T^("1C87-E7V9U;F,H0$]#24-O;'5M;DYA
M;64H)')E<W5L="P@)&DK,2DI+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M='EP92<@(#T^($!/0TE#;VQU;6Y4>7!E*"1R97-U;'0L("1I*S$I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G;&5N)R`@(#T^($!/0TE#;VQU;6Y3:7IE
M*"1R97-U;'0L("1I*S$I+`H@("`@("`@("`@("`@("`@("`@("`@("`G9FQA
M9W,G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;
M)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E<ULG;W)D97)T86)L
M92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M92==72`]("1I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O
M*BH*("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R
M(&QI<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO
M=2!W86YT('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R:79E
M<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G0@=&AE
M(&]B:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@
M("`@>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S
M92`G=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4('1A
M8FQE7VYA;64@1E)/32!U<V5R7W1A8FQE<R<["B`@("`@("`@("`@(&-A<V4@
M)W-Y;F]N>6US)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4('-Y
M;F]N>6U?;F%M92!&4D]-('5S97)?<WEN;VYY;7,G.PH@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M?0H@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S
M.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD
M.@H@*B\*"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$
M0B]O9&)C+G!H<```````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`V-#0U-@`Q,#4Q-30S,3`U-P`P,3<R-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S
M=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G
M<R!O9&)C(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!D871A
M8F%S97,@=FEA($]$0D,@8V]N;F5C=&EO;G,*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T
M:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P
M86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N
M:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(&]D8F,N<&AP+'8@,2XW."`R,#`U+S`R+S(X(#`Q.C0R.C$W
M(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?8V]M
M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U
M:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H;V1S
M(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S(&]D8F,@97AT
M96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H(&1A=&%B87-E<R!V:6$@
M3T1"0R!C;VYN96-T:6]N<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D
M('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@36]R92!I
M;F9O(&]N($]$0D,@97)R;W)S(&-O=6QD(&)E(&9O=6YD(&AE<F4Z"B`J(&AT
M='`Z+R]M<V1N+FUI8W)O<V]F="YC;VTO;&EB<F%R>2]D969A=6QT+F%S<#]U
M<FP]+VQI8G)A<GDO96XM=7,O=')B;'-Q;"]T<E]E<G)?;V1B8U\U<W1Z+F%S
M<`H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N
M-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]$0@H@*B\*8VQA<W,@1$)?;V1B8R!E>'1E;F1S($1"7V-O;6UO;@I["B`@
M("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"(&1R
M:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]("=O9&)C)SL*
M"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T
M;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=S<6PY
M,B<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@
M1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK
M)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T
M('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"
M35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@
M("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@
M("`J("`@*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y
M(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R
M>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@
M("`J($Y/5$4Z(%1H92!F96%T=7)E('-E="!O9B!T:&4@9F]L;&]W:6YG(&1R
M:79E<G,@87)E(&1I9F9E<F5N="!T:&%N"B`@("`@*B!T:&4@9&5F875L=#H*
M("`@("`J("`@*R!S;VQI9#H@)W1R86YS86-T:6]N<R<@/2!T<G5E"B`@("`@
M*B`@("L@;F%V:7-I;VXZ("=L:6UI="<@/2!F86QS90H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y
M*`H@("`@("`@("=L:6UI="<@("`@("`@("`]/B`G96UU;&%T92<L"B`@("`@
M("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N=6UR;W=S
M)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T
M<G5E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS92P*("`@("`@
M("`G<W-L)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T
M:6]N<R<@(#T^(&9A;'-E+`H@("`@*3L*"B`@("`O*BH*("`@("`J($$@;6%P
M<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@=&\@1$(@97)R;W(@8V]D97,*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1E<G)O<F-O9&5?
M;6%P(#T@87)R87DH"B`@("`@("`@)S`Q,#`T)R`]/B!$0E]%4E)/4E]44E5.
M0T%4140L"B`@("`@("`@)S`W,#`Q)R`]/B!$0E]%4E)/4E]-25--051#2"P*
M("`@("`@("`G,C%3,#$G(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/
M5RP*("`@("`@("`G,C%3,#(G(#T^($1"7T524D]27TU)4TU!5$-(+`H@("`@
M("`@("<R,C`P,2<@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`G,C(P
M,#,G(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("<R,C`P
M-2<@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@("`@("`@)S(R,#`X
M)R`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L"B`@("`@("`@)S(R,#$R)R`]
M/B!$0E]%4E)/4E]$259:15)/+`H@("`@("`@("<R,S`P,"<@/3X@1$)?15)2
M3U)?0T].4U1204E.5"P*("`@("`@("`G,C,U,#(G(#T^($1"7T524D]27T-/
M3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@)S(S-3`S)R`]/B!$0E]%4E)/
M4E]#3TY35%)!24Y4+`H@("`@("`@("<R,S4P-"<@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`G,C,U,#4G(#T^($1"7T524D]27T-/3E-44D%)
M3E0L"B`@("`@("`@)S(T,#`P)R`]/B!$0E]%4E)/4E])3E9!3$E$+`H@("`@
M("`@("<S-#`P,"<@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`G,S<P
M,#`G(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`G-#(P,#`G(#T^($1"
M7T524D]27U-93E1!6"P*("`@("`@("`G-#(V,#$G(#T^($1"7T524D]27U-9
M3E1!6"P*("`@("`@("`G24TP,#$G(#T^($1"7T524D]27U5.4U504$]25$5$
M+`H@("`@("`@("=3,#`P,"<@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@
M("`@("`@)U,P,#`Q)R`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@
M("`@("`G4S`P,#(G(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@
M("=3,#`Q,2<@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@
M)U,P,#$R)R`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@)U,P,#(Q
M)R`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`G4S`P,C(G
M(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("=3,3`P.2<@/3X@
M1$)?15)23U)?24Y604Q)1"P*("`@("`@("`G4S$P.3`G(#T^($1"7T524D]2
M7TE.5D%,240L"B`@("`@("`@)U,Q0S`P)R`]/B!$0E]%4E)/4E].3U1?0T%0
M04),12P*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E
M(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R
M8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@
M("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A
M=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N
M(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O
M=W,@869F96-T960@8GD@82!D871A(&UA;FEP=6QA=&EO;B!Q=65R>0H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1A9F9E8W1E9"`](#`["@H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C
M=&]R(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@
M*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"
M7V]D8F,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*
M("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN
M(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A
M;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I
M;G-T96%D+@H@("`@("H*("`@("`J(%!%05(@1$(G<R!O9&)C(&1R:79E<B!S
M=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@
M("H@("`K(&-U<G-O<B`@5&AE('1Y<&4@;V8@8W5R<V]R('1O(&)E('5S960@
M9F]R('1H:7,@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@*B!`
M<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO
M;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T
M96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL;V%D17AT
M96YS:6]N*"=O9&)C)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@("`@:68@
M*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN
M=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"B`@("`@("`@<W=I
M=&-H("@D=&AI<RT^9&)S>6YT87@I('L*("`@("`@("`@("`@8V%S92`G86-C
M97-S)SH*("`@("`@("`@("`@8V%S92`G9&(R)SH*("`@("`@("`@("`@8V%S
M92`G<V]L:60G.@H@("`@("`@("`@("`@("`@)'1H:7,M/F9E871U<F5S6R=T
M<F%N<V%C=&EO;G,G72`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`G;F%V:7-I;VXG.@H@("`@("`@("`@("`@("`@
M)'1H:7,M/F9E871U<F5S6R=L:6UI="==(#T@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O*@H@("`@("`@("`J(%1H:7,@:7,@:&5A<B!F;W(@8F%C:W=A
M<F1S(&-O;7!A=&EB:6QI='DN(%-H;W5L9"!H879E(&)E96X@=7-I;F<*("`@
M("`@("`@*B`G9&%T86)A<V4G(&%L;"!A;&]N9RP@8G5T('!R:6]R('1O(#$N
M-BXP4D,S("=H;W-T<W!E8R<@=V%S('5S960N"B`@("`@("`@("HO"B`@("`@
M("`@:68@*"1D<VY;)V1A=&%B87-E)UTI('L*("`@("`@("`@("`@)&]D8F-D
M<VX@/2`D9'-N6R=D871A8F%S92==.PH@("`@("`@('T@96QS96EF("@D9'-N
M6R=H;W-T<W!E8R==*2!["B`@("`@("`@("`@("1O9&)C9'-N(#T@)&1S;ELG
M:&]S='-P96,G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V1B
M8V1S;B`]("=L;V-A;&AO<W0G.PH@("`@("`@('T*"B`@("`@("`@)&-O;FYE
M8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=O9&)C7W!C;VYN96-T)R`Z
M("=O9&)C7V-O;FYE8W0G.PH*("`@("`@("!I9B`H96UP='DH)&1S;ELG8W5R
M<V]R)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0"1C
M;VYN96-T7V9U;F-T:6]N*"1O9&)C9'-N+"`D9'-N6R=U<V5R;F%M92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9'-N6R=P87-S=V]R9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC=&EO
M;B@D;V1B8V1S;BP@)&1S;ELG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG<&%S
M<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1S;ELG8W5R<V]R)UTI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^8V]N;F5C=&EO;BDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<DYA=&EV92@I*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@1&ES
M8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A
M:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("![
M"B`@("`@("`@)&5R<B`]($!O9&)C7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@
M<F5T=7)N("1E<G(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM
M<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T
M:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S<V9U
M;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!T:&4@
M1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<PH@
M("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R
M>2D*("`@('L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*
M("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)'%U97)Y*3L*
M("`@("`@("`D<F5S=6QT(#T@0&]D8F-?97AE8R@D=&AI<RT^8V]N;F5C=&EO
M;BP@)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O<B@I.R`O+R!86%@@15)2
M3U)-4T<*("`@("`@("!]"B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U
M97)I97,@=&AA="!S:&]U;&0@<F5T=7)N(&1A=&$L(&%N9"!W:&EC:`H@("`@
M("`@("\O('-H;W5L9"!R971U<FX@86X@97)R;W(@8V]D92!O;FQY+@H@("`@
M("`@(&EF("A$0CHZ:7--86YI<"@D<75E<GDI*2!["B`@("`@("`@("`@("1T
M:&ES+3YA9F9E8W1E9"`]("1R97-U;'0[("\O($9O<B!A9F9E8W1E9%)O=W,H
M*0H@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YA9F9E8W1E9"`](#`["B`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@
M("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!O9&)C(')E<W5L="!P
M;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@("`J"B`@
M("`@*B!`<&%R86T@82!V86QI9"!F8G-Q;"!R97-U;'0@<F5S;W5R8V4*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U
M<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I;&%B;&4@;W1H97)W:7-E(')E
M='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT4F5S=6QT*"1R
M97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N($!O9&)C7VYE>'1?<F5S=6QT
M*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H
M26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@
M<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J
M($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@
M87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H
M26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN
M("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@
M("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*("`@
M("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT
M:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H,"`]
M(&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$0E]/
M2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L="!S
M970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N(&9A
M:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D
M87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@
M("`D87)R(#T@87)R87DH*3L*("`@("`@("!I9B`H)')O=VYU;2`A/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D<F]W;G5M*RL[("\O($]$0D,@9FER<W0@<F]W
M(&ES(#$*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S
M:6]N*"DL("<T+C(N,"<L("=G92<I*2!["B`@("`@("`@("`@("`@("`D8V]L
M<R`]($!O9&)C7V9E=&-H7VEN=&\H)')E<W5L="P@)&%R<BP@)')O=VYU;2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8V]L<R`]
M($!O9&)C7V9E=&-H7VEN=&\H)')E<W5L="P@)')O=VYU;2P@)&%R<BD["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V]L
M<R`]($!O9&)C7V9E=&-H7VEN=&\H)')E<W5L="P@)&%R<BD["B`@("`@("`@
M?0H@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("$]/2!$0E]&
M151#2$U/1$5?3U)$15)%1"D@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D87)R*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&-O
M;$YA;64@/2!`;V1B8U]F:65L9%]N86UE*"1R97-U;'0L("1I*S$I.PH@("`@
M("`@("`@("`@("`@)&%;)&-O;$YA;65=(#T@)&%R<ELD:5T["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@
M("`@("`@("`D82`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D82P@0T%315],
M3U=%4BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&%R<B`]("1A.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL
M:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/
M4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U<&EE
M9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@
M("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B92!D
M96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@
M:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&
M04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E
M($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R9652
M97-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&]D8F-?9G)E
M95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@
M;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@
M8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@
M1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@
M<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E
M<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@
M("`D8V]L<R`]($!O9&)C7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@("`@
M:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*
M("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@
M869F96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*
M("`@("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M
M86YI<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H
M92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YA9F9E8W1E9"DI('L@("\O($EN
M(&-A<V4@;V8@4T5,14-4('-T;7,*("`@("`@("`@("`@<F5T=7)N(#`["B`@
M("`@("`@?0H@("`@("`@("1N<F]W<R`]($!O9&)C7VYU;5]R;W=S*"1T:&ES
M+3YA9F9E8W1E9"D["B`@("`@("`@:68@*"1N<F]W<R`]/2`M,2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D;G)O=W,["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H
M92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!.;W0@86QL($]$0D,@9')I=F5R<R!S=7!P;W)T('1H:7,@9G5N8W1I;VYA
M;&ET>2X@($EF('1H97D@9&]N)W0*("`@("`J(&$@1$)?17)R;W(@;V)J96-T
M(&9O<B!$0E]%4E)/4E]53E-54%!/4E1%1"!I<R!R971U<FYE9"X*("`@("`J
M"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D
M(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I
M;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@
M("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q
M=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W
M<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@
M('L*("`@("`@("`D;G)O=W,@/2!`;V1B8U]N=6U?<F]W<R@D<F5S=6QT*3L*
M("`@("`@("!I9B`H)&YR;W=S(#T]("TQ*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H1$)?15)23U)?54Y355!03U)4140I
M.PH@("`@("`@('T*("`@("`@("!I9B`H)&YR;W=S(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D;G)O=W,["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<75O=&5)9&5N=&EF:65R*"D*"B`@("`O*BH*("`@
M("`J(%%U;W1E<R!A('-T<FEN9R!S;R!I="!C86X@8F4@<V%F96QY('5S960@
M87,@82!T86)L92!O<B!C;VQU;6X@;F%M90H@("`@("H*("`@("`J(%5S92`G
M;7-S<6PG(&%S('1H92!D8G-Y;G1A>"!I;B!T:&4@1$(@1%-.(&]N;'D@:68@
M>6]U)W9E('5N8VAE8VME9`H@("`@("H@(E5S92!!3E-)('%U;W1E9"!I9&5N
M=&EF:65R<R(@=VAE;B!S971T:6YG('5P('1H92!/1$)#(&1A=&$@<V]U<F-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@:61E;G1I9FEE
M<B!N86UE('1O(&)E('%U;W1E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!Q=6]T960@:61E;G1I9FEE<B!S=')I;F<*("`@("`J"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ<75O=&5)9&5N=&EF:65R*"D*("`@("`J($!S:6YC
M92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J
M+PH@("`@9G5N8W1I;VX@<75O=&5)9&5N=&EF:65R*"1S='(I"B`@("!["B`@
M("`@("`@<W=I=&-H("@D=&AI<RT^9'-N6R=D8G-Y;G1A>"==*2!["B`@("`@
M("`@("`@(&-A<V4@)V%C8V5S<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@
M)ULG("X@)'-T<B`N("==)SL*("`@("`@("`@("`@8V%S92`G;7-S<6PG.@H@
M("`@("`@("`@("!C87-E("=S>6)A<V4G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("=;)R`N('-T<E]R97!L86-E*"==)RP@)UU=)RP@)'-T<BD@+B`G72<[
M"B`@("`@("`@("`@(&-A<V4@)VUY<W%L)SH*("`@("`@("`@("`@8V%S92`G
M;7ES<6QI)SH*("`@("`@("`@("`@("`@(')E='5R;B`G8"<@+B`D<W1R("X@
M)V`G.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("<B)R`N('-T<E]R97!L86-E*"<B)RP@)R(B)RP@)'-T<BD@+B`G(B<[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E
M*"D*"B`@("`O*BH*("`@("`J($!D97!R96-A=&5D("!$97!R96-A=&5D(&EN
M(')E;&5A<V4@,2XV+C`*("`@("`J($!I;G1E<FYA;`H@("`@("HO"B`@("!F
M=6YC=&EO;B!Q=6]T92@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^<75O=&53;6%R="@D<W1R*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X
M="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E
M<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@
M=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*
M("`@("`J("`@("`@1$)?;V1B8SHZ8W)E871E4V5Q=65N8V4H*2P@1$)?;V1B
M8SHZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED
M*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@('L*("`@("`@("`D
M<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*
M("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("!D;R!["B`@("`@("`@("`@
M("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH(G5P9&%T92`D
M>W-E<6YA;65]('-E="!I9"`](&ED("L@,2(I.PH@("`@("`@("`@("`D=&AI
M<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@("!I9B`H)&]N9&5M
M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@
M("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I
M('L*("`@("`@("`@("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q
M=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP;W!%
M<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*")I;G-E<G0@
M:6YT;R`D>W-E<6YA;65]("AI9"D@=F%L=65S*#`I(BD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@
M("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E870I.PH*("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@('T*"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B<V5L96-T(&ED(&9R;VT@)'MS
M97%N86UE?2(I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$
M15)%1"D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R;W<@?'P@(21R;W<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F]W.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R;W=;,%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U
M96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;V1B8SHZ;F5X=$E$*"DL($1"
M7V]D8F,Z.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R
M96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G%U97)Y*"=#4D5!5$4@5$%"3$4@)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M
M92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R`H:60@:6YT96=E
M<B!.3U0@3E5,3"PG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@
M4%))34%262!+15DH:60I*2<I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M
M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N
M8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V]D8F,Z.FYE>'1)1"@I+"!$0E]O
M9&)C.CIC<F5A=&5397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R
M;W!397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YQ=65R>2@G1%)/4"!404),12`G("X@)'1H:7,M/F=E=%-E<75E;F-E
M3F%M92@D<V5Q7VYA;64I*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES
M86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J"B`@("`@*B!`<&%R86T@
M8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL(&9A;'-E('1U<FYS(&ET
M(&]F9@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E<@H@("`@("H@
M("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@875T;RUC;VUM:71T:6YG
M('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O;6UI
M="@D;VYO9F8@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(4!O9&)C7V%U
M=&]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXL("1O;F]F9BDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O<B@I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@("`J($-O;6UI=',@=&AE
M(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@
M("`@("`@:68@*"%`;V1B8U]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J(%)E
M=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O;&QB86-K
M*"D*("`@('L*("`@("`@("!I9B`H(4!O9&)C7W)O;&QB86-K*"1T:&ES+3YC
M;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!O9&)C4F%I<V5%<G)O<B@I
M"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B:F5C="!R
M96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@("`J($!P
M87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@;6%N=6%L
M;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("!$
M0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@<&%S<V5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!I;F9O<FUA
M=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@("`J($!R
M971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J("`@("`@
M1$)?;V1B8SHZ97)R;W).871I=F4H*2P@1$)?8V]M;6]N.CIE<G)O<D-O9&4H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!O9&)C4F%I<V5%<G)O<B@D97)R;F\@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*
M("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^9&)S>6YT87@I('L*("`@("`@
M("`@("`@("`@(&-A<V4@)V%C8V5S<R<Z"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"
M24Q)5%E?15)23U)3*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YE<G)O<F-O9&5?;6%P6R<P-S`P,2==(#T@1$)?15)23U)?3D]354-(1DE%
M3$0["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@1&]I;F<@=&AI<R!I;B!C87-E(&UO9&4@8VAA;F=E
M<R!D=7)I;F<@<G5N=&EM92X*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F5R<F]R8V]D95]M87!;)S`W,#`Q)UT@/2!$0E]%4E)/4E]-25--051#
M2#L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@
M("1N871I=F5?8V]D92`](&]D8F-?97)R;W(H)'1H:7,M/F-O;FYE8W1I;VXI
M.PH*("`@("`@("`@("`@("`@("`@("`O+R!3,3`P,"!I<R!F;W(@(D=E;F5R
M86P@17)R;W(N(B`@3&5T)W,@8F4@;6]R92!S<&5C:69I8RX*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&YA=&EV95]C;V1E(#T]("=3,3`P,"<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<F]R;7-G(#T@;V1B8U]E<G)O<FUS
M9R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("`@("`@("`@
M('-T871I8R`D97)R;W)?<F5G97AP<SL*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D97)R;W)?<F5G97AP<RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)O<E]R96=E>'!S(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R]I;F-L=61E<R!R96QA=&5D
M(')E8V]R9',N)"]I)R`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G+V-A;FYO="!C;VYT86EN(&$@
M3G5L;"!V86QU92]I)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D97)R;W)?<F5G97AP<R!A<R`D<F5G97AP(#T^("1C;V1E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G97AP
M+"`D97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C;V1E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M871I=F5?8V]D92`N("<@)R`N("1E<G)O<FUS9RD["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<FYO(#T@1$)?15)23U(["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92@D;F%T:79E7V-O9&4I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@
M("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92AO9&)C7V5R<F]R*"1T:&ES
M+3YC;VYN96-T:6]N*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L
M;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F5R<F]R3F%T:79E*"DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"
M35,G(&YA=&EV92!E<G)O<B!C;V1E(&%N9"!M97-S86=E('!R;V1U8V5D(&)Y
M('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!$0DU3)R!E<G)O<B!C;V1E(&%N9"!M97-S86=E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!I9B`H(6ES
M7W)E<V]U<F-E*"1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R
M971U<FX@0&]D8F-?97)R;W(H*2`N("<@)R`N($!O9&)C7V5R<F]R;7-G*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!`;V1B8U]E<G)O<B@D=&AI<RT^
M8V]N;F5C=&EO;BD@+B`G("<@+B!`;V1B8U]E<G)O<FUS9R@D=&AI<RT^8V]N
M;F5C=&EO;BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5)
M;F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O
M=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!`<&%R
M86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F
M<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A
M8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!7
M:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I9&5N
M=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R86T@
M:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D
M90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E
M(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J
M("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@
M("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@
M)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)')E
M<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B
M;'D@<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A
M=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@
M("HO"B`@("`@("`@("`@("1I9"`]($!O9&)C7V5X96,H)'1H:7,M/F-O;FYE
M8W1I;VXL(")314Q%0U0@*B!&4D]-("1R97-U;'0B*3L*("`@("`@("`@("`@
M:68@*"$D:60I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V1B
M8U)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9V]T
M7W-T<FEN9R`]('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1R97-U
M;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@
M4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@("`@("`@("`@
M("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0M/G)E
M<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B
M86)L>2!R96-E:79E9"!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@
M("`@("`@("`@("`@*B!#;W!Y(&ET+@H@("`@("`@("`@("`@*B!$97!R96-A
M=&5D+B`@2&5R92!F;W(@8V]M<&%T:6)I;&ET>2!O;FQY+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@
M)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F]D8F-286ES945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI
M='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@
M("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]
M"@H@("`@("`@("1C;W5N="`]($!O9&)C7VYU;5]F:65L9',H)&ED*3L*("`@
M("`@("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*
M("`@("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@
M("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK
M*2!["B`@("`@("`@("`@("1C;VP@/2`D:2`K(#$["B`@("`@("`@("`@("1R
M97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("1G
M;W1?<W1R:6YG(#\@)&-A<V5?9G5N8R@D<F5S=6QT*2`Z("<G+`H@("`@("`@
M("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*$!O9&)C7V9I96QD7VYA
M;64H)&ED+"`D8V]L*2DL"B`@("`@("`@("`@("`@("`G='EP92<@(#T^($!O
M9&)C7V9I96QD7W1Y<&4H)&ED+"`D8V]L*2P*("`@("`@("`@("`@("`@("=L
M96XG("`@/3X@0&]D8F-?9FEE;&1?;&5N*"1I9"P@)&-O;"DL"B`@("`@("`@
M("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("`@("`I.PH@("`@("`@
M("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@("`@
M("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@/2`D
M:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]4
M04),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@)')E<ULG
M;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M
M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O;B!A
M('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@("`@
M($!O9&)C7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P
M96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R
M>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O
M8FIE8W1S"B`@("`@*@H@("`@("H@5&AA;FMS('1O('-Y;6)O;#%`9VUA:6PN
M8V]M(&%N9"!0:&EL:7!P92Y*875S:6]N<T`Q,6%B86-U<RYC;VTN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J
M96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@;&ES="!O9B!O8FIE8W1S(')E<75E<W1E9`H@("`@
M("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ9V5T3&ES=$]F*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G9&%T86)A<V5S)SH*("`@("`@
M("`@("`@("`@(&EF("@A9G5N8W1I;VY?97AI<W1S*"=O9&)C7V1A=&%?<V]U
M<F-E)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R97,@/2!`;V1B8U]D
M871A7W-O=7)C92@D=&AI<RT^8V]N;F5C=&EO;BP@4U%,7T9%5$-(7T9)4E-4
M*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5S*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1O=70@/2!A<G)A>2@D<F5S6R=S97)V97(G72D[
M"B`@("`@("`@("`@("`@("`@("`@=VAI;&4H)')E<R`]($!O9&)C7V1A=&%?
M<V]U<F-E*"1T:&ES+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!344Q?1D540TA?3D58
M5"DI"B`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T6UT@/2`D<F5S6R=S97)V97(G73L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1O=70["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=T86)L
M97,G.@H@("`@("`@("`@("!C87-E("=S8VAE;6$N=&%B;&5S)SH*("`@("`@
M("`@("`@("`@("1K965P(#T@)U1!0DQ%)SL*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E("=V:65W<R<Z"B`@("`@("`@("`@("`@
M("`D:V5E<"`]("=62457)SL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@("`J(%)E;6]V:6YG(&YO
M;BUC;VYF;W)M:6YG(&ET96US(&EN('1H92!W:&EL92!L;V]P(')A=&AE<B!T
M:&%N"B`@("`@("`@("H@:6X@=&AE(&]D8F-?=&%B;&5S*"D@8V%L;"!B96-A
M=7-E('-O;64@8F%C:V5N9',@8VAO:V4@;VX@=&AI<SH*("`@("`@("`@*B`@
M("`@;V1B8U]T86)L97,H)'1H:7,M/F-O;FYE8W1I;VXL("<G+"`G)RP@)R<L
M("=404),12<I"B`@("`@("`@("HO"B`@("`@("`@)')E<R`@/2!`;V1B8U]T
M86)L97,H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<RD@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D[
M"B`@("`@("`@?0H@("`@("`@("1O=70@/2!A<G)A>2@I.PH@("`@("`@('=H
M:6QE("@D<F]W(#T@;V1B8U]F971C:%]A<G)A>2@D<F5S*2D@>PH@("`@("`@
M("`@("!I9B`H)')O=ULG5$%"3$5?5%E012==("$]("1K965P*2!["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)'1Y<&4@/3T@)W-C:&5M82YT86)L97,G*2!["B`@("`@("`@("`@
M("`@("`D;W5T6UT@/2`D<F]W6R=404),15]30TA%32==("X@)RXG("X@)')O
M=ULG5$%"3$5?3D%-12==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&]U=%M=(#T@)')O=ULG5$%"3$5?3D%-12==.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;W5T.PH@("`@?0H*
M("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M
M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]$0B]P9W-Q;"YP:'``````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P-38U,0`Q,#4Q-30S,3`U-P`P
M,3<T-S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%05(@
M1$(@9')I=F5R(&9O<B!02%`G<R!P9W-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN
M=&5R86-T:6YG('=I=&@@4&]S=&=R95-13"!D871A8F%S97,*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B
M87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%)U:2!(:7)O
M:V%W82`\:&ER;VMA=V%`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@4W1I9R!"
M86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@<&=S<6PN<&AP+'8@,2XQ,C8@,C`P-2\P
M,R\P-"`R,SHQ,CHS-B!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A
M:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@
M9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@
M*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!0
M2%`G<R!P9W-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@
M4&]S=&=R95-13"!D871A8F%S97,*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R
M;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J($!C
M871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H
M;W(@("`@(%)U:2!(:7)O:V%W82`\:&ER;VMA=V%`<&AP+FYE=#X*("H@0&%U
M=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO
M"F-L87-S($1"7W!G<W%L(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[
M>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y
M<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)W!G<W%L)SL*"B`@("`O
M*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!B92!U
M<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=P9W-Q;"<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP
M;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M
M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I
M9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#
M;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@
M("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@("`J("`@
M*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E
M<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@
M("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@
M("`@("`@("=L:6UI="<@("`@("`@("`]/B`G86QT97(G+`H@("`@("`@("=N
M97=?;&EN:R<@("`@("`]/B`G-"XS+C`G+`H@("`@("`@("=N=6UR;W=S)R`@
M("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E
M+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS92P*("`@("`@("`G
M<W-L)R`@("`@("`@("`@/3X@=')U92P*("`@("`@("`G=')A;G-A8W1I;VYS
M)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA<'!I;F<@
M;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C;V1E7VUA<"`]
M(&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A
M<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O
M=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@
M("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@
M9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D
M<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J(%-H;W5L9"!D871A(&UA
M;FEP=6QA=&EO;B!Q=65R:65S(&)E(&-O;6UI='1E9"!A=71O;6%T:6-A;&QY
M/PH@("`@("H@0'9A<B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1A=71O8V]M;6ET(#T@=')U93L*"B`@("`O*BH*("`@
M("`J(%1H92!Q=6%N=&ET>2!O9B!T<F%N<V%C=&EO;G,@8F5G=6X*("`@("`J
M"B`@("`@*B![0&EN=&5R;F%L("!7:&EL92!T:&ES(&ES('!R:79A=&4L(&ET
M(&-A;B=T(&%C='5A;&QY(&)E(&1E<VEG;F%T960*("`@("`J('!R:79A=&4@
M:6X@4$A0(#4@8F5C875S92!I="!I<R!D:7)E8W1L>2!A8V-E<W-E9"!I;B!T
M:&4@=&5S="!S=6ET92Y]?0H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D=')A;G-A
M8W1I;VY?;W!C;W5N="`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R
M(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA;FEP=6QA=&EO;B!Q=65R
M>0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D869F96-T
M960@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@<F]W(&)E:6YG
M(&QO;VME9"!A="!I;B!F971C:$EN=&\H*0H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D<F]W(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@<F]W<R!I
M;B!A(&=I=F5N(')E<W5L="!S970*("`@("`J($!V87(@87)R87D*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]N=6U?<F]W<R`]
M(&%R<F%Y*"D["@H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R(&-A;&QS(#QK8F0^
M)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7W!G<W%L*"D*("`@('L*
M("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T
M('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@
M9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D
M(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J
M"B`@("`@*B!014%2($1")W,@<&=S<6P@9')I=F5R('-U<'!O<G1S('1H92!F
M;VQL;W=I;F<@97AT<F$@1%-.(&]P=&EO;G,Z"B`@("`@*B`@("L@8V]N;F5C
M=%]T:6UE;W5T("!(;W<@;6%N>2!S96-O;F1S('1O('=A:70@9F]R(&$@8V]N
M;F5C=&EO;B!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&)E(&5S
M=&%B;&ES:&5D+B`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@
M("`@*B`@("L@;F5W7VQI;FL@("`@("`@("!)9B!S970@=&\@=')U92P@8V%U
M<V5S('-U8G-E<75E;G0@8V%L;',@=&\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!C;VYN96-T*"D@=&\@<F5T=7)N(&$@;F5W(&-O;FYE8W1I;VX@
M;&EN:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@
M=&AE(&5X:7-T:6YG(&]N92X@(%=!4DY)3D<Z('1H:7,@:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!N;W0@<&]R=&%B;&4@=&\@;W1H97(@1$)-
M4R=S+B`@079A:6QA8FQE(&]N;'D*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!I9B!02%`@:7,@/CT@-"XS+C`@86YD(%!%05(@1$(@:7,@/CT@,2XW
M+C`N"B`@("`@*B`@("L@;W!T:6]N<R`@("`@("`@("!#;VUM86YD(&QI;F4@
M;W!T:6]N<R!T;R!B92!S96YT('1O('1H92!S97)V97(N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XV
M+C0N"B`@("`@*B`@("L@<V5R=FEC92`@("`@("`@("!3<&5C:69I97,@82!S
M97)V:6-E(&YA;64@:6X@<&=?<V5R=FEC92YC;VYF('1H870*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!H;VQD<R!A9&1I=&EO;F%L(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!!
M=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C<N,"X*("`@("`J("`@*R!S<VQM
M;V1E("`@("`@("`@($AO=R!S:&]U;&0@4U-,(&)E('5S960@=VAE;B!C;VYN
M96-T:6YG/R`@5F%L=65S.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&1I<V%B;&4L(&%L;&]W+"!P<F5F97(@;W(@<F5Q=6ER92X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q
M+C<N,"X*("`@("`J("`@*R!T='D@("`@("`@("`@("`@(%1H:7,@=V%S('5S
M960@=&\@<W!E8VEF>2!W:&5R92!T;R!S96YD('-E<G9E<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&1E8G5G(&]U='!U="X@($%V86EL86)L92!S
M:6YC92!014%2($1"(#$N-BXT+@H@("`@("H*("`@("`J($5X86UP;&4@;V8@
M8V]N;F5C=&EN9R!T;R!A(&YE=R!L:6YK('9I82!A('-O8VME=#H*("`@("`J
M(#QC;V1E/@H@("`@("H@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("H@
M"B`@("`@*B`D9'-N(#T@)W!G<W%L.B\O=7-E<CIP87-S0'5N:7@H+W1M<"DO
M9&)N86UE/VYE=U]L:6YK/71R=64G.PH@("`@("H@)&]P=&EO;G,@/2!A<G)A
M>2@*("`@("`J("`@("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,2519
M7T%,3"P*("`@("`J("D["B`@("`@*B`*("`@("`J("1D8B`])B!$0CHZ8V]N
M;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@*B!I9B`H4$5!4CHZ:7-%<G)O
M<B@D9&(I*2!["B`@("`@*B`@("`@9&EE*"1D8BT^9V5T365S<V%G92@I*3L*
M("`@("`J('T*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@
M*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C
M=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!L:6YK(&AT='`Z+R]W=W<N<&]S=&=R97-Q
M;"YO<F<O9&]C<R]C=7)R96YT+W-T871I8R]L:6)P<2YH=&UL(TQ)0E!1+4-/
M3DY%0U0*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R
M<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A
M9$5X=&5N<VEO;B@G<&=S<6PG*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@
M("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI<RT^
M9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@('T*"B`@("`@
M("`@)'!R;W1O8V]L(#T@)&1S;ELG<')O=&]C;VPG72`_("1D<VY;)W!R;W1O
M8V]L)UT@.B`G=&-P)SL*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"<G*3L*
M("`@("`@("!I9B`H)'!R;W1O8V]L(#T]("=T8W`G*2!["B`@("`@("`@("`@
M(&EF("@D9'-N6R=H;W-T<W!E8R==*2!["B`@("`@("`@("`@("`@("`D<&%R
M86US6S!=("X]("=H;W-T/2<@+B`D9'-N6R=H;W-T<W!E8R==.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D9'-N6R=P;W)T)UTI('L*("`@("`@
M("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!P;W)T/2<@+B`D9'-N6R=P;W)T
M)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)'!R;W1O8V]L
M(#T]("=U;FEX)RD@>PH@("`@("`@("`@("`O+R!!;&QO=R!F;W(@<&<@<V]C
M:V5T(&EN(&YO;BUS=&%N9&%R9"!L;V-A=&EO;G,N"B`@("`@("`@("`@(&EF
M("@D9'-N6R=S;V-K970G72D@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULP
M72`N/2`G:&]S=#TG("X@)&1S;ELG<V]C:V5T)UT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1D<VY;)W!O<G0G72D@>PH@("`@("`@("`@("`@
M("`@)'!A<F%M<ULP72`N/2`G('!O<G0])R`N("1D<VY;)W!O<G0G73L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&1S;ELG9&%T86)A
M<V4G72D@>PH@("`@("`@("`@("`D<&%R86US6S!=("X]("<@9&)N86UE/5PG
M)R`N(&%D9'-L87-H97,H)&1S;ELG9&%T86)A<V4G72D@+B`G7"<G.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&1S;ELG=7-E<FYA;64G72D@>PH@("`@("`@
M("`@("`D<&%R86US6S!=("X]("<@=7-E<CU<)R<@+B!A9&1S;&%S:&5S*"1D
M<VY;)W5S97)N86UE)UTI("X@)UPG)SL*("`@("`@("!]"B`@("`@("`@:68@
M*"1D<VY;)W!A<W-W;W)D)UTI('L*("`@("`@("`@("`@)'!A<F%M<ULP72`N
M/2`G('!A<W-W;W)D/5PG)R`N(&%D9'-L87-H97,H)&1S;ELG<&%S<W=O<F0G
M72D@+B`G7"<G.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1D<VY;
M)V]P=&EO;G,G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULP72`N/2`G(&]P
M=&EO;G,])R`N("1D<VY;)V]P=&EO;G,G73L*("`@("`@("!]"B`@("`@("`@
M:68@*"%E;7!T>2@D9'-N6R=T='DG72DI('L*("`@("`@("`@("`@)'!A<F%M
M<ULP72`N/2`G('1T>3TG("X@)&1S;ELG='1Y)UT["B`@("`@("`@?0H@("`@
M("`@(&EF("@A96UP='DH)&1S;ELG8V]N;F5C=%]T:6UE;W5T)UTI*2!["B`@
M("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!C;VYN96-T7W1I;65O=70])R`N
M("1D<VY;)V-O;FYE8W1?=&EM96]U="==.PH@("`@("`@('T*("`@("`@("!I
M9B`H(65M<'1Y*"1D<VY;)W-S;&UO9&4G72DI('L*("`@("`@("`@("`@)'!A
M<F%M<ULP72`N/2`G('-S;&UO9&4])R`N("1D<VY;)W-S;&UO9&4G73L*("`@
M("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D9'-N6R=S97)V:6-E)UTI*2![
M"B`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!S97)V:6-E/2<@+B`D9'-N
M6R=S97)V:6-E)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&1S
M;ELG;F5W7VQI;FLG72D*("`@("`@("`@("`@)B8@*"1D<VY;)VYE=U]L:6YK
M)UT@/3T@)W1R=64G('Q\("1D<VY;)VYE=U]L:6YK)UT@/3T]('1R=64I*0H@
M("`@("`@('L*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V
M97)S:6]N*"DL("<T+C,N,"<L("<^/2<I*2!["B`@("`@("`@("`@("`@("`D
M<&%R86US6UT@/2!01U-13%]#3TY.14-47T9/4D-%7TY%5SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D
M<&5R<VES=&5N="`_("=P9U]P8V]N;F5C="<@.B`G<&=?8V]N;F5C="<["@H@
M("`@("`@("1I;FD@/2!I;FE?9V5T*"=T<F%C:U]E<G)O<G,G*3L*("`@("`@
M("`D<&AP7V5R<F]R;7-G(#T@)R<["B`@("`@("`@:68@*"1I;FDI('L*("`@
M("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?
M87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R
M<F]R<R<L(#$I.PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C
M86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO;BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M<RD["B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R
M<R<L("1I;FDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^8V]N
M;F5C=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<%]E<G)O<FUS9RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J
M($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O
M;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@("1R970@/2!`<&=?8VQO<V4H)'1H:7,M/F-O;FYE8W1I
M;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@
M("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S
M:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O
M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@("L@82!02%`@<F5S=6QT(')E<W)O=6-E(&9O<B!S=6-C97-S
M9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K('1H
M92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S
M"B`@("`@*B`@("`@("`@("`@("`@("`K(&$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@<VEM<&QE475E<GDH)'%U
M97)Y*0H@("`@>PH@("`@("`@("1I<VUA;FEP(#T@1$(Z.FES36%N:7`H)'%U
M97)Y*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@
M("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)'%U97)Y*3L*("`@
M("`@("!I9B`H(21T:&ES+3YA=71O8V]M;6ET("8F("1I<VUA;FEP*2!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]/2`P
M*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@0'!G7V5X96,H)'1H:7,M
M/F-O;FYE8W1I;VXL("=B96=I;CLG*3L*("`@("`@("`@("`@("`@(&EF("@A
M)')E<W5L="D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<&=S<6Q286ES945R<F]R*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0K
M*SL*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]($!P9U]E>&5C*"1T:&ES
M+3YC;VYN96-T:6]N+"`D<75E<GDI.PH@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G!G<W%L4F%I<V5%<G)O<B@I
M.PH@("`@("`@('T*("`@("`@("`O+R!$971E<FUI;F4@=VAI8V@@<75E<FEE
M<R!T:&%T('-H;W5L9"!R971U<FX@9&%T82P@86YD('=H:6-H"B`@("`@("`@
M+R\@<VAO=6QD(')E='5R;B!A;B!E<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@
M:68@*"1I<VUA;FEP*2!["B`@("`@("`@("`@("1T:&ES+3YA9F9E8W1E9"`]
M($!P9U]A9F9E8W1E9%]R;W=S*"1R97-U;'0I.PH@("`@("`@("`@("!R971U
M<FX@1$)?3TL["B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>7',J
M7"@J7',J*%-%3$5#5'Q%6%!,04E.?%-(3U<I7',O<VDG+"`D<75E<GDI*2![
M"B`@("`@("`@("`@("\J(%!O<W1G<F5344P@8V]M;6%N9',Z"B`@("`@("`@
M("`@("`@($%"3U)4+"!!3%1%4BP@0D5'24XL($-,3U-%+"!#3%535$52+"!#
M3TU-250L($-/4%DL"B`@("`@("`@("`@("`@($-214%412P@1$5#3$%212P@
M1$5,151%+"!$4D]0(%1!0DQ%+"!%6%!,04E.+"!&151#2"P*("`@("`@("`@
M("`@("`@1U)!3E0L($E.4T525"P@3$E35$5.+"!,3T%$+"!,3T-++"!-3U9%
M+"!.3U1)1EDL(%)%4T54+`H@("`@("`@("`@("`@("!2159/2T4L(%)/3$Q"
M04-++"!314Q%0U0L(%-%3$5#5"!)3E1/+"!3150L(%-(3U<L"B`@("`@("`@
M("`@("`@(%5.3$E35$5.+"!54$1!5$4L(%9!0U5530H@("`@("`@("`@("`J
M+PH@("`@("`@("`@("`D=&AI<RT^<F]W6RAI;G0I)')E<W5L=%T@/2`P.R`O
M+R!R97-E="!T:&4@<F]W(&-O=6YT97(N"B`@("`@("`@("`@("1N=6UR;W=S
M(#T@)'1H:7,M/FYU;5)O=W,H)')E<W5L="D["B`@("`@("`@("`@(&EF("AI
M<U]O8FIE8W0H)&YU;7)O=W,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&YU;7)O=W,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]N
M=6U?<F]W<ULH:6YT*21R97-U;'1=(#T@)&YU;7)O=W,["B`@("`@("`@("`@
M("1T:&ES+3YA9F9E8W1E9"`](#`["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YA9F9E
M8W1E9"`](#`["B`@("`@("`@("`@(')E='5R;B!$0E]/2SL*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@
M("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!P9W-Q;"!R97-U;'0@
M<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@
M("`@("H@0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T
M=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R=VES92!R
M971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D
M<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@
M("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@
M9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R
M<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@
M("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O
M<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A
M;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U
M;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E
M9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S
M97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H@
M0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@87)R
M87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@("`@
M)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@
M:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@=&AE
M(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W
M:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@
M("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@
M0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O
M=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@)')E<W5L=%]I;G0@/2`H:6YT
M*21R97-U;'0["B`@("`@("`@)')O=VYU;2`]("@D<F]W;G5M("$]/2!N=6QL
M*2`_("1R;W=N=6T@.B`D=&AI<RT^<F]W6R1R97-U;'1?:6YT73L*("`@("`@
M("!I9B`H)')O=VYU;2`^/2`D=&AI<RT^7VYU;5]R;W=S6R1R97-U;'1?:6YT
M72D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@
M("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@
M("`@("`@("`@)&%R<B`]($!P9U]F971C:%]A<G)A>2@D<F5S=6QT+"`D<F]W
M;G5M+"!01U-13%]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12`F)B`D87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA
M;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!P9U]F971C
M:%]R;W<H)')E<W5L="P@)')O=VYU;2D["B`@("`@("`@?0H@("`@("`@(&EF
M("@A)&%R<BD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R
M=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E4
M65].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R
M=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YR;W=;)')E<W5L=%]I;G1=(#T@*RLD<F]W;G5M.PH@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E
M<W5L="!S970@86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE
M(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@
M;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R
M97-U;'0Z.F9R964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@
M(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P
M87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@
M)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U
M;'0Z.F9R964H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R
M97-U;'0I"B`@("!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1R97-U;'0I
M*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YR;W=;*&EN="DD<F5S=6QT
M72D["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?;G5M7W)O=W-;*&EN="DD
M<F5S=6QT72D["B`@("`@("`@("`@("1T:&ES+3YA9F9E8W1E9"`](#`["B`@
M("`@("`@("`@(')E='5R;B!`<&=?9G)E97)E<W5L="@D<F5S=6QT*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[('%U;W1E*"D*"B`@("`O*BH*("`@("`J($!D97!R96-A
M=&5D("!$97!R96-A=&5D(&EN(')E;&5A<V4@,2XV+C`*("`@("`J($!I;G1E
M<FYA;`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T92@D<W1R*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<75O=&53;6%R="@D<W1R*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T95-M87)T*"D*"B`@("`O*BH*
M("`@("`J($9O<FUA=',@:6YP=70@<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D
M(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&EN("!T
M:&4@9&%T82!T;R!B92!F;W)M871T960*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!T:&4@9F]R;6%T=&5D(&1A=&$N("!4:&4@9F]R;6%T(&1E<&5N
M9',@;VX@=&AE(&EN<'5T)W,*("`@("`J("`@("`@("`@("`@("`@("!02%`@
M='EP93H*("`@("`J("`@("`@("`@("`@("`@("`K(&YU;&P@/2!T:&4@<W1R
M:6YG(#QS86UP/DY53$P\+W-A;7`^"B`@("`@*B`@("`@("`@("`@("`@("`@
M*R!B;V]L96%N(#T@<W1R:6YG(#QS86UP/E12544\+W-A;7`^(&]R(#QS86UP
M/D9!3%-%/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`@("L@:6YT96=E
M<B!O<B!D;W5B;&4@/2!T:&4@=6YQ=6]T960@;G5M8F5R"B`@("`@*B`@("`@
M("`@("`@("`@("`@*R!O=&AE<B`H:6YC;'5D:6YG('-T<FEN9W,@86YD(&YU
M;65R:6,@<W1R:6YG<RD@/0H@("`@("H@("`@("`@("`@("`@("`@("`@=&AE
M(&1A=&$@97-C87!E9"!A8V-O<F1I;F<@=&\@37E344PG<R!S971T:6YG<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@=&AE;B!E;F-A<'-U;&%T960@8F5T
M=V5E;B!S:6YG;&4@<75O=&5S"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q
M=6]T95-M87)T*"1I;BD*("`@('L*("`@("`@("!I9B`H:7-?:6YT*"1I;BD@
M?'P@:7-?9&]U8FQE*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I;CL*
M("`@("`@("!](&5L<V5I9B`H:7-?8F]O;"@D:6XI*2!["B`@("`@("`@("`@
M(')E='5R;B`D:6X@/R`G5%)512<@.B`G1D%,4T4G.PH@("`@("`@('T@96QS
M96EF("AI<U]N=6QL*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("=.54Q,
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@(B<B("X@
M)'1H:7,M/F5S8V%P95-I;7!L92@D:6XI("X@(B<B.PH@("`@("`@('T*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<V-A<&53:6UP;&4H*0H*("`@
M("\J*@H@("`@("H@17-C87!E<R!A('-T<FEN9R!A8V-O<F1I;F<@=&\@=&AE
M(&-U<G)E;G0@1$)-4R=S('-T86YD87)D<PH@("`@("H*("`@("`J('M`:6YT
M97)N86P@4&]S=&=R95-13"!T<F5A=',@82!B86-K<VQA<V@@87,@86X@97-C
M87!E(&-H87)A8W1E<BP*("`@("`J('-O('1H97D@87)E(&5S8V%P960@87,@
M=V5L;"X*("`@("`J"B`@("`@*B!.;W0@=7-I;F<@<&=?97-C87!E7W-T<FEN
M9R@I('EE="!B96-A=7-E(&ET(')E<75I<F5S(%!O<W1G<F5344P*("`@("`J
M('1O(&)E(&%T('9E<G-I;VX@-RXR(&]R(&=R96%T97(N?7T*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S='(@('1H92!S=')I;F<@=&\@8F4@97-C
M87!E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@97-C87!E
M9"!S=')I;F<*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53
M;6%R="@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&5S8V%P95-I;7!L
M92@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@B)R(L
M("(G)R(L('-T<E]R97!L86-E*"=<7"<L("=<7%Q<)RP@)'-T<BDI.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@
M("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@
M<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O
M(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN
M=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T
M96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L
M="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R
M97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS
M*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`<&=?;G5M9FEE;&1S
M*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R
M(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S
M90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET(&-A
M;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"
M7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E
M<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@
M;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O
M=W,@/2!`<&=?;G5M<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H)')O=W,@
M/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YP9W-Q;%)A
M:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@
M("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M
M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T
M=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B
M:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N
M)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@
M("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I;VY?;W!C
M;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O(&ES<W5E
M(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@
M)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@("\J
M*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T
M:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@("\O("AD:7-A8FQE9"D@
M:&%C:R!T;R!S:'5T('5P(&5R<F]R(&UE<W-A9V5S(&9R;VT@;&EB<'$N80H@
M("`@("`@("`@("`O+T!F8VQO<V4H0&9O<&5N*")P:'`Z+R]S=&1E<G(B+"`B
M=R(I*3L*("`@("`@("`@("`@)')E<W5L="`]($!P9U]E>&5C*"1T:&ES+3YC
M;VYN96-T:6]N+"`G96YD.R<I.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A
M8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R
M;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH
M*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C
M=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@("`@("`@)')E
M<W5L="`]($!P9U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`G86)O<G0[)RD[
M"B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*
M("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G!G<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@
M("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@
M82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J(#`@:7,@
M<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L871E(&1A
M=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@
M<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YA9F9E8W1E9#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X
M="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E
M<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@
M=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*
M("`@("`J("`@("`@1$)?<&=S<6PZ.F-R96%T95-E<75E;F-E*"DL($1"7W!G
M<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT
M260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@
M("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I
M.PH@("`@("`@("1R97!E870@/2!F86QS93L*("`@("`@("!D;R!["B`@("`@
M("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD["B`@("`@("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y*")3
M14Q%0U0@3D585%9!3"@G)'MS97%N86UE?2<I(BD["B`@("`@("`@("`@("1T
M:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@(&EF("@D;VYD
M96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@)B8*("`@("`@("`@("`@
M("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U-50TA404),
M12D@>PH@("`@("`@("`@("`@("`@)')E<&5A="`]('1R=64["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A
M=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97!E
M870@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R
M97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D[
M"B`@("`@("`@?0H@("`@("`@("1A<G(@/2`D<F5S=6QT+3YF971C:%)O=RA$
M0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@)')E<W5L="T^9G)E92@I
M.PH@("`@("`@(')E='5R;B`D87)R6S!=.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&-R96%T95-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($-R
M96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E;F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E
M<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]P9W-Q;#HZ;F5X=$E$*"DL
M($1"7W!G<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@)'-E
M<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B0U)%051%(%-%455%3D-%
M("1[<V5Q;F%M97TB*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O
M(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+"!$
M0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]P
M9W-Q;#HZ;F5X=$E$*"DL($1"7W!G<W%L.CIC<F5A=&5397%U96YC92@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!315%514Y#
M12`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YG9713
M97%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!!
M9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D:6YG
M('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M;V1I9GD*("`@("`J
M($!P87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R="!T;R!F
M971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`<&%R86T@:6YT
M("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*("`@
M("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O<B!N
M=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N
M=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI
M;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD97(@
M<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C;&%U<V5S(&%D9&5D
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@
M9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U
M;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E='5R;B`B
M)'%U97)Y($Q)34E4("1C;W5N="!/1D93150@)&9R;VTB.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[('!G<W%L4F%I<V5%<G)O<B@I"@H@("`@+RHJ
M"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@
M=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@("`J($!P87)A;2!I;G0@
M)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D
M('!A<W,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("!$0E]%4E)/4BH@
M8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G871H
M97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J("`@("`@1$)?<&=S<6PZ
M.F5R<F]R3F%T:79E*"DL($1"7W!G<W%L.CIE<G)O<D-O9&4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!P9W-Q;%)A:7-E17)R;W(H)&5R<FYO(#T@;G5L;"D*
M("`@('L*("`@("`@("`D;F%T:79E(#T@)'1H:7,M/F5R<F]R3F%T:79E*"D[
M"B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D
M97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*"1N871I=F4I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL
M+"!N=6QL+"!N=6QL+"`D;F%T:79E*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H
M92!$0DU3)R!N871I=F4@97)R;W(@;65S<V%G92!P<F]D=6-E9"!B>2!T:&4@
M;&%S="!Q=65R>0H@("`@("H*("`@("`J('M`:6YT97)N86P@17)R;W(@;65S
M<V%G97,@87)E('5S960@:6YS=&5A9"!O9B!E<G)O<B!C;V1E<R`*("`@("`J
M(&EN(&]R9&5R('1O('-U<'!O<G0@;VQD97(@=F5R<VEO;G,@;V8@4&]S=&=R
M95-13"Y]?0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@1$)-
M4R<@97)R;W(@;65S<V%G90H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA
M=&EV92@I"B`@("!["B`@("`@("`@<F5T=7)N($!P9U]E<G)O<FUE<W-A9V4H
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(%!%
M05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!T:&4@9&%T86)A<V4G<R!T97AT(&5R
M<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@("1E
M<G)O<FUS9R`@97)R;W(@;65S<V%G92!R971U<FYE9"!F<F]M('1H92!D871A
M8F%S90H@("`@("H@0')E='5R;B!I;G1E9V5R("!A;B!E<G)O<B!N=6UB97(@
M9G)O;2!A($1"(&5R<F]R(&-O;G-T86YT"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5R<F]R0V]D92@D97)R;W)M<V<I"B`@("!["B`@("`@("`@<W1A=&EC("1E
M<G)O<E]R96=E>'!S.PH@("`@("`@(&EF("@A:7-S970H)&5R<F]R7W)E9V5X
M<',I*2!["B`@("`@("`@("`@("1E<G)O<E]R96=E>'!S(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`G+RAR96QA=&EO;GQS97%U96YC97QT86)L92DN*F1O
M97,@;F]T(&5X:7-T?&-L87-S("XJ(&YO="!F;W5N9"]I)PH@("`@("`@("`@
M("`@("`@("`@(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@("`@
M("`@("`@)R]I;F1E>"`N*B!D;V5S(&YO="!E>&ES="\G"B`@("`@("`@("`@
M("`@("`@("`@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@("`@("`@
M("`@)R]C;VQU;6X@+BH@9&]E<R!N;W0@97AI<W0O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@
M("`@("<O<F5L871I;VX@+BH@86QR96%D>2!E>&ES=',O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@
M("`@("`@("`@("<O*&1I=FED97QD:79I<VEO;BD@8GD@>F5R;R0O:2<*("`@
M("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]$259:15)/+`H@("`@("`@
M("`@("`@("`@)R]P9U]A=&]I.B!E<G)O<B!I;B`N*CH@8V%N7"=T('!A<G-E
M("]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?
M3E5-0D52+`H@("`@("`@("`@("`@("`@)R]I;G9A;&ED(&EN<'5T('-Y;G1A
M>"!F;W(H('1Y<&4I/R`H:6YT96=E<GQN=6UE<FEC*2]I)PH@("`@("`@("`@
M("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@
M("`@("`@("`@)R]V86QU92`N*B!I<R!O=70@;V8@<F%N9V4@9F]R('1Y<&4@
M7'<J:6YT+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?24Y6
M04Q)1%].54U"15(L"B`@("`@("`@("`@("`@("`G+VEN=&5G97(@;W5T(&]F
M(')A;F=E+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?24Y6
M04Q)1%].54U"15(L"B`@("`@("`@("`@("`@("`G+W9A;'5E('1O;R!L;VYG
M(&9O<B!T>7!E(&-H87)A8W1E<B]I)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27TE.5D%,240L"B`@("`@("`@("`@("`@("`G+V%T=')I8G5T
M92`N*B!N;W0@9F]U;F1\<F5L871I;VX@+BH@9&]E<R!N;W0@:&%V92!A='1R
M:6)U=&4O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-5
M0TA&245,1"P*("`@("`@("`@("`@("`@("<O8V]L=6UN("XJ('-P96-I9FEE
M9"!I;B!54TE.1R!C;&%U<V4@9&]E<R!N;W0@97AI<W0@:6X@*&QE9G1\<FEG
M:'0I('1A8FQE+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M3D]354-(1DE%3$0L"B`@("`@("`@("`@("`@("`G+W!A<G-E<CH@<&%R<V4@
M97)R;W(@870@;W(@;F5A<B]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"
M7T524D]27U-93E1!6"P*("`@("`@("`@("`@("`@("<O<WEN=&%X(&5R<F]R
M(&%T+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L
M"B`@("`@("`@("`@("`@("`G+V-O;'5M;B!R969E<F5N8V4@+BH@:7,@86UB
M:6=U;W5S+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.
M5$%8+`H@("`@("`@("`@("`@("`@)R]P97)M:7-S:6]N(&1E;FEE9"\G"B`@
M("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/
M3BP*("`@("`@("`@("`@("`@("<O=FEO;&%T97,@;F]T+6YU;&P@8V]N<W1R
M86EN="\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?0T].4U12
M04E.5%].3U1?3E5,3"P*("`@("`@("`@("`@("`@("<O=FEO;&%T97,@6UQW
M(%TK(&-O;G-T<F%I;G0O)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@("`@("`G+W)E9F5R96YT:6%L
M(&EN=&5G<FET>2!V:6]L871I;VXO)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@("`@("`G+VUO<F4@
M97AP<F5S<VEO;G,@=&AA;B!T87)G970@8V]L=6UN<R]I)PH@("`@("`@("`@
M("`@("`@("`@(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*("`@
M("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&5R<F]R
M7W)E9V5X<',@87,@)')E9V5X<"`]/B`D8V]D92D@>PH@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@D<F5G97AP+"`D97)R;W)M<V<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)&-O9&4["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@+R\@1F%L;"!B86-K('1O($1"7T524D]2(&EF('1H97)E('=A
M<R!N;R!M87!P:6YG+@H@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J($Y/5$4Z(&]N;'D@<W5P<&]R=',@
M)W1A8FQE)R!A;F0@)V9L86=S)R!I9B`\=F%R/B1R97-U;'0\+W9A<CX*("`@
M("`J(&ES(&$@=&%B;&4@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@
M<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!7:&EL92!T
M:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R
M+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`@
M("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y
M('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@
M("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@
M("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@
M82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@
M<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@
M("`@("1I9"`]($!P9U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`B4T5,14-4
M("H@1E)/32`D<F5S=6QT($Q)34E4(#`B*3L*("`@("`@("`@("`@)&=O=%]S
M=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT
M+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R
M;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@
M("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@
M("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U
M;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B
M;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@
M("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@("H@1&5P<F5C871E
M9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@
M("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G
M;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES
M7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YP
M9W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET
M>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@
M("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*
M"B`@("`@("`@)&-O=6YT(#T@0'!G7VYU;69I96QD<R@D:60I.PH@("`@("`@
M("1R97,@("`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D;6]D92D@>PH@("`@
M("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@
M?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*
M("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("=T86)L92<@/3X@)&=O=%]S=')I;F<@/R`D8V%S95]F=6YC*"1R97-U;'0I
M(#H@)R<L"B`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1C87-E7V9U;F,H
M0'!G7V9I96QD;F%M92@D:60L("1I*2DL"B`@("`@("`@("`@("`@("`G='EP
M92<@(#T^($!P9U]F:65L9'1Y<&4H)&ED+"`D:2DL"B`@("`@("`@("`@("`@
M("`G;&5N)R`@(#T^($!P9U]F:65L9'-I>F4H)&ED+"`D:2DL"B`@("`@("`@
M("`@("`@("`G9FQA9W,G(#T^("1G;W1?<W1R:6YG"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#\@)'1H:7,M/E]P9T9I96QD1FQA9W,H)&ED+"`D:2P@
M)')E<W5L="D*("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`G)RP*("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)
M3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R
M97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"3$4I('L*("`@
M("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B
M;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@
M=V4@=V5R92!C86QL960@;VX@82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T
M<FEN9RD@>PH@("`@("`@("`@("!`<&=?9G)E97)E<W5L="@D:60I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!?<&=&:65L9$9L86=S*"D*"B`@("`O*BH*("`@("`J($=E
M="!A(&-O;'5M;B=S(&9L86=S"B`@("`@*@H@("`@("H@4W5P<&]R=',@(FYO
M=%]N=6QL(BP@(F1E9F%U;'1?=F%L=64B+"`B<')I;6%R>5]K97DB+"`B=6YI
M<75E7VME>2(*("`@("`J(&%N9"`B;75L=&EP;&5?:V5Y(BX@(%1H92!D969A
M=6QT('9A;'5E(&ES('!A<W-E9"!T:')O=6=H"B`@("`@*B!R87=U<FQE;F-O
M9&4H*2!I;B!C87-E('1H97)E(&%R92!S<&%C97,@:6X@:70N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN="`D<F5S;W5R8V4@("!T:&4@4&]S=&=R95-13"!R
M97-U;'0@:61E;G1I9FEE<@H@("`@("H@0'!A<F%M(&EN="`D;G5M7V9I96QD
M("!T:&4@9FEE;&0@;G5M8F5R"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!F;&%G<PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<&=&:65L9$9L86=S*"1R97-O=7)C92P@
M)&YU;5]F:65L9"P@)'1A8FQE7VYA;64I"B`@("!["B`@("`@("`@)&9I96QD
M7VYA;64@/2!`<&=?9FEE;&1N86UE*"1R97-O=7)C92P@)&YU;5]F:65L9"D[
M"@H@("`@("`@("1R97-U;'0@/2!`<&=?97AE8R@D=&AI<RT^8V]N;F5C=&EO
M;BP@(E-%3$5#5"!F+F%T=&YO=&YU;&PL(&8N871T:&%S9&5F"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@1E)/32!P9U]A='1R:6)U=&4@9BP@
M<&=?8VQA<W,@=&%B+"!P9U]T>7!E('1Y<`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%=(15)%('1A8BYR96QN86UE(#T@='EP+G1Y<&YA;64*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!3D0@='EP+G1Y<')E
M;&ED(#T@9BYA='1R96QI9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($%.1"!F+F%T=&YA;64@/2`G)&9I96QD7VYA;64G"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@04Y$('1A8BYR96QN86UE(#T@)R1T86)L
M95]N86UE)R(I.PH@("`@("`@(&EF("A`<&=?;G5M<F]W<R@D<F5S=6QT*2`^
M(#`I('L*("`@("`@("`@("`@)')O=R`]($!P9U]F971C:%]R;W<H)')E<W5L
M="P@,"D["B`@("`@("`@("`@("1F;&%G<R`@/2`H)')O=ULP72`]/2`G="<I
M(#\@)VYO=%]N=6QL("<@.B`G)SL*"B`@("`@("`@("`@(&EF("@D<F]W6S%=
M(#T]("=T)RD@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]($!P9U]E>&5C
M*"1T:&ES+3YC;VYN96-T:6]N+"`B4T5,14-4(&$N861S<F,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1E)/32!P9U]A='1R:6)U=&4@
M9BP@<&=?8VQA<W,@=&%B+"!P9U]T>7!E('1Y<"P@<&=?871T<F1E9B!A"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('1A8BYR
M96QN86UE(#T@='EP+G1Y<&YA;64@04Y$('1Y<"YT>7!R96QI9"`](&8N871T
M<F5L:60*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$
M(&8N871T<F5L:60@/2!A+F%D<F5L:60@04Y$(&8N871T;F%M92`]("<D9FEE
M;&1?;F%M92<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M04Y$('1A8BYR96QN86UE(#T@)R1T86)L95]N86UE)R!!3D0@9BYA='1N=6T@
M/2!A+F%D;G5M(BD["B`@("`@("`@("`@("`@("`D<F]W(#T@0'!G7V9E=&-H
M7W)O=R@D<F5S=6QT+"`P*3L*("`@("`@("`@("`@("`@("1N=6T@/2!P<F5G
M7W)E<&QA8V4H(B\G*"XJ*2<Z.EQW*R\B+"`B7%PQ(BP@)')O=ULP72D["B`@
M("`@("`@("`@("`@("`D9FQA9W,@+CT@)V1E9F%U;'1?)R`N(')A=W5R;&5N
M8V]D92@D;G5M*2`N("<@)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F;&%G<R`]("<G.PH@("`@("`@('T*("`@("`@
M("`D<F5S=6QT(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL(")314Q%
M0U0@:2YI;F1I<W5N:7%U92P@:2YI;F1I<W!R:6UA<GDL(&DN:6YD:V5Y"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1E)/32!P9U]A='1R:6)U
M=&4@9BP@<&=?8VQA<W,@=&%B+"!P9U]T>7!E('1Y<"P@<&=?:6YD97@@:0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('1A8BYR96QN
M86UE(#T@='EP+G1Y<&YA;64*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!!3D0@='EP+G1Y<')E;&ED(#T@9BYA='1R96QI9`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($%.1"!F+F%T=')E;&ED(#T@:2YI;F1R
M96QI9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!F+F%T
M=&YA;64@/2`G)&9I96QD7VYA;64G"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@04Y$('1A8BYR96QN86UE(#T@)R1T86)L95]N86UE)R(I.PH@
M("`@("`@("1C;W5N="`]($!P9U]N=6UR;W=S*"1R97-U;'0I.PH*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0@.R`D:2LK*2!["B`@("`@("`@
M("`@("1R;W<@/2!`<&=?9F5T8VA?<F]W*"1R97-U;'0L("1I*3L*("`@("`@
M("`@("`@)&ME>7,@/2!E>'!L;V1E*"<@)RP@)')O=ULR72D["@H@("`@("`@
M("`@("!I9B`H:6Y?87)R87DH)&YU;5]F:65L9"`K(#$L("1K97ES*2D@>PH@
M("`@("`@("`@("`@("`@)&9L86=S("X]("@D<F]W6S!=(#T]("=T)R`F)B`D
M<F]W6S%=(#T]("=F)RD@/R`G=6YI<75E7VME>2`G(#H@)R<["B`@("`@("`@
M("`@("`@("`D9FQA9W,@+CT@*"1R;W=;,5T@/3T@)W0G*2`_("=P<FEM87)Y
M7VME>2`G(#H@)R<["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&ME>7,I
M(#X@,2D*("`@("`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)VUU;'1I<&QE
M7VME>2`G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')I;2@D9FQA9W,I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H
M92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP
M92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T
M<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@("H@("`@
M("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R97%U97-T
M960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@
M*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@
M("`@("`@("!R971U<FX@)U-%3$5#5"!C+G)E;&YA;64@05,@(DYA;64B)PH@
M("`@("`@("`@("`@("`@("`@("`@("`N("<@1E)/32!P9U]C;&%S<R!C+"!P
M9U]U<V5R('4G"B`@("`@("`@("`@("`@("`@("`@("`@("X@)R!72$5212!C
M+G)E;&]W;F5R(#T@=2YU<V5S>7-I9"<*("`@("`@("`@("`@("`@("`@("`@
M("`@+B`B($%.1"!C+G)E;&MI;F0@/2`G<B<B"B`@("`@("`@("`@("`@("`@
M("`@("`@("X@)R!!3D0@3D]4($5825-44R<*("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G("A314Q%0U0@,2!&4D]-('!G7W9I97=S)PH@("`@("`@("`@
M("`@("`@("`@("`@("`N("<@(%=(15)%('9I97=N86UE(#T@8RYR96QN86UE
M*2<*("`@("`@("`@("`@("`@("`@("`@("`@+B`B($%.1"!C+G)E;&YA;64@
M(7X@)UXH<&=??'-Q;%\I)R(*("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M(%5.24].)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@4T5,14-4(&,N
M<F5L;F%M92!!4R`B3F%M92(G"B`@("`@("`@("`@("`@("`@("`@("`@("X@
M)R!&4D]-('!G7V-L87-S(&,G"B`@("`@("`@("`@("`@("`@("`@("`@("X@
M(B!72$5212!C+G)E;&MI;F0@/2`G<B<B"B`@("`@("`@("`@("`@("`@("`@
M("`@("X@)R!!3D0@3D]4($5825-44R<*("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G("A314Q%0U0@,2!&4D]-('!G7W9I97=S)PH@("`@("`@("`@("`@
M("`@("`@("`@("`N("<@(%=(15)%('9I97=N86UE(#T@8RYR96QN86UE*2<*
M("`@("`@("`@("`@("`@("`@("`@("`@+B`G($%.1"!.3U0@15A)4U13)PH@
M("`@("`@("`@("`@("`@("`@("`@("`N("<@*%-%3$5#5"`Q($923TT@<&=?
M=7-E<B<*("`@("`@("`@("`@("`@("`@("`@("`@+B`G("!72$5212!U<V5S
M>7-I9"`](&,N<F5L;W=N97(I)PH@("`@("`@("`@("`@("`@("`@("`@("`N
M("(@04Y$(&,N<F5L;F%M92`A?B`G7G!G7R<B.PH@("`@("`@("`@("!C87-E
M("=S8VAE;6$N=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`B4T5,
M14-4('-C:&5M86YA;64@?'P@)RXG('Q\('1A8FQE;F%M92(*("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G($%3(").86UE(B<*("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G($923TT@<&=?8V%T86QO9RYP9U]T86)L97,G"B`@("`@
M("`@("`@("`@("`@("`@("`@("X@)R!72$5212!S8VAE;6%N86UE($Y/5"!)
M3B<*("`@("`@("`@("`@("`@("`@("`@("`@+B`B("@G<&=?8V%T86QO9R<L
M("=I;F9O<FUA=&EO;E]S8VAE;6$G+"`G<&=?=&]A<W0G*2(["B`@("`@("`@
M("`@(&-A<V4@)W9I97=S)SH*("`@("`@("`@("`@("`@("\O(%1A8FQE(&-O
M;',Z('9I97=N86UE('P@=FEE=V]W;F5R('P@9&5F:6YI=&EO;@H@("`@("`@
M("`@("`@("`@<F5T=7)N("=314Q%0U0@=FEE=VYA;64@9G)O;2!P9U]V:65W
M<R!72$5212!S8VAE;6%N86UE)PH@("`@("`@("`@("`@("`@("`@("`@("`N
M("(@3D]4($E.("@G:6YF;W)M871I;VY?<V-H96UA)RP@)W!G7V-A=&%L;V<G
M*2(["B`@("`@("`@("`@(&-A<V4@)W5S97)S)SH*("`@("`@("`@("`@("`@
M("\O(&-O;',Z('5S96YA;64@?'5S97-Y<VED?'5S96-R96%T961B?'5S971R
M86-E?'5S97-U<&5R?'5S96-A='5P9'QP87-S=V0@('QV86QU;G1I;`H@("`@
M("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@=7-E;F%M92!&4D]-('!G7W5S
M97(G.PH@("`@("`@("`@("!C87-E("=D871A8F%S97,G.@H@("`@("`@("`@
M("`@("`@<F5T=7)N("=314Q%0U0@9&%T;F%M92!&4D]-('!G7V1A=&%B87-E
M)SL*("`@("`@("`@("`@8V%S92`G9G5N8W1I;VYS)SH*("`@("`@("`@("`@
M8V%S92`G<')O8V5D=7)E<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%
M3$5#5"!P<F]N86UE($923TT@<&=?<')O8R!72$5212!P<F]O=VYE<B`\/B`Q
M)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*"GT*"B\J"B`J
M($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M
M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O1$(O<WEB87-E+G!H<```````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-C8T,#,`,3`U,34T,S$P-3<`,#$W-C,V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R:79E
M<B!F;W(@4$A0)W,@<WEB87-E(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I
M;F<@=VET:"!3>6)A<V4@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C
M:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&5R;&EN9R!(=6=H97,@/'-T
M97)L:6YG0'!H<"YN970^"B`J($!A=71H;W(@("`@($%N=/1N:6\@0V%R;&]S
M(%9E;N)N8VEO($KZ;FEO<B`\9FQO<FEP84!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<WEB87-E+G!H
M<"QV(#$N-S@@,C`P-2\P,B\R,"`P,#HT-#HT."!D86YI96QC($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@
M*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C
M86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM
M;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@
M:6YT97)A8W0@=VET:"!02%`G<R!S>6)A<V4@97AT96YS:6]N"B`J(&9O<B!I
M;G1E<F%C=&EN9R!W:71H(%-Y8F%S92!D871A8F%S97,*("H*("H@5&AE<V4@
M;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM
M;VXN"B`J"B`J(%=!4DY)3D<Z("!4:&ES(&1R:79E<B!M87D@9F%I;"!W:71H
M(&UU;'1I<&QE(&-O;FYE8W1I;VYS('5N9&5R('1H90H@*B!S86UE('5S97(O
M<&%S<R]H;W-T(&%N9"!D:69F97)E;G0@9&%T86)A<V5S+@H@*@H@*B!`8V%T
M96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R
M("`@("!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H<"YN970^"B`J($!A
M=71H;W(@("`@($%N=/1N:6\@0V%R;&]S(%9E;N)N8VEO($KZ;FEO<B`\9FQO
M<FEP84!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4
M:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7W-Y8F%S92!E>'1E
M;F1S($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J
M*@H@("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B
M8RP@971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M<&AP='EP92`]("=S>6)A<V4G.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B
M87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E
M=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)&1B<WEN=&%X(#T@)W-Y8F%S92<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J
M"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!0
M2%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN
M:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I
M="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE
M("=L:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L
M871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E
M<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]
M('-K:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@
M("`@("`]/B`G96UU;&%T92<L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("=N=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@("`@
M("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@("`@("`@("=P<F5P87)E
M)R`@("`@("`]/B!F86QS92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^('1R=64L"B`@("`I
M.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV92!E<G)O<B!C
M;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E
M871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@
M=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O
M<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@
M("`@+RHJ"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE
M<R!B92!C;VUM:71T960@875T;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O
M;`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D875T
M;V-O;6UI="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@<75A;G1I='D@
M;V8@=')A;G-A8W1I;VYS(&)E9W5N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA
M;"`@5VAI;&4@=&AI<R!I<R!P<FEV871E+"!I="!C86XG="!A8W1U86QL>2!B
M92!D97-I9VYA=&5D"B`@("`@*B!P<FEV871E(&EN(%!(4"`U(&)E8V%U<V4@
M:70@:7,@9&ER96-T;'D@86-C97-S960@:6X@=&AE('1E<W0@<W5I=&4N?7T*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)'1R86YS86-T:6]N7V]P8V]U;G0@/2`P
M.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-P96-I9FEE9"!I;B!T
M:&4@1%-."B`@("`@*@H@("`@("H@270G<R!A(&9I>"!T;R!A;&QO=R!C86QL
M<R!T;R!D:69F97)E;G0@9&%T86)A<V5S(&EN('1H92!S86UE('-C<FEP="X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7V1B(#T@)R<["@H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O
M;G-T<G5C=&]R(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^
M"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T
M:6]N($1"7W-Y8F%S92@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO
M;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*
M("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R
M+"!L;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@
M1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N
M;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@4$5!4B!$0B=S('-Y8F%S
M92!D<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T
M:6]N<SH*("`@("`J("`@*R!A<'!N86UE("`@("`@(%1H92!A<'!L:6-A=&EO
M;B!N86UE('1O('5S92!O;B!T:&ES(&-O;FYE8W1I;VXN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C<N,"X*
M("`@("`J("`@*R!C:&%R<V5T("`@("`@(%1H92!C:&%R86-T97(@<V5T('1O
M('5S92!O;B!T:&ES(&-O;FYE8W1I;VXN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C<N,"X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C
M92!N86UE"B`@("`@*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L
M9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T
M*"1D<VXL("1P97)S:7-T96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@
M*"%014%2.CIL;V%D17AT96YS:6]N*"=S>6)A<V4G*2`F)@H@("`@("`@("`@
M("`A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G<WEB87-E7V-T)RDI"B`@("`@("`@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G
M72D@>PH@("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y
M;G1A>"==.PH@("`@("`@('T*"B`@("`@("`@)&1S;ELG:&]S='-P96,G72`]
M("1D<VY;)VAO<W1S<&5C)UT@/R`D9'-N6R=H;W-T<W!E8R==(#H@)VQO8V%L
M:&]S="<["B`@("`@("`@)&1S;ELG<&%S<W=O<F0G72`]("%E;7!T>2@D9'-N
M6R=P87-S=V]R9"==*2`_("1D<VY;)W!A<W-W;W)D)UT@.B!F86QS93L*("`@
M("`@("`D9'-N6R=C:&%R<V5T)UT@/2!I<W-E="@D9'-N6R=C:&%R<V5T)UTI
M(#\@)&1S;ELG8VAA<G-E="==(#H@9F%L<V4["B`@("`@("`@)&1S;ELG87!P
M;F%M92==(#T@:7-S970H)&1S;ELG87!P;F%M92==*2`_("1D<VY;)V%P<&YA
M;64G72`Z(&9A;'-E.PH*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P
M97)S:7-T96YT(#\@)W-Y8F%S95]P8V]N;F5C="<@.B`G<WEB87-E7V-O;FYE
M8W0G.PH*("`@("`@("!I9B`H)&1S;ELG=7-E<FYA;64G72D@>PH@("`@("`@
M("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D
M9'-N6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9'-N6R=U<V5R;F%M92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9'-N6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9'-N6R=C:&%R<V5T)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D<VY;)V%P<&YA;64G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%
M0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=4:&4@1%-.(&1I9"!N;W0@8V]N=&%I;B!A('5S97)N
M86UE+B<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C
M=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@0'-Y8F%S95]G971?;&%S=%]M
M97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1D<VY;)V1A=&%B
M87-E)UTI('L*("`@("`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D
M9'-N6R=D871A8F%S92==+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].
M3T1"4T5,14-4140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!`<WEB87-E7V=E=%]L87-T7VUE<W-A
M9V4H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]D8B`]
M("1D<VY;)V1A=&%B87-E)UT["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C
M="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D871A
M8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@
M;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC
M=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0'-Y8F%S
M95]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O
M;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*
M("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H92!344P@<75E<GD@<W1R
M:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U
M;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@
M("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O
M=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@
M("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@("!F
M=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)&ES
M;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES+3YL
M87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@(&EF("@A0'-Y8F%S95]S96QE
M8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<BA$0E]%4E)/
M4E].3T1"4T5,14-4140I.PH@("`@("`@('T*("`@("`@("`D<75E<GD@/2`D
M=&AI<RT^;6]D:69Y475E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H(21T:&ES
M+3YA=71O8V]M;6ET("8F("1I<VUA;FEP*2!["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@0'-Y8F%S95]Q=65R>2@G0D5'24X@5%)!3E-!0U1)
M3TXG+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G-Y8F%S95)A:7-E17)R;W(H*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N
M="LK.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@0'-Y8F%S95]Q=65R
M>2@D<75E<GDL("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES
M945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]R97-O=7)C92@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U97)I97,@=&AA="!S
M:&]U;&0@<F5T=7)N(&1A=&$L(&%N9"!W:&EC:`H@("`@("`@("\O('-H;W5L
M9"!R971U<FX@86X@97)R;W(@8V]D92!O;FQY+@H@("`@("`@(')E='5R;B`D
M:7-M86YI<"`_($1"7T]+(#H@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@
M=&AE(&EN=&5R;F%L('-Y8F%S92!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X
M="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L
M:60@<WEB87-E(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S
M=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F
M<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@
M*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@
M=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L
M=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D
M:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I
M;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@
M("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H92!Q
M=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@("`D
M87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@9&%T
M82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H
M92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P
M87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E
M=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F(&$@
M<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@("`@(')E86-H960@
M;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF
M971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E
M<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@
M(&EF("@A0'-Y8F%S95]D871A7W-E96LH)')E<W5L="P@)')O=VYU;2DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%
M7T%34T]#*2!["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)W-Y
M8F%S95]F971C:%]A<W-O8R<I*2!["B`@("`@("`@("`@("`@("`D87)R(#T@
M0'-Y8F%S95]F971C:%]A<W-O8R@D<F5S=6QT*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&EF("@D87)R(#T@0'-Y8F%S95]F971C
M:%]A<G)A>2@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1A<G(@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7VEN="@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=6YS970H)&%R<ELD:V5Y72D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#
M05-%("8F("1A<G(I('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C
M:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0'-Y8F%S
M95]F971C:%]R;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A
M)&%R<BD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@
M("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?
M4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R=')I
M;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].
M54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU
M;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F
M<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L
M="!S970@86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E
M<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A
M;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U
M;'0Z.F9R964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R
M;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A
M=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S
M=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E
M<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z
M.F9R964H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U
M;'0I"B`@("!["B`@("`@("`@<F5T=7)N($!S>6)A<V5?9G)E95]R97-U;'0H
M)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L
M<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@8V]L=6UN
M<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I
M<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@
M*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@
M9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT
M(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R
M97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU
M;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@("`D8V]L<R`]
M($!S>6)A<V5?;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C
M;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%
M<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@
M("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@
M8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O
M=W,H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E
M9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!0
M2%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ
M;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L
M="D*("`@('L*("`@("`@("`D<F]W<R`]($!S>6)A<V5?;G5M7W)O=W,H)')E
M<W5L="D["B`@("`@("`@:68@*"1R;W=S(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E
M<FUI;F5S('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@
M;6%N:75P;&%T:6]N('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE
M9"!F;W(@<75E<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@869F96-T9612;W=S*"D*("`@('L*("`@("`@("!I9B`H1$(Z.FES
M36%N:7`H)'1H:7,M/FQA<W1?<75E<GDI*2!["B`@("`@("`@("`@("1R97-U
M;'0@/2!`<WEB87-E7V%F9F5C=&5D7W)O=W,H)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2`P.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S
M97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N
M('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N
M;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@
M:60@;G5M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J("`@("`@("`@("`@
M("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q
M=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7W-Y8F%S93HZ8W)E871E4V5Q
M=65N8V4H*2P@1$)?<WEB87-E.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E
M*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E
M3F%M92@D<V5Q7VYA;64I.PH@("`@("`@(&EF("@A0'-Y8F%S95]S96QE8W1?
M9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].
M3T1"4T5,14-4140I.PH@("`@("`@('T*("`@("`@("`D<F5P96%T(#T@,#L*
M("`@("`@("!D;R!["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^<75E<GDH(DE.4T525"!)3E1/("1S97%N86UE("AV87!O<BD@
M5D%,5453("@P*2(I.PH@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD
M;&EN9R@I.PH@("`@("`@("`@("!I9B`H)&]N9&5M86YD("8F($1".CII<T5R
M<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@("`H)')E<W5L="T^9V5T
M0V]D92@I(#T]($1"7T524D]2('Q\("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$
M0E]%4E)/4E].3U-50TA404),12DI"B`@("`@("`@("`@('L*("`@("`@("`@
M("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@
M("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H(41".CII
M<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#TF
M("1T:&ES+3YQ=65R>2@B4T5,14-4($!`241%3E1)5%D@1E)/32`D<V5Q;F%M
M92(I.PH@("`@("`@("`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T*3L*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@('T*("`@
M("`@("`D<F5S=6QT(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%
M7T]21$52140I.PH@("`@("`@(')E='5R;B`D<F5S=6QT6S!=.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!N
M97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL
M($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"
M7W-Y8F%S93HZ;F5X=$E$*"DL($1"7W-Y8F%S93HZ9')O<%-E<75E;F-E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N86UE
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T-214%412!4
M04),12`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YG
M971397%U96YC94YA;64H)'-E<5]N86UE*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G("AI9"!N=6UE<FEC*#$P+"`P*2!)1$5.5$E462!.3U0@
M3E5,3"PG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@=F%P;W(@
M:6YT($Y53$PI)RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O
M<%-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!S97%U96YC
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE
M(&]F('1H92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CID<F]P4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H
M*2P*("`@("`J("`@("`@1$)?<WEB87-E.CIN97AT240H*2P@1$)?<WEB87-E
M.CIC<F5A=&5397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!3
M97%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YQ=65R>2@G1%)/4"!404),12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M
M92@D<V5Q7VYA;64I*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A
M=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES86)L
M97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL(&9A;'-E('1U<FYS(&ET(&]F
M9@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S
M+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E<@H@("`@("H@("`@
M("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@875T;RUC;VUM:71T:6YG('1R
M86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O;6UI="@D
M;VYO9F8@/2!F86QS92D*("`@('L*("`@("`@("`O+R!86%@@:68@)'1H:7,M
M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P+"!W92!S:&]U;&0@<')O8F%B;'D*
M("`@("`@("`O+R!I<W-U92!A('=A<FYI;F<@:&5R92X*("`@("`@("`D=&AI
M<RT^875T;V-O;6UI="`]("1O;F]F9B`_('1R=64@.B!F86QS93L*("`@("`@
M("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M8V]M;6ET*"D*"B`@("`O*BH*("`@("`J($-O;6UI=',@=&AE(&-U<G)E;G0@
M=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@
M("!I9B`H(4!S>6)A<V5?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC
M;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS
M>6)A<V5286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`]($!S>6)A<V5?<75E<GDH
M)T-/34U)5"<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB
M87-E4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2979E<G1S('1H92!C=7)R
M96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"
M7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@
M("`@("`@("!I9B`H(4!S>6)A<V5?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T
M:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS>6)A<V5286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`]($!S>6)A<V5?
M<75E<GDH)U)/3$Q"04-+)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@
M("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS>6)A<V5286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('-Y8F%S95)A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@
M4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D:6YG('1H92!C=7)R
M96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1E<G)N;R`@
M:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)23U(J(&-O;G-T86YT
M(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@9V%T:&5R960@9G)O
M;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE
M($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7W-Y8F%S93HZ97)R;W).
M871I=F4H*2P@1$)?<WEB87-E.CIE<G)O<D-O9&4H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!S>6)A<V5286ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@("![
M"B`@("`@("`@)&YA=&EV92`]("1T:&ES+3YE<G)O<DYA=&EV92@I.PH@("`@
M("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R<FYO
M(#T@)'1H:7,M/F5R<F]R0V]D92@D;F%T:79E*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L
M;"P@;G5L;"P@)&YA=&EV92D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@1$)-
M4R<@;F%T:79E(&5R<F]R(&UE<W-A9V4@<')O9'5C960@8GD@=&AE(&QA<W0@
M<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE($1"35,G
M(&5R<F]R(&UE<W-A9V4*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I
M=F4H*0H@("`@>PH@("`@("`@(')E='5R;B!`<WEB87-E7V=E=%]L87-T7VUE
M<W-A9V4H*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<D-O
M9&4H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!014%2.CI$0B!E<G)O
M<B!C;V1E(&9R;VT@=&AE(&1A=&%B87-E)W,@=&5X="!E<G)O<B!M97-S86=E
M+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D97)R;W)M<V<@(&5R
M<F]R(&UE<W-A9V4@<F5T=7)N960@9G)O;2!T:&4@9&%T86)A<V4*("`@("`J
M($!R971U<FX@:6YT96=E<B`@86X@97)R;W(@;G5M8F5R(&9R;VT@82!$0B!E
M<G)O<B!C;VYS=&%N=`H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<D-O9&4H
M)&5R<F]R;7-G*0H@("`@>PH@("`@("`@('-T871I8R`D97)R;W)?<F5G97AP
M<SL*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<E]R96=E>'!S*2D@>PH@("`@
M("`@("`@("`D97)R;W)?<F5G97AP<R`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)R]);F-O<G)E8W0@<WEN=&%X(&YE87(O)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`@("`@("`@("<O7E5N
M8VQO<V5D('%U;W1E(&)E9F]R92!T:&4@8VAA<F%C=&5R('-T<FEN9R!;7")<
M)UTN*EM<(EPG75PN+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/
M4E]364Y405@L"B`@("`@("`@("`@("`@("`G+TEM<&QI8VET(&-O;G9E<G-I
M;VX@*&9R;VT@9&%T871Y<&5\;V8@3E5-15))0R!V86QU92DO:2<*("`@("`@
M("`@("`@("`@("`@("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@
M("`@("`@("`@("`@("<O0V%N;F]T(&1R;W`@=&AE('1A8FQE(%M<(EPG72XK
M6UPB7"==+"!B96-A=7-E(&ET(&1O97-N7"=T(&5X:7-T(&EN('1H92!S>7-T
M96T@8V%T86QO9W-<+B\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`G+T]N;'D@=&AE(&]W
M;F5R(&]F(&]B:F5C="!;7")<)UTN*UM<(EPG72!O<B!A('5S97(@=VET:"!3
M>7-T96T@061M:6YI<W1R871O<B!<*%-!7"D@<F]L92!C86X@<G5N('1H:7,@
M8V]M;6%N9%PN+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]!
M0T-%4U-?5DE/3$%424].+`H@("`@("`@("`@("`@("`@)R]>+BL@<&5R;6ES
M<VEO;B!D96YI960@;VX@;V)J96-T("XK+"!D871A8F%S92`N*RP@;W=N97(@
M+BLO)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]6
M24],051)3TXL"B`@("`@("`@("`@("`@("`G+UXN*B!P97)M:7-S:6]N(&1E
M;FEE9"P@9&%T86)A<V4@+BLL(&]W;F5R("XK+R<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@("`@
M("`@("`@)R];7BXJ72!N;W0@9F]U;F1<+B\G"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`G
M+U1H97)E(&ES(&%L<F5A9'D@86X@;V)J96-T(&YA;65D+R<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@
M("`@("`@("`@("<O26YV86QI9"!C;VQU;6X@;F%M92\G"B`@("`@("`@("`@
M("`@("`@("`@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@("`@
M("`@("`G+V1O97,@;F]T(&%L;&]W(&YU;&P@=F%L=65S+R<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@
M("`@("`@("`@("`@("`@)R]#;VUM86YD(&AA<R!B965N(&%B;W)T960O)PH@
M("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@
M("`@("`@("`@("`@("`G+UY#86YN;W0@9')O<"!T:&4@:6YD97@@+BH@8F5C
M875S92!I="!D;V5S;EPG="!E>&ES="]I)PH@("`@("`@("`@("`@("`@("`@
M(#T^($1"7T524D]27TY/5%]&3U5.1"P*("`@("`@("`@("`@("`@("<O7E1H
M97)E(&ES(&%L<F5A9'D@86X@:6YD97@O:2<*("`@("`@("`@("`@("`@("`@
M("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@("`@("`@
M("<O7E1H97)E(&%R92!F97=E<B!C;VQU;6YS(&EN('1H92!)3E-%4E0@<W1A
M=&5M96YT('1H86X@=F%L=65S('-P96-I9FEE9"]I)PH@("`@("`@("`@("`@
M("`@("`@(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*("`@("`@
M("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1E<G)O<E]R
M96=E>'!S(&%S("1R96=E>'`@/3X@)&-O9&4I('L*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)')E9V5X<"P@)&5R<F]R;7-G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1C;V1E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I
M;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT('-E=`H@("`@
M("H*("`@("`J($Y/5$4Z(&]N;'D@<W5P<&]R=',@)W1A8FQE)R!A;F0@)V9L
M86=S)R!I9B`\=F%R/B1R97-U;'0\+W9A<CX*("`@("`J(&ES(&$@=&%B;&4@
M;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E
M<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N
M=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T
M<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E
M<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@
M("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R
M;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@
M+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N
M86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@
M:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@(&EF("@A
M0'-Y8F%S95]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I
M;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A
M:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:60@/2!`<WEB87-E7W%U97)Y*")314Q%0U0@*B!&
M4D]-("1R97-U;'0@5TA%4D4@,3TP(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G
M;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E
M<W5L="T^<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@
M*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@
M("`@("`J($5X=')A8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R
M+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^
M<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R
M;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N
M"B`@("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')E
M8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@
M("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<U]R97-O=7)C92@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<WEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A
M8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@
M("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@
M("`@?0H*("`@("`@("`D8V]U;G0@/2!`<WEB87-E7VYU;5]F:65L9',H)&ED
M*3L*("`@("`@("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO
M9&4I('L*("`@("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT
M.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT
M.R`D:2LK*2!["B`@("`@("`@("`@("1F(#T@0'-Y8F%S95]F971C:%]F:65L
M9"@D:60L("1I*3L*("`@("`@("`@("`@+R\@8V]L=6UN7W-O=7)C92!I<R!O
M9G1E;B!B;&%N:PH@("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)W1A8FQE)R`]/B`D9V]T7W-T<FEN9PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`_("1C87-E7V9U;F,H)')E<W5L="D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`D8V%S95]F=6YC*"1F+3YC;VQU;6Y?
M<V]U<F-E*2P*("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N
M8R@D9BT^;F%M92DL"B`@("`@("`@("`@("`@("`G='EP92<@(#T^("1F+3YT
M>7!E+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]/B`D9BT^;6%X7VQE;F=T
M:"P*("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@("`@
M("D["B`@("`@("`@("`@(&EF("@D<F5S6R1I75LG=&%B;&4G72D@>PH@("`@
M("`@("`@("`@("`@)')E<ULD:5U;)V9L86=S)UT@/2`D=&AI<RT^7W-Y8F%S
M95]F:65L9%]F;&%G<R@*("`@("`@("`@("`@("`@("`@("`@("`@)')E<ULD
M:5U;)W1A8FQE)UTL("1R97-;)&E=6R=N86UE)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@
M>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M
M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D;6]D
M92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@
M("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;
M)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E<F4@8V%L
M;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I('L*("`@
M("`@("`@("`@0'-Y8F%S95]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!?<WEB87-E7V9I96QD7V9L86=S*"D*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@9FQA9W,@9F]R(&$@9FEE;&0*("`@("`J"B`@("`@*B!#=7)R96YT
M;'D@<W5P<&]R=',Z"B`@("`@*B`@*R`\<V%M<#YU;FEQ=65?:V5Y/"]S86UP
M/B`@("`H=6YI<75E(&EN9&5X+"!U;FEQ=64@8VAE8VL@;W(@<')I;6%R>5]K
M97DI"B`@("`@*B`@*R`\<V%M<#YM=6QT:7!L95]K97D\+W-A;7`^("`H;75L
M=&DM:V5Y(&EN9&5X*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1T
M86)L92`@('1H92!T86)L92!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M8V]L=6UN("!T:&4@9FEE;&0@;F%M90H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!S<&%C92!D96QI;6ET960@<W1R:6YG(&]F(&9L86=S+B`@16UP
M='D@<W1R:6YG(&EF(&YO;F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S>6)A<V5?9FEE;&1?9FQA9W,H
M)'1A8FQE+"`D8V]L=6UN*0H@("`@>PH@("`@("`@('-T871I8R`D=&%B;&5.
M86UE(#T@;G5L;#L*("`@("`@("!S=&%T:6,@)&9L86=S(#T@87)R87DH*3L*
M"B`@("`@("`@:68@*"1T86)L92`A/2`D=&%B;&5.86UE*2!["B`@("`@("`@
M("`@("1F;&%G<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1T86)L94YA;64@
M/2`D=&%B;&4["@H@("`@("`@("`@("`O+R!G970@=6YI<75E+W!R:6UA<GD@
M:V5Y<PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F=E=$%L;"@B<W!?:&5L
M<&EN9&5X("1T86)L92(L($1"7T9%5$-(34]$15]!4U-/0RD["@H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1R97-;,%U;)VEN9&5X7V1E<V-R:7!T:6]N)UTI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1R97,@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@)&ME>7,@/2!E>'!L;V1E*"<L("<L('1R:6TH)'9A;%LG:6YD
M97A?:V5Y<R==*2D["@H@("`@("`@("`@("`@("`@:68@*'-I>F5O9B@D:V5Y
M<RD@/B`Q*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@
M87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M9%]F;&%G*"1F;&%G<ULD:V5Y72P@)VUU;'1I<&QE7VME>2<I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1V86Q;)VEN9&5X7V1E<V-R:7!T:6]N)UTL("=U
M;FEQ=64G*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES
M(&%S("1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M9&1?9FQA9R@D9FQA9W-;)&ME>5TL("=U;FEQ=65?:V5Y)RD["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@('T*"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)&-O
M;'5M;BP@)&9L86=S*2D@>PH@("`@("`@("`@("!R971U<FXH:6UP;&]D92@G
M("<L("1F;&%G<ULD8V]L=6UN72DI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("<G.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]A9&1?9FQA
M9R@I"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<W1R:6YG('1O('1H92!F;&%G
M<R!A<G)A>2!I9B!T:&4@9FQA9R!I<R!N;W0@>65T(&EN('1H97)E"B`@("`@
M*B`M(&EF('1H97)E(&ES(&YO(&9L86<@<')E<V5N="!T:&4@87)R87D@:7,@
M8W)E871E9`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)&%R<F%Y("!R
M969E<F5N8V4@;V8@9FQA9W,@87)R87D@=&\@861D(&$@=F%L=64@=&\*("`@
M("`J($!P87)A;2!M:7AE9"`@)'9A;'5E("!V86QU92!T;R!A9&0@=&\@=&AE
M(&9L86<@87)R87D*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V%D9%]F;&%G*"8D87)R87DL("1V86QU92D*("`@('L*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1A<G)A>2DI('L*("`@("`@("`@("`@)&%R<F%Y(#T@87)R
M87DH)'9A;'5E*3L*("`@("`@("!](&5L<V5I9B`H(6EN7V%R<F%Y*"1V86QU
M92P@)&%R<F%Y*2D@>PH@("`@("`@("`@("!A<G)A>5]P=7-H*"1A<G)A>2P@
M)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*("`@("`J($]B=&%I;G,@
M=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R(&QI<W1I;F<@82!G:79E;B!T
M>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO=2!W86YT('1O(')E=')I979E
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!344P@<75E<GD@
M<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R:79E<B!D;V5S;B=T"B`@("`@*B`@
M("`@("`@("`@("`@("`@('-U<'!O<G0@=&AE(&]B:F5C="!T>7!E(')E<75E
M<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C
M:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@
M("`@("`@("`@(')E='5R;B`B4T5,14-4(&YA;64@1E)/32!S>7-O8FIE8W1S
M(%=(15)%('1Y<&4@/2`G52<B"B`@("`@("`@("`@("`@("`@("`@("`@+B`G
M($]21$52($)9(&YA;64G.PH@("`@("`@("`@("!C87-E("=V:65W<R<Z"B`@
M("`@("`@("`@("`@("!R971U<FX@(E-%3$5#5"!N86UE($923TT@<WES;V)J
M96-T<R!72$5212!T>7!E(#T@)U8G(CL*("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B
M+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T1"+W-T;W)A9V4N<&AP````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,#`T`#$P-3$U-#,Q,#4W`#`R
M,#`P-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF
M='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!0<F]V:61E<R!A
M;B!O8FIE8W0@:6YT97)F86-E('1O(&$@=&%B;&4@<F]W"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W1I9T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z('-T;W)A9V4N<&AP+'8@,2XR,2`R,#`U+S`R+S`R(#`R
M.C4T.C4Q(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@
M1$(@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I
M<F5?;VYC92`G1$(N<&AP)SL*"B\J*@H@*B!0<F]V:61E<R!A;B!O8FIE8W0@
M:6YT97)F86-E('1O(&$@=&%B;&4@<F]W"B`J"B`J($ET(&QE=',@>6]U(&%D
M9"P@9&5L971E(&%N9"!C:&%N9V4@<F]W<R!U<VEN9R!O8FIE8W1S(')A=&AE
M<B!T:&%N(%-13`H@*B!S=&%T96UE;G1S+@H@*@H@*B!`8V%T96=O<GD@("!$
M871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG
M($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]S=&]R86=E
M(&5X=&5N9',@4$5!4@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J
M*B!T:&4@;F%M92!O9B!T:&4@=&%B;&4@*&]R('9I97<L(&EF('1H92!B86-K
M96YD(&1A=&%B87-E('-U<'!O<G1S"B`@("`@("`@=7!D871E<R!I;B!V:65W
M<RD@=V4@:&]L9"!D871A(&9R;VT@*B\*("`@('9A<B`D7W1A8FQE(#T@;G5L
M;#L*"B`@("`O*BH@=VAI8V@@8V]L=6UN*',I(&EN('1H92!T86)L92!C;VYT
M86EN<R!P<FEM87)Y(&ME>7,L(&-A;B!B92!A"B`@("`@("`@<W1R:6YG(&9O
M<B!S:6YG;&4M8V]L=6UN('!R:6UA<GD@:V5Y<RP@;W(@86X@87)R87D@;V8@
M<W1R:6YG<PH@("`@("`@(&9O<B!M=6QT:7!L92UC;VQU;6X@<')I;6%R>2!K
M97ES("HO"B`@("!V87(@)%]K97EC;VQU;6X@/2!N=6QL.PH*("`@("\J*B!$
M0B!C;VYN96-T:6]N(&AA;F1L92!U<V5D(&9O<B!A;&P@=')A;G-A8W1I;VYS
M("HO"B`@("!V87(@)%]D8F@@/2!N=6QL.PH*("`@("\J*B!A;B!A<W-O8R!W
M:71H('1H92!N86UE<R!O9B!D871A8F%S92!F:65L9',@<W1O<F5D(&%S('!R
M;W!E<G1I97,*("`@("`@("!I;B!T:&ES(&]B:F5C="`J+PH@("`@=F%R("1?
M<')O<&5R=&EE<R`](&%R<F%Y*"D["@H@("`@+RHJ(&%N(&%S<V]C('=I=&@@
M=&AE(&YA;65S(&]F('1H92!P<F]P97)T:65S(&EN('1H:7,@;V)J96-T('1H
M870*("`@("`@("!H879E(&)E96X@8VAA;F=E9"!S:6YC92!T:&5Y('=E<F4@
M9F5T8VAE9"!F<F]M('1H92!D871A8F%S92`J+PH@("`@=F%R("1?8VAA;F=E
M<R`](&%R<F%Y*"D["@H@("`@+RHJ(&9L86<@=&AA="!D96-I9&5S(&EF(&1A
M=&$@:6X@=&AI<R!O8FIE8W0@8V%N(&)E(&-H86YG960N"B`@("`@("`@;V)J
M96-T<R!T:&%T(&1O;B=T(&AA=F4@=&AE:7(@=&%B;&4G<R!K97D@8V]L=6UN
M(&EN('1H96ER"B`@("`@("`@<')O<&5R='D@;&ES=',@=VEL;"!B92!F;&%G
M9V5D(&%S(')E860M;VYL>2X@*B\*("`@('9A<B`D7W)E861O;FQY(#T@9F%L
M<V4["@H@("`@+RHJ(&9U;F-T:6]N(&]R(&UE=&AO9"!T:&%T(&EM<&QE;65N
M=',@82!V86QI9&%T;W(@9F]R(&9I96QD<R!T:&%T"B`@("`@("`@87)E('-E
M="P@=&AI<R!V86QI9&%T;W(@9G5N8W1I;VX@<F5T=7)N<R!T<G5E(&EF('1H
M92!F:65L9"!I<PH@("`@("`@('9A;&ED+"!F86QS92!I9B!N;W0@*B\*("`@
M('9A<B`D7W9A;&ED871O<B`](&YU;&P["@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@
M("`@*@H@("`@("H@0'!A<F%M("1T86)L92!S=')I;F<@=&AE(&YA;64@;V8@
M=&AE(&1A=&%B87-E('1A8FQE"B`@("`@*@H@("`@("H@0'!A<F%M("1K97EC
M;VQU;6X@;6EX960@<W1R:6YG('=I=&@@;F%M92!O9B!K97D@8V]L=6UN+"!O
M<B!A<G)A>2!O9@H@("`@("H@<W1R:6YG<R!I9B!T:&4@=&%B;&4@:&%S(&$@
M<')I;6%R>2!K97D@;V8@;6]R92!T:&%N(&]N92!C;VQU;6X*("`@("`J"B`@
M("`@*B!`<&%R86T@)&1B:"!O8FIE8W0@9&%T86)A<V4@8V]N;F5C=&EO;B!O
M8FIE8W0*("`@("`J"B`@("`@*B!`<&%R86T@)'9A;&ED871O<B!M:7AE9"!F
M=6YC=&EO;B!O<B!M971H;V0@=7-E9"!T;R!V86QI9&%T90H@("`@("H@96%C
M:"!N97<@=F%L=64L(&-A;&QE9"!W:71H('1H<F5E('!A<F%M971E<G,Z('1H
M92!N86UE(&]F('1H90H@("`@("H@9FEE;&0O8V]L=6UN('1H870@:7,@8VAA
M;F=I;F<L(&$@<F5F97)E;F-E('1O('1H92!N97<@=F%L=64@86YD"B`@("`@
M*B!A(')E9F5R96YC92!T;R!T:&ES(&]B:F5C=`H@("`@("H*("`@("`J+PH@
M("`@9G5N8W1I;VX@1$)?<W1O<F%G92@D=&%B;&4L("1K97EC;VQU;6XL("8D
M9&)H+"`D=F%L:61A=&]R(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^
M4$5!4B@G1$)?17)R;W(G*3L*("`@("`@("`D=&AI<RT^7W1A8FQE(#T@)'1A
M8FQE.PH@("`@("`@("1T:&ES+3Y?:V5Y8V]L=6UN(#T@)&ME>6-O;'5M;CL*
M("`@("`@("`D=&AI<RT^7V1B:"`]("1D8F@["B`@("`@("`@)'1H:7,M/E]R
M96%D;VYL>2`](&9A;'-E.PH@("`@("`@("1T:&ES+3Y?=F%L:61A=&]R(#T@
M)'9A;&ED871O<CL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?;6%K
M95=H97)E*"D*"B`@("`O*BH*("`@("`J(%5T:6QI='D@;65T:&]D('1O(&)U
M:6QD(&$@(E=(15)%(B!C;&%U<V4@=&\@;&]C871E(&]U<G-E;'9E<R!I;@H@
M("`@("H@=&AE('1A8FQE+@H@("`@("H*("`@("`J(%A86"!F=71U<F4@:6UP
M<F]V96UE;G0Z('5S92!R;W=I9',_"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]M86ME5VAE<F4H)&ME>79A
M;"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?
M:V5Y8V]L=6UN*2D@>PH@("`@("`@("`@("!I9B`H)&ME>79A;"`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F
M*"1T:&ES+3Y?:V5Y8V]L=6UN*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("1K97EV86Q;72`]("1T:&ES+3Y[)'1H:7,M/E]K97EC;VQU;6Y;)&E=
M?3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=VAE<F5C;&%U<V4@/2`G)SL*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@<VEZ96]F*"1T:&ES+3Y?:V5Y8V]L=6UN*3L@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1I(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1W:&5R96-L875S92`N/2`G($%.1"`G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'=H97)E8VQA=7-E("X]("1T:&ES+3Y?:V5Y8V]L
M=6UN6R1I73L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1K97EV86Q;
M)&E=*2D@>PH@("`@("`@("`@("`@("`@("`@("\O('1H97)E)W,@;F]T(&UU
M8V@@<&]I;G0@:6X@:&%V:6YG(&$@3E5,3"!K97DL"B`@("`@("`@("`@("`@
M("`@("`@+R\@8G5T('=E('-U<'!O<G0@:70@86YY=V%Y"B`@("`@("`@("`@
M("`@("`@("`@)'=H97)E8VQA=7-E("X]("<@25,@3E5,3"<["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R96-L
M875S92`N/2`G(#T@)R`N("1T:&ES+3Y?9&)H+3YQ=6]T92@D:V5Y=F%L6R1I
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&ME>79A;"`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("`@("`@)&ME>79A;"`]($`D=&AI<RT^>R1T:&ES+3Y?:V5Y
M8V]L=6UN?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VAE<F5C;&%U
M<V4@/2`D=&AI<RT^7VME>6-O;'5M;CL*("`@("`@("`@("`@:68@*&ES7VYU
M;&PH)&ME>79A;"DI('L*("`@("`@("`@("`@("`@("\O('1H97)E)W,@;F]T
M(&UU8V@@<&]I;G0@:6X@:&%V:6YG(&$@3E5,3"!K97DL"B`@("`@("`@("`@
M("`@("`O+R!B=70@=V4@<W5P<&]R="!I="!A;GEW87D*("`@("`@("`@("`@
M("`@("1W:&5R96-L875S92`N/2`G($E3($Y53$PG.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'=H97)E8VQA=7-E("X]("<@/2`G
M("X@)'1H:7,M/E]D8F@M/G%U;W1E*"1K97EV86PI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=VAE<F5C;&%U<V4["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<V5T=7`H*0H*("`@("\J*@H@("`@
M("H@365T:&]D('5S960@=&\@:6YI=&EA;&EZ92!A($1"7W-T;W)A9V4@;V)J
M96-T(&9R;VT@=&AE"B`@("`@*B!C;VYF:6=U<F5D('1A8FQE+@H@("`@("H*
M("`@("`J($!P87)A;2`D:V5Y=F%L(&UI>&5D('1H92!K97E;<UT@;V8@=&AE
M(')O=R!T;R!F971C:"`H<W1R:6YG(&]R(&%R<F%Y*0H@("`@("H*("`@("`J
M($!R971U<FX@:6YT($1"7T]+(&]N('-U8V-E<W,L(&$@1$(@97)R;W(@:68@
M;F]T"B`@("`@*B\*("`@(&9U;F-T:6]N('-E='5P*"1K97EV86PI"B`@("![
M"B`@("`@("`@)'=H97)E8VQA=7-E(#T@)'1H:7,M/E]M86ME5VAE<F4H)&ME
M>79A;"D["B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"`J($923TT@)R`N("1T
M:&ES+3Y?=&%B;&4@+B`G(%=(15)%("<@+B`D=VAE<F5C;&%U<V4["B`@("`@
M("`@)'-T:"`]("1T:&ES+3Y?9&)H+3YQ=65R>2@D<75E<GDI.PH@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'-T:#L*("`@("`@("!]"B`@("`@("`@)')O=R`]("1S=&@M/F9E=&-H4F]W
M*$1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R;W<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F]W.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21R;W<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*&YU;&PL($1"7T524D]27TY/5%]&3U5.1"P@;G5L;"P@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Q
M=65R>2P@;G5L;"P@=')U92D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@
M*"1R;W<@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)'1H:7,M
M/E]P<F]P97)T:65S6R1K97E=(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M
M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!I;G-E<G0H*0H*("`@
M("\J*@H@("`@("H@0W)E871E(&$@;F5W("AE;7!T>2D@<F]W(&EN('1H92!C
M;VYF:6=U<F5D('1A8FQE(&9O<B!T:&ES"B`@("`@*B!O8FIE8W0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&EN<V5R="@D;F5W<&LI"B`@("!["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T:&ES+3Y?:V5Y8V]L=6UN*2D@>PH@("`@("`@("`@
M("`D<')I;6%R>6ME>2`]("1T:&ES+3Y?:V5Y8V]L=6UN.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1P<FEM87)Y:V5Y(#T@87)R87DH)'1H:7,M
M/E]K97EC;VQU;6XI.PH@("`@("`@('T*("`@("`@("!S971T>7!E*"1N97=P
M:RP@(F%R<F%Y(BD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F
M*"1P<FEM87)Y:V5Y*3L@)&DK*RD@>PH@("`@("`@("`@("`D<&MV86QS6UT@
M/2`D=&AI<RT^7V1B:"T^<75O=&4H)&YE=W!K6R1I72D["B`@("`@("`@?0H*
M("`@("`@("`D<W1H(#T@)'1H:7,M/E]D8F@M/G%U97)Y*"))3E-%4E0@24Y4
M3R`D=&AI<RT^7W1A8FQE("@B("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&QO9&4H(BPB+"`D<')I;6%R>6ME>2D@+B`B*2!604Q5
M15,H(B`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L
M;V1E*"(L(BP@)'!K=F%L<RD@+B`B*2(I.PH@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D<W1H*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T:#L*("`@("`@
M("!]"B`@("`@("`@:68@*'-I>F5O9B@D;F5W<&LI(#T](#$I('L*("`@("`@
M("`@("`@)&YE=W!K(#T@)&YE=W!K6S!=.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^<V5T=7`H)&YE=W!K*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!T;U-T<FEN9R@I"@H@("`@+RHJ"B`@("`@*B!/=71P=70@82!S:6UP
M;&4@9&5S8W)I<'1I;VX@;V8@=&AI<R!$0E]S=&]R86=E(&]B:F5C="X*("`@
M("`J($!R971U<FX@<W1R:6YG(&]B:F5C="!D97-C<FEP=&EO;@H@("`@("HO
M"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@("`@("`@)&EN9F\@
M/2!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI.PH@("`@("`@("1I;F9O
M("X]("(@*'1A8FQE/2(["B`@("`@("`@)&EN9F\@+CT@)'1H:7,M/E]T86)L
M93L*("`@("`@("`D:6YF;R`N/2`B+"!K97EC;VQU;6X](CL*("`@("`@("!I
M9B`H:7-?87)R87DH)'1H:7,M/E]K97EC;VQU;6XI*2!["B`@("`@("`@("`@
M("1I;F9O("X]("(H(B`N(&EM<&QO9&4H(BPB+"`D=&AI<RT^7VME>6-O;'5M
M;BD@+B`B*2(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&EN9F\@
M+CT@)'1H:7,M/E]K97EC;VQU;6X["B`@("`@("`@?0H@("`@("`@("1I;F9O
M("X]("(L(&1B:#TB.PH@("`@("`@(&EF("AI<U]O8FIE8W0H)'1H:7,M/E]D
M8F@I*2!["B`@("`@("`@("`@("1I;F9O("X]("1T:&ES+3Y?9&)H+3YT;U-T
M<FEN9R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;F9O("X]
M(")N=6QL(CL*("`@("`@("!]"B`@("`@("`@)&EN9F\@+CT@(BDB.PH@("`@
M("`@(&EF("AS:7IE;V8H)'1H:7,M/E]P<F]P97)T:65S*2D@>PH@("`@("`@
M("`@("`D:6YF;R`N/2`B(%ML;V%D960L(&ME>3TB.PH@("`@("`@("`@("`D
M:V5Y;F%M92`]("1T:&ES+3Y?:V5Y8V]L=6UN.PH@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)&ME>6YA;64I*2!["B`@("`@("`@("`@("`@("`D:6YF;R`N
M/2`B*"(["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE
M;V8H)&ME>6YA;64I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1I(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;R`N/2`B
M+"(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("1I;F9O("X]("1T:&ES+3XD:V5Y;F%M95LD:5T["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D:6YF;R`N/2`B*2(["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D:6YF;R`N/2`D=&AI<RT^)&ME
M>6YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EN9F\@+CT@(ETB
M.PH@("`@("`@('T*("`@("`@("!I9B`H<VEZ96]F*"1T:&ES+3Y?8VAA;F=E
M<RDI('L*("`@("`@("`@("`@)&EN9F\@+CT@(B!;;6]D:69I961=(CL*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&1U;7`H*0H*("`@("\J*@H@("`@("H@1'5M<"!T:&4@
M8V]N=&5N=',@;V8@=&AI<R!O8FIE8W0@=&\@(G-T86YD87)D(&]U='!U="(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1U;7`H*0H@("`@>PH@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?<')O<&5R=&EE<R!A<R`D<')O<"`]/B`D9F]O*2![
M"B`@("`@("`@("`@('!R:6YT("(D<')O<"`]("(["B`@("`@("`@("`@('!R
M:6YT(&AT;6QE;G1I=&EE<R@D=&AI<RT^)'!R;W`I.PH@("`@("`@("`@("!P
M<FEN="`B/&)R("\^7&XB.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R`F8W)E871E*"D*"B`@("`O*BH*("`@("`J(%-T871I8R!M
M971H;V0@=7-E9"!T;R!C<F5A=&4@;F5W($1"('-T;W)A9V4@;V)J96-T<RX*
M("`@("`J($!P87)A;2`D9&%T82!A<W-O8RX@87)R87D@=VAE<F4@=&AE(&ME
M>7,@87)E('1H92!N86UE<PH@("`@("H@("`@("`@("`@("`@(&]F('!R;W!E
M<G1I97,O8V]L=6UN<PH@("`@("H@0')E='5R;B!O8FIE8W0@82!N97<@:6YS
M=&%N8V4@;V8@1$)?<W1O<F%G92!O<B!A('-U8F-L87-S(&]F(&ET"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9C<F5A=&4H)'1A8FQE+"`F)&1A=&$I"B`@("![
M"B`@("`@("`@)&-L87-S;F%M92`]('-T<G1O;&]W97(H9V5T7V-L87-S*"1T
M:&ES*2D["B`@("`@("`@)&]B:B`])B!N97<@)&-L87-S;F%M92@D=&%B;&4I
M.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1N86UE(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`D;V)J+3Y?<')O<&5R=&EE<ULD;F%M95T@/2!T<G5E
M.PH@("`@("`@("`@("`D;V)J+3XD;F%M92`]("8D=F%L=64["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D;V)J.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&QO861&<F]M475E<GDH*0H*("`@("\J*@H@("`@("H@3&]A9',@
M9&%T82!I;G1O('1H:7,@;V)J96-T(&9R;VT@=&AE(&=I=F5N('%U97)Y+B`@
M268@=&AI<PH@("`@("H@;V)J96-T(&%L<F5A9'D@8V]N=&%I;G,@=&%B;&4@
M9&%T82P@8VAA;F=E<R!W:6QL(&)E('-A=F5D(&%N9`H@("`@("H@=&AE(&]B
M:F5C="!R92UI;FET:6%L:7IE9"!F:7)S="X*("`@("`J"B`@("`@*B!`<&%R
M86T@)'%U97)Y(%-13"!Q=65R>0H@("`@("H*("`@("`J($!P87)A;2`D<&%R
M86US('!A<F%M971E<B!L:7-T(&EN(&-A<V4@>6]U('=A;G0@=&\@=7-E"B`@
M("`@*B!P<F5P87)E+V5X96-U=&4@;6]D90H@("`@("H*("`@("`J($!R971U
M<FX@:6YT($1"7T]+(&]N('-U8V-E<W,L($1"7U=!4DY)3D=?4D5!1%]/3DQ9
M(&EF('1H90H@("`@("H@<F5T=7)N960@;V)J96-T(&ES(')E860M;VYL>2`H
M8F5C875S92!T:&4@;V)J96-T)W,@<W!E8VEF:65D"B`@("`@*B!K97D@8V]L
M=6UN('=A<R!N;W0@9F]U;F0@86UO;F<@=&AE(&-O;'5M;G,@<F5T=7)N960@
M8GD@)'%U97)Y*2P*("`@("`J(&]R(&%N;W1H97(@1$(@97)R;W(@8V]D92!I
M;B!C87-E(&]F(&5R<F]R<RX*("`@("`J+PHO+R!86%@@8V]M;65N=&5D(&]U
M="!F;W(@;F]W"B\J"B`@("!F=6YC=&EO;B!L;V%D1G)O;5%U97)Y*"1Q=65R
M>2P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*'-I>F5O9B@D
M=&AI<RT^7W!R;W!E<G1I97,I*2!["B`@("`@("`@("`@(&EF("AS:7IE;V8H
M)'1H:7,M/E]C:&%N9V5S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-T
M;W)E*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG97,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?<')O<&5R
M=&EE<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1R;W=D871A(#T@
M)'1H:7,M/E]D8F@M/F=E=%)O=R@D<75E<GDL($1"7T9%5$-(34]$15]!4U-/
M0RP@)'!A<F%M<RD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R;W=D871A
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')O=V1A=&$["B`@("`@("`@?0H@
M("`@("`@(')E<V5T*"1R;W=D871A*3L*("`@("`@("`D9F]U;F1?:V5Y8V]L
M=6UN(#T@9F%L<V4["B`@("`@("`@=VAI;&4@*&QI<W0H)&ME>2P@)'9A;'5E
M*2`](&5A8V@H)')O=V1A=&$I*2!["B`@("`@("`@("`@(&EF("@D:V5Y(#T]
M("1T:&ES+3Y?:V5Y8V]L=6UN*2!["B`@("`@("`@("`@("`@("`D9F]U;F1?
M:V5Y8V]L=6UN(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^7W!R;W!E<G1I97-;)&ME>5T@/2!T<G5E.PH@("`@("`@("`@("`D
M=&AI<RT^)&ME>2`]("8D=F%L=64["B`@("`@("`@("`@('5N<V5T*"1V86QU
M92D[("\O(&AA=F4@=&\@=6YS970L(&]R(&%L;"!P<F]P97)T:65S('=I;&P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<F5F97(@=&\@=&AE('-A
M;64@=F%L=64*("`@("`@("!]"B`@("`@("`@:68@*"$D9F]U;F1?:V5Y8V]L
M=6UN*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5A9&]N;'D@/2!T<G5E.PH@
M("`@("`@("`@("!R971U<FX@1$)?5T%23DE.1U]214%$7T].3%D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*("HO"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<V5T*"D*"B`@("`O*BH*("`@("`J($UO9&EF>2!A
M;B!A='1R:75T92!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1P
M<F]P97)T>2P@)&YE=W9A;'5E*0H@("`@>PH@("`@("`@("\O(&]N;'D@8VAA
M;F=E(&EF("1P<F]P97)T>2!I<R!K;F]W;B!A;F0@;V)J96-T(&ES(&YO=`H@
M("`@("`@("\O(')E860M;VYL>0H@("`@("`@(&EF("@D=&AI<RT^7W)E861O
M;FQY*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAN
M=6QL+"!$0E]705).24Y'7U)%041?3TY,62P@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL('1R
M=64I.PH@("`@("`@('T*("`@("`@("!I9B`H0&ES<V5T*"1T:&ES+3Y?<')O
M<&5R=&EE<ULD<')O<&5R='E=*2D@>PH@("`@("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]V86QI9&%T;W(I*2!["B`@("`@("`@("`@("`@("`D=F%L:60@
M/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'9A;&ED(#T@0&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?=F%L:61A=&]R+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!R;W!E<G1Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1N97=V86QU92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^)'!R;W!E<G1Y+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'9A;&ED*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^)'!R;W!E<G1Y(#T@)&YE=W9A;'5E.PH@("`@("`@
M("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?8VAA;F=E<ULD<')O<&5R='E=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E<ULD<')O
M<&5R='E=(#T@,#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5S6R1P<F]P97)T>5TK*SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAN=6QL+"!$0E]%4E)/
M4E])3E9!3$E$+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YU;&PL(")I;G9A;&ED(&9I96QD.B`D<')O<&5R='DB
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;&PL('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H;G5L;"P@1$)?15)23U)?3D]354-(1DE%3$0L(&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(")U;FMN;W=N(&9I96QD
M.B`D<')O<&5R='DB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!N=6QL+"!T<G5E*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R`F
M9V5T*"D*"B`@("`O*BH*("`@("`J($9E=&-H(&%N(&%T=')I8G5T92!V86QU
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&%T=')I8G5T92!N86UE
M"B`@("`@*@H@("`@("H@0')E='5R;B!A='1R:6)U=&4@8V]N=&5N=',L(&]R
M(&YU;&P@:68@=&AE(&%T=')I8G5T92!N86UE(&ES"B`@("`@*B!U;FMN;W=N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9G970H)'!R;W!E<G1Y*0H@("`@>PH@
M("`@("`@("\O(&]N;'D@<F5T=7)N(&EF("1P<F]P97)T>2!I<R!K;F]W;@H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R;W!E<G1I97-;)'!R;W!E<G1Y
M72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3XD<')O<&5R='D["B`@
M("`@("`@?0H@("`@("`@("1T;7`@/2!N=6QL.PH@("`@("`@(')E='5R;B`D
M=&UP.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]$0E]S=&]R86=E
M*"D*"B`@("`O*BH*("`@("`J($1E<W1R=6-T;W(L(&-A;&QS($1"7W-T;W)A
M9V4Z.G-T;W)E*"D@:68@=&AE<F4@87)E(&-H86YG97,*("`@("`J('1H870@
M87)E('1O(&)E(&ME<'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]$0E]S=&]R
M86=E*"D*("`@('L*("`@("`@("!I9B`H<VEZ96]F*"1T:&ES+3Y?8VAA;F=E
M<RDI('L*("`@("`@("`@("`@)'1H:7,M/G-T;W)E*"D["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?<')O<&5R=&EE<R`](&%R<F%Y*"D["B`@("`@("`@
M)'1H:7,M/E]C:&%N9V5S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W1A
M8FQE(#T@;G5L;#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S=&]R
M92@I"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@8VAA;F=E<R!T;R!T:&ES(&]B
M:F5C="!I;B!T:&4@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!$
M0E]/2R!O<B!A($1"(&5R<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E
M*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H86YG97,@87,@
M)&YA;64@/3X@)&9O;RD@>PH@("`@("`@("`@("`D<&%R86US6UT@/2`F)'1H
M:7,M/B1N86UE.PH@("`@("`@("`@("`D=F%R<UM=(#T@)&YA;64@+B`G(#T@
M/R<["B`@("`@("`@?0H@("`@("`@(&EF("@D=F%R<RD@>PH@("`@("`@("`@
M("`D<75E<GD@/2`G55!$051%("<@+B`D=&AI<RT^7W1A8FQE("X@)R!3150@
M)R`N"B`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1V87)S*2`N("<@
M5TA%4D4@)R`N"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:V57:&5R92@I
M.PH@("`@("`@("`@("`D<W1M="`]("1T:&ES+3Y?9&)H+3YP<F5P87)E*"1Q
M=65R>2D["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^7V1B:"T^97AE8W5T
M92@D<W1M="P@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D<F5S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5S(#T@87)R87DH
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(')E;6]V92@I"@H@("`@+RHJ"B`@("`@*B!2
M96UO=F4@=&AE(')O=R!R97!R97-E;G1E9"!B>2!T:&ES(&]B:F5C="!F<F]M
M('1H92!D871A8F%S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"
M7T]+(&]R(&$@1$(@97)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]R96%D;VYL>2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H;G5L;"P@1$)?5T%2
M3DE.1U]214%$7T].3%DL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+"!T<G5E*3L*("`@("`@
M("!]"B`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^
M7W1A8FQE("XG(%=(15)%("<N"B`@("`@("`@("`@("1T:&ES+3Y?;6%K95=H
M97)E*"D["B`@("`@("`@)')E<R`]("1T:&ES+3Y?9&)H+3YQ=65R>2@D<75E
M<GDI.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<SL*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]P<F]P97)T:65S(&%S("1P<F]P(#T^("1F;V\I('L*("`@("`@
M("`@("`@=6YS970H)'1H:7,M/B1P<F]P*3L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/E]P<F]P97)T:65S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M7V-H86YG97,@/2!A<G)A>2@I.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@
M('T*"B`@("`O+R!]?7T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T
M86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O1$(O<W%L:71E+G!H<```````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-S(Q-#4`,3`U,34T,S$P-3<`,#$W-C4Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T
M=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R:79E<B!F;W(@
M4$A0)W,@<W%L:71E(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET
M:"!344QI=&4@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@
M("!$0@H@*B!`875T:&]R("`@("!5<G,@1V5H<FEG(#QU<G-`8VER8VQE+F-H
M/@H@*B!`875T:&]R("`@("!-:6MA(%1U=7!O;&$@/'1U=7!O;&%`87!P96QS
M:6EN:2YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A
M;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!0
M2%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP(#,N,`H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@<W%L:71E+G!H<"QV(#$N,3`Y(#(P,#4O,#,O,3`@
M,#$Z,C(Z-#@@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H
M92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*
M("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H<"<["@HO*BH*("H@5&AE
M(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R86-T('=I=&@@4$A0)W,@
M<W%L:71E(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!344QI
M=&4@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@=&AE
M(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@*@H@*B!.3U1)0T4Z("!4
M:&ES(&1R:79E<B!N965D<R!02%`G<R!T<F%C:U]E<G)O<G,@:6YI('-E='1I
M;F<@=&\@8F4@;VXN"B`J($ET(&ES(&%U=&]M871I8V%L;'D@='5R;F5D(&]N
M('=H96X@8V]N;F5C=&EN9R!T;R!T:&4@9&%T86)A<V4N"B`J($UA:V4@<W5R
M92!Y;W5R('-C<FEP=',@9&]N)W0@='5R;B!I="!O9F8N"B`J"B`J($!C871E
M9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@
M("`@(%5R<R!'96AR:6<@/'5R<T!C:7)C;&4N8V@^"B`J($!A=71H;W(@("`@
M($UI:V$@5'5U<&]L82`\='5U<&]L84!A<'!E;'-I:6YI+FYE=#X*("H@0&%U
M=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N
M-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]$0@H@*B\*8VQA<W,@1$)?<W%L:71E(&5X=&5N9',@1$)?8V]M;6]N"GL*
M("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@
M9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)W-Q;&ET
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA
M;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G
M<W%L:71E)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@
M=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W
M7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@
M9FER<W0@<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H
M:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N
M"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT
M.@H@("`@("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R
M;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE
M('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S
M(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=A;'1E<B<L
M"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N
M=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@
M("`]/B!T<G5E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS92P*
M("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W1R
M86YS86-T:6]N<R<@(#T^(&9A;'-E+`H@("`@*3L*"B`@("`O*BH*("`@("`J
M($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@=&\@1$(@97)R;W(@
M8V]D97,*("`@("`J"B`@("`@*B![0&EN=&5R;F%L("!%<G)O<B!C;V1E<R!A
M8V-O<F1I;F<@=&\@<W%L:71E7V5X96,N("!3964@=&AE(&]N;&EN90H@("`@
M("H@;6%N=6%L(&%T(&AT='`Z+R]S<6QI=&4N;W)G+V-?:6YT97)F86-E+FAT
M;6P@9F]R(&EN9F\N"B`@("`@*B!4:&ES(&5R<F]R(&AA;F1L:6YG(&)A<V5D
M(&]N('-Q;&ET95]E>&5C(&ES(&YO="!Y970@:6UP;&5M96YT960N?7T*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C
M;V1E7VUA<"`](&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R
M87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@
M0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@
M("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T
M:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J(%-13&ET
M92!D871A('1Y<&5S"B`@("`@*@H@("`@("H@0&QI;FL@:'1T<#HO+W=W=RYS
M<6QI=&4N;W)G+V1A=&%T>7!E<RYH=&UL"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&ME>7=O<F1S(#T@87)R87D@*`H@("`@
M("`@("="3$]")R`@("`@(#T^("<G+`H@("`@("`@("="3T],14%.)R`@(#T^
M("<G+`H@("`@("`@("=#2$%204-415(G(#T^("<G+`H@("`@("`@("=#3$]"
M)R`@("`@(#T^("<G+`H@("`@("`@("=&3$]!5"<@("`@(#T^("<G+`H@("`@
M("`@("=)3E1%1T52)R`@(#T^("<G+`H@("`@("`@("=+15DG("`@("`@(#T^
M("<G+`H@("`@("`@("=.051)3TY!3"<@(#T^("<G+`H@("`@("`@("=.54U%
M4DE#)R`@(#T^("<G+`H@("`@("`@("=.5D%20TA!4B<@(#T^("<G+`H@("`@
M("`@("=04DE-05)9)R`@(#T^("<G+`H@("`@("`@("=415A4)R`@("`@(#T^
M("<G+`H@("`@("`@("=424U%4U1!35`G(#T^("<G+`H@("`@("`@("=53DE1
M544G("`@(#T^("<G+`H@("`@("`@("=605)#2$%2)R`@(#T^("<G+`H@("`@
M("`@("=605)924Y')R`@(#T^("<G+`H@("`@*3L*"B`@("`O*BH*("`@("`J
M(%1H92!M;W-T(')E8V5N="!E<G)O<B!M97-S86=E(&9R;VT@)'!H<%]E<G)O
M<FUS9PH@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]L87-T97)R;W(@/2`G)SL*"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H
M:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\
M+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@1$)?<W%L:71E*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?
M8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C
M="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92!S
M97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@
M("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1"
M.CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@*B!014%2($1")W,@
M<W%L:71E(&1R:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($13
M3B!O<'1I;VYS.@H@("`@("H@("`K(&UO9&4@(%1H92!P97)M:7-S:6]N<R!F
M;W(@=&AE(&1A=&%B87-E(&9I;&4L(&EN(&9O=7(@9&EG:70*("`@("`J("`@
M("`@("`@("`@8VAM;V0@;V-T86P@9F]R;6%T("AE9R`B,#8P,"(I+@H@("`@
M("H*("`@("`J($5X86UP;&4@;V8@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E
M(&EN(')E860M;VYL>2!M;V1E.@H@("`@("H@/&-O9&4^"B`@("`@*B!R97%U
M:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@*B`*("`@("`J("1D<VX@/2`G<W%L
M:71E.B\O+W!A=&@O86YD+VYA;64O;V8O9&(O9FEL93]M;V1E/3`T,#`G.PH@
M("`@("H@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`J("`@("`G<&]R=&%B:6QI
M='DG(#T^($1"7U!/4E1!0DE,25197T%,3"P*("`@("`J("D["B`@("`@*B`*
M("`@("`J("1D8B`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@
M("`@*B!I9B`H4$5!4CHZ:7-%<G)O<B@D9&(I*2!["B`@("`@*B`@("`@9&EE
M*"1D8BT^9V5T365S<V%G92@I*3L*("`@("`J('T*("`@("`J(#PO8V]D93X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1S;B`@("`@("`@('1H92!D
M871A('-O=7)C92!N86UE"B`@("`@*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E
M;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S:7-T96YT/PH@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VYN96-T*"1D<VXL("1P97)S:7-T96YT(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@:68@*"%014%2.CIL;V%D17AT96YS:6]N*"=S<6QI=&4G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?
M15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@
M>PH@("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A
M>"==.PH@("`@("`@('T*"B`@("`@("`@:68@*"1D<VY;)V1A=&%B87-E)UTI
M('L*("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9'-N6R=D871A8F%S
M92==*2D@>PH@("`@("`@("`@("`@("`@:68@*"%T;W5C:"@D9'-N6R=D871A
M8F%S92==*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<W%L:71E4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?1D]53D0I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9'-N6R=M
M;V1E)UTI('Q\"B`@("`@("`@("`@("`@("`@("`@(6ES7VYU;65R:6,H)&1S
M;ELG;6]D92==*2D*("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("`@("`D;6]D92`](#`V-#0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1M;V1E(#T@;V-T9&5C*"1D<VY;)VUO9&4G
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6-H
M;6]D*"1D<VY;)V1A=&%B87-E)UTL("1M;V1E*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%<G)O<BA$0E]%4E)/
M4E].3U1?1D]53D0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D9'-N6R=D871A8F%S92==*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%<G)O
M<BA$0E]%4E)/4E].3U1?1D]53D0I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-?9FEL92@D9'-N6R=D871A
M8F%S92==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS<6QI
M=&5286ES945R<F]R*$1"7T524D]27TE.5D%,240I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@A:7-?<F5A9&%B;&4H)&1S;ELG9&%T86)A<V4G
M72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I
M<V5%<G)O<BA$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<W%L:71E4F%I<V5%<G)O<BA$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].
M*3L*("`@("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E
M<G-I<W1E;G0@/R`G<W%L:71E7W!O<&5N)R`Z("=S<6QI=&5?;W!E;B<["@H@
M("`@("`@("\O('1R86-K7V5R<F]R<R!M=7-T(')E;6%I;B!O;B!F;W(@<VEM
M<&QE475E<GDH*0H@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I
M.PH@("`@("`@("1P:'!?97)R;W)M<V<@/2`G)SL*"B`@("`@("`@:68@*"$D
M=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9'-N6R=D
M871A8F%S92==*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P:'!?97)R;W)M<V<I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@
M*B!$:7-C;VYN96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@
M;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*
M("`@('L*("`@("`@("`D<F5T(#T@0'-Q;&ET95]C;&]S92@D=&AI<RT^8V]N
M;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL.PH@
M("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@<75E
M<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($Y/5$E#
M13H@(%1H:7,@;65T:&]D(&YE961S(%!(4"=S('1R86-K7V5R<F]R<R!I;FD@
M<V5T=&EN9R!T;R!B92!O;BX*("`@("`J($ET(&ES(&%U=&]M871I8V%L;'D@
M='5R;F5D(&]N('=H96X@8V]N;F5C=&EN9R!T;R!T:&4@9&%T86)A<V4N"B`@
M("`@*B!-86ME('-U<F4@>6]U<B!S8W)I<'1S(&1O;B=T('1U<FX@:70@;V9F
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H92!344P@<75E<GD@
M<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R
M97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*
M("`@("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O
M<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J("`@("`@("`@("`@
M("`@("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@
M("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@
M)&ES;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES
M+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T:&ES
M+3YM;V1I9GE1=65R>2@D<75E<GDI.PH*("`@("`@("`D<&AP7V5R<F]R;7-G
M(#T@)R<["@H@("`@("`@("1R97-U;'0@/2!`<W%L:71E7W%U97)Y*"1Q=65R
M>2P@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3Y?;&%S=&5R
M<F]R(#T@)'!H<%]E<G)O<FUS9R`_("1P:'!?97)R;W)M<V<@.B`G)SL*"B`@
M("`@("`@)'1H:7,M/G)E<W5L="`]("1R97-U;'0["B`@("`@("`@:68@*"$D
M=&AI<RT^<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L
M:71E4F%I<V5%<G)O<BAN=6QL*3L*("`@("`@("!]"@H@("`@("`@("\O('-Q
M;&ET95]Q=65R>2@I('-E96US('1O(&%L;'=A>7,@<F5T=7)N(&$@<F5S;W5R
M8V4*("`@("`@("`O+R!S;R!C86YT('5S92!T:&%T+B!5<VEN9R`D:7-M86YI
M<"!I;G-T96%D"B`@("`@("`@:68@*"$D:7-M86YI<"D@>PH@("`@("`@("`@
M("`D;G5M4F]W<R`]("1T:&ES+3YN=6U2;W=S*"1R97-U;'0I.PH@("`@("`@
M("`@("!I9B`H:7-?;V)J96-T*"1N=6U2;W=S*2D@>PH@("`@("`@("`@("`@
M("`@+R\@=V4G=F4@9V]T(%!%05)?17)R;W(*("`@("`@("`@("`@("`@(')E
M='5R;B`D;G5M4F]W<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@
M("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@<W%L:71E(')E<W5L="!P
M;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@=&AE('9A;&ED('-Q;&ET
M92!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@
M('1R=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R=VES92!R971U
M<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S
M=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@
M4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@9VEV
M96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y
M(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@
M*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA
M=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@
M=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z
M.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H@0'!A
M<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@87)R87D@
M=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@("`@)&9E
M=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@:6YD
M97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@=&AE(')O
M=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N
M('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@
M("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU
M;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@(3T](&YU;&PI
M('L*("`@("`@("`@("`@:68@*"%`<W%L:71E7W-E96LH)'1H:7,M/G)E<W5L
M="P@)')O=VYU;2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E
M("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1A<G(@/2!`
M<W%L:71E7V9E=&-H7V%R<F%Y*"1R97-U;'0L(%-13$E415]!4U-/0RD["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F
M($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@
M("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!
M4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&%R<B`]($!S<6QI=&5?9F5T8VA?87)R87DH)')E<W5L="P@
M4U%,251%7TY532D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)
M5%E?4E1224TI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@179E
M;B!T:&]U9V@@=&AI<R!$0DU3(&%L<F5A9'D@=')I;7,@;W5T<'5T+"!W92!D
M;R!T:&ES(&)E8V%U<V4*("`@("`@("`@("`@("H@82!F:65L9"!M:6=H="!H
M879E(&EN=&5N=&EO;F%L('=H:71E<W!A8V4@870@=&AE(&5N9"!T:&%T"B`@
M("`@("`@("`@("`J(&=E=',@<F5M;W9E9"!B>2!$0E]03U)404))3$E465]2
M5%))32!U;F1E<B!A;F]T:&5R(&1R:79E<BX*("`@("`@("`@("`@("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET
M>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A
M<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M
M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L
M>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET
M(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E
M($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT
M(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N
M('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*
M("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9G)E95)E<W5L="@F)')E<W5L="D*("`@('L*("`@("`@("`O+R!8
M6%@@3F\@;F%T:79E(&9R964_"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@("`@("1R97-U;'0@/2!N=6QL.PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@
M("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R
M97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE
M86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S
M=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D
M(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E
M<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@
M)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N
M=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`<W%L:71E
M7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R;W(H*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D
M:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS
M=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@
M*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E
M<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("![
M"B`@("`@("`@)')O=W,@/2!`<W%L:71E7VYU;5]R;W=S*"1R97-U;'0I.PH@
M("`@("`@(&EF("@D<F]W<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1R;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&%F9F5C=&5D*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU
M;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@
M<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S
M('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E
M9%)O=W,H*0H@("`@>PH@("`@("`@(')E='5R;B!`<W%L:71E7V-H86YG97,H
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M
M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N
M8V5.86UE*"DL"B`@("`@*B`@("`@($1"7W-Q;&ET93HZ;F5X=$E$*"DL($1"
M7W-Q;&ET93HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N("1T:&ES+3YG971397%U
M96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E
M($1"7V-O;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG9713
M97%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?<W%L:71E.CIN97AT240H
M*2P@1$)?<W%L:71E.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@
M)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D[
M"B`@("`@("`@)'%U97)Y("`@/2`G0U)%051%(%1!0DQ%("<@+B`D<V5Q;F%M
M92`N"B`@("`@("`@("`@("`@("`@("`G("AI9"!)3E1%1T52(%5.4TE'3D5$
M(%!224U!4ED@2T59*2`G.PH@("`@("`@("1R97-U;'0@(#T@)'1H:7,M/G%U
M97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I
M*2!["B`@("`@("`@("`@(')E='5R;B@D<F5S=6QT*3L*("`@("`@("!]"B`@
M("`@("`@)'%U97)Y("`@/2`B0U)%051%(%1224='15(@)'MS97%N86UE?5]C
M;&5A;G5P($%&5$52($E.4T525"!/3B`D<V5Q;F%M90H@("`@("`@("`@("`@
M("`@("`@($)%1TE."B`@("`@("`@("`@("`@("`@("`@("`@($1%3$5412!&
M4D]-("1S97%N86UE(%=(15)%(&ED/$Q!4U1?24Y315)47U)/5TE$*"D["B`@
M("`@("`@("`@("`@("`@("`@14Y$("(["B`@("`@("`@)')E<W5L="`@/2`D
M=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N*"1R97-U;'0I.PH@("`@
M("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA
M=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E
M871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@
M("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@
M1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?
M<W%L:71E.CIC<F5A=&5397%U96YC92@I+"!$0E]S<6QI=&4Z.F1R;W!397%U
M96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L
M("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D
M=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["@H@("`@("`@(&1O
M('L*("`@("`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@("`@("1T:&ES
M+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH(DE.4T525"!)3E1/("1S
M97%N86UE("AI9"D@5D%,5453("A.54Q,*2(I.PH@("`@("`@("`@("`D=&AI
M<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@("!I9B`H)')E<W5L
M="`]/3T@1$)?3TLI('L*("`@("`@("`@("`@("`@("1I9"`]($!S<6QI=&5?
M;&%S=%]I;G-E<G1?<F]W:60H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("`@("`@:68@*"1I9"`A/2`P*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1I9#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E:68@*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@
M("`@("`@("`@("`@("`@("`@("`@)')E<W5L="T^9V5T0V]D92@I(#T]($1"
M7T524D]27TY/4U5#2%1!0DQ%*0H@("`@("`@("`@("!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M
M92D["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!G971$8D9I;&53=&%T<R@I"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&9I;&4@<W1A=',@9F]R('1H92!C=7)R96YT
M(&1A=&%B87-E"B`@("`@*@H@("`@("H@4&]S<VEB;&4@87)G=6UE;G1S(&%R
M92!D978L(&EN;RP@;6]D92P@;FQI;FLL('5I9"P@9VED+"!R9&5V+"!S:7IE
M+`H@("`@("H@871I;64L(&UT:6UE+"!C=&EM92P@8FQK<VEZ92P@8FQO8VMS
M(&]R(&$@;G5M97)I8R!K97D@8F5T=V5E;@H@("`@("H@,"!A;F0@,3(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87)G("!T:&4@87)R87D@:V5Y
M(&9O<B!S=&%T<R@I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@86X@
M87)R87D@;VX@86X@=6YS<&5C:69I960@:V5Y+"!I;G1E9V5R(&]N(&$@<&%S
M<V5D"B`@("`@*B`@("`@("`@("`@("`@("!A<F<@86YD(&9A;'-E(&%T(&$@
M<W1A=',@97)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&)&:6QE4W1A
M=',H)&%R9R`]("<G*0H@("`@>PH@("`@("`@("1S=&%T<R`]('-T870H)'1H
M:7,M/F1S;ELG9&%T86)A<V4G72D["B`@("`@("`@:68@*"1S=&%T<R`]/2!F
M86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<U]A<G)A>2@D<W1A=',I*2!["B`@("`@("`@("`@(&EF
M("AI<U]N=6UE<FEC*"1A<F<I*2!["B`@("`@("`@("`@("`@("!I9B`H*"AI
M;G0I)&%R9R`\/2`Q,BD@)B`H*&EN="DD87)G(#X](#`I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T<ULD87)G(%T["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H=')I;2@D
M87)G*2P@)'-T871S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T
M<ULD87)G(%T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1S=&%T<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<V-A
M<&53:6UP;&4H*0H*("`@("\J*@H@("`@("H@17-C87!E<R!A('-T<FEN9R!A
M8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@1$)-4R=S('-T86YD87)D<PH@("`@
M("H*("`@("`J($EN(%-13&ET92P@=&AI<R!M86ME<R!T:&EN9W,@<V%F92!F
M;W(@:6YS97)T<R]U<&1A=&5S+"!B=70@;6%Y"B`@("`@*B!C875S92!P<F]B
M;&5M<R!W:&5N('!E<F9O<FUI;F<@=&5X="!C;VUP87)I<V]N<R!A9V%I;G-T
M(&-O;'5M;G,*("`@("`J(&-O;G1A:6YI;F<@8FEN87)Y(&1A=&$N(%-E92!T
M:&4*("`@("`J('M`;&EN:R!H='1P.B\O<&AP+FYE="]S<6QI=&5?97-C87!E
M7W-T<FEN9R!02%`@;6%N=6%L?2!F;W(@;6]R92!I;F9O+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<B`@=&AE('-T<FEN9R!T;R!B92!E<V-A
M<&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E<V-A<&5D
M('-T<FEN9PH@("`@("H*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XV+C$*("`@("`J($!S964@1$)?8V]M;6]N.CIE
M<V-A<&53:6UP;&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&53:6UP
M;&4H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@0'-Q;&ET95]E<V-A<&5?
M<W1R:6YG*"1S='(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO
M9&EF>4QI;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C
M;&%U<V5S('1O(&$@<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT
M($1"35,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<75E<GD@("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT
M("`@("1F<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@
M/2!T:&4@9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@
M("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@
M;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A
M('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E
M;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T
M(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H
M;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E
M;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75E
M<GD@<W1R:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@("H*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO
M9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!R971U<FX@(B1Q=65R>2!,24U)
M5"`D8V]U;G0@3T9&4T54("1F<F]M(CL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!M;V1I9GE1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S
M(&$@<75E<GD@<W1R:6YG(&9O<B!V87)I;W5S($1"35,@<W!E8VEF:6,@<F5A
M<V]N<PH@("`@("H*("`@("`J(%1H:7,@;&ET=&QE(&AA8VL@;&5T<R!Y;W4@
M:VYO=R!H;W<@;6%N>2!R;W=S('=E<F4@9&5L971E9`H@("`@("H@=VAE;B!R
M=6YN:6YG(&$@(D1%3$5412!&4D]-('1A8FQE(B!Q=65R>2X@($]N;'D@:6UP
M;&5M96YT960*("`@("`J(&EF('1H92!$0E]03U)404))3$E465]$14Q%5$5?
M0T]53E0@<&]R=&%B:6QI='D@;W!T:6]N(&ES(&]N+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@<75E<GD@<W1R:6YG('1O(&UO
M9&EF>0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@;6]D:69I
M960@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D<75E<GDI"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?1$5,151%7T-/54Y4*2!["B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7EQS*D1%3$5415QS*T923TU<<RLH7%,K*5QS*B0O:2<L("1Q
M=65R>2DI('L*("`@("`@("`@("`@("`@("1Q=65R>2`]('!R96=?<F5P;&%C
M92@G+UY<<RI$14Q%5$5<<RM&4D]-7',K*%Q3*RE<<RHD+R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T1%3$5412!&4D]-(%PQ
M(%=(15)%(#$],2<L("1Q=65R>2D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!S<6QI=&5286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R
M;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N
M="!P<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF
M('1H92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H
M97)E+B`@268@=&AI<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@
M=&AE($1"35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$
M0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M<F%I<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]S<6QI=&4Z.F5R<F]R3F%T
M:79E*"DL($1"7W-Q;&ET93HZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@<W%L:71E4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@
M("`@("`@("1N871I=F4@/2`D=&AI<RT^97)R;W).871I=F4H*3L*("`@("`@
M("!I9B`H)&5R<FYO(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1E<G)N;R`]
M("1T:&ES+3YE<G)O<D-O9&4H)&YA=&EV92D["B`@("`@("`@?0H*("`@("`@
M("`D97)R;W)C;V1E(#T@0'-Q;&ET95]L87-T7V5R<F]R*"1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@("`@("`D=7-E<FEN9F\@/2`B)&5R<F]R8V]D92`J*B`D
M=&AI<RT^;&%S=%]Q=65R>2(["@H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL("1U<V5R:6YF;RP@)&YA=&EV
M92D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).871I=F4H
M*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R
M(&UE<W-A9V4@<')O9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J"B`@
M("`@*B![0&EN=&5R;F%L(%1H:7,@:7,@=7-E9"!T;R!R971R:65V92!M;W)E
M(&UE86YI;F=F=6QL(&5R<F]R(&UE<W-A9V5S"B`@("`@*B!B96-A=7-E('-Q
M;&ET95]L87-T7V5R<F]R*"D@9&]E<R!N;W0@<')O=FED92!A9&5Q=6%T92!I
M;F9O+GU]"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!$0DU3
M)R!E<G)O<B!M97-S86=E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T
M:79E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L87-T97)R;W([
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)#;V1E*"D*"B`@
M("`O*BH*("`@("`J($1E=&5R;6EN97,@4$5!4CHZ1$(@97)R;W(@8V]D92!F
M<F]M('1H92!D871A8F%S92=S('1E>'0@97)R;W(@;65S<V%G90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R;7-G("!T:&4@97)R;W(@;65S
M<V%G92!R971U<FYE9"!F<F]M('1H92!D871A8F%S90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@=&AE($1"(&5R<F]R(&YU;6)E<@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E<G)O<D-O9&4H)&5R<F]R;7-G*0H@("`@>PH@("`@
M("`@('-T871I8R`D97)R;W)?<F5G97AP<SL*("`@("`@("!I9B`H(6ES<V5T
M*"1E<G)O<E]R96=E>'!S*2D@>PH@("`@("`@("`@("`D97)R;W)?<F5G97AP
M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)R]>;F\@<W5C:"!T86)L93HO
M)R`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@("`@("<O
M7FYO('-U8V@@:6YD97@Z+R<@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@
M("`@("`@("`@("`@)R]>*'1A8FQE?&EN9&5X*2`N*B!A;')E861Y(&5X:7-T
M<R0O)R`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@("`@
M("`@("<O4%))34%262!+15D@;75S="!B92!U;FEQ=64O:2<@/3X@1$)?15)2
M3U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@("<O:7,@;F]T('5N:7%U
M92\G(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@("`@("`G
M+V-O;'5M;G,@+BH@87)E(&YO="!U;FEQ=64O:2<@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`@("`@("`@("<O=6YI<75E;F5S<R!C;VYS=')A
M:6YT(&9A:6QE9"\G(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@
M("`@("`@("`G+VUA>2!N;W0@8F4@3E5,3"\G(#T^($1"7T524D]27T-/3E-4
M4D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@("`G+UYN;R!S=6-H(&-O
M;'5M;CHO)R`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@
M("`@("<O8V]L=6UN(&YO="!P<F5S96YT(&EN(&)O=&@@=&%B;&5S+VDG(#T^
M($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@("`@("`@)R]>;F5A
M<B`B+BHB.B!S>6YT87@@97)R;W(D+R<@/3X@1$)?15)23U)?4UE.5$%8+`H@
M("`@("`@("`@("`@("`@)R];,"TY72L@=F%L=65S(&9O<B!;,"TY72L@8V]L
M=6UN<R]I)R`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@
M("`@("`@("D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1E<G)O<E]R
M96=E>'!S(&%S("1R96=E>'`@/3X@)&-O9&4I('L*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)')E9V5X<"P@)&5R<F]R;7-G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1C;V1E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@("\O($9A;&P@8F%C:R!T;R!$0E]%4E)/4B!I9B!T:&5R92!W87,@
M;F\@;6%P<&EN9RX*("`@("`@("!R971U<FX@1$)?15)23U(["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@("`@("`@("`D<F5S=6QT("!A('-T<FEN
M9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4*("`@("`J($!P87)A
M;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M
M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I
M=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@
M("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I
M"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT
M+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B
M86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R
M96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@)&ED(#T@0'-Q;&ET95]A<G)A>5]Q=65R>2@D
M=&AI<RT^8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`B4%)!1TU!('1A8FQE7VEN9F\H)R1R97-U;'0G*3LB+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%-13$E415]!
M4U-/0RD["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("<G
M.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?3D]47T-!4$%"3$4L(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G5&AI<R!$0DU3(&-A;B!N;W0@
M;V)T86EN('1A8FQE26YF;R<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R!F<F]M(')E<W5L="!S971S)RD["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$
M0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?
M9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@
M("`D8V]U;G0@/2!C;W5N="@D:60I.PH@("`@("`@("1R97,@("`](&%R<F%Y
M*"D["@H@("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N
M=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@:68@
M*'-T<G!O<R@D:61;)&E=6R=T>7!E)UTL("<H)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`D8FET<R`](&5X<&QO9&4H)R@G+"`D:61;)&E=6R=T
M>7!E)UTI.PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D8FET<ULP73L*("`@
M("`@("`@("`@("`@("1L96X@(#T@<G1R:6TH)&)I='-;,5TL)RDG*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T>7!E(#T@)&ED
M6R1I75LG='EP92==.PH@("`@("`@("`@("`@("`@)&QE;B`@/2`P.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D9FQA9W,@/2`G)SL*("`@("`@("`@
M("`@:68@*"1I9%LD:5U;)W!K)UTI('L*("`@("`@("`@("`@("`@("1F;&%G
M<R`N/2`G<')I;6%R>5]K97D@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&ED6R1I75LG;F]T;G5L;"==*2!["B`@("`@("`@("`@("`@("`D
M9FQA9W,@+CT@)VYO=%]N=6QL("<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1I9%LD:5U;)V1F;'1?=F%L=64G72`A/3T@;G5L;"D@>PH@("`@
M("`@("`@("`@("`@)&9L86=S("X]("=D969A=6QT7R<@+B!R87=U<FQE;F-O
M9&4H)&ED6R1I75LG9&9L=%]V86QU92==*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D9FQA9W,@/2!T<FEM*"1F;&%G<RD["@H@("`@("`@("`@("`D
M<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D
M8V%S95]F=6YC*"1R97-U;'0I+`H@("`@("`@("`@("`@("`@)VYA;64G("`]
M/B`D8V%S95]F=6YC*"1I9%LD:5U;)VYA;64G72DL"B`@("`@("`@("`@("`@
M("`G='EP92<@(#T^("1T>7!E+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]
M/B`D;&5N+`H@("`@("`@("`@("`@("`@)V9L86=S)R`]/B`D9FQA9W,L"B`@
M("`@("`@("`@("D["@H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),
M14E.1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;
M)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@
M("`@("`@("`@("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T
M86)L92==75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@
M("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R:6YG(&YE961E9"!F;W(@;&ES
M=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T<PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD(&]F(&]B:F5C=',@>6]U('=A
M;G0@=&\@<F5T<FEE=F4*("`@("`J($!P87)A;2!A<G)A>2`@)&%R9W,@(%-1
M3$E412!$4DE615(@3TY,63H@82!P<FEV871E(&%R<F%Y(&]F(&%R9W5M96YT
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@('5S960@8GD@=&AE(&=E
M=%-P96-I86Q1=65R>2@I+B`@1&\@;F]T('5S90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('1H:7,@9&ER96-T;'DN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@
M=&AE(&1R:79E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U
M<'!O<G0@=&AE(&]B:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T
M3&ES=$]F*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y
M*"1T>7!E+"`D87)G<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D87)G<RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=N;R!K97D@<W!E8VEF:65D)RP@;G5L;"P@;G5L;"P@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=!<F=U
M;65N="!H87,@=&\@8F4@86X@87)R87DN)RD["B`@("`@("`@?0H*("`@("`@
M("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VUA<W1E<B<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"`J($923TT@<W%L:71E
M7VUA<W1E<CLG.PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@
M("`@("`@("`@<F5T=7)N(")314Q%0U0@;F%M92!&4D]-('-Q;&ET95]M87-T
M97(@5TA%4D4@='EP93TG=&%B;&4G("(*("`@("`@("`@("`@("`@("`@("`@
M("`N("=53DE/3B!!3$P@4T5,14-4(&YA;64@1E)/32!S<6QI=&5?=&5M<%]M
M87-T97(@)PH@("`@("`@("`@("`@("`@("`@("`@("X@(E=(15)%('1Y<&4]
M)W1A8FQE)R!/4D1%4B!"62!N86UE.R(["B`@("`@("`@("`@(&-A<V4@)W-C
M:&5M82<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!S<6P@1E)/
M32`H4T5,14-4("H@1E)/32!S<6QI=&5?;6%S=&5R("<*("`@("`@("`@("`@
M("`@("`@("`@("`N("=53DE/3B!!3$P@4T5,14-4("H@1E)/32!S<6QI=&5?
M=&5M<%]M87-T97(I("<*("`@("`@("`@("`@("`@("`@("`@("`N(")72$52
M12!T>7!E(3TG;65T82<@(@H@("`@("`@("`@("`@("`@("`@("`@("X@)T]2
M1$52($)9('1B;%]N86UE+"!T>7!E($1%4T,L(&YA;64[)SL*("`@("`@("`@
M("`@8V%S92`G<V-H96UA>"<Z"B`@("`@("`@("`@(&-A<V4@)W-C:&5M85]X
M)SH*("`@("`@("`@("`@("`@("\J"B`@("`@("`@("`@("`@("`@*B!5<V4@
M;&EK93H*("`@("`@("`@("`@("`@("`J("1R97,@/2`D9&(M/G%U97)Y*"1D
M8BT^9V5T4W!E8VEA;%%U97)Y*"=S8VAE;6%?>"<L"B`@("`@("`@("`@("`@
M("`@*B`@("`@("`@("`@("`@("`@("!A<G)A>2@G=&%B;&4G(#T^("=T86)L
M93,G*2DI.PH@("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@("!R
M971U<FX@)U-%3$5#5"!S<6P@1E)/32`H4T5,14-4("H@1E)/32!S<6QI=&5?
M;6%S=&5R("<*("`@("`@("`@("`@("`@("`@("`@("`N("=53DE/3B!!3$P@
M4T5,14-4("H@1E)/32!S<6QI=&5?=&5M<%]M87-T97(I("<*("`@("`@("`@
M("`@("`@("`@("`@("`N(")72$5212!T8FQ?;F%M92!,24M%("=[)&%R9W-;
M)W1A8FQE)UU])R`B"B`@("`@("`@("`@("`@("`@("`@("`@+B`B04Y$('1Y
M<&4A/2=M971A)R`B"B`@("`@("`@("`@("`@("`@("`@("`@+B`G3U)$15(@
M0ED@='EP92!$15-#+"!N86UE.R<["B`@("`@("`@("`@(&-A<V4@)V%L=&5R
M)SH*("`@("`@("`@("`@("`@("\J"B`@("`@("`@("`@("`@("`@*B!344QI
M=&4@9&]E<R!N;W0@<W5P<&]R="!!3%1%4B!404),13L@=&AI<R!I<R!A(&AE
M;'!E<B!Q=65R>0H@("`@("`@("`@("`@("`@("H@=&\@:&%N9&QE('1H:7,N
M("=T86)L92<@<F5P<F5S96YT<R!T:&4@=&%B;&4@;F%M92P@)W)O=W,G"B`@
M("`@("`@("`@("`@("`@*B!T:&4@;F5W<R!R;W=S('1O(&-R96%T92P@)W-A
M=F4G('1H92!R;W<H<RD@=&\@:V5E<"!?=VET:%\*("`@("`@("`@("`@("`@
M("`J('1H92!D871A+@H@("`@("`@("`@("`@("`@("H*("`@("`@("`@("`@
M("`@("`J(%5S92!L:6ME.@H@("`@("`@("`@("`@("`@("H@)&%R9W,@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`J("`@("`G=&%B;&4G(#T^("1T86)L
M92P*("`@("`@("`@("`@("`@("`J("`@("`G<F]W<R<@(#T^(")I9"!)3E1%
M1T52(%!224U!4ED@2T59+"!F:7)S=&YA;64@5$585"P@<W5R;F%M92!415A4
M+"!D871E=&EM92!415A4(BP*("`@("`@("`@("`@("`@("`J("`@("`G<V%V
M92<@(#T^(").54Q,+"!T:71E;"P@8V]N=&5N="P@9&%T971I;64B"B`@("`@
M("`@("`@("`@("`@*B`I.PH@("`@("`@("`@("`@("`@("H@)')E<R`]("1D
M8BT^<75E<GDH("1D8BT^9V5T4W!E8VEA;%%U97)Y*"=A;'1E<B<L("1A<F=S
M*2D["B`@("`@("`@("`@("`@("`@*B\*("`@("`@("`@("`@("`@("1R;W=S
M(#T@<W1R='(H)&%R9W-;)W)O=W,G72P@)'1H:7,M/FME>7=O<F1S*3L*"B`@
M("`@("`@("`@("`@("`D<2`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("="14=)3B!44D%.4T%#5$E/3B<L"B`@("`@("`@("`@("`@("`@("`@(D-2
M14%412!414U03U)!4ED@5$%"3$4@>R1A<F=S6R=T86)L92==?5]B86-K=7`@
M*'LD87)G<ULG<F]W<R==?2DB+`H@("`@("`@("`@("`@("`@("`@("))3E-%
M4E0@24Y43R![)&%R9W-;)W1A8FQE)UU]7V)A8VMU<"!314Q%0U0@>R1A<F=S
M6R=S879E)UU]($923TT@>R1A<F=S6R=T86)L92==?2(L"B`@("`@("`@("`@
M("`@("`@("`@(D123U`@5$%"3$4@>R1A<F=S6R=T86)L92==?2(L"B`@("`@
M("`@("`@("`@("`@("`@(D-214%412!404),12![)&%R9W-;)W1A8FQE)UU]
M("A[)&%R9W-;)W)O=W,G77TI(BP*("`@("`@("`@("`@("`@("`@("`B24Y3
M15)4($E.5$\@>R1A<F=S6R=T86)L92==?2!314Q%0U0@>R1R;W=S?2!&4D]-
M('LD87)G<ULG=&%B;&4G77U?8F%C:W5P(BP*("`@("`@("`@("`@("`@("`@
M("`B1%)/4"!404),12![)&%R9W-;)W1A8FQE)UU]7V)A8VMU<"(L"B`@("`@
M("`@("`@("`@("`@("`@)T-/34U)5"<L"B`@("`@("`@("`@("`@("`I.PH*
M("`@("`@("`@("`@("`@("\J"B`@("`@("`@("`@("`@("`@*B!4:&ES(&ES
M(&$@9&ER='D@:&%C:RP@<VEN8V4@=&AE(&%B;W9E('%U97)Y('=I;&P@;F]T
M(&=E=`H@("`@("`@("`@("`@("`@("H@97AE8W5T960@=VET:"!A('-I;F=L
M92!Q=65R>2!C86QL('-O(&AE<F4@=&AE('%U97)Y(&UE=&AO9`H@("`@("`@
M("`@("`@("`@("H@=VEL;"!B92!C86QL960@9&ER96-T;'D@86YD(')E='5R
M;B!A('-E;&5C="!I;G-T96%D+@H@("`@("`@("`@("`@("`@("HO"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<2!A<R`D<75E<GDI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`B4T5,14-4("H@1E)/32![
M)&%R9W-;)W1A8FQE)UU].R(["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@
M+R\@?7U]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H
M.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O9&)A<V4N<&AP
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S8V
M,#$`,3`U,34T,S$P-3<`,#$W-#(S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*
M+RHJ"B`J(%1H92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@9&)A<V4@97AT
M96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H(&1"87-E(&1A=&%B87-E
M<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G
M;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@
M("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO
M<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&1B87-E+G!H
M<"QV(#$N,SD@,C`P-2\P,B\Q.2`R,SHR-3HR-2!D86YI96QC($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@
M*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C
M86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM
M;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@
M:6YT97)A8W0@=VET:"!02%`G<R!D8F%S92!E>'1E;G-I;VX*("H@9F]R(&EN
M=&5R86-T:6YG('=I=&@@9$)A<V4@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE
M=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N
M8V]M/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7V1B87-E(&5X=&5N9',@1$)?8V]M
M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4
M:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@
M)V1B87-E)SL*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@
M=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N
M>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A
M>"`]("=D8F%S92<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET:65S
M(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4:&4@
M)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO;B!T
M:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O
M<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P<&]R
M=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@96QE
M;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@9F5T
M8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L=&5R
M('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W<PH@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F96%T
M=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@("`]/B!F86QS
M92P*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M)VYU;7)O=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN96-T)R`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS
M92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M)W1R86YS86-T:6]N<R<@(#T^(&9A;'-E+`H@("`@*3L*"B`@("`O*BH*("`@
M("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@=&\@1$(@97)R
M;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1E
M<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`I.PH*("`@("\J*@H@("`@("H@
M5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@8GD@4$A0"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D8V]N;F5C=&EO
M;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I;VX@9F]R(&-O
M;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@("H@
M02!M96%N<R!O9B!E;75L871I;F<@<F5S=6QT(')E<V]U<F-E<PH@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)')E<U]R;W<@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE('%U86YT:71Y(&]F(')E<W5L=',@<V\@
M9F%R"B`@("`@*@H@("`@("H@1F]R(&5M=6QA=&EN9R!R97-U;'0@<F5S;W5R
M8V5S+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V
M87(@)')E<W5L="`](#`["@H@("`@+RHJ"B`@("`@*B!-87!S(&1B87-E(&1A
M=&$@='EP92!I9"=S('1O(&AU;6%N(')E861A8FQE('-T<FEN9W,*("`@("`J
M"B`@("`@*B!4:&4@:'5M86X@<F5A9&%B;&4@=F%L=65S(&%R92!B87-E9"!O
M;B!T:&4@;W5T<'5T(&]F(%!(4"=S"B`@("`@*B!D8F%S95]G971?:&5A9&5R
M7VEN9F\H*2!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B!`<VEN8V4@4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XW+C`*("`@("`J+PH@("`@=F%R("1T>7!E<R`](&%R<F%Y*`H@("`@("`@
M("=#)R`]/B`G8VAA<F%C=&5R)RP*("`@("`@("`G1"<@/3X@)V1A=&4G+`H@
M("`@("`@("=,)R`]/B`G8F]O;&5A;B<L"B`@("`@("`@)TTG(#T^("=M96UO
M)RP*("`@("`@("`G3B<@/3X@)VYU;6)E<B<L"B`@("`I.PH*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AI
M<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO
M:V)D/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!$0E]D8F%S92@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O
M;6UO;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H
M*0H*("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@86YD
M(&-R96%T92!I="!I9B!I="!D;V5S;B=T(&5X:7-T"B`@("`@*@H@("`@("H@
M1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N
M;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@4$5!4B!$0B=S(&1B87-E
M(&1R:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($133B!O<'1I
M;VYS.@H@("`@("H@("`K(&UO9&4@("`@06X@:6YT96=E<B!S<&5C:69Y:6YG
M('1H92!R96%D+W=R:71E(&UO9&4@=&\@=7-E"B`@("`@*B`@("`@("`@("`@
M("`@*#`@/2!R96%D(&]N;'DL(#$@/2!W<FET92!O;FQY+"`R(#T@<F5A9"]W
M<FET92DN"B`@("`@*B`@("`@("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%
M05(@1$(@,2XW+C`N"B`@("`@*B`@("L@9FEE;&1S("!!;B!A<G)A>2!O9B!A
M<G)A>7,@=&AA="!02%`G<R!D8F%S95]C<F5A=&4H*2!F=6YC=&EO;B!N965D
M<PH@("`@("H@("`@("`@("`@("`@('1O(&-R96%T92!A(&YE=R!D871A8F%S
M92X@(%1H:7,@:6YF;W)M871I;VX@:7,@=7-E9"!I9B!T:&4*("`@("`J("`@
M("`@("`@("`@("!D0F%S92!F:6QE('-P96-I9FEE9"!I;B!T:&4@(F1A=&%B
M87-E(B!S96=M96YT(&]F('1H92!$4TX*("`@("`J("`@("`@("`@("`@("!D
M;V5S(&YO="!E>&ES="X@($9O<B!M;W)E(&EN9F\L('-E92!T:&4@4$A0(&UA
M;G5A;"=S"B`@("`@*B`@("`@("`@("`@("`@>T!L:6YK(&AT='`Z+R]P:'`N
M;F5T+V1B87-E7V-R96%T92!D8F%S95]C<F5A=&4H*7T@<&%G92X*("`@("`J
M("`@("`@("`@("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C<N,"X*
M("`@("`J"B`@("`@*B!%>&%M<&QE(&]F(&AO=R!T;R!C;VYN96-T(&%N9"!E
M<W1A8FQI<V@@82!N97<@9$)A<V4@9FEL92!I9B!N96-E<W-A<GDZ"B`@("`@
M*B`\8V]D93X*("`@("`J(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`J
M"B`@("`@*B`D9'-N(#T@87)R87DH"B`@("`@*B`@("`@)W!H<'1Y<&4G("`]
M/B`G9&)A<V4G+`H@("`@("H@("`@("=D871A8F%S92<@/3X@)R]P871H+V%N
M9"]N86UE+V]F+V1B87-E+V9I;&4G+`H@("`@("H@("`@("=M;V1E)R`@("`@
M/3X@,BP*("`@("`J("`@("`G9FEE;&1S)R`@(#T^(&%R<F%Y*`H@("`@("H@
M("`@("`@("!A<G)A>2@G82<L("=.)RP@-2P@,"DL"B`@("`@*B`@("`@("`@
M(&%R<F%Y*"=B)RP@)T,G+"`T,"DL"B`@("`@*B`@("`@("`@(&%R<F%Y*"=C
M)RP@)T,G+"`R-34I+`H@("`@("H@("`@("`@("!A<G)A>2@G9"<L("=#)RP@
M,C`I+`H@("`@("H@("`@("DL"B`@("`@*B`I.PH@("`@("H@)&]P=&EO;G,@
M/2!A<G)A>2@*("`@("`J("`@("`G9&5B=6<G("`@("`@(#T^(#(L"B`@("`@
M*B`@("`@)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465]!3$PL"B`@
M("`@*B`I.PH@("`@("H*("`@("`J("1D8B`])B!$0CHZ8V]N;F5C="@D9'-N
M+"`D;W!T:6]N<RD["B`@("`@*B!I9B`H4$5!4CHZ:7-%<G)O<B@D9&(I*2![
M"B`@("`@*B`@("`@9&EE*"1D8BT^9V5T365S<V%G92@I*3L*("`@("`J('T*
M("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1S
M;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@*B!`<&%R86T@
M8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO;B!B92!P
M97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O
M;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T96YT(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL;V%D17AT96YS:6]N
M*"=D8F%S92<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N
M6R=D8G-Y;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]
M("1D<VY;)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@
M("`@("`J(%1U<FX@=')A8VM?97)R;W)S(&]N(&9O<B!E;G1I<F4@<V-R:7!T
M('-I;F-E("1P:'!?97)R;W)M<V<*("`@("`@("`@*B!I<R!T:&4@;VYL>2!W
M87D@=&\@9FEN9"!E<G)O<G,@9G)O;2!T:&4@9&)A<V4@97AT96YS:6]N+@H@
M("`@("`@("`J+PH@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I
M.PH@("`@("`@("1P:'!?97)R;W)M<V<@/2`G)SL*"B`@("`@("`@:68@*"%F
M:6QE7V5X:7-T<R@D9'-N6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^9'-N6R=M;V1E)UT@/2`R.PH@("`@("`@("`@("!I9B`H96UP='DH
M)&1S;ELG9FEE;&1S)UTI('Q\("%I<U]A<G)A>2@D9'-N6R=F:65L9',G72DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T:&4@9&)A<V4@
M9FEL92!D;V5S(&YO="!E>&ES="!A;F0@)PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)VET(&-O=6QD(&YO="!B92!C<F5A
M=&5D(&)E8V%U<V4@)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)W1H92`B9FEE;&1S(B!E;&5M96YT(&]F('1H92!$4TX@
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@
M)VES(&YO="!P<F]P97)L>2!S970G*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!D8F%S95]C<F5A=&4H)&1S;ELG
M9&%T86)A<V4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D<VY;)V9I96QD<R==*3L*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL
M(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1H92!D8F%S92!F:6QE(&1O97,@;F]T(&5X:7-T(&%N9"`G
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M=&AE(&%T=&5M<'0@=&\@8W)E871E(&ET(&9A:6QE9#H@)PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'!H<%]E<G)O<FUS
M9RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3YD<VY;)VUO9&4G72DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YD<VY;)VUO9&4G72`](#`["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`9&)A<V5?;W!E;B@D
M9'-N6R=D871A8F%S92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YD<VY;)VUO9&4G72D["B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!
M24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P:'!?97)R;W)M<V<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J
M($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O
M;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@("1R970@/2!`9&)A<V5?8VQO<V4H)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@
M("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R`F<75E<GDH*0H*("`@(&9U;F-T:6]N("9Q=65R>2@D<75E<GD@/2!N=6QL
M*0H@("`@>PH@("`@("`@("\O(&5M=6QA=&4@<F5S=6QT(')E<V]U<F-E<PH@
M("`@("`@("1T:&ES+3YR97-?<F]W6RAI;G0I)'1H:7,M/G)E<W5L=%T@/2`P
M.PH@("`@("`@("1T;7`@/28@;F5W($1"7W)E<W5L="@D=&AI<RP@)'1H:7,M
M/G)E<W5L="LK*3L*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@
M4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@9VEV
M96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y
M(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@
M*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA
M=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@
M=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z
M.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H@0'!A
M<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@87)R87D@
M=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@("`@)&9E
M=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@:6YD
M97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@=&AE(')O
M=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N
M('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@
M("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU
M;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@/3T](&YU;&PI
M('L*("`@("`@("`@("`@)')O=VYU;2`]("1T:&ES+3YR97-?<F]W6RAI;G0I
M)')E<W5L=%TK*SL*("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@
M)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@("`@)&%R<B`]($!D
M8F%S95]G971?<F5C;W)D7W=I=&A?;F%M97,H)'1H:7,M/F-O;FYE8W1I;VXL
M("1R;W=N=6TI.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O
M<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@)&%R
M<BD@>PH@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?
M8V%S92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1A<G(@/2!`9&)A<V5?9V5T7W)E8V]R
M9"@D=&AI<RT^8V]N;F5C=&EO;BP@)')O=VYU;2D["B`@("`@("`@?0H@("`@
M("`@(&EF("@A)&%R<BD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET
M>2==("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H
M:7,M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)4
M04))3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU
M;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T
M;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I(&EN<W1E860N
M("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C
M875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E
M<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U#;VQS*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D9F]O*0H@("`@>PH@("`@
M("`@(')E='5R;B!`9&)A<V5?;G5M9FEE;&1S*"1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S
M=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N
M="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L
M=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIN=6U2;W=S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W
M<R@D9F]O*0H@("`@>PH@("`@("`@(')E='5R;B!`9&)A<V5?;G5M<F5C;W)D
M<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@<75O=&53;6%R="@I"@H@("`@+RHJ"B`@("`@*B!&;W)M871S(&EN
M<'5T('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!I;B!A('%U97)Y"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;B`@=&AE(&1A=&$@=&\@8F4@9F]R
M;6%T=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@=&AE(&9O<FUA
M='1E9"!D871A+B`@5&AE(&9O<FUA="!D97!E;F1S(&]N('1H92!I;G!U="=S
M"B`@("`@*B`@("`@("`@("`@("`@("`@4$A0('1Y<&4Z"B`@("`@*B`@("`@
M("`@("`@("`@("`@*R!N=6QL(#T@=&AE('-T<FEN9R`\<V%M<#Y.54Q,/"]S
M86UP/@H@("`@("H@("`@("`@("`@("`@("`@("L@8F]O;&5A;B`](#QS86UP
M/E0\+W-A;7`^(&EF('1R=64@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M(#QS86UP/D8\+W-A;7`^(&EF(&9A;'-E+B`@57-E('1H92`\:V)D/DQO9VEC
M86P\+VMB9#X*("`@("`J("`@("`@("`@("`@("`@("`@(&1A=&$@='EP92X*
M("`@("`J("`@("`@("`@("`@("`@("`K(&EN=&5G97(@;W(@9&]U8FQE(#T@
M=&AE('5N<75O=&5D(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("L@
M;W1H97(@*&EN8VQU9&EN9R!S=')I;F=S(&%N9"!N=6UE<FEC('-T<FEN9W,I
M(#T*("`@("`J("`@("`@("`@("`@("`@("`@('1H92!D871A('=I=&@@<VEN
M9VQE('%U;W1E<R!E<V-A<&5D(&)Y('!R96-E961I;F<*("`@("`J("`@("`@
M("`@("`@("`@("`@('-I;F=L92!Q=6]T97,@=&AE;B!T:&4@=VAO;&4@<W1R
M:6YG(&ES(&5N8V%P<W5L871E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M8F5T=V5E;B!S:6YG;&4@<75O=&5S"B`@("`@*@H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!Q=6]T95-M87)T*"1I;BD*("`@('L*("`@("`@("!I9B`H:7-?:6YT*"1I
M;BD@?'P@:7-?9&]U8FQE*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M;CL*("`@("`@("!](&5L<V5I9B`H:7-?8F]O;"@D:6XI*2!["B`@("`@("`@
M("`@(')E='5R;B`D:6X@/R`G5"<@.B`G1B<["B`@("`@("`@?2!E;'-E:68@
M*&ES7VYU;&PH)&EN*2D@>PH@("`@("`@("`@("!R971U<FX@)TY53$PG.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`B)R(@+B`D=&AI
M<RT^97-C87!E4VEM<&QE*"1I;BD@+B`B)R(["B`@("`@("`@?0H@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T('1H92!C=7)R96YT(&1A
M=&%B87-E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1R97-U;'0@(%1(
M25,@25,@54Y54T5$($E.($1"05-%+B`@5&AE(&-U<G)E;G0@9&%T86)A<V4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I<R!E>&%M:6YE9"!R96=A
M<F1L97-S(&]F('=H870@:7,@<')O=FED960@:&5R92X*("`@("`J($!P87)A
M;2!I;G0@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@
M=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@
M("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B!`
M<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT(#T@;G5L;"P@
M)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V1B87-E7V=E=%]H96%D97)?:6YF;R<I*2!["B`@("`@("`@("`@("1I
M9"`]($!D8F%S95]G971?:&5A9&5R7VEN9F\H)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@("`@("!I9B`H(21I9"`F)B`D<&AP7V5R<F]R;7-G*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J
M(%1H:7,@<V5G;65N="!F;W(@4$A0(#0@:7,@;&]O<V5L>2!B87-E9"!O;B!C
M;V1E(&)Y"B`@("`@("`@("`@("`J($AA9&D@4G5S:6%H(#QD965G;W-`>6%H
M;V\N8V]M/B!I;B!T:&4@8V]M;65N=',@;VX*("`@("`@("`@("`@("H@=&AE
M(&1"87-E(')E9F5R96YC92!P86=E(&EN('1H92!02%`@;6%N=6%L+@H@("`@
M("`@("`@("`@*B\*("`@("`@("`@("`@)&1B(#T@0&9O<&5N*"1T:&ES+3YD
M<VY;)V1A=&%B87-E)UTL("=R)RD["B`@("`@("`@("`@(&EF("@A)&1B*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?
M15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP7V5R<F]R;7-G
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&ED(#T@87)R87DH*3L*
M("`@("`@("`@("`@)&D@(#T@,#L*"B`@("`@("`@("`@("1L:6YE(#T@9G)E
M860H)&1B+"`S,BD["B`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9&(I*2![
M"B`@("`@("`@("`@("`@("`D;&EN92`](&9R96%D*"1D8BP@,S(I.PH@("`@
M("`@("`@("`@("`@:68@*'-U8G-T<B@D;&EN92P@,"P@,2D@/3T@8VAR*#$S
M*2D@>PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<&]S(#T@<W1R<&]S
M*'-U8G-T<B@D;&EN92P@,"P@,3`I+"!C:'(H,"DI.PH@("`@("`@("`@("`@
M("`@("`@("1P;W,@/2`H)'!O<R`]/2`P(#\@,3`@.B`D<&]S*3L*("`@("`@
M("`@("`@("`@("`@("`D:61;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=N86UE)R`@(#T^('-U8G-T<B@D;&EN92P@,"P@)'!O<RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@(#T^("1T:&ES+3YT
M>7!E<UMS=6)S='(H)&QI;F4L(#$Q+"`Q*5TL"B`@("`@("`@("`@("`@("`@
M("`@("`@("=L96YG=&@G(#T^(&]R9"AS=6)S='(H)&QI;F4L(#$V+"`Q*2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("=P<F5C:7-I;VXG(#T^(&]R9"AS
M=6)S='(H)&QI;F4L(#$W+"`Q*2DL"B`@("`@("`@("`@("`@("`@("`@*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1I*RL["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&9C;&]S92@D9&(I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@("1C87-E
M7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@("`@
M("`@)')E<R`@(#T@87)R87DH*3L*("`@("`@("`D8V]U;G0@/2!C;W5N="@D
M:60I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@("`@("`@)')E<ULG
M;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@('T*"B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1R
M97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("1T
M:&ES+3YD<VY;)V1A=&%B87-E)UTL"B`@("`@("`@("`@("`@("`G;F%M92<@
M(#T^("1C87-E7V9U;F,H)&ED6R1I75LG;F%M92==*2P*("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)&ED6R1I75LG='EP92==+`H@("`@("`@("`@("`@
M("`@)VQE;B<@("`]/B`D:61;)&E=6R=L96YG=&@G72P*("`@("`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<*("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@
M("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)
M3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R
M=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R97,["B`@("!]"@H@("`@+R\@?7U]"GT*"B\J"B`J($QO8V%L('9A<FEA
M8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J
M($5N9#H*("HO"@H_/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R\`````
M````````````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#4W`#`Q-C`V-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O3&]G+V-O;7!O<VET92YP:'``````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3$W-C<`,3`U,34T,S$P-3<`,#(P-C$Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O8V]M
M<&]S:71E+G!H<"QV(#$N,C8@,C`P-2\P."\R-"`P-3HP.3HT-2!J;VX@17AP
M("0*("H@)$AO<F1E.B!H;W)D92]L:6(O3&]G+V-O;7!O<VET92YP:'`L=B`Q
M+C(@,C`P,"\P-B\R."`R,3HS-CHQ,R!J;VX@17AP("0*("H*("H@0'9E<G-I
M;VX@)%)E=FES:6]N.B`Q+C(V("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ
M"B`J(%1H92!,;V=?8V]M<&]S:71E.CH@8VQA<W,@:6UP;&5M96YT<R!A($-O
M;7!O<VET92!P871T97)N('=H:6-H"B`J(&%L;&]W<R!M=6QT:7!L92!,;V<@
M:6UP;&5M96YT871I;VYS('1O(')E8V5I=F4@=&AE('-A;64@979E;G1S+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J"B`J
M($!S:6YC92!(;W)D92`Q+C,*("H@0'-I;F-E($QO9R`Q+C`*("H@0'!A8VMA
M9V4@3&]G"B`J"B`J($!E>&%M<&QE(&-O;7!O<VET92YP:'`@("!5<VEN9R!T
M:&4@8V]M<&]S:71E(&AA;F1L97(N"B`J+PIC;&%S<R!,;V=?8V]M<&]S:71E
M(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@07)R87D@:&]L9&EN9R!A
M;&P@;V8@=&AE($QO9R!I;G-T86YC97,@=&\@=VAI8V@@;&]G(&5V96YT<R!S
M:&]U;&0@8F4*("`@("`J('-E;G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V-H
M:6QD<F5N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W(&-O;7!O<VET92!,;V<@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("`@)&YA;64@("`@("`@5&AI<R!P87)A;65T97(@:7,@
M:6=N;W)E9"X*("`@("`J($!P87)A;2!B;V]L96%N("`@)&ED96YT("`@("`@
M5&AI<R!P87)A;65T97(@:7,@:6=N;W)E9"X*("`@("`J($!P87)A;2!B;V]L
M96%N("`@)&-O;F8@("`@("`@5&AI<R!P87)A;65T97(@:7,@:6=N;W)E9"X*
M("`@("`J($!P87)A;2!B;V]L96%N("`@)&QE=F5L("`@("`@5&AI<R!P87)A
M;65T97(@:7,@:6=N;W)E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?8V]M<&]S:71E*"1N86UE+"`D
M:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@
M("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@3W!E;G,@=&AE(&-H:6QD(&-O;FYE8W1I;VYS+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&]P96XH
M*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960I('L*("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D:60@/3X@)&-H
M:6QD*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H:6QD<F5N6R1I9%TM
M/F]P96XH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]P
M96YE9"`]('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M0VQO<V5S(&%N>2!C:&EL9"!I;G-T86YC97,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V-H:6QD<F5N(&%S("1I9"`]/B`D8VAI;&0I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;)&ED72T^8VQO<V4H
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]
M(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9L=7-H
M97,@86QL(&]P96X@8VAI;&0@:6YS=&%N8V5S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N."XR"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9L=7-H*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/E]O<&5N960I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&EL
M9')E;B!A<R`D:60@/3X@)&-H:6QD*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-H:6QD<F5N6R1I9%TM/F9L=7-H*"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R`D;65S<V%G92!A
M;F0@)'!R:6]R:71Y('1O(&5A8V@@8VAI;&0@;V8@=&AI<R!C;VUP;W-I=&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`@("`D;65S<V%G92`@("!3
M=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@("`D<')I;W)I='D@("`H;W!T:6]N86PI(%1H92!P
M<FEO<FET>2!O9B!T:&4@;65S<V%G92X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@5F%L:60@=F%L=65S(&%R93H@4$5!4E],3T=?14U%
M4D<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?
M3$]'7T%,15)4+"!014%27TQ/1U]#4DE4+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)
M3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?
M3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T1%0E5'+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@96YT<GD@:7,@
M<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO
M<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@82!P<FEO<FET>2!H
M87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F875L="!V86QU92X@
M*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@("`@
M("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@("`@?0H*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H:6QD<F5N(&%S("1I9"`]/B`D
M8VAI;&0I('L*("`@("`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD:61=+3YL
M;V<H)&UE<W-A9V4L("1P<FEO<FET>2D["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y
M+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@=&AI
M<R!I<R!A(&-O;7!O<VET92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@=&AI<R!I<R!A(&-O;7!O<VET92!C;&%S<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!I
M<T-O;7!O<VET92@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S('1H:7,@:61E;G1I9FEC871I;VX@<W1R
M:6YG(&9O<B!A;&P@;V8@=&AI<R!C;VUP;W-I=&4G<R!C:&EL9')E;BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1I9&5N="`@("`@(%1H92!N
M97<@:61E;G1I9FEC871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@($QO9R`Q+C8N-PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S971)9&5N="@D:61E;G0I"B`@("!["B`@("`@("`@+RH@
M0V%L;"!O=7(@8F%S92!C;&%S<R=S('-E=$ED96YT*"D@;65T:&]D+B`J+PH@
M("`@("`@('!A<F5N=#HZ<V5T261E;G0H)&ED96YT*3L*"B`@("`@("`@+RH@
M+BXN(&%N9"!T:&5N(&-A;&P@<V5T261E;G0H*2!O;B!A;&P@;V8@;W5R(&-H
M:6QD<F5N+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAI;&1R96X@
M87,@)&ED(#T^("1C:&EL9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-H:6QD
M<F5N6R1I9%TM/G-E=$ED96YT*"1I9&5N="D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A($QO9R!I;G-T86YC92!T;R!T:&4@;&ES
M="!O9B!C:&EL9')E;BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("`@
M("1C:&EL9"`@("`@(%1H92!,;V<@:6YS=&%N8V4@=&\@861D+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@3&]G(&EN<W1A
M;F-E('=A<R!S=6-C97-S9G5L;'D@861D960N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@861D0VAI;&0H)B1C
M:&EL9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=&AI<R!I<R!A($QO
M9R!I;G-T86YC92X@*B\*("`@("`@("!I9B`H(6ES7V$H)&-H:6QD+"`G3&]G
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]C:&EL9')E;ELD8VAI;&0M/E]I9%T@/2`F)&-H:6QD
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V97,@82!,;V<@:6YS=&%N8V4@9G)O;2!T:&4@;&ES="!O9B!C:&EL
M9')E;BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("`@("1C:&EL9"`@
M("`@(%1H92!,;V<@:6YS=&%N8V4@=&\@<F5M;W9E+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@3&]G(&EN<W1A;F-E('=A
M<R!S=6-C97-S9G5L;'D@<F5M;W9E9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5#:&EL9"@D8VAI
M;&0I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1C:&EL9"P@)TQO9R<I('Q\
M("%I<W-E="@D=&AI<RT^7V-H:6QD<F5N6R1C:&EL9"T^7VED72DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@=6YS
M970H)'1H:7,M/E]C:&EL9')E;ELD8VAI;&0M/E]I9%TI.PH*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"GT*````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+TQO9R]D865M;VXN<&AP````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,#,T`#$P-3$U-#,Q,#4W`#`R
M,#`T,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+R`D260Z(&1A96UO;BYP:'`L=B`Q+C(@,C`P-2\P,B\R-B`Q
M-#HT.#HU."!C:&%G96YB=2!%>'`@)`H*+RHJ"B`J(%1H92!,;V=?9&%E;6]N
M(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO
M9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H:6-H('-E;F1S(&UE<W-A9V5S('1O
M('-Y<VQO9R!D865M;VX@;VX@54Y)6"UL:6ME(&UA8VAI;F5S+@H@*B!4:&ES
M(&-L87-S('5S97,@=&AE('-Y<VQO9R!P<F]T;V-O;#H@:'1T<#HO+W=W=RYI
M971F+F]R9R]R9F,O<F9C,S$V-"YT>'0*("H*("H@0&%U=&AO<B`@0F%R="!V
M86X@9&5R(%-C:&%N<R`\<V-H86YS0&1D<RYN;#X*("H@0'9E<G-I;VX@)%)E
M=FES:6]N.B`Q+C(@)`H@*B!`<&%C:V%G92!,;V<*("HO"F-L87-S($QO9U]D
M865M;VX@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!);G1E9V5R(&AO
M;&1I;F<@=&AE(&QO9R!F86-I;&ET>2!T;R!U<V4N"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]N86UE(#T@3$]'7T1!14U/3CL*"B`@
M("`O*BH*("`@("`J(%9A<B!H;VQD:6YG('1H92!R97-O=7)C92!P;VEN=&5R
M('1O('1H92!S;V-K970*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@
M("`@=F%R("1?<V]C:V5T.PH*("`@("\J*@H@("`@("H@5&AE(&EP(&%D9')E
M<W,@;W(@<V5R=F5R;F%M90H@("`@("H@0'-E92!H='1P.B\O=W=W+G!H<"YN
M970O;6%N=6%L+V5N+W1R86YS<&]R=',N<&AP"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]I<"`]("<Q,C<N,"XP+C$G.PH*("`@("\J
M*@H@("`@("H@4')O=&]C;VP@=&\@=7-E("AT8W`L('5D<"P@971C+BD*("`@
M("`J($!S964@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]T<F%N<W!O
M<G1S+G!H<`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M<')O=&\@/2`G=61P)SL*"B`@("`O*BH*("`@("`J(%!O<G0@=&\@8V]N;F5C
M="!T;PH@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1?<&]R="`]
M(#4Q-#L*"B`@("`O*BH*("`@("`J($UA>&EM=6T@;65S<V%G92!L96YG=&@@
M:6X@8GET97,*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D7VUA
M>'-I>F4@/2`T,#DV.PH*("`@("\J*@H@("`@("H@4V]C:V5T('1I;65O=70@
M:6X@<V5C;VYD<PH@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1?
M=&EM96]U="`](#$["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!S>7-L;V<@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@(%1H92!S>7-L;V<@9F%C:6QI='DN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9&5N="`@("!4:&4@:61E;G1I='D@<W1R:6YG+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("`D8V]N9B`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R
M87DN"B`@("`@*B!`<&%R86T@:6YT("`@("1M87A,979E;"!-87AI;75M(&QE
M=F5L(&%T('=H:6-H('1O(&QO9RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N($QO9U]D865M;VXH)&YA;64L("1I9&5N="`]
M("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("\J($5N
M<W5R92!W92!H879E(&$@=F%L:60@:6YT96=E<B!V86QU92!F;W(@)&YA;64N
M("HO"B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2!\?"`A:7-?:6YT*"1N86UE
M*2D@>PH@("`@("`@("`@("`D;F%M92`]($Q/1U]365-,3T<["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@
M("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED
M96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!4
M3R@D;&5V96PI.PH*("`@("`@("!I9B`H:7-S970H)&-O;F9;)VEP)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?:7`@/2`D8V]N9ELG:7`G73L*("`@("`@
M("!]"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=P<F]T;R==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!R;W1O(#T@)&-O;F9;)W!R;W1O)UT["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG<&]R="==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!O<G0@/2`D8V]N9ELG<&]R="==.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)&-O;F9;)VUA>'-I>F4G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]M87AS:7IE(#T@)&-O;F9;)VUA>'-I>F4G73L*
M("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=T:6UE;W5T)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&EM96]U="`]("1C;VYF6R=T:6UE
M;W5T)UT["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?<')O=&\@/2`D=&AI
M<RT^7W!R;W1O("X@)SHO+R<["@H@("`@("`@(')E9VES=&5R7W-H=71D;W=N
M7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U],;V=?9&%E;6]N)RDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5S=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7TQO9U]D865M
M;VXH*0H@("`@>PH@("`@("`@("1T:&ES+3YC;&]S92@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3W!E;G,@82!C;VYN96-T:6]N('1O('1H92!S>7-T96T@
M;&]G9V5R+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@("`J(&)E96X@;W!E
M;F5D+B`@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@
M;F5C97-S87)Y+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V]P
M96YE9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]("AB;V]L*2@D
M=&AI<RT^7W-O8VME="`]($!F<V]C:V]P96XH"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<')O=&\@
M+B`D=&AI<RT^7VEP+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!O<G0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)N;RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5R<G-T<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]T:6UE;W5T*2D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-L;W-E<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@<WES=&5M(&QO9V=E
M<BP@:68@:70@:7,@;W!E;BX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]O<&5N960I('L*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!F
M86QS93L*("`@("`@("`@("`@<F5T=7)N(&9C;&]S92@D=&AI<RT^7W-O8VME
M="D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9',@)&UE<W-A9V4@=&\@=&AE(&-U<G)E;G1L>2!O
M<&5N('-Y<VQO9R!C;VYN96-T:6]N+B`@0V%L;',*("`@("`J(&]P96XH*2!I
M9B!N96-E<W-A<GDN($%L<V\@<&%S<V5S('1H92!M97-S86=E(&%L;VYG('1O
M(&%N>2!,;V=?;V)S97)V97(*("`@("`J(&EN<W1A;F-E<R!T:&%T(&%R92!O
M8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;65S<V%G92`@5&AE('1E>'1U86P@;65S<V%G92!T;R!B92!L;V=G960N
M"B`@("`@*B!`<&%R86T@:6YT("1P<FEO<FET>2`H;W!T:6]N86PI(%1H92!P
M<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@("`@("`@
M("`@("`@("`@('9A;'5E<R!A<F4Z($Q/1U]%34521RP@3$]'7T%,15)4+"!,
M3T=?0U))5"P*("`@("`J("`@("`@("`@("`@("`@("`@3$]'7T524BP@3$]'
M7U=!4DY)3D<L($Q/1U].3U1)0T4L($Q/1U])3D9/+`H@("`@("H@("`@("`@
M("`@("`@("`@("!A;F0@3$]'7T1%0E5'+B`@5&AE(&1E9F%U;'0@:7,@3$]'
M7TE.1D\N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@
M("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L
M('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R
M:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES
M+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L
M>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN
M9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R
M:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!T:&4@8V]N;F5C=&EO;B!I<VXG="!O<&5N(&%N
M9"!C86XG="!B92!O<&5N960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@
M(&EF("@A)'1H:7,M/E]O<&5N960@)B8@(21T:&ES+3YO<&5N*"DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M17AT<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S
M86=E+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S
M<V%G92@D;65S<V%G92D["@H@("`@("`@("\J(%-E="!T:&4@9F%C:6QI='D@
M;&5V96PN("HO"B`@("`@("`@)&9A8VEL:71Y7VQE=F5L(#T@:6YT=F%L*"1T
M:&ES+3Y?;F%M92D@*PH@("`@("`@("`@("`@("`@("`@("`@("`@(&EN='9A
M;"@D=&AI<RT^7W1O4WES;&]G*"1P<FEO<FET>2DI.PH*("`@("`@("`O*B!0
M<F5P96YD(&ED96YT(&EN9F\N("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7VED96YT*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?
M:61E;G0@+B`G("<@+B`D;65S<V%G93L*("`@("`@("!]"@H@("`@("`@("\J
M($-H96-K(&9O<B!M97-S86=E(&QE;F=T:"X@*B\*("`@("`@("!I9B`H<W1R
M;&5N*"1M97-S86=E*2`^("1T:&ES+3Y?;6%X<VEZ92D@>PH@("`@("`@("`@
M("`D;65S<V%G92`]('-U8G-T<B@D;65S<V%G92P@,"P@*"1T:&ES+3Y?;6%X
M<VEZ92D@+2`Q,"D@+B`G(%LN+BY=)SL*("`@("`@("!]"@H@("`@("`@("\J
M(%=R:71E('1O('-O8VME="X@*B\*("`@("`@("!F=W)I=&4H)'1H:7,M/E]S
M;V-K970L("<\)R`N("1F86-I;&ET>5]L979E;"`N("<^)R`N("1M97-S86=E
M("X@(EQN(BD["@H@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R
M:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!014%27TQ/1U\J
M(&-O;G-T86YT(&EN=&\@82!S>7-L;V<@3$]'7RH@8V]N<W1A;G0N"B`@("`@
M*@H@("`@("H@5&AI<R!F=6YC=&EO;B!E>&ES=',@8F5C875S92P@=6YD97(@
M5VEN9&]W<RP@;F]T(&%L;"!O9B!T:&4@3$]'7RH*("`@("`J(&-O;G-T86YT
M<R!H879E('5N:7%U92!V86QU97,N("!);G-T96%D+"!T:&4@4$5!4E],3T=?
M*B!W97)E(&EN=')O9'5C960*("`@("`J(&9O<B!G;&]B86P@=7-E+"!W:71H
M('1H92!C;VYV97)S:6]N('1O('1H92!,3T=?*B!C;VYS=&%N=',@:V5P="!L
M;V-A;"!T;PH@("`@("H@=&\@=&AE('-Y<VQO9R!D<FEV97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN="`D<')I;W)I='D@("`@(%!%05)?3$]'7RH@=F%L
M=64@=&\@8V]N=F5R="!T;R!,3T=?*B!V86QU92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N("!4:&4@3$]'7RH@<F5P<F5S96YT871I;VX@;V8@)'!R:6]R:71Y
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=&]3>7-L;V<H)'!R:6]R:71Y*0H@("`@>PH@("`@("`@('-T
M871I8R`D<')I;W)I=&EE<R`](&%R<F%Y*`H@("`@("`@("`@("!014%27TQ/
M1U]%34521R`@(#T^($Q/1U]%34521RP*("`@("`@("`@("`@4$5!4E],3T=?
M04Q%4E0@("`]/B!,3T=?04Q%4E0L"B`@("`@("`@("`@(%!%05)?3$]'7T-2
M250@("`@/3X@3$]'7T-2250L"B`@("`@("`@("`@(%!%05)?3$]'7T524B`@
M("`@/3X@3$]'7T524BP*("`@("`@("`@("`@4$5!4E],3T=?5T%23DE.1R`]
M/B!,3T=?5T%23DE.1RP*("`@("`@("`@("`@4$5!4E],3T=?3D]424-%("`]
M/B!,3T=?3D]424-%+`H@("`@("`@("`@("!014%27TQ/1U])3D9/("`@(#T^
M($Q/1U])3D9/+`H@("`@("`@("`@("!014%27TQ/1U]$14)51R`@(#T^($Q/
M1U]$14)51PH@("`@("`@("D["@H@("`@("`@("\J($EF('=E)W)E('!A<W-E
M9"!A;B!U;FMN;W=N('!R:6]R:71Y+"!D969A=6QT('1O($Q/1U])3D9/+B`J
M+PH@("`@("`@(&EF("@A:7-?:6YT*"1P<FEO<FET>2D@?'P@(6EN7V%R<F%Y
M*"1P<FEO<FET>2P@)'!R:6]R:71I97,I*2!["B`@("`@("`@("`@(')E='5R
M;B!,3T=?24Y&3SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<')I;W)I
M=&EE<ULD<')I;W)I='E=.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+TQO9R]D:7-P;&%Y+G!H<```````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`W,#8S`#$P-3$U-#,Q,#4W`#`R,#(T-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+V1I<W!L87DN<&AP
M+'8@,2XX(#(P,#4O,#@O,#8@,C,Z,C@Z,S4@:F]N($5X<"`D"B`J"B`J($!V
M97)S:6]N("12979I<VEO;CH@,2XX("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*
M+RHJ"B`J(%1H92!,;V=?9&ES<&QA>2!C;&%S<R!I<R!A(&-O;F-R971E(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.@H@*B!A8G-T<F%C="!C;&%S<R!W
M:&EC:"!W<FET97,@;65S<V%G92!I;G1O(&)R;W=S97(@:6X@=7-U86P@4$A0
M(&UA;F5R+@H@*B!4:&ES(&UA>2!B92!U<V5F=6P@8F5C875S92!W:&5N('EO
M=2!U<V4@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R!I;@H@*B!014%27T524D]2
M7T-!3$Q"04-+(&UO9&4@97)R;W(@;65S<V%G97,@87)E(&YO="!D:7-P;&%Y
M960@8GD*("H@4$A0(&5R<F]R(&AA;F1L97(N"B`J"B`J($!A=71H;W(@(%!A
M=6P@66%N8VAE;FMO(#QP=7-H97)`:6YA8V\N<G4^"B`J($!S:6YC92`@($QO
M9R`Q+C@N,`H@*B!`<&%C:V%G92!,;V<*("H*("H@0&5X86UP;&4@9&ES<&QA
M>2YP:'`@("`@(%5S:6YG('1H92!D:7-P;&%Y(&AA;F1L97(N"B`J+PIC;&%S
M<R!,;V=?9&ES<&QA>2!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@("`J(%-T
M<FEN9R!T;R!O=71P=70@8F5F;W)E(&%N(&5R<F]R(&UE<W-A9V4*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?97)R;W)?<')E<&5N9"`]("<G.PH*("`@("\J*@H@("`@("H@
M4W1R:6YG('1O(&]U='!U="!A9G1E<B!A;B!E<G)O<B!M97-S86=E"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V5R<F]R7V%P<&5N9"`]("<G.PH*("`@("\J*@H@("`@("H@
M4W1R:6YG('5S960@=&\@<F5P<F5S96YT(&$@;&EN92!B<F5A:RX*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?;&EN96)R96%K(#T@(CQB<B`O/EQN(CL*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=',@82!N97<@3&]G7V1I<W!L87D@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@($EG;F]R960N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("!4:&4@:61E;G1I='D@<W1R
M:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8V]N9B`@("`@5&AE(&-O;F9I
M9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R86T@:6YT("`@("1L979E;"`@
M("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN8VQU9&EN9R!T:&ES(&QE=F5L
M+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M3&]G7V1I<W!L87DH)&YA;64@/2`G)RP@)&ED96YT(#T@)R<L("1C;VYF(#T@
M87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1L979E;"`](%!%
M05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H
M;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0[
M"B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D["@H@
M("`@("`@(&EF("AI<W-E="@D8V]N9ELG97)R;W)?<')E<&5N9"==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V5R<F]R7W!R97!E;F0@/2`D8V]N9ELG97)R
M;W)?<')E<&5N9"==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?97)R;W)?<')E<&5N9"`](&EN:5]G970H)V5R<F]R7W!R97!E;F1?
M<W1R:6YG)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O;F9;
M)V5R<F]R7V%P<&5N9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R
M7V%P<&5N9"`]("1C;VYF6R=E<G)O<E]A<'!E;F0G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7V%P<&5N9"`](&EN:5]G
M970H)V5R<F]R7V%P<&5N9%]S=')I;F<G*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D8V]N9ELG;&EN96)R96%K)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?;&EN96)R96%K(#T@)&-O;F9;)VQI;F5B<F5A:R==.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E<R`D;65S<V%G92!T
M;R!T:&4@=&5X="!B<F]W<V5R+B!!;'-O+"!P87-S97,@=&AE(&UE<W-A9V4*
M("`@("`J(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(@:6YS=&%N8V5S('1H
M870@87)E(&]B<V5R=FEN9R!T:&ES($QO9RX*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I
M;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI
M9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/
M1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@
M("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%2
M3DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%
M+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F
M86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@
M("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D
M+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO
M<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI
M<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R
M;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I
M;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P
M<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@17AT<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T
M:6]N(&]F('1H92!M97-S86=E+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H
M:7,M/E]E>'1R86-T365S<V%G92@D;65S<V%G92D["@H@("`@("`@("\J($)U
M:6QD(&%N9"!O=71P=70@=&AE(&-O;7!L971E(&QO9R!L:6YE+B`J+PH@("`@
M("`@(&5C:&\@)'1H:7,M/E]E<G)O<E]P<F5P96YD("X*("`@("`@("`@("`@
M("<\8CXG("X@=6-F:7)S="@D=&AI<RT^<')I;W)I='E4;U-T<FEN9R@D<')I
M;W)I='DI*2`N("<\+V(^.B`G+@H@("`@("`@("`@("`@;FPR8G(H:'1M;'-P
M96-I86QC:&%R<R@D;65S<V%G92DI("X*("`@("`@("`@("`@("1T:&ES+3Y?
M97)R;W)?87!P96YD("X@)'1H:7,M/E]L:6YE8G)E86L["@H@("`@("`@("\J
M($YO=&EF>2!O8G-E<G9E<G,@86)O=70@=&AI<R!L;V<@;65S<V%G92X@*B\*
M("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@
M)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+TQO9R]E<G)O<E]L;V<N<&AP````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,#8T`#$P-3$U-#,Q,#4W
M`#`R,#4W,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],
M;V<O3&]G+V5R<F]R7VQO9RYP:'`L=B`Q+C<@,C`P-2\P,B\R-B`Q-#HT.#HU
M."!C:&%G96YB=2!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N
M-R`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7V5R<F]R
M7VQO9R!C;&%S<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H
M92!,;V<@86)S=')A8W0*("H@8VQA<W,@=&AA="!L;V=S(&UE<W-A9V5S('5S
M:6YG(%!(4"=S(&5R<F]R7VQO9R@I(&9U;F-T:6]N+@H@*@H@*B!`875T:&]R
M("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X*("H@0'-I;F-E("`@3&]G(#$N
M-RXP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!E<G)O<E]L;V<N
M<&AP("`@57-I;F<@=&AE(&5R<F]R7VQO9R!H86YD;&5R+@H@*B\*8VQA<W,@
M3&]G7V5R<F]R7VQO9R!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@("`J(%1H
M92!E<G)O<E]L;V<H*2!L;V<@='EP92X*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1Y<&4@
M/2!014%27TQ/1U]465!%7U-94U1%33L*"B`@("`O*BH*("`@("`J(%1H92!T
M>7!E+7-P96-I9FEC(&1E<W1I;F%T:6]N('9A;'5E+@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@
M)%]D97-T:6YA=&EO;B`]("<G.PH*("`@("\J*@H@("`@("H@061D:71I;VYA
M;"!H96%D97)S('1O('!A<W,@=&\@=&AE(&UA:6PH*2!F=6YC=&EO;B!W:&5N
M('1H90H@("`@("H@4$5!4E],3T=?5%E015]-04E,('1Y<&4@:7,@=7-E9"X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?97AT<F%?:&5A9&5R<R`]("<G.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,;V=?97)R;W)?;&]G(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y
M('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C
M;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V
M96P@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L
M979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($QO9U]E<G)O<E]L;V<H)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`]
M(&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1L979E;"`]
M(%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M
M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?='EP92`]("1N86UE
M.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@("`@("`@)'1H
M:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D["@H@("`@("`@(&EF("@A
M96UP='DH)&-O;F9;)V1E<W1I;F%T:6]N)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9&5S=&EN871I;VX@/2`D8V]N9ELG9&5S=&EN871I;VXG73L*("`@
M("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG97AT<F%?:&5A9&5R
M<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5X=')A7VAE861E<G,@/2`D
M8V]N9ELG97AT<F%?:&5A9&5R<R==.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($QO9W,@)&UE<W-A9V4@=7-I;F<@4$A0)W,@97)R;W)?;&]G
M*"D@9G5N8W1I;VXN("!4:&4@;65S<V%G92!I<R!A;'-O"B`@("`@*B!P87-S
M960@86QO;F<@=&\@86YY($QO9U]O8G-E<G9E<B!I;G-T86YC97,@=&AA="!A
M<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`@)&UE<W-A9V4@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@
M=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I
M;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@
M("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%
M4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!0
M14%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!
M4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R
M92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@
M("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E
M('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@
M/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P
M<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF
M('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE
M=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I
M='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O
M9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?
M97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`D<W5C8V5S<R`]
M(&5R<F]R7VQO9R@D=&AI<RT^7VED96YT("X@)SH@)R`N("1M97-S86=E+"`D
M=&AI<RT^7W1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D97-T:6YA=&EO;BP@)'1H:7,M/E]E>'1R85]H96%D97)S*3L*"B`@
M("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P
M<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E
M='5R;B`D<W5C8V5S<SL*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O9FEL92YP:'``````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,34V,0`Q,#4Q-30S,3`U
M-P`P,3<U,3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O
M3&]G+TQO9R]F:6QE+G!H<"QV(#$N-#4@,C`P-B\P,2\Q,2`P-SHU-CHS-R!J
M;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C0U("0*("H@
M0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,;V=?9FEL92!C;&%S<R!I
M<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<@86)S=')A
M8W0*("H@8VQA<W,@=&AA="!L;V=S(&UE<W-A9V5S('1O(&$@=&5X="!F:6QE
M+@H@*B`*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J
M($!A=71H;W(@(%)O;6%N($YE=6AA=7-E<B`\;F5U:&%U<V5R0&)E;&QA=FES
M=&$N8WH^"B`J($!S:6YC92`@($QO9R`Q+C`*("H@0'!A8VMA9V4@3&]G"B`J
M"B`J($!E>&%M<&QE(&9I;&4N<&AP("`@(%5S:6YG('1H92!F:6QE(&AA;F1L
M97(N"B`J+PIC;&%S<R!,;V=?9FEL92!E>'1E;F1S($QO9PI["B`@("`O*BH*
M("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F('1H92!L;V<@
M9FEL92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?9FEL96YA;64@/2`G<&AP+FQO9R<["@H@
M("`@+RHJ"B`@("`@*B!(86YD;&4@=&\@=&AE(&QO9R!F:6QE+@H@("`@("H@
M0'9A<B!R97-O=7)C90H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V9P(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@
M;F5W(&QO9R!E;G1R:65S(&)E(&%P<&5N9"!T;R!A;B!E>&ES=&EN9R!L;V<@
M9FEL92P@;W(@<VAO=6QD('1H90H@("`@("H@82!N97<@;&]G(&9I;&4@;W9E
M<G=R:71E(&%N(&5X:7-T:6YG(&]N93\*("`@("`J($!V87(@8F]O;&5A;@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V%P<&5N
M9"`]('1R=64["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@861V:7-O<GD@9FEL
M92!L;V-K:6YG("AI+F4N+"!F;&]C:R@I*2!B92!U<V5D/PH@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?;&]C:VEN9R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@26YT96=E
M<B`H:6X@;V-T86PI(&-O;G1A:6YI;F<@=&AE(&QO9R!F:6QE)W,@<&5R;6ES
M<VEO;G,@;6]D92X*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VUO9&4@/2`P-C0T.PH*("`@
M("\J*@H@("`@("H@26YT96=E<B`H:6X@;V-T86PI('-P96-I9GEI;F<@=&AE
M(&9I;&4@<&5R;6ES<VEO;B!M;V1E('1H870@=VEL;"!B90H@("`@("H@=7-E
M9"!W:&5N(&-R96%T:6YG(&1I<F5C=&]R:65S('1H870@9&\@;F]T(&%L<F5A
M9'D@97AI<W0N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D:7)M;V1E(#T@,#<U-3L*"B`@
M("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!F;W)M870@;V8@
M82!L;V<@;&EN92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;&EN949O<FUA="`]("<E,21S
M("4R)',@6R4S)'-=("4T)',G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O
M;G1A:6YI;F<@=&AE('1I;65S=&%M<"!F;W)M870N("!)="!W:6QL(&)E('!A
M<W-E9"!D:7)E8W1L>2!T;PH@("`@("H@<W1R9G1I;64H*2X@($YO=&4@=&AA
M="!T:&4@=&EM97-T86UP('-T<FEN9R!W:6QL(&=E;F5R871E9"!U<VEN9R!T
M:&4*("`@("`J(&-U<G)E;G0@;&]C86QE+@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T:6UE
M1F]R;6%T(#T@)R5B("5D("5(.B5-.B53)SL*"B`@("`O*BH*("`@("`J(%-T
M<FEN9R!C;VYT86EN:6YG('1H92!E;F0M;VXM;&EN92!C:&%R86-T97(@<V5Q
M=65N8V4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7V5O;"`](")<;B(["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1S(&$@;F5W($QO9U]F:6QE(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN
M9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U
M<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@
M3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO
M9U]F:6QE*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@
M("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D[
M"B`@("`@("`@)'1H:7,M/E]F:6QE;F%M92`]("1N86UE.PH@("`@("`@("1T
M:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@
M3&]G.CI54%1/*"1L979E;"D["@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG
M87!P96YD)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?87!P96YD(#T@)&-O
M;F9;)V%P<&5N9"==.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1C
M;VYF6R=L;V-K:6YG)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&]C:VEN
M9R`]("1C;VYF6R=L;V-K:6YG)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1C;VYF6R=M;V1E)UTI*2!["B`@("`@("`@("`@(&EF("AI<U]S
M=')I;F<H)&-O;F9;)VUO9&4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;6]D92`](&]C=&1E8R@D8V]N9ELG;6]D92==*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]D92`]("1C;VYF
M6R=M;V1E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@A96UP='DH)&-O;F9;)V1I<FUO9&4G72DI('L*("`@("`@("`@("`@:68@
M*&ES7W-T<FEN9R@D8V]N9ELG9&ER;6]D92==*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D:7)M;V1E(#T@;V-T9&5C*"1C;VYF6R=D:7)M;V1E)UTI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D:7)M;V1E(#T@)&-O;F9;)V1I<FUO9&4G73L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG;&EN949O<FUA
M="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI;F5&;W)M870@/2!S=')?
M<F5P;&%C92AA<G)A>5]K97ES*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M=F%L=65S*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)VQI;F5&;W)M870G
M72D["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=T:6UE
M1F]R;6%T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&EM949O<FUA="`]
M("1C;VYF6R=T:6UE1F]R;6%T)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1C;VYF6R=E;VPG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]E
M;VP@/2`D8V]N9ELG96]L)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]E;VP@/2`H<W1R<W1R*%!(4%]/4RP@)U=)3B<I*2`_(")<
M<EQN(B`Z(")<;B(["B`@("`@("`@?0H*("`@("`@("!R96=I<W1E<E]S:'5T
M9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?3&]G7V9I;&4G*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<G5C=&]R"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%],;V=?9FEL92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?
M;W!E;F5D*2!["B`@("`@("`@("`@("1T:&ES+3YC;&]S92@I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@=&AE(&=I=F5N(&1I
M<F5C=&]R>2!P871H+B`@268@=&AE('!A<F5N="!D:7)E8W1O<FEE<R!D;VXG
M=`H@("`@("H@86QR96%D>2!E>&ES="P@=&AE>2!W:6QL(&)E(&-R96%T960L
M('1O;RX*("`@("`J"B`@("`@*B!4:&ES(&EM<&QE;65N=&%T:6]N(&ES(&EN
M<W!I<F5D(&)Y(%!Y=&AO;B=S(&]S+FUA:V5D:7)S(&9U;F-T:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@)'!A=&@@("`@("`@5&AE(&9U
M;&P@9&ER96-T;W)Y('!A=&@@=&\@8W)E871E+@H@("`@("H@0'!A<F%M("`@
M:6YT96=E<B`D;6]D92`@("`@("!4:&4@<&5R;6ES<VEO;G,@;6]D92!W:71H
M('=H:6-H('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D:7)E8W1O<FEE<R!W:6QL(&)E(&-R96%T960N"B`@("`@*@H@("`@("H@
M0')E='5R;B`@5')U92!I9B!T:&4@9G5L;"!P871H(&ES('-U8V-E<W-F=6QL
M>2!C<F5A=&5D(&]R(&%L<F5A9'D*("`@("`J("`@("`@("`@(&5X:7-T<RX*
M("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]M:W!A=&@H)'!A=&@L("1M;V1E(#T@,#<P,"D*("`@('L*("`@
M("`@("`O*B!397!A<F%T92!T:&4@;&%S="!P871H;F%M92!C;VUP;VYE;G0@
M9G)O;2!T:&4@<F5S="!O9B!T:&4@<&%T:"X@*B\*("`@("`@("`D:&5A9"`]
M(&1I<FYA;64H)'!A=&@I.PH@("`@("`@("1T86EL(#T@8F%S96YA;64H)'!A
M=&@I.PH*("`@("`@("`O*B!-86ME('-U<F4@=V4G=F4@<W!L:70@=&AE('!A
M=&@@:6YT;R!T=V\@8V]M<&QE=&4@8V]M<&]N96YT<RX@*B\*("`@("`@("!I
M9B`H96UP='DH)'1A:6PI*2!["B`@("`@("`@("`@("1H96%D(#T@9&ER;F%M
M92@D<&%T:"D["B`@("`@("`@("`@("1T86EL(#T@8F%S96YA;64H)'!A=&@I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5C=7)S92!U<"!T:&4@<&%T:"!I
M9B!O=7(@8W5R<F5N="!S96=M96YT(&1O97,@;F]T(&5X:7-T+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)&AE860I("8F("%E;7!T>2@D=&%I;"D@)B8@(6ES
M7V1I<B@D:&5A9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]M:W!A=&@H)&AE
M860L("1M;V1E*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T:&ES
M('-E9VUE;G0@;V8@=&AE('!A=&@N("HO"B`@("`@("`@<F5T=7)N($!M:V1I
M<B@D:&5A9"P@)&UO9&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@3W!E;G,@
M=&AE(&QO9R!F:6QE(&9O<B!O=71P=70N("!)9B!T:&4@<W!E8VEF:65D(&QO
M9R!F:6QE(&1O97,@;F]T"B`@("`@*B!A;')E861Y(&5X:7-T+"!I="!W:6QL
M(&)E(&-R96%T960N("!">2!D969A=6QT+"!N97<@;&]G(&5N=')I97,@87)E
M"B`@("`@*B!A<'!E;F1E9"!T;R!T:&4@96YD(&]F('1H92!L;V<@9FEL92X*
M("`@("`J"B`@("`@*B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y(&QO
M9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@
M:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`O*B!)9B!T:&4@
M;&]G(&9I;&4G<R!D:7)E8W1O<GD@9&]E<VXG="!E>&ES="P@8W)E871E(&ET
M+B`J+PH@("`@("`@("`@("!I9B`H(6ES7V1I<BAD:7)N86UE*"1T:&ES+3Y?
M9FEL96YA;64I*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M:W!A=&@H
M)'1H:7,M/E]F:6QE;F%M92P@)'1H:7,M/E]D:7)M;V1E*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@1&5T97)M:6YE('=H971H97(@=&AE(&QO
M9R!F:6QE(&YE961S('1O(&)E(&-R96%T960N("HO"B`@("`@("`@("`@("1C
M<F5A=&EN9R`]("%F:6QE7V5X:7-T<R@D=&AI<RT^7V9I;&5N86UE*3L*"B`@
M("`@("`@("`@("\J($]B=&%I;B!A(&AA;F1L92!T;R!T:&4@;&]G(&9I;&4N
M("HO"B`@("`@("`@("`@("1T:&ES+3Y?9G`@/2!F;W!E;B@D=&AI<RT^7V9I
M;&5N86UE+"`H)'1H:7,M/E]A<'!E;F0I(#\@)V$G(#H@)W<G*3L*"B`@("`@
M("`@("`@("\J(%=E(&-O;G-I9&5R('1H92!F:6QE(")O<&5N960B(&EF('=E
M(&AA=F4@82!V86QI9"!F:6QE('!O:6YT97(N("HO"B`@("`@("`@("`@("1T
M:&ES+3Y?;W!E;F5D(#T@*"1T:&ES+3Y?9G`@(3T](&9A;'-E*3L*"B`@("`@
M("`@("`@("\J($%T=&5M<'0@=&\@<V5T('1H92!F:6QE)W,@<&5R;6ES<VEO
M;G,@:68@=V4@:G5S="!C<F5A=&5D(&ET+B`J+PH@("`@("`@("`@("!I9B`H
M)&-R96%T:6YG("8F("1T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("`@
M("!C:&UO9"@D=&AI<RT^7V9I;&5N86UE+"`D=&AI<RT^7VUO9&4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]O
M<&5N960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&QO9R!F
M:6QE(&EF(&ET(&ES(&]P96XN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@
M("\J($EF('1H92!L;V<@9FEL92!I<R!O<&5N+"!C;&]S92!I="X@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]O<&5N960@)B8@9F-L;W-E*"1T:&ES+3Y?9G`I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;'5S:&5S(&%L;"!P96YD:6YG
M(&1A=&$@=&\@=&AE(&9I;&4@:&%N9&QE+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N."XR"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9L=7-H*"D*("`@('L*("`@("`@("!R971U<FX@9F9L=7-H
M*"1T:&ES+3Y?9G`I.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R`D;65S
M<V%G92!T;R!T:&4@;W5T<'5T('=I;F1O=RX@(%1H92!M97-S86=E(&ES(&%L
M<V\@<&%S<V5D(&%L;VYG"B`@("`@*B!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN
M<W1A;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C
M="!C;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A
M;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G
M92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z
M(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%2
M7TQ/1U]705).24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/
M1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A
M;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI
M"B`@("!["B`@("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S
M<&5C:69I960L('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I
M9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET
M>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!
M8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM
M=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--
M87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@;&]G(&9I;&4@:7-N)W0@
M86QR96%D>2!O<&5N+"!O<&5N(&ET(&YO=RX@*B\*("`@("`@("!I9B`H(21T
M:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@
M=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*
M("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE
M<W-A9V4I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@<W1R:6YG(&-O;G1A:6YI
M;F<@=&AE(&-O;7!L971E(&QO9R!L:6YE+B`J+PH@("`@("`@("1L:6YE(#T@
M)'1H:7,M/E]F;W)M870H)'1H:7,M/E]L:6YE1F]R;6%T+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R9G1I;64H)'1H:7,M/E]T:6UE1F]R
M;6%T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<FEO<FET
M>2P@)&UE<W-A9V4I("X@)'1H:7,M/E]E;VP["@H@("`@("`@("\J($EF(&QO
M8VMI;F<@:7,@96YA8FQE9"P@86-Q=6ER92!A;B!E>&-L=7-I=F4@;&]C:R!O
M;B!T:&4@9FEL92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]L;V-K:6YG*2![
M"B`@("`@("`@("`@(&9L;V-K*"1T:&ES+3Y?9G`L($Q/0TM?15@I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@5W)I=&4@=&AE(&QO9R!L:6YE('1O('1H92!L
M;V<@9FEL92X@*B\*("`@("`@("`D<W5C8V5S<R`]("AF=W)I=&4H)'1H:7,M
M/E]F<"P@)&QI;F4I("$]/2!F86QS92D["@H@("`@("`@("\J(%5N;&]C:R!T
M:&4@9FEL92!N;W<@=&AA="!W92=R92!F:6YI<VAE9"!W<FET:6YG('1O(&ET
M+B`J+R`*("`@("`@("!I9B`H)'1H:7,M/E]L;V-K:6YG*2!["B`@("`@("`@
M("`@(&9L;V-K*"1T:&ES+3Y?9G`L($Q/0TM?54XI.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3F]T:69Y(&]B<V5R=F5R<R!A8F]U="!T:&ES(&QO9R!M97-S
M86=E+B`J+PH@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R
M:71Y)R`]/B`D<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*
M("`@("`@("!R971U<FX@)'-U8V-E<W,["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]M86EL+G!H<```````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V,#`S`#$P
M-3$U-#,Q,#4W`#`Q-S4Q-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O
M<GDO<&5A<B],;V<O3&]G+VUA:6PN<&AP+'8@,2XR-"`R,#`V+S`Q+S,P(#`U
M.C,W.C$X(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N
M,C0@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]M86EL
M(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO
M9SHZ(&%B<W1R86-T(&-L87-S"B`J('=H:6-H('-E;F1S(&QO9R!M97-S86=E
M<R!T;R!A(&UA:6QB;W@N"B`J(%1H92!M86EL(&ES(&%C='5A;&QY('-E;G0@
M=VAE;B!Y;W4@8VQO<V4H*2!T:&4@;&]G9V5R+"!O<B!W:&5N('1H92!D97-T
M<G5C=&]R"B`J(&ES(&-A;&QE9"`H=VAE;B!T:&4@<V-R:7!T(&ES('1E<FUI
M;F%T960I+@H@*@H@*B!03$5!4T4@3D]412!T:&%T('EO=2!M=7-T(&-R96%T
M92!A($QO9U]M86EL(&]B:F5C="!U<VEN9R`])BP@;&EK92!T:&ES(#H*("H@
M("1L;V=G97(@/28@3&]G.CIF86-T;W)Y*")M86EL(BP@(G)E8VEP:65N=$!E
M>&%M<&QE+F-O;2(L("XN+BD*("H*("H@5&AI<R!I<R!A(%!%05(@<F5Q=6ER
M96UE;G0@9F]R(&1E<W1R=6-T;W)S('1O('=O<FL@<')O<&5R;'DN"B`J(%-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]C;&%S<RYP96%R+G!H
M<`H@*@H@*B!`875T:&]R("!2;VYN:64@1V%R8VEA(#QR;VYN:65`;6LR+FYE
M=#X*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!S
M:6YC92`@($QO9R`Q+C,*("H@0'!A8VMA9V4@3&]G"B`J"B`J($!E>&%M<&QE
M(&UA:6PN<&AP("`@(%5S:6YG('1H92!M86EL(&AA;F1L97(N"B`J+PIC;&%S
M<R!,;V=?;6%I;"!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@("`J(%-T<FEN
M9R!H;VQD:6YG('1H92!R96-I<&EE;G0G<R!E;6%I;"!A9&1R97-S+@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]R96-I<&EE;G0@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T
M<FEN9R!H;VQD:6YG('1H92!S96YD97(G<R!E;6%I;"!A9&1R97-S+@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]F<F]M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@
M:&]L9&EN9R!T:&4@96UA:6PG<R!S=6)J96-T+@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]S
M=6)J96-T(#T@)UM,;V=?;6%I;%T@3&]G(&UE<W-A9V4G.PH*("`@("\J*@H@
M("`@("H@4W1R:6YG(&AO;&1I;F<@86X@;W!T:6]N86P@<')E86UB;&4@9F]R
M('1H92!L;V<@;65S<V%G97,N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W!R96%M8FQE(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@9F]R
M;6%T(&]F(&$@;&]G(&QI;F4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VQI;F5&;W)M870@
M/2`G)3$D<R`E,B1S(%LE,R1S72`E-"1S)SL*"B`@("`O*BH*("`@("`J(%-T
M<FEN9R!C;VYT86EN:6YG('1H92!T:6UE<W1A;7`@9F]R;6%T+B`@270@=VEL
M;"!B92!P87-S960@9&ER96-T;'D@=&\*("`@("`J('-T<F9T:6UE*"DN("!.
M;W1E('1H870@=&AE('1I;65S=&%M<"!S=')I;F<@=VEL;"!G96YE<F%T960@
M=7-I;F<@=&AE"B`@("`@*B!C=7)R96YT(&QO8V%L92X*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?=&EM949O<FUA="`]("<E8B`E9"`E2#HE33HE4R<["@H@("`@+RHJ"B`@
M("`@*B!3=')I;F<@:&]L9&EN9R!T:&4@;6%I;"!M97-S86=E(&)O9'DN"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7VUE<W-A9V4@/2`G)SL*"@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W($QO9U]M86EL(&]B:F5C="X*("`@("`J"B`@("`@
M*B!(97)E(&ES(&AO=R!Y;W4@8V%N(&-U<W1O;6EZ92!T:&4@;6%I;"!D<FEV
M97(@=VET:"!T:&4@8V]N9EM=(&AA<V@@.@H@("`@("H@("`D8V]N9ELG9G)O
M;2==("`@(#H@=&AE(&UA:6PG<R`B1G)O;2(@:&5A9&5R(&QI;F4L"B`@("`@
M*B`@("1C;VYF6R=S=6)J96-T)UT@.B!T:&4@;6%I;"=S(")3=6)J96-T(B!L
M:6YE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!4
M:&4@9FEL96YA;64@;V8@=&AE(&QO9V9I;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9&5N="`@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P
M87)A;2!A<G)A>2`@)&-O;F8@("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A
M>2X*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@("!,;V<@;65S<V%G
M97,@=7`@=&\@86YD(&EN8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@3&]G7VUA:6PH)&YA
M;64L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@
M("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D
M=&AI<RT^7W)E8VEP:65N="`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?:61E
M;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/
M*"1L979E;"D["@H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)V9R;VTG72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]F<F]M(#T@)&-O;F9;)V9R;VTG73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V9R;VT@/2!I
M;FE?9V5T*"=S96YD;6%I;%]F<F]M)RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1C;VYF6R=S=6)J96-T)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<W5B:F5C="`]("1C;VYF6R=S=6)J96-T)UT["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=P<F5A;6)L92==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!R96%M8FQE(#T@)&-O;F9;)W!R96%M8FQE)UT[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=L:6YE1F]R
M;6%T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&EN949O<FUA="`]('-T
M<E]R97!L86-E*&%R<F%Y7VME>7,H)'1H:7,M/E]F;W)M871-87`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>5]V86QU97,H)'1H:7,M/E]F;W)M871-87`I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9ELG;&EN949O<FUA
M="==*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)W1I
M;65&;W)M870G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T:6UE1F]R;6%T
M(#T@)&-O;F9;)W1I;65&;W)M870G73L*("`@("`@("!]"@H@("`@("`@("\J
M(')E9VES=&5R('1H92!D97-T<G5C=&]R("HO"B`@("`@("`@<F5G:7-T97)?
M<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G7TQO9U]M86EL)RDI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S=')U8W1O<BX@0V%L;',@8VQO
M<V4H*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7TQO9U]M86EL*"D*("`@('L*("`@("`@("`D=&AI<RT^
M8VQO<V4H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T87)T<R!A(&YE=R!M
M86EL(&UE<W-A9V4N"B`@("`@*B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D
M(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<')E86UB;&4I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VUE<W-A9V4@/2`D=&AI<RT^7W!R96%M8FQE("X@(EQR7&Y<<EQN
M(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]
M('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N
M960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&UE<W-A9V4L
M(&EF(&ET(&ES(&]P96XL(&%N9"!S96YD<R!T:&4@;6%I;"X*("`@("`J(%1H
M:7,@:7,@:6UP;&EC:71L>2!C86QL960@8GD@=&AE(&1E<W1R=6-T;W(L(&EF
M(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]M97-S86=E*2D@>PH@("`@("`@("`@("`@("`@)&AE861E<G,@/2`B1G)O
M;3H@)'1H:7,M/E]F<F]M7')<;B(["B`@("`@("`@("`@("`@("`D:&5A9&5R
M<R`N/2`B57-E<BU!9V5N=#H@3&]G7VUA:6PB.PH*("`@("`@("`@("`@("`@
M(&EF("AM86EL*"1T:&ES+3Y?<F5C:7!I96YT+"`D=&AI<RT^7W-U8FIE8W0L
M("1T:&ES+3Y?;65S<V%G92P*("`@("`@("`@("`@("`@("`@("`@("`@("1H
M96%D97)S*2`]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@(&5R<F]R
M7VQO9R@B3&]G7VUA:6PZ($9A:6QU<F4@97AE8W5T:6YG(&UA:6PH*2(L(#`I
M.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!#;&5A<B!T:&4@;65S<V%G
M92!S=')I;F<@;F]W('1H870@=&AE(&5M86EL(&AA<R!B965N('-E;G0N("HO
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUE<W-A9V4@/2`G)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@
M9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1FQU<VAE<R!T:&4@;&]G
M(&]U='!U="!B>2!F;W)C:6YG('1H92!E;6%I;"!M97-S86=E('1O(&)E('-E
M;G0@;F]W+@H@("`@("H@179E;G1S('1H870@87)E(&QO9V=E9"!A9G1E<B!F
M;'5S:"@I(&ES(&-A;&QE9"!W:6QL(&)E(&%P<&5N9&5D('1O(&$*("`@("`J
M(&YE=R!E;6%I;"!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N."XR"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9L=7-H*"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($ET)W,@
M<W5F9FEC:65N="!T;R!S:6UP;'D@8V%L;"!C;&]S92@I('1O(&9L=7-H('1H
M92!O=71P=70N"B`@("`@("`@("H@5&AE(&YE>'0@8V%L;"!T;R!L;V<H*2!W
M:6QL(&-A=7-E('1H92!H86YD;&5R('1O(&)E(')E;W!E;F5D+@H@("`@("`@
M("`J+PH@("`@("`@(')E='5R;B`D=&AI<RT^8VQO<V4H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%=R:71E<R`D;65S<V%G92!T;R!T:&4@8W5R<F5N=&QY
M(&]P96X@;6%I;"!M97-S86=E+@H@("`@("H@0V%L;',@;W!E;B@I+"!I9B!N
M96-E<W-A<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G
M92`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E('1O
M(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO
M<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@
M("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!
M3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@
M4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@("H@("`@("`@
M("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N
M9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L
M("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@82!P<FEO
M<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F875L="!V
M86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@
M("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@
M:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@
M("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T
M:&4@;65S<V%G92!I<VXG="!O<&5N(&%N9"!C86XG="!B92!O<&5N960L(')E
M='5R;B!F86EL=7)E+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960@
M)B8@(21T:&ES+3YO<&5N*"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@17AT<F%C="!T:&4@<W1R:6YG(')E
M<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E+B`J+PH@("`@("`@("1M97-S
M86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G92@D;65S<V%G92D["@H@("`@
M("`@("\J($)U:6QD('1H92!S=')I;F<@8V]N=&%I;FEN9R!T:&4@8V]M<&QE
M=&4@;&]G(&QI;F4N("HO"B`@("`@("`@)'1H:7,M/E]M97-S86=E("X]("1T
M:&ES+3Y?9F]R;6%T*"1T:&ES+3Y?;&EN949O<FUA="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R9G1I;64H)'1H:7,M
M/E]T:6UE1F]R;6%T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R:6]R:71Y+"`D;65S<V%G92D@+B`B7')<;B(["@H@
M("`@("`@("\J($YO=&EF>2!O8G-E<G9E<G,@86)O=70@=&AI<R!L;V<@;65S
M<V%G92X@*B\*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO
M<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+VUC86PN<&AP````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$U,C4`
M,3`U,34T,S$P-3<`,#$W-3$S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I
M=&]R>2]P96%R+TQO9R],;V<O;6-A;"YP:'`L=B`Q+C$X(#(P,#4O,#(O,C8@
M,30Z-#@Z-3@@8VAA9V5N8G4@17AP("0*("H@)$AO<F1E.B!H;W)D92]L:6(O
M3&]G+VUC86PN<&AP+'8@,2XR(#(P,#`O,#8O,C@@,C$Z,S8Z,3,@:F]N($5X
M<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@,2XQ."`D"B`J($!P86-K
M86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7VUC86P@8VQA<W,@:7,@82!C
M;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A
M8W0@8VQA<W,@=VAI8V@@<V5N9',@;65S<V%G97,@=&\@82!L;V-A;"!O<B!R
M96UO=&4@8V%L96YD87(*("H@<W1O<F4@86-C97-S960@=&AR;W5G:"!-0T%,
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E($AO<F1E(#$N,PH@*B!`<VEN8V4@3&]G(#$N,`H@
M*B!`<&%C:V%G92!,;V<*("HO"F-L87-S($QO9U]M8V%L(&5X=&5N9',@3&]G
M"GL*("`@("\J*@H@("`@("H@:&]L9&EN9R!T:&4@8V%L96YD87(@<W!E8VEF
M:6-A=&EO;B!T;R!C;VYN96-T('1O+@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C86QE;F1A
M<B`]("=[;&]C86QH;W-T+VUS=&]R97TG.PH*("`@("\J*@H@("`@("H@:&]L
M9&EN9R!T:&4@=7-E<FYA;64@=&\@=7-E+@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]U<V5R
M;F%M92`]("<G.PH*("`@("\J*@H@("`@("H@:&]L9&EN9R!T:&4@<&%S<W=O
M<F0@=&\@=7-E+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]P87-S=V]R9"`]("<G.PH*("`@
M("\J*@H@("`@("H@:&]L9&EN9R!T:&4@;W!T:6]N<R!T;R!P87-S('1O('1H
M92!C86QE;F1A<B!S=')E86TN"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]O<'1I;VYS(#T@
M,#L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E240@;V8@=&AE($U#04P@<W1R
M96%M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]S=')E86T@/2`G)SL*"B`@("`O*BH*("`@
M("`J($EN=&5G97(@:&]L9&EN9R!T:&4@;&]G(&9A8VEL:71Y('1O('5S92X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?;F%M92`]($Q/1U]365-,3T<["@H*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,;V=?;6-A;"!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@5&AE(&-A=&5G;W)Y
M('1O('5S92!F;W(@;W5R(&5V96YT<RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@
M87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@
M("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E<R!U<"!T
M;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?;6-A;"@D;F%M92P@)&ED
M96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@
M("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?
M;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0[
M"B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D["B`@
M("`@("`@)'1H:7,M/E]C86QE;F1A<B`]("1C;VYF6R=C86QE;F1A<B==.PH@
M("`@("`@("1T:&ES+3Y?=7-E<FYA;64@/2`D8V]N9ELG=7-E<FYA;64G73L*
M("`@("`@("`D=&AI<RT^7W!A<W-W;W)D(#T@)&-O;F9;)W!A<W-W;W)D)UT[
M"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@)&-O;F9;)V]P=&EO;G,G73L*
M("`@('T*"B`@("`O*BH*("`@("`J($]P96YS(&$@8V%L96YD87(@<W1R96%M
M+"!I9B!I="!H87,@;F]T(&%L<F5A9'D@8F5E;@H@("`@("H@;W!E;F5D+B!4
M:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A
M<GDN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!O<&5N*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<W1R96%M(#T@;6-A;%]O<&5N*"1T:&ES
M+3Y?8V%L96YD87(L("1T:&ES+3Y?=7-E<FYA;64L"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<W-W;W)D+"`D=&AI<RT^7V]P=&EO;G,I.PH@("`@("`@
M("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H:7,M/E]O<&5N960["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;&]S97,@=&AE(&-A;&5N9&%R('-T<F5A;2P@:68@:70@:7,@;W!E;BX*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L
M;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N960I('L*("`@
M("`@("`@("`@;6-A;%]C;&]S92@D=&AI<RT^7W-T<F5A;2D["B`@("`@("`@
M("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!,;V=S("1M97-S86=E(&%N9"!A<W-O8VEA=&5D(&EN
M9F]R;6%T:6]N('1O('1H92!C=7)R96YT;'D@;W!E;@H@("`@("H@8V%L96YD
M87(@<W1R96%M+B!#86QL<R!O<&5N*"D@:68@;F5C97-S87)Y+B!!;'-O('!A
M<W-E<R!T:&4*("`@("`J(&UE<W-A9V4@86QO;F<@=&\@86YY($QO9U]O8G-E
M<G9E<B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG"B`@("`@*B!T:&ES
M($QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E("!3
M=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@;&]G
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I;W)I='D@5&AE('!R:6]R:71Y
M(&]F('1H92!M97-S86=E+B!686QI9`H@("`@("H@("`@("`@("`@("`@("`@
M("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?
M3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@
M("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!
M4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I
M;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@
M:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N
M("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@
M("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*
M"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B
M;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@
M*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&-O
M;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D+"!R971U
M<FX@9F%I;'5R92X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F
M("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R
M97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G
M92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@
M("`D9&%T95]S='(@/2!D871E*"=9.FXZ:CI'.FDZ<R<I.PH@("`@("`@("1D
M871E<R`](&5X<&QO9&4H)SHG+"`D9&%T95]S='(I.PH*("`@("`@("!M8V%L
M7V5V96YT7VEN:70H)'1H:7,M/E]S=')E86TI.PH@("`@("`@(&UC86Q?979E
M;G1?<V5T7W1I=&QE*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7VED96YT*3L*
M("`@("`@("!M8V%L7V5V96YT7W-E=%]C871E9V]R>2@D=&AI<RT^7W-T<F5A
M;2P@)'1H:7,M/E]N86UE*3L*("`@("`@("!M8V%L7V5V96YT7W-E=%]D97-C
M<FEP=&EO;B@D=&AI<RT^7W-T<F5A;2P@)&UE<W-A9V4I.PH@("`@("`@(&UC
M86Q?979E;G1?861D7V%T=')I8G5T92@D=&AI<RT^7W-T<F5A;2P@)W!R:6]R
M:71Y)RP@)'!R:6]R:71Y*3L*("`@("`@("!M8V%L7V5V96YT7W-E=%]S=&%R
M="@D=&AI<RT^7W-T<F5A;2P@)&1A=&5S6S!=+"`D9&%T97-;,5TL("1D871E
M<ULR72P*("`@("`@("`@("`@)&1A=&5S6S-=+"`D9&%T97-;-%TL("1D871E
M<ULU72D["B`@("`@("`@;6-A;%]E=F5N=%]S971?96YD*"1T:&ES+3Y?<W1R
M96%M+"`D9&%T97-;,%TL("1D871E<ULQ72P@)&1A=&5S6S)=+`H@("`@("`@
M("`@("`D9&%T97-;,UTL("1D871E<ULT72P@)&1A=&5S6S5=*3L*("`@("`@
M("!M8V%L7V%P<&5N9%]E=F5N="@D=&AI<RT^7W-T<F5A;2D["@H@("`@("`@
M("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I
M='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]M9&(R
M+G!H<```````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(U,34W`#$P-3$U-#,Q,#4W`#`Q-S0S,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AE861E<CH@
M+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+VUD8C(N<&AP+'8@,2XU(#(P,#8O
M,#$O,#@@,#,Z,S4Z-#0@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12979I
M<VEO;CH@,2XU("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ(%!%05(G<R!-
M1$(R('!A8VMA9V4@*B\*<F5Q=6ER95]O;F-E("=-1$(R+G!H<"<["DU$0C(Z
M.FQO861&:6QE*"=$871E)RD["@HO*BH*("H@5&AE($QO9U]M9&(R(&-L87-S
M(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO9SHZ(&%B
M<W1R86-T(&-L87-S"B`J('=H:6-H('-E;F1S(&UE<W-A9V5S('1O(&%N(%-1
M3"!S97)V97(N("!%86-H(&5N=')Y(&]C8W5P:65S(&$@<V5P87)A=&4@<F]W
M"B`J(&EN('1H92!D871A8F%S92X*("H*("H@5&AI<R!I;7!L96UE;G1A=&EO
M;B!U<V5S(%!%05(G<R!-1$(R(&1A=&%B87-E(&%B<W1R86-T:6]N(&QA>65R
M+@H@*@H@*B!#4D5!5$4@5$%"3$4@;&]G7W1A8FQE("@*("H@(&ED("`@("`@
M("`@($E.5"!.3U0@3E5,3"P*("H@(&QO9W1I;64@("`@(%1)34535$%-4"!.
M3U0@3E5,3"P*("H@(&ED96YT("`@("`@($-(05(H,38I($Y/5"!.54Q,+`H@
M*B`@<')I;W)I='D@("`@24Y4($Y/5"!.54Q,+`H@*B`@;65S<V%G92`@("`@
M5D%20TA!4B@R,#`I+`H@*B`@4%))34%262!+15D@*&ED*0H@*B`I.PH@*@H@
M*B!`875T:&]R("!,=6MA<R!3;6ET:"`\<VUI=&A`8F%C:V5N9&UE9&EA+F-O
M;3X*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!S
M:6YC92`@($QO9R`Q+CDN,`H@*B!`<&%C:V%G92!,;V<*("HO"F-L87-S($QO
M9U]M9&(R(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@5F%R:6%B;&4@
M8V]N=&%I;FEN9R!T:&4@1%-.(&EN9F]R;6%T:6]N+@H@("`@("H@0'9A<B!M
M:7AE9`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7V1S;B`]("<G.PH*("`@("\J*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!O
M=7(@<V5T(&]F($1"(&-O;F9I9W5R871I;VX@;W!T:6]N<RX*("`@("`J($!V
M87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]O<'1I;VYS(#T@87)R87DH)W!E<G-I<W1E;G0G(#T^('1R=64I.PH*
M("`@("\J*@H@("`@("H@3V)J96-T(&AO;&1I;F<@=&AE(&1A=&%B87-E(&AA
M;F1L92X*("`@("`J($!V87(@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?9&(@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@4F5S;W5R8V4@:&]L9&EN9R!T:&4@<')E<&%R960@<W1A=&5M96YT(&AA
M;F1L92X*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]S=&%T96UE;G0@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@1FQA9R!I;F1I8V%T:6YG('1H870@=V4G<F4@=7-I;F<@
M86X@97AI<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7V5X:7-T:6YG0V]N;F5C=&EO;B`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@4W1R:6YG(&AO;&1I;F<@=&AE(&1A=&%B87-E('1A8FQE('1O('5S92X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?=&%B;&4@/2`G;&]G7W1A8FQE)SL*"B`@("`O*BH*
M("`@("`J(%-T<FEN9R!H;VQD:6YG('1H92!N86UE(&]F('1H92!)1"!S97%U
M96YC92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?<V5Q=65N8V4@/2`G;&]G7VED)SL*"B`@
M("`O*BH*("`@("`J($UA>&EM=6T@;&5N9W1H(&]F('1H92`D:61E;G0@<W1R
M:6YG+B`@5&AI<R!C;W)R97-P;VYD<R!T;R!T:&4@<VEZ92!O9@H@("`@("H@
M=&AE("=I9&5N="<@8V]L=6UN(&EN('1H92!344P@=&%B;&4N"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]I9&5N=$QI;6ET(#T@,38["@H@("`@+RHJ"B`@("`@*B!3970@
M;V8@9FEE;&0@='EP97,@=7-E9"!I;B!T:&4@9&%T86)A<V4@=&%B;&4N"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1?='EP97,@/2!A<G)A>2@*("`@("`@("`G:60G("`@("`@
M("`]/B`G:6YT96=E<B<L"B`@("`@("`@)VQO9W1I;64G("`@/3X@)W1I;65S
M=&%M<"<L"B`@("`@("`@)VED96YT)R`@("`@/3X@)W1E>'0G+`H@("`@("`@
M("=P<FEO<FET>2<@(#T^("=T97AT)RP*("`@("`@("`G;65S<V%G92<@("`]
M/B`G8VQO8B<*("`@("D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@
M;F5W('-Q;"!L;V=G:6YG(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("`@("`@5&AE('1A<F=E="!344P@=&%B;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("`@("`@5&AE(&ED96YT:69I
M8V%T:6]N(&9I96QD+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@("`@
M("`@(%1H92!C;VYN96-T:6]N(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@
M*B!`<&%R86T@:6YT("1L979E;"`@("`@("`@("`@3&]G(&UE<W-A9V5S('5P
M('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]M9&(R*"1N86UE+"`D
M:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@
M("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D
M=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^
M7W1A8FQE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI5
M4%1/*"1L979E;"D["@H@("`@("`@("\J($EF(&%N(&]P=&EO;G,@87)R87D@
M=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@("`@:68@*&ES<V5T*"1C
M;VYF6R=O<'1I;VYS)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=O<'1I;VYS)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N<R`]("1C;VYF6R=O<'1I
M;VYS)UT["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A('-P96-I9FEC('-E
M<75E;F-E(&YA;64@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@("`@
M:68@*"%E;7!T>2@D8V]N9ELG<V5Q=65N8V4G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]S97%U96YC92`]("1C;VYF6R=S97%U96YC92==.PH@("`@("`@
M('T*"B`@("`@("`@+RH@268@82!S<&5C:69I8R!S97%U96YC92!N86UE('=A
M<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("AI<W-E="@D8V]N
M9ELG:61E;G1,:6UI="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VED96YT
M3&EM:70@/2`D8V]N9ELG:61E;G1,:6UI="==.PH@("`@("`@('T*"B`@("`@
M("`@+RH@3F]W('1H870@=&AE(&ED96YT(&QI;6ET(&ES(&-O;F9I<FUE9"P@
M<V5T('1H92!I9&5N="!S=')I;F<N("HO"B`@("`@("`@)'1H:7,M/G-E=$ED
M96YT*"1I9&5N="D["@H@("`@("`@("\J($EF(&%N(&5X:7-T:6YG(&1A=&%B
M87-E(&-O;FYE8W1I;VX@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@
M("`@:68@*&ES<V5T*"1C;VYF6R=D8B==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V1B(#T@)B1C;VYF6R=D8B==.PH@("`@("`@("`@("`D=&AI<RT^7V5X
M:7-T:6YG0V]N;F5C=&EO;B`]('1R=64["B`@("`@("`@("`@("1T:&ES+3Y?
M;W!E;F5D(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)&-O;F9;
M)W-I;F=L971O;B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@)DU$
M0C(Z.G-I;F=L971O;B@D8V]N9ELG<VEN9VQE=&]N)UTL("1T:&ES+3Y?;W!T
M:6]N<RD["B`@("`@("`@("`@("1T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N
M(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?9'-N(#T@)&-O
M;F9;)V1S;B==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($]P
M96YS(&$@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4L(&EF(&ET(&AA<R!N
M;W0@86QR96%D>0H@("`@("H@8F5E;B!O<&5N960N(%1H:7,@:7,@:6UP;&EC
M:71L>2!C86QL960@8GD@;&]G*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?
M;W!E;F5D*2!["B`@("`@("`@("`@("\J(%5S92!T:&4@1%-.(&%N9"!O<'1I
M;VYS('1O(&-R96%T92!A(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@
M("`@("`@("1T:&ES+3Y?9&(@/2`F341",CHZ8V]N;F5C="@D=&AI<RT^7V1S
M;BP@)'1H:7,M/E]O<'1I;VYS*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)'1H:7,M/E]D8BDI('L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0W)E871E(&$@
M<')E<&%R960@<W1A=&5M96YT(&9O<B!R97!E871E9"!U<V4@:6X@;&]G*"DN
M("HO"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]P<F5P87)E4W1A=&5M96YT
M*"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@5V4@;F]W(&-O;G-I9&5R(&]U="!C;VYN
M96-T:6]N(&]P96XN("HO"B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@
M=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V]P96YE
M9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E<R!T:&4@8V]N;F5C=&EO
M;B!T;R!T:&4@9&%T86)A<V4@:68@:70@:7,@<W1I;&P@;W!E;B!A;F0@=V4@
M=V5R90H@("`@("H@=&AE(&]N97,@=&AA="!O<&5N960@:70N("!)="!I<R!T
M:&4@8V%L;&5R)W,@<F5S<&]N<VEB;&4@=&\@8VQO<V4@86X*("`@("`J(&5X
M:7-T:6YG(&-O;FYE8W1I;VX@=&AA="!W87,@<&%S<V5D('1O('5S('9I82`D
M8V]N9ELG9&(G72X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("![
M"B`@("`@("`@+RH@268@=V4@:&%V92!A('-T871E;65N="!O8FIE8W0L(&9R
M964@:70N("HO"B`@("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^7W-T871E
M;65N="DI('L*("`@("`@("`@("`@)'1H:7,M/E]S=&%T96UE;G0M/F9R964H
M*3L*("`@("`@("`@("`@)'1H:7,M/E]S=&%T96UE;G0@/2!N=6QL.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@=V4@;W!E;F5D('1H92!D871A8F%S92!C
M;VYN96-T:6]N+"!D:7-C;VYN96-T(&ET+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^7V]P96YE9"`F)B`A)'1H:7,M/E]E>&ES=&EN9T-O;FYE8W1I;VXI('L*
M("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!F86QS93L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`H)'1H:7,M/E]O<&5N960@/3T](&9A;'-E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AI<R!,;V<@:6YS=&%N8V4G
M<R!I9&5N=&EF:6-A=&EO;B!S=')I;F<N("!.;W1E('1H870@=&AI<PH@("`@
M("H@4U%,+7-P96-I9FEC(&EM<&QE;65N=&%T:6]N('=I;&P@;&EM:70@=&AE
M(&QE;F=T:"!O9B!T:&4@)&ED96YT('-T<FEN9PH@("`@("H@=&\@<VEX=&5E
M;B`H,38I(&-H87)A8W1E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@("`D:61E;G0@("`@("!4:&4@;F5W(&ED96YT:69I8V%T:6]N('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC
M92`@($QO9R`Q+C@N-0H@("`@("HO"B`@("!F=6YC=&EO;B!S971)9&5N="@D
M:61E;G0I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9&5N="`]('-U8G-T<B@D
M:61E;G0L(#`L("1T:&ES+3Y?:61E;G1,:6UI="D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!);G-E<G1S("1M97-S86=E('1O('1H92!C=7)R96YT;'D@;W!E
M;B!D871A8F%S92X@($-A;&QS(&]P96XH*2P*("`@("`J(&EF(&YE8V5S<V%R
M>2X@($%L<V\@<&%S<V5S('1H92!M97-S86=E(&%L;VYG('1O(&%N>2!,;V=?
M;V)S97)V97(*("`@("`J(&EN<W1A;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@
M=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G
M92`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E('1O
M(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO
M<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@
M("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!
M3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@
M4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@("H@("`@("`@
M("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N
M9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L
M("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@82!P<FEO
M<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F875L="!V
M86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@
M("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@
M:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@
M("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T
M:&4@8V]N;F5C=&EO;B!I<VXG="!O<&5N(&%N9"!C86XG="!B92!O<&5N960L
M(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N
M960@)B8@(21T:&ES+3YO<&5N*"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@9&]N)W0@86QR96%D
M>2!H879E(&$@<W1A=&5M96YT(&]B:F5C="P@8W)E871E(&]N92X@*B\*("`@
M("`@("!I9B`H(6ES7V]B:F5C="@D=&AI<RT^7W-T871E;65N="D@)B8@(21T
M:&ES+3Y?<')E<&%R95-T871E;65N="@I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T
M<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@
M("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I
M.PH*("`@("`@("`O*B!"=6EL9"!O=7(@<V5T(&]F('9A;'5E<R!F;W(@=&AI
M<R!L;V<@96YT<GDN("HO"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*`H@("`@
M("`@("`@("`G:60G("`@("`@(#T^("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI
M<RT^7W-E<75E;F-E*2P*("`@("`@("`@("`@)VQO9W1I;64G("`]/B!-1$(R
M7T1A=&4Z.FUD8DYO=R@I+`H@("`@("`@("`@("`G:61E;G0G("`@(#T^("1T
M:&ES+3Y?:61E;G0L"B`@("`@("`@("`@("=P<FEO<FET>2<@/3X@)'!R:6]R
M:71Y+`H@("`@("`@("`@("`G;65S<V%G92<@(#T^("1M97-S86=E"B`@("`@
M("`@*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@4U%,('%U97)Y(&9O<B!T
M:&ES(&QO9R!E;G1R>2!I;G-E<G1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]D
M8BT^97AP96-T17)R;W(H341",E]%4E)/4E].3U-50TA404),12D["B`@("`@
M("`@)')E<W5L="`]("8D=&AI<RT^7W-T871E;65N="T^97AE8W5T92@D=F%L
M=65S*3L*("`@("`@("`D=&AI<RT^7V1B+3YP;W!%>'!E8W0H*3L*"B`@("`@
M("`@+RH@071T96UP="!T;R!H86YD;&4@86YY(&5R<F]R<RX@*B\*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O
M*B!792!C86X@;VYL>2!H86YD;&4@341",E]%4E)/4E].3U-50TA404),12!E
M<G)O<G,N("HO"B`@("`@("`@("`@(&EF("@D<F5S=6QT+3YG971#;V1E*"D@
M(3T@341",E]%4E)/4E].3U-50TA404),12D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!
M='1E;7!T('1O(&-R96%T92!T:&4@=&%R9V5T('1A8FQE+B`J+PH@("`@("`@
M("`@("!I9B`H(21T:&ES+3Y?8W)E871E5&%B;&4H*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!296-R96%T92!O=7(@<')E<&%R960@<W1A=&5M96YT(')E<V]U<F-E
M+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W-T871E;65N="T^9G)E92@I.PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?<')E<&%R95-T871E;65N="@I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J($%T=&5M<'0@=&\@<F4M97AE8W5T92!T:&4@:6YS
M97)T:6]N('%U97)Y+B`J+PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]S=&%T96UE;G0M/F5X96-U=&4H)'9A;'5E<RD["B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I
M='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@;&]G('1A
M8FQE(&EN('1H92!D871A8F%S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M<F5A=&5486)L92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]D8BT^;&]A9$UO
M9'5L92@G36%N86=E<B<L(&YU;&PL('1R=64I.PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YM86YA9V5R+3YC<F5A=&5486)L92@*("`@("`@("`@
M("`@)'1H:7,M/E]T86)L92P*("`@("`@("`@("`@87)R87DH"B`@("`@("`@
M("`@("`@("`G:60G("`@("`@("`]/B!A<G)A>2@G='EP92<@/3X@)'1H:7,M
M/E]T>7!E<ULG:60G72DL"B`@("`@("`@("`@("`@("`G;&]G=&EM92<@("`]
M/B!A<G)A>2@G='EP92<@/3X@)'1H:7,M/E]T>7!E<ULG;&]G=&EM92==*2P*
M("`@("`@("`@("`@("`@("=I9&5N="<@("`@(#T^(&%R<F%Y*"=T>7!E)R`]
M/B`D=&AI<RT^7W1Y<&5S6R=I9&5N="==*2P*("`@("`@("`@("`@("`@("=P
M<FEO<FET>2<@(#T^(&%R<F%Y*"=T>7!E)R`]/B`D=&AI<RT^7W1Y<&5S6R=P
M<FEO<FET>2==*2P*("`@("`@("`@("`@("`@("=M97-S86=E)R`@(#T^(&%R
M<F%Y*"=T>7!E)R`]/B`D=&AI<RT^7W1Y<&5S6R=M97-S86=E)UTI"B`@("`@
M("`@("`@("D*("`@("`@("`I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YM86YA9V5R+3YC
M<F5A=&5);F1E>"@*("`@("`@("`@("`@)'1H:7,M/E]T86)L92P*("`@("`@
M("`@("`@)W5N:7%U95]I9"<L"B`@("`@("`@("`@(&%R<F%Y*"=F:65L9',G
M(#T^(&%R<F%Y*"=I9"<@/3X@=')U92DL("=U;FEQ=64G(#T^('1R=64I"B`@
M("`@("`@*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%!R97!A<F4@
M=&AE(%-13"!I;G-E<G1I;VX@<W1A=&5M96YT+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@<W1A=&5M96YT('=A<R!S=6-C
M97-S9G5L;'D@8W)E871E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B!`<VEN8V4@("!,;V<@,2XY+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W!R97!A<F53=&%T96UE;G0H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<W1A=&5M96YT(#T@)B1T:&ES+3Y?9&(M/G!R97!A<F4H"B`@("`@("`@
M("`@("`@("`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?=&%B;&4@+@H@("`@
M("`@("`@("`@("`@)R`H:60L(&QO9W1I;64L(&ED96YT+"!P<FEO<FET>2P@
M;65S<V%G92DG("X*("`@("`@("`@("`@("`@("<@5D%,5453*#II9"P@.FQO
M9W1I;64L(#II9&5N="P@.G!R:6]R:71Y+"`Z;65S<V%G92DG+`H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]T>7!E<RP@341",E]04D5005)%7TU!3DE0*3L*
M"B`@("`@("`@+RH@4F5T=7)N('-U8V-E<W,@:68@=V4@9&ED;B=T(&=E;F5R
M871E(&%N(&5R<F]R+B`J+PH@("`@("`@(')E='5R;B`H4$5!4CHZ:7-%<G)O
M<B@D=&AI<RT^7W-T871E;65N="D@/3T](&9A;'-E*3L*("`@('T*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O;G5L;"YP:'``````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#`P-@`Q,#4Q-30S
M,3`U-P`P,3<U-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E
M87(O3&]G+TQO9R]N=6QL+G!H<"QV(#$N-"`R,#`U+S`R+S(V(#$T.C0X.C4X
M(&-H86=E;F)U($5X<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@,2XT
M("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,;V=?;G5L;"!C
M;&%S<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z
M.B!A8G-T<F%C=`H@*B!C;&%S<RX@($ET('-I;7!L>2!C;VYS=6UE<R!L;V<@
M979E;G1S+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE
M=#X*("H@0'-I;F-E("`@3&]G(#$N."XR"B`J($!P86-K86=E($QO9PH@*@H@
M*B!`97AA;7!L92!N=6QL+G!H<"`@("!5<VEN9R!T:&4@;G5L;"!H86YD;&5R
M+@H@*B\*8VQA<W,@3&]G7VYU;&P@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1S(&$@;F5W($QO9U]N=6QL(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN
M9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U
M<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@
M3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO
M9U]N=6QL*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H)
M"0D)"2`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M
M/E]I9&5N="`]("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z
M.E505$\H)&QE=F5L*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-I;7!L>2!C
M;VYS=6UE<R!T:&4@;&]G(&5V96YT+B`@5&AE(&UE<W-A9V4@=VEL;"!S=&EL
M;"!B92!P87-S960*("`@("`J(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(@
M:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN9R!T:&ES($QO9RX*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E("`@(%-T<FEN9R!O<B!O
M8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE
M<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@
M87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@
M("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@
M4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!
M4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"
M54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O
M<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N
M=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E
M96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@
M("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I
M;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@
M+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M
M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^
M7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A
M>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S
M86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O;V)S97)V
M97(N<&AP````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,#`U-P`Q,#4Q-30S,3`U-P`P,C`T,C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R
M97!O<VET;W)Y+W!E87(O3&]G+TQO9R]O8G-E<G9E<BYP:'`L=B`Q+C$X(#(P
M,#8O,#0O,C4@,#8Z,#(Z,C,@:F]N($5X<"`D"B`J("1(;W)D93H@:&]R9&4O
M;&EB+TQO9R]O8G-E<G9E<BYP:'`L=B`Q+C4@,C`P,"\P-B\R."`R,3HS-CHQ
M,R!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C$X("0*
M("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,;V=?;V)S97)V97(Z
M.B!C;&%S<R!I;7!L96UE;G1S('1H92!/8G-E<G9E<B!E;F0@;V8@82!3=6)J
M96-T+4]B<V5R=F5R"B`J('!A='1E<FX@9F]R('=A=&-H:6YG(&QO9R!A8W1I
M=FET>2!A;F0@=&%K:6YG(&%C=&EO;G,@;VX@97AC97!T:6]N86P@979E;G1S
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!S:6YC92`@($QO9R`Q
M+C`*("H@0'!A8VMA9V4@3&]G"B`J"B`J($!E>&%M<&QE(&]B<V5R=F5R7VUA
M:6PN<&AP("`@06X@97AA;7!L92!,;V=?;V)S97)V97(@:6UP;&5M96YT871I
M;VXN"B`J+PIC;&%S<R!,;V=?;V)S97)V97(*>PH@("`@+RHJ"B`@("`@*B!)
M;G-T86YC92US<&5C:69I8R!U;FEQ=64@:61E;G1I9FEC871I;VX@;G5M8F5R
M+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7VED(#T@,#L*"B`@("`O*BH*("`@
M("`J(%1H92!M:6YI;75M('!R:6]R:71Y(&QE=F5L(&]F(&UE<W-A9V4@=&AA
M="!W92!W86YT('1O(&AE87(@86)O=70N"B`@("`@*B!014%27TQ/1U]%3452
M1R!I<R!T:&4@:&EG:&5S="!P<FEO<FET>2P@<V\@=V4@=VEL;"!O;FQY(&AE
M87(@;65S<V%G97,*("`@("`J('=I=&@@86X@:6YT96=E<B!P<FEO<FET>2!V
M86QU92!L97-S('1H86X@;W(@97%U86P@=&\@;W5R<RX@($ET(&1E9F%U;'1S
M"B`@("`@*B!T;R!014%27TQ/1U])3D9/+"!W:&EC:"!L:7-T96YS('1O(&5V
M97)Y=&AI;F<@97AC97!T(%!%05)?3$]'7T1%0E5'+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?<')I;W)I='D@/2!014%27TQ/1U])3D9/.PH*("`@("\J*@H@
M("`@("H@0W)E871E<R!A(&YE=R!B87-I8R!,;V=?;V)S97)V97(@:6YS=&%N
M8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@("`D<')I;W)I='D@
M("!4:&4@:&EG:&5S="!P<FEO<FET>2!A="!W:&EC:"!T;R!R96-E:79E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QO9R!E=F5N="!N
M;W1I9FEC871I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N($QO9U]O8G-E<G9E<B@D<')I;W)I='D@/2!0
M14%27TQ/1U])3D9/*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H
M;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?<')I;W)I='D@/2`D<')I
M;W)I='D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U
M<FX@82!N97<@8V]N8W)E=&4@3&]G7V]B<V5R=F5R(&EN<W1A;F-E(&]F('1H
M92!R97%U97-T960*("`@("`J('1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@("`D='EP92`@("`@("!4:&4@='EP92!O9B!C;VYC<F5A=&4@
M3&]G7V]B<V5R=F5R('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1O(')E='5R;BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("`@)'!R:6]R:71Y("`@5&AE(&AI9VAE<W0@<')I;W)I='D@870@=VAI8V@@
M=&\@<F5C96EV90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!L;V<@979E;G0@;F]T:69I8V%T:6]N<RX*("`@("`J($!P87)A;2!A<G)A
M>2`@("`@)&-O;F8@("`@("`@3W!T:6]N86P@87-S;V-I871I=F4@87)R87D@
M;V8@861D:71I;VYA;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYF:6=U<F%T:6]N('9A;'5E<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&]B:F5C="`@("`@("`@("`@("`@(%1H92!N97=L>2!C<F5A=&5D(&-O
M;F-R971E($QO9U]O8G-E<G9E<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I;G-T86YC92P@;W(@;G5L;"!O;B!A;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)'1Y<&4L("1P<FEO<FET>2`]
M(%!%05)?3$]'7TE.1D\L("1C;VYF(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D='EP92`]('-T<G1O;&]W97(H)'1Y<&4I.PH@("`@("`@("1C;&%S<R`]
M("=,;V=?;V)S97)V97)?)R`N("1T>7!E.PH*("`@("`@("`O*@H@("`@("`@
M("`J($EF('1H92!D97-I<F5D(&-L87-S(&%L<F5A9'D@97AI<W1S("AB96-A
M=7-E('1H92!C86QL97(@:&%S('-U<'!L:65D"B`@("`@("`@("H@:70@9G)O
M;2!S;VUE(&-U<W1O;2!L;V-A=&EO;BDL('-I;7!L>2!I;G-T86YT:6%T92!A
M;F0@<F5T=7)N(&$@;F5W"B`@("`@("`@("H@:6YS=&%N8V4N"B`@("`@("`@
M("HO"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@
M("`@("`@("1O8FIE8W0@/2`F;F5W("1C;&%S<R@D<')I;W)I='DL("1C;VYF
M*3L*("`@("`@("`@("`@<F5T=7)N("1O8FIE8W0["B`@("`@("`@?0H*("`@
M("`@("`O*B!3=7!P;W)T(&)O=&@@=&AE(&YE=RUS='EL92!A;F0@;VQD+7-T
M>6QE(&9I;&4@;F%M:6YG(&-O;G9E;G1I;VYS+B`J+PH@("`@("`@("1N97=S
M='EL92`]('1R=64["B`@("`@("`@)&-L87-S9FEL92`](&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]O8G-E<G9E<E\G("X@)'1Y<&4@+B`G+G!H<"<["@H@("`@
M("`@(&EF("@A9FEL95]E>&ES=',H)&-L87-S9FEL92DI('L*("`@("`@("`@
M("`@)&-L87-S9FEL92`]("=,;V<O)R`N("1T>7!E("X@)RYP:'`G.PH@("`@
M("`@("`@("`D;F5W<W1Y;&4@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\J"B`@("`@("`@("H@071T96UP="!T;R!I;F-L=61E(&]U<B!V97)S:6]N
M(&]F('1H92!N86UE9"!C;&%S<RP@8G5T(&1O;B=T('1R96%T"B`@("`@("`@
M("H@82!F86EL=7)E(&%S(&9A=&%L+B`@5&AE(&-A;&QE<B!M87D@:&%V92!A
M;')E861Y(&EN8VQU9&5D('1H96ER(&]W;@H@("`@("`@("`J('9E<G-I;VX@
M;V8@=&AE(&YA;65D(&-L87-S+@H@("`@("`@("`J+PH@("`@("`@($!I;F-L
M=61E7V]N8V4@)&-L87-S9FEL93L*"B`@("`@("`@+RH@268@=&AE(&-L87-S
M(&5X:7-T<RP@<F5T=7)N(&$@;F5W(&EN<W1A;F-E(&]F(&ET+B`J+PH@("`@
M("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`O
M*B!3=7!P;W)T(&)O=&@@;F5W+7-T>6QE(&%N9"!O;&0M<W1Y;&4@8V]N<W1R
M=6-T:6]N+B`J+PH@("`@("`@("`@("!I9B`H)&YE=W-T>6QE*2!["B`@("`@
M("`@("`@("`@("`D;V)J96-T(#T@)FYE=R`D8VQA<W,H)'!R:6]R:71Y+"`D
M8V]N9BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M;V)J96-T(#T@)FYE=R`D8VQA<W,H)'!R:6]R:71Y*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&]B:F5C=#L*("`@("`@("!]"@H@("`@
M("`@("1N=6QL(#T@;G5L;#L*("`@("`@("!R971U<FX@)&YU;&P["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&ES(&$@<W1U8B!M971H;V0@=&\@;6%K
M92!S=7)E('1H870@3&]G7T]B<V5R=F5R(&-L87-S97,@9&\*("`@("`J('-O
M;65T:&EN9R!W:&5N('1H97D@87)E(&YO=&EF:65D(&]F(&$@;65S<V%G92X@
M(%1H92!D969A=6QT(&)E:&%V:6]R"B`@("`@*B!I<R!T;R!J=7-T('!R:6YT
M('1H92!M97-S86=E+"!W:&EC:"!I<R!O8G9I;W5S;'D@;F]T(&1E<VER96%B
M;&4@:6X*("`@("`J('!R86-T:6-A;&QY(&%N>2!S:71U871I;VX@+2!W:&EC
M:"!I<R!W:'D@>6]U(&YE960@=&\@;W9E<G)I9&4@=&AI<PH@("`@("H@;65T
M:&]D+B`Z*0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("`@)&5V96YT
M("`@("`@02!H87-H(&1E<V-R:6)I;F<@=&AE(&QO9R!E=F5N="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;F]T:69Y*"1E=F5N="D*("`@('L*("`@("`@("!P
M<FEN=%]R*"1E=F5N="D["B`@("!]"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]S<6PN<&AP````````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q,#<S`#$P-3$U
M-#,Q,#4W`#`Q-S,W-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO
M<&5A<B],;V<O3&]G+W-Q;"YP:'`L=B`Q+C0P(#(P,#8O,#$O,#,@,#0Z,3(Z
M-#4@:F]N($5X<"`D"B`J("1(;W)D93H@:&]R9&4O;&EB+TQO9R]S<6PN<&AP
M+'8@,2XQ,B`R,#`P+S`X+S$V(#(P.C(W.C,T(&-H=6-K($5X<"`D"B`J"B`J
M($!V97)S:6]N("12979I<VEO;CH@,2XT,"`D"B`J($!P86-K86=E($QO9PH@
M*B\*"B\J"B`J(%=E(')E<75I<F4@=&AE(%!%05(@1$(@8VQA<W,N("!4:&ES
M(&ES(&=E;F5R86QL>2!D969I;F5D(&EN('1H92!$0BYP:'`@9FEL92P*("H@
M8G5T(&ET)W,@<&]S<VEB;&4@=&AA="!T:&4@8V%L;&5R(&UA>2!H879E('!R
M;W9I9&5D('1H92!$0B!C;&%S<RP@;W(@80H@*B!C;VUP871I8FQE('=R87!P
M97(@*'-U8V@@87,@=&AE(&]N92!S:&EP<&5D('=I=&@@341",BDL('-O('=E
M(&9I<G-T(&-H96-K"B`J(&9O<B!A;B!E>&ES=&EN9R`G1$(G(&-L87-S(&)E
M9F]R92!I;F-L=61I;F<@)T1"+G!H<"<N"B`J+PII9B`H(6-L87-S7V5X:7-T
M<R@G1$(G*2D@>PH@("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PI]"@HO*BH*
M("H@5&AE($QO9U]S<6P@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE;G1A
M=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA<W,@=VAI8V@@<V5N
M9',@;65S<V%G97,@=&\@86X@4U%,('-E<G9E<BX@($5A8V@@96YT<GD*("H@
M;V-C=7!I97,@82!S97!A<F%T92!R;W<@:6X@=&AE(&1A=&%B87-E+@H@*@H@
M*B!4:&ES(&EM<&QE;65N=&%T:6]N('5S97,@4$A0)W,@4$5!4B!D871A8F%S
M92!A8G-T<F%C=&EO;B!L87EE<BX*("H*("H@0U)%051%(%1!0DQ%(&QO9U]T
M86)L92`H"B`J("!I9"`@("`@("`@("!)3E0@3D]4($Y53$PL"B`J("!L;V=T
M:6UE("`@("!424U%4U1!35`@3D]4($Y53$PL"B`J("!I9&5N="`@("`@("!#
M2$%2*#$V*2!.3U0@3E5,3"P*("H@('!R:6]R:71Y("`@($E.5"!.3U0@3E5,
M3"P*("H@(&UE<W-A9V4@("`@(%9!4D-(05(H,C`P*2P*("H@(%!224U!4ED@
M2T59("AI9"D*("H@*3L*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N
M0'!H<"YN970^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<VEN8V4@("!,
M;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!S<6PN<&AP
M("`@("!5<VEN9R!T:&4@4U%,(&AA;F1L97(N"B`J+PIC;&%S<R!,;V=?<W%L
M(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@5F%R:6%B;&4@8V]N=&%I
M;FEN9R!T:&4@1%-.(&EN9F]R;6%T:6]N+@H@("`@("H@0'9A<B!M:7AE9`H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1S;B`]
M("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(%-1
M3"!I;G-E<G1I;VX@<W1A=&5M96YT+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M<W%L(#T@)R<["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!C;VYT86EN:6YG(&]U
M<B!S970@;V8@1$(@8V]N9FEG=7)A=&EO;B!O<'1I;VYS+@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7V]P=&EO;G,@/2!A<G)A>2@G<&5R<VES=&5N="<@/3X@=')U92D["@H@
M("`@+RHJ"B`@("`@*B!/8FIE8W0@:&]L9&EN9R!T:&4@9&%T86)A<V4@:&%N
M9&QE+@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]D8B`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!297-O=7)C92!H;VQD:6YG('1H92!P<F5P87)E9"!S=&%T96UE;G0@:&%N
M9&QE+@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7W-T871E;65N="`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!&;&%G(&EN9&EC871I;F<@=&AA="!W92=R92!U<VEN9R!A
M;B!E>&ES=&EN9R!D871A8F%S92!C;VYN96-T:6]N+@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?97AI<W1I;F=#;VYN96-T:6]N(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!3=')I;F<@:&]L9&EN9R!T:&4@9&%T86)A<V4@=&%B;&4@=&\@=7-E+@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]T86)L92`]("=L;V=?=&%B;&4G.PH*("`@("\J*@H@
M("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&YA;64@;V8@=&AE($E$('-E<75E
M;F-E+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]S97%U96YC92`]("=L;V=?:60G.PH*("`@
M("\J*@H@("`@("H@36%X:6UU;2!L96YG=&@@;V8@=&AE("1I9&5N="!S=')I
M;F<N("!4:&ES(&-O<G)E<W!O;F1S('1O('1H92!S:7IE(&]F"B`@("`@*B!T
M:&4@)VED96YT)R!C;VQU;6X@:6X@=&AE(%-13"!T86)L92X*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7VED96YT3&EM:70@/2`Q-CL*"@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1S(&$@;F5W('-Q;"!L;V=G:6YG(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE('1A<F=E="!344P@
M=&%B;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("`@("`@5&AE
M(&ED96YT:69I8V%T:6]N(&9I96QD+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C
M;VYF("`@("`@("`@(%1H92!C;VYN96-T:6]N(&-O;F9I9W5R871I;VX@87)R
M87DN"B`@("`@*B!`<&%R86T@:6YT("1L979E;"`@("`@("`@("`@3&]G(&UE
M<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]S<6PH
M)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@
M("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@
M("1T:&ES+3Y?=&%B;&4@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VUA<VL@
M/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@("`@("`@+RH@3F]W('1H870@=V4@
M:&%V92!A('1A8FQE(&YA;64L(&%S<VEG;B!O=7(@4U%,('-T871E;65N="X@
M*B\*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<W%L*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-Q;"`]("1C;VYF6R=S<6PG73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-Q;"`]("=)3E-%4E0@24Y43R`G
M("X@)'1H:7,M/E]T86)L92`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R`H:60L(&QO9W1I;64L(&ED96YT+"!P<FEO<FET>2P@;65S<V%G92DG("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(%9!3%5%4R@_+"!#55)214Y4
M7U1)34535$%-4"P@/RP@/RP@/RDG.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@86X@;W!T:6]N<R!A<G)A>2!W87,@<')O=FED960L('5S92!I="X@*B\*
M("`@("`@("!I9B`H:7-S970H)&-O;F9;)V]P=&EO;G,G72D@)B8@:7-?87)R
M87DH)&-O;F9;)V]P=&EO;G,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]O
M<'1I;VYS(#T@)&-O;F9;)V]P=&EO;G,G73L*("`@("`@("!]"@H@("`@("`@
M("\J($EF(&$@<W!E8VEF:6,@<V5Q=65N8V4@;F%M92!W87,@<')O=FED960L
M('5S92!I="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=S97%U96YC
M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E<75E;F-E(#T@)&-O;F9;
M)W-E<75E;F-E)UT["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A('-P96-I
M9FEC('-E<75E;F-E(&YA;64@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@
M("`@("`@:68@*&ES<V5T*"1C;VYF6R=I9&5N=$QI;6ET)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?:61E;G1,:6UI="`]("1C;VYF6R=I9&5N=$QI;6ET
M)UT["B`@("`@("`@?0H*("`@("`@("`O*B!.;W<@=&AA="!T:&4@:61E;G0@
M;&EM:70@:7,@8V]N9FER;65D+"!S970@=&AE(&ED96YT('-T<FEN9RX@*B\*
M("`@("`@("`D=&AI<RT^<V5T261E;G0H)&ED96YT*3L*"B`@("`@("`@+RH@
M268@86X@97AI<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;B!W87,@<')O=FED
M960L('5S92!I="X@*B\*("`@("`@("!I9B`H:7-S970H)&-O;F9;)V1B)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`F)&-O;F9;)V1B)UT["B`@
M("`@("`@("`@("1T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N(#T@=')U93L*
M("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?9'-N(#T@)&-O;F9;)V1S;B==
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS(&$@8V]N
M;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4L(&EF(&ET(&AA<R!N;W0@86QR96%D
M>0H@("`@("H@8F5E;B!O<&5N960N(%1H:7,@:7,@:6UP;&EC:71L>2!C86QL
M960@8GD@;&]G*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU
M<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!O<&5N*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2![
M"B`@("`@("`@("`@("\J(%5S92!T:&4@1%-.(&%N9"!O<'1I;VYS('1O(&-R
M96%T92!A(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@("`@("1T
M:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]D<VXL("1T:&ES+3Y?
M;W!T:6]N<RD["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D=&AI<RT^
M7V1B*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!#<F5A=&4@82!P<F5P87)E9"!S=&%T
M96UE;G0@9F]R(')E<&5A=&5D('5S92!I;B!L;V<H*2X@*B\*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^7W!R97!A<F53=&%T96UE;G0H*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!792!N;W<@8V]N<VED97(@;W5T(&-O;FYE8W1I;VX@;W!E;BX@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VQO<V5S('1H92!C;VYN96-T:6]N('1O('1H92!D871A
M8F%S92!I9B!I="!I<R!S=&EL;"!O<&5N(&%N9"!W92!W97)E"B`@("`@*B!T
M:&4@;VYE<R!T:&%T(&]P96YE9"!I="X@($ET(&ES('1H92!C86QL97(G<R!R
M97-P;VYS:6)L92!T;R!C;&]S92!A;@H@("`@("H@97AI<W1I;F<@8V]N;F5C
M=&EO;B!T:&%T('=A<R!P87-S960@=&\@=7,@=FEA("1C;VYF6R=D8B==+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]O<&5N960@)B8@(21T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/F9R9650<F5P87)E9"@D=&AI<RT^7W-T871E
M;65N="D["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YD:7-C;VYN
M96-T*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"1T:&ES+3Y?;W!E
M;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M:7,@3&]G(&EN<W1A;F-E)W,@:61E;G1I9FEC871I;VX@<W1R:6YG+B`@3F]T
M92!T:&%T('1H:7,*("`@("`J(%-13"US<&5C:69I8R!I;7!L96UE;G1A=&EO
M;B!W:6QL(&QI;6ET('1H92!L96YG=&@@;V8@=&AE("1I9&5N="!S=')I;F<*
M("`@("`J('1O('-I>'1E96X@*#$V*2!C:&%R86-T97)S+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("`@)&ED96YT("`@("`@5&AE(&YE=R!I9&5N
M=&EF:6-A=&EO;B!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XX+C4*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T261E;G0H)&ED96YT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M:61E;G0@/2!S=6)S='(H)&ED96YT+"`P+"`D=&AI<RT^7VED96YT3&EM:70I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@26YS97)T<R`D;65S<V%G92!T;R!T
M:&4@8W5R<F5N=&QY(&]P96X@9&%T86)A<V4N("!#86QL<R!O<&5N*"DL"B`@
M("`@*B!I9B!N96-E<W-A<GDN("!!;'-O('!A<W-E<R!T:&4@;65S<V%G92!A
M;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R"B`@("`@*B!I;G-T86YC97,@=&AA
M="!A<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN
M9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@
M("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%
M34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@
M(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.
M1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!0
M14%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL
M=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@
M("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U
M<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET
M>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^
M7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@
M:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@
M;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO
M<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@=&AE(&-O;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@
M8V%N)W0@8F4@;W!E;F5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!I
M9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($EF
M('=E(&1O;B=T(&%L<F5A9'D@:&%V92!O=7(@<W1A=&5M96YT(&]B:F5C="!Y
M970L(&-R96%T92!I="X@*B\*("`@("`@("!I9B`H(6ES7V]B:F5C="@D=&AI
M<RT^7W-T871E;65N="D@)B8@(21T:&ES+3Y?<')E<&%R95-T871E;65N="@I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T
M:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT
M<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`O*B!"=6EL9"!O=7(@
M<V5T(&]F('9A;'5E<R!F;W(@=&AI<R!L;V<@96YT<GDN("HO"B`@("`@("`@
M)&ED(#T@)'1H:7,M/E]D8BT^;F5X=$ED*"1T:&ES+3Y?<V5Q=65N8V4I.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D:60L("1T:&ES+3Y?:61E;G0L("1P
M<FEO<FET>2P@)&UE<W-A9V4I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!3
M44P@<75E<GD@9F]R('1H:7,@;&]G(&5N=')Y(&EN<V5R=&EO;BX@*B\*("`@
M("`@("`D<F5S=6QT(#TF("1T:&ES+3Y?9&(M/F5X96-U=&4H)'1H:7,M/E]S
M=&%T96UE;G0L("1V86QU97,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@
M/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<F5P87)E
M('1H92!344P@:6YS97)T:6]N('-T871E;65N="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('-T871E;65N="!W87,@<W5C
M8V5S<V9U;&QY(&-R96%T960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("H@0'-I;F-E("`@3&]G(#$N.2XQ"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]P<F5P87)E4W1A=&5M96YT*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W-T871E;65N="`]("1T:&ES+3Y?9&(M/G!R97!A<F4H)'1H:7,M/E]S
M<6PI.PH*("`@("`@("`O*B!2971U<FX@<W5C8V5S<R!I9B!W92!D:61N)W0@
M9V5N97)A=&4@86X@97)R;W(N("HO"B`@("`@("`@<F5T=7)N("A$0CHZ:7-%
M<G)O<B@D=&AI<RT^7W-T871E;65N="D@/3T](&9A;'-E*3L*("`@('T*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+W-Q;&ET92YP
M:'``````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34U
M-C(`,3`U,34T,S$P-3<`,#(P,3`U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P
M;W-I=&]R>2]P96%R+TQO9R],;V<O<W%L:71E+G!H<"QV(#$N-2`R,#`U+S$R
M+S`U(#`U.C,X.C,Q(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I
M;VXZ(#$N-2`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G
M7W-Q;&ET92!C;&%S<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F
M('1H92!,;V<Z.@H@*B!A8G-T<F%C="!C;&%S<R!W:&EC:"!S96YD<R!M97-S
M86=E<R!T;R!A;B!3<6QI=&4@9&%T86)A<V4N"B`J($5A8V@@96YT<GD@;V-C
M=7!I97,@82!S97!A<F%T92!R;W<@:6X@=&AE(&1A=&%B87-E+@H@*@H@*B!4
M:&ES(&EM<&QE;65N=&%T:6]N('5S97,@4$A0(&YA=&EV92!3<6QI=&4@9G5N
M8W1I;VYS+@H@*@H@*B!#4D5!5$4@5$%"3$4@;&]G7W1A8FQE("@*("H@(&ED
M("`@("`@("`@($E.5$5'15(@4%))34%262!+15D@3D]4($Y53$PL"B`J("!L
M;V=T:6UE("`@("!.3U0@3E5,3"P*("H@(&ED96YT("`@("`@($-(05(H,38I
M($Y/5"!.54Q,+`H@*B`@<')I;W)I='D@("`@24Y4($Y/5"!.54Q,+`H@*B`@
M;65S<V%G90H@*B`I.PH@*@H@*B!`875T:&]R("!"97)T<F%N9"!-86YS:6]N
M(#QB;6%N<VEO;D!M86UA<V%M+F-O;3X*("H@0&%U=&AO<B`@2F]N(%!A<FES
M92`\:F]N0'!H<"YN970^"B`J($!S:6YC92`@($QO9R`Q+C@N,PH@*B!`<&%C
M:V%G92!,;V<*("H*("H@0&5X86UP;&4@<W%L:71E+G!H<"`@("`@(%5S:6YG
M('1H92!3<6QI=&4@:&%N9&QE<BX*("HO"F-L87-S($QO9U]S<6QI=&4@97AT
M96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!!<G)A>2!C;VYT86EN:6YG('1H
M92!C;VYN96-T:6]N(&1E9F%U;'1S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`]
M(&%R<F%Y*"=M;V1E)R`@("`@("`]/B`P-C8V+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P97)S:7-T96YT)R`]/B!F86QS92D["@H@("`@+RHJ"B`@
M("`@*B!/8FIE8W0@:&]L9&EN9R!T:&4@9&%T86)A<V4@:&%N9&QE+@H@("`@
M("H@0'9A<B!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]D8B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!&;&%G(&EN
M9&EC871I;F<@=&AA="!W92=R92!U<VEN9R!A;B!E>&ES=&EN9R!D871A8F%S
M92!C;VYN96-T:6]N+@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?97AI<W1I;F=#;VYN96-T
M:6]N(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T
M:&4@9&%T86)A<V4@=&%B;&4@=&\@=7-E+@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T86)L
M92`]("=L;V=?=&%B;&4G.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@<W%L(&QO9V=I;F<@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@=&%R9V5T(%-13"!T86)L92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT("`@("`@("!4:&4@:61E;G1I
M9FEC871I;VX@9FEE;&0N"B`@("`@*B!`<&%R86T@;6EX960@("1C;VYF("`@
M("`@("`@0V%N(&)E(&%N(&%R<F%Y(&]F(&-O;F9I9W5R871I;VX@;W!T:6]N
M<R!U<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@
M;W!E;B!A(&YE=R!D871A8F%S92!C;VYN96-T:6]N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;W(@86X@86QR96%D>2!O<&5N960@<W%L
M:71E(&-O;FYE8W1I;VXN"B`@("`@*B!`<&%R86T@:6YT("`@("1L979E;"`@
M("`@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L
M979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($QO9U]S<6QI=&4H)&YA;64L("1I9&5N="`]("<G+"`F)&-O;F8L("1L
M979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?=&%B;&4@
M/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@
M("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@
M("!I9B`H:7-?87)R87DH)&-O;F8I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1C;VYF(&%S("1K(#T^("1O<'0I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W!T:6]N<ULD:UT@/2`D;W!T.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@268@86X@97AI<W1I;F<@9&%T86)A
M<V4@8V]N;F5C=&EO;B!W87,@<')O=FED960L('5S92!I="X*("`@("`@("`@
M("`@)'1H:7,M/E]D8B`])B`D8V]N9CL*("`@("`@("`@("`@)'1H:7,M/E]E
M>&ES=&EN9T-O;FYE8W1I;VX@/2!T<G5E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($]P96YS(&$@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A
M<V4L(&EF(&ET(&AA<R!N;W0@86QR96%D>0H@("`@("H@8F5E;B!O<&5N960N
M(%1H:7,@:7,@:6UP;&EC:71L>2!C86QL960@8GD@;&]G*"DL(&EF(&YE8V5S
M<V%R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@
M("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]D8BDI('L*("`@("`@("`@("`@
M)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]C<F5A=&5486)L92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\J(%-E="!T:&4@8V]N;F5C=&EO;B!F=6YC=&EO;B!B87-E9"!O;B!T
M:&4@)W!E<G-I<W1E;G0G(&]P=&EO;BX@*B\*("`@("`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<&5R<VES=&5N="==*2D@>PH@("`@("`@
M("`@("`@("`@)&-O;FYE8W1&=6YC=&EO;B`]("=S<6QI=&5?;W!E;B<["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8V]N;F5C=$9U
M;F-T:6]N(#T@)W-Q;&ET95]P;W!E;B<["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($%T=&5M<'0@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N
M("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1B(#T@)&-O;FYE8W1&=6YC
M=&EO;B@D=&AI<RT^7V]P=&EO;G-;)V9I;&5N86UE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21T:&ES
M+3Y?;W!T:6]N<ULG;6]D92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<F]R*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8W)E871E5&%B;&4H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VQO<V5S('1H92!C;VYN96-T:6]N('1O('1H92!D
M871A8F%S92!I9B!I="!I<R!S=&EL;"!O<&5N(&%N9"!W92!W97)E"B`@("`@
M*B!T:&4@;VYE<R!T:&%T(&]P96YE9"!I="X@($ET(&ES('1H92!C86QL97(G
M<R!R97-P;VYS:6)L92!T;R!C;&]S92!A;@H@("`@("H@97AI<W1I;F<@8V]N
M;F5C=&EO;B!T:&%T('=A<R!P87-S960@=&\@=7,@=FEA("1C;VYF6R=D8B==
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O
M*B!792!N979E<B!C;&]S92!E>&ES=&EN9R!C;VYN96-T:6]N<RX@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]E>&ES=&EN9T-O;FYE8W1I;VXI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@
M9F%L<V4["B`@("`@("`@("`@('-Q;&ET95]C;&]S92@D=&AI<RT^7V1B*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`H)'1H:7,M/E]O<&5N960@/3T]
M(&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN<V5R=',@)&UE<W-A
M9V4@=&\@=&AE(&-U<G)E;G1L>2!O<&5N(&1A=&%B87-E+B`@0V%L;',@;W!E
M;B@I+`H@("`@("H@:68@;F5C97-S87)Y+B`@06QS;R!P87-S97,@=&AE(&UE
M<W-A9V4@86QO;F<@=&\@86YY($QO9U]O8G-E<G9E<@H@("`@("H@:6YS=&%N
M8V5S('1H870@87)E(&]B<V5R=FEN9R!T:&ES($QO9RX*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@("1M97-S86=E("!3=')I;F<@;W(@;V)J96-T(&-O
M;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<')I;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@
M5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!
M4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@
M("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'
M7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/
M5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@
M;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@
M('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I
M9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D
M<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@
M)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T
M(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L
M;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME
M9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\J($EF('1H92!C;VYN96-T:6]N(&ES;B=T(&]P
M96X@86YD(&-A;B=T(&)E(&]P96YE9"P@<F5T=7)N(&9A:6QU<F4N("HO"B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`O+R!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE
M(&UE<W-A9V4N"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-
M97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@+R\@0G5I;&0@=&AE(%-13"!Q
M=65R>2!F;W(@=&AI<R!L;V<@96YT<GD@:6YS97)T:6]N+@H@("`@("`@("1Q
M(#T@<W!R:6YT9B@G24Y315)4($E.5$\@6R5S72`H;&]G=&EM92P@:61E;G0L
M('!R:6]R:71Y+"!M97-S86=E*2`G("X*("`@("`@("`@("`@("`@("`@("`@
M(E9!3%5%4R`H)R5S)RP@)R5S)RP@)60L("<E<R<I(BP*("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]T86)L92P*("`@("`@("`@("`@("`@("`@("`@
M<W1R9G1I;64H)R59+25M+25D("5(.B5-.B53)RP@=&EM92@I*2P*("`@("`@
M("`@("`@("`@("`@("`@<W%L:71E7V5S8V%P95]S=')I;F<H)'1H:7,M/E]I
M9&5N="DL"B`@("`@("`@("`@("`@("`@("`@("1P<FEO<FET>2P*("`@("`@
M("`@("`@("`@("`@("`@<W%L:71E7V5S8V%P95]S=')I;F<H)&UE<W-A9V4I
M*3L*("`@("`@("!I9B`H(2@D<F5S(#T@0'-Q;&ET95]U;F)U9F9E<F5D7W%U
M97)Y*"1T:&ES+3Y?9&(L("1Q*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y
M*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A
M9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@=VAE=&AE<B!T:&4@;&]G('1A8FQE(&5X:7-T<R!A;F0@
M8W)E871E<R!I="!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R
M92X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8W)E871E5&%B;&4H*0H@("`@>PH@("`@("`@("1Q(#T@(E-%3$5#5"!N
M86UE($923TT@<W%L:71E7VUA<W1E<B!72$5212!N86UE/2<B("X@)'1H:7,M
M/E]T86)L92`N"B`@("`@("`@("`@("`B)R!!3D0@='EP93TG=&%B;&4G(CL*
M"B`@("`@("`@)')E<R`]('-Q;&ET95]Q=65R>2@D=&AI<RT^7V1B+"`D<2D[
M"@H@("`@("`@(&EF("AS<6QI=&5?;G5M7W)O=W,H)')E<RD@/3T@,"D@>PH@
M("`@("`@("`@("`D<2`]("=#4D5!5$4@5$%"3$4@6R<@+B`D=&AI<RT^7W1A
M8FQE("X@)UT@*"<@+@H@("`@("`@("`@("`@("`@("=I9"!)3E1%1T52(%!2
M24U!4ED@2T59($Y/5"!.54Q,+"`G("X*("`@("`@("`@("`@("`@("`G;&]G
M=&EM92!.3U0@3E5,3"P@)R`N"B`@("`@("`@("`@("`@("`@)VED96YT($-(
M05(H,38I($Y/5"!.54Q,+"`G("X*("`@("`@("`@("`@("`@("`G<')I;W)I
M='D@24Y4($Y/5"!.54Q,+"`G("X*("`@("`@("`@("`@("`@("`G;65S<V%G
M92DG.PH*("`@("`@("`@("`@:68@*"$H)')E<R`]('-Q;&ET95]U;F)U9F9E
M<F5D7W%U97)Y*"1T:&ES+3Y?9&(L("1Q*2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3&]G+W-Y<VQO9RYP:'``````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$T,34`,3`U,34T,S$P-3<`
M,#(P,3$U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO
M9R],;V<O<WES;&]G+G!H<"QV(#$N,C,@,C`P-2\P,B\R-B`Q-#HT.#HU.2!C
M:&%G96YB=2!%>'`@)`H@*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<O<WES;&]G
M+G!H<"QV(#$N-B`R,#`P+S`V+S(X(#(Q.C,V.C$S(&IO;B!%>'`@)`H@*@H@
M*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,C,@)`H@*B!`<&%C:V%G92!,;V<*
M("HO"@HO*BH*("H@5&AE($QO9U]S>7-L;V<@8VQA<W,@:7,@82!C;VYC<F5T
M92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA
M<W,@=VAI8V@@<V5N9',@;65S<V%G97,@=&\@<WES;&]G(&]N(%5.25@M;&EK
M92!M86-H:6YE<PH@*B`H4$A0(&5M=6QA=&5S('1H:7,@=VET:"!T:&4@179E
M;G0@3&]G(&]N(%=I;F1O=W,@;6%C:&EN97,I+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!S:6YC92`@($QO9R`Q+C`*("H@0'!A8VMA9V4@3&]G
M"B`J"B`J($!E>&%M<&QE('-Y<VQO9RYP:'`@("`@("!5<VEN9R!T:&4@<WES
M;&]G(&AA;F1L97(N"B`J+PIC;&%S<R!,;V=?<WES;&]G(&5X=&5N9',@3&]G
M"GL*("`@("\J*@H@("`@*B!);G1E9V5R(&AO;&1I;F<@=&AE(&QO9R!F86-I
M;&ET>2!T;R!U<V4N"B`@("`J($!V87(@<W1R:6YG"B`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@*B\*("`@('9A<B`D7VYA;64@/2!,3T=?4UE33$]'.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!S>7-L;V<@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!S
M>7-L;V<@9F%C:6QI='DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@
M("!4:&4@:61E;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D
M8V]N9B`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R
M86T@:6YT("`@("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN
M8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@3&]G7W-Y<VQO9R@D;F%M92P@)&ED96YT(#T@
M)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@+RH@16YS
M=7)E('=E(&AA=F4@82!V86QI9"!I;G1E9V5R('9A;'5E(&9O<B`D;F%M92X@
M*B\*("`@("`@("!I9B`H96UP='DH)&YA;64I('Q\("%I<U]I;G0H)&YA;64I
M*2!["B`@("`@("`@("`@("1N86UE(#T@3$]'7U-94TQ/1SL*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@
M("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?:61E
M;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/
M*"1L979E;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&-O;FYE
M8W1I;VX@=&\@=&AE('-Y<W1E;2!L;V=G97(L(&EF(&ET(&AA<R!N;W0@86QR
M96%D>0H@("`@("H@8F5E;B!O<&5N960N("!4:&ES(&ES(&EM<&QI8VET;'D@
M8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@
M("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@(&]P96YL
M;V<H)'1H:7,M/E]I9&5N="P@3$]'7U!)1"P@)'1H:7,M/E]N86UE*3L*("`@
M("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VQO<V5S('1H92!C;VYN96-T:6]N('1O('1H92!S>7-T96T@;&]G
M9V5R+"!I9B!I="!I<R!O<&5N+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("!C;&]S96QO9R@I.PH@("`@
M("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5N9',@)&UE<W-A9V4@=&\@=&AE(&-U<G)E
M;G1L>2!O<&5N('-Y<VQO9R!C;VYN96-T:6]N+B`@0V%L;',*("`@("`J(&]P
M96XH*2!I9B!N96-E<W-A<GDN($%L<V\@<&%S<V5S('1H92!M97-S86=E(&%L
M;VYG('1O(&%N>2!,;V=?;V)S97)V97(*("`@("`J(&EN<W1A;F-E<R!T:&%T
M(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1M97-S86=E(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T
M:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@:6YT("1P<FEO<FET
M>2`H;W!T:6]N86PI(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A
M;&ED"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?
M3$]'7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@
M("`@("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]7
M05).24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)
M0T4L(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N
M(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("![
M"B`@("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I
M960L('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R
M:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T
M:&ES+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E
M87)L>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G
M9VEN9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H
M)'!R:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!T:&4@8V]N;F5C=&EO;B!I<VXG="!O<&5N
M(&%N9"!C86XG="!B92!O<&5N960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@
M("`@(&EF("@A)'1H:7,M/E]O<&5N960@)B8@(21T:&ES+3YO<&5N*"DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M+RH@17AT<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M
M97-S86=E+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T
M365S<V%G92@D;65S<V%G92D["@H@("`@("`@(&EF("@A<WES;&]G*"1T:&ES
M+3Y?=&]3>7-L;V<H)'!R:6]R:71Y*2P@)&UE<W-A9V4I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S
M86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@4$5!4E],3T=?*B!C;VYS
M=&%N="!I;G1O(&$@<WES;&]G($Q/1U\J(&-O;G-T86YT+@H@("`@("H*("`@
M("`J(%1H:7,@9G5N8W1I;VX@97AI<W1S(&)E8V%U<V4L('5N9&5R(%=I;F1O
M=W,L(&YO="!A;&P@;V8@=&AE($Q/1U\J"B`@("`@*B!C;VYS=&%N=',@:&%V
M92!U;FEQ=64@=F%L=65S+B`@26YS=&5A9"P@=&AE(%!%05)?3$]'7RH@=V5R
M92!I;G1R;V1U8V5D"B`@("`@*B!F;W(@9VQO8F%L('5S92P@=VET:"!T:&4@
M8V]N=F5R<VEO;B!T;R!T:&4@3$]'7RH@8V]N<W1A;G1S(&ME<'0@;&]C86P@
M=&\*("`@("`J('1O('1H92!S>7-L;V<@9')I=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G0@)'!R:6]R:71Y("`@("!014%27TQ/1U\J('9A;'5E('1O
M(&-O;G9E<G0@=&\@3$]'7RH@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R
M;B`@5&AE($Q/1U\J(')E<')E<V5N=&%T:6]N(&]F("1P<FEO<FET>2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W1O4WES;&]G*"1P<FEO<FET>2D*("`@('L*("`@("`@("!S=&%T:6,@
M)'!R:6]R:71I97,@/2!A<G)A>2@*("`@("`@("`@("`@4$5!4E],3T=?14U%
M4D<@("`]/B!,3T=?14U%4D<L"B`@("`@("`@("`@(%!%05)?3$]'7T%,15)4
M("`@/3X@3$]'7T%,15)4+`H@("`@("`@("`@("!014%27TQ/1U]#4DE4("`@
M(#T^($Q/1U]#4DE4+`H@("`@("`@("`@("!014%27TQ/1U]%4E(@("`@(#T^
M($Q/1U]%4E(L"B`@("`@("`@("`@(%!%05)?3$]'7U=!4DY)3D<@/3X@3$]'
M7U=!4DY)3D<L"B`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12`@/3X@3$]'
M7TY/5$E#12P*("`@("`@("`@("`@4$5!4E],3T=?24Y&3R`@("`]/B!,3T=?
M24Y&3RP*("`@("`@("`@("`@4$5!4E],3T=?1$5"54<@("`]/B!,3T=?1$5"
M54<*("`@("`@("`I.PH*("`@("`@("`O*B!)9B!W92=R92!P87-S960@86X@
M=6YK;F]W;B!P<FEO<FET>2P@9&5F875L="!T;R!,3T=?24Y&3RX@*B\*("`@
M("`@("!I9B`H(6ES7VEN="@D<')I;W)I='DI('Q\("%I;E]A<G)A>2@D<')I
M;W)I='DL("1P<FEO<FET:65S*2D@>PH@("`@("`@("`@("!R971U<FX@3$]'
M7TE.1D\["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!R:6]R:71I97-;
M)'!R:6]R:71Y73L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]W:6XN<&AP````````````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W,C8S`#$P-3$U
M-#,Q,#4W`#`Q-S0P,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO
M<&5A<B],;V<O3&]G+W=I;BYP:'`L=B`Q+C$X(#(P,#8O,#,O,#(@,#,Z,#8Z
M-#,@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@,2XQ."`D
M"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7W=I;B!C;&%S
M<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<@86)S
M=')A8W0*("H@8VQA<W,@=&AA="!L;V=S(&UE<W-A9V5S('1O(&$@<V5P87)A
M=&4@8G)O=W-E<B!W:6YD;W<N"B`J"B`J(%1H92!C;VYC97!T(&9O<B!T:&ES
M(&QO9R!H86YD;&5R(&ES(&)A<V5D(&]N('!A<G0@8GD@0W)A:6<@1&%V:7,G
M(&%R=&EC;&4*("H@96YT:71L960@(DIA=F%38W)I<'0@4&]W97(@4$A0($1E
M8G5G9VEN9SH*("H*("H@(&AT='`Z+R]W=W<N>F5N9"YC;VTO>F5N9"]T=70O
M='5T;W)I86PM1&5B=6=,:6(N<&AP"B`J"B`J($!A=71H;W(@($IO;B!087)I
M<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XW+C`*("H@0'!A
M8VMA9V4@3&]G"B`J"B`J($!E>&%M<&QE('=I;BYP:'`@("`@(%5S:6YG('1H
M92!W:6YD;W<@:&%N9&QE<BX*("HO"F-L87-S($QO9U]W:6X@97AT96YD<R!,
M;V<*>PH@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@;W5T<'5T('=I
M;F1O=RX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?;F%M92`]("=,;V=7:6YD;W<G.PH*("`@
M("\J*@H@("`@("H@5&AE('1I=&QE(&]F('1H92!O=71P=70@=VEN9&]W+@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]T:71L92`]("=,;V<@3W5T<'5T(%=I;F1O=R<["@H@
M("`@+RHJ"B`@("`@*B!-87!P:6YG(&]F(&QO9R!P<FEO<FET:65S('1O(&-O
M;&]R<RX*("`@("`J($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]C;VQO<G,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4E],3T=?14U%4D<@("`]/B`G<F5D)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?04Q%4E0@("`]/B`G;W)A
M;F=E)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?0U))5"`@
M("`]/B`G>65L;&]W)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],
M3T=?15)2("`@("`]/B`G9W)E96XG+`H@("`@("`@("`@("`@("`@("`@("`@
M("!014%27TQ/1U]705).24Y'(#T^("=B;'5E)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@4$5!4E],3T=?3D]424-%("`]/B`G:6YD:6=O)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@4$5!4E],3T=?24Y&3R`@("`]/B`G=FEO;&5T
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?1$5"54<@("`]
M/B`G8FQA8VLG"B`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`O*BH*("`@
M("`J(%-T<FEN9R!B=69F97(@=&AA="!H;VQD<R!L:6YE('1H870@87)E('!E
M;F1I;F<@;W5T<'5T+@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V)U9F9E<B`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($QO9U]W:6X@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@($EG
M;F]R960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("!4:&4@:61E
M;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8V]N9B`@("`@
M5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R86T@:6YT("`@
M("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN8VQU9&EN9R!T
M:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@3&]G7W=I;B@D;F%M92P@)&ED96YT(#T@)R<L("1C;VYF(#T@
M87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!0
M14%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U
M*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*
M("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES
M+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H:7-S
M970H)&-O;F9;)W1I=&QE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&ET
M;&4@/2`D8V]N9ELG=&ET;&4G73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=C;VQO<G,G72D@)B8@:7-?87)R87DH)&-O;F9;)V-O;&]R
M<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;&]R<R`]("1C;VYF6R=C
M;VQO<G,G73L*("`@("`@("!]"@H@("`@("`@(')E9VES=&5R7W-H=71D;W=N
M7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U],;V=?=VEN)RDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5S=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?3&]G7W=I;B@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D
M('Q\("AC;W5N="@D=&AI<RT^7V)U9F9E<BD@/B`P*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^8VQO<V4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!4:&4@9FER<W0@=&EM92!O<&5N*"D@:7,@8V%L;&5D+"!I="!W:6QL
M(&]P96X@82!N97<@8G)O=W-E<B!W:6YD;W<@86YD"B`@("`@*B!P<F5P87)E
M(&ET(&9O<B!O=71P=70N"B`@("`@*@H@("`@("H@5&AI<R!I<R!I;7!L:6-I
M=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@;F5C97-S87)Y+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&]P96XH
M*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960I('L*("`@("`@
M("`@("`@)'=I;B`]("1T:&ES+3Y?;F%M93L*"B`@("`@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]I9&5N="DI('L*("`@("`@("`@("`@("`@("1I9&5N
M=$AE861E<B`]("(D=VEN+F1O8W5M96YT+G=R:71E;&XH)SQT:#Y)9&5N=#PO
M=&@^)RDB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&ED96YT2&5A9&5R(#T@)R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&5C:&\@/#P\($5.1%]/1E]30U))4%0*/'-C<FEP="!L86YG=6%G93TB2F%V
M85-C<FEP="(^"B1W:6X@/2!W:6YD;W<N;W!E;B@G)RP@)WLD=&AI<RT^7VYA
M;65])RP@)W1O;VQB87(];F\L<V-R;VQL8F%R<RQW:61T:#TV,#`L:&5I9VAT
M/30P,"<I.PHD=VEN+F1O8W5M96YT+G=R:71E;&XH)SQH=&UL/B<I.PHD=VEN
M+F1O8W5M96YT+G=R:71E;&XH)SQH96%D/B<I.PHD=VEN+F1O8W5M96YT+G=R
M:71E;&XH)SQT:71L93Y[)'1H:7,M/E]T:71L97T\+W1I=&QE/B<I.PHD=VEN
M+F1O8W5M96YT+G=R:71E;&XH)SQS='EL92!T>7!E/2)T97AT+V-S<R(^)RD[
M"B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G8F]D>2![(&9O;G0M9F%M:6QY.B!M
M;VYO<W!A8V4[(&9O;G0M<VEZ93H@.'!T.R!])RD["B1W:6XN9&]C=6UE;G0N
M=W)I=&5L;B@G=&0L=&@@>R!F;VYT+7-I>F4Z(#AP=#L@?2<I.PHD=VEN+F1O
M8W5M96YT+G=R:71E;&XH)W1D+'1H('L@8F]R9&5R+6)O='1O;3H@(SDY.3DY
M.2!S;VQI9"`Q<'@[('TG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"=T9"QT
M:"![(&)O<F1E<BUR:6=H=#H@(SDY.3DY.2!S;VQI9"`Q<'@[('TG*3L*)'=I
M;BYD;V-U;65N="YW<FET96QN*"=T<B![('1E>'0M86QI9VXZ(&QE9G0[('9E
M<G1I8V%L+6%L:6=N.B!T;W`[('TG*3L*)'=I;BYD;V-U;65N="YW<FET96QN
M*"<\+W-T>6QE/B<I.PHD=VEN+F1O8W5M96YT+G=R:71E;&XH)SPO:&5A9#XG
M*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\8F]D>3XG*3L*)'=I;BYD;V-U
M;65N="YW<FET96QN*"<\=&%B;&4@8F]R9&5R/2(P(B!C96QL<&%D9&EN9STB
M,B(@8V5L;'-P86-I;F<](C`B/B<I.PHD=VEN+F1O8W5M96YT+G=R:71E;&XH
M)SQT<CX\=&@^5&EM93PO=&@^)RD["B1I9&5N=$AE861E<@HD=VEN+F1O8W5M
M96YT+G=R:71E;&XH)SQT:#Y0<FEO<FET>3PO=&@^/'1H('=I9'1H/2(Q,#`E
M(CY-97-S86=E/"]T:#X\+W1R/B<I.PH\+W-C<FEP=#X*14Y$7T]&7U-#4DE0
M5#L*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VQO<V5S('1H92!O=71P=70@<W1R96%M(&EF(&ET(&ES
M(&]P96XN("!)9B!T:&5R92!A<F4@<W1I;&P@<&5N9&EN9PH@("`@("H@;&EN
M97,@:6X@=&AE(&]U='!U="!B=69F97(L('1H92!O=71P=70@=VEN9&]W('=I
M;&P@8F4@;W!E;F5D('-O('1H870*("`@("`J('1H92!B=69F97(@8V%N(&)E
M(&1R86EN960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J"B`@("`@
M("`@("H@268@=&AE<F4@87)E('-T:6QL(&QI;F5S('=A:71I;F<@=&\@8F4@
M=W)I='1E;BP@;W!E;B!T:&4@;W5T<'5T"B`@("`@("`@("H@=VEN9&]W('-O
M('1H870@=V4@8V%N(&1R86EN('1H92!B=69F97(N"B`@("`@("`@("HO"B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`H8V]U;G0H)'1H:7,M/E]B
M=69F97(I(#X@,"DI('L*("`@("`@("`@("`@)'1H:7,M/F]P96XH*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W=R:71E;&XH)SPO=&%B;&4^)RD["B`@("`@("`@("`@
M("1T:&ES+3Y?=W)I=&5L;B@G/"]B;V1Y/CPO:'1M;#XG*3L*("`@("`@("`@
M("`@)'1H:7,M/E]O<&5N960@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`H)'1H:7,M/E]O<&5N960@/3T](&9A;'-E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%=R:71E<R!A('-I;F=L92!L:6YE(&]F('1E>'0@=&\@
M=&AE(&]U='!U="!W:6YD;W<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@("`D;&EN92`@(%1H92!L:6YE(&]F('1E>'0@=&\@=W)I=&4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]W<FET96QN*"1L:6YE*0H@("`@>PH@("`@("`@("\J($%D9"!T:&ES(&QI
M;F4@=&\@;W5R(&]U='!U="!B=69F97(N("HO"B`@("`@("`@)'1H:7,M/E]B
M=69F97);72`]("1L:6YE.PH*("`@("`@("`O*B!"=69F97(@=&AE(&]U='!U
M="!U;G1I;"!T:&ES('!A9V4G<R!H96%D97)S(&AA=F4@8F5E;B!S96YT+B`J
M+PH@("`@("`@(&EF("@A:&5A9&5R<U]S96YT*"DI('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@:&%V96XG="!A
M;')E861Y(&]P96YE9"!T:&4@;W5T<'5T('=I;F1O=RP@9&\@<V\@;F]W+B`J
M+PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960@)B8@(21T:&ES+3YO<&5N
M*"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@1')A:6X@=&AE(&)U9F9E<B!T;R!T:&4@;W5T<'5T('=I;F1O
M=RX@*B\*("`@("`@("`D=VEN(#T@)'1H:7,M/E]N86UE.PH@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?8G5F9F5R(&%S("1L:6YE*2!["B`@("`@("`@("`@
M(&5C:&\@(CQS8W)I<'0@;&%N9W5A9V4])TIA=F%38W)I<'0G/EQN(CL*("`@
M("`@("`@("`@96-H;R`B)'=I;BYD;V-U;65N="YW<FET96QN*"<B("X@861D
M<VQA<VAE<R@D;&EN92D@+B`B)RD[7&XB.PH@("`@("`@("`@("!E8VAO(")S
M96QF+F9O8W5S*"D[7&XB.PH@("`@("`@("`@("!E8VAO("(\+W-C<FEP=#Y<
M;B(["B`@("`@("`@?0H*("`@("`@("`O*B!.;W<@=&AA="!T:&4@8G5F9F5R
M(&AA<R!B965N(&1R86EN960L(&-L96%R(&ET+B`J+PH@("`@("`@("1T:&ES
M+3Y?8G5F9F5R(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO
M9W,@)&UE<W-A9V4@=&\@=&AE(&]U='!U="!W:6YD;W<N("!4:&4@;65S<V%G
M92!I<R!A;'-O('!A<W-E9"!A;&]N9PH@("`@("H@=&\@86YY($QO9U]O8G-E
M<G9E<B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O
M<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE
M(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU
M97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@
M*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T52
M4BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@
M4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?
M1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T
M(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@
M("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D
M<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@
M("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H
M92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI
M<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@17AT<F%C="!T:&4@<W1R
M:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E+B`J+PH@("`@("`@
M("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G92@D;65S<V%G92D[
M"@H@("`@("`@(&QI<W0H)'5S96,L("1S96,I(#T@97AP;&]D92@G("<L(&UI
M8W)O=&EM92@I*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(&]U='!U="!L:6YE
M('1H870@8V]N=&%I;G,@=&AE(&QO9R!E;G1R>2!R;W<N("HO"B`@("`@("`@
M)&QI;F4@(#T@)SQT<CXG.PH@("`@("`@("1L:6YE("X]('-P<FEN=&8H)SQT
M9#XE<RXE<SPO=&0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@('-T<F9T
M:6UE*"<E5"<L("1S96,I+"!S=6)S='(H)'5S96,L(#(L(#(I*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?:61E;G0I*2!["B`@("`@("`@("`@("1L
M:6YE("X]("<\=&0^)R`N("1T:&ES+3Y?:61E;G0@+B`G/"]T9#XG.PH@("`@
M("`@('T*("`@("`@("`D;&EN92`N/2`G/'1D/B<@+B!U8V9I<G-T*"1T:&ES
M+3YP<FEO<FET>51O4W1R:6YG*"1P<FEO<FET>2DI("X@)SPO=&0^)SL*("`@
M("`@("`D;&EN92`N/2!S<')I;G1F*"<\=&0@<W1Y;&4](F-O;&]R.B`E<R(^
M)7,\+W1D/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;&]R<ULD<')I;W)I='E=+`H@("`@("`@("`@("`@("`@("`@("`@("`@<')E
M9U]R97!L86-E*"<O7')<;GQ<;GQ<<B\G+"`G/&)R("\^)RP@)&UE<W-A9V4I
M*3L*("`@("`@("`D;&EN92`N/2`G/"]T<CXG.PH*("`@("`@("`D=&AI<RT^
M7W=R:71E;&XH)&QI;F4I.PH*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R
M<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE
M<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],
M;V<O8V]N<V]L92YP:'``````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,C,S,P`Q,#4Q-30S,3`U-P`P,C`R,S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]C;VYS;VQE+G!H<"QV
M(#$N,C(@,C`P-B\P,2\Q,2`P-SHU-CHS-R!J;VX@17AP("0*("H*("H@0'9E
M<G-I;VX@)%)E=FES:6]N.B`Q+C(R("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*
M+RHJ"B`J(%1H92!,;V=?8V]N<V]L92!C;&%S<R!I<R!A(&-O;F-R971E(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.@H@*B!A8G-T<F%C="!C;&%S<R!W
M:&EC:"!W<FET97,@;65S<V%G92!T;R!T:&4@=&5X="!C;VYS;VQE+@H@*B`*
M("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!S:6YC
M92`@($QO9R`Q+C$*("H@0'!A8VMA9V4@3&]G"B`J"B`J($!E>&%M<&QE(&-O
M;G-O;&4N<&AP("`@("!5<VEN9R!T:&4@8V]N<V]L92!H86YD;&5R+@H@*B\*
M8VQA<W,@3&]G7V-O;G-O;&4@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@
M*B!(86YD;&4@=&\@=&AE(&-U<G)E;G0@;W5T<'5T('-T<F5A;2X*("`@("`J
M($!V87(@<F5S;W5R8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]S=')E86T@/2!35$1/550["@H@("`@+RHJ"B`@("`@*B!3
M:&]U;&0@=&AE(&]U='!U="!B92!B=69F97)E9"!O<B!D:7-P;&%Y960@:6UM
M961I871E;'D_"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7V)U9F9E<FEN9R`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&)U9F9E<F5D(&]U
M='!U="X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?8G5F9F5R(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@9F]R;6%T(&]F(&$@;&]G(&QI
M;F4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7VQI;F5&;W)M870@/2`G)3$D<R`E,B1S(%LE
M,R1S72`E-"1S)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG
M('1H92!T:6UE<W1A;7`@9F]R;6%T+B`@270@=VEL;"!B92!P87-S960@9&ER
M96-T;'D@=&\*("`@("`J('-T<F9T:6UE*"DN("!.;W1E('1H870@=&AE('1I
M;65S=&%M<"!S=')I;F<@=VEL;"!G96YE<F%T960@=7-I;F<@=&AE"B`@("`@
M*B!C=7)R96YT(&QO8V%L92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&EM949O<FUA="`]
M("<E8B`E9"`E2#HE33HE4R<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W($QO9U]C;VYS;VQE(&]B:F5C="X*("`@("`J(`H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`
M<&%R86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A
M>2X*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E
M<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?8V]N<V]L92@D
M;F%M92P@)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@
M("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M
M87-K(#T@3&]G.CI54%1/*"1L979E;"D["@H@("`@("`@(&EF("@A96UP='DH
M)&-O;F9;)W-T<F5A;2==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-T<F5A
M;2`]("1C;VYF6R=S=')E86TG73L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D8V]N9ELG8G5F9F5R:6YG)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?8G5F9F5R:6YG(#T@)&-O;F9;)V)U9F9E<FEN9R==.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG;&EN949O<FUA="==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQI;F5&;W)M870@/2!S=')?<F5P;&%C92AA
M<G)A>5]K97ES*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T
M:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;F9;)VQI;F5&;W)M870G72D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=T:6UE1F]R;6%T)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&EM949O<FUA="`]("1C;VYF6R=T
M:6UE1F]R;6%T)UT["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@("`J
M($EF(&]U='!U="!B=69F97)I;F<@:&%S(&)E96X@<F5Q=65S=&5D+"!W92!N
M965D('1O(')E9VES=&5R(&$*("`@("`@("`@*B!S:'5T9&]W;B!F=6YC=&EO
M;B!T:&%T('=I;&P@9'5M<"!T:&4@8G5F9F5R('5P;VX@=&5R;6EN871I;VXN
M"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8G5F9F5R:6YG*2![
M"B`@("`@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y
M*"8D=&AI<RP@)U],;V=?8V]N<V]L92<I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$97-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%],;V=?8V]N<V]L92@I"B`@("!["B`@("`@("`@)'1H:7,M/F-L;W-E*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&]U='!U="!S=')E
M86TN"B`@("`@*@H@("`@("H@5&AI<R!R97-U;'1S(&EN(&$@8V%L;"!T;R!F
M;'5S:"@I+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@3&]G(#$N.2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*
M("`@('L*("`@("`@("`D=&AI<RT^9FQU<V@H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9L=7-H97,@86QL('!E;F1I;F<@*")B=69F97)E9"(I(&1A=&$@
M=&\@=&AE(&]U='!U="!S=')E86TN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S:6YC92!,;V<@,2XX+C(*("`@("`J+PH@("`@9G5N
M8W1I;VX@9FQU<V@H*0H@("`@>PH@("`@("`@("\J"B`@("`@("`@("H@268@
M;W5T<'5T(&)U9F9E<FEN9R!I<R!E;F%B;&5D+"!D=6UP('1H92!C;VYT96YT
M<R!O9B!T:&4@8G5F9F5R('1O"B`@("`@("`@("H@=&AE(&]U='!U="!S=')E
M86TN"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8G5F9F5R:6YG
M("8F("AS=')L96XH)'1H:7,M/E]B=69F97(I(#X@,"DI('L*("`@("`@("`@
M("`@9G=R:71E*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V)U9F9E<BD["B`@
M("`@("`@("`@("1T:&ES+3Y?8G5F9F5R(#T@)R<["B`@("`@("`@?0H@"B`@
M("`@("`@<F5T=7)N(&9F;'5S:"@D=&AI<RT^7W-T<F5A;2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!7<FET97,@)&UE<W-A9V4@=&\@=&AE('1E>'0@8V]N
M<V]L92X@06QS;RP@<&%S<V5S('1H92!M97-S86=E"B`@("`@*B!A;&]N9R!T
M;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E<R!T:&%T(&%R92!O8G-E<G9I
M;F<@=&AI<R!,;V<N"B`@("`@*B`*("`@("`J($!P87)A;2!M:7AE9"`@)&UE
M<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S
M86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y(%1H
M92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@("`@
M("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!014%2
M7TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?
M0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@("H@
M("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.
M1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE
M<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@
M82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F
M875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL
M*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@<')I
M;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*
M("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE
M<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-
M97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE('-T<FEN
M9R!C;VYT86EN:6YG('1H92!C;VUP;&5T92!L;V<@;&EN92X@*B\*("`@("`@
M("`D;&EN92`]("1T:&ES+3Y?9F]R;6%T*"1T:&ES+3Y?;&EN949O<FUA="P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<F9T:6UE*"1T:&ES
M+3Y?=&EM949O<FUA="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<')I;W)I='DL("1M97-S86=E*2`N(")<;B(["@H@("`@("`@("\J"B`@
M("`@("`@("H@268@8G5F9F5R:6YG(&ES(&5N86)L960L(&%P<&5N9"!T:&ES
M(&QI;F4@=&\@=&AE(&]U='!U="!B=69F97(N"B`@("`@("`@("H@3W1H97)W
M:7-E+"!P<FEN="!T:&4@;&EN92!T;R!T:&4@;W5T<'5T('-T<F5A;2!I;6UE
M9&EA=&5L>2X*("`@("`@("`@*B\*("`@("`@("!I9B`H)'1H:7,M/E]B=69F
M97)I;F<I('L*("`@("`@("`@("`@)'1H:7,M/E]B=69F97(@+CT@)&QI;F4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9G=R:71E*"1T:&ES+3Y?
M<W1R96%M+"`D;&EN92D["B`@("`@("`@?0H*("`@("`@("`O*B!.;W1I9GD@
M;V)S97)V97)S(&%B;W5T('1H:7,@;&]G(&UE<W-A9V4N("HO"B`@("`@("`@
M)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET
M>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+P``````````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`U-P`P,38Q,#8`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O
M5')A;G-P;W)T+P``````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`R,#$P,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O<G0O4TU44"YP:'``````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38S,C0`,3`U,34T,S$P-3<`,#(Q-#`Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R(&%N
M(%--5%`@=')A;G-P;W)T(&QA>65R+@H@*@H@*B!4:&ES(&-O9&4@:7,@<W1I
M;&P@82!R;W5G:"!A;F0@=6YT97-T960@9')A9G0N"B`J(%1/1$\Z"B`J("!S
M=VET8V@@=&\@<&5A<B!M86EL('-T=69F"B`J("!S;71P(&%U=&AE;G1I8V%T
M:6]N"B`J("!S;71P('-S;"!S=7!P;W)T"B`J("!A8FEL:71Y('1O(&1E9FEN
M92!S;71P(&]P=&EO;G,@*&5N8V]D:6YG+"!F<F]M+"!E=&,N*0H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@
M;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E
M9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A
M=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/@H@
M*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@
M4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]"
M87-E+G!H<"<["G)E<75I<F5?;VYC92`G36%I;"]S;71P+G!H<"<["@HO*BH*
M("H@(%--5%`@5')A;G-P;W)T(&9O<B!33T%0"B`J"B`J(&EM<&QE;65N=',@
M4T]!4"U33510(&%S(&1E9FEN960@870*("H@:'1T<#HO+W=W=RYP;V-K971S
M;V%P+F-O;2]S<&5C<R]S;71P8FEN9&EN9R\*("H*("H@5$]$3SH@=7-E(%!%
M05(@<VUT<"!A;F0@36EM92!C;&%S<V5S"B`J"B`J($!A8V-E<W,@<'5B;&EC
M"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O(#QS
M:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@4T]!4%]4<F%N<W!O<G1?4TU44"!E
M>'1E;F1S(%-/05!?0F%S90I["@H@("`@=F%R("1C<F5D96YT:6%L<R`]("<G
M.PH@("`@=F%R("1T:6UE;W5T(#T@-#L@+R\@8V]N;F5C="!T:6UE;W5T"B`@
M("!V87(@)'5R;'!A<G1S(#T@3E5,3#L*("`@('9A<B`D=7)L(#T@)R<["B`@
M("!V87(@)&EN8V]M:6YG7W!A>6QO860@/2`G)SL*("`@('9A<B`D7W5S97)!
M9V5N="`](%-/05!?3$E"4D%265].04U%.PH@("`@=F%R("1E;F-O9&EN9R`]
M(%-/05!?1$5&055,5%]%3D-/1$E.1SL*("`@('9A<B`D:&]S="`]("<Q,C<N
M,"XP+C$G.PH@("`@=F%R("1P;W)T(#T@,C4["B`@("!V87(@)&%U=&@@/2!.
M54Q,.PH@("`@+RHJ"B`@("`J(%-/05!?5')A;G-P;W)T7U--5%`@0V]N<W1R
M=6-T;W(*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D55),("`@(&UA:6QT
M;SIA9&1R97-S"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@
M("`@9G5N8W1I;VX@4T]!4%]4<F%N<W!O<G1?4TU44"@D55),+"`D96YC;V1I
M;F<])U53+4%30TE))RD*("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?0F%S
M92@G4TU44"<I.PH@("`@("`@("1T:&ES+3YE;F-O9&EN9R`]("1E;F-O9&EN
M9SL*("`@("`@("`D=&AI<RT^=7)L<&%R=',@/2!`<&%R<V5?=7)L*"154DPI
M.PH@("`@("`@("1T:&ES+3YU<FP@/2`D55),.PH@("`@?0H*("`@("\J*@H@
M("`@*B!S96YD(&%N9"!R96-E:79E('-O87`@9&%T80H@("`@*@H@("`@*B!`
M<&%R86T@<W1R:6YG("8D;7-G("`@("`@(&]U=&=O:6YG('!O<W0@9&%T80H@
M("`@*B!`<&%R86T@<W1R:6YG("1A8W1I;VX@("`@("!33T%0($%C=&EO;B!H
M96%D97(@9&%T80H@("`@*B!`<&%R86T@:6YT("1T:6UE;W5T("!S;V-K970@
M=&EM96]U="P@9&5F875L="`P(&]R(&]F9@H@("`@*@H@("`@*B!`<F5T=7)N
M('-T<FEN9R`F)')E<W!O;G-E("`@<F5S<&]N<V4@9&%T82P@;6EN=7,@:'1T
M<"!H96%D97)S"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N
M8W1I;VX@<V5N9"@F)&US9RP@("\J87)R87DJ+R`D;W!T:6]N<R`]($Y53$PI
M"B`@("!["B`@("`@("`@)'1H:7,M/FEN8V]M:6YG7W!A>6QO860@/2`G)SL*
M("`@("`@("`D=&AI<RT^;W5T9V]I;F=?<&%Y;&]A9"`]("8D;7-G.PH@("`@
M("`@(&EF("@A)'1H:7,M/E]V86QI9&%T955R;"@I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^9F%U;'0["B`@("`@("`@?0H@("`@("`@(&EF("@A
M)&]P=&EO;G,@?'P@(6%R<F%Y7VME>5]E>&ES=',H)V9R;VTG+"1O<'1I;VYS
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@B3F\@1E)/32!A9&1R97-S('1O('-E;F0@;65S<V%G92!W:71H(BD["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VAO<W0G72DI
M("1T:&ES+3YH;W-T(#T@)&]P=&EO;G-;)VAO<W0G73L*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)W!O<G0G72DI("1T:&ES+3YP;W)T(#T@)&]P=&EO
M;G-;)W!O<G0G73L*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V%U=&@G
M72DI("1T:&ES+3YA=71H(#T@)&]P=&EO;G-;)V%U=&@G73L*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)W5S97)N86UE)UTI*2`D=&AI<RT^=7-E<FYA
M;64@/2`D;W!T:6]N<ULG=7-E<FYA;64G73L*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)W!A<W-W;W)D)UTI*2`D=&AI<RT^<&%S<W=O<F0@/2`D;W!T
M:6]N<ULG<&%S<W=O<F0G73L*"B`@("`@("`@)&AE861E<G,@/2!A<G)A>2@I
M.PH@("`@("`@("1H96%D97)S6R=&<F]M)UT@/2`D;W!T:6]N<ULG9G)O;2==
M.PH@("`@("`@("1H96%D97)S6R=8+4UA:6QE<B==(#T@)'1H:7,M/E]U<V5R
M06=E;G0["B`@("`@("`@)&AE861E<G-;)TU)344M5F5R<VEO;B==(#T@)S$N
M,"<["B`@("`@("`@)&AE861E<G-;)TUE<W-A9V4M240G72`](&UD-2AT:6UE
M*"DI+B<N<V]A<$`G+B1T:&ES+3YH;W-T.PH@("`@("`@("1H96%D97)S6R=4
M;R==(#T@)'1H:7,M/G5R;'!A<G1S6R=P871H)UT["B`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H)W-O87!A8W1I;VXG+"`D;W!T:6]N<RDI('L*("`@
M("`@("`@("`@)&AE861E<G-;)U-O87!A8W1I;VXG72`](")<(GLD;W!T:6]N
M<ULG<V]A<&%C=&EO;B==?5PB(CL*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG:&5A9&5R<R==*2D*("`@("`@("`@("`@)&AE861E
M<G,@/2!A<G)A>5]M97)G92@D:&5A9&5R<RP@)&]P=&EO;G-;)VAE861E<G,G
M72D["@H@("`@("`@("\O(&EF('1H92!C;VYT96YT('1Y<&4@:7,@86QR96%D
M>2!S970L('=E(&%S<W5M92!T:&%T($UI;64@96YC;V1I;F<*("`@("`@("`O
M+R!I<R!A;')E861Y(&1O;F4*("`@("`@("!I9B`H:7-S970H)&AE861E<G-;
M)T-O;G1E;G0M5'EP92==*2D@>PH@("`@("`@("`@("`D;W5T(#T@)&US9SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!D;R!A('-I;7!L92!I
M;FQI;F4@36EM92!E;F-O9&EN9PH@("`@("`@("`@("`D:&5A9&5R<ULG0V]N
M=&5N="U$:7-P;W-I=&EO;B==(#T@)VEN;&EN92<["B`@("`@("`@("`@("1H
M96%D97)S6R=#;VYT96YT+51Y<&4G72`](")T97AT+WAM;#L@8VAA<G-E=#U<
M(B1T:&ES+3YE;F-O9&EN9UPB(CL*("`@("`@("`@("`@:68@*&%R<F%Y7VME
M>5]E>&ES=',H)W1R86YS9F5R+65N8V]D:6YG)RP@)&]P=&EO;G,I*2!["B`@
M("`@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D;W!T:6]N<ULG=')A;G-F
M97(M96YC;V1I;F<G72PG<75O=&5D+7!R:6YT86)L92<I/3TP*2!["B`@("`@
M("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<G72`]("1O<'1I;VYS6R=T<F%N<V9E<BUE;F-O9&EN9R==.PH@("`@
M("`@("`@("`@("`@("`@("1O=70@/2`F)&US9SL*("`@("`@("`@("`@("`@
M('T@96QS92!I9B`H<W1R8V%S96-M<"@D;W!T:6]N<ULG=')A;G-F97(M96YC
M;V1I;F<G72PG8F%S938T)RD]/3`I('L*("`@("`@("`@("`@("`@("`@("`D
M:&5A9&5R<ULG0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9R==(#T@)V)A<V4V
M-"<["B`@("`@("`@("`@("`@("`@("`@)&]U="`](&-H=6YK7W-P;&ET*&)A
M<V4V-%]E;F-O9&4H)&US9RDL-S8L(EQN(BD["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"));G9A;&ED(%1R86YS9F5R($5N8V]D:6YG.B![)&]P
M=&EO;G-;)W1R86YS9F5R+65N8V]D:6YG)UU](BD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!D
M969A=6QT('1O(&)A<V4V-`H@("`@("`@("`@("`@("`@)&AE861E<G-;)T-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<G72`]("=B87-E-C0G.PH@("`@("`@
M("`@("`@("`@)&]U="`](&-H=6YK7W-P;&ET*&)A<V4V-%]E;F-O9&4H)&US
M9RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:&5A9&5R
M<ULG4W5B:F5C="==(#T@87)R87E?:V5Y7V5X:7-T<R@G<W5B:F5C="<L("1O
M<'1I;VYS*2`_("1O<'1I;VYS6R=S=6)J96-T)UT@.B`G4T]!4"!-97-S86=E
M)SL*"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@)&ME>2`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@)&AE861E<E]T97AT("X]("(D:V5Y.B`D=F%L
M=65<;B(["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YO=71G;VEN9U]P87EL
M;V%D(#T@)&AE861E<E]T97AT+B)<<EQN(BXD=&AI<RT^;W5T9V]I;F=?<&%Y
M;&]A9#L*("`@("`@("`C('=E('=A;G0@=&\@<F5T=7)N(&$@<')O<&5R(%A-
M3"!M97-S86=E"@H@("`@("`@("1M86EL97)?<&%R86US(#T@87)R87DH"B`@
M("`@("`@("`@("=H;W-T)R`]/B`D=&AI<RT^:&]S="P*("`@("`@("`@("`@
M)W!O<G0G(#T^("1T:&ES+3YP;W)T+`H@("`@("`@("`@("`G=7-E<FYA;64G
M(#T^("1T:&ES+3YU<V5R;F%M92P*("`@("`@("`@("`@)W!A<W-W;W)D)R`]
M/B`D=&AI<RT^<&%S<W=O<F0L"B`@("`@("`@("`@("=A=71H)R`]/B`D=&AI
M<RT^875T:`H@("`@("`@("D["B`@("`@("`@)&UA:6QE<B`])B!N97<@36%I
M;%]S;71P*"1M86EL97)?<&%R86US*3L*("`@("`@("`D<F5S=6QT(#T@)&UA
M:6QE<BT^<V5N9"@D=&AI<RT^=7)L<&%R='-;)W!A=&@G72P@)&AE861E<G,L
M("1O=70I.PH@("`@("`@(",D<F5S=6QT(#T@;6%I;"@D=&AI<RT^=7)L<&%R
M='-;)W!A=&@G72P@)&AE861E<G-;)U-U8FIE8W0G72P@)&]U="P@)&AE861E
M<E]T97AT*3L*"B`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("1V86P@/28@;F5W(%-/05!?5F%L=64H)TUE<W-A
M9V4M240G+"=S=')I;F<G+"1H96%D97)S6R=-97-S86=E+4E$)UTI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S=F%L6UT@/28@;F5W(%-/05!?
M5F%L=64H)V9A=6QT8V]D92<L)U%.86UE)RPG4T]!4"U%3E8Z0VQI96YT)RD[
M"B`@("`@("`@("`@("1S=F%L6UT@/28@;F5W(%-/05!?5F%L=64H)V9A=6QT
M<W1R:6YG)RPG<W1R:6YG)RPB8V]U;&1N)W0@<V5N9"!33510(&UE<W-A9V4@
M=&\@>R1T:&ES+3YU<FQP87)T<ULG<&%T:"==?2(I.PH@("`@("`@("`@("`D
M=F%L(#TF(&YE=R!33T%07U9A;'5E*"=&875L="<L)U-T<G5C="<L)'-V86PI
M.PH@("`@("`@('T*"B`@("`@("`@)&UQ;F%M92`])B!N97<@44YA;64H)&UE
M=&AO9"P@)&YA;65S<&%C92D["B`@("`@("`@)&UE=&AO9%9A;'5E(#TF(&YE
M=R!33T%07U9A;'5E*"=297-P;VYS92<L("=3=')U8W0G+"!A<G)A>2@D=F%L
M*2D["@H@("`@("`@("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D(#TF("1T:&ES
M+3Y?;6%K945N=F5L;W!E*"1M971H;V1686QU92P@)'1H:7,M/FAE861E<G,L
M("1T:&ES+3YE;F-O9&EN9RD["@H@("`@("`@(')E='5R;B`D=&AI<RT^:6YC
M;VUI;F=?<&%Y;&]A9#L*("`@('T*"B`@("`O*BH*("`@("H@<V5T(&1A=&$@
M9F]R(&AT='`@875T:&5N=&EC871I;VX*("`@("H@8W)E871E<R!!=71H;W)I
M>F%T:6]N(&AE861E<@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M;F%M92`@('5S97)N86UE"B`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D
M("`@<F5S<&]N<V4@9&%T82P@;6EN=7,@:'1T<"!H96%D97)S"B`@("`J"B`@
M("`J($!R971U<FX@;F]N90H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$-R961E;G1I86QS*"1U<V5R;F%M92P@)'!A<W-W
M;W)D*0H@("`@>PH@("`@("`@("1T:&ES+3YU<V5R;F%M92`]("1U<V5R;F%M
M93L*("`@("`@("`D=&AI<RT^<&%S<W=O<F0@/2`D<&%S<W=O<F0["B`@("!]
M"@H@("`@+R\@<')I=F%T92!M96UB97)S"@H@("`@+RHJ"B`@("`J('9A;&ED
M871E('5R;"!D871A('!A<W-E9"!T;R!C;VYS=')U8W1O<@H@("`@*@H@("`@
M*B!`<F5T=7)N(&)O;VQE86X*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J
M+PH@("`@9G5N8W1I;VX@7W9A;&ED871E57)L*"D*("`@('L*("`@("`@("!I
M9B`H("$@:7-?87)R87DH)'1H:7,M/G5R;'!A<G1S*2`I('L*("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O('!A<G-E(%52
M3"`D=7)L(BD["B`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@("`@("!]
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)W-C:&5M92==
M*2!\?`H@("`@("`@("`@("!S=')C87-E8VUP*"1T:&ES+3YU<FQP87)T<ULG
M<V-H96UE)UTL("=M86EL=&\G*2`A/2`P*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<&%R<V4@55),("1U
M<FPB*3L*("`@("`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@("`@("!]
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)W!A=&@G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA8FQE
M('1O('!A<G-E(%523"`D=7)L(BD["B`@("`@("`@("`@(')E='5R;B!&04Q3
M13L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(%12544["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="]40U`N<&AP````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#8T-P`Q,#4Q-30S,3`U-P`P,C$R
M-#8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@
M82!40U`@=')A;G-P;W)T(&QA>65R+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V
M:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@(%-H86YE
M($AA;FYA(#QI;W)D>5]A=%]I;W)D>5]D;W1?8V]M/@H@*B!`8V]P>7)I9VAT
M("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI8V5N<V4@
M,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]"87-E+G!H<"<["@HO
M*BH*("H@5$-0('1R86YS<&]R="!F;W(@4T]!4"X*("H*("H@0'1O9&\@("`@
M=7-E($YE=%]3;V-K970[(&EM<&QE;65N="!S;VUE('-E8W5R:71Y('-C:&5M
M93L@:6UP;&5M96YT('-U<'!O<G0*("H@("`@("`@("`@9F]R(&%T=&%C:&UE
M;G1S"B`J($!A8V-E<W,@('!U8FQI8PH@*B!`<&%C:V%G92!33T%0"B`J($!A
M=71H;W(@(%-H86YE($AA;FYA(#QI;W)D>5]A=%]I;W)D>5]D;W1?8V]M/@H@
M*B\*8VQA<W,@4T]!4%]4<F%N<W!O<G1?5$-0(&5X=&5N9',@4T]!4%]"87-E
M7T]B:F5C=`I["@H@("`@=F%R("1H96%D97)S(#T@87)R87DH*3L*("`@('9A
M<B`D=7)L<&%R=',@/2!.54Q,.PH@("`@=F%R("1U<FP@/2`G)SL*("`@('9A
M<B`D:6YC;VUI;F=?<&%Y;&]A9"`]("<G.PH@("`@=F%R("1?=7-E<D%G96YT
M(#T@4T]!4%],24)205)97TY!344["B`@("!V87(@)&5N8V]D:6YG(#T@4T]!
M4%]$149!54Q47T5.0T]$24Y'.PH@("`@=F%R("1R97-U;'1?96YC;V1I;F<@
M/2`G551&+3@G.PH@("`@=F%R("1R97-U;'1?8V]N=&5N=%]T>7!E.PH*("`@
M("\J*@H@("`@("H@<V]C:V5T"B`@("`@*B\*("`@('9A<B`D<V]C:V5T(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!33T%07U1R86YS<&]R=%]40U`@0V]N<W1R
M=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("154DP@("`@:'1T
M<"!U<FP@=&\@<V]A<"!E;F1P;VEN=`H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?5')A;G-P;W)T7U1#
M4"@D55),+"`D96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<I"B`@
M("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V5?3V)J96-T*"=40U`G*3L*
M("`@("`@("`D=&AI<RT^=7)L<&%R=',@/2!`<&%R<V5?=7)L*"154DPI.PH@
M("`@("`@("1T:&ES+3YU<FP@/2`D55),.PH@("`@("`@("1T:&ES+3YE;F-O
M9&EN9R`]("1E;F-O9&EN9SL*("`@('T*"B`@("!F=6YC=&EO;B!?<V]C:V5T
M7W!I;F<H*0H@("`@>PH@("`@("`@("\O(%A86"!H;W<@9&\@=V4@<F5S=&%R
M="!A9G1E<B!S;V-K971?<VAU=&1O=VX_"B`@("`@("`@+R]I9B`H(21T:&ES
M+3YS;V-K970I('L*("`@("`@("`@("`@(R!C<F5A=&4@<V]C:V5T(')E<V]U
M<F-E"B`@("`@("`@("`@("1T:&ES+3YS;V-K970@/2!`<V]C:V5T7V-R96%T
M92A!1E])3D54+"!33T-+7U-44D5!32P@4T],7U1#4"D["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^<V]C:V5T(#P@,"D@<F5T=7)N(#`["@H@("`@("`@("`@
M("`C(&-O;FYE8W0*("`@("`@("`@("`@)')E<W5L="`]('-O8VME=%]C;VYN
M96-T*"1T:&ES+3YS;V-K970L("1T:&ES+3YU<FQP87)T<ULG:&]S="==+"`D
M=&AI<RT^=7)L<&%R='-;)W!O<G0G72D["B`@("`@("`@("`@(&EF("@D<F5S
M=6QT(#P@,"D@<F5T=7)N(#`["B`@("`@("`@+R]]"B`@("`@("`@<F5T=7)N
M(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!S96YD(&%N9"!R96-E:79E('-O
M87`@9&%T80H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1M<V<@("`@
M("`@;W5T9V]I;F<@<&]S="!D871A"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M8W1I;VX@("`@("!33T%0($%C=&EO;B!H96%D97(@9&%T80H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG?&9A=6QT(')E<W!O;G-E"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F<V5N9"@F)&US9RP@
M)&]P=&EO;G,@/2!.54Q,*0H@("`@>PH@("`@("`@("1T:&ES+3YI;F-O;6EN
M9U]P87EL;V%D(#T@)R<["B`@("`@("`@)'1H:7,M/F]U=&=O:6YG7W!A>6QO
M860@/2`F)&US9SL*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&55<FPH
M*2D@<F5T=7)N("1T:&ES+3YF875L=#L*"B`@("`@("`@+R\@8VAE8VL@9F]R
M(%1#4"!S8VAE;64*("`@("`@("!I9B`H<W1R8V%S96-M<"@D=&AI<RT^=7)L
M<&%R='-;)W-C:&5M92==+"`G5$-0)RD@/3T@,"D@>PH@("`@("`@("`@("`O
M+R!C:&5C:R!C;VYN96-T:6]N"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]S
M;V-K971?<&EN9R@I*0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)V5R<F]R(&]N("<N)'1H:7,M/G5R;"XG(')E87-O
M;B`G+G-O8VME=%]S=')E<G)O<BAS;V-K971?;&%S=%]E<G)O<B@D=&AI<RT^
M<V]C:V5T*2DI.PH*("`@("`@("`@("`@+R\@=W)I=&4@=&\@=&AE('-O8VME
M=`H@("`@("`@("`@("!I9B`H(4!S;V-K971?=W)I=&4H)'1H:7,M/G-O8VME
M="P@)'1H:7,M/F]U=&=O:6YG7W!A>6QO860L('-T<FQE;B@D=&AI<RT^;W5T
M9V]I;F=?<&%Y;&]A9"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@G17)R;W(@<V5N9&EN9R!D871A('1O("<N
M)'1H:7,M/G5R;"XG(')E87-O;B`G+G-O8VME=%]S=')E<G)O<BAS;V-K971?
M;&%S=%]E<G)O<B@D=&AI<RT^<V]C:V5T*2DI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+R!S:'5T9&]W;B!W<FET:6YG"B`@("`@("`@("`@(&EF
M*"%S;V-K971?<VAU=&1O=VXH)'1H:7,M/G-O8VME="P@,2DI"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B8V%N)W0@
M8VAA;F=E('-O8VME="!M;V1E('1O(')E860N(BD["@H@("`@("`@("`@("`O
M+R!R96%D(&5V97)Y=&AI;F<@=V4@8V%N+@H@("`@("`@("`@("!W:&EL92@D
M8G5F(#T@0'-O8VME=%]R96%D*"1T:&ES+3YS;V-K970L(#$P,C0L(%!(4%]"
M24Y!4EE?4D5!1"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YI;F-O;6EN
M9U]P87EL;V%D("X]("1B=68["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O(')E='5R;B!P87EL;V%D(&]R(&1I90H@("`@("`@("`@("!I9B`H)'1H
M:7,M/FEN8V]M:6YG7W!A>6QO860I"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/FEN8V]M:6YG7W!A>6QO860["@H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R86ES95-O87!&875L="@B17)R;W(@<F5V96EV:6YG(&1A=&$@
M9G)O;2`B+B1T:&ES+3YU<FPI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@=7)L('-C:&5M92`G
M+B1T:&ES+3YU<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@=F%L:61A=&4@
M=7)L(&1A=&$@<&%S<V5D('1O(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W9A;&ED871E57)L*"D*("`@('L*("`@("`@("!I
M9B`H("$@:7-?87)R87DH)'1H:7,M/G5R;'!A<G1S*2`I('L*("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O('!A<G-E(%52
M3"`D=7)L(BD["B`@("`@("`@("`@(')E='5R;B!&04Q313L*("`@("`@("!]
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)VAO<W0G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B3F\@:&]S
M="!I;B!54DP@)'5R;"(I.PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=P
M871H)UTI('Q\("$D=&AI<RT^=7)L<&%R='-;)W!A=&@G72D*("`@("`@("`@
M("`@)'1H:7,M/G5R;'!A<G1S6R=P871H)UT@/2`G+R<["B`@("`@("`@<F5T
M=7)N(%12544["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U-/05`O5')A;G-P;W)T+TA45%`N<&AP````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#0W-#,Q`#$P-3$U-#,Q,#4W`#`R,30P,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!A($A45%`@=')A
M;G-P;W)T(&QA>65R+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`
M<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@(%-H86YE($-A<F%V96\@
M/%-H86YE0$-A<F%V96\N8V]M/@H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*
M"B\J*@H@*B!(5%10(%1R86YS<&]R="!C;&%S<PH@*@H@*B!`<&%C:V%G92`@
M4T]!4`H@*B!`8V%T96=O<GD@5V5B7U-E<G9I8V5S"B`J+PH*+RHJ"B`J($YE
M961E9"!#;&%S<V5S"B`J+PIR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G
M.PH*+RHJ"B`J("!(5%10(%1R86YS<&]R="!F;W(@4T]!4`H@*@H@*B!`86-C
M97-S('!U8FQI8PH@*B!`<&%C:V%G92!33T%0"B`J($!A=71H;W(@4VAA;F4@
M0V%R879E;R`\<VAA;F5`<&AP+FYE=#X*("HO"F-L87-S(%-/05!?5')A;G-P
M;W)T7TA45%`@97AT96YD<R!33T%07T)A<V4*>PH*("`@("\J*@H@("`@("H@
M0F%S:6,@075T:"!S=')I;F<*("`@("`J"B`@("`@*B!`=F%R("!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&AE861E<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@0V]O:VEE<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1C;V]K:65S.PH*("`@("\J*@H@("`@("H*("`@("`J($!V
M87(@(&EN="!C;VYN96-T:6]N('1I;65O=70@:6X@<V5C;VYD<R`M(#`@/2!N
M;VYE"B`@("`@*B\*("`@('9A<B`D=&EM96]U="`](#0["@H@("`@+RHJ"B`@
M("`@*B!!<G)A>2!C;VYT86EN:6YG('5R;'!A<G1S("T@<&%R<V5?=7)L*"D*
M("`@("`J"B`@("`@*B!`=F%R("!M:7AE9`H@("`@("HO"B`@("!V87(@)'5R
M;'!A<G1S(#T@3E5,3#L*"B`@("`O*BH*("`@("`J($-O;FYE8W1I;VX@96YD
M<&]I;G0@+2!54DP*("`@("`J"B`@("`@*B!`=F%R("!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1U<FP@/2`G)SL*"B`@("`O*BH*("`@("`J($EN8V]M:6YG
M('!A>6QO860*("`@("`J"B`@("`@*B!`=F%R("!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1I;F-O;6EN9U]P87EL;V%D(#T@)R<["@H@("`@+RHJ"B`@("`@
M*B!(5%10+5)E<75E<W0@57-E<BU!9V5N=`H@("`@("H*("`@("`J($!V87(@
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]U<V5R06=E;G0@/2!33T%07TQ)
M0E)!4EE?3D%-13L*"B`@("`O*BH*("`@("`J($A45%`@16YC;V1I;F<*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&5N8V]D
M:6YG(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH*("`@("\J*@H@("`@("H@
M2%144"U297-P;VYS92!#;VYT96YT+51Y<&4@96YC;V1I;F<*("`@("`J"B`@
M("`@*B!W92!A<W-U;64@551&+3@@:68@;F\@96YC;V1I;F<@:7,@<V5T"B`@
M("`@*B!`=F%R("!S=')I;F<*("`@("`J+PH@("`@=F%R("1R97-U;'1?96YC
M;V1I;F<@/2`G551&+3@G.PH*("`@("\J*@H@("`@("H@2%144"U297-P;VYS
M92!#;VYT96YT+51Y<&4*("`@("`J+PH@("`@=F%R("1R97-U;'1?8V]N=&5N
M=%]T>7!E.PH*("`@('9A<B`D<F5S=6QT7VAE861E<G,@/2!A<G)A>2@I.PH*
M("`@('9A<B`D<F5S=6QT7V-O;VMI97,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@4T]!4%]4<F%N<W!O<G1?2%144"!#;VYS=')U8W1O<@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)%523"`@("!H='1P('5R;"!T;R!S;V%P
M(&5N9'!O:6YT"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!P87)A;2`@<W1R:6YG("154DD*("`@("`J($!P87)A;2`@<W1R:6YG("1E
M;F-O9&EN9R`@96YC;V1I;F<@=&\@=7-E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%-/05!?5')A;G-P;W)T7TA45%`H)%523"P@)&5N8V]D:6YG(#T@4T]!4%]$
M149!54Q47T5.0T]$24Y'*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4T]!4%]"
M87-E*"=(5%10)RD["B`@("`@("`@)'1H:7,M/G5R;'!A<G1S(#T@0'!A<G-E
M7W5R;"@D55),*3L*("`@("`@("`D=&AI<RT^=7)L(#T@)%523#L*("`@("`@
M("`D=&AI<RT^96YC;V1I;F<@/2`D96YC;V1I;F<["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!S96YD(&%N9"!R96-E:79E('-O87`@9&%T80H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@;W5T9V]I;F<@<&]S="!D871A"B`@("`@*B!`
M<&%R86T@87)R87D@(&]P=&EO;G,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9WQF875L="!R97-P;VYS90H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@)G-E;F0H)B1M<V<L("1O<'1I;VYS(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&55<FPH*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A=6QT.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=T:6UE;W5T)UTI*0H@("`@
M("`@("`@("`D=&AI<RT^=&EM96]U="`]("AI;G0I)&]P=&EO;G-;)W1I;65O
M=70G73L*"B`@("`@("`@:68@*'-T<F-A<V5C;7`H)'1H:7,M/G5R;'!A<G1S
M6R=S8VAE;64G72P@)TA45%`G*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W-E;F1(5%10*"1M<V<L("1O<'1I;VYS*3L*("`@("`@("!]
M(&5L<V4@:68@*'-T<F-A<V5C;7`H)'1H:7,M/G5R;'!A<G1S6R=S8VAE;64G
M72P@)TA45%!3)RD@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]S96YD2%144%,H)&US9RP@)&]P=&EO;G,I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@=7)L
M('-C:&5M92`G+B1T:&ES+3YU<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M<V5T(&1A=&$@9F]R(&AT='`@875T:&5N=&EC871I;VX*("`@("`J(&-R96%T
M97,@075T:&]R:7IA=&EO;B!H96%D97(*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R;F%M92`@('5S97)N86UE"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P87-S=V]R9"`@(')E<W!O;G-E(&1A=&$L(&UI;G5S(&AT='`@:&5A
M9&5R<PH@("`@("H*("`@("`J($!R971U<FX@;F]N90H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0W)E9&5N=&EA;',H
M)'5S97)N86UE+"`D<&%S<W=O<F0I"B`@("!["B`@("`@("`@)'1H:7,M/FAE
M861E<G-;)T%U=&AO<FEZ871I;VXG72`]("="87-I8R`G("X@8F%S938T7V5N
M8V]D92@D=7-E<FYA;64@+B`G.B<@+B`D<&%S<W=O<F0I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D(&$@8V]O:VEE"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!P87)A;2`@<W1R:6YG("`D;F%M92`@(&-O;VMI
M92!N86UE"B`@("`@*B!`<&%R86T@(&UI>&5D("`@)'9A;'5E("!C;V]K:64@
M=F%L=64*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1#;V]K:64H)&YA;64L("1V86QU92D*("`@('L*("`@("`@("`D=&AI
M<RT^8V]O:VEE<ULD;F%M95T])'9A;'5E.PH@("`@?0H*("`@("\O('!R:79A
M=&4@;65T:&]D<PH*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!C;W)R
M96-T(&AE861E<G,@9F]R('1H92!C;V]K:65S"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V=E;D-O;VMI94AE861E<B@I"B`@("!["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/F-O;VMI97,@87,@)&YA;64]/B1V86QU92D@>PH@("`@
M("`@("`@("`D8V]O:VEE<R`]("AI<W-E="@D8V]O:VEE<RD@/R`D8V]O:VEE
M<RX@)SL@)R`Z("<G*2`N"B`@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D;F%M92D@+B`G/2<@+B!U<FQE;F-O9&4H)'9A;'5E*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1C;V]K:65S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@=F%L:61A=&4@=7)L(&1A=&$@<&%S<V5D('1O(&-O;G-T<G5C=&]R
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E57)L*"D*
M("`@('L*("`@("`@("!I9B`H("$@:7-?87)R87DH)'1H:7,M/G5R;'!A<G1S
M*2`I('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA
M8FQE('1O('!A<G-E(%523"`B("X@)'1H:7,M/G5R;"D["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^=7)L<&%R='-;)VAO<W0G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@B3F\@:&]S="!I;B!54DP@(B`N("1T:&ES+3YU
M<FPI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=P;W)T)UTI*2!["@H@
M("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D=&AI<RT^=7)L<&%R='-;)W-C
M:&5M92==+"`G2%144"<I(#T](#`I"B`@("`@("`@("`@("`@("`D=&AI<RT^
M=7)L<&%R='-;)W!O<G0G72`](#@P.PH@("`@("`@("`@("!E;'-E(&EF("AS
M=')C87-E8VUP*"1T:&ES+3YU<FQP87)T<ULG<V-H96UE)UTL("=(5%104R<I
M(#T](#`I"B`@("`@("`@("`@("`@("`D=&AI<RT^=7)L<&%R='-;)W!O<G0G
M72`](#0T,SL*"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M=7)L<&%R='-;)W5S97(G72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$-R
M961E;G1I86QS*'5R;&1E8V]D92@D=&AI<RT^=7)L<&%R='-;)W5S97(G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5R;&1E8V]D
M92@D=&AI<RT^=7)L<&%R='-;)W!A<W,G72DI.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP87)T<ULG<&%T:"==*2!\?"`A)'1H
M:7,M/G5R;'!A<G1S6R=P871H)UTI"B`@("`@("`@("`@("1T:&ES+3YU<FQP
M87)T<ULG<&%T:"==(#T@)R\G.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1FEN9',@;W5T('=H870@:7,@=&AE(&5N8V]D
M:6YG+@H@("`@("H*("`@("`J(%-E=',@=&AE(&]B:F5C="!P<F]P97)T>2!A
M8V-O<F1I;F=L>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J($!P87)A;2`@87)R87D@)&AE861E<G,@(&AE861E<G,*("`@("`J($!R
M971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5%;F-O9&EN
M9R@D:&5A9&5R<RD*("`@('L*("`@("`@("`D:"`]('-T<FES='(H)&AE861E
M<G,L("=#;VYT96YT+51Y<&4G*3L*("`@("`@("!P<F5G7VUA=&-H7V%L;"@G
M+UY#;VYT96YT+51Y<&4Z7',J*"XJ*20O:6TG+"`D:"P@)&-T+"!04D5'7U-%
M5%]/4D1%4BD["B`@("`@("`@)&X@/2!C;W5N="@D8W0I.PH@("`@("`@("1C
M="`]("1C=%LD;B`M(#%=.PH@("`@("`@("1T:&ES+3YR97-U;'1?8V]N=&5N
M=%]T>7!E(#T@<W1R7W)E<&QA8V4H(EQR(BP@)R<L("1C=%LQ72D["B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\H+BH_*2@_.CM<<S]C:&%R<V5T/2DH+BHI
M+VDG+"`D=&AI<RT^<F5S=6QT7V-O;G1E;G1?='EP92P@)&TI*2!["B`@("`@
M("`@("`@("\O('-T<FEP('1H92!S=')I;F<@;V8@7'(*("`@("`@("`@("`@
M)'1H:7,M/G)E<W5L=%]C;VYT96YT7W1Y<&4@/2`D;5LQ73L*("`@("`@("`@
M("`@:68@*&-O=6YT*"1M*2`^(#(I('L*("`@("`@("`@("`@("`@("1E;F,@
M/2!S=')T;W5P<&5R*'-T<E]R97!L86-E*"<B)RP@)R<L("1M6S)=*2D["B`@
M("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&5N8RP@)'1H:7,M/E]E;F-O
M9&EN9W,I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G)E<W5L=%]E
M;F-O9&EN9R`]("1E;F,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@+R\@9&5A;"!W:71H(&)R;VME;B!S97)V
M97)S('1H870@9&]N)W0@<V5T(&-O;G1E;G0@='EP92!O;B!F875L=',*("`@
M("`@("!I9B`H(21T:&ES+3YR97-U;'1?8V]N=&5N=%]T>7!E*2`D=&AI<RT^
M<F5S=6QT7V-O;G1E;G1?='EP92`]("=T97AT+WAM;"<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!087)S97,@=&AE(&AE861E<G,*("`@("`J"B`@("`@*B!`
M<&%R86T@(&%R<F%Y("1H96%D97)S('1H92!H96%D97)S"B`@("`@*B!`<F5T
M=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E2&5A9&5R<R@D
M:&5A9&5R<RD*("`@('L*("`@("`@("`O*B!L87)G96QY(&)O<G)O=V5D(&9R
M;VT@2%144%]297%U97-T("HO"B`@("`@("`@)'1H:7,M/G)E<W5L=%]H96%D
M97)S(#T@87)R87DH*3L*("`@("`@("`D:&5A9&5R<R`]('-P;&ET*")<<C]<
M;B(L("1H96%D97)S*3L*("`@("`@("!F;W)E86-H("@D:&5A9&5R<R!A<R`D
M=F%L=64I('L*("`@("`@("`@("`@:68@*'-T<G!O<R@D=F%L=64L)SHG*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YR97-U;'1?:&5A
M9&5R<ULP73TD=F%L=64["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!L:7-T*"1N86UE+"1V86QU92D@/2!S
M<&QI="@G.B<L)'9A;'5E*3L*("`@("`@("`@("`@)&AE861E<FYA;64@/2!S
M=')T;VQO=V5R*"1N86UE*3L*("`@("`@("`@("`@)&AE861E<G9A;'5E(#T@
M=')I;2@D=F%L=64I.PH@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7VAE861E
M<G-;)&AE861E<FYA;65=/21H96%D97)V86QU93L*"B`@("`@("`@("`@(&EF
M("@D:&5A9&5R;F%M92`]/2`G<V5T+6-O;VMI92<I('L*("`@("`@("`@("`@
M("`@("\O(%!A<G-E(&$@4V5T0V]O:VEE(&AE861E<B!T;R!F:6QL(%]C;V]K
M:65S(&%R<F%Y"B`@("`@("`@("`@("`@("`D8V]O:VEE(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@)V5X<&ER97,G(#T^(&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@)V1O;6%I;B<@(#T^("1T:&ES+3YU<FQP87)T<ULG:&]S
M="==+`H@("`@("`@("`@("`@("`@("`@("=P871H)R`@("`]/B!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("=S96-U<F4G("`]/B!F86QS90H@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@("`@("`@("`O+R!/;FQY(&$@;F%M93UV
M86QU92!P86ER"B`@("`@("`@("`@("`@("!I9B`H(7-T<G!O<R@D:&5A9&5R
M=F%L=64L("<[)RDI('L*("`@("`@("`@("`@("`@("`@("!L:7-T*"1C;V]K
M:65;)VYA;64G72P@)&-O;VMI95LG=F%L=64G72D@/2!A<G)A>5]M87`H)W1R
M:6TG+"!E>'!L;V1E*"<])RP@)&AE861E<G9A;'5E*2D["B`@("`@("`@("`@
M("`@("`@("`@)&-O;VMI95LG;F%M92==("`]('5R;&1E8V]D92@D8V]O:VEE
M6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@("`@("1C;V]K:65;)W9A;'5E
M)UT@/2!U<FQD96-O9&4H)&-O;VMI95LG=F%L=64G72D["@H@("`@("`@("`@
M("`@("`@+R\@4V]M92!O<'1I;VYA;"!P87)A;65T97)S(&%R92!S=7!P;&EE
M9`H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D96QE;65N=',@/2!E>'!L;V1E*"<[)RP@)&AE861E<G9A;'5E*3L*("`@
M("`@("`@("`@("`@("`@("!L:7-T*"1C;V]K:65;)VYA;64G72P@)&-O;VMI
M95LG=F%L=64G72D@/2!A<G)A>5]M87`H)W1R:6TG+"!E>'!L;V1E*"<])RP@
M)&5L96UE;G1S6S!=*2D["B`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LG
M;F%M92==("`]('5R;&1E8V]D92@D8V]O:VEE6R=N86UE)UTI.PH@("`@("`@
M("`@("`@("`@("`@("1C;V]K:65;)W9A;'5E)UT@/2!U<FQD96-O9&4H)&-O
M;VMI95LG=F%L=64G72D["@H@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@
M/2`Q.R`D:2`\(&-O=6YT*"1E;&5M96YT<RD[)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!L:7-T("@D96Q.86UE+"`D96Q686QU92D@/2!A<G)A
M>5]M87`H)W1R:6TG+"!E>'!L;V1E*"<])RP@)&5L96UE;G1S6R1I72DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)W-E8W5R92<@/3T@)&5L3F%M
M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LG<V5C
M=7)E)UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)V5X<&ER97,G(#T]("1E;$YA;64I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;V]K:65;)V5X<&ER97,G72`]('-T<E]R97!L86-E*"<B
M)RP@)R<L("1E;%9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"=P871H)R`]/2`D96Q.86UE($]2("=D;VUA:6XG(#T]("1E;$YA
M;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;V]K:65;)&5L
M3F%M95T@/2!U<FQD96-O9&4H)&5L5F%L=64I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;VMI95LD96Q.86UE72`]("1E;%9A;'5E.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G)E<W5L=%]C;V]K:65S6UT@
M/2`D8V]O:VEE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5M;W9E(&AT='`@:&5A9&5R<R!F<F]M(')E<W!O;G-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E4F5S<&]N<V4H
M*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7B@N*C\I7'(_7&Y<
M<C]<;B@N*BDO<R(L("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D+"`D;6%T8V@I
M*2!["B`@("`@("`@("`@(",D=&AI<RT^<F5S<&]N<V4@/2!P<F5G7W)E<&QA
M8V4H(B];7')\7&Y=+R(L("<G+"`D;6%T8VA;,ETI.PH@("`@("`@("`@("`D
M=&AI<RT^<F5S<&]N<V4@/28@)&UA=&-H6S)=.PH@("`@("`@("`@("`O+R!F
M:6YD('1H92!R97-P;VYS92!E<G)O<BP@<V]M92!S97)V97)S(')E<W!O;G-E
M('=I=&@@-3`P(&9O<B!S;V%P(&9A=6QT<PH@("`@("`@("`@("`D=&AI<RT^
M7W!A<G-E2&5A9&5R<R@D;6%T8VA;,5TI.PH*("`@("`@("`@("`@;&ES="@D
M<')O=&]C;VPL("1C;V1E+"`D;7-G*2`]('-S8V%N9B@D=&AI<RT^<F5S=6QT
M7VAE861E<G-;,%TL("<E<R`E<R`E<R<I.PH@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^<F5S=6QT7VAE861E<G-;,%TI.PH*("`@("`@("`@("`@<W=I=&-H
M*"1C;V1E*2!["B`@("`@("`@("`@("`@("!C87-E(#$P,#H@+R\@0V]N=&EN
M=64*("`@("`@("`@("`@("`@("`@("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D
M(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%R<V5297-P;VYS92@I.PH@("`@("`@("`@("`@("`@8V%S92`T,#`Z
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B
M2%144"!297-P;VYS92`D8V]D92!"860@4F5Q=65S="(I.PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@-#`Q.@H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@4F5S<&]N<V4@
M)&-O9&4@075T:&5N=&EC871I;VX@1F%I;&5D(BD["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@8V%S92`T,#,Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@B2%144"!297-P;VYS92`D8V]D
M92!&;W)B:61D96XB*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(#0P-#H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*")(5%10(%)E<W!O;G-E("1C;V1E($YO="!&;W5N9"(I.PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@-#`W.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@
M4F5S<&]N<V4@)&-O9&4@4')O>'D@075T:&5N=&EC871I;VX@4F5Q=6ER960B
M*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(#0P.#H*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")(
M5%10(%)E<W!O;G-E("1C;V1E(%)E<75E<W0@5&EM96]U="(I.PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@-#$P.@H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@4F5S<&]N
M<V4@)&-O9&4@1V]N92(I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@:68@*"1C;V1E(#X]
M(#0P,"`F)B`D8V]D92`\(#4P,"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")(5%10(%)E<W!O;G-E("1C;V1E
M($YO="!&;W5N9"P@4V5R=F5R(&UE<W-A9V4Z("1M<V<B*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]P87)S
M945N8V]D:6YG*"1M871C:%LQ72D["@H@("`@("`@("`@("!I9B`H)'1H:7,M
M/G)E<W5L=%]C;VYT96YT7W1Y<&4@/3T@)V%P<&QI8V%T:6]N+V1I;64G*2![
M"B`@("`@("`@("`@("`@("`O+R!86%@@<75I8VL@:&%C:R!I;G-E<G1I;VX@
M;V8@1$E-10H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H
M:7,M/E]D96-O9&5$24U%365S<V%G92@D=&AI<RT^<F5S<&]N<V4L)'1H:7,M
M/FAE861E<G,L)'1H:7,M/F%T=&%C:&UE;G1S*2DI('L*("`@("`@("`@("`@
M("`@("`@("`O+R!?9&5C;V1E1$E-14UE<W-A9V4@86QR96%D>2!R86ES960@
M)'1H:7,M/F9A=6QT"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G)E
M<W5L=%]C;VYT96YT7W1Y<&4@/2`D=&AI<RT^:&5A9&5R<ULG8V]N=&5N="UT
M>7!E)UT["B`@("`@("`@("`@('T@96QS92!I9B`H<W1R:7-T<B@D=&AI<RT^
M<F5S=6QT7V-O;G1E;G1?='EP92PG;75L=&EP87)T+W)E;&%T960G*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G)E<W!O;G-E(#T@)'1H:7,M/FEN8V]M
M:6YG7W!A>6QO860["B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D=&AI<RT^7V1E8V]D94UI;65-97-S86=E*"1T:&ES+3YR97-P;VYS92PD
M=&AI<RT^:&5A9&5R<RPD=&AI<RT^871T86-H;65N=',I*2D@>PH@("`@("`@
M("`@("`@("`@("`@("\O(%]D96-O9&5-:6UE365S<V%G92!A;')E861Y(')A
M:7-E9"`D=&AI<RT^9F%U;'0*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!I
M9B`H)'1H:7,M/G)E<W5L=%]C;VYT96YT7W1Y<&4@(3T@)W1E>'0O>&UL)RD@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI
M<RT^<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("\O(&EF(&YO(&-O;G1E;G0L(')E
M='5R;B!F86QS90H@("`@("`@("`@("!R971U<FX@<W1R;&5N*"1T:&ES+3YR
M97-P;VYS92D@/B`P.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"=);G9A;&ED($A45%`@4F5S<&]N<V4G*3L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@:'1T
M<"!R97%U97-T+"!I;F-L=61I;F<@:&5A9&5R<RP@9F]R(&]U=&=O:6YG(')E
M<75E<W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)B1M<V<@("!O
M=71G;VEN9R!33T%0('!A8VMA9V4*("`@("`J($!P87)A;2`D;W!T:6]N<PH@
M("`@("H@0')E='5R;B!S=')I;F<@;W5T9V]I;F=?<&%Y;&]A9`H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9V5T4F5Q
M=65S="@F)&US9RP@)&]P=&EO;G,I"B`@("!["B`@("`@("`@)&%C=&EO;B`]
M(&ES<V5T*"1O<'1I;VYS6R=S;V%P86-T:6]N)UTI/R1O<'1I;VYS6R=S;V%P
M86-T:6]N)UTZ)R<["B`@("`@("`@)&9U;&QP871H(#T@)'1H:7,M/G5R;'!A
M<G1S6R=P871H)UTN"B`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E="@D
M=&AI<RT^=7)L<&%R='-;)W%U97)Y)UTI/R<_)RXD=&AI<RT^=7)L<&%R='-;
M)W%U97)Y)UTZ)R<I+@H@("`@("`@("`@("`@("`@("`@("`@("`H:7-S970H
M)'1H:7,M/G5R;'!A<G1S6R=F<F%G;65N="==*3\G(R<N)'1H:7,M/G5R;'!A
M<G1S6R=F<F%G;65N="==.B<G*3L*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=P<F]X>5]H;W-T)UTI*2!["B`@("`@("`@("`@("1F=6QL<&%T:"`]
M("=H='1P.B\O)R`N("1T:&ES+3YU<FQP87)T<ULG:&]S="==("X@)SHG("X@
M)'1H:7,M/G5R;'!A<G1S6R=P;W)T)UT@+B`D9G5L;'!A=&@["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!R;WAY7W5S97(G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/FAE861E<G-;)U!R;WAY+4%U=&AO<FEZ
M871I;VXG72`]("="87-I8R`G("X@8F%S938T7V5N8V]D92@D;W!T:6]N<ULG
M<')O>'E?=7-E<B==+B(Z(BXD;W!T:6]N<ULG<')O>'E?<&%S<R==*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG=7-E<B==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V5T0W)E9&5N=&EA;',H)&]P=&EO;G-;
M)W5S97(G72P@)&]P=&EO;G-;)W!A<W,G72D["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^:&5A9&5R<ULG57-E<BU!9V5N="==(#T@)'1H:7,M/E]U<V5R
M06=E;G0["B`@("`@("`@)'1H:7,M/FAE861E<G-;)TAO<W0G72`]("1T:&ES
M+3YU<FQP87)T<ULG:&]S="==.PH@("`@("`@("1T:&ES+3YH96%D97)S6R=#
M;VYT96YT+51Y<&4G72`](")T97AT+WAM;#L@8VAA<G-E=#TD=&AI<RT^96YC
M;V1I;F<B.PH@("`@("`@("1T:&ES+3YH96%D97)S6R=#;VYT96YT+4QE;F=T
M:"==(#T@<W1R;&5N*"1M<V<I.PH@("`@("`@("1T:&ES+3YH96%D97)S6R=3
M3T%006-T:6]N)UT@/2`B7"(D86-T:6]N7"(B.PH@("`@("`@(&EF("AI<W-E
M="@D;W!T:6]N<ULG:&5A9&5R<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M:&5A9&5R<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3YH96%D97)S+"`D;W!T:6]N
M<ULG:&5A9&5R<R==*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YC;V]K
M:65S(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=N
M;V-O;VMI97,G72D@?'P@(21O<'1I;VYS6R=N;V-O;VMI97,G72D@>PH@("`@
M("`@("`@("`O+R!A9&0@=&AE(&-O;VMI97,@=V4@9V]T(&9R;VT@=&AE(&QA
M<W0@<F5Q=65S=`H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/G)E<W5L
M=%]C;V]K:65S*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/G)E<W5L=%]C;V]K:65S(&%S("1C;V]K:64I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&-O;VMI95LG9&]M86EN)UT@/3T@)'1H:7,M/G5R;'!A<G1S
M6R=H;W-T)UTI"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;V]K
M:65S6R1C;V]K:65;)VYA;64G75T])&-O;VMI95LG=F%L=64G73L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O
M+R!A9&0@8V]O:VEE<R!T:&4@=7-E<B!W86YT<R!T;R!S970*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)V-O;VMI97,G72DI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&]P=&EO;G-;)V-O;VMI97,G72!A<R`D8V]O:VEE*2!["B`@
M("`@("`@("`@("`@("!I9B`H)&-O;VMI95LG9&]M86EN)UT@/3T@)'1H:7,M
M/G5R;'!A<G1S6R=H;W-T)UTI"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F-O;VMI97-;)&-O;VMI95LG;F%M92==73TD8V]O:VEE6R=V86QU92==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AC;W5N="@D=&AI
M<RT^8V]O:VEE<RDI('L*("`@("`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O
M;VMI92==(#T@)'1H:7,M/E]G96Y#;V]K:65(96%D97(H*3L*("`@("`@("!]
M"B`@("`@("`@)&AE861E<G,@/2`G)SL*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^:&5A9&5R<R!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`D:&5A9&5R
M<R`N/2`B)&LZ("1V7')<;B(["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YO
M=71G;VEN9U]P87EL;V%D(#T*("`@("`@("`@("`@("`@(")03U-4("1F=6QL
M<&%T:"!(5%10+S$N,%QR7&XB+@H@("`@("`@("`@("`@("`@)&AE861E<G,N
M(EQR7&XB+@H@("`@("`@("`@("`@("`@)&US9SL*("`@("`@("!R971U<FX@
M)'1H:7,M/F]U=&=O:6YG7W!A>6QO860["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!396YD(&]U=&=O:6YG(')E<75E<W0L(&%N9"!R96%D+W!A<G-E(')E<W!O
M;G-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)B1M<V<@("!O=71G
M;VEN9R!33T%0('!A8VMA9V4*("`@("`J($!P87)A;2!S=')I;F<@("1A8W1I
M;VX@("!33T%0($%C=&EO;@H@("`@("H@0')E='5R;B!S=')I;F<@)B1R97-P
M;VYS92`@(')E<W!O;G-E(&1A=&$L(&UI;G5S(&AT='`@:&5A9&5R<PH@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?<V5N
M9$A45%`H)B1M<V<L("1O<'1I;VYS*0H@("`@>PH@("`@("`@("1T:&ES+3YI
M;F-O;6EN9U]P87EL;V%D(#T@)R<["B`@("`@("`@)'1H:7,M/E]G971297%U
M97-T*"1M<V<L("1O<'1I;VYS*3L*("`@("`@("`D:&]S="`]("1T:&ES+3YU
M<FQP87)T<ULG:&]S="==.PH@("`@("`@("1P;W)T(#T@)'1H:7,M/G5R;'!A
M<G1S6R=P;W)T)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P<F]X
M>5]H;W-T)UTI*2!["B`@("`@("`@("`@("1H;W-T(#T@)&]P=&EO;G-;)W!R
M;WAY7VAO<W0G73L*("`@("`@("`@("`@)'!O<G0@/2!I<W-E="@D;W!T:6]N
M<ULG<')O>'E?<&]R="==*2`_("1O<'1I;VYS6R=P<F]X>5]P;W)T)UT@.B`X
M,#@P.PH@("`@("`@('T*("`@("`@("`O+R!S96YD"B`@("`@("`@:68@*"1T
M:&ES+3YT:6UE;W5T(#X@,"D@>PH@("`@("`@("`@("`D9G`@/2!`9G-O8VMO
M<&5N*"1H;W-T+"`D<&]R="P@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R;7-G
M+"`D=&AI<RT^=&EM96]U="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9P(#T@0&9S;V-K;W!E;B@D:&]S="P@)'!O<G0L("1T:&ES+3YE<G)N
M;RP@)'1H:7,M/F5R<FUS9RD["B`@("`@("`@?0H@("`@("`@(&EF("@A)&9P
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*")#;VYN96-T($5R<F]R('1O("1H;W-T.B1P;W)T(BD["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^=&EM96]U="`^(#`I('L*("`@("`@("`@("`@
M+R\@<V]M92!B=6EL9',@;V8@<&AP(&1O(&YO="!S=7!P;W)T('1H:7,L('-I
M;&5N8V4*("`@("`@("`@("`@+R\@=&AE('=A<FYI;F<*("`@("`@("`@("`@
M0'-O8VME=%]S971?=&EM96]U="@D9G`L("1T:&ES+3YT:6UE;W5T*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"%F<'5T<R@D9G`L("1T:&ES+3YO=71G;VEN
M9U]P87EL;V%D+"!S=')L96XH)'1H:7,M/F]U=&=O:6YG7W!A>6QO860I*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B
M17)R;W(@4$]35&EN9R!$871A('1O("1H;W-T(BD["B`@("`@("`@?0H*("`@
M("`@("`O+R!G970@<F5P;VYS90H@("`@("`@("\O(%A86"!T:6UE(&-O;G-U
M;65R"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F
M<"P@-#`Y-BD["B`@("`@("`@("`@("1?=&UP7W-T871U<R`]('-O8VME=%]G
M971?<W1A='5S*"1F<"D["B`@("`@("`@("`@(&EF("@D7W1M<%]S=&%T=7-;
M)W1I;65D7V]U="==*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]R86ES95-O87!&875L="@B5&EM960@;W5T(')E860@9G)O;2`D:&]S="(I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FEN8V]M:6YG7W!A>6QO860@+CT@)&1A=&$["B`@("`@("`@("`@('T*("`@
M("`@("!]('=H:6QE("@A)%]T;7!?<W1A='5S6R=E;V8G72D["@H@("`@("`@
M(&9C;&]S92@D9G`I.PH*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R<V5297-P
M;VYS92@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%U;'0["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F5S<&]N<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!396YD(&]U=&=O:6YG(')E<75E<W0L(&%N9"!R
M96%D+W!A<G-E(')E<W!O;G-E+"!V:6$@2%144%,*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`F)&US9R`@(&]U=&=O:6YG(%-/05`@<&%C:V%G90H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&%C=&EO;B`@(%-/05`@06-T:6]N"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`F)')E<W!O;G-E("`@<F5S<&]N<V4@9&%T
M82P@;6EN=7,@:'1T<"!H96%D97)S"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@)E]S96YD2%144%,H)B1M<V<L("1O<'1I
M;VYS*0H@("`@>PH@("`@("`@("\J($Y/5$4@5&AI<R!F=6YC=&EO;B!U<V5S
M('1H92!#55),(&9U;F-T:6]N<PH@("`@("`@("`J("!9;W5R('!H<"!M=7-T
M(&)E(&-O;7!I;&5D('=I=&@@0U523`H@("`@("`@("`J+PH@("`@("`@(&EF
M("@A97AT96YS:6]N7VQO861E9"@G8W5R;"<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=#55),($5X=&5N<VEO;B!I
M<R!R97%U:7)E9"!F;W(@2%144%,G*3L*("`@("`@("!]"@H@("`@("`@("1C
M:"`](&-U<FQ?:6YI="@I.PH*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W!R;WAY7VAO<W0G72DI('L*("`@("`@("`@("`@+R\@)&]P=&EO;G-;)VAT
M='!?<')O>'DG72`]/2`G:&]S=&YA;64Z<&]R="<*("`@("`@("`@("`@)&AO
M<W0@/2`D;W!T:6]N<ULG<')O>'E?:&]S="==.PH@("`@("`@("`@("`D<&]R
M="`](&ES<V5T*"1O<'1I;VYS6R=P<F]X>5]P;W)T)UTI(#\@)&]P=&EO;G-;
M)W!R;WAY7W!O<G0G72`Z(#@P.#`["B`@("`@("`@("`@(&-U<FQ?<V5T;W!T
M*"1C:"P@0U523$]05%]04D]862P@)&AO<W0@+B`B.B(@+B`D<&]R="D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!R;WAY7W5S
M97(G72DI('L*("`@("`@("`@("`@+R\@)&]P=&EO;G-;)VAT='!?<')O>'E?
M=7-E<G!W)UT@/3T@)W5S97)N86UE.G!A<W-W;W)D)PH@("`@("`@("`@("!C
M=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?4%)/6%E54T524%=$+"`D;W!T:6]N
M<ULG<')O>'E?=7-E<B==("X@)SHG("X@)&]P=&EO;G-;)W!R;WAY7W!A<W,G
M72D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W5S
M97(G72DI('L*("`@("`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!4
M7U5315)05T0L("1O<'1I;VYS6R=U<V5R)UT@+B`G.B<@+B`D;W!T:6]N<ULG
M<&%S<R==*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&]P=&EO
M;G-;)W-O87!A8W1I;VXG72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;)W-O
M87!A8W1I;VXG72`]("<G.PH@("`@("`@('T*("`@("`@("!C=7)L7W-E=&]P
M="@D8V@L($-54DQ/4%1?2%144$A%041%4B`L("`@(&%R<F%Y*"=#;VYT96YT
M+51Y<&4Z('1E>'0O>&UL.V-H87)S970])R`N("1T:&ES+3YE;F-O9&EN9RP@
M)U-/05!!8W1I;VXZ("(G+B1O<'1I;VYS6R=S;V%P86-T:6]N)UTN)R(G*2D[
M"B`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47U5315)!1T5.5"`L
M("`@("`D=&AI<RT^7W5S97)!9V5N="D["@H@("`@("`@(&EF("@D=&AI<RT^
M=&EM96]U="D@>PH@("`@("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/
M4%1?5$E-14]55"P@)'1H:7,M/G1I;65O=70I.R`O+W1I;65S(&]U="!A9G1E
M<B`T<PH@("`@("`@('T*"B`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),
M3U!47U!/4U1&245,1%,L("`@("`@("1M<V<I.PH@("`@("`@(&-U<FQ?<V5T
M;W!T*"1C:"P@0U523$]05%]54DPL("`@("`@("`@("`@("`D=&AI<RT^=7)L
M*3L*("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?4$]35"P@("`@
M("`@("`@("`@,2D["B`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!4
M7T9!24Q/3D524D]2+"`@("`@(#`I.PH@("`@("`@(&-U<FQ?<V5T;W!T*"1C
M:"P@0U523$]05%]&3TQ,3U=,3T-!5$E/3BP@("`Q*3L*("`@("`@("!C=7)L
M7W-E=&]P="@D8V@L($-54DQ/4%1?4D5455).5%)!3E-&15(L("`@,2D["B`@
M("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47TA%041%4BP@("`@("`@
M("`@(#$I.PH@("`@("`@(&EF("AD969I;F5D*"=#55),3U!47TA45%!?5D52
M4TE/3B<I*2!["B`@("`@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]0
M5%](5%107U9%4E-)3TXL(#$I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=C=7)L)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1O<'1I;VYS6R=C=7)L)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("`@("!C=7)L7W-E=&]P="@D8V@L("1K97DL("1V86PI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!3879E('1H92!O=71G;VEN
M9R!834PN(%1H:7,@9&]E<VXG="!Q=6ET92!M871C:"!?<V5N9$A45%`*("`@
M("`@("`O+R!A<R!#55),(&=E;F5R871E<R!T:&4@:&5A9&5R<RP@8G5T(&AA
M=FEN9R!T:&4@6$U,(&ES"B`@("`@("`@+R\@=7-U86QL>2!T:&4@;6]S="!I
M;7!O<G1A;G0@<&%R="!F;W(@=')A8VEN9R]D96)U9V=I;F<N"B`@("`@("`@
M)'1H:7,M/F]U=&=O:6YG7W!A>6QO860@/2`D;7-G.PH*("`@("`@("`D=&AI
M<RT^:6YC;VUI;F=?<&%Y;&]A9"`](&-U<FQ?97AE8R@D8V@I.PH@("`@("`@
M(&EF("@A)'1H:7,M/FEN8V]M:6YG7W!A>6QO860I('L*("`@("`@("`@("`@
M)&T@/2`G8W5R;%]E>&5C(&5R<F]R("<@+B!C=7)L7V5R<FYO*"1C:"D@+B`G
M("<@+B!C=7)L7V5R<F]R*"1C:"D["B`@("`@("`@("`@(&-U<FQ?8VQO<V4H
M)&-H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H)&TI.PH@("`@("`@('T*("`@("`@("!C=7)L7V-L;W-E*"1C:"D["@H@
M("`@("`@(&EF("@A)'1H:7,M/E]P87)S95)E<W!O;G-E*"DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YF875L=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F5S<&]N<V4["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U-E<G9E<B\`````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`U-P`P,3<S-30`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/
M05`O4V5R=F5R+U1#4"YP:'``````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`V-S$U`#$P-3$U-#,Q,#4W`#`R,#4R,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AI
M<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T:&4@5$-0(%-/05`@<V5R
M=F5R+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I
M;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@
M("!33T%0"B`J($!A=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A
M<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`8V]P>7)I
M9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI8V5N
M<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(N<&AP
M)SL*"B\J*@H@*B!33T%0(%-E<G9E<B!#;&%S<R!T:&%T(&EM<&QE;65N=',@
M82!40U`@4T]!4"!397)V97(N"B`J(&AT='`Z+R]W=W<N<&]C:V5T<V]A<"YC
M;VTO<W!E8W,O<VUT<&)I;F1I;F<O"B`J"B`J(%1H:7,@8VQA<W,@;W9E<G)I
M9&5S('1H92!D969A=6QT($A45%`@<V5R=F5R+"!P<F]V:61I;F<@=&AE(&%B
M:6QI='D@=&\*("H@86-C97!T('-O8VME="!C;VYN96-T:6]N<R!A;F0@97AE
M8W5T92!33T%0(&-A;&QS+@H@*@H@*B!43T1/.@H@*B`@('5S92!.971?4V]C
M:V5T"B`J("`@:6UP;&5M96YT('-O;64@<V5C=7)I='D@<V-H96UE"B`J("`@
M:6UP;&5M96YT('-U<'!O<G0@9F]R(&%T=&%C:&UE;G1S"B`J"B`J($!A8V-E
M<W,@("!P=6)L:6,*("H@0'!A8VMA9V4@(%-/05`*("H@0&%U=&AO<B`@(%-H
M86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^"B`J+PIC;&%S<R!33T%07U-E
M<G9E<E]40U`@97AT96YD<R!33T%07U-E<G9E<B!["@H@("`@=F%R("1H96%D
M97)S(#T@87)R87DH*3L*("`@('9A<B`D;&]C86QA9&1R.PH@("`@=F%R("1P
M;W)T.PH@("`@=F%R("1L:7-T96X["B`@("!V87(@)')E=7-E.PH*("`@(&9U
M;F-T:6]N(%-/05!?4V5R=F5R7U1#4"@D;&]C86QA9&1R(#T@)S$R-RXP+C`N
M,2<L("1P;W)T(#T@,3`P,#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&QI<W1E;B`](#4L("1R975S92`]('1R=64I"B`@("!["B`@("`@("`@
M<&%R96YT.CI33T%07U-E<G9E<B@I.PH@("`@("`@("1T:&ES+3YL;V-A;&%D
M9'(@/2`D;&]C86QA9&1R.PH@("`@("`@("1T:&ES+3YP;W)T(#T@)'!O<G0[
M"B`@("`@("`@)'1H:7,M/FQI<W1E;B`]("1L:7-T96X["B`@("`@("`@)'1H
M:7,M/G)E=7-E(#T@)')E=7-E.PH@("`@?0H*("`@(&9U;F-T:6]N(')U;B@I
M"B`@("!["B`@("`@("`@:68@*"@D<V]C:R`]('-O8VME=%]C<F5A=&4H049?
M24Y%5"P@4T]#2U]35%)%04TL(#`I*2`\(#`I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)W-O8VME=%]C<F5A=&4H*2!F
M86EL960N(%)E87-O;CH@)R`N('-O8VME=%]S=')E<G)O<B@D<V]C:RDI.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/G)E=7-E("8F"B`@("`@("`@
M("`@("%`<V]C:V5T7W-E=&]P="@D<V]C:RP@4T],7U-/0TM%5"P@4T]?4D55
M4T5!1$12+"`Q*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES
M95-O87!&875L="@G<V]C:V5T7W-E=&]P="@I(&9A:6QE9"X@4F5A<V]N.B`G
M("X@<V]C:V5T7W-T<F5R<F]R*'-O8VME=%]L87-T7V5R<F]R*"1S;V-K*2DI
M.PH@("`@("`@('T*("`@("`@("!I9B`H*"1R970@/2!S;V-K971?8FEN9"@D
M<V]C:RP@)'1H:7,M/FQO8V%L861D<BP@)'1H:7,M/G!O<G0I*2`\(#`I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)W-O
M8VME=%]B:6YD*"D@9F%I;&5D+B!296%S;VXZ("<@+B!S;V-K971?<W1R97)R
M;W(H)')E="DI.PH@("`@("`@('T*("`@("`@("!I9B`H*"1R970@/2!S;V-K
M971?;&ES=&5N*"1S;V-K+"`D=&AI<RT^;&ES=&5N*2D@/"`P*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=S;V-K971?
M;&ES=&5N*"D@9F%I;&5D+B!296%S;VXZ("<@+B!S;V-K971?<W1R97)R;W(H
M)')E="DI.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*'1R=64I('L*("`@
M("`@("`@("`@)&1A=&$@/2!N=6QL.PH@("`@("`@("`@("!I9B`H*"1M<V=S
M;V-K(#T@<V]C:V5T7V%C8V5P="@D<V]C:RDI(#P@,"D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G<V]C:V5T7V%C8V5P="@I
M(&9A:6QE9"X@4F5A<V]N.B`G("X@<V]C:V5T7W-T<F5R<F]R*"1M<V=S;V-K
M*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!W:&EL92`H)&)U9B`]('-O8VME=%]R96%D*"1M<V=S;V-K+"`X
M,3DR*2D@>PH@("`@("`@("`@("`@("`@:68@*"$D8G5F(#T@=')I;2@D8G5F
M*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&$@+CT@)&)U9CL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"1D871A*2!["B`@("`@("`@("`@
M("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^<V5R=FEC92@D9&%T82D["B`@("`@
M("`@("`@("`@("`O*B!7<FET92!T;R!T:&4@<V]C:V5T+B`J+PH@("`@("`@
M("`@("`@("`@:68@*"%S;V-K971?=W)I=&4H)&US9W-O8VLL("1R97-P;VYS
M92P@<W1R;&5N*"1R97-P;VYS92DI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)T5R<F]R('-E;F1I;F<@
M<F5S<&]N<V4@9&%T82!R96%S;VX@)R`N('-O8VME=%]S=')E<G)O<B@I*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M<V]C:V5T7V-L;W-E("@D;7-G<V]C:RD["B`@("`@("`@?0H*("`@("`@("!S
M;V-K971?8VQO<V4@*"1S;V-K*3L*("`@('T*"B`@("!F=6YC=&EO;B!S97)V
M:6-E*"8D9&%T82D*("`@('L*("`@("`@("`O*B!43T1/.B!W92!N965D('1O
M(&AA;F1L92!A='1A8VAM96YT<R!S;VUE:&]W+B`J+PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<&%R<V5297%U97-T*"1D871A+"`D871T86-H;65N=',I.PH@
M("`@?0I]"@``````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]3
M3T%0+U-E<G9E<B]%;6%I;"YP:'``````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q-C4Q-P`Q,#4Q-30S,3`U-P`P,C$Q,C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(&5M86EL(%-/05`@
M<V5R=F5R+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A
M=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G
M92`@("!33T%0"B`J($!A=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE
M0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`8V]P
M>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI
M8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(N
M<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+T-L:65N="YP:'`G.PIR97%U:7)E
M7V]N8V4@)U-/05`O5')A;G-P;W)T+G!H<"<["G)E<75I<F5?;VYC92`G36%I
M;"]M:6UE1&5C;V1E+G!H<"<["@HO*BH*("H@4T]!4"!397)V97(@0VQA<W,@
M=&AA="!I;7!L96UE;G1S(&%N(&5M86EL(%-/05`@<V5R=F5R+@H@*B!H='1P
M.B\O=W=W+G!O8VME='-O87`N8V]M+W-P96-S+W-M='!B:6YD:6YG+PH@*@H@
M*B!4:&ES(&-L87-S(&]V97)R:61E<R!T:&4@9&5F875L="!(5%10('-E<G9E
M<BP@<')O=FED:6YG('1H92!A8FEL:71Y('1O"B`J('!A<G-E(&%N(&5M86EL
M(&UE<W-A9V4@86YD(&5X96-U=&4@4T]!4"!C86QL<RX@(%1H:7,@8VQA<W,@
M1$]%4R!.3U0@<&]P('1H90H@*B!M97-S86=E.R!T:&4@;65S<V%G92P@8V]M
M<&QE=&4@=VET:"!H96%D97)S+"!M=7-T(&)E('!A<W-E9"!I;B!A<R!A"B`J
M('!A<F%M971E<B!T;R!T:&4@<V5R=FEC92!F=6YC=&EO;B!C86QL+@H@*@H@
M*B!`86-C97-S("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H
M;W(@("!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@
M4T]!4%]397)V97)?16UA:6P@97AT96YD<R!33T%07U-E<G9E<B!["@H@("`@
M=F%R("1H96%D97)S(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!33T%07U-E
M<G9E<E]%;6%I;"@D<V5N9%]R97-P;VYS92`]('1R=64I"B`@("!["B`@("`@
M("`@<&%R96YT.CI33T%07U-E<G9E<B@I.PH@("`@("`@("1T:&ES+3YS96YD
M7W)E<W!O;G-E(#T@)'-E;F1?<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296UO=F5S($A45%`@:&5A9&5R<R!F<F]M(')E<W!O;G-E+@H@("`@
M("H*("`@("`J(%1/1$\Z('5S92!014%2(&5M86EL(&-L87-S97,*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5%;6%I;"@F)&1A=&$I"B`@
M("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>*"XJ/RE<<C]<;EQR/UQN
M*"XJ*2]S(BP@)&1A=&$L("1M871C:"DI('L*"B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H7V%L;"@G+UXH+BH_*3I<<RLH+BHI)"]M)RP@)&UA=&-H6S%=
M+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1H8R`](&-O=6YT*"1M
M871C:&5S6S!=*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1H8SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH96%D
M97)S6W-T<G1O;&]W97(H)&UA=&-H97-;,5U;)&E=*5T@/2!T<FEM*"1M871C
M:&5S6S)=6R1I72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A<W1R:7-T<B@D=&AI<RT^:&5A9&5R<ULG8V]N
M=&5N="UT>7!E)UTL("=T97AT+WAM;"<I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@G26YV86QI9"!#;VYT96YT(%1Y
M<&4G+"`G)RP@)R<L("=#;&EE;G0G*3L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AS
M=')C87-E8VUP*"1T:&ES+3YH96%D97)S6R=C;VYT96YT+71R86YS9F5R+65N
M8V]D:6YG)UTL("=B87-E-C0G*3T],"D@>PH@("`@("`@("`@("`@("`@+RH@
M56YF;VQD(&QI;F5S+B`J+PH@("`@("`@("`@("`@("`@)&5N8W1E>'0@/2!P
M<F5G7W)E<&QA8V4H(B];7')\7&Y=+R(L("<G+"`D;6%T8VA;,ETI.PH@("`@
M("`@("`@("`@("`@)&1A=&$@/2!B87-E-C1?9&5C;V1E*"1E;F-T97AT*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D871A(#T@
M)&UA=&-H6S)=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)9B!N
M;R!C;VYT96YT+"!R971U<FX@9F%L<V4N("HO"B`@("`@("`@("`@(')E='5R
M;B!S=')L96XH)'1H:7,M/G)E<75E<W0I(#X@,#L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@16UA:6P@1F]R
M;6%T)RP@)R<L("<G+"`G0VQI96YT)RD["@H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("!F=6YC=&EO;B!C;&EE;G0H)B1D871A*0H@("`@>PH@
M("`@("`@("1A='1A8VAM96YT<R`](&%R<F%Y*"D["@H@("`@("`@("\J($EF
M(&YE:71H97(@;6%T8VAE<RP@=V4G;&P@:G5S="!T<GD@:70@86YY=V%Y+B`J
M+PH@("`@("`@(&EF("AS=')I<W1R*"1D871A+"`G0V]N=&5N="U4>7!E.B!A
M<'!L:6-A=&EO;B]D:6UE)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D96-O
M9&5$24U%365S<V%G92@D9&%T82P@)'1H:7,M/FAE861E<G,L("1A='1A8VAM
M96YT<RD["B`@("`@("`@("`@("1U<V5%;F-O9&EN9R`]("=$24U%)SL*("`@
M("`@("!](&5L<V5I9B`H<W1R:7-T<B@D9&%T82P@)TU)344M5F5R<VEO;CHG
M*2D@>PH@("`@("`@("`@("`O*B!4:&ES(&ES(&$@;6EM92!M97-S86=E+"!L
M970G<R!D96-O9&4@:70N("HO"B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E
M36EM94UE<W-A9V4H)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H;65N
M=',I.PH@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G36EM92<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@5&AE(&]L9"!F86QL8F%C:RP@
M8G5T(&1E8V]D94UI;65-97-S86=E(&AA;F1L97,@=&AI;F=S(&9I;F4N("HO
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5%;6%I;"@D9&%T82D["B`@("`@
M("`@?0H*("`@("`@("`O*B!'970@=&AE(&-H87)A8W1E<B!E;F-O9&EN9R!O
M9B!T:&4@:6YC;VUI;F<@<F5Q=65S="!T<F5A="!I;F-O;6EN9PH@("`@("`@
M("`J(&1A=&$@87,@551&+3@@:68@;F\@96YC;V1I;F<@<V5T+B`J+PH@("`@
M("`@(&EF("@A)'1H:7,M/G-O87!F875L="`F)@H@("`@("`@("`@("`A)'1H
M:7,M/E]G971#;VYT96YT16YC;V1I;F<H)'1H:7,M/FAE861E<G-;)V-O;G1E
M;G0M='EP92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG
M(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH@("`@("`@("`@("`O*B!!;B!E
M;F-O9&EN9R!W92!D;VXG="!U;F1E<G-T86YD+"!R971U<FX@82!F875L="X@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G56YS=7!P
M;W)T960@96YC;V1I;F<L('5S92!O;F4@;V8@25-/+3@X-3DM,2P@55,M05-#
M24DL(%541BTX)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1H:7,M/G-O87!F875L="D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G-O87!F875L="T^9V5T1F%U;'0H*3L*("`@("`@("!]"@H@
M("`@("`@("1C;&EE;G0@/28@;F5W(%-/05!?0VQI96YT*&YU;&PI.PH*("`@
M("`@("!R971U<FX@)&-L:65N="T^7U]P87)S92@D9&%T82P@)'1H:7,M/GAM
M;%]E;F-O9&EN9RP@)'1H:7,M/F%T=&%C:&UE;G1S*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!S97)V:6-E*"8D9&%T82P@)&5N9'!O:6YT(#T@)R<L("1S96YD
M7W)E<W!O;G-E(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@)&1U;7`@
M/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^96YD<&]I;G0@/2`D96YD
M<&]I;G0["B`@("`@("`@)&%T=&%C:&UE;G1S(#T@87)R87DH*3L*("`@("`@
M("`D:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@("`@("\J($EF(&YE:71H97(@
M;6%T8VAE<RP@=V4G;&P@:G5S="!T<GD@:70@86YY=V%Y+B`J+PH@("`@("`@
M(&EF("AS=')I<W1R*"1D871A+"`G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO
M;B]D:6UE)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D96-O9&5$24U%365S
M<V%G92@D9&%T82P@)'1H:7,M/FAE861E<G,L("1A='1A8VAM96YT<RD["B`@
M("`@("`@("`@("1U<V5%;F-O9&EN9R`]("=$24U%)SL*("`@("`@("!](&5L
M<V5I9B`H<W1R:7-T<B@D9&%T82P@)TU)344M5F5R<VEO;CHG*2D@>PH@("`@
M("`@("`@("`O*B!4:&ES(&ES(&$@;6EM92!M97-S86=E+"!L970G<R!D96-O
M9&4@:70N("HO"B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E36EM94UE<W-A
M9V4H)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H;65N=',I.PH@("`@
M("`@("`@("`D=7-E16YC;V1I;F<@/2`G36EM92<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH@5&AE(&]L9"!F86QL8F%C:RP@8G5T(&1E8V]D
M94UI;65-97-S86=E(&AA;F1L97,@=&AI;F=S(&9I;F4N("HO"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R<V5%;6%I;"@D9&%T82D["B`@("`@("`@?0H*("`@
M("`@("`O*B!'970@=&AE(&-H87)A8W1E<B!E;F-O9&EN9R!O9B!T:&4@:6YC
M;VUI;F<@<F5Q=65S="!T<F5A="!I;F-O;6EN9PH@("`@("`@("`J(&1A=&$@
M87,@551&+3@@:68@;F\@96YC;V1I;F<@<V5T+B`J+PH@("`@("`@(&EF("@A
M)')E<W!O;G-E("8F"B`@("`@("`@("`@("$D=&AI<RT^7V=E=$-O;G1E;G1%
M;F-O9&EN9R@D=&AI<RT^:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2!33T%07T1%1D%53%1?
M14Y#3T1)3D<["B`@("`@("`@("`@("\J($%N(&5N8V]D:6YG('=E(&1O;B=T
M('5N9&5R<W1A;F0L(')E='5R;B!A(&9A=6QT+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=5;G-U<'!O<G1E9"!E;F-O9&EN9RP@
M=7-E(&]N92!O9B!)4T\M.#@U.2TQ+"!54RU!4T-)22P@551&+3@G+"`G)RP@
M)R<L("=397)V97(G*3L*("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M
M/F=E=$9A=6QT365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3YS;V%P9F%U;'0I('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H
M:7,M/G-O87!F875L="T^;65S<V%G92@I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S;V%P7VUS9R`]("1T:&ES+3YP87)S95)E<75E<W0H)&1A
M=&$L)&%T=&%C:&UE;G1S*3L*"B`@("`@("`@("`@("\J($AA;F1L92!-:6UE
M(&]R($1)344@96YC;V1I;F<N("HO"B`@("`@("`@("`@("\J(%1/1$\Z($1)
M344@16YC;V1I;F<@<VAO=6QD(&UO=F4@=&\@=&AE('1R86YS<&]R="P@9&\@
M:70@:&5R90H@("`@("`@("`@("`@*B!F;W(@;F]W(&%N9"!F;W(@96%S92!O
M9B!G971T:6YG(&ET(&1O;F4N("HO"B`@("`@("`@("`@(&EF("AC;W5N="@D
M=&AI<RT^7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@("`@("`@(&EF("@D
M=7-E16YC;V1I;F<@/3T@)TUI;64G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-O87!?;7-G(#T@)'1H:7,M/E]M86ME36EM94UE<W-A9V4H)'-O87!?;7-G
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@+RH@1&5F875L="!I<R!$24U%+B`J+PH@("`@("`@("`@("`@("`@("`@
M("1S;V%P7VUS9R`]("1T:&ES+3Y?;6%K941)345-97-S86=E*"1S;V%P7VUS
M9RD["B`@("`@("`@("`@("`@("`@("`@)&AE861E<ELG0V]N=&5N="U4>7!E
M)UT@/2`G87!P;&EC871I;VXO9&EM92<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<V]A<%]M<V<I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES95-O87!&
M875L="@D<V]A<%]M<V<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'-O87!?;7-G*2D@>PH@
M("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?;7-G6R=B;V1Y)UT[
M"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'-O87!?;7-G6R=H96%D97)S
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&AE861E<G,@/2`D<V]A<%]M
M<V=;)VAE861E<G,G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7VUS
M9SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES
M+3YS96YD7W)E<W!O;G-E*2!["B`@("`@("`@("`@(&EF("@D9'5M<"D@>PH@
M("`@("`@("`@("`@("`@<')I;G0@)')E<W!O;G-E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&9R;VT@/2!A<G)A>5]K97E?97AI
M<W1S*"=R97!L>2UT;R<L("1T:&ES+3YH96%D97)S*2`_("1T:&ES+3YH96%D
M97)S6R=R97!L>2UT;R==(#H@)'1H:7,M/FAE861E<G-;)V9R;VTG73L*"B`@
M("`@("`@("`@("`@("`D<V]A<%]T<F%N<W!O<G0@/28@4T]!4%]4<F%N<W!O
M<G0Z.F=E=%1R86YS<&]R="@G;6%I;'1O.B<@+B`D9G)O;2P@)'1H:7,M/G)E
M<W!O;G-E7V5N8V]D:6YG*3L*("`@("`@("`@("`@("`@("1F<F]M(#T@)'1H
M:7,M/F5N9'!O:6YT(#\@)'1H:7,M/F5N9'!O:6YT(#H@)'1H:7,M/FAE861E
M<G-;)W1O)UT["B`@("`@("`@("`@("`@("`D:&5A9&5R<ULG26XM4F5P;'DM
M5&\G72`]("1T:&ES+3YH96%D97)S6R=M97-S86=E+6ED)UT["B`@("`@("`@
M("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"=F<F]M)R`]/B`D9G)O;2P@)W-U
M8FIE8W0G(#T^("1T:&ES+3YH96%D97)S6R=S=6)J96-T)UTL("=H96%D97)S
M)R`]/B`D:&5A9&5R<RD["B`@("`@("`@("`@("`@("`D<V]A<%]T<F%N<W!O
M<G0M/G-E;F0H)')E<W!O;G-E+"`D;W!T:6]N<RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U-/05`O4V5R=F5R+T5M86EL7T=A=&5W87DN<&AP````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$R-34V`#$P-3$U-#,Q,#4W`#`R,C8P,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T:&4@96UA:6PM2%14
M4"!33T%0(&=A=&5W87D@<V5R=F5R+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V
M:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@(%-H86YE
M($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A
M;F0@;6]R90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U
M<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC
M92`G4T]!4"]397)V97(O16UA:6PN<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0
M+U1R86YS<&]R="YP:'`G.PH*+RHJ"B`J(%-/05`@4V5R=F5R($-L87-S('1H
M870@:6UP;&5M96YT<R!A;B!E;6%I;"!33T%0('-E<G9E<BX*("H@:'1T<#HO
M+W=W=RYP;V-K971S;V%P+F-O;2]S<&5C<R]S;71P8FEN9&EN9R\*("H*("H@
M5&AI<R!C;&%S<R!O=F5R<FED97,@=&AE(&1E9F%U;'0@2%144"!S97)V97(L
M('!R;W9I9&EN9R!T:&4@86)I;&ET>2!T;PH@*B!P87)S92!A;B!E;6%I;"!M
M97-S86=E(&%N9"!E>&5C=71E('-O87`@8V%L;',N("!4:&ES(&-L87-S($1/
M15,@3D]4('!O<"!T:&4*("H@;65S<V%G93L@=&AE(&UE<W-A9V4L(&-O;7!L
M971E('=I=&@@:&5A9&5R<RP@;75S="!B92!P87-S960@:6X@87,@80H@*B!P
M87)A;65T97(@=&\@=&AE('-E<G9I8V4@9G5N8W1I;VX@8V%L;"X*("H*("H@
M5&AI<R!C;&%S<R!C86QL<R!A('!R;W9I9&5D($A45%`@4T]!4"!S97)V97(L
M(&9O<G=A<F1I;F<@=&AE(&5M86EL(')E<75E<W0L"B`J('1H96X@<V5N9&EN
M9R!T:&4@2%144"!R97-P;VYS92!O=70@87,@86X@96UA:6PN"B`J"B`J($!A
M8V-E<W,@("!P=6)L:6,*("H@0'!A8VMA9V4@(%-/05`*("H@0&%U=&AO<B`@
M(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^"B`J+PIC;&%S<R!33T%0
M7U-E<G9E<E]%;6%I;%]'871E=V%Y(&5X=&5N9',@4T]!4%]397)V97)?16UA
M:6P@>PH*("`@('9A<B`D9V%T97=A>2`](&YU;&P["B`@("!V87(@)&1U;7`@
M/2!F86QS93L*"B`@("!F=6YC=&EO;B!33T%07U-E<G9E<E]%;6%I;%]'871E
M=V%Y*"1G871E=V%Y(#T@)R<L("1S96YD7W)E<W!O;G-E(#T@=')U92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1U;7`@/2!F
M86QS92D*("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?4V5R=F5R*"D["B`@
M("`@("`@)'1H:7,M/G-E;F1?<F5S<&]N<V4@/2`D<V5N9%]R97-P;VYS93L*
M("`@("`@("`D=&AI<RT^9V%T97=A>2`]("1G871E=V%Y.PH@("`@("`@("1T
M:&ES+3YD=6UP(#T@)&1U;7`["B`@("!]"@H@("`@9G5N8W1I;VX@<V5R=FEC
M92@F)&1A=&$L("1G871E=V%Y(#T@)R<L("1E;F1P;VEN="`]("<G+`H@("`@
M("`@("`@("`@("`@("`@("`D<V5N9%]R97-P;VYS92`]('1R=64L("1D=6UP
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F5N9'!O:6YT(#T@)&5N
M9'!O:6YT.PH@("`@("`@("1R97-P;VYS92`]("<G.PH@("`@("`@("1U<V5%
M;F-O9&EN9R`]("=-:6UE)SL*("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*"$D9V%T97=A>2D@>PH@("`@("`@("`@("`D9V%T97=A
M>2`]("1T:&ES+3YG871E=V%Y.PH@("`@("`@('T*"B`@("`@("`@+RH@5V4@
M:&%V92!A(&9U;&P@<V5T(&]F(&AE861E<G,L(&YE960@=&\@9FEN9"!T:&4@
M9FER<W0@8FQA;FL*("`@("`@("`@*B!L:6YE+B`J+PH@("`@("`@("1T:&ES
M+3Y?<&%R<V5%;6%I;"@D9&%T82D["B`@("`@("`@:68@*"1T:&ES+3YF875L
M="D@>PH@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^9F%U;'0M/FUE
M<W-A9V4H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YH96%D97)S
M6R=C;VYT96YT+71Y<&4G72`]/2`G87!P;&EC871I;VXO9&EM92<I"B`@("`@
M("`@("`@("1U<V5%;F-O9&EN9R`]("=$24U%)SL*"B`@("`@("`@+RH@0V%L
M;"!T:&4@2%144"!397)V97(N("HO"B`@("`@("`@:68@*"$D<F5S<&]N<V4I
M('L*("`@("`@("`@("`@)'-O87!?=')A;G-P;W)T(#TF(%-/05!?5')A;G-P
M;W)T.CIG9714<F%N<W!O<G0H)&=A=&5W87DL("1T:&ES+3YX;6Q?96YC;V1I
M;F<I.PH@("`@("`@("`@("!I9B`H)'-O87!?=')A;G-P;W)T+3YF875L="D@
M>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?=')A;G-P;W)T
M+3YF875L="T^;65S<V%G92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!396YD('1H92!M97-S86=E+B`J+PH@("`@("`@(&EF("@A
M)')E<W!O;G-E*2!["B`@("`@("`@("`@("1O<'1I;VYS6R=S;V%P86-T:6]N
M)UT@/2`D=&AI<RT^:&5A9&5R<ULG<V]A<&%C=&EO;B==.PH@("`@("`@("`@
M("`D;W!T:6]N<ULG:&5A9&5R<R==6R=#;VYT96YT+51Y<&4G72`]("1T:&ES
M+3YH96%D97)S6R=C;VYT96YT+71Y<&4G73L*"B`@("`@("`@("`@("1R97-P
M;VYS92`]("1S;V%P7W1R86YS<&]R="T^<V5N9"@D9&%T82P@)&]P=&EO;G,I
M.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/FAE861E<G-;)VUI;64M
M=F5R<VEO;B==*2D*("`@("`@("`@("`@("`@("1O<'1I;VYS6R=H96%D97)S
M)UU;)TU)344M5F5R<VEO;B==(#T@)'1H:7,M/FAE861E<G-;)VUI;64M=F5R
M<VEO;B==.PH*("`@("`@("`@("`@:68@*"1S;V%P7W1R86YS<&]R="T^9F%U
M;'0I('L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7W1R86YS
M<&]R="T^9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S;V%P7W1R86YS<&]R="T^=')A
M;G-P;W)T+3YA='1A8VAM96YT<R!A<R`D8VED(#T^("1B;V1Y*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F%T=&%C:&UE;G1S6UT@/2!A<G)A>2@G
M8F]D>2<@/3X@)&)O9'DL("=C:60G(#T^("1C:60L("=E;F-O9&EN9R<@/3X@
M)V)A<V4V-"<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1T:&ES+3Y?7V%T=&%C:&UE;G1S*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D=7-E16YC;V1I;F<@/3T@)TUI;64G*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1S;V%P7VUS9R`]("1T:&ES+3Y?;6%K94UI
M;65-97-S86=E*"1R97-P;VYS92D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1O<'1I;VYS6R=H96%D97)S)UU;)TU)344M5F5R<VEO;B==(#T@)S$N,"<[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@+RH@1&5F875L="!I<R!$24U%+B`J+PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<V]A<%]M<V<@/2`D=&AI<RT^7VUA:V5$24U%365S<V%G
M92@D<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N
M<ULG:&5A9&5R<R==6R=#;VYT96YT+51Y<&4G72`]("=A<'!L:6-A=&EO;B]D
M:6UE)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D
M<V]A<%]M<V<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)'-O87!?;7-G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]M<V=;)V)O9'DG73L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1S;V%P7VUS9ULG
M:&5A9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1O<'1I;VYS6R=H96%D97)S)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;)VAE861E<G,G72`](&%R<F%Y
M7VUE<F=E*"1O<'1I;VYS6R=H96%D97)S)UTL("1S;V%P7VUS9ULG:&5A9&5R
M<R==*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;)VAE861E
M<G,G72`]("1S;V%P7VUS9ULG:&5A9&5R<R==.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/G-E;F1?<F5S<&]N
M<V4I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YD=6UP('Q\("1D=6UP*2![
M"B`@("`@("`@("`@("`@("!P<FEN="`D<F5S<&]N<V4["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D9G)O;2`](&%R<F%Y7VME>5]E
M>&ES=',H)W)E<&QY+71O)RP@)'1H:7,M/FAE861E<G,I(#\@)'1H:7,M/FAE
M861E<G-;)W)E<&QY+71O)UT@.B`D=&AI<RT^:&5A9&5R<ULG9G)O;2==.PH*
M("`@("`@("`@("`@("`@("1S;V%P7W1R86YS<&]R="`])B!33T%07U1R86YS
M<&]R=#HZ9V5T5')A;G-P;W)T*"=M86EL=&\Z)R`N("1F<F]M+"`D=&AI<RT^
M<F5S<&]N<V5?96YC;V1I;F<I.PH@("`@("`@("`@("`@("`@)&9R;VT@/2`D
M=&AI<RT^96YD<&]I;G0@/R`D=&AI<RT^96YD<&]I;G0@.B`D=&AI<RT^:&5A
M9&5R<ULG=&\G73L*("`@("`@("`@("`@("`@("1H96%D97)S(#T@87)R87DH
M)TEN+5)E<&QY+51O)R`]/B`D=&AI<RT^:&5A9&5R<ULG;65S<V%G92UI9"==
M*3L*("`@("`@("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH)V9R;VTG(#T^
M("1F<F]M+"`G<W5B:F5C="<]/B`D=&AI<RT^:&5A9&5R<ULG<W5B:F5C="==
M+"`G:&5A9&5R<R<@/3X@)&AE861E<G,I.PH@("`@("`@("`@("`@("`@)'-O
M87!?=')A;G-P;W)T+3YS96YD*"1R97-P;VYS92P@)&]P=&EO;G,I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O5'EP92\`````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#4W`#`Q-S`R-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!
M4"]4>7!E+V1U<F%T:6]N+G!H<```````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3,T,#8`,3`U,34T,S$P-3<`,#(Q,S8V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J"FAT='`Z+R]W
M=W<N=S,N;W)G+U12+WAM;'-C:&5M82TR+PH*6T1E9FEN:71I;VXZ72`@(&1U
M<F%T:6]N(')E<')E<V5N=',@82!D=7)A=&EO;B!O9B!T:6UE+B!4:&4@=F%L
M=64@<W!A8V4@;V8*9'5R871I;VX@:7,@82!S:7@M9&EM96YS:6]N86P@<W!A
M8V4@=VAE<F4@=&AE(&-O;W)D:6YA=&5S(&1E<VEG;F%T92!T:&4*1W)E9V]R
M:6%N('EE87(L(&UO;G1H+"!D87DL(&AO=7(L(&UI;G5T92P@86YD('-E8V]N
M9"!C;VUP;VYE;G1S"F1E9FEN960@:6X@(#4N-2XS+C(@;V8@6TE33R`X-C`Q
M72P@<F5S<&5C=&EV96QY+B!4:&5S92!C;VUP;VYE;G1S(&%R90IO<F1E<F5D
M(&EN('1H96ER('-I9VYI9FEC86YC92!B>2!T:&5I<B!O<F1E<B!O9B!A<'!E
M87)A;F-E(&DN92X@87,@>65A<BP*;6]N=&@L(&1A>2P@:&]U<BP@;6EN=71E
M+"!A;F0@<V5C;VYD+B`*"C,N,BXV+C$@3&5X:6-A;"!R97!R97-E;G1A=&EO
M;@I4:&4@;&5X:6-A;"!R97!R97-E;G1A=&EO;B!F;W(@9'5R871I;VX@:7,@
M=&AE(%M)4T\@.#8P,5T@97AT96YD960*9F]R;6%T(%!N66X@36Y$5&Y((&Y-
M;E,L('=H97)E(&Y9(')E<')E<V5N=',@=&AE(&YU;6)E<B!O9@IY96%R<RP@
M;DT@=&AE(&YU;6)E<B!O9B!M;VYT:',L(&Y$('1H92!N=6UB97(@;V8@9&%Y
M<RP@)U0G(&ES('1H90ID871E+W1I;64@<V5P87)A=&]R+"!N2"!T:&4@;G5M
M8F5R(&]F(&AO=7)S+"!N32!T:&4@;G5M8F5R(&]F"FUI;G5T97,@86YD(&Y3
M('1H92!N=6UB97(@;V8@<V5C;VYD<RX@5&AE(&YU;6)E<B!O9B!S96-O;F1S
M"F-A;B!I;F-L=61E(&1E8VEM86P@9&EG:71S('1O(&%R8FET<F%R>2!P<F5C
M:7-I;VXN"@I4:&4@=F%L=65S(&]F('1H92!996%R+"!-;VYT:"P@1&%Y+"!(
M;W5R(&%N9"!-:6YU=&5S(&-O;7!O;F5N=',*87)E(&YO="!R97-T<FEC=&5D
M(&)U="!A;&QO=R!A;B!A<F)I=')A<GD@:6YT96=E<BX@4VEM:6QA<FQY+"!T
M:&4*=F%L=64@;V8@=&AE(%-E8V]N9',@8V]M<&]N96YT(&%L;&]W<R!A;B!A
M<F)I=')A<GD@9&5C:6UA;"X*5&AU<RP@=&AE(&QE>&EC86P@<F5P<F5S96YT
M871I;VX@;V8@9'5R871I;VX@9&]E<R!N;W0@9F]L;&]W('1H90IA;'1E<FYA
M=&EV92!F;W)M870@;V8@(#4N-2XS+C(N,2!O9B!;25-/(#@V,#%=+@H*06X@
M;W!T:6]N86P@<')E8V5D:6YG(&UI;G5S('-I9VX@*"<M)RD@:7,@86QL;W=E
M9"P@=&\@:6YD:6-A=&4@80IN96=A=&EV92!D=7)A=&EO;BX@268@=&AE('-I
M9VX@:7,@;VUI='1E9"!A('!O<VET:79E(&1U<F%T:6]N(&ES"FEN9&EC871E
M9"X@4V5E(&%L<V\@25-/(#@V,#$@1&%T92!A;F0@5&EM92!&;W)M871S("A$
M*2X@"@I&;W(@97AA;7!L92P@=&\@:6YD:6-A=&4@82!D=7)A=&EO;B!O9B`Q
M('EE87(L(#(@;6]N=&AS+"`S(&1A>7,L"C$P(&AO=7)S+"!A;F0@,S`@;6EN
M=71E<RP@;VYE('=O=6QD('=R:71E.B!0,5DR33-$5#$P2#,P32X*3VYE(&-O
M=6QD(&%L<V\@:6YD:6-A=&4@82!D=7)A=&EO;B!O9B!M:6YU<R`Q,C`@9&%Y
M<R!A<SH@+5`Q,C!$+B`*"E)E9'5C960@<')E8VES:6]N(&%N9"!T<G5N8V%T
M960@<F5P<F5S96YT871I;VYS(&]F('1H:7,@9F]R;6%T"F%R92!A;&QO=V5D
M('!R;W9I9&5D('1H97D@8V]N9F]R;2!T;R!T:&4@9F]L;&]W:6YG.B`*"DEF
M('1H92!N=6UB97(@;V8@>65A<G,L(&UO;G1H<RP@9&%Y<RP@:&]U<G,L(&UI
M;G5T97,L(&]R('-E8V]N9',*:6X@86YY(&5X<')E<W-I;VX@97%U86QS('IE
M<F\L('1H92!N=6UB97(@86YD(&ET<R!C;W)R97-P;VYD:6YG"F1E<VEG;F%T
M;W(@*FUA>2H@8F4@;VUI='1E9"X@2&]W979E<BP@870@;&5A<W0@;VYE(&YU
M;6)E<B!A;F0*:71S(&1E<VEG;F%T;W(@*FUU<W0J(&)E('!R97-E;G0N(`I4
M:&4@<V5C;VYD<R!P87)T("IM87DJ(&AA=F4@82!D96-I;6%L(&9R86-T:6]N
M+B`*5&AE(&1E<VEG;F%T;W(@)U0G('-H86QL(&)E(&%B<V5N="!I9B!A;&P@
M;V8@=&AE('1I;64@:71E;7,@87)E(&%B<V5N="X*5&AE(&1E<VEG;F%T;W(@
M)U`G(&UU<W0@86QW87ES(&)E('!R97-E;G0N(`I&;W(@97AA;7!L92P@4#$S
M-#=9+"!0,3,T-TT@86YD(%`Q63)-5#)((&%R92!A;&P@86QL;W=E9#L@4#!9
M,3,T-TT*86YD(%`P63$S-#=-,$0@87)E(&%L;&]W960N(%`M,3,T-TT@:7,@
M;F]T(&%L;&]W960@86QT:&]U9V@@+5`Q,S0W30II<R!A;&QO=V5D+B!0,5DR
M350@:7,@;F]T(&%L;&]W960N(`H**B\*"B\J('1H:7,@:7,@;VYL>2!A;B!A
M<')O>&EM871I;VX@;V8@9'5R871I;VXL(&UO<F4@=V]R:R!S=&EL;"!T;R!D
M;RX*("`@<V5E(&%B;W9E('-C:&5M82!U<FP@9F]R(&UO<F4@:6YF;R!O;B!D
M=7)A=&EO;@H@("`*("`@5$]$3SH@9FEG=7)E(&]U="!B97-T(&%P<F]X:6UA
M=&EO;B!F;W(@>65A<B!A;F0@;6]N=&@@8V]N=F5R<VEO;B!T;R!S96-O;F1S
M"BHO"B`@(`HD97)E9U]D=7)A=&EO;B`]("<H+2D_4"A;,"TY72M9*3\H6S`M
M.5TK32D_*%LP+3E=*T0I/U0_*%LP+3E=*T@I/RA;,"TY72M-*3\H6S`M.5TK
M4RD_)SL*8VQA<W,@4T]!4%]4>7!E7V1U<F%T:6]N"GL*("`@("\O(&9O<FUA
M="!0;EEN36Y$5&Y(;DUN4PH@("`@9G5N8W1I;VX@=6YI>%]T;U]D=7)A=&EO
M;B@D<V5C;VYD<RD@>PH@("`@("`@(')E='5R;B!33T%07U1Y<&5?9'5R871I
M;VXZ.F=E=&1U<F%T:6]N*"1S96-O;F1S*3L*("`@('T*("`@(`H@("`@9G5N
M8W1I;VX@;6]D*"1A+"`D8BP@)B1D+"`F)'(I('L*("`@("`@("`D9"`](&9L
M;V]R*"`D82`O("1B("D["B`@("`@("`@)'(@/2`D82`E("1B.PH@("`@?0H@
M("`@"B`@("!F=6YC=&EO;B!G971D=7)A=&EO;B@D<V5C;VYD<RD@>PH@("`@
M("`@("1N96<@/2`G)SL*("`@("`@("!I9B`H)'-E8V]N9',@/"`P*2!["B`@
M("`@("`@("`@("1N96<@/2`G+2<["B`@("`@("`@("`@("1S96-O;F1S(#T@
M)'-E8V]N9',@*B`M,3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)%]M
M:2`](#8P.PH@("`@("`@("1?:"`]("1?;6D@*B`V,#L*("`@("`@("`D7V0@
M/2`D7V@@*B`R-#L*("`@("`@("`O+R!86%@@:&]W(&1O('=E('!R;W!E<FQY
M(&AA;F1L92!M;VYT:"!A;F0@>65A<B!V86QU97,_"B`@("`@("`@)%]M(#T@
M)%]D("H@,S`["B`@("`@("`@)%]Y(#T@)%]D("H@,S8U.PH*("`@("`@("!3
M3T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D<V5C;VYD<RP@)%]Y+"`D>2P@)'-E
M8V]N9',I.PH@("`@("`@(%-/05!?5'EP95]D=7)A=&EO;CHZ;6]D*"1S96-O
M;F1S+"`D7VTL("1M+"`D<V5C;VYD<RD["B`@("`@("`@4T]!4%]4>7!E7V1U
M<F%T:6]N.CIM;V0H)'-E8V]N9',L("1?9"P@)&0L("1S96-O;F1S*3L*("`@
M("`@("!33T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D<V5C;VYD<RP@)%]H+"`D
M:"P@)'-E8V]N9',I.PH@("`@("`@(%-/05!?5'EP95]D=7)A=&EO;CHZ;6]D
M*"1S96-O;F1S+"`D7VUI+"`D;6DL("1S*3L*("`@("`@("`*("`@("`@("`D
M9'5R871I;VX@/2`D;F5G+B=0)SL*("`@("`@("!I9B`H)'DI("1D=7)A=&EO
M;B`N/2`D>2XG62<["B`@("`@("`@:68@*"1M*2`D9'5R871I;VX@+CT@)&TN
M)TTG.PH@("`@("`@(&EF("@D9"D@)&1U<F%T:6]N("X]("1D+B=$)SL*("`@
M("`@("!I9B`H)&@@?'P@)&UI('Q\("1S*2`D9'5R871I;VX@+CTG5"<["B`@
M("`@("`@:68@*"1H*2`D9'5R871I;VX@+CT@)&@N)T@G.PH@("`@("`@(&EF
M("@D;6DI("1D=7)A=&EO;B`N/2`D;6DN)TTG.PH@("`@("`@(&EF("@D<RD@
M)&1U<F%T:6]N("X]("1S+B=3)SL*("`@("`@("!I9B`H)&1U<F%T:6]N(#T]
M("=0)R!\?"`D9'5R871I;VX@/3T@)RU0)RD@)&1U<F%T:6]N(#T@)U!4,%,G
M.PH@("`@("`@(')E='5R;B`D9'5R871I;VX["B`@("!]"B`@("`*("`@(&9U
M;F-T:6]N(&UK9'5R871I;VXH)&XL("19+"`D36\L("1$+"`D2"P@)$UI+"`D
M4RD@>PH@("`@("`@("1?;6D@/2`V,#L*("`@("`@("`D7V@@/2`D7VUI("H@
M-C`["B`@("`@("`@)%]D(#T@)%]H("H@,C0["B`@("`@("`@+R\@6%A8(&AO
M=R!D;R!W92!P<F]P97)L>2!H86YD;&4@;6]N=&@@86YD('EE87(@=F%L=65S
M/PH@("`@("`@("1?;2`]("1?9"`J(#,P.PH@("`@("`@("1?>2`]("1?9"`J
M(#,V-3L*("`@("`@("`*("`@("`@("`D<V5C(#T@)%D@*B`D7WD@*R`D36\@
M*B`D7VT@*R`D1"`J("1?9"`K("1(("H@)%]H("L@)$UI("H@)%]M:2`K("13
M.PH@("`@("`@(&EF("@D;B`]/2`G+2<I("1S96,@/2`D<V5C("H@+3$["B`@
M("`@("`@<F5T=7)N("1S96,["B`@("!]"B`@("`*("`@(&9U;F-T:6]N(&1U
M<F%T:6]N7W1O7W5N:7@H)&1U<F%T:6]N*2!["B`@("`@("`@9VQO8F%L("1E
M<F5G7V1U<F%T:6]N.PH@("`@("`@(&EF("AE<F5G*"1E<F5G7V1U<F%T:6]N
M+"1D=7)A=&EO;BPD<F5G<RDI('L*("`@("`@("`@("`@<F5T=7)N(%-/05!?
M5'EP95]D=7)A=&EO;CHZ;6MD=7)A=&EO;B@D<F5G<ULQ72P@)')E9W-;,ETL
M("1R96=S6S-=+"`D<F5G<ULT72P@)')E9W-;-5TL("1R96=S6S9=+"`D<F5G
M<ULW72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!&04Q313L*("`@('T*
M("`@(`H@("`@9G5N8W1I;VX@:7-?9'5R871I;VXH)&1U<F%T:6]N*2!["B`@
M("`@("`@9VQO8F%L("1E<F5G7V1U<F%T:6]N.PH@("`@("`@(')E='5R;B!E
M<F5G*"1E<F5G7V1U<F%T:6]N+"1D=7)A=&EO;BPD<F5G<RD["B`@("!]"B`@
M("`*("`@(&9U;F-T:6]N(%]T97-T*"1T:6UE*2!["B`@("`@("`@:68@*%-/
M05!?5'EP95]D=7)A=&EO;CHZ:7-?9'5R871I;VXH)'1I;64I*2!["B`@("`@
M("`@("`@("1T(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CID=7)A=&EO;E]T;U]U
M;FEX*"1T:6UE*3L*("`@("`@("`@("`@96-H;R`B1'5R871I;VXZ("1T:6UE
M(&ES("(N)'0N(B!S96-O;F1S7&XB.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CIU;FEX7W1O7V1U<F%T
M:6]N*"1T:6UE*3L*("`@("`@("`@("`@96-H;R`B4V5C;VYD<SH@)'1I;64@
M:7,@(BXD="XB(&1U<F%T:6]N7&XB.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'0["B`@("!]"B`@("`*("`@(&9U;F-T:6]N(&%D9"@D9#$L("1D,BD@
M>PH@("`@("`@("1S,2`](%-/05!?5'EP95]D=7)A=&EO;CHZ9'5R871I;VY?
M=&]?=6YI>"@D9#$I.PH@("`@("`@("1S,B`](%-/05!?5'EP95]D=7)A=&EO
M;CHZ9'5R871I;VY?=&]?=6YI>"@D9#(I.PH@("`@("`@(')E='5R;B!33T%0
M7U1Y<&5?9'5R871I;VXZ.G5N:7A?=&]?9'5R871I;VXH)',Q("L@)',R*3L*
M("`@('T*("`@(`H@("`@9G5N8W1I;VX@<W5B=')A8W0H)&0Q+"`D9#(I('L*
M("`@("`@("`D<S$@/2!33T%07U1Y<&5?9'5R871I;VXZ.F1U<F%T:6]N7W1O
M7W5N:7@H)&0Q*3L*("`@("`@("`D<S(@/2!33T%07U1Y<&5?9'5R871I;VXZ
M.F1U<F%T:6]N7W1O7W5N:7@H)&0R*3L*("`@("`@("!R971U<FX@4T]!4%]4
M>7!E7V1U<F%T:6]N.CIU;FEX7W1O7V1U<F%T:6]N*"1S,2`M("1S,BD["B`@
M("!]"@I]"@HO*B!T97-T<R`J+PH*)'0@/2!33T%07U1Y<&5?9'5R871I;VXZ
M.E]T97-T*"=0,5DR33-$5#$P2#,P32<I.PI33T%07U1Y<&5?9'5R871I;VXZ
M.E]T97-T*"1T*3L*)'0@/2!33T%07U1Y<&5?9'5R871I;VXZ.E]T97-T*"<M
M4#$R,$0G*3L*4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@D="D["@HO+R!D
M=7)A=&EO;B!S:6YC92`Q.3<P"B1T(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CI?
M=&5S="AT:6UE*"DI.PI33T%07U1Y<&5?9'5R871I;VXZ.E]T97-T*"1T*3L*
M"G!R:6YT(")!9&0@<VAO=6QD(&)E(%!4,%,Z("(N4T]!4%]4>7!E7V1U<F%T
M:6]N.CIA9&0H)RU0,3(P1"<L)U`T32<I+B)<;B(["G!R:6YT(")3=6)T<F%C
M="!S:&]U;&0@8F4@4%0P4SH@(BY33T%07U1Y<&5?9'5R871I;VXZ.G-U8G1R
M86-T*"=0,3(P1"<L)U`T32<I+B)<;B(["C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y
M<&4O:&5X0FEN87)Y+G!H<```````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S4Q,@`Q,#4Q-30S,3`U-P`P,C$T-C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@
M4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!0
M14%2(&%N9"!M;W)E("`@?`HO+R!\($%U=&AO<G,Z($1I971R:6-H($%Y86QA
M(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<B`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@
M:&5X0FEN87)Y+G!H<"QV(#$N-B`R,#`U+S`S+S$P(#(S.C$V.C,Y('EU;F]S
M:"!%>'`@)`HO+PIC;&%S<R!33T%07U1Y<&5?:&5X0FEN87)Y"GL*("`@(&9U
M;F-T:6]N('1O7V)I;B@D=F%L=64I"B`@("!["B`@("`@("`@)&QE;B`]('-T
M<FQE;B@D=F%L=64I.PH@("`@("`@(')E='5R;B!P86-K*"=()R`N("1L96XL
M("1V86QU92D["B`@("!]"B`@("!F=6YC=&EO;B!T;U]H97@H)'9A;'5E*0H@
M("`@>PH@("`@("`@(')E='5R;B!B:6XR:&5X*"1V86QU92D["B`@("!]"B`@
M("!F=6YC=&EO;B!I<U]H97AB:6XH)'9A;'5E*0H@("`@>PH@("`@("`@(",@
M9FER<W0@<V5E(&EF('1H97)E(&%R92!A;GD@:6YV86QI9"!C:&%R<PH@("`@
M("`@("1L(#T@<W1R;&5N*"1V86QU92D["@H@("`@("`@(&EF("@D;"`\(#$@
M?'P@<W1R<W!N*"1V86QU92P@)S`Q,C,T-38W.#E!0D-$149A8F-D968G*2`A
M/2`D;"D@<F5T=7)N($9!3%-%.PH*("`@("`@("`D8FEN(#T@4T]!4%]4>7!E
M7VAE>$)I;F%R>3HZ=&]?8FEN*"1V86QU92D["B`@("`@("`@)&AE>"`](%-/
M05!?5'EP95]H97A":6YA<GDZ.G1O7VAE>"@D8FEN*3L*("`@("`@("!R971U
M<FX@<W1R8V%S96-M<"@D=F%L=64L("1H97@I(#T](#`["B`@("!]"GT*"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E+V1A
M=&54:6UE+G!H<```````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(U
M-#``,3`U,34T,S$P-3<`,#(Q,C<S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE
M($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A
M;F0@;6]R92`@('P*+R\@?"!!=71H;W)S.B!$:65T<FEC:"!!>6%L82`\9&EE
M=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&1A=&54
M:6UE+G!H<"QV(#$N-R`R,#`U+S`S+S$P(#(S.C$V.C,Y('EU;F]S:"!%>'`@
M)`HO+PIC;&%S<R!33T%07U1Y<&5?9&%T951I;64*>PH@("`@=F%R("1E<F5G
M7VES;S@V,#$@/2`G*"T_6S`M.5U[-'TI+2A;,"TY77LR?2DM*%LP+3E=>S)]
M*50H6S`M.5U[,GTI.BA;,"TY77LR?2DZ*%LP+3E=>S)]*2A<+ELP+3E=*BD_
M*%I\6RM<+5U;,"TY77LT?7Q;*UPM75LP+3E=>S)].ELP+3E=>S)]*3\G.PH@
M("`@("`@(",B*"T_6S`M.5U[-'TI+2(N("`O+R!C96YT=7)I97,@)B!Y96%R
M<R!#0UE9+0H@("`@("`@(",B*%LP+3E=>S)]*2TB+B`@+R\@;6]N=&AS($U-
M+0H@("`@("`@(",B*%LP+3E=>S)]*2(N("`@("\O(&1A>7,@1$0*("`@("`@
M("`C(E0B+B`@("`@("`@("`@("`@("`@("`@+R\@<V5P87)A=&]R(%0*("`@
M("`@("`C(BA;,"TY77LR?2DZ(BX@("\O(&AO=7)S(&AH.@H@("`@("`@(",B
M*%LP+3E=>S)]*3HB+B`@+R\@;6EN=71E<R!M;3H*("`@("`@("`C(BA;,"TY
M77LR?2DH7"Y;,"TY72HI/R(N("\O('-E8V]N9',@<W,N<W,N+BX*("`@("`@
M("`C(BA:?%LK7"U=6S`M.5U[-'U\6RM<+5U;,"TY77LR?3I;,"TY77LR?2D_
M(CL@+R\@6B!T;R!I;F1I8V%T92!55$,L("TO*TA(.DU-.E-3+E-3+BXN(&9O
M<B!L;V-A;"!T>B=S"B`@("`@("`@(R!I9B!N;R`X=&@@<F5G("A:*2!A<W-U
M;65S(%540PH@("`@=F%R("1T:6UE<W1A;7`@/2`M,3L*("`@(`H@("`@9G5N
M8W1I;VX@4T]!4%]4>7!E7V1A=&54:6UE*"1D871E(#T@+3$I"B`@("!["B`@
M("`@("`@:68@*"1D871E(#T]("TQ*2`D9&%T92`]('1I;64H*3L*"B`@("`@
M("`@:68@*&=E='1Y<&4H)&1A=&4I(#T]("=I;G1E9V5R)RD@>PH@("`@("`@
M("`@("`D=&AI<RT^=&EM97-T86UP(#T@)&1A=&4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/G1I;65S=&%M<"`]("1T:&ES+3YT;U5N
M:7AT:6UE*"1D871E*3L*("`@("`@("!]"B`@("!]"B`@("`*("`@(&9U;F-T
M:6]N('1O4T]!4"@D9&%T92`]($Y53$PI"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YT;U540R@D9&%T92D["B`@("!]"B`@("`*("`@(&9U;F-T:6]N
M('1O4W1R:6YG*"1T:6UE<W1A;7`@/2`P*0H@("`@>PH@("`@("`@(&EF("@A
M)'1I;65S=&%M<"D@)'1I;65S=&%M<"`]("1T:&ES+3YT:6UE<W1A;7`["B`@
M("`@("`@:68@*"1T:6UE<W1A;7`@/"`P*2!R971U<FX@,#L*"B`@("`@("`@
M<F5T=7)N(&1A=&4H)UDM;2UD7%1(.FDZ<T\G+"1T:6UE<W1A;7`I.PH@("`@
M?0H@("`@"B`@("!F=6YC=&EO;B!?<W!L:70H)&1A=&5S='(I"B`@("!["B`@
M("`@("`@:68@*"$D9&%T97-T<BD*("`@("`@("`@("`@)&1A=&5S='(@/2`D
M=&AI<RT^=&]3=')I;F<H*3L*("`@("`@("!E;'-E(&EF("AG971T>7!E*"1D
M871E<W1R*2`]/2`G:6YT96=E<B<I"B`@("`@("`@("`@("1D871E<W1R(#T@
M)'1H:7,M/G1O4W1R:6YG*"1D871E<W1R*3L*("`@("`@("`@("`@"B`@("`@
M("`@:68@*&5R96<H)'1H:7,M/F5R96=?:7-O.#8P,2PD9&%T97-T<BPD<F5G
M<RDI('L*("`@("`@("`@("`@:68@*"1R96=S6SA=("$]("<G("8F("1R96=S
M6SA=("$]("=:)RD@>PH@("`@("`@("`@("`@("`@)&]P(#T@<W5B<W1R*"1R
M96=S6SA=+#`L,2D["B`@("`@("`@("`@("`@("`D:"`]('-U8G-T<B@D<F5G
M<ULX72PQ+#(I.PH@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D<F5G<ULX
M72PG.B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&T@/2!S=6)S='(H)')E
M9W-;.%TL-"PR*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&T@/2!S=6)S='(H)')E9W-;.%TL,RPR*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D;W`@/3T@)RLG*2![
M"B`@("`@("`@("`@("`@("`@("`@)')E9W-;-%T@/2`D<F5G<ULT72`M("1H
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5G<ULT72`\(#`I("1R96=S
M6S1=("L](#(T.PH@("`@("`@("`@("`@("`@("`@("1R96=S6S5=(#T@)')E
M9W-;-5T@+2`D;3L*("`@("`@("`@("`@("`@("`@("!I9B`H)')E9W-;-5T@
M/"`P*2`D<F5G<ULU72`K/2`V,#L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)')E9W-;-%T@/2`D<F5G<ULT72`K("1H
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5G<ULT72`^(#(S*2`D<F5G
M<ULT72`M/2`R-#L*("`@("`@("`@("`@("`@("`@("`D<F5G<ULU72`]("1R
M96=S6S5=("L@)&T["B`@("`@("`@("`@("`@("`@("`@:68@*"1R96=S6S5=
M(#X@-3DI("1R96=S6S5=("T](#8P.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5G<SL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@?0H@("`@"B`@("!F=6YC=&EO
M;B!T;U540R@D9&%T97-T<B`]($Y53$PI"B`@("!["B`@("`@("`@)')E9W,@
M/2`D=&AI<RT^7W-P;&ET*"1D871E<W1R*3L*"B`@("`@("`@:68@*"1R96=S
M*2!["B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"<E,#1D+24P,F0M)3`R
M9%0E,#)D.B4P,F0Z)3`R9%HG+"1R96=S6S%=+"1R96=S6S)=+"1R96=S6S-=
M+"1R96=S6S1=+"1R96=S6S5=+"1R96=S6S9=*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!T;U5N:7AT:6UE
M*"1D871E<W1R(#T@3E5,3"D*("`@('L*("`@("`@("`D<F5G<R`]("1T:&ES
M+3Y?<W!L:70H)&1A=&5S='(I.PH@("`@("`@(&EF("@D<F5G<RD@>PH@("`@
M("`@("`@("!R971U<FX@<W1R=&]T:6UE*"(D<F5G<ULQ72TD<F5G<ULR72TD
M<F5G<ULS72`D<F5G<ULT73HD<F5G<ULU73HD<F5G<ULV75HB*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H*("`@(&9U;F-T:6]N(&-O
M;7!A<F4H)&1A=&4Q+"`D9&%T93(@/2!.54Q,*0H@("`@>PH@("`@("`@(&EF
M("@D9&%T93(@/3T](&YU;&PI('L*("`@("`@("`@("`@)&1A=&4R(#T@)&1A
M=&4Q.PH@("`@("`@("`@("`D9&%T93$@/2`D=&AI<RT^=&EM97-T86UP.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;65R:6,H)&1A=&4Q*2D*("`@
M("`@("`@("`@)&1A=&4Q(#T@)'1H:7,M/G1O56YI>'1I;64H)&1A=&4Q*3L*
M("`@("`@("!I9B`H(6ES7VYU;65R:6,H)&1A=&4R*2D*("`@("`@("`@("`@
M)&1A=&4R(#T@)'1H:7,M/G1O56YI>'1I;64H)&1A=&4R*3L*("`@("`@("!I
M9B`H)&1A=&4Q("$]("TQ("8F("1D871E,B`A/2`M,2D@<F5T=7)N("1D871E
M,2`M("1D871E,CL*("`@("`@("!R971U<FX@+3$["B`@("!]"B`@("`*("`@
M(&9U;F-T:6]N(%]T97-T*"1O<FEG(#T@)S(P,#$M,#0M,C54,#DZ,S$Z-#$M
M,#<P,"<I"B`@("!["B`@("`@("`@)'5T8R`]("1T:&ES+3YT;U540R@D;W)I
M9RD["B`@("`@("`@)'1S,2`]("1T:&ES+3YT;U5N:7AT:6UE*"1O<FEG*3L*
M("`@("`@("`D=',R(#T@)'1H:7,M/G1O56YI>'1I;64H)'5T8RD["B`@("`@
M("`@)&(Q(#T@)'1H:7,M/G1O4W1R:6YG*"1T<S$I.PH@("`@("`@("1B,B`]
M("1T:&ES+3YT;U-T<FEN9R@D=',R*3L*("`@("`@("!P<FEN="`B;W)I9SH@
M)&]R:6=<;B(["B`@("`@("`@<')I;G0@(F]R:6<@=&]55$,Z("1U=&-<;B([
M"B`@("`@("`@<')I;G0@(F]R:6<@=',Z("1T<S%<;B(["B`@("`@("`@<')I
M;G0@(G5T8R!T<SH@)'1S,EQN(CL*("`@("`@("!P<FEN="`B;W)I9R!T<R!B
M86-K.B`D8C%<;B(["B`@("`@("`@<')I;G0@(G5T8R!T<R!B86-K.B`D8C)<
M;B(["B`@("`@("`@:68@*"1B,2`A/2`D;W)I9R!\?"`D8C(@(3T@)&]R:6<I
M('L*("`@("`@("`@("`@96-H;R`B17)R;W(@:6X@:7-O.#8P,2!C;VYV97)S
M:6]N<UQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO(")D
M871E5&EM92!/2UQN(CL*("`@("`@("!]"B`@("!]"GT*"B,@=&AE<V4@<VAO
M=6QD(&%L;"!M871C:`HC)&0@/2!N97<@4T]!4%]4>7!E7V1A=&54:6UE*"D[
M"B-E8VAO("1D+3YC;VUP87)E*"(R,#`Q+3`T+3(U5#(P.C,Q.C0Q6B(L(C(P
M,#$M,#0M,C54,C`Z,S$Z-#%:(BDN(EQN(CL*(V5C:&\@)&0M/F-O;7!A<F4H
M(C(P,#$M,#0M,C54,C`Z,S$Z-#%:(BPB,C`P,2TP-"TR-50Q,CHS,3HT,2TP
M.#`P(BDN(EQN(CL*(V5C:&\@)&0M/F-O;7!A<F4H(C(P,#$M,#0M,C54,C`Z
M,S$Z-#%:(BPB,C`P,2TP-"TR-50Q,CHS,3HT,2TP.#HP,"(I+B)<;B(["@H_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4T]!4"]T;V]L<R\`````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$W,C0V
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+W1O;VQS+V=E;G!R
M;WAY+G!H<```````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8R,P`Q
M,#4Q-30S,3`U-P`P,C$V,S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*
M<F5Q=6ER95]O;F-E("=33T%0+U=31$PN<&AP)SL*"B\J*@H@*B!G96YP<F]X
M>0H@*@H@*B!A(&-O;6UA;F0@;&EN92!T;V]L(&9O<B!G96YE<F%T:6YG(%-/
M05`@<')O>&EE<R!F<F]M(%=31$P@9FEL97,*("H*("H@9V5N<')O>'DN<&AP
M(&AT='`Z+R]S:71E+V9O;RYW<V1L(#X@9F]O+G!H<`H@*@H@*B\*"F9U;F-T
M:6]N(&1O7W=S9&PH)'5R:2D@>PH@("`@)'=S9&P@/28@;F5W(%-/05!?5U-$
M3"@D=7)I*3L*("`@('!R:6YT("1W<V1L+3YG96YE<F%T94%L;%!R;WAI97,H
M*3L*?0IE8VAO("(\/W!H<%QN7&YR97%U:7)E7V]N8V4@)U-/05`O0VQI96YT
M+G!H<"<[7&Y<;B(["F1O7W=S9&PH)%]315)615);)V%R9W8G75LQ72D["F5C
M:&\@(EQN/SXB.PH_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]397)V97(N<&AP````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S`W,S,`,3`U,34T,S$P-3<`
M,#(P,#<T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@
M9F]R('1H92!33T%0('-E<G9E<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC
M97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!$:65T<FEC
M:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*
M("H@0&%U=&AO<B`@("`@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC
M;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E"B`J($!A=71H;W(@("`@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@($UA:6YT96YA;F-E
M"B`J($!A=71H;W(@("`@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M("`@("`@($UA:6YT96YA;F-E"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4
M:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S)?,#(N='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*
M<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=3
M3T%0+T9A=6QT+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]087)S97(N<&AP
M)SL*<F5Q=6ER95]O;F-E("=33T%0+U9A;'5E+G!H<"<["G)E<75I<F5?;VYC
M92`G4T]!4"]74T1,+G!H<"<["@HO*BH*("H@4T]!4"!397)V97(@0VQA<W,*
M("H*("H@3W)I9VEN86QY(&)A<V5D(&]N(%-/05!X-"!B>2!$:65T<FEC:"!!
M>6%L80H@*B!H='1P.B\O9&EE=')I8V@N9V%N>#0N8V]M+W-O87!X-`H@*@H@
M*B!`86-C97-S("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H
M;W(@("!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N
M('1O(%!%05(@86YD('5P9&%T97,*("H@0&%U=&AO<B`@($1I971R:6-H($%Y
M86QA(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B\*
M8VQA<W,@4T]!4%]397)V97(@97AT96YD<R!33T%07T)A<V4*>PH@("`@+RHJ
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1I
M<W!A=&-H7VUA<"`](&%R<F%Y*"D[("\O(&-R96%T92!E;7!T>2!D:7-P871C
M:"!M87`*("`@('9A<B`D9&ES<&%T8VA?;V)J96-T<R`](&%R<F%Y*"D["B`@
M("!V87(@)'-O87!O8FIE8W0@/2!N=6QL.PH@("`@=F%R("1C86QL7VUE=&AO
M9&YA;64@/2!N=6QL.PH@("`@=F%R("1C86QL2&%N9&QE<B`](&YU;&P["B`@
M("!V87(@)&-A;&Q686QI9&%T:6]N(#T@=')U93L*"B`@("`O*BH*("`@("`J
M($$@;&ES="!O9B!H96%D97)S('1H870@87)E(&=O:6YG('1O(&)E('-E;G0@
M8F%C:R!T;R!T:&4@8VQI96YT+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1H96%D97)S(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)')E
M<75E<W0@/2`G)SL*"B`@("`O*BH*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9R`@6$U,+45N8V]D:6YG"B`@("`@*B\*("`@('9A<B`D>&UL7V5N8V]D:6YG
M(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH@("`@=F%R("1R97-P;VYS95]E
M;F-O9&EN9R`]("=55$8M."<["@H@("`@=F%R("1R97-U;'0@/2`G<W5C8V5S
M<V9U;"<[("\O(&9O<B!L;V=G:6YG(&EN=&5R;W`@<F5S=6QT<R!T;R!D8@H*
M("`@('9A<B`D96YD<&]I;G0@/2`G)SL@+R\@=&AE('5R:2!T;R!-12$*"B`@
M("!V87(@)'-E<G9I8V4@/2`G)SL@+R]S;V%P86-T:6]N(&AE861E<@H@("`@
M=F%R("1M971H;V1?;F%M97-P86-E(#T@;G5L;#L*("`@('9A<B`D7U]O<'1I
M;VYS(#T@87)R87DH)W5S92<@/3X@)V5N8V]D960G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<W1Y;&4G(#T^("=R<&,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%R86UE=&5R<R<@/3X@,"D["@H@("`@9G5N8W1I
M;VX@4T]!4%]397)V97(H)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@('!A<F5N=#HZ
M4T]!4%]"87-E*"=397)V97(G*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O
M<'1I;VYS*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W5S
M92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG=7-E
M)UT@/2`D;W!T:6]N<ULG=7-E)UT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S='EL92==*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G72`]("1O<'1I;VYS6R=S
M='EL92==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG<&%R86UE=&5R<R==*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]?;W!T:6]N<ULG<&%R86UE=&5R<R==(#T@)&]P=&EO;G-;)W!A<F%M
M971E<G,G73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!A
M<W-U;64@=V4@96YC;V1E('=I=&@@<V5C=&EO;B`U"B`@("`@("`@)'1H:7,M
M/E]S96-T:6]N-2`]('1R=64["B`@("`@("`@:68@*"1T:&ES+3Y?7V]P=&EO
M;G-;)W5S92==/3TG;&ET97)A;"<I('L*("`@("`@("`@("`@)'1H:7,M/E]S
M96-T:6]N-2`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($5R<F]R(&AA;F1L97(@9F]R(&5R<F]R<R!T:&%T(&AA<'!E;B!I;B!P
M<F]X:65D(&UE=&AO9',N"B`@("`@*@H@("`@("H@5&\@86QW87ES(')E='5R
M;B!A('9A;&ED(%-/05`@<F5S<&]N<V4@979E;B!O;B!E<G)O<G,@=&AA="!D
M;VXG="!H87!P96X*("`@("`J(&EN('1H:7,@8V]D92P@=&AE(&5R<F]R<R!A
M<F4@8V%T8VAE9"P@=')A;G-F;W)M960@=&\@82!33T%0(&9A=6QT(&%N9`H@
M("`@("H@:6UM961I871E;'D@<V5N="!T;R!T:&4@8VQI96YT+@H@("`@("H*
M("`@("`J($!S964@:'1T<#HO+W=W=RYP:'`N;F5T+W-E=%]E<G)O<E]H86YD
M;&5R"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E<G)O<DAA;F1L97(H)&5R<FYO
M+"`D97)R;7-G+"`D9FEL96YA;64L("1L:6YE;G5M+"`D=F%R<RD*("`@('L*
M("`@("`@("`O*B!4:&4@97)R;W(@:&%N9&QE<B!S:&]U;&0@:6=N;W)E("<P
M)R!E<G)O<G,L(&5G+B!H:61D96X@8GD@0"`M('-E90H@("`@("`@("`J('1H
M92!S971?97)R;W)?:&%N9&QE<B!M86YU86P@<&%G92X@*'1H86YK<R!T;R!!
M;&%N($MN;W=L97,I+B`J+PH@("`@("`@(&EF("@A)&5R<FYO('Q\("1E<G)N
M;R`]/2!%7TY/5$E#12D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^9F%U;'0@/28@;F5W(%-/05!?1F%U;'0H)&5R
M<FUS9RP@)U-E<G9E<B<L("=02%`G+"`B17)R;F\Z("1E<G)N;UQN1FEL96YA
M;64Z("1F:6QE;F%M95QN3&EN96YO.B`D;&EN96YU;5QN(BD["@H@("`@("`@
M("1T:&ES+3Y?<V5N9%)E<W!O;G-E*"D["B`@("`@("`@97AI=#L*("`@('T*
M"B`@("!F=6YC=&EO;B!?9V5T0V]N=&5N=$5N8V]D:6YG*"1C;VYT96YT7W1Y
M<&4I"B`@("!["B`@("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@96YC;V1I
M;F<@;V8@=&AE(&EN8V]M:6YG(')E<75E<W0@=')E870@:6YC;VUI;F<*("`@
M("`@("`@*B!D871A(&%S(%541BTX(&EF(&YO(&5N8V]D:6YG('-E="X@*B\*
M("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@)U541BTX)SL*("`@("`@
M("!I9B`H<W1R<&]S*"1C;VYT96YT7W1Y<&4L("<])RDI('L*("`@("`@("`@
M("`@)&5N8R`]('-T<G1O=7!P97(H<W1R7W)E<&QA8V4H)R(G+"`G)RP@<W5B
M<W1R*'-T<G-T<B@D8V]N=&5N=%]T>7!E+"`G/2<I+"`Q*2DI.PH@("`@("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"1E;F,L("1T:&ES+3Y?96YC;V1I;F=S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2`D96YC.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H*("`@("\J*@H@
M("`@("H@4&%R<V5S(')E<75E<W0@86YD('!O<W1S(')E<W!O;G-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S97)V:6-E*"1D871A+"`D96YD<&]I;G0@/2`G
M)RP@)'1E<W0@/2!F86QS92D*("`@('L*("`@("`@("`D<F5S<&]N<V4@/2!N
M=6QL.PH@("`@("`@("1A='1A8VAM96YT<R`](&%R<F%Y*"D["B`@("`@("`@
M)'5S945N8V]D:6YG(#T@)T1)344G.PH*("`@("`@("`O*B!&:6=U<F4@;W5T
M(&]U<B!E;F1P;VEN="X@*B\*("`@("`@("`D=&AI<RT^96YD<&]I;G0@/2`D
M96YD<&]I;G0["B`@("`@("`@:68@*"$D=&5S="`F)B`A)'1H:7,M/F5N9'!O
M:6YT*2!["B`@("`@("`@("`@("\J(%=E)VQL('1R>2!T;R!B=6EL9"!O=7(@
M96YD<&]I;G0N("HO"B`@("`@("`@("`@("1T:&ES+3YE;F1P;VEN="`]("=H
M='1P.B\O)R`N("1?4T525D526R=315)615)?3D%-12==.PH@("`@("`@("`@
M("!I9B`H)%]315)615);)U-%4E9%4E]03U)4)UTI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YE;F1P;VEN="`N/2`G.B<@+B`D7U-%4E9%4ELG4T525D52
M7U!/4E0G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^96YD
M<&]I;G0@+CT@)%]315)615);)U-#4DE05%].04U%)UT["B`@("`@("`@?0H*
M("`@("`@("`O*B!'970@=&AE(&-H87)A8W1E<B!E;F-O9&EN9R!O9B!T:&4@
M:6YC;VUI;F<@<F5Q=65S="!T<F5A="!I;F-O;6EN9PH@("`@("`@("`J(&1A
M=&$@87,@551&+3@@:68@;F\@96YC;V1I;F<@<V5T+B`J+PH@("`@("`@(&EF
M("AI<W-E="@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTI*2!["B`@("`@("`@
M("`@(&EF("AS=')C87-E8VUP*"1?4T525D526R=#3TY414Y47U194$4G72P@
M)V%P<&QI8V%T:6]N+V1I;64G*2`]/2`P*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1E8V]D941)345-97-S86=E*"1D871A+"`D:&5A9&5R<RP@)&%T
M=&%C:&UE;G1S*3L*("`@("`@("`@("`@("`@("1U<V5%;F-O9&EN9R`]("=$
M24U%)SL*("`@("`@("`@("`@?2!E;'-E:68@*'-T<FES='(H)%]315)615);
M)T-/3E1%3E1?5%E012==+"`G;75L=&EP87)T+W)E;&%T960G*2D@>PH@("`@
M("`@("`@("`@("`@+RH@5&AI<R!I<R!A(&UI;64@;65S<V%G92P@;&5T)W,@
M9&5C;V1E(&ET+B`J+PH@("`@("`@("`@("`@("`@)&1A=&$@/2`G0V]N=&5N
M="U4>7!E.B`G("X*("`@("`@("`@("`@("`@("`@("!S=')I<'-L87-H97,H
M)%]315)615);)T-/3E1%3E1?5%E012==*2`N"B`@("`@("`@("`@("`@("`@
M("`@(EQR7&Y<<EQN(B`N("1D871A.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D96-O9&5-:6UE365S<V%G92@D9&%T82P@)&AE861E<G,L("1A='1A8VAM
M96YT<RD["B`@("`@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G36EM92<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D:&5A9&5R
M<ULG8V]N=&5N="UT>7!E)UTI*2!["B`@("`@("`@("`@("`@("`D:&5A9&5R
M<ULG8V]N=&5N="UT>7!E)UT@/2!S=')I<'-L87-H97,H)%]315)615);)T-/
M3E1%3E1?5%E012==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(21T:&ES+3YF875L="`F)@H@("`@("`@("`@("`@("`@(21T:&ES+3Y?9V5T
M0V]N=&5N=$5N8V]D:6YG*"1H96%D97)S6R=C;VYT96YT+71Y<&4G72DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2!33T%07T1%
M1D%53%1?14Y#3T1)3D<["B`@("`@("`@("`@("`@("`O*B!&;W5N9"!E;F-O
M9&EN9R!W92!D;VXG="!U;F1E<G-T86YD.R!R971U<FX@82!F875L="X@*B\*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)U5N<W5P
M<&]R=&5D(&5N8V]D:6YG+"!U<V4@;VYE(&]F($E33RTX.#4Y+3$L(%53+4%3
M0TE)+"!55$8M."<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&ES(&ES(&YO="!A(%!/4U0@
M=VET:"!#;VYT96YT+51Y<&4@=&5X="]X;6PL('1R>2!T;R!R971U<FX@80H@
M("`@("`@("`J(%=31$P@9FEL92X@*B\*("`@("`@("!I9B`H(21T:&ES+3YF
M875L="`F)B`A)'1E<W0@)B8*("`@("`@("`@("`@*"1?4T525D526R=215%5
M15-47TU%5$A/1"==("$]("=03U-4)R!\?`H@("`@("`@("`@("`@<W1R;F-M
M<"@D:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTL("=T97AT+WAM;"<L(#@I("$]
M(#`I*2!["B`@("`@("`@("`@("\J(%1H:7,@:7,@;F]T('!O<W-I8FQY(&$@
M=F%L:60@4T]!4"!R97%U97-T+"!T<GD@=&\@<F5T=7)N(&$@5U-$3`H@("`@
M("`@("`@("`@*B!F:6QE+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"=);G9A;&ED(%-/05`@<F5Q=65S="P@;75S="!B92!03U-4
M('=I=&@@8V]N=&5N="UT>7!E.B!T97AT+WAM;"P@9V]T.B`G("X@*&ES<V5T
M*"1H96%D97)S6R=C;VYT96YT+71Y<&4G72D@/R`D:&5A9&5R<ULG8V]N=&5N
M="UT>7!E)UT@.B`G3F]T:&EN9R$G*2P@)R<L("<G+"`G4V5R=F5R)RD["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YF875L="D@>PH@("`@("`@
M("`@("`O*B`D<F5S<&]N<V4@:7,@82!33T%07TUS9R!O8FIE8W0N("HO"B`@
M("`@("`@("`@("1S;V%P7VUS9R`]("1T:&ES+3YP87)S95)E<75E<W0H)&1A
M=&$L("1A='1A8VAM96YT<RD["@H@("`@("`@("`@("`O*B!(86YD;&4@36EM
M92!O<B!$24U%(&5N8V]D:6YG+B`J+PH@("`@("`@("`@("`O*B!43T1/.B!$
M24U%(&1E8V]D:6YG('-H;W5L9"!M;W9E('1O('1H92!T<F%N<W!O<G0L(&1O
M(&ET(&AE<F4*("`@("`@("`@("`@("H@9F]R(&YO=R!A;F0@9F]R(&5A<V4@
M;V8@9V5T=&EN9R!I="!D;VYE+B`J+PH@("`@("`@("`@("!I9B`H8V]U;G0H
M)'1H:7,M/E]?871T86-H;65N=',I*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'5S945N8V]D:6YG(#T]("=-:6UE)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1S;V%P7VUS9R`]("1T:&ES+3Y?;6%K94UI;65-97-S86=E*"1S;V%P7VUS
M9RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("\O(&1E9F%U;'0@:7,@9&EM90H@("`@("`@("`@("`@("`@("`@("1S
M;V%P7VUS9R`]("1T:&ES+3Y?;6%K941)345-97-S86=E*"1S;V%P7VUS9RD[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O;G1E;G0M
M5'EP92==(#T@)V%P<&QI8V%T:6]N+V1I;64G.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V53
M;V%P1F%U;'0H)'-O87!?;7-G*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1S;V%P7VUS9RDI
M('L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7VUS9ULG8F]D
M>2==.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1S;V%P7VUS9ULG:&5A
M9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S
M(#T@)'-O87!?;7-G6R=H96%D97)S)UT["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@
M/2`D<V]A<%]M<V<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?<V5N9%)E<W!O;G-E*"1R97-P;VYS92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!396YD<R!T:&4@9FEN86P@2%144"!R97-P;VYS92!T;R!T
M:&4@8VQI96YT+"!I;F-L=61I;F<@=&AE($A45%`@:&5A9&5R"B`@("`@*B!A
M;F0@=&AE($A45%`@8F]D>2X*("`@("`J"B`@("`@*B!)9B!A;B!E<G)O<B!H
M87!P96YE9"P@:70@<F5T=7)N<R!A(%-/05`@9F%U;'0@:6YS=&5A9"!O9B!T
M:&4@<F5S<&]N<V4*("`@("`J(&)O9'DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F5S<&]N<V4@(%1H92!R97-P;VYS92!B;V1Y+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5N9%)E<W!O;G-E*"1R97-P;VYS92`]("<G*0H@
M("`@>PH@("`@("`@("\J($UA:V4@9&ES=&EN8W1I;VX@8F5T=V5E;B!T:&4@
M9&EF9F5R96YT(%-!4$ES+"!R=6YN:6YG(%!(4"!A<R!#1TD@;W(*("`@("`@
M("`@*B!A<R!A(&UO9'5L92X@*B\*("`@("`@("!I9B`H<W1R:7-T<BAP:'!?
M<V%P:5]N86UE*"DL("=C9VDG*2`]/3T@,"D@>PH@("`@("`@("`@("`D:&1R
M<U]T>7!E(#T@)U-T871U<SHG.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1H9')S7W1Y<&4@/2`G2%144"\Q+C$G.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3YF875L="D@>PH@("`@("`@("`@("`D:&1R<R`]("(D
M:&1R<U]T>7!E(#4P,"!3;V%P($9A=6QT7')<;B(["B`@("`@("`@("`@("1R
M97-P;VYS92`]("1T:&ES+3YF875L="T^;65S<V%G92@I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1H9')S(#T@(B1H9')S7W1Y<&4@,C`P($]+
M7')<;B(["B`@("`@("`@?0H@("`@("`@(&AE861E<B@D:&1R<RD["@H@("`@
M("`@("1T:&ES+3YH96%D97)S6R=397)V97(G72`](%-/05!?3$E"4D%265].
M04U%.PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/FAE861E<G-;)T-O;G1E
M;G0M5'EP92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<ULG0V]N
M=&5N="U4>7!E)UT@/2`G=&5X="]X;6P[(&-H87)S970])R`N"B`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5S<&]N<V5?96YC;V1I;F<["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3YH96%D97)S6R=#;VYT96YT+4QE;F=T:"==(#T@<W1R
M;&5N*"1R97-P;VYS92D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YH96%D
M97)S(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@(&AE861E<B@B)&LZ("1V
M(BD["B`@("`@("`@("`@("1H9')S("X]("(D:SH@)'9<<EQN(CL*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YR97-P;VYS92`]("1H9')S("X@(EQR7&XB
M("X@)')E<W!O;G-E.PH@("`@("`@('!R:6YT("1R97-P;VYS93L*("`@('T*
M"B`@("!F=6YC=&EO;B`F8V%L;$UE=&AO9"@D;65T:&]D;F%M92P@)B1A<F=S
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^8V%L;$AA;F1L97(I('L*("`@
M("`@("`@("`@<F5T=7)N($!C86QL7W5S97)?9G5N8U]A<G)A>2@D=&AI<RT^
M8V%L;$AA;F1L97(L(&%R<F%Y*"1M971H;V1N86UE+"`D87)G<RDI.PH@("`@
M("`@('T*"B`@("`@("`@<V5T7V5R<F]R7VAA;F1L97(H87)R87DH)'1H:7,L
M("=?97)R;W)(86YD;&5R)RDI.PH*("`@("`@("!I9B`H)&%R9W,I('L*("`@
M("`@("`@("`@+RH@0V%L;"!M971H;V0@=VET:"!P87)A;65T97)S+B`J+PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/G-O87!O8FIE8W0I("8F(&ES
M7V]B:F5C="@D=&AI<RT^<V]A<&]B:F5C="DI('L*("`@("`@("`@("`@("`@
M("1R970@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)B1T:&ES+3YS
M;V%P;V)J96-T+"`D;65T:&]D;F%M92DL("1A<F=S*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R970@/2!`8V%L;%]U<V5R7V9U
M;F-?87)R87DH)&UE=&AO9&YA;64L("1A<F=S*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($-A;&P@;65T:&]D('=I
M=&AO=7(@<&%R86UE=&5R<RX@*B\*("`@("`@("`@("`@:68@*&ES7V]B:F5C
M="@D=&AI<RT^<V]A<&]B:F5C="DI('L*("`@("`@("`@("`@("`@("1R970@
M/2!`8V%L;%]U<V5R7V9U;F,H87)R87DH)B1T:&ES+3YS;V%P;V)J96-T+"`D
M;65T:&]D;F%M92DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)')E="`]($!C86QL7W5S97)?9G5N8R@D;65T:&]D;F%M92D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<W1O<F5?97)R;W)?
M:&%N9&QE<B@I.PH*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T97,@4T]!4%]686QU92!O8FIE8W0@=VET:"!R971U
M<FX@=F%L=65S(&9R;VT@;65T:&]D+@H@("`@("H@57-E<R!M971H;V0@<VEG
M;F%T=7)E('1O(&1E=&5R;6EN92!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!B=6EL9%)E<W5L="@F)&UE=&AO9%]R97-P;VYS92P@)B1R971U<FY?='EP
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FY?;F%M92`]("=R
M971U<FXG+"`D;F%M97-P86-E(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)&UE=&AO9%]R97-P;VYS92P@)U-/05!?5F%L=64G*2D@>PH@("`@("`@
M("`@("`D<F5T=7)N7W9A;"`](&%R<F%Y*"1M971H;V1?<F5S<&]N<V4I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T
M=7)N7W1Y<&4I("8F(&ES7V%R<F%Y*"1M971H;V1?<F5S<&]N<V4I*2!["B`@
M("`@("`@("`@("`@("`D:2`](#`["@H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)')E='5R;E]T>7!E(&%S("1K97D@/3X@)'1Y<&4I('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D:V5Y*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:V5Y(#T@)VET96TG.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D;65T:&]D7W)E
M<W!O;G-E6R1I72PG<V]A<%]V86QU92<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1R971U<FY?=F%L6UT@/2`D;65T:&]D7W)E<W!O;G-E6R1I*RM=
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1Q;B`])B!N97<@44YA;64H)&ME>2P@)&YA;65S<&%C92D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FY?=F%L6UT@/28@;F5W
M(%-/05!?5F%L=64H)'%N+3YF<6XH*2P@)'1Y<&4L("1M971H;V1?<F5S<&]N
M<V5;)&DK*UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D<F5T=7)N7W1Y<&4I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&ME>7,@/2!A<G)A>5]K97ES*"1R971U<FY?='EP92D["B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<U]N=6UE<FEC*"1K97ES6S!=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7VYA;64@/2`D:V5Y<ULP73L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y7W9A;'5E<R@D<F5T=7)N7W1Y<&4I.PH@("`@("`@("`@
M("`@("`@("`@("1R971U<FY?='EP92`]("1V86QU97-;,%T["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1R
M971U<FY?;F%M92P@)&YA;65S<&%C92D["B`@("`@("`@("`@("`@("`D<F5T
M=7)N7W9A;"`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D<F5T=7)N7W9A
M;%M=(#TF(&YE=R!33T%07U9A;'5E*"1Q;BT^9G%N*"DL("1R971U<FY?='EP
M92P@)&UE=&AO9%]R97-P;VYS92D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1R971U<FY?=F%L.PH@("`@?0H*("`@(&9U;F-T
M:6]N('!A<G-E4F5Q=65S="@D9&%T82`]("<G+"`D871T86-H;65N=',@/2!N
M=6QL*0H@("`@>PH@("`@("`@("\J(%!A<G-E(')E<W!O;G-E+"!G970@4T]!
M4%]087)S97(@;V)J96-T+B`J+PH@("`@("`@("1P87)S97(@/28@;F5W(%-/
M05!?4&%R<V5R*"1D871A+"`D=&AI<RT^>&UL7V5N8V]D:6YG+"`D871T86-H
M;65N=',I.PH@("`@("`@("\J($EF(&9A=6QT(&]C8W5R<F5D(&1U<FEN9R!M
M97-S86=E('!A<G-I;F<N("HO"B`@("`@("`@:68@*"1P87)S97(M/F9A=6QT
M*2!["B`@("`@("`@("`@("1T:&ES+3YF875L="`]("1P87)S97(M/F9A=6QT
M.PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@
M("\J($AA;F1L92!M97-S86=E(&AE861E<G,N("HO"B`@("`@("`@)')E<75E
M<W1?:&5A9&5R<R`]("1P87)S97(M/F=E=$AE861E<G,H*3L*("`@("`@("`D
M:&5A9&5R7W)E<W5L=',@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)')E<75E
M<W1?:&5A9&5R<RD@>PH@("`@("`@("`@("!I9B`H(6ES7V$H)')E<75E<W1?
M:&5A9&5R<RP@)U-/05!?5F%L=64G*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@G4&%R<V5R(&1I9"!N;W0@<F5T=7)N(%-/
M05!?5F%L=64@;V)J96-T.B`G("X@)')E<75E<W1?:&5A9&5R<RP@)R<L("<G
M+"`G4V5R=F5R)RD["B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)')E<75E<W1?:&5A9&5R<RT^
M=F%L=64I('L*("`@("`@("`@("`@("`@("\J($AA;F1L92!H96%D97)S(&YO
M=RX@*B\*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R97%U97-T7VAE861E
M<G,M/G9A;'5E(&%S("1H96%D97)?=F%L*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9?97AI<W1S(#T@)'1H:7,M/G9A;&ED871E365T:&]D*"1H96%D97)?
M=F%L+3YN86UE+"`D:&5A9&5R7W9A;"T^;F%M97-P86-E*3L*"B`@("`@("`@
M("`@("`@("`@("`@+RH@5$]$3SH@=&AI<R!D;V5S(&YO="!T86ME(&EN=&\@
M86-C;W5N="!M97-S86=E(')O=71I;F<*("`@("`@("`@("`@("`@("`@("`@
M*B!Y970N("HO"B`@("`@("`@("`@("`@("`@("`@)&UY86-T;W(@/2`A)&AE
M861E<E]V86PM/F%C=&]R('Q\"B`@("`@("`@("`@("`@("`@("`@("`@("1H
M96%D97)?=F%L+3YA8W1O<B`]/2`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O<V]A<"]A8W1O<B]N97AT)R!\?`H@("`@("`@("`@("`@("`@("`@("`@
M("`D:&5A9&5R7W9A;"T^86-T;W(@/3T@)'1H:7,M/F5N9'!O:6YT.PH*("`@
M("`@("`@("`@("`@("`@("!I9B`H(21F7V5X:7-T<R`F)B`D:&5A9&5R7W9A
M;"T^;75S='5N9&5R<W1A;F0@)B8@)&UY86-T;W(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G22!D;VY<)W0@
M=6YD97)S=&%N9"!H96%D97(@)R`N("1H96%D97)?=F%L+3YN86UE+"`G)RP@
M)R<L("=-=7-T56YD97)S=&%N9"<I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@;G5L;#L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("\J(%=E(&]N;'D@:&%N9&QE('1H92!H96%D97(@:68@
M:70G<R!F;W(@=7,N("HO"B`@("`@("`@("`@("`@("`@("`@)&ES;VL@/2`D
M9E]E>&ES=',@)B8@)&UY86-T;W(["@H@("`@("`@("`@("`@("`@("`@(&EF
M("@D:7-O:RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!#86QL(&]U
M<B!H96%D97(@;F]W(2`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D:&5A
M9&5R7VUE=&AO9"`]("1H96%D97)?=F%L+3YN86UE.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:&5A9&5R7V1A=&$@/2!A<G)A>2@D=&AI<RT^7V1E8V]D
M92@D:&5A9&5R7W9A;"DI.PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!)
M9B!T:&5R92!A<F4@<&%R86UE=&5R<R!T;R!P87-S+B`J+PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:'(@/28@)'1H:7,M/F-A;&Q-971H;V0H)&AE861E
M<E]M971H;V0L("1H96%D97)?9&%T82D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1H96%D97)?<F5S=6QT<UM=(#T@87)R87E?<VAI9G0H)'1H:7,M/F)U
M:6QD4F5S=6QT*"1H<BP@)'1H:7,M/G)E='5R;E]T>7!E+"`D:&5A9&5R7VUE
M=&AO9"P@)&AE861E<E]V86PM/FYA;65S<&%C92DI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@2&%N9&QE('1H92!M971H;V0@8V%L;"X@*B\*
M("`@("`@("`O*B!%=F%L=6%T92!M97-S86=E+"!G971T:6YG(&)A8VL@82!3
M3T%07U9A;'5E(&]B:F5C="X@*B\*("`@("`@("`D=&AI<RT^8V%L;%]M971H
M;V1N86UE(#T@)'1H:7,M/FUE=&AO9&YA;64@/2`D<&%R<V5R+3YR;V]T7W-T
M<G5C=%]N86UE6S!=.PH*("`@("`@("`O*B!&:6=U<F4@;W5T('1H92!M971H
M;V0@;F%M97-P86-E+B`J+PH@("`@("`@("1T:&ES+3YM971H;V1?;F%M97-P
M86-E(#T@)'!A<G-E<BT^;65S<V%G95LD<&%R<V5R+3YR;V]T7W-T<G5C=%LP
M75U;)VYA;65S<&%C92==.PH*("`@("`@("!I9B`H)'1H:7,M/E]W<V1L*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<V5T4V-H96UA5F5R<VEO;B@D=&AI<RT^
M7W=S9&PM/GAS9"D["B`@("`@("`@("`@("1D871A2&%N9&QE<B`]("1T:&ES
M+3Y?=W-D;"T^9V5T1&%T84AA;F1L97(H)'1H:7,M/FUE=&AO9&YA;64L("1T
M:&ES+3YM971H;V1?;F%M97-P86-E*3L*("`@("`@("`@("`@:68@*"1D871A
M2&%N9&QE<BD*("`@("`@("`@("`@("`@("1T:&ES+3YC86QL7VUE=&AO9&YA
M;64@/2`D=&AI<RT^;65T:&]D;F%M92`]("1D871A2&%N9&QE<CL*"B`@("`@
M("`@("`@("1T:&ES+3Y?<&]R=$YA;64@/2`D=&AI<RT^7W=S9&PM/F=E=%!O
M<G1.86UE*"1T:&ES+3YM971H;V1N86UE*3L*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)'1H:7,M/E]P;W)T3F%M92DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1T:&ES+3Y?<&]R
M=$YA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1O<$1A=&$@/2`D
M=&AI<RT^7W=S9&PM/F=E=$]P97)A=&EO;D1A=&$H)'1H:7,M/E]P;W)T3F%M
M92P@)'1H:7,M/FUE=&AO9&YA;64I.PH@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D;W!$871A*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&]P1&%T82D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G72`]("1O<$1A
M=&%;)W-T>6QE)UT["B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W5S
M92==(#T@)&]P1&%T85LG;W5T<'5T)UU;)W5S92==.PH@("`@("`@("`@("`D
M=&AI<RT^7U]O<'1I;VYS6R=P87)A;65T97)S)UT@/2`D;W!$871A6R=P87)A
M;65T97)S)UT["B`@("`@("`@?0H*("`@("`@("`O*B!$;V5S(&UE=&AO9"!E
M>&ES=#\@*B\*("`@("`@("!I9B`H(21T:&ES+3YM971H;V1N86UE('Q\"B`@
M("`@("`@("`@("$D=&AI<RT^=F%L:61A=&5-971H;V0H)'1H:7,M/FUE=&AO
M9&YA;64L("1T:&ES+3YM971H;V1?;F%M97-P86-E*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=M971H;V0@(B<@+B`D=&AI<RT^
M;65T:&]D7VYA;65S<&%C92`N("1T:&ES+3YM971H;V1N86UE("X@)R(@;F]T
M(&1E9FEN960@:6X@<V5R=FEC92<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M)')E<75E<W1?=F%L(#T@)'!A<G-E<BT^9V5T4F5S<&]N<V4H*2D@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"%I
M<U]A*"1R97%U97-T7W9A;"P@)U-/05!?5F%L=64G*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=087)S97(@9&ED(&YO="!R971U
M<FX@4T]!4%]686QU92!O8FIE8W0Z("<@+B`D<F5Q=65S=%]V86PL("<G+"`G
M)RP@)U-E<G9E<B<I.PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"@H@("`@("`@("\J(%9E<FEF>2!T:&%T(%-/05!?5F%L=64@;V)J96-T
M<R!I;B!R97%U97-T(&UA=&-H('1H92!M971H;V1S"B`@("`@("`@("H@<VEG
M;F%T=7)E+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/G9E<FEF>4UE=&AO9"@D
M<F5Q=65S=%]V86PI*2!["B`@("`@("`@("`@("\J('9E<FEF>4UE=&AO9"@I
M(&-R96%T97,@=&AE(&9A=6QT+B`J+PH@("`@("`@("`@("!R971U<FX@;G5L
M;#L*("`@("`@("!]"@H@("`@("`@("\J($YE960@=&\@<V5T('-P96-I86P@
M97)R;W(@9&5T96-T:6]N(&EN<VED92!T:&4@=F%L=64@8VQA<W,@=&\*("`@
M("`@("`@*B!D:69F97)E;G1I871E(&)E='=E96X@;F\@<&%R86US('!A<W-E
M9"P@86YD(&%N(&5R<F]R(&1E8V]D:6YG+B`J+PH@("`@("`@("1R97%U97-T
M7V1A=&$@/2`D=&AI<RT^7U]D96-O9&5297%U97-T*"1R97%U97-T7W9A;"D[
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<75E<W1?9&%T82DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E
M<75E<W1?9&%T82D["B`@("`@("`@?0H@("`@("`@("1M971H;V1?<F5S<&]N
M<V4@/28@)'1H:7,M/F-A;&Q-971H;V0H)'1H:7,M/F-A;&Q?;65T:&]D;F%M
M92P@)')E<75E<W1?9&%T82D["@H@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I
M;VYS6R=P87)A;65T97)S)UT@?'P*("`@("`@("`@("`@(21M971H;V1?<F5S
M<&]N<V4@?'P*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G
M73T])W)P8R<I('L*("`@("`@("`@("`@+RH@1V5T('1H92!M971H;V0@<F5S
M=6QT+B`J+PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D;65T:&]D7W)E<W!O
M;G-E*2D@>PH@("`@("`@("`@("`@("`@)')E='5R;E]V86P@/2!N=6QL.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E='5R;E]V
M86P@/2`D=&AI<RT^8G5I;&1297-U;'0H)&UE=&AO9%]R97-P;VYS92P@)'1H
M:7,M/G)E='5R;E]T>7!E*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'%N(#TF(&YE=R!13F%M92@D=&AI<RT^;65T:&]D;F%M92`N("=297-P;VYS
M92<L("1T:&ES+3YM971H;V1?;F%M97-P86-E*3L*("`@("`@("`@("`@)&UE
M=&AO9%9A;'5E(#TF(&YE=R!33T%07U9A;'5E*"1Q;BT^9G%N*"DL("=3=')U
M8W0G+"`D<F5T=7)N7W9A;"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&UE=&AO9%9A;'5E(#TF("1M971H;V1?<F5S<&]N<V4["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VUA:V5%;G9E;&]P92@D;65T:&]D
M5F%L=64L("1H96%D97)?<F5S=6QT<RP@)'1H:7,M/G)E<W!O;G-E7V5N8V]D
M:6YG*3L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]D96-O9&5297%U97-T*"1R
M97%U97-T+"`D<VAI9G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(21R
M97%U97-T*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0VAE8VL@9F]R('9A;&ED(')E<W!O;G-E+B`J+PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R97%U97-T*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D<F5Q=65S="D["B`@
M("`@("`@?2!E;'-E(&EF("@A:7-?82@D<F5Q=65S="P@)U-/05!?5F%L=64G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@G26YV86QI9"!D871A(&EN('-E<G9E<CHZ7U]D96-O9&5297%U97-T)RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!$96-O9&4@=&\@;F%T:79E('!H<"!D
M871A='EP92X@*B\*("`@("`@("`D<F5Q=65S=$%R<F%Y(#T@)'1H:7,M/E]D
M96-O9&4H)')E<75E<W0I.PH@("`@("`@("\J($9A=6QT/R`J+PH@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1R97%U97-T07)R87DI*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1R97%U97-T07)R
M87DI.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?;V)J96-T*"1R97%U97-T
M07)R87DI("8F"B`@("`@("`@("`@(&=E=%]C;&%S<R@D<F5Q=65S=$%R<F%Y
M*2`]/2`G<W1D0VQA<W,G*2!["B`@("`@("`@("`@("1R97%U97-T07)R87D@
M/2!G971?;V)J96-T7W9A<G,H)')E<75E<W1!<G)A>2D["B`@("`@("`@?2!E
M;'-E:68@*"1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@/3T@)V1O8W5M96YT
M)RD@>PH@("`@("`@("`@("`D<F5Q=65S=$%R<F%Y(#T@87)R87DH)')E<75E
M<W1!<G)A>2D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A<G)A>2@D<F5Q
M=65S=$%R<F%Y*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)')E<75E<W1!
M<G)A>5LG9F%U;'1C;V1E)UTI('Q\"B`@("`@("`@("`@("`@("!I<W-E="@D
M<F5Q=65S=$%R<F%Y6R=33T%0+45.5CIF875L=&-O9&4G72DI('L*("`@("`@
M("`@("`@("`@("1F875L=&-O9&4@/2`D9F%U;'1S=')I;F<@/2`D9F%U;'1D
M971A:6P@/2`D9F%U;'1A8W1O<B`]("<G.PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)')E<75E<W1!<G)A>2!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("AS=')I<W1R*"1K+"`G9F%U;'1C;V1E)RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9A=6QT8V]D92`]("1V.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T
M<B@D:RP@)V9A=6QT<W1R:6YG)RDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&9A=6QT<W1R:6YG(#T@)'8["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1K+"`G9&5T86EL)RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9A=6QT9&5T86EL(#T@)'8[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF
M("AS=')I<W1R*"1K+"`G9F%U;'1A8W1O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1F875L=&%C=&]R(#T@)'8["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&9A=6QT<W1R:6YG+"`D9F%U;'1D
M971A:6PL("1F875L=&%C=&]R+"`D9F%U;'1C;V1E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`O*B!2971U<FX@87)R87D@;V8@<F5T=7)N('9A;'5E
M<RX@*B\*("`@("`@("`@("`@:68@*"1S:&EF="`F)B!C;W5N="@D<F5Q=65S
M=$%R<F%Y*2`]/2`Q*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87E?
M<VAI9G0H)')E<75E<W1!<G)A>2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5T=7)N("1R97%U97-T07)R87D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5Q=65S=$%R<F%Y.PH@("`@?0H*("`@(&9U;F-T:6]N('9E<FEF
M>4UE=&AO9"@D<F5Q=65S="D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YC
M86QL5F%L:61A=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("1P87)A;7,@/2`D<F5Q=65S="T^=F%L=64["@H@
M("`@("`@("\J($=E="!T:&4@9&ES<&%T8V@@;6%P(&EF(&]N92!E>&ES=',N
M("HO"B`@("`@("`@)&UA<"`](&YU;&P["B`@("`@("`@:68@*&%R<F%Y7VME
M>5]E>&ES=',H)'1H:7,M/FUE=&AO9&YA;64L("1T:&ES+3YD:7-P871C:%]M
M87`I*2!["B`@("`@("`@("`@("1M87`@/2`D=&AI<RT^9&ES<&%T8VA?;6%P
M6R1T:&ES+3YM971H;V1N86UE73L*("`@("`@("!](&5L<V5I9B`H:7-S970H
M)'1H:7,M/G-O87!O8FIE8W0I*2!["B`@("`@("`@("`@(&EF("AM971H;V1?
M97AI<W1S*"1T:&ES+3YS;V%P;V)J96-T+"`G7U]D:7-P871C:"<I*2!["B`@
M("`@("`@("`@("`@("`D;6%P(#T@)'1H:7,M/G-O87!O8FIE8W0M/E]?9&ES
M<&%T8V@H)'1H:7,M/FUE=&AO9&YA;64I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H;65T:&]D7V5X:7-T<R@D=&AI<RT^<V]A<&]B:F5C="P@)'1H:7,M/FUE
M=&AO9&YA;64I*2!["B`@("`@("`@("`@("`@("`O*B!.;R!M87`L(&%L;"!P
M=6)L:6,@9G5N8W1I;VYS(&%R92!33T%0(&9U;F-T:6]N<RX@*B\*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&EF("@A)&UA<"D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"=33T%0(')E<75E<W0@<W!E8VEF:65D(&%N('5N:&%N
M9&QE9"!M971H;V0@(B<@+B`D=&AI<RT^;65T:&]D;F%M92`N("<B)RP@)R<L
M("<G+"`G0VQI96YT)RD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\J($EF('=E(&%L:6%S960@=&AE(%-/05`@;65T
M:&]D(&YA;64@=&\@82!02%`@9G5N8W1I;VXL(&-H86YG90H@("`@("`@("`J
M(&-A;&Q?;65T:&]D;F%M92!S;R!W92!D;R!T:&4@<FEG:'0@=&AI;F<N("HO
M"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V%L:6%S)RP@)&UA<"D@
M)B8@(65M<'1Y*"1M87!;)V%L:6%S)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3YC86QL7VUE=&AO9&YA;64@/2`D;6%P6R=A;&EA<R==.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@=&AE<F4@87)E(&EN<'5T('!A<F%M971E<G,@<F5Q
M=6ER960N("HO"B`@("`@("`@:68@*"1S:6<@/2`D;6%P6R=I;B==*2!["B`@
M("`@("`@("`@("1T:&ES+3YI;G!U=%]V86QU92`](&-O=6YT*"1S:6<I.PH@
M("`@("`@("`@("`D=&AI<RT^<F5T=7)N7W1Y<&4@/2!I<U]A<G)A>2@D;6%P
M6R=O=70G72D@/R`D;6%P6R=O=70G72`Z(&9A;'-E.PH@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@("`@("`@("\J(%9A
M;&ED871E('1H92!N=6UB97(@;V8@<&%R86UE=&5R<RX@*B\*("`@("`@("`@
M("`@("`@(&EF("AC;W5N="@D<&%R86US*2`]/2!C;W5N="@D<VEG*2D@>PH@
M("`@("`@("`@("`@("`@("`@("\J($UA:V4@87)R87D@;V8@<&%R86T@='EP
M97,N("HO"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D<&%R86TI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!;72`]('-T
M<G1O;&]W97(H)'!A<F%M+3YT>7!E*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)'-I9U]T(#T@87)R87E?=F%L=65S*"1S
M:6<I.PH@("`@("`@("`@("`@("`@("`@("\J(%9A;&ED871E(&5A8V@@<&%R
M86TG<R!T>7!E+B`J+PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(&-O=6YT*"1P*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O*B!)9B!33T%0('1Y<&5S(&1O(&YO="!M871C:"P@:70G<R!S=&EL
M;"!F:6YE(&EF('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@*B!M87!P
M960@<&AP('1Y<&5S(&UA=&-H('1H:7,@86QL;W=S('5S:6YG('!L86EN(%!(
M4`H@("`@("`@("`@("`@("`@("`@("`@("`@*B!V87)I86)L97,@=&\@=V]R
M:R`H:2YE+B!S='5F9B!L:6ME($1E8VEM86P@=V]U;&0*("`@("`@("`@("`@
M("`@("`@("`@("`@("H@9F%I;"!O=&AE<G=I<V4I+B!792!C;VYS:61E<B!T
M:&ES(&]N;'D@97)R;W(@:68@=&AE"B`@("`@("`@("`@("`@("`@("`@("`@
M("`J('1Y<&5S(&5X:7-T(&EN(&]U<B!T>7!E(&UA<',L(&%N9"!T:&5Y(&1I
M9F9E<BX@*B\*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<F-A<V5C
M;7`H)'-I9U]T6R1I72P@)'!;)&E=*2`A/2`P("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W1Y<&5M87!;4T]!4%]834Q?
M4T-(14U!7U9%4E-)3TY=6R1S:6=?=%LD:5U=*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R8V%S96-M<"@D=&AI<RT^7W1Y<&5M87!;4T]!
M4%]834Q?4T-(14U!7U9%4E-)3TY=6R1S:6=?=%LD:5U=+"`D=&AI<RT^7W1Y
M<&5M87!;4T]!4%]834Q?4T-(14U!7U9%4E-)3TY=6R1P6R1I75TI("$](#`I
M('L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D<&%R
M86US6R1I73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H(E-/05`@<F5Q=65S="!C;VYT86EN960@;6ES;6%T
M8VAI;F<@<&%R86UE=&5R<R!O9B!N86UE("1P87)A;2T^;F%M92!H860@='EP
M92!;>R1P6R1I77U=+"!W:&EC:"!D:60@;F]T(&UA=&-H('-I9VYA='5R92=S
M('1Y<&4Z(%M[)'-I9U]T6R1I77U=+"!M871C:&5D/R`B("X@*'-T<F-A<V5C
M;7`H)'-I9U]T6R1I72P@)'!;)&E=*2DL("<G+"`G)RP@)T-L:65N="<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!7<F]N9R!N=6UB
M97(@;V8@<&%R86US+B`J+PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)U-/05`@<F5Q=65S="!C;VYT86EN960@:6YC;W)R
M96-T(&YU;6)E<B!O9B!P87)A;65T97)S+B!M971H;V0@(B<@+B`D=&AI<RT^
M;65T:&]D;F%M92`N("<B(')E<75I<F5D("<@+B!C;W5N="@D<VEG*2`N("<@
M86YD(')E<75E<W0@<')O=FED960@)R`N(&-O=6YT*"1P87)A;7,I+"`G)RP@
M)R<L("=#;&EE;G0G*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`O*B!.;R!P87)A;7,N("HO"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=33T%0(')E<75E<W0@8V]N=&%I
M;F5D(&EN8V]R<F5C="!N=6UB97(@;V8@<&%R86UE=&5R<RX@;65T:&]D("(G
M("X@)'1H:7,M/FUE=&AO9&YA;64@+B`G(B!R97%U:7)E<R`G("X@8V]U;G0H
M)'-I9RD@+B`G('!A<F%M971E<G,L(&%N9"!R97%U97-T('!R;W9I9&5D(&YO
M;F4N)RP@)R<L("<G+"`G0VQI96YT)RD["B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M(%=E)VQL('1R>2!I="!A;GEW87DN("HO"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=F%L:61A=&5-971H;V0H)&UE=&AO9&YA
M;64L("1N86UE<W!A8V4@/2!N=6QL*0H@("`@>PH@("`@("`@('5N<V5T*"1T
M:&ES+3YS;V%P;V)J96-T*3L*"B`@("`@("`@:68@*"$D=&AI<RT^8V%L;%9A
M;&ED871I;VXI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("`O*B!.;R!33T%0(&%C8V5S<R!T;R!P<FEV871E(&9U;F-T
M:6]N<RX@*B\*("`@("`@("!I9B`H)&UE=&AO9&YA;65;,%T@/3T@)U\G*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\J(&EF(&ET)W,@:6X@;W5R(&9U;F-T:6]N(&QI<W0L(&]K("HO"B`@("`@
M("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)&UE=&AO9&YA;64L("1T:&ES+3YD
M:7-P871C:%]M87`I("8F"B`@("`@("`@("`@("@A)&YA;65S<&%C92!\?`H@
M("`@("`@("`@("`@(6%R<F%Y7VME>5]E>&ES=',H)VYA;65S<&%C92<L("1T
M:&ES+3YD:7-P871C:%]M87!;)&UE=&AO9&YA;65=*2!\?`H@("`@("`@("`@
M("`@)&YA;65S<&%C92`]/2`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M971H;V1N
M86UE75LG;F%M97-P86-E)UTI*2!["B`@("`@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"=N86UE<W!A8V4G+"`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M
M971H;V1N86UE72DI"B`@("`@("`@("`@("`@("`D=&AI<RT^;65T:&]D7VYA
M;65S<&%C92`]("1T:&ES+3YD:7-P871C:%]M87!;)&UE=&AO9&YA;65=6R=N
M86UE<W!A8V4G73L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("`O*B!I9B!I="=S(&EN(&%N(&]B:F5C="P@:70G<R!O:R`J
M+PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9&ES<&%T8VA?;V)J96-T<ULD
M;F%M97-P86-E72DI('L*("`@("`@("`@("`@)&,@/2!C;W5N="@D=&AI<RT^
M9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E72D["B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D
M;V)J(#TF("1T:&ES+3YD:7-P871C:%]O8FIE8W1S6R1N86UE<W!A8V5=6R1I
M73L*("`@("`@("`@("`@("`@("\J($EF('=E(&AA=F4@82!D:7-P871C:"!M
M87`L(&%N9"!T:&4@9G5N8W1I;VX@:7,@;F]T(&EN('1H90H@("`@("`@("`@
M("`@("`@("H@9&ES<&%T8V@@;6%P+"!T:&5N(&ET(&ES(&YO="!C86QL86)L
M92$@*B\*("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1O8FHL
M("=?7V1I<W!A=&-H)RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&]B
M:BT^7U]D:7-P871C:"@D;65T:&]D;F%M92DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4@/2`D;F%M97-P86-E
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V]A<&]B:F5C="`]
M)B`D;V)J.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H;65T:&]D7V5X:7-T<R@D;V)J+"`D;65T:&]D;F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;65T:&]D7VYA;65S<&%C92`]("1N86UE
M<W!A8V4["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-O87!O8FIE8W0@
M/28@)&]B:CL*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N(&%D9$]B:F5C
M=$UA<"@F)&]B:BP@)&YA;65S<&%C92`](&YU;&PL("1S97)V:6-E7VYA;64@
M/2`G1&5F875L="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'-E<G9I
M8V5?9&5S8R`]("<G*0H@("`@>PH@("`@("`@(&EF("@A)&YA;65S<&%C92D@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)&]B:BT^;F%M97-P86-E*2D@>PH@
M("`@("`@("`@("`@("`@+R\@6%A8(&$@8FET(&]F(&)A8VMW87)D<R!C;VUP
M871I8FEL:71Y"B`@("`@("`@("`@("`@("`D;F%M97-P86-E(#T@)&]B:BT^
M;F%M97-P86-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@G3F\@;F%M97-P86-E('!R;W9I
M9&5D(&9O<B!C;&%S<R$G+"`G)RP@)R<L("=397)V97(G*3L*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YD:7-P871C:%]O8FIE8W1S6R1N
M86UE<W!A8V5=*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&ES<&%T8VA?;V)J
M96-T<ULD;F%M97-P86-E72`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YD:7-P871C:%]O8FIE8W1S6R1N86UE<W!A8V5=6UT@/28@)&]B
M:CL*"B`@("`@("`@+R\@0W)E871E(&EN=&5R;F%L(%=31$P@<W1R=6-T=7)E
M<R!F;W(@;V)J96-T"@H@("`@("`@("\O(%A86"!"96-A=7-E('-O;64@:6YT
M97)N86P@=V]R:VEN9W,@;V8@4$5!4CHZ4T]!4"!D96-I9&4@=VAE=&AE<B!T
M;PH@("`@("`@("\O(&1O(&-E<G1A:6X@=&AI;F=S(&)Y('1H92!P<F5S96YC
M92!O<B!A8G-E;F-E(&]F(%]W<V1L+"!W92!S:&]U;&0*("`@("`@("`O+R!O
M;FQY(&-R96%T92!A(%]W<V1L('-T<G5C='5R92!I9B!W92!K;F]W('=E(&-A
M;B!F:6QL(&ET.R!I9@H@("`@("`@("\O(%]?9&ES<&%T8VA?;6%P(&]R(%]?
M='EP961E9B!F;W(@=&AE(&]B:F5C="!I<R!M:7-S:6YG+"!W92!S:&]U;&0*
M("`@("`@("`O+R!A=F]I9"!C<F5A=&EN9R!I="X@3&%T97(L('=H96X@=V4@
M87)E('5S:6YG(%!(4"`U(&EN=')O<W!E8W1I;VXL('=E"B`@("`@("`@+R\@
M=VEL;"!B92!A8FQE('1O(&UA:V4@=&AE(&1A=&$@9F]R(&%L;"!O8FIE8W1S
M('=I=&AO=70@86YY(&5X=')A"B`@("`@("`@+R\@:6YF;W)M871I;VX@9G)O
M;2!T:&4@9&5V96QO<&5R<RP@86YD('1H:7,@8V]N9&ET:6]N('-H;W5L9"!B
M90H@("`@("`@("\O(&1R;W!P960N"@H@("`@("`@("\O(%A86"!+;F]W;B!I
M<W-U93H@:68@:6UP;W)T960@5U-$3"`H8FEN9%=31$PI(&]R(&%N;W1H97(@
M5U-$3"!S;W5R8V4*("`@("`@("`O+R!I<R!U<V5D('1O(&%D9"!?=W-D;"!S
M=')U8W1U<F4@:6YF;W)M871I;VXL('1H96X@861D3V)J96-T5U-$3"!I<PH@
M("`@("`@("\O('5S960L('1H97)E(&ES(&$@:&EG:"!P;W-S:6)I;&ET>2!O
M9B!?=W-D;"!D871A(&-O<G)U<'1I;VX["B`@("`@("`@+R\@=&AE<F5F;W)E
M('EO=2!S:&]U;&0@879O:60@=7-I;F<@7U]D:7-P871C:%]M87`O7U]T>7!E
M9&5F"B`@("`@("`@+R\@9&5F:6YI=&EO;G,@04Y$(&]T:&5R(%=31$P@9&%T
M82!S;W5R8V5S(&EN('1H92!S86UE('-E<G9I8V4N(%=E"B`@("`@("`@+R\@
M97AC;'5D92!C;&%S<V5S('1H870@9&]N)W0@:&%V92!?7W1Y<&5D969S('1O
M(&%L;&]W(&5X=&5R;F%L(%=31$P*("`@("`@("`O+R!F:6QE<R!T;R!B92!U
M<V5D('=I=&@@8VQA<W-E<R!W:71H(&YO(&EN=&5R;F%L('1Y<&4@9&5F:6YI
M=&EO;G,*("`@("`@("`O+R`H=&AE('1Y<&5S(&%R92!D969I;F5D(&EN('1H
M92!74T1,(&9I;&4I+B!7:&5N(&%D9$]B:F5C=%=31$P@:7,*("`@("`@("`O
M+R!R969A8W1O<F5D('1O(&YO="!C875S92!C;W)R=7!T:6]N+"!T:&ES(')E
M<W1R:6-T:6]N(&-A;B!B90H@("`@("`@("\O(')E;&%X960N"@H@("`@("`@
M("\O($EN('-U;6UA<GDL(&EF('EO=2!A9&0@86X@;V)J96-T('=I=&@@8F]T
M:"!A(&1I<W!A=&-H(&UA<"!A;F0@='EP90H@("`@("`@("\O(&1E9FEN:71I
M;VYS+"!T:&5N('!R979I;W5S(%=31$P@9FEL92!O<&5R871I;VX@86YD('1Y
M<&4@9&5F:6YI=&EO;G,*("`@("`@("`O+R!W:6QL(&)E(&]V97)W<FET=&5N
M+@H@("`@("`@(&EF("AI<W-E="@D;V)J+3Y?7V1I<W!A=&-H7VUA<"D@)B8@
M:7-S970H)&]B:BT^7U]T>7!E9&5F*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M861D3V)J96-T5U-$3"@D;V)J+"`D;F%M97-P86-E+"`D<V5R=FEC95]N86UE
M+"`D<V5R=FEC95]D97-C*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&UE=&AO9"!T;R!T
M:&4@9&ES<&%T8V@@;6%P+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&14;TUA
M<"@D;65T:&]D;F%M92P@)&EN+"`D;W5T+"`D;F%M97-P86-E(#T@;G5L;"P@
M)&%L:6%S(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@D;65T:&]D;F%M92DI('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES
M95-O87!&875L="@G17)R;W(@;6%P<&EN9R!F=6YC=&EO;B<L("<G+"`G)RP@
M)U-E<G9E<B<I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M971H;V1N86UE75LG
M:6XG72`]("1I;CL*("`@("`@("`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M971H
M;V1N86UE75LG;W5T)UT@/2`D;W5T.PH@("`@("`@("1T:&ES+3YD:7-P871C
M:%]M87!;)&UE=&AO9&YA;65=6R=A;&EA<R==(#T@)&%L:6%S.PH@("`@("`@
M(&EF("@D;F%M97-P86-E*2!["B`@("`@("`@("`@("1T:&ES+3YD:7-P871C
M:%]M87!;)&UE=&AO9&YA;65=6R=N86UE<W!A8V4G72`]("1N86UE<W!A8V4[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F
M=6YC=&EO;B!S971#86QL2&%N9&QE<B@D8V%L;$AA;F1L97(L("1V86QI9&%T
M:6]N(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^8V%L;$AA;F1L97(@
M/2`D8V%L;$AA;F1L97(["B`@("`@("`@)'1H:7,M/F-A;&Q686QI9&%T:6]N
M(#T@)'9A;&ED871I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C
M871E9"!U<V4@8FEN9%=31$P@9G)O;2!N;W<@;VX*("`@("`J+PH@("`@9G5N
M8W1I;VX@8FEN9"@D=W-D;%]U<FPI"B`@("!["B`@("`@("`@)'1H:7,M/F)I
M;F174T1,*"1W<V1L7W5R;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<&%R
M86T@('-T<FEN9R!A('5R;"!T;R!A(%=31$P@<F5S;W5R8V4*("`@("`J($!R
M971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!B:6YD5U-$3"@D=W-D
M;%]U<FPI"B`@("!["B`@("`@("`@+RH@26YS=&%N=&EA=&4@5U-$3"!C;&%S
M<RX@*B\*("`@("`@("`D=&AI<RT^7W=S9&P@/28@;F5W(%-/05!?5U-$3"@D
M=W-D;%]U<FPI.PH@("`@("`@(&EF("@D=&AI<RT^7W=S9&PM/F9A=6QT*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M/E]W
M<V1L+3YF875L="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$]B:F5C=%=3
M1$PH)B1W<V1L7V]B:BP@)'1A<F=E=$YA;65S<&%C92P@)'-E<G9I8V5?;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-E<G9I8V5?9&5S8R`]
M("<G*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]W<V1L*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W=S9&P@/28@;F5W(%-/05!?5U-$3#L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?=W-D;"T^<&%R<V5/8FIE8W0H
M)'=S9&Q?;V)J+"`D=&%R9V5T3F%M97-P86-E+"`D<V5R=FEC95]N86UE+"`D
M<V5R=FEC95]D97-C*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?=W-D;"T^9F%U
M;'0I('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI
M<RT^7W=S9&PM/F9A=6QT*3L*("`@("`@("!]"B`@("!]"GT*````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="YP:'``````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#4S,``Q,#4Q-30S,3`U-P`P,C`V
M,3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@
M86X@86)S=')A8W0@=')A;G-P;W)T(&QA>65R+@H@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*
M("H@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E
M8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@
M($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC;VT^"B`J($!A=71H
M;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/@H@*B!`
M8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0
M($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]"87-E
M+G!H<"<["@HO*BH*("H@4T]!4"!4<F%N<W!O<G0@3&%Y97(*("H*("H@5&AI
M<R!L87EE<B!C86X@=7-E(&1I9F9E<F5N="!P<F]T;V-O;',@9&5P96YD86YT
M(&]N('1H92!E;F1P;VEN="!U<FP@<')O=FED960*("H@;F\@:VYO=VQE9V4@
M;V8@=&AE(%-/05`@<')O=&]C;VP@:7,@879A:6QA8FQE(&%T('1H:7,@;&5V
M96P*("H@;F\@:VYO=VQE9V4@;V8@=&AE('1R86YS<&]R="!P<F]T;V-O;',@
M:7,@879A:6QA8FQE(&%T('1H:7,@;&5V96P*("H*("H@0&%C8V5S<R`@('!U
M8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@4VAA;F4@0V%R
M879E;R`\<VAA;F5`<&AP+FYE=#X*("HO"F-L87-S(%-/05!?5')A;G-P;W)T
M"GL*("`@(&9U;F-T:6]N("9G9714<F%N<W!O<G0H)'5R;"P@)&5N8V]D:6YG
M(#T@4T]!4%]$149!54Q47T5.0T]$24Y'*0H@("`@>PH@("`@("`@("1U<FQP
M87)T<R`]($!P87)S95]U<FPH)'5R;"D["@H@("`@("`@(&EF("@A)'5R;'!A
M<G1S6R=S8VAE;64G72D@>PH@("`@("`@("`@("!R971U<FX@4T]!4%]"87-E
M7T]B:F5C=#HZ7W)A:7-E4V]A<$9A=6QT*"));G9A;&ED('1R86YS<&]R="!5
M4DDZ("1U<FPB*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')C87-E8VUP
M*"1U<FQP87)T<ULG<V-H96UE)UTL("=M86EL=&\G*2`]/2`P*2!["B`@("`@
M("`@("`@("1T<F%N<W!O<G1?='EP92`]("=33510)SL*("`@("`@("!](&5L
M<V5I9B`H<W1R8V%S96-M<"@D=7)L<&%R='-;)W-C:&5M92==+"`G:'1T<',G
M*2`]/2`P*2!["B`@("`@("`@("`@("1T<F%N<W!O<G1?='EP92`]("=(5%10
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!H86YD;&4@;W1H
M97(@=')A;G-P;W)T('1Y<&5S("HO"B`@("`@("`@("`@("1T<F%N<W!O<G1?
M='EP92`]('-T<G1O=7!P97(H)'5R;'!A<G1S6R=S8VAE;64G72D["B`@("`@
M("`@?0H@("`@("`@("1T<F%N<W!O<G1?:6YC;'5D92`]("=33T%0+U1R86YS
M<&]R="\G("X@)'1R86YS<&]R=%]T>7!E("X@)RYP:'`G.PH@("`@("`@("1R
M97,@/2!`:6YC;'5D95]O;F-E*"1T<F%N<W!O<G1?:6YC;'5D92D["B`@("`@
M("`@:68@*"$D<F5S("8F("%I;E]A<G)A>2@D=')A;G-P;W)T7VEN8VQU9&4L
M(&=E=%]I;F-L=61E9%]F:6QE<R@I*2D@>PH@("`@("`@("`@("!R971U<FX@
M4T]!4%]"87-E7T]B:F5C=#HZ7W)A:7-E4V]A<$9A=6QT*").;R!4<F%N<W!O
M<G0@9F]R('LD=7)L<&%R='-;)W-C:&5M92==?2(I.PH@("`@("`@('T*("`@
M("`@("`D=')A;G-P;W)T7V-L87-S(#T@(E-/05!?5')A;G-P;W)T7R1T<F%N
M<W!O<G1?='EP92(["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)'1R86YS
M<&]R=%]C;&%S<RDI('L*("`@("`@("`@("`@<F5T=7)N(%-/05!?0F%S95]/
M8FIE8W0Z.E]R86ES95-O87!&875L="@B3F\@5')A;G-P;W)T(&-L87-S("1T
M<F%N<W!O<G1?8VQA<W,B*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M(#TF(&YE=R`D=')A;G-P;W)T7V-L87-S*"1U<FPL("1E;F-O9&EN9RD["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U9A;'5E+G!H<```````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-3$V,``Q,#4Q
M-30S,3`U-P`P,3<V-S,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T
M:&4@8V]D92!F;W(@8V]N=F5R=&EN9R!V86QU97,@8F5T=V5E;B!33T%0(&%N
M9"!02%`N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V
M86EL86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E
M("`@(%-/05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA;&$@/&1I971R
M:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A=71H;W(@("`@
M(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@
M4$5!4B!A;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`875T:&]R("`@
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@("!-86EN=&5N
M86YC90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G
M4T]!4"]"87-E+G!H<"<["@HO*BH*("H@4T]!4#HZ5F%L=64*("H*("H@5&AI
M<R!C;&%S<R!C;VYV97)T<R!V86QU97,@8F5T=V5E;B!02%`@86YD(%-/05`N
M"B`J"B`J($]R:6=I;F%L;'D@8F%S960@;VX@4T]!4'@T(&)Y($1I971R:6-H
M($%Y86QA"B`J(&AT='`Z+R]D:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T"B`J
M"B`J($!A8V-E<W,@<'5B;&EC"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO
M<B!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O
M(%!%05(@86YD('5P9&%T97,*("H@0&%U=&AO<B!$:65T<FEC:"!!>6%L82`\
M9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S
M(%-/05!?5F%L=64*>PH@("`@+RHJ"B`@("`@*@H@("`@("H*("`@("`J($!V
M87(@('-T<FEN9PH@("`@("HO"B`@("!V87(@)'9A;'5E(#T@;G5L;#L*"B`@
M("`O*BH*("`@("`J"B`@("`@*B!`=F%R("!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1N86UE(#T@)R<["@H@("`@+RHJ"B`@("`@*@H@("`@("H@0'9A<B`@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D='EP92`]("<G.PH*("`@("\J*@H@
M("`@("H@3F%M97-P86-E"B`@("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D;F%M97-P86-E(#T@)R<["B`@("!V87(@)'1Y<&5?
M;F%M97-P86-E(#T@)R<["@H@("`@=F%R("1A='1R:6)U=&5S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)&%R<F%Y5'EP92`]("<G.PH*("`@('9A<B`D;W!T:6]N<R`]
M(&%R<F%Y*"D["@H@("`@=F%R("1N<6X["B`@("!V87(@)'1Q;CL*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("`@(&YA;64@;V8@=&AE('-O87`M=F%L=64@>VYA
M;65S<&%C97UN86UE"B`@("`@*B!`<&%R86T@;6EX960@("1T>7!E("`@("`@
M("!S;V%P('9A;'5E('MN86UE<W!A8V5]='EP92P@:68@;F]T('-E="!A;B!A
M=71O;6%T:6,*("`@("`J($!P87)A;2!M:7AE9"`@)'9A;'5E("`@("`@('9A
M;'5E('1O('-E=`H@("`@("H@0'!A<F%M(&%R<F%Y("`D871T<FEB=71E<R`@
M*&]P=&EO;F%L*2!!='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!3
M3T%07U9A;'5E*"1N86UE(#T@)R<L("1T>7!E(#T@9F%L<V4L("1V86QU92`]
M(&YU;&PL("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("`O
M+R!$971E8W0@='EP92!I9B!N;W0@<&%S<V5D+@H@("`@("`@("1T:&ES+3YN
M<6X@/28@;F5W(%%.86UE*"1N86UE*3L*("`@("`@("`D=&AI<RT^;F%M92`]
M("1T:&ES+3YN<6XM/FYA;64["B`@("`@("`@)'1H:7,M/FYA;65S<&%C92`]
M("1T:&ES+3YN<6XM/FYA;65S<&%C93L*("`@("`@("`D=&AI<RT^='%N(#TF
M(&YE=R!13F%M92@D='EP92D["B`@("`@("`@)'1H:7,M/G1Y<&4@/2`D=&AI
M<RT^='%N+3YN86UE.PH@("`@("`@("1T:&ES+3YT>7!E7W!R969I>"`]("1T
M:&ES+3YT<6XM/FYS.PH@("`@("`@("1T:&ES+3YT>7!E7VYA;65S<&%C92`]
M("1T:&ES+3YT<6XM/FYA;65S<&%C93L*("`@("`@("`D=&AI<RT^=F%L=64@
M/28@)'9A;'5E.PH@("`@("`@("1T:&ES+3YA='1R:6)U=&5S(#T@)&%T=')I
M8G5T97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!397)I86QI>F4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(%-/05!?0F%S92`F)'-E<FEA;&EZ97(@($$@4T]!
M4%]"87-E(&EN<W1A;F-E(&]R('-U8F-L87-S('1O('-E<FEA;&EZ92!W:71H
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!834P@<F5P<F5S96YT
M871I;VX@;V8@)'1H:7,N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S97)I86QI
M>F4H)B1S97)I86QI>F5R*0H@("`@>PH@("`@("`@(')E='5R;B`D<V5R:6%L
M:7IE<BT^7W-E<FEA;&EZ959A;'5E*"1T:&ES+3YV86QU92P@)'1H:7,M/FYA
M;64L("1T:&ES+3YT>7!E+"`D=&AI<RT^;F%M97-P86-E+"`D=&AI<RT^='EP
M95]N86UE<W!A8V4L("1T:&ES+3YO<'1I;VYS+"`D=&AI<RT^871T<FEB=71E
M<RP@)'1H:7,M/F%R<F%Y5'EP92D["B`@("!]"@I]"@HO*BH*("H@4T]!4#HZ
M2&5A9&5R"B`J"B`J(%1H:7,@8VQA<W,@8V]N=F5R=',@=F%L=65S(&)E='=E
M96X@4$A0(&%N9"!33T%0+B!)="!I<R!A('-I;7!L90H@*B!W<F%P<&5R(&%R
M;W5N9"!33T%07U9A;'5E+"!A9&1I;F<@<W5P<&]R="!F;W(@4T]!4"!A8W1O
M<B!A;F0*("H@;75S='5N9&5R<W1A;F0@<&%R86UE=&5R<RX*("H*("H@3W)I
M9VEN86QL>2!B87-E9"!O;B!33T%0>#0@8GD@1&EE=')I8V@@07EA;&$*("H@
M:'1T<#HO+V1I971R:6-H+F=A;G@T+F-O;2]S;V%P>#0*("H*("H@0&%C8V5S
M<R!P=6)L:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`875T:&]R(%-H86YE($-A
M<F%V96\@/'-H86YE0'!H<"YN970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@
M=7!D871E<PH@*B!`875T:&]R($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G
M86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B\*8VQA<W,@4T]!4%](96%D
M97(@97AT96YD<R!33T%07U9A;'5E"GL*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;F%M92`@("`@
M("`@("`@(&YA;64@;V8@=&AE('-O87`M=F%L=64@>VYA;65S<&%C97UN86UE
M"B`@("`@*B!`<&%R86T@;6EX960@("`D='EP92`@("`@("`@("`@('-O87`@
M=F%L=64@>VYA;65S<&%C97UT>7!E+"!I9B!N;W0@<V5T(&%N(&%U=&]M871I
M8PH@("`@("H@0'!A<F%M(&UI>&5D("`@)'9A;'5E("`@("`@("`@("!V86QU
M92!T;R!S970*("`@("`J($!P87)A;2!I;G1E9V5R("1M=7-T=6YD97)S=&%N
M9"`@6F5R;R!O<B!O;F4N"B`@("`@*B!`<&%R86T@;6EX960@("`D871T<FEB
M=71E<R`@("`@("AO<'1I;VYA;"D@071T<FEB=71E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@4T]!4%](96%D97(H)&YA;64@/2`G)RP@)'1Y<&4L("1V86QU
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("1M=7-T=6YD97)S=&%N9"`]
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB=71E<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D871T<FEB=71E
M<RDI('L*("`@("`@("`@("`@)&%C=&]R(#T@)&%T=')I8G5T97,["B`@("`@
M("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@
M("`@('!A<F5N=#HZ4T]!4%]686QU92@D;F%M92P@)'1Y<&4L("1V86QU92P@
M)&%T=')I8G5T97,I.PH*("`@("`@("!I9B`H:7-S970H)&%C=&]R*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^871T<FEB=71E<ULG4T]!4"U%3E8Z86-T;W(G
M72`]("1A8W1O<CL*("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1T:&ES+3YA
M='1R:6)U=&5S6R=33T%0+45.5CIA8W1O<B==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^871T<FEB=71E<ULG4T]!4"U%3E8Z86-T;W(G72`]("=H='1P.B\O
M<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V%C=&]R+VYE>'0G.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^871T<FEB=71E<ULG4T]!4"U%3E8Z;75S=%5N
M9&5R<W1A;F0G72`]("AI;G0I)&UU<W1U;F1E<G-T86YD.PH@("`@?0H*?0H*
M+RHJ"B`J(%-/05`Z.D%T=&%C:&UE;G0*("H@=&AI<R!C;&%S<R!C;VYV97)T
M<R!V86QU97,@8F5T=V5E;B!02%`@86YD(%-/05`*("H@:70@:&%N9&QE<R!-
M:6UE(&%T=&%C:&5M96YT<R!P97(@5S-#($YO=&4@;VX@4V]A<"!!='1A8VAE
M;65N=',@870*("H@:'1T<#HO+W=W=RYW,RYO<F<O5%(O4T]!4"UA='1A8VAM
M96YT<PH@*@H@*@H@*B!`86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!33T%0
M"B`J($!A=71H;W(@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N
M=F5R<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J+PIC;&%S<R!33T%07T%T
M=&%C:&UE;G0@97AT96YD<R!33T%07U9A;'5E"GL*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!N
M86UE(&]F('1H92!S;V%P+79A;'5E(#QV86QU95]N86UE/@H@("`@("H@0'!A
M<F%M("`@(&UI>&5D("`@<V]A<"!H96%D97(@=F%L=64*("`@("`J($!P87)A
M;2`@("!S=')I;F<@;F%M97-P86-E"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/
M05!?071T86-H;65N="@D;F%M92`]("<G+"`D='EP92`]("=A<'!L:6-A=&EO
M;B]O8W1E="US=')E86TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F:6QE;F%M92P@)&9I;&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D4T]!4%]O<'1I;VYS.PH@("`@("`@(&EF("@A:7-S970H)%-/05!?;W!T
M:6]N<ULG36EM92==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G36%I;%]M:6UE(&ES(&YO="!I;G-T86QL960L('5N86)L92!T
M;R!S=7!P;W)T(%-/05`@071T86-H96UE;G1S)RD["B`@("`@("`@?0H@("`@
M("`@('!A<F5N=#HZ4T]!4%]686QU92@D;F%M92P@;G5L;"P@;G5L;"D["@H@
M("`@("`@("1F:6QE9&%T82`]("@D9FEL92`]/3T@;G5L;"D@/R`D=&AI<RT^
M7V9I;&4R<W1R*"1F:6QE;F%M92D@.B`D9FEL93L*("`@("`@("`D9FEL96YA
M;64@/2!B87-E;F%M92@D9FEL96YA;64I.PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1F:6QE9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE
M9&%T83L*("`@("`@("!]"@H@("`@("`@("1C:60@/2!M9#4H=6YI<6ED*'1I
M;64H*2DI.PH*("`@("`@("`D=&AI<RT^871T<FEB=71E<ULG:')E9B==(#T@
M)V-I9#HG+B1C:60["@H@("`@("`@("1T:&ES+3YO<'1I;VYS6R=A='1A8VAM
M96YT)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8F]D>2<@("`@(#T^("1F:6QE9&%T82P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&ES<&]S:71I;VXG("`@("`]/B`D9FEL96YA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G1E;G1?='EP
M92<@("`]/B`D='EP92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G96YC;V1I;F<G(#T^("=B87-E-C0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C:60G(#T^("1C:60*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!C;VYT96YT<R!O9B!T:&4@9VEV96X@9FEL92!N86UE(&%S('-T<FEN
M9PH@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL95]N86UE"B`@("`@*B!`<F5T
M=7)N('-T<FEN9PH@("`@("H@0&%C8V5S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@)E]F:6QE,G-T<B@D9FEL95]N86UE*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?<F5A9&%B;&4H)&9I;&5?;F%M92DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9I;&4@:7,@;F]T(')E861A8FQE
M("<@+B`D9FEL95]N86UE*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D9F0@
M/2!F;W!E;B@D9FEL95]N86UE+"`G<F(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&]P96X@)R`N("1F:6QE
M7VYA;64I.PH@("`@("`@('T*("`@("`@("`D8V]N="`](&9R96%D*"1F9"P@
M9FEL97-I>F4H)&9I;&5?;F%M92DI.PH@("`@("`@(&9C;&]S92@D9F0I.PH@
M("`@("`@(')E='5R;B`D8V]N=#L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]33T%0+U=31$PN<&AP````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#(T-S(V,``Q,#4Q-30S,3`U-P`P,3<T,#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@9&5A
M;&EN9R!W:71H(%=31$P@86-C97-S(&%N9"!S97)V:6-E<RX*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI
M8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*
M("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O
M<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T
M:&]R("`@("!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/
M<FEG:6YA;"!!=71H;W(*("H@0&%U=&AO<B`@("`@4VAA;F4@0V%R879E;R`\
M4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E"B`J
M($!A=71H;W(@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/B`@($UA:6YT96YA;F-E"B`J($!A=71H;W(@("`@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^("`@("`@($UA:6YT96YA;F-E"B`J($!C;W!Y<FEG
M:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT("!02%`@3&EC96YS
M92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]33T%0"B`J+PH*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*
M<F5Q=6ER95]O;F-E("=33T%0+T9A=6QT+G!H<"<["G)E<75I<F5?;VYC92`G
M2%144"]297%U97-T+G!H<"<["@ID969I;F4H)U=31$Q?0T%#2$5?34%87T%'
M12<L(#0S,C`P*3L*9&5F:6YE*"=74T1,7T-!0TA%7U5312<L("`@("`P*3L@
M+R\@<V5T('1O('IE<F\@=&\@='5R;B!O9F8@8V%C:&EN9PH*+RHJ"B`J(%1H
M:7,@8VQA<W,@<&%R<V5S(%=31$P@9FEL97,L(&%N9"!C86X@8F4@=7-E9"!B
M>2!33T%0.CI#;&EE;G0@=&\*("H@<')O<&5R;'D@<F5G:7-T97(@<V]A<"!V
M86QU97,@9F]R('-E<G9I8V5S+@H@*@H@*B!/<FEG:6YA;&QY(&)A<V5D(&]N
M(%-/05!X-"!B>2!$:65T<FEC:"!!>6%L80H@*B!H='1P.B\O9&EE=')I8V@N
M9V%N>#0N8V]M+W-O87!X-`H@*@H@*B!43T1/.@H@*B`@(&%D9"!W<V1L(&-A
M8VAI;F<*("H@("!R969A8W1O<B!N86UE<W!A8V4@:&%N9&QI;F<@*"1N86UE
M<W!A8V4O)&YS*0H@*B`@(&EM<&QE;65N="!)1$P@='EP92!S>6YT87@@9&5C
M;&%R871I;VX@<V\@=V4@8V%N(&=E;F5R871E(%=31$P*("H*("H@0&%C8V5S
M<R!P=6)L:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`875T:&]R(%-H86YE($-A
M<F%V96\@/'-H86YE0'!H<"YN970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@
M=7!D871E<PH@*B!`875T:&]R($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G
M86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B\*8VQA<W,@4T]!4%]74T1,
M(&5X=&5N9',@4T]!4%]"87-E"GL*("`@('9A<B`D=&YS(#T@;G5L;#L*("`@
M('9A<B`D9&5F:6YI=&EO;B`](&%R<F%Y*"D["B`@("!V87(@)&YA;65S<&%C
M97,@/2!A<G)A>2@I.PH@("`@=F%R("1N<R`](&%R<F%Y*"D["B`@("!V87(@
M)'AS9"`](%-/05!?6$U,7U-#2$5-05]615)324]..PH@("`@=F%R("1C;VUP
M;&5X5'EP97,@/2!A<G)A>2@I.PH@("`@=F%R("1E;&5M96YT<R`](&%R<F%Y
M*"D["B`@("!V87(@)&UE<W-A9V5S(#T@87)R87DH*3L*("`@('9A<B`D<&]R
M=%1Y<&5S(#T@87)R87DH*3L*("`@('9A<B`D8FEN9&EN9W,@/2!A<G)A>2@I
M.PH@("`@=F%R("1I;7!O<G1S(#T@87)R87DH*3L*("`@('9A<B`D<V5R=FEC
M97,@/2!A<G)A>2@I.PH@("`@=F%R("1S97)V:6-E(#T@)R<["B`@("!V87(@
M)'5R:2`]("<G.PH@("`@=F%R("1D;V-S(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!0<F]X>2!P87)A;65T97)S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)'!R;WAY(#T@;G5L;#L*"B`@("!V87(@)'1R
M86-E(#T@,#L*"B`@("`O*BH*("`@("`J(%5S92!74T1,(&-A8VAE"B`@("`@
M*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D8V%C:&55
M<V4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V%C:&4@;6%X(&QI9F5T:6UE
M("AI;B!S96-O;F1S*0H@("`@("H*("`@("`J($!V87(@:6YT"B`@("`@*B\*
M("`@('9A<B`D8V%C:&5-87A!9V4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M0VQA<W,@=&\@=7-E(&9O<B!74T1,('!A<G-I;F<N($-A;B!B92!O=F5R<FED
M9&5N(&9O<B!S<&5C:6%L"B`@("`@*B!C87-E<RP@<W5B8VQA<W-E<RP@971C
M+@H@("`@("H@0'9A<B!S=')I;F<@)'=S9&Q087)S97)#;&%S<PH@("`@("HO
M"B`@("!V87(@)'=S9&Q087)S97)#;&%S<R`]("=33T%07U=31$Q?4&%R<V5R
M)SL*"B`@("`O*BH*("`@("`J(%-/05!?5U-$3"!C;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=W-D;%]U<FD@("`@(%523"!T
M;R!74T1,(&9I;&4N"B`@("`@*B!`<&%R86T@87)R87D@("`D<')O>'D@("`@
M("`@($-O;G1A:6YS(&]P=&EO;G,@9F]R($A45%!?4F5Q=65S="!C;&%S<R`H
M<V5E($A45%`O4F5Q=65S="YP:'`I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&-A8VAE57-E("`@("!5<V4@5U-$3"!C86-H:6YG+B!$969A=6QT<R!T;R!F
M86QS92X*("`@("`J($!P87)A;2!I;G1E9V5R("1C86-H94UA>$%G92`@0V%C
M:&4@;6%X(&QI9F5T:6UE("AI;B!S96-O;F1S*2X*("`@("`J($!P87)A;2!B
M;V]L96%N("1D;V-S("`@("`@("`@4&%R<V4@9&]C=6UE;G1A=&EO;B!I;B!T
M:&4@5U-$3#\@1&5F875L=',@=&\@9F%L<V4N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]74T1,*"1W
M<V1L7W5R:2`@("`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("1P
M<F]X>2`@("`@("`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M)&-A8VAE57-E("`@(#T@5U-$3%]#04-(15]54T4L"B`@("`@("`@("`@("`@
M("`@("`@("`@)&-A8VAE36%X06=E(#T@5U-$3%]#04-(15]-05A?04=%+`H@
M("`@("`@("`@("`@("`@("`@("`@("1D;V-S("`@("`@("`](&9A;'-E*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ4T]!4%]"87-E*"=74T1,)RD["B`@("`@
M("`@)'1H:7,M/G5R:2`@("`@("`@(#T@)'=S9&Q?=7)I.PH@("`@("`@("1T
M:&ES+3YP<F]X>2`@("`@("`]("1P<F]X>3L*("`@("`@("`D=&AI<RT^8V%C
M:&55<V4@("`@/2`D8V%C:&55<V4["B`@("`@("`@)'1H:7,M/F-A8VAE36%X
M06=E(#T@)&-A8VAE36%X06=E.PH@("`@("`@("1T:&ES+3YD;V-S("`@("`@
M("`]("1D;V-S.PH*("`@("`@("!I9B`H)'=S9&Q?=7)I*2!["B`@("`@("`@
M("`@("1T:&ES+3YP87)S95523"@D=W-D;%]U<FDI.PH@("`@("`@("`@("!R
M97-E="@D=&AI<RT^<V5R=FEC97,I.PH@("`@("`@("`@("`D=&AI<RT^<V5R
M=FEC92`](&ME>2@D=&AI<RT^<V5R=FEC97,I.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!S971?<V5R=FEC92@D<V5R=FEC92D*("`@('L*("`@
M("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D<V5R=FEC92P@)'1H:7,M/G-E
M<G9I8V5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5R=FEC92`]("1S97)V
M:6-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!D97!R96-A
M=&5D('5S92!P87)S95523"!I;G-T96%D"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!A<G-E*"1W<V1L7W5R:2P@)'!R;WAY(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D=&AI<RT^<&%R<V554DPH)'=S9&Q?=7)I+"`D<')O>'DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1FEL;"!T:&4@5U-$3"!A<G)A>2!T<F5E('=I
M=&@@9&%T82!F<F]M(&$@5U-$3"!F:6QE"B`@("`@*@H@("`@("H@0'!A<F%M
M("!S=')I;F<*("`@("`J($!P87)A;2`@87)R87D@('!R;WAY(')E;&%T960@
M<&%R86UE=&5R<PH@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!A<G-E55),*"1W<V1L7W5R:2P@)'!R;WAY(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D<&%R<V5R(#TF(&YE=R`D=&AI<RT^=W-D;%!A<G-E
M<D-L87-S*"1W<V1L7W5R:2P@)'1H:7,L("1T:&ES+3YD;V-S*3L*"B`@("`@
M("`@:68@*"1P87)S97(M/F9A=6QT*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)'!A<G-E<BT^9F%U;'0I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($9I;&P@=&AE(%=31$P@87)R87D@=')E92!W
M:71H(&1A=&$@9G)O;2!O;F4@;W(@;6]R92!02%`@8VQA<W,@;V)J96-T<PH@
M("`@("H*("`@("`J($!P87)A;2`@;6EX960@("1W<V1L7V]B:B!!;B!O8FIE
M8W0@;W(@87)R87D@;V8@;V)J96-T<R!T;R!A9&0@=&\@=&AE(&EN=&5R;F%L
M(%=31$P@=')E90H@("`@("H@0'!A<F%M("!S=')I;F<@("1S97)V:6-E7VYA
M;64@3F%M92!O9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!P87)A;2`@
M<W1R:6YG("`D<V5R=FEC95]D97-C($]P=&EO;F%L(&1E<V-R:7!T:6]N(&]F
M('1H92!74T1,(#QS97)V:6-E/@H@("`@("H@0')E='5R;B!V;VED"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!A<G-E3V)J96-T*"8D=W-D;%]O8FHL("1T87)G
M971.86UE<W!A8V4L("1S97)V:6-E7VYA;64L("1S97)V:6-E7V1E<V,@/2`G
M)RD*("`@('L*("`@("`@("`D<&%R<V5R(#TF(&YE=R!33T%07U=31$Q?3V)J
M96-T4&%R<V5R*"1W<V1L7V]B:BP@)'1H:7,L("1T87)G971.86UE<W!A8V4L
M("1S97)V:6-E7VYA;64L("1S97)V:6-E7V1E<V,I.PH*("`@("`@("`@:68@
M*"1P87)S97(M/F9A=6QT*2!["B`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"1P87)S97(M/F9A=6QT*3L*("`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$5N9'!O:6YT*"1P;W)T3F%M92D*("`@('L*("`@
M("`@("!R971U<FX@*&ES<V5T*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R
M=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG861D<F5S<R==6R=L;V-A=&EO
M;B==*2D*("`@("`@("`@("`@("`@(#\@)'1H:7,M/G-E<G9I8V5S6R1T:&ES
M+3YS97)V:6-E75LG<&]R=',G75LD<&]R=$YA;65=6R=A9&1R97-S)UU;)VQO
M8V%T:6]N)UT*("`@("`@("`@("`@("`@(#H@)'1H:7,M/E]R86ES95-O87!&
M875L="@B;F\@96YD<&]I;G0@9F]R('!O<G0@9F]R("1P;W)T3F%M92(L("1T
M:&ES+3YU<FDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G9710;W)T3F%M92@D
M;W!E<F%T:6]N+"`D<V5R=FEC92D*("`@('L*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/G-E<G9I8V5S6R1S97)V:6-E75LG<&]R=',G72DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/G-E<G9I8V5S6R1S97)V:6-E75LG<&]R
M=',G72!A<R`D<&]R="`]/B`D<&]R=$%T=')S*2!["B`@("`@("`@("`@("`@
M("`D='EP92`]("1T:&ES+3YS97)V:6-E<ULD<V5R=FEC95U;)W!O<G1S)UU;
M)'!O<G1=6R=T>7!E)UT["B`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@
M)W-O87`G("8F"B`@("`@("`@("`@("`@("`@("`@:7-S970H)'1H:7,M/F)I
M;F1I;F=S6R1P;W)T071T<G-;)V)I;F1I;F<G75U;)V]P97)A=&EO;G,G75LD
M;W!E<F%T:6]N72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!O
M<G0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!F
M:6YD('1H92!N86UE(&]F('1H92!F:7)S="!P;W)T('1H870@8V]N=&%I;G,@
M86X@;W!E<F%T:6]N(&]F"B`@("`@*B!N86UE("1O<&5R871I;VXN("!A;'=A
M>7,@<F5T=7)N<R!A('1H92!S;V%P('!O<G1.86UE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9710;W)T3F%M92@D;W!E<F%T:6]N+"`D<V5R=FEC92`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"$D<V5R=FEC92D@)'-E<G9I8V4@/2`D
M=&AI<RT^<V5R=FEC93L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/G-E<G9I
M8V5S6R1S97)V:6-E75LG<&]R=',G72DI('L*("`@("`@("`@("`@)'!O<G1.
M86UE(#T@)'1H:7,M/E]G9710;W)T3F%M92@D;W!E<F%T:6]N+"`D<V5R=FEC
M92D["B`@("`@("`@("`@(&EF("@D<&]R=$YA;64I(')E='5R;B`D<&]R=$YA
M;64["B`@("`@("`@?0H@("`@("`@("\O(%1R>2!A;GD@<V5R=FEC92!I;B!T
M:&4@5U-$3"X*("`@("`@("!F;W)E86-H("@D=&AI<RT^<V5R=FEC97,@87,@
M)'-E<G9I8V5.86UE(#T^("1S97)V:6-E*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^<V5R=FEC97-;)'-E<G9I8V5.86UE75LG<&]R=',G72DI
M('L*("`@("`@("`@("`@("`@("1P;W)T3F%M92`]("1T:&ES+3Y?9V5T4&]R
M=$YA;64H)&]P97)A=&EO;BP@)'-E<G9I8V5.86UE*3L*("`@("`@("`@("`@
M("`@(&EF("@D<&]R=$YA;64I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5R=FEC92`]("1S97)V:6-E3F%M93L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'!O<G1.86UE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*")N;R!O<&5R871I;VX@)&]P97)A=&EO;B!I;B!W<V1L(BP@
M)'1H:7,M/G5R:2D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T3W!E<F%T:6]N
M1&%T82@D<&]R=$YA;64L("1O<&5R871I;VXI"B`@("!["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UU;)'!O<G1.86UE75LG8FEN9&EN9R==*0H@("`@("`@("`@("`F)B`D8FEN
M9&EN9R`]("1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UU;)'!O<G1.86UE75LG8FEN9&EN9R==*2!["B`@("`@("`@("`@("\O(&=E
M="!O<&5R871I;VX@9&%T82!F<F]M(&)I;F1I;F<*("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T:&ES+3YB:6YD:6YG<ULD8FEN9&EN9UU;)V]P97)A=&EO
M;G,G75LD;W!E<F%T:6]N72DI('L*("`@("`@("`@("`@("`@("1O<$1A=&$@
M/2`D=&AI<RT^8FEN9&EN9W-;)&)I;F1I;F==6R=O<&5R871I;VYS)UU;)&]P
M97)A=&EO;ET["B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@9V5T(&]P
M97)A=&EO;B!D871A(&9R;VT@<&]R='1Y<&4*("`@("`@("`@("`@)'!O<G14
M>7!E(#T@)'1H:7,M/F)I;F1I;F=S6R1B:6YD:6YG75LG='EP92==.PH@("`@
M("`@("`@("!I9B`H(21P;W)T5'EP92D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(FYO('!O<G0@='EP92!F;W(@
M8FEN9&EN9R`D8FEN9&EN9R!I;B!W<V1L("(@+B`D=&AI<RT^=7)I*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/G!O
M<G14>7!E<ULD<&]R=%1Y<&5=6R1O<&5R871I;VY=*2D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YP;W)T5'EP97-;)'!O<G14>7!E75LD
M;W!E<F%T:6]N75LG<&%R86UE=&5R3W)D97(G72DI"B`@("`@("`@("`@("`@
M("`@("`@)&]P1&%T85LG<&%R86UE=&5R3W)D97(G72`]("1T:&ES+3YP;W)T
M5'EP97-;)'!O<G14>7!E75LD;W!E<F%T:6]N75LG<&%R86UE=&5R3W)D97(G
M73L*("`@("`@("`@("`@("`@("1O<$1A=&%;)VEN<'5T)UT@/2!A<G)A>5]M
M97)G92@D;W!$871A6R=I;G!U="==+"`D=&AI<RT^<&]R=%1Y<&5S6R1P;W)T
M5'EP95U;)&]P97)A=&EO;EU;)VEN<'5T)UTI.PH@("`@("`@("`@("`@("`@
M)&]P1&%T85LG;W5T<'5T)UT@/2!A<G)A>5]M97)G92@D;W!$871A6R=O=71P
M=70G72P@)'1H:7,M/G!O<G14>7!E<ULD<&]R=%1Y<&5=6R1O<&5R871I;VY=
M6R=O=71P=70G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D
M;W!$871A*0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H(FYO(&]P97)A=&EO;B`D;W!E<F%T:6]N(&9O<B!P;W)T("1P
M;W)T3F%M92P@:6X@=W-D;"(L("1T:&ES+3YU<FDI.PH@("`@("`@("`@("`D
M;W!$871A6R=P87)A;65T97)S)UT@/2!F86QS93L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YB:6YD:6YG<ULD=&AI<RT^<V5R=FEC97-;)'1H:7,M
M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T3F%M95U;)V)I;F1I;F<G75U;)V]P
M97)A=&EO;G,G75LD;W!E<F%T:6]N75LG:6YP=70G75LG;F%M97-P86-E)UTI
M*0H@("`@("`@("`@("`@("`@)&]P1&%T85LG;F%M97-P86-E)UT@/2`D=&AI
M<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG
M<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG)UU=6R=O<&5R871I;VYS)UU;
M)&]P97)A=&EO;EU;)VEN<'5T)UU;)VYA;65S<&%C92==.PH@("`@("`@("`@
M("`O+R!M97-S86=E(&1A=&$@9G)O;2!M97-S86=E<PH@("`@("`@("`@("`D
M:6YP=71-<V<@/2`D;W!$871A6R=I;G!U="==6R=M97-S86=E)UT["B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^;65S<V%G97-;)&EN<'5T37-G
M72DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM97-S86=E
M<ULD:6YP=71-<V==(&%S("1P;F%M92`]/B`D<&%T=')S*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1O<$1A=&%;)W-T>6QE)UT@/3T@)V1O8W5M96YT
M)R`F)B`D;W!$871A6R=I;G!U="==6R=U<V4G72`]/2`G;&ET97)A;"<*("`@
M("`@("`@("`@("`@("`@("`@("`@)B8@)'!N86UE(#T]("=P87)A;65T97)S
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!$871A6R=P87)A;65T
M97)S)UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!$871A
M6R=N86UE<W!A8V4G72`]("1T:&ES+3YN86UE<W!A8V5S6R1P871T<G-;)VYA
M;65S<&%C92==73L*("`@("`@("`@("`@("`@("`@("`@("`@)&5L(#T@)'1H
M:7,M/F5L96UE;G1S6R1P871T<G-;)VYA;65S<&%C92==75LD<&%T=')S6R=T
M>7!E)UU=.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5L
M6R=E;&5M96YT<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&5L6R=E;&5M96YT<R==(&%S("1E;&YA;64@/3X@)&5L871T
M<G,I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W!$871A
M6R=I;G!U="==6R=P87)T<R==6R1E;&YA;65=(#T@)&5L871T<G,["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;W!$871A6R=I;G!U="==6R=P87)T<R==6R1P;F%M
M95T@/2`D<&%T=')S.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T<'5T37-G
M(#T@)&]P1&%T85LG;W5T<'5T)UU;)VUE<W-A9V4G73L*("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T:&ES+3YM97-S86=E<ULD;W5T<'5T37-G72DI('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM97-S86=E<ULD;W5T
M<'5T37-G72!A<R`D<&YA;64@/3X@)'!A='1R<RD@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D;W!$871A6R=S='EL92==(#T]("=D;V-U;65N="<@)B8@
M)&]P1&%T85LG;W5T<'5T)UU;)W5S92==(#T]("=L:71E<F%L)PH@("`@("`@
M("`@("`@("`@("`@("`@("`F)B`D<&YA;64@/3T@)W!A<F%M971E<G,G*2![
M"@H@("`@("`@("`@("`@("`@("`@("`@("`D96P@/2`D=&AI<RT^96QE;65N
M='-;)'!A='1R<ULG;F%M97-P86-E)UU=6R1P871T<G-;)W1Y<&4G75T["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96Q;)V5L96UE;G1S
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M96Q;)V5L96UE;G1S)UT@87,@)&5L;F%M92`]/B`D96QA='1R<RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<$1A=&%;)V]U='!U="==
M6R=P87)T<R==6R1E;&YA;65=(#T@)&5L871T<G,["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;W!$871A6R=O=71P=70G75LG<&%R=',G75LD<&YA;65=(#T@)'!A
M='1R<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1O<$1A=&$["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*")N;R!B:6YD:6YG(&9O<B!P;W)T("1P;W)T3F%M92!I;B!W<V1L(BP@)'1H
M:7,M/G5R:2D["B`@("!]"@H@("`@9G5N8W1I;VX@;6%T8VA-971H;V0H)B1O
M<&5R871I;VXI"B`@("!["B`@("`@("`@+R\@3W9E<FQO861I;F<@;&]W97)C
M87-E<R!F=6YC=&EO;B!N86UE<R`Z*`H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UT@87,@)'!O<G0@
M/3X@)'!O<G1!='1R<RD@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K
M97ES*"1T:&ES+3YB:6YD:6YG<ULD<&]R=$%T=')S6R=B:6YD:6YG)UU=6R=O
M<&5R871I;VYS)UTI(&%S("1O<"D@>PH@("`@("`@("`@("`@("`@:68@*'-T
M<F-A<V5C;7`H)&]P+"`D;W!E<F%T:6]N*2`]/2`P*2!["B`@("`@("`@("`@
M("`@("`@("`@)&]P97)A=&EO;B`]("1O<#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(&=E=$1A=&%(86YD;&5R"B`@("`@*@H@("`@("H@1VEV96X@82!D871A='EP
M92P@=VAA="!F=6YC=&EO;B!H86YD;&5S('1H92!P<F]C97-S:6YG/PH@("`@
M("H@=&AI<R!I<R!U<V5D(&9O<B!D;V,O;&ET97)A;"!R97%U97-T<R!W:&5R
M92!W92!R96-E:79E"B`@("`@*B!A(&1A=&%T>7!E+"!A;F0@=V4@;F5E9"!T
M;R!P87-S(&ET('1O(&$@;65T:&]D(&EN(&]U=`H@("`@("H@<V5R=F5R(&-L
M87-S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!D871A='EP90H@("`@
M("H@0'!A<F%M('-T<FEN9R!N86UE<W!A8V4*("`@("`J($!R971U<FYS('-T
M<FEN9R!M971H;V1N86UE"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G971$871A2&%N9&QE<B@D9&%T871Y<&4L("1N86UE
M<W!A8V4I"B`@("!["B`@("`@("`@+R\@<V5E(&EF('=E(&AA=F4@86X@96QE
M;65N="!B>2!T:&ES(&YA;64*("`@("`@("!I9B`H:7-S970H)'1H:7,M/FYA
M;65S<&%C97-;)&YA;65S<&%C95TI*0H@("`@("`@("`@("`D;F%M97-P86-E
M(#T@)'1H:7,M/FYA;65S<&%C97-;)&YA;65S<&%C95T["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YN<ULD;F%M97-P86-E72DI('L*("`@("`@("`@("`@
M)&YS<"`]("1T:&ES+3YN<ULD;F%M97-P86-E73L*("`@("`@("`@("`@+R]I
M9B`H(6ES<V5T*"1T:&ES+3YE;&5M96YT<ULD;G-P72DI"B`@("`@("`@("`@
M("\O("`@("1N<W`@/2`D=&AI<RT^;F%M97-P86-E<ULD;G-P73L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YE;&5M96YT<ULD;G-P75LD9&%T871Y
M<&5=*2D@>PH@("`@("`@("`@("`@("`@)&-H96-K;65S<V%G97,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@+R\@9FEN9"!W:&%T(&UE<W-A9V5S('5S
M92!T:&ES(&1A=&%T>7!E"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^;65S<V%G97,@87,@)&UE<W-A9V5N86UE(#T^("1M97-S86=E*2!["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UE<W-A9V4@87,@)'!A<G1N
M86UE(#T^("1P87)T*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M<&%R=%LG='EP92==(#T]("1D871A='EP92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-H96-K;65S<V%G97-;72`]("1M97-S86=E;F%M93L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@9FEN9"!T:&4@;W!E<F%T
M:6]N('1H870@=7-E<R!T:&ES(&UE<W-A9V4*("`@("`@("`@("`@("`@("1D
M871A2&%N9&QE<B`](&YU;&P["B`@("`@("`@("`@("`@("!F;W)E86-H*"1T
M:&ES+3YP;W)T5'EP97,@87,@)'!O<G1N86UE(#T^("1P;W)T='EP92D@>PH@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P;W)T='EP92!A<R`D;W!N
M86UE(#T^("1O<&EN9F\I('L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&-H96-K;65S<V%G97,@87,@)&UE<W-A9V5N86UE*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&]P:6YF;ULG:6YP=70G75LG
M;65S<V%G92==(#T]("1M97-S86=E;F%M92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D;W!N86UE.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=%-O87!!8W1I;VXH)'!O<G1.86UE+"`D;W!E<F%T
M:6]N*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8FEN9&EN9W-;
M)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G75LD<&]R
M=$YA;65=6R=B:6YD:6YG)UU=6R=O<&5R871I;VYS)UU;)&]P97)A=&EO;EU;
M)W-O87!!8W1I;VXG72D@)B8*("`@("`@("`@("`@)'-O87!!8W1I;VX@/2`D
M=&AI<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E
M75LG<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG)UU=6R=O<&5R871I;VYS
M)UU;)&]P97)A=&EO;EU;)W-O87!!8W1I;VXG72D@>PH@("`@("`@("`@("!R
M971U<FX@)'-O87!!8W1I;VX["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971.86UE<W!A8V4H)'!O<G1.
M86UE+"`D;W!E<F%T:6]N*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG
M<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG)UU=*2`F)@H@("`@("`@("`@
M("!I<W-E="@D=&AI<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S6R1T:&ES
M+3YS97)V:6-E75LG<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG)UU=6R=O
M<&5R871I;VYS)UU;)&]P97)A=&EO;EU;)VEN<'5T)UU;)VYA;65S<&%C92==
M*2`F)@H@("`@("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/F)I;F1I;F=S
M6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;)'!O
M<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=
M6R=I;G!U="==6R=N86UE<W!A8V4G72D@>PH@("`@("`@("`@("!R971U<FX@
M)&YA;65S<&%C93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$YA;65S<&%C94%T=')I8G5T94YA;64H
M)&YA;65S<&%C92D*("`@('L*("`@("`@("`O*B!)9B!I="!D;V5S;B=T(&5X
M:7-T(&%T(&9I<G-T+"!F;&EP('1H92!A<G)A>2!A;F0@8VAE8VL*("`@("`@
M("`@*B!A9V%I;BX@*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M/FYS6R1N
M86UE<W!A8V5=*2D@>PH@("`@("`@("`@("`D=&AI<RT^;G,@/2!A<G)A>5]F
M;&EP*"1T:&ES+3YN86UE<W!A8V5S*3L*("`@("`@("!]"B`@("`@("`@+RH@
M268@:70@9&]E<VXG="!E>&ES="!N;W<L(&%D9"!I="X@*B\*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/FYS6R1N86UE<W!A8V5=*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F%D9$YA;65S<&%C92@D;F%M97-P86-E*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^;G-;)&YA;65S<&%C95T[
M"B`@("!]"@H@("`@9G5N8W1I;VX@861D3F%M97-P86-E*"1N86UE<W!A8V4I
M"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^;G-;)&YA;65S<&%C
M95TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;G-;)&YA;65S<&%C
M95T["B`@("`@("`@?0H*("`@("`@("`D;B`](&-O=6YT*"1T:&ES+3YN<RD[
M"B`@("`@("`@)&%T='(@/2`G;G,G("X@)&X["B`@("`@("`@)'1H:7,M/FYA
M;65S<&%C97-;)VYS)R`N("1N72`]("1N86UE<W!A8V4["B`@("`@("`@)'1H
M:7,M/FYS6R1N86UE<W!A8V5=(#T@)&%T='(["B`@("`@("`@<F5T=7)N("1A
M='1R.PH@("`@?0H*("`@(&9U;F-T:6]N(%]V86QI9&%T95-T<FEN9R@D<W1R
M:6YG*0H@("`@>PH@("`@("`@("\O(%A86"!T:&ES('-H;W5L9"!B92!D;VYE
M('-O;VYE<B!O<B!L871E<@H@("`@("`@("\O(')E='5R;B!T<G5E.PH@("`@
M("`@(')E='5R;B!P<F5G7VUA=&-H*"(O7EM<=U\Z(UPO72LD+R(L("1S=')I
M;F<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]A9&1!<F<H)B1A<F=S+"`F)&%R
M9V%R<F%Y+"`D87)G;F%M92D*("`@('L*("`@("`@("!I9B`H)&%R9W,I('L*
M("`@("`@("`@("`@)&%R9W,@+CT@)RP@)SL*("`@("`@("!]"B`@("`@("`@
M)&%R9W,@+CT@(EPD(B`N("1A<F=N86UE.PH@("`@("`@(&EF("@A)'1H:7,M
M/E]V86QI9&%T95-T<FEN9R@D87)G;F%M92DI('L*("`@("`@("`@("`@<F5T
M=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D87)G87)R87DI('L*
M("`@("`@("`@("`@)&%R9V%R<F%Y("X]("<L("<["B`@("`@("`@?0H@("`@
M("`@("1A<F=A<G)A>2`N/2`B)R1A<F=N86UE)R`]/B!<)"(@+B`D87)G;F%M
M93L*("`@('T*"B`@("!F=6YC=&EO;B!?96QE;65N=$%R9R@F)&%R9W,L("8D
M87)G87)R87DL("8D7V%R9W1Y<&4L("1?87)G;F%M92D*("`@('L*("`@("`@
M("`D8V]M;65N=',@/2`G)SL*("`@("`@("`D96P@/2`D=&AI<RT^96QE;65N
M='-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75U;)%]A<F=T>7!E6R=T>7!E)UU=
M.PH@("`@("`@("1T;G,@/2!I<W-E="@D=&AI<RT^;G-;)&5L6R=N86UE<W!A
M8V4G75TI(#\@)'1H:7,M/FYS6R1E;%LG;F%M97-P86-E)UU=(#H@)%]A<F=T
M>7!E6R=N86UE<W!A8V4G73L*"B`@("`@("`@:68@*"%E;7!T>2@D96Q;)V-O
M;7!L97@G72D@?'P@*&ES<V5T*"1E;%LG='EP92==*2`F)B!I<W-E="@D=&AI
M<RT^8V]M<&QE>%1Y<&5S6R1T;G-=6R1E;%LG='EP92==72DI*2!["B`@("`@
M("`@("`@("\O(%1H92!E;&5M96YT(&ES(&$@8V]M<&QE>"!T>7!E+@H@("`@
M("`@("`@("`D8V]M;65N=',@+CT@(B`@("`@("`@+R\@>R1?87)G='EP95LG
M='EP92==?2!I<R!A($-O;7!L97A4>7!E+"!R969E<B!T;R!T:&4@5U-$3"!F
M;W(@;6]R92!I;F9O+EQN(CL*("`@("`@("`@("`@)&%T=')N86UE(#T@(GLD
M7V%R9W1Y<&5;)W1Y<&4G77U?871T<B(["B`@("`@("`@("`@(&EF("AI<W-E
M="@D96Q;)W1Y<&4G72D@)B8@:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD
M=&YS75LD96Q;)W1Y<&4G75U;)V%T=')I8G5T92==*2D@>PH@("`@("`@("`@
M("`@("`@)&-O;6UE;G1S("X]("(@("`@("`@("\O('LD7V%R9W1Y<&5;)W1Y
M<&4G77T@;6%Y(')E<75I<F4@871T<FEB=71E<RP@<F5F97(@=&\@=&AE(%=3
M1$P@9F]R(&UO<F4@:6YF;RY<;B(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&-O;6UE;G1S("X]("(@("`@("`@(%PD>R1A='1R;F%M97U;)WAM;&YS
M)UT@/2`G>R1T:&ES+3YN86UE<W!A8V5S6R1?87)G='EP95LG;F%M97-P86-E
M)UU=?2<[7&XB.PH@("`@("`@("`@("`D8V]M;65N=',@+CT@(B`@("`@("`@
M7"1[)%]A<F=T>7!E6R=T>7!E)UU](#TF(&YE=R!33T%07U9A;'5E*"=[)%]A
M<F=T>7!E6R=T>7!E)UU])RP@9F%L<V4L(%PD>R1?87)G='EP95LG='EP92==
M?2P@7"0D871T<FYA;64I.UQN(CL*("`@("`@("`@("`@)'1H:7,M/E]A9&1!
M<F<H)&%R9W,L("1A<F=A<G)A>2P@)%]A<F=T>7!E6R=T>7!E)UTI.PH@("`@
M("`@("`@("!I9B`H:7-S970H)&5L6R=T>7!E)UTI("8F(&ES<V5T*"1T:&ES
M+3YC;VUP;&5X5'EP97-;)'1N<UU;)&5L6R=T>7!E)UU=6R=A='1R:6)U=&4G
M72DI('L*("`@("`@("`@("`@("`@(&EF("@D87)G<RD@>PH@("`@("`@("`@
M("`@("`@("`@("1A<F=S("X]("<L("<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D87)G<R`N/2`G)"<@+B`D871T<FYA;64["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-S970H)&5L6R=E;&5M96YT
M<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D96Q;)V5L96UE;G1S)UT@
M87,@)&5N86UE(#T^("1E;&5M96YT*2!["B`@("`@("`@("`@("`@("`D8V]M
M;65N=',@+CT@(B`@("`@("`@7"0D96YA;64@/28@;F5W(%-/05!?5F%L=64H
M)WM[)'1H:7,M/FYA;65S<&%C97-;)&5L96UE;G1;)VYA;65S<&%C92==77U]
M)&5N86UE)RP@)R(@+@H@("`@("`@("`@("`@("`@("`@("AI<W-E="@D96QE
M;65N=%LG='EP92==*2`_("1E;&5M96YT6R=T>7!E)UT@.B!F86QS92D@+B`B
M)RP@7"0D96YA;64I.UQN(CL*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D
M07)G*"1A<F=S+"`D87)G87)R87DL("1E;F%M92D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V]M;65N=',@+CT@(B`@
M("`@("`@7"0D7V%R9VYA;64@/28@;F5W(%-/05!?5F%L=64H)WM[)'1H:7,M
M/FYA;65S<&%C97-;)'1N<UU]?21?87)G;F%M92<L("=[)&5L6R=T>7!E)UU]
M)RP@7"0D7V%R9VYA;64I.UQN(CL*("`@("`@("`@("`@)'1H:7,M/E]A9&1!
M<F<H)&%R9W,L("1A<F=A<G)A>2P@)%]A<F=N86UE*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8V]M;65N=',["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V-O;7!L97A4>7!E07)G*"8D87)G<RP@)B1A<F=A<G)A>2P@)B1?87)G='EP
M92P@)%]A<F=N86UE*0H@("`@>PH@("`@("`@("1C;VUM96YT<R`]("<G.PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1?87)G='EP
M95LG;F%M97-P86-E)UU=6R1?87)G='EP95LG='EP92==72DI('L*("`@("`@
M("`@("`@)&-O;6UE;G1S("`]("(@("`@("`@("\O("1?87)G;F%M92!I<R!A
M($-O;7!L97A4>7!E('LD7V%R9W1Y<&5;)W1Y<&4G77TL7&XB.PH@("`@("`@
M("`@("`D8V]M;65N=',@+CT@(B`@("`@("`@+R\@<F5F97(@=&\@=W-D;"!F
M;W(@;6]R92!I;F9O7&XB.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F-O;7!L97A4>7!E<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==75LD7V%R9W1Y
M<&5;)W1Y<&4G75U;)V%T=')I8G5T92==*2D@>PH@("`@("`@("`@("`@("`@
M)&-O;6UE;G1S("X]("(@("`@("`@("\O("1?87)G;F%M92!M87D@<F5Q=6ER
M92!A='1R:6)U=&5S+"!R969E<B!T;R!W<V1L(&9O<B!M;W)E(&EN9F]<;B([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=R87!N86UE(#T@)WLG("X@
M)'1H:7,M/FYA;65S<&%C97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75TN)WTG
M("X@)%]A<F=T>7!E6R=T>7!E)UT["B`@("`@("`@("`@("1C;VUM96YT<R`N
M/2`B("`@("`@("!<)"1?87)G;F%M92`])B!N97<@4T]!4%]686QU92@G)%]A
M<F=N86UE)RP@)R1W<F%P;F%M92<L(%PD)%]A<F=N86UE*3M<;B(["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V%D9$%R9R@D87)G<RP@)&%R9V%R<F%Y
M+"`D7V%R9VYA;64I.PH@("`@("`@(')E='5R;B`D8V]M;65N=',["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@<W1U8B!C;V1E(&9R;VT@=&AE
M(%=31$P@=&AA="!C86X@8F4@<V%V960@=&\@82!F:6QE"B`@("`@*B!O<B!E
M=F%L)V0@:6YT;R!E>&ES=&5N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M;F5R871E4')O>'E#;V1E*"1P;W)T(#T@)R<L("1C;&%S<VYA;64])R<I"B`@
M("!["B`@("`@("`@)&UU;'1I<&]R="`](&-O=6YT*"1T:&ES+3YS97)V:6-E
M<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI(#X@,3L*("`@("`@("!I9B`H
M(21P;W)T*2!["B`@("`@("`@("`@(')E<V5T*"1T:&ES+3YS97)V:6-E<ULD
M=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI.PH@("`@("`@("`@("`D<&]R="`]
M(&-U<G)E;G0H)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R
M=',G72D["B`@("`@("`@?0H@("`@("`@("\O(%A86"!C=7)R96YT;'D@9&\@
M;F]T('-U<'!O<G0@2%144"!P;W)T<PH@("`@("`@(&EF("@D<&]R=%LG='EP
M92==("$]("=S;V%P)RD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("!]"@H@("`@("`@("\O(%A86"!C=7)R96YT4&]R="!I<R!"040*("`@
M("`@("`D8VQI96YT=7)L(#T@)'!O<G1;)V%D9')E<W,G75LG;&]C871I;VXG
M73L*("`@("`@("!I9B`H(21C;&%S<VYA;64I('L*("`@("`@("`@("`@:68@
M*"1M=6QT:7!O<G0@?'P@)'!O<G0I('L*("`@("`@("`@("`@("`@("1C;&%S
M<VYA;64@/2`G5V5B4V5R=FEC95\G("X@)'1H:7,M/G-E<G9I8V4@+B`G7R<@
M+B`D<&]R=%LG;F%M92==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&-L87-S;F%M92`]("=796)397)V:6-E7R<@+B`D=&AI<RT^
M<V5R=FEC93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8VQA<W-N86UE
M(#T@<')E9U]R97!L86-E*"<O6R`N7"U<*%PI72LO)RP@)U\G+"`D8VQA<W-N
M86UE*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/E]V86QI9&%T
M95-T<FEN9R@D8VQA<W-N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L
M;#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^<')O
M>'DI("8F(&-O=6YT*"1T:&ES+3YP<F]X>2DI('L*("`@("`@("`@("`@)&-L
M87-S(#T@(F-L87-S("1C;&%S<VYA;64@97AT96YD<R!33T%07T-L:65N=%QN
M>UQN(B`N"B`@("`@("`@("`@("(@("`@9G5N8W1I;VX@)&-L87-S;F%M92A<
M)'!A=&@@/2`G)&-L:65N='5R;"<I7&X@("`@>UQN(B`N"B`@("`@("`@("`@
M("(@("`@("`@(%PD=&AI<RT^4T]!4%]#;&EE;G0H7"1P871H+"`P+"`P+%QN
M(B`N"B`@("`@("`@("`@("<@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G.PH*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/G!R;WAY(&%S
M("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1V86PI*2!["B`@("`@("`@("`@("`@("`@("`@)&-L87-S("X]("(G)&ME
M>2<@/3X@87)R87DH(CL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M=F%L(&%S("1K97DR(#T^("1V86PR*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C;&%S<R`N/2`B)R1K97DR)R`]/B`G)'9A;#(G+"`B.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@+CT@
M)RDG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D8VQA<W,@+CT@(B<D:V5Y)R`]/B`G)'9A;"<L("(["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-L87-S("X]
M("(I*3M<;B`@("!]7&XB.PH@("`@("`@("`@("`D8VQA<W,@/2!S=')?<F5P
M;&%C92@G+"`I*2<L("<I*2<L("1C;&%S<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-L87-S(#T@(F-L87-S("1C;&%S<VYA;64@97AT96YD
M<R!33T%07T-L:65N=%QN>UQN(B`N"B`@("`@("`@("`@("(@("`@9G5N8W1I
M;VX@)&-L87-S;F%M92A<)'!A=&@@/2`G)&-L:65N='5R;"<I7&X@("`@>UQN
M(B`N"B`@("`@("`@("`@("(@("`@("`@(%PD=&AI<RT^4T]!4%]#;&EE;G0H
M7"1P871H+"`P*3M<;B(@+@H@("`@("`@("`@("`B("`@('U<;B(["B`@("`@
M("`@?0H*("`@("`@("`O+R!G970@=&AE(&)I;F1I;F<L(&9R;VT@=&AA="!G
M970@=&AE('!O<G0@='EP90H@("`@("`@("1P<FEM87)Y0FEN9&EN9R`]("1P
M;W)T6R=B:6YD:6YG)UT[("\O)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V
M:6-E75LG<&]R=',G75LD<&]R=%LG;F%M92==75LB8FEN9&EN9R)=.PH@("`@
M("`@("1P<FEM87)Y0FEN9&EN9R`]('!R96=?<F5P;&%C92@B+UXH+BHZ*2\B
M+"`G)RP@)'!R:6UA<GE":6YD:6YG*3L*("`@("`@("`D<&]R=%1Y<&4@/2`D
M=&AI<RT^8FEN9&EN9W-;)'!R:6UA<GE":6YD:6YG75LG='EP92==.PH@("`@
M("`@("1P;W)T5'EP92`]('!R96=?<F5P;&%C92@B+UXH+BHZ*2\B+"`G)RP@
M)'!O<G14>7!E*3L*("`@("`@("`D<W1Y;&4@/2`D=&AI<RT^8FEN9&EN9W-;
M)'!R:6UA<GE":6YD:6YG75LG<W1Y;&4G73L*"B`@("`@("`@+R\@6%A8(&-U
M<G)E;G10;W)T5'EP92!I<R!"040*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M<&]R=%1Y<&5S6R1P;W)T5'EP95T@87,@)&]P;F%M92`]/B`D;W!E<F%T:6]N
M*2!["B`@("`@("`@("`@("1S;V%P86-T:6]N(#T@:7-S970H)'1H:7,M/F)I
M;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD;W!N86UE
M75LG<V]A<$%C=&EO;B==*2`_"B`@("`@("`@("`@("`@("`D=&AI<RT^8FEN
M9&EN9W-;)'!R:6UA<GE":6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&YA;65=
M6R=S;V%P06-T:6]N)UT@.@H@("`@("`@("`@("`@("`@;G5L;#L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YB:6YD:6YG<ULD<')I;6%R>4)I;F1I
M;F==6R=O<&5R871I;VYS)UU;)&]P;F%M95U;)W-T>6QE)UTI*2!["B`@("`@
M("`@("`@("`@("`D;W!S='EL92`]("1T:&ES+3YB:6YD:6YG<ULD<')I;6%R
M>4)I;F1I;F==6R=O<&5R871I;VYS)UU;)&]P;F%M95U;)W-T>6QE)UT["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;W!S='EL92`]
M("1S='EL93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=7-E(#T@)'1H
M:7,M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD
M;W!N86UE75LG:6YP=70G75LG=7-E)UT["B`@("`@("`@("`@(&EF("@D=7-E
M(#T]("=E;F-O9&5D)RD@>PH@("`@("`@("`@("`@("`@)&YA;65S<&%C92`]
M("1T:&ES+3YB:6YD:6YG<ULD<')I;6%R>4)I;F1I;F==6R=O<&5R871I;VYS
M)UU;)&]P;F%M95U;)VEN<'5T)UU;)VYA;65S<&%C92==.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&)I;F1I;F=4>7!E(#T@)'1H
M:7,M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)W1Y<&4G73L*("`@("`@
M("`@("`@("`@("1N<R`]("1T:&ES+3YP;W)T5'EP97-;)&)I;F1I;F=4>7!E
M75LD;W!N86UE75LG:6YP=70G75LG;F%M97-P86-E)UT["B`@("`@("`@("`@
M("`@("`D;F%M97-P86-E(#T@)'1H:7,M/FYA;65S<&%C97-;)&YS73L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&%R9W,@/2`G)SL*("`@("`@("`@
M("`@)&%R9V%R<F%Y(#T@)R<["B`@("`@("`@("`@("1C;VUM96YT<R`]("<G
M.PH@("`@("`@("`@("`D=W)A<'!E<G,@/2`G)SL*("`@("`@("`@("`@9F]R
M96%C:"`H)&]P97)A=&EO;ELG:6YP=70G72!A<R`D87)G;F%M92`]/B`D87)G
M='EP92D@>PH@("`@("`@("`@("`@("`@:68@*"1A<F=N86UE(#T]("=M97-S
M86=E)RD@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM
M97-S86=E<ULD87)G='EP95T@87,@)%]A<F=N86UE(#T^("1?87)G='EP92D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&]P<W1Y;&4@/3T@)V1O
M8W5M96YT)R`F)B`D=7-E(#T]("=L:71E<F%L)R`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)%]A<F=T>7!E6R=N86UE)UT@/3T@)W!A<F%M971E
M<G,G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!4:&4@='EP
M92!O<B!E;&5M96YT(')E9F5R960@=&\@:7,@=7-E9`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@9F]R('!A<F%M971E<G,N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D96QA='1R<R`](&YU;&P["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D96QE;65N="`]("1?87)G='EP95LG96QE;65N
M="==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5L(#T@)'1H:7,M
M/F5L96UE;G1S6R1?87)G='EP95LG;F%M97-P86-E)UU=6R1?87)G='EP95LG
M='EP92==73L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&5L
M6R=C;VUP;&5X)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;F%M97-P86-E(#T@)'1H:7,M/FYA;65S<&%C97-;)%]A<F=T>7!E6R=N
M86UE<W!A8V4G75T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@6%A8(&YE960@=&\@=W)A<"!T:&4@<&%R86UE=&5R<R!I;@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&$@<V]A<%]V86QU92X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D96Q;)V5L96UE;G1S)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5L6R=E;&5M
M96YT<R==(&%S("1E;&YA;64@/3X@)&5L871T<G,I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@27,@=&AE(&5L96UE;G0@82!C
M;VUP;&5X('1Y<&4_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1E;&%T=')S6R=N
M86UE<W!A8V4G75U;)&5L;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]M;65N=',@+CT@)'1H:7,M/E]C;VUP
M;&5X5'EP94%R9R@D87)G<RP@)&%R9V%R<F%Y+"`D7V%R9W1Y<&4L("1?87)G
M;F%M92D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9$%R9R@D87)G<RP@)&%R9V%R<F%Y+"`D96QN86UE*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M96Q;)V-O;7!L97@G72`F)B`D87)G87)R87DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=W)A<&YA;64@/2`G>R<@+B`D=&AI<RT^;F%M
M97-P86-E<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==72XG?2<@+B`D96Q;)VYA
M;64G73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]M;65N
M=',@+CT@(B`@("`@("`@7"1[)&5L6R=N86UE)UU](#TF(&YE=R!33T%07U9A
M;'5E*"<D=W)A<&YA;64G+"!F86QS92P@7"1V(#T@87)R87DH)&%R9V%R<F%Y
M*2D[7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<F=A
M<G)A>2`]("(G>R1E;%LG;F%M92==?2<@/3X@7"1[)&5L6R=N86UE)UU](CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D7V%R9W1Y<&5;)V5L96UE;G0G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!%;&5M96YT(&%R9W5M96YT+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VUM96YT<R`N/2`D
M=&AI<RT^7V5L96UE;G1!<F<H)&%R9W,L("1A<F=A<G)A>2P@)%]A<F=T>7!E
M+"`D7V%R9W1Y<&5;)W1Y<&4G72D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O($-O;7!L97@@='EP92!A<F=U;65N="X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8V]M;65N=',@+CT@)'1H:7,M/E]C;VUP;&5X5'EP
M94%R9R@D87)G<RP@)&%R9V%R<F%Y+"`D7V%R9W1Y<&4L("1?87)G;F%M92D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%9A;&ED871E
M(&5N=')I97,N"@H@("`@("`@("`@("`O+R!/<&5R871I;VX@;F%M97,@87)E
M(&9U;F-T:6]N(&YA;65S+"!S;R!T<GD@=&\@;6%K92!S=7)E"B`@("`@("`@
M("`@("\O(&ET)W,@;&5G86PN(%1H:7,@8V]U;&0@<&]T96YT:6%L;'D@8V%U
M<V4@8V]L;&ES:6]N<RP*("`@("`@("`@("`@+R\@8G5T(&QE="=S('1R>2!T
M;R!M86ME(&5V97)Y=&AI;F<@8V%L;&%B;&4@86YD('-E92!H;W<*("`@("`@
M("`@("`@+R\@;6%N>2!P<F]B;&5M<R!T:&%T(&-A=7-E<RX*("`@("`@("`@
M("`@)&]P;F%M95]P:'`@/2!P<F5G7W)E<&QA8V4H)R];("Y<+5PH7"E=*R\G
M+"`G7R<L("1O<&YA;64I.PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?=F%L
M:61A=&53=')I;F<H)&]P;F%M95]P:'`I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1A
M<F=A<G)A>2D@>PH@("`@("`@("`@("`@("`@)&%R9V%R<F%Y(#T@(F%R<F%Y
M*"1A<F=A<G)A>2DB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&%R9V%R<F%Y(#T@)VYU;&PG.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D8VQA<W,@+CT@(B`@("!F=6YC=&EO;B`F)&]P;F%M95]P:'`H
M)&%R9W,I7&X@("`@>UQN)&-O;6UE;G1S)'=R87!P97)S(B`N"B`@("`@("`@
M("`@("`@("`B("`@("`@("!R971U<FX@7"1T:&ES+3YC86QL*"<D;W!N86UE
M)RQ<;B(@+@H@("`@("`@("`@("`@("`@(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%PD=B`]("1A<F=A<G)A>2Q<;B(@+@H@("`@("`@("`@("`@("`@
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=N86UE<W!A8V4G
M(#T^("<D;F%M97-P86-E)RQ<;B(@+@H@("`@("`@("`@("`@("`@(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S;V%P86-T:6]N)R`]/B`G
M)'-O87!A8W1I;VXG+%QN(B`N"B`@("`@("`@("`@("`@("`B("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`G)&]P<W1Y;&4G
M+%QN(B`N"B`@("`@("`@("`@("`@("`B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W5S92<@/3X@)R1U<V4G(B`N"B`@("`@("`@("`@("`@
M("`H)'1H:7,M/G1R86-E/R(L7&X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=')A8V4G(#T^(#$B(#H@)R<I("X@(BDI.UQN(B`N"B`@("`@
M("`@("`@("`@("`B("`@('U<;B(["B`@("`@("`@?0H*("`@("`@("`D8VQA
M<W,@+CT@(GU<;B(["B`@("`@("`@<F5T=7)N("1C;&%S<SL*("`@('T*"B`@
M("!F=6YC=&EO;B!G96YE<F%T94%L;%!R;WAI97,H*0H@("`@>PH@("`@("`@
M("1P<F]X>6-O9&4@/2`G)SL*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES
M*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI(&%S
M("1K97DI('L*("`@("`@("`@("`@)'!O<G0@/28@)'1H:7,M/G-E<G9I8V5S
M6R1T:&ES+3YS97)V:6-E75LG<&]R=',G75LD:V5Y73L*("`@("`@("`@("`@
M)'!R;WAY8V]D92`N/2`D=&AI<RT^9V5N97)A=&50<F]X>4-O9&4H)'!O<G0I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'!R;WAY8V]D93L*("`@('T*
M"B`@("!F=6YC=&EO;B`F9V5T4')O>'DH)'!O<G0@/2`G)RP@)&YA;64@/2`G
M)RD*("`@('L*("`@("`@("`D;75L=&EP;W)T(#T@8V]U;G0H)'1H:7,M/G-E
M<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G72D@/B`Q.PH*("`@("`@
M("!I9B`H(21P;W)T*2!["B`@("`@("`@("`@(')E<V5T*"1T:&ES+3YS97)V
M:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI.PH@("`@("`@("`@("`D
M<&]R="`](&-U<G)E;G0H)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E
M75LG<&]R=',G72D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&UU;'1I<&]R
M="!\?"`D<&]R="D@>PH@("`@("`@("`@("`D8VQA<W-N86UE(#T@)U=E8E-E
M<G9I8V5?)R`N("1T:&ES+3YS97)V:6-E("X@)U\G("X@)'!O<G1;)VYA;64G
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8VQA<W-N86UE(#T@
M)U=E8E-E<G9I8V5?)R`N("1T:&ES+3YS97)V:6-E.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1N86UE*2!["B`@("`@("`@("`@("1C;&%S<VYA;64@/2`D
M;F%M92`N("=?)R`N("1C;&%S<VYA;64["B`@("`@("`@?0H*("`@("`@("`D
M8VQA<W-N86UE(#T@<')E9U]R97!L86-E*"<O6R`N7"U<*%PI72LO)RP@)U\G
M+"`D8VQA<W-N86UE*3L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA
M<W-N86UE*2D@>PH@("`@("`@("`@("`D<')O>'D@/2`D=&AI<RT^9V5N97)A
M=&50<F]X>4-O9&4H)'!O<G0L("1C;&%S<VYA;64I.PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U-/05`O0VQI96YT+G!H<"<["B`@("`@("`@("`@(&5V
M86PH)'!R;WAY*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!N97<@)&-L
M87-S;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F7V=E=$-O;7!L97A4>7!E
M1F]R16QE;65N="@D;F%M92P@)&YA;65S<&%C92D*("`@('L*("`@("`@("`D
M="`](&YU;&P["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YN<ULD;F%M97-P
M86-E72D@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/F5L96UE;G1S6R1T
M:&ES+3YN<ULD;F%M97-P86-E75U;)&YA;65=6R=T>7!E)UTI*2!["@H@("`@
M("`@("`@("`D='EP92`]("1T:&ES+3YE;&5M96YT<ULD=&AI<RT^;G-;)&YA
M;65S<&%C95U=6R1N86UE75LG='EP92==.PH@("`@("`@("`@("`D;G,@/2`D
M=&AI<RT^96QE;65N='-;)'1H:7,M/FYS6R1N86UE<W!A8V5=75LD;F%M95U;
M)VYA;65S<&%C92==.PH*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC
M;VUP;&5X5'EP97-;)&YS75LD='EP95TI*2!["B`@("`@("`@("`@("`@("`D
M="`]("1T:&ES+3YC;VUP;&5X5'EP97-;)&YS75LD='EP95T["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$-O;7!L97A4>7!E3F%M949O<D5L96UE;G0H)&YA;64L
M("1N86UE<W!A8V4I"B`@("!["B`@("`@("`@)'0@/2`D=&AI<RT^7V=E=$-O
M;7!L97A4>7!E1F]R16QE;65N="@D;F%M92P@)&YA;65S<&%C92D["B`@("`@
M("`@:68@*"1T*2!["B`@("`@("`@("`@(')E='5R;B`D=%LG;F%M92==.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971#;VUP;&5X5'EP94-H:6QD5'EP92@D;G,L("1N86UE+"`D8VAI
M;&1?;G,L("1C:&EL9%]N86UE*0H@("`@>PH@("`@("`@("\O(&ES('1H92!T
M>7!E(&%N(&5L96UE;G0_"B`@("`@("`@)'0@/2`D=&AI<RT^7V=E=$-O;7!L
M97A4>7!E1F]R16QE;65N="@D;F%M92P@)&YS*3L*("`@("`@("!I9B`H)'0I
M('L*("`@("`@("`@("`@+R\@;F\L(&=E="!I="!F<F]M(&-O;7!L97@@='EP
M97,@9&ER96-T;'D*("`@("`@("`@("`@:68@*&ES<V5T*"1T6R=E;&5M96YT
M<R==6R1C:&EL9%]N86UE75LG='EP92==*2D*("`@("`@("`@("`@("`@(')E
M='5R;B`D=%LG96QE;65N=',G75LD8VAI;&1?;F%M95U;)W1Y<&4G73L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T4V-H96UA5'EP92@D='EP92P@)&YA;64L("1T>7!E7VYA;65S<&%C
M92D*("`@('L*("`@("`@("`O+R!S964@:68@:70G<R!A(&-O;7!L97@@='EP
M92!S;R!W92!C86X@9&5A;"!P<F]P97)L>2!W:71H"B`@("`@("`@+R\@4T]!
M4$5.0SIA<G)A>51Y<&4N"B`@("`@("`@:68@*"1N86UE("8F("1T>7!E*2![
M"B`@("`@("`@("`@("\O(%A86"!43T1/.@H@("`@("`@("`@("`O+R!L;V]K
M('5P('1H92!N86UE(&EN('1H92!W<V1L(&%N9"!V86QI9&%T92!T:&4@='EP
M92X*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F-O;7!L97A4>7!E<R!A
M<R`D;G,@/3X@)'1Y<&5S*2!["B`@("`@("`@("`@("`@("!I9B`H87)R87E?
M:V5Y7V5X:7-T<R@D='EP92P@)'1Y<&5S*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=T>7!E)RP@)'1Y<&5S6R1T>7!E
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D87)R87ET>7!E
M7VYS+"`D87)R87ET>7!E+"`D87)R87E?9&5P=&@I(#T@:7-S970H)'1Y<&5S
M6R1T>7!E75LG87)R87E4>7!E)UTI/PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G971$965P97-T07)R87E4>7!E*"1T>7!E<ULD='EP
M95U;)VYA;65S<&%C92==+"`D='EP97-;)'1Y<&5=6R=A<G)A>51Y<&4G72D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@87)R87DH)'1H:7,M/FYA
M;65S<&%C97-;)'1Y<&5S6R1T>7!E75LG;F%M97-P86-E)UU=+"!N=6QL+"`P
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1T>7!E
M<ULD='EP95U;)W1Y<&4G72P@)&%R<F%Y='EP92P@)&%R<F%Y='EP95]N<RP@
M)&%R<F%Y7V1E<'1H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V%R<F%Y5'EP92<L
M("1T>7!E<ULD='EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QI
M<W0H)&%R<F%Y='EP95]N<RP@)&%R<F%Y='EP92P@)&%R<F%Y7V1E<'1H*2`]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$1E97!E
M<W1!<G)A>51Y<&4H)'1Y<&5S6R1T>7!E75LG;F%M97-P86-E)UTL("1T>7!E
M<ULD='EP95U;)V%R<F%Y5'EP92==*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=!<G)A>2<L("1A<G)A>71Y<&4L("1A<G)A>71Y
M<&5?;G,L("1A<G)A>5]D97!T:"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=E;&5M
M96YT<R<L("1T>7!E<ULD='EP95TI("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y7VME>5]E>&ES=',H)&YA;64L("1T>7!E<ULD='EP95U;)V5L
M96UE;G1S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@
M)'1Y<&5S6R1T>7!E75LG96QE;65N=',G75LG='EP92==.PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH)'1Y<&4L(&YU;&PL("1T:&ES
M+3YN86UE<W!A8V5S6R1T>7!E<ULD='EP95U;)VYA;65S<&%C92==72P@;G5L
M;"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D='EP92`F)B`D
M='EP95]N86UE<W!A8V4I('L*("`@("`@("`@("`@)&%R<F%Y5'EP92`](&YU
M;&P["B`@("`@("`@("`@("\O(%A86"!43T1/.@H@("`@("`@("`@("`O+R!T
M:&ES(&-O9&4@8W5R<F5N=&QY(&AA;F1L97,@;VYL>2!O;F4@=V%Y(&]F(&5N
M8V]D:6YG(&%R<F%Y('1Y<&5S(&EN('=S9&P*("`@("`@("`@("`@+R\@;F5E
M9"!T;R!D;R!A(&=E;F5R86QI>F5D(&9U;F-T:6]N('1O(&9I9W5R92!O=70@
M8V]M<&QE>"!T>7!E<PH@("`@("`@("`@("`D<"`]("1T:&ES+3YN<ULD='EP
M95]N86UE<W!A8V5=.PH@("`@("`@("`@("!I9B`H)'`@)B8*("`@("`@("`@
M("`@("`@(&%R<F%Y7VME>5]E>&ES=',H)'`L("1T:&ES+3YC;VUP;&5X5'EP
M97,I("8F"B`@("`@("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S*"1T>7!E
M+"`D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P72DI('L*("`@("`@("`@("`@("`@
M(&EF("@D87)R87E4>7!E(#T@)'1H:7,M/F-O;7!L97A4>7!E<ULD<%U;)'1Y
M<&5=6R=A<G)A>51Y<&4G72D@>PH@("`@("`@("`@("`@("`@("`@("1T>7!E
M(#T@)T%R<F%Y)SL*("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^
M8V]M<&QE>%1Y<&5S6R1P75LD='EP95U;)V]R9&5R)UT]/2=S97%U96YC92<@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S
M*"=E;&5M96YT<R<L("1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E72DI
M('L*("`@("`@("`@("`@("`@("`@("!R97-E="@D=&AI<RT^8V]M<&QE>%1Y
M<&5S6R1P75LD='EP95U;)V5L96UE;G1S)UTI.PH@("`@("`@("`@("`@("`@
M("`@("\O(&%S<W5M92!A;B!A<G)A>0H@("`@("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P75LD='EP95U;)V5L96UE
M;G1S)UTI(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%R9R`]
M(&-U<G)E;G0H)'1H:7,M/F-O;7!L97A4>7!E<ULD<%U;)'1Y<&5=6R=E;&5M
M96YT<R==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y5'EP92`]
M("1A<F=;)W1Y<&4G73L*("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@
M/2`G07)R87DG.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VUP;&5X5'EP
M97-;)'!=6R1T>7!E75LG96QE;65N=',G72!A<R`D96QE;65N="D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E;&5M96YT6R=N86UE)UT@
M/3T@)'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M87)R87E4>7!E(#T@)&5L96UE;G1;)W1Y<&4G73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D='EP92`]("1E;&5M96YT6R=T>7!E)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)U-T<G5C
M="<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@
M87)R87DH)'1Y<&4L("1A<G)A>51Y<&4L("1T>7!E7VYA;65S<&%C92P@;G5L
M;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*&YU;&PL(&YU;&PL(&YU;&PL(&YU;&PI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5C=7)S92!T:')O=6=H('1H92!74T1,('-T<G5C='5R92!L;V]K
M:6YG(&9O<B!T:&4@:6YN97)M;W-T"B`@("`@*B!A<G)A>2!T>7!E(&]F(&UU
M;'1I+61I;65N<VEO;F%L(&%R<F%Y<RX*("`@("`J"B`@("`@*B!486ME<R!A
M(&YA;65S<&%C92!P<F5F:7@@86YD(&$@='EP92P@=VAI8V@@8V%N(&)E(&EN
M('1H92!F;W)M"B`@("`@*B`G='EP92<@;W(@)W1Y<&5;72<L(&%N9"!R971U
M<FYS('1H92!F=6QL(&YA;65S<&%C92!54DDL('1H90H@("`@("H@='EP92!O
M9B!T:&4@;6]S="!D965P;'D@;F5S=&5D(&%R<F%Y('1Y<&4@9F]U;F0L(&%N
M9"!T:&4@;G5M8F5R"B`@("`@*B!O9B!L979E;',@;V8@;F5S=&EN9RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!R971U<FX@;6EX
M960@87)R87D@;W(@;F]T:&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T
M1&5E<&5S=$%R<F%Y5'EP92@D;G-0<F5F:7@L("1A<G)A>51Y<&4I"B`@("![
M"B`@("`@("`@<W1A=&EC("1T<F%I;"`](&%R<F%Y*"D["@H@("`@("`@("1A
M<G)A>51Y<&4@/2!E<F5G7W)E<&QA8V4H)UQ;7%TD)RP@)R<L("1A<G)A>51Y
M<&4I.PH*("`@("`@("`O+R!0<F]T96-T(&%G86EN<W0@8VER8W5L87(@<F5F
M97)E;F-E<PH@("`@("`@("\O(%A86"!792!R96%L;'D@;F5E9"!T;R!R96UO
M=F4@=')A:6P@9G)O;2!T:&ES(&%L=&]G971H97(@*&ET)W,@=F5R>2!I;F5F
M9FEC:65N="!A;F0*("`@("`@("`O+R!I;B!T:&4@=W)O;F<@<&QA8V4A*2!A
M;F0@<'5T(&-I<F-U;&%R(')E9F5R96YC92!C:&5C:VEN9R!I;B!W:&5N('1H
M92!74T1,(&EN9F\*("`@("`@("`O+R!I<R!G96YE<F%T960@:6X@=&AE(&9I
M<G-T('!L86-E"B`@("`@("`@:68@*&%R<F%Y7W-E87)C:"@D;G-0<F5F:7@@
M+B`G.B<@+B`D87)R87E4>7!E+"`D=')A:6PI*2!["B`@("`@("`@("`@(')E
M='5R;B!A<G)A>2AN=6QL+"!N=6QL+"`M8V]U;G0H)'1R86EL*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D;G-0<F5F:7@L
M("1T:&ES+3YC;VUP;&5X5'EP97,I("8F"B`@("`@("`@("`@(&%R<F%Y7VME
M>5]E>&ES=',H)&%R<F%Y5'EP92P@)'1H:7,M/F-O;7!L97A4>7!E<ULD;G-0
M<F5F:7A=*2`F)@H@("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S*"=A<G)A
M>51Y<&4G+"`D=&AI<RT^8V]M<&QE>%1Y<&5S6R1N<U!R969I>%U;)&%R<F%Y
M5'EP95TI*2!["B`@("`@("`@("`@("1T<F%I;%M=(#T@)&YS4')E9FEX("X@
M)SHG("X@)&%R<F%Y5'EP93L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9V5T1&5E<&5S=$%R<F%Y5'EP92@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1N
M<U!R969I>%U;)&%R<F%Y5'EP95U;)VYA;65S<&%C92==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC;VUP;&5X5'EP97-;)&YS4')E9FEX75LD87)R87E4>7!E75LG87)R87E4
M>7!E)UTI.PH@("`@("`@("`@("!R971U<FX@87)R87DH)')E<W5L=%LP72P@
M)')E<W5L=%LQ72P@)')E<W5L=%LR72`K(#$I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@87)R87DH)'1H:7,M/FYA;65S<&%C97-;)&YS4')E9FEX72P@
M)&%R<F%Y5'EP92P@,"D["B`@("!]"@I]"@IC;&%S<R!33T%07U=31$Q?0V%C
M:&4@97AT96YD<R!33T%07T)A<V4*>PH@("`@+R\@0V%C:&4@<V5T=&EN9W,*
M"B`@("`O*BH*("`@("`J(%5S92!74T1,(&-A8VAE"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-A8VAE57-E(#T@;G5L
M;#L*"B`@("`O*BH*("`@("`J($-A8VAE(&UA>"!L:69E=&EM92`H:6X@<V5C
M;VYD<RD*("`@("`J"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@
M)%]C86-H94UA>$%G92`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!33T%07U=3
M1$Q?0V%C:&4@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@(&)O
M;VQE86X@=7-E(&-A8VAI;F<*("`@("`J($!P87)A;2`@:6YT("`@("!C86-H
M92!M87@@;&EF971I;64@*&EN('-E8V]N9',I"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!33T%07U=31$Q?0V%C:&4H)&-A
M8VAE57-E(#T@5U-$3%]#04-(15]54T4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-A8VAE36%X06=E(#T@5U-$3%]#04-(15]-05A?04=%*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ4T]!4%]"87-E*"=74T1,0T%#2$4G*3L*
M("`@("`@("`D=&AI<RT^7V-A8VAE57-E(#T@)&-A8VAE57-E.PH@("`@("`@
M("1T:&ES+3Y?8V%C:&5-87A!9V4@/2`D8V%C:&5-87A!9V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!?8V%C:&5$:7(*("`@("`J(')E='5R;B!T:&4@<&%T
M:"!T;R!T:&4@8V%C:&4L(&EF(&ET(&1O97-N)W0@97AI<W0L(&UA:V4@:70*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-A8VAE1&ER*"D*("`@('L*("`@("`@
M("`D9&ER(#T@9V5T96YV*")74T1,0T%#2$4B*3L*("`@("`@("!I9B`H(21D
M:7(I("1D:7(@/2`B("XO=W-D;&-A8VAE(CL*("`@("`@("!`;6MD:7(H)&1I
M<BP@,#<P,"D["B`@("`@("`@<F5T=7)N("1D:7(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971R:65V97,@82!F:6QE(&9R;VT@8V%C:&4@:68@:70@97AI
M<W1S+"!O=&AE<G=I<V4@<F5T<F5I=F4@9G)O;2!N970L"B`@("`@*B!A9&0@
M=&\@8V%C:&4L(&%N9"!R971U<FX@9G)O;2!C86-H92X*("`@("`J"B`@("`@
M*B!`<&%R86T@('-T<FEN9R`@(%523"!T;R!74T1,"B`@("`@*B!`<&%R86T@
M(&%R<F%Y("`@('!R;WAY('!A<F%M971E<G,*("`@("`J($!P87)A;2`@:6YT
M("`@("`@97AP96-T960@340U(&]F(%=31$P@55),"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0')E='5R;B!S=')I;F<@(&1A=&$*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T*"1W<V1L7V9N86UE+"`D<')O>'E?<&%R86US(#T@
M87)R87DH*2P@)&-A8VAE(#T@,"D*("`@('L*("`@("`@("`D8V%C:&5N86UE
M(#T@)&UD-5]W<V1L(#T@)&9I;&5?9&%T82`]("<G.PH@("`@("`@(&EF("@D
M=&AI<RT^7V-A8VAE57-E*2!["B`@("`@("`@("`@("\O(%1R>2!T;R!R971R
M:65V92!74T1,(&9R;VT@8V%C:&4*("`@("`@("`@("`@)&-A8VAE;F%M92`]
M(%-/05!?5U-$3%]#86-H93HZ7V-A8VAE1&ER*"D@+B`G+R<@+B!M9#4H)'=S
M9&Q?9FYA;64I+B`G("YW<V1L)SL*("`@("`@("`@("`@:68@*&9I;&5?97AI
M<W1S*"1C86-H96YA;64I*2!["B`@("`@("`@("`@("`@("`D=V8@/2!F;W!E
M;B@D8V%C:&5N86UE+"`G<F(G*3L*("`@("`@("`@("`@("`@(&EF("@D=V8I
M('L*("`@("`@("`@("`@("`@("`@("`O+R!296%D:6YG(&-A8VAE9"!F:6QE
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&5?9&%T82`](&9R96%D*"1W9BP@
M9FEL97-I>F4H)&-A8VAE;F%M92DI.PH@("`@("`@("`@("`@("`@("`@("1M
M9#5?=W-D;"`](&UD-2@D9FEL95]D871A*3L*("`@("`@("`@("`@("`@("`@
M("!F8VQO<V4H)'=F*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@D8V%C:&4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-A
M8VAE("$]("1M9#5?=W-D;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G5U-$3"!#:&5C:W-U;2!E
M<G)O<B$G+"`D=W-D;%]F;F%M92D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M9FD@/2!S=&%T*"1C86-H96YA;64I.PH@("`@("`@("`@("`@("`@("`@("1C
M86-H95]M=&EM92`]("1F:5LX73L*("`@("`@("`@("`@("`@("`@("`O+W!R
M:6YT(&-A8VAE7VUT:6UE+"!T:6UE*"D*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&-A8VAE7VUT:6UE("L@)'1H:7,M/E]C86-H94UA>$%G92`\('1I;64H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!E>'!I<F5D"B`@("`@
M("`@("`@("`@("`@("`@("`@("1M9#5?=W-D;"`]("<G.R`O+R!R969E=&-H
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(21M9#5?=W-D;"D@
M>PH@("`@("`@("`@("`O+R!.;W0@8V%C:&5D(&]R(&YO="!U<VEN9R!C86-H
M92X@4F5T<FEE=F4@5U-$3"!F<F]M(%523`H*("`@("`@("`@("`@+R\@:7,@
M:70@82!L;V-A;"!F:6QE/PH@("`@("`@("`@("`O+R!T:&ES('-E8W1I;VX@
M<VAO=6QD(&)E(')E<&QA8V4@8GD@8W5R;"!A="!S;VUE('!O:6YT"B`@("`@
M("`@("`@(&EF("@A<')E9U]M871C:"@G+UXH:'1T<',_?&9I;&4I.EPO7"\O
M)RP@)'=S9&Q?9FYA;64I*2!["B`@("`@("`@("`@("`@("!I9B`H(69I;&5?
M97AI<W1S*"1W<V1L7V9N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<F5A9"!L
M;V-A;"!74T1,("1W<V1L7V9N86UE(BP@)'=S9&Q?9FYA;64I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE7V1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D=W-D;%]F;F%M92D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE7V1A=&$@/2!I;7!L;V1E*"<G+&9I;&4H)'=S9&Q?9FYA;64I*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1U<FD@/2!E>'!L;V1E*"<_)RP@)'=S9&Q?9FYA;64I.PH@
M("`@("`@("`@("`@("`@)')Q(#TF(&YE=R!(5%107U)E<75E<W0H)'5R:5LP
M72P@)'!R;WAY7W!A<F%M<RD["B`@("`@("`@("`@("`@("`O+R!T:&4@=7-E
M<B!A9V5N="!(5%107U)E<75E<W0@=7-E<R!F;W5L<R!T:&EN9W,@=7`*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=7)I6S%=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1R<2T^861D4F%W475E<GE3=')I;F<H)'5R:5LQ72D["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P
M<F]X>5]P87)A;7-;)W!R;WAY7VAO<W0G72D@)B8*("`@("`@("`@("`@("`@
M("`@("!I<W-E="@D<')O>'E?<&%R86US6R=P<F]X>5]P;W)T)UTI("8F"B`@
M("`@("`@("`@("`@("`@("`@:7-S970H)'!R;WAY7W!A<F%M<ULG<')O>'E?
M=7-E<B==*2`F)@H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1P<F]X>5]P
M87)A;7-;)W!R;WAY7W!A<W,G72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<G$M/G-E=%!R;WAY*"1P<F]X>5]P87)A;7-;)W!R;WAY7VAO<W0G72P@)'!R
M;WAY7W!A<F%M<ULG<')O>'E?<&]R="==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R;WAY7W!A<F%M<ULG<')O>'E?=7-E<B==+"`D
M<')O>'E?<&%R86US6R=P<F]X>5]P87-S)UTI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1P<F]X>5]P87)A;7-;)W!R;WAY7VAO<W0G72D@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D<')O>'E?<&%R
M86US6R=P<F]X>5]P;W)T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)')Q
M+3YS9710<F]X>2@D<')O>'E?<&%R86US6R=P<F]X>5]H;W-T)UTL("1P<F]X
M>5]P87)A;7-;)W!R;WAY7W!O<G0G72D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1R<2T^<V5N9%)E<75E<W0H*3L*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H(E5N86)L92!T;R!R971R:65V92!74T1,("1W<V1L7V9N86UE+"(@
M+B`D<G$M/F=E=%)E<W!O;G-E0V]D92@I+"`D=W-D;%]F;F%M92D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9FEL95]D871A(#T@)')Q
M+3YG971297-P;VYS94)O9'DH*3L*("`@("`@("`@("`@("`@(&EF("@A)&9I
M;&5?9&%T82D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@<F5T<FEE=F4@5U-$3"`D=W-D
M;%]F;F%M92P@;F\@:'1T<"!B;V1Y(BP@)'=S9&Q?9FYA;64I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;60U7W=S
M9&P@/2!M9#4H)&9I;&5?9&%T82D["@H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]C86-H955S92D@>PH@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH)&-A
M8VAE;F%M92P@(G=B(BD["B`@("`@("`@("`@("`@("!F=W)I=&4H)&9P+"`D
M9FEL95]D871A*3L*("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE
M57-E("8F("1C86-H92`F)B`D8V%C:&4@(3T@)&UD-5]W<V1L*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")74T1,($-H
M96-K<W5M(&5R<F]R(2(L("1W<V1L7V9N86UE*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1F:6QE7V1A=&$["B`@("!]"@I]"@IC;&%S<R!33T%07U=3
M1$Q?4&%R<V5R(&5X=&5N9',@4T]!4%]"87-E"GL*"B`@("`O*BH*("`@("`J
M($1E9FEN92!I;G1E<FYA;"!A<G)A>7,@;V8@8FEN9&EN9W,L('!O<G1S+"!O
M<&5R871I;VYS+`H@("`@("H@;65S<V%G97,L(&5T8RX*("`@("`J+PH@("`@
M=F%R("1C=7)R96YT365S<V%G93L*("`@('9A<B`D8W5R<F5N=$]P97)A=&EO
M;CL*("`@('9A<B`D8W5R<F5N=%!O<G14>7!E.PH@("`@=F%R("1C=7)R96YT
M0FEN9&EN9SL*("`@('9A<B`D8W5R<F5N=%!O<G0["@H@("`@+RHJ"B`@("`@
M*B!087)S97(@=F%R<RX*("`@("`J+PH@("`@=F%R("1C86-H93L*"B`@("!V
M87(@)'1N<R`](&YU;&P["B`@("!V87(@)'-O87!N<R`](&%R<F%Y*"=S;V%P
M)RD["B`@("!V87(@)'5R:2`]("<G.PH@("`@=F%R("1W<V1L(#T@;G5L;#L*
M"B`@("!V87(@)'-T871U<R`]("<G.PH@("`@=F%R("1E;&5M96YT7W-T86-K
M(#T@87)R87DH*3L*("`@('9A<B`D<&%R96YT16QE;65N="`]("<G.PH*("`@
M('9A<B`D<V-H96UA(#T@)R<["B`@("!V87(@)'-C:&5M85-T871U<R`]("<G
M.PH@("`@=F%R("1S8VAE;6%?<W1A8VL@/2!A<G)A>2@I.PH@("`@=F%R("1C
M=7)R96YT0V]M<&QE>%1Y<&4["B`@("!V87(@)'-C:&5M85]E;&5M96YT7W-T
M86-K(#T@87)R87DH*3L*("`@('9A<B`D8W5R<F5N=$5L96UE;G0["@H@("`@
M+RHJ"B`@("`@*B!C;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!3
M3T%07U=31$Q?4&%R<V5R*"1U<FDL("8D=W-D;"P@)&1O8W,@/2!F86QS92D*
M("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$3%!!4E-%4B<I
M.PH@("`@("`@("1T:&ES+3YC86-H92`])B!N97<@4T]!4%]74T1,7T-A8VAE
M*"1W<V1L+3YC86-H955S92P@)'=S9&PM/F-A8VAE36%X06=E*3L*("`@("`@
M("`D=&AI<RT^=7)I(#T@)'5R:3L*("`@("`@("`D=&AI<RT^=W-D;"`]("8D
M=W-D;#L*("`@("`@("`D=&AI<RT^9&]C<R`]("1D;V-S.PH@("`@("`@("1T
M:&ES+3YP87)S92@D=7)I*3L*("`@('T*"B`@("!F=6YC=&EO;B!P87)S92@D
M=7)I*0H@("`@>PH@("`@("`@("\O($-H96-K('=H971H97(@8V]N=&5N="!H
M87,@8F5E;B!R96%D+@H@("`@("`@("1F9"`]("1T:&ES+3YC86-H92T^9V5T
M*"1U<FDL("1T:&ES+3YW<V1L+3YP<F]X>2D["B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&9D*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R
M86ES95-O87!&875L="@D9F0I.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E
M871E(&%N(%A-3"!P87)S97(N"B`@("`@("`@)'!A<G-E<B`]('AM;%]P87)S
M97)?8W)E871E*"D["B`@("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1P
M87)S97(L(%A-3%]/4%1)3TY?0T%315]&3TQ$24Y'+"`P*3L*("`@("`@("!X
M;6Q?<V5T7V]B:F5C="@D<&%R<V5R+"`D=&AI<RD["B`@("`@("`@>&UL7W-E
M=%]E;&5M96YT7VAA;F1L97(H)'!A<G-E<BP@)W-T87)T16QE;65N="<L("=E
M;F1%;&5M96YT)RD["B`@("`@("`@:68@*"1T:&ES+3YD;V-S*2!["B`@("`@
M("`@("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D<&%R<V5R
M+"`G8VAA<F%C=&5R1&%T82<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%X
M;6Q?<&%R<V4H)'!A<G-E<BP@)&9D+"!T<G5E*2D@>PH@("`@("`@("`@("`D
M9&5T86EL(#T@<W!R:6YT9B@G6$U,(&5R<F]R(&]N(&QI;F4@)60Z("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT
M7VQI;F5?;G5M8F5R*"1P87)S97(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!X;6Q?97)R;W)?<W1R:6YG*'AM;%]G971?97)R;W)?8V]D92@D
M<&%R<V5R*2DI.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O
M87!&875L="@B56YA8FQE('1O('!A<G-E(%=31$P@9FEL92`D=7)I7&XD9&5T
M86EL(BD["B`@("`@("`@?0H@("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R
M<V5R*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J('-T87)T+65L96UE;G0@:&%N9&QE<@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S=&%R=$5L96UE;G0H)'!A<G-E<BP@)&YA;64L("1A='1R<RD*("`@('L*
M("`@("`@("`O+R!'970@96QE;65N="!P<F5F:7@N"B`@("`@("`@)'%N86UE
M(#TF(&YE=R!13F%M92@D;F%M92D["B`@("`@("`@:68@*"1Q;F%M92T^;G,I
M('L*("`@("`@("`@("`@)&YS(#T@)'%N86UE+3YN<SL*("`@("`@("`@("`@
M:68@*"1N<R`F)B`H*"$D=&AI<RT^=&YS("8F('-T<F-A<V5C;7`H)'%N86UE
M+3YN86UE+"`G9&5F:6YI=&EO;G,G*2`]/2`P*2!\?"`D;G,@/3T@)'1H:7,M
M/G1N<RDI('L*("`@("`@("`@("`@("`@("1N86UE(#T@)'%N86UE+3YN86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YC=7)R
M96YT5&%G(#T@)'%N86UE+3YN86UE.PH@("`@("`@("1T:&ES+3YP87)E;G1%
M;&5M96YT(#T@)R<["B`@("`@("`@)'-T86-K7W-I>F4@/2!C;W5N="@D=&AI
M<RT^96QE;65N=%]S=&%C:RD["B`@("`@("`@:68@*"1S=&%C:U]S:7IE*2![
M"B`@("`@("`@("`@("1T:&ES+3YP87)E;G1%;&5M96YT(#T@)'1H:7,M/F5L
M96UE;G1?<W1A8VM;)'-T86-K7W-I>F4@+2`Q73L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/F5L96UE;G1?<W1A8VM;72`]("1T:&ES+3YC=7)R96YT5&%G
M.PH*("`@("`@("`O+R!&:6YD('-T871U<RP@<F5G:7-T97(@9&%T82X*("`@
M("`@("!S=VET8V@@*"1T:&ES+3YS=&%T=7,I('L*("`@("`@("!C87-E("=T
M>7!E<R<Z"B`@("`@("`@("`@("\O('-E8W0@,BXR('=S9&PZ='EP97,*("`@
M("`@("`@("`@+R\@8VAI;&1R96XZ('AS9#IS8VAE;6$*("`@("`@("`@("`@
M)'!A<F5N=%]T86<@/2`G)SL*("`@("`@("`@("`@)'-T86-K7W-I>F4@/2!C
M;W5N="@D=&AI<RT^<V-H96UA7W-T86-K*3L*("`@("`@("`@("`@:68@*"1S
M=&%C:U]S:7IE*2!["B`@("`@("`@("`@("`@("`D<&%R96YT7W1A9R`]("1T
M:&ES+3YS8VAE;6%?<W1A8VM;)'-T86-K7W-I>F4@+2`Q73L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@
M("`@("`@("`@8V%S92`G<V-H96UA)SH*("`@("`@("`@("`@("`@("\O($YO
M('!A<F5N="!S:&]U;&0@8F4@:6X@=&AE('-T86-K+@H@("`@("`@("`@("`@
M("`@:68@*"$D<&%R96YT7W1A9R!\?"`D<&%R96YT7W1A9R`]/2`G='EP97,G
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H
M)W1A<F=E=$YA;65S<&%C92<L("1A='1R<RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-C:&5M82`]("1T:&ES+3YW<V1L+3YG971.86UE
M<W!A8V5!='1R:6)U=&5.86UE*"1A='1R<ULG=&%R9V5T3F%M97-P86-E)UTI
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS8VAE;6$@/2`D=&AI<RT^=W-D;"T^9V5T3F%M
M97-P86-E071T<FEB=71E3F%M92@D=&AI<RT^=W-D;"T^=&YS*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA72`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F5L96UE;G1S6R1T:&ES
M+3YS8VAE;6%=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]M<&QE>%1Y
M<&4G.@H@("`@("`@("`@("`@("`@:68@*"1P87)E;G1?=&%G(#T]("=S8VAE
M;6$G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1#;VUP
M;&5X5'EP92`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&%T=')S6R=N86UE<W!A8V4G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%T=')S6R=N86UE<W!A8V4G72`]("1T:&ES+3YS
M8VAE;6$["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;
M)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95T@/2`D871T<G,["B`@("`@("`@
M("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V)A<V4G+"`D871T
M<G,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1Q;B`])B!N97<@44YA
M;64H)&%T=')S6R=B87-E)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES
M+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`D<6XM/FYA;64["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP
M97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;
M)VYA;65S<&%C92==(#T@)'%N+3YN<SL*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^
M8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G4W1R=6-T)SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-C:&5M85-T871U
M<R`]("=C;VUP;&5X5'EP92<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI
M<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$5L96UE;G1=6R=C;VUP;&5X)UT@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=E;&5M96YT)SH*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D871T<G-;)W1Y<&4G72DI('L*("`@("`@("`@("`@
M("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R<ULG='EP92==*3L*("`@
M("`@("`@("`@("`@("`@("`D871T<G-;)W1Y<&4G72`]("1Q;BT^;F%M93L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'%N+3YN<R`F)B!A<G)A>5]K97E?
M97AI<W1S*"1Q;BT^;G,L("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D871T<G-;)VYA;65S<&%C92==(#T@
M)'%N+3YN<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)'!A<F5N=$5L96UE;G0@/2`G)SL*("`@
M("`@("`@("`@("`@("1S=&%C:U]S:7IE(#T@8V]U;G0H)'1H:7,M/G-C:&5M
M85]E;&5M96YT7W-T86-K*3L*("`@("`@("`@("`@("`@(&EF("@D<W1A8VM?
M<VEZ92`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D<&%R96YT16QE;65N
M="`]("1T:&ES+3YS8VAE;6%?96QE;65N=%]S=&%C:ULD<W1A8VM?<VEZ92`M
M(#%=.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<G-;)W)E9B==*2D@>PH@("`@("`@("`@("`@("`@("`@("1Q
M;B`])B!N97<@44YA;64H)&%T=')S6R=R968G72D["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-U<G)E;G1%;&5M96YT(#T@)'%N+3YN86UE.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^8W5R<F5N=$5L96UE;G0@/2`D871T<G-;)VYA;64G73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YS8VAE;6%?96QE;65N
M=%]S=&%C:UM=(#T@)'1H:7,M/F-U<G)E;G1%;&5M96YT.PH@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D871T<G-;)VYA;65S<&%C92==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1A='1R<ULG;F%M97-P86-E)UT@/2`D=&AI<RT^
M<V-H96UA.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF
M("@D<&%R96YT7W1A9R`]/2`G<V-H96UA)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI<RT^<V-H96UA75LD=&AI
M<RT^8W5R<F5N=$5L96UE;G1=(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI<RT^<V-H96UA75LD=&AI
M<RT^8W5R<F5N=$5L96UE;G1=6R=C;VUP;&5X)UT@/2!F86QS93L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V-H96UA4W1A='5S(#T@)V5L96UE;G0G
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`O+R!W92=R92!I;G-I
M9&4@82!C;VUP;&5X5'EP90H@("`@("`@("`@("`@("`@("`@(&EF("@H:7-S
M970H)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD
M=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG;W)D97(G72D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;
M)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V]R
M9&5R)UT@/3T@)W-E<75E;F-E)RD*("`@("`@("`@("`@("`@("`@("`@("`@
M)B8@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD
M=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T]("=!<G)A>2<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L
M97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4
M>7!E75LG87)R87E4>7!E)UT@/2!I<W-E="@D871T<G-;)W1Y<&4G72D@/R`D
M871T<G-;)W1Y<&4G72`Z(&YU;&P["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;
M)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V5L
M96UE;G1S)UU;)'1H:7,M/F-U<G)E;G1%;&5M96YT72`]("1A='1R<SL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/F5L96UE;G1S6R1T:&ES+3YS8VAE;6%=6R1P87)E;G1%;&5M
M96YT75LG96QE;65N=',G75LD=&AI<RT^8W5R<F5N=$5L96UE;G1=(#T@)&%T
M=')S.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=C;VUP;&5X0V]N=&5N="<Z"B`@("`@("`@
M("`@(&-A<V4@)W-I;7!L94-O;G1E;G0G.@H@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=E>'1E;G-I;VXG.@H@("`@("`@("`@
M("!C87-E("=R97-T<FEC=&EO;B<Z"B`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/G-C:&5M85-T871U<R`]/2`G8V]M<&QE>%1Y<&4G*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D871T<G-;)V)A<V4G72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D871T<G-;
M)V)A<V4G72D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#
M;VUP;&5X5'EP95U;)W1Y<&4G72`]("1Q;BT^;F%M93L*"B`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%1Y<&5S('1H870@97AT96YD(&9R;VT@;W1H97(@
M='EP97,@87)E;B=T"B`@("`@("`@("`@("`@("`@("`@("`@("\O("IO9BH@
M=&AO<V4@='EP97,N(%)E9FQE8W0@=&AI<R!B>2!D96YO=&EN9PH@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!W:&EC:"!T>7!E('1H97D@97AT96YD+B!)
M)VT@;&5A=FEN9R!T:&4*("`@("`@("`@("`@("`@("`@("`@("`@+R\@)W1Y
M<&4G('-E='1I;F<@:&5R92!S:6YC92!))VT@;F]T('-U<F4@=VAA=`H@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!R96UO=FEN9R!I="!M:6=H="!B<F5A
M:R!A="!T:&4@;6]M96YT+@H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)'%N86UE+3YN86UE(#T]("=E>'1E;G-I;VXG*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=E>'1E;F1S
M)UT@/2`D<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=
M6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G4W1R=6-T
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W-E<75E
M;F-E)SH*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^<V-H96UA4W1A='5S
M(#T]("=C;VUP;&5X5'EP92<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC
M=7)R96YT0V]M<&QE>%1Y<&5=6R=O<F1E<B==(#T@)'%N86UE+3YN86UE.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G=S9&PM/F-O
M;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L
M97A4>7!E75LG='EP92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES
M+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G07)R87DG.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G86QL)SH*("`@("`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C
M:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V]R9&5R)UT@/2`D
M<6YA;64M/FYA;64["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=
M6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G4W1R=6-T
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G8VAO:6-E)SH*("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M
M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V]R9&5R)UT@/2`D<6YA;64M/FYA;64[
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YW<V1L+3YC;VUP
M;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X
M5'EP95U;)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R
M96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@8V%S92`G871T<FEB=71E)SH*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^<V-H96UA4W1A='5S(#T]("=C;VUP;&5X
M5'EP92<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')S
M6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E
M;G1#;VUP;&5X5'EP95U;)V%T=')I8G5T92==6R1A='1R<ULG;F%M92==72`]
M("1A='1R<SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')S6R=R968G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Q(#TF(&YE=R!13F%M92@D
M871T<G-;)W)E9B==*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1A='1R<R!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D:R`A/2`G<F5F)R`F)B!S=')S='(H)&LL
M("1Q+3YN86UE*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=G$@/28@;F5W(%%.86UE*"1V*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1Q+3YN86UE(#T]("=A<G)A>51Y<&4G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES
M+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R1Q+3YN86UE72`]("1V<2T^;F%M92X@
M)'9Q+3YA<G)A>4EN9F\["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS
M8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G
M07)R87DG.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD
M=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG;F%M97-P86-E)UT@/2`D=G$M
M/FYS.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI
M<RT^8W5R<F5N=$-O;7!L97A4>7!E75LD<2T^;F%M95T@/2`D=G$M/FYA;64[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M
M/G-C:&5M85]S=&%C:UM=(#T@)'%N86UE+3YN86UE.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G;65S<V%G92<Z"B`@("`@("`@("`@("\O
M('-E8W0@,BXS('=S9&PZ;65S<V%G92!C:&EL9"!W<V1L.G!A<G0*("`@("`@
M("`@("`@<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@("`@("`@("`@8V%S
M92`G<&%R="<Z"B`@("`@("`@("`@("`@("`D<6X@/2!N=6QL.PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG='EP92==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1Q;B`])B!N97<@44YA;64H)&%T=')S6R=T>7!E)UTI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1A='1R<ULG96QE
M;65N="==*2D@>PH@("`@("`@("`@("`@("`@("`@("1Q;B`])B!N97<@44YA
M;64H)&%T=')S6R=E;&5M96YT)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*"1Q;BD@>PH@("`@("`@("`@("`@("`@("`@("1A
M='1R<ULG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@("`@("`@("`@("`@
M("1A='1R<ULG;F%M97-P86-E)UT@/2`D<6XM/FYS.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FUE<W-A9V5S6R1T
M:&ES+3YC=7)R96YT365S<V%G95U;)&%T=')S6R=N86UE)UU=(#T@)&%T=')S
M.PH@("`@("`@("`@("`@("`@+R\@97)R;W(@:6X@=W-D;`H*("`@("`@("`@
M("`@8V%S92`G9&]C=6UE;G1A=&EO;B<Z"B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G<&]R=%1Y<&4G.@H@("`@("`@("`@("`O+R!S96-T(#(N-`H@("`@
M("`@("`@("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@("`@("`@("!C
M87-E("=O<&5R871I;VXG.@H@("`@("`@("`@("`@("`@+R\@871T<FEB=71E
M<SH@;F%M90H@("`@("`@("`@("`@("`@+R\@8VAI;&1R96XZ('=S9&PZ:6YP
M=70@=W-D;#IO=71P=70@=W-D;#IF875L=`H@("`@("`@("`@("`@("`@)'1H
M:7,M/F-U<G)E;G1/<&5R871I;VX@/2`D871T<G-;)VYA;64G73L*("`@("`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E
M;G10;W)T5'EP95U;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=(#T@)&%T=')S
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=I
M;G!U="<Z"B`@("`@("`@("`@(&-A<V4@)V]U='!U="<Z"B`@("`@("`@("`@
M(&-A<V4@)V9A=6QT)SH*("`@("`@("`@("`@("`@("\O('=S9&PZ:6YP=70@
M=W-D;#IO=71P=70@=W-D;#IF875L=`H@("`@("`@("`@("`@("`@+R\@871T
M<FEB=71E<SH@;F%M92!M97-S86=E('!A<F%M971E<D]R9&5R*&]P=&EO;F%L
M*0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YC=7)R96YT3W!E<F%T:6]N
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YW<V1L
M+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;)'1H:7,M/F-U
M<G)E;G1/<&5R871I;VY=6R1N86UE72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O
M<G14>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)&YA;65=(#T@87)R
M87E?;65R9V4H)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N
M=%!O<G14>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)&YA;65=+"`D
M871T<G,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M
M/F-U<G)E;G10;W)T5'EP95U;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1N
M86UE72`]("1A='1R<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)VUE<W-A9V4G+"`D
M871T<G,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1Q;B`])B!N97<@
M44YA;64H)&%T=')S6R=M97-S86=E)UTI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R
M=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD;F%M95U;)VUE<W-A
M9V4G72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E75LD
M=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)&YA;65=6R=N86UE<W!A8V4G72`]
M("1Q;BT^;G,["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=D;V-U;65N=&%T:6]N)SH*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=B
M:6YD:6YG)SH*("`@("`@("`@("`@)&YS(#T@)'%N86UE+3YN<R`_("1T:&ES
M+3YW<V1L+3YN86UE<W!A8V5S6R1Q;F%M92T^;G-=(#H@4T-(14U!7U=31$P[
M"B`@("`@("`@("`@('-W:71C:"`H)&YS*2!["B`@("`@("`@("`@(&-A<V4@
M4T-(14U!7U-/05`Z"B`@("`@("`@("`@("`@("`O+R!T:&ES(&1E86QS('=I
M=&@@=W-D;"!S96-T:6]N(#,@<V]A<"!B:6YD:6YG"B`@("`@("`@("`@("`@
M("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@("`@("`@("`@("`@8V%S
M92`G8FEN9&EN9R<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`S+C,*
M("`@("`@("`@("`@("`@("`@("`O+R!S;V%P.F)I;F1I;F<L(&%T=')I8G5T
M97,Z('1R86YS<&]R="AR97%U:7)E9"DL('-T>6QE*&]P=&EO;F%L+"!D969A
M=6QT(#T@9&]C=6UE;G0I"B`@("`@("`@("`@("`@("`@("`@+R\@:68@<W1Y
M;&4@:7,@;6ES<VEN9RP@:70@:7,@87-S=6UE9"!T;R!B92`G9&]C=6UE;G0G
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D871T<G-;)W-T>6QE
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R<ULG<W1Y;&4G
M72`]("=D;V-U;65N="<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R
M<F5N=$)I;F1I;F==(#T@87)R87E?;65R9V4H)'1H:7,M/G=S9&PM/F)I;F1I
M;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UTL("1A='1R<RD["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G;W!E
M<F%T:6]N)SH*("`@("`@("`@("`@("`@("`@("`O+R!S96-T(#,N-`H@("`@
M("`@("`@("`@("`@("`@("\O('-O87`Z;W!E<F%T:6]N+"!A='1R:6)U=&5S
M.B!S;V%P06-T:6]N*')E<75I<F5D*2P@<W1Y;&4H;W!T:6]N86PL(&1E9F%U
M;'0@/2!S;V%P.F)I;F1I;F<Z<W1Y;&4I"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D871T<G-;)W-T>6QE)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A='1R<ULG<W1Y;&4G72`]("1T:&ES+3YW<V1L+3YB:6YD
M:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=S='EL92==.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;
M)V]P97)A=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD
M=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UU;)'1H:7,M/F-U
M<G)E;G1/<&5R871I;VY=(#T@87)R87E?;65R9V4H)'1H:7,M/G=S9&PM/F)I
M;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD
M=&AI<RT^8W5R<F5N=$]P97)A=&EO;ETL("1A='1R<RD["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)V]P
M97)A=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;ET@/2`D871T<G,[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V)O9'DG.@H@("`@("`@("`@
M("`@("`@("`@("\O('-E8W0@,RXU"B`@("`@("`@("`@("`@("`@("`@+R\@
M<V]A<#IB;V1Y(&%T=')I8G5T97,Z"B`@("`@("`@("`@("`@("`@("`@+R\@
M<&%R="`M(&]P=&EO;F%L+B`@;&ES=&5D('!A<G1S(&UU<W0@87!P96%R(&EN
M(&)O9'DL(&UI<W-I;F<@;65A;G,@86QL('!A<G1S(&%P<&5A<B!I;B!B;V1Y
M"B`@("`@("`@("`@("`@("`@("`@+R\@=7-E("T@<F5Q=6ER960N(&5N8V]D
M961\;&ET97)A;`H@("`@("`@("`@("`@("`@("`@("\O(&5N8V]D:6YG4W1Y
M;&4@+2!O<'1I;VYA;"X@('-P86-E('-E<&5R871E9"!L:7-T(&]F(&5N8V]D
M:6YG<R`H=7)I)W,I"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6R=O<&5R871I;VYS)UU;)'1H:7,M
M/F-U<G)E;G1/<&5R871I;VY=6R1T:&ES+3YO<%-T871U<UT@/2`D871T<G,[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G9F%U;'0G.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@,RXV
M"B`@("`@("`@("`@("`@("`@("`@+R\@<V]A<#IF875L="!A='1R:6)U=&5S
M.B!N86UE('5S92`@96YC;V1I;F=3='EL92!N86UE<W!A8V4*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E
M;G1":6YD:6YG70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!;)V]P97)A=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H
M:7,M/F]P4W1A='5S72`]("1A='1R<SL*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=H96%D97(G.@H@("`@("`@
M("`@("`@("`@("`@("\O('-E8W0@,RXW"B`@("`@("`@("`@("`@("`@("`@
M+R\@<V]A<#IH96%D97(@871T<FEB=71E<SH@;65S<V%G92!P87)T('5S92!E
M;F-O9&EN9U-T>6QE(&YA;65S<&%C90H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F=="B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LG;W!E<F%T:6]N
M<R==6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD=&AI<RT^;W!3=&%T=7-=
M6R=H96%D97)S)UU;72`]("1A='1R<SL*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=H96%D97)F875L="<Z"B`@
M("`@("`@("`@("`@("`@("`@+R\@<V5C="`S+C<*("`@("`@("`@("`@("`@
M("`@("`O+R!S;V%P.FAE861E<B!A='1R:6)U=&5S.B!M97-S86=E('!A<G0@
M=7-E(&5N8V]D:6YG4W1Y;&4@;F%M97-P86-E"B`@("`@("`@("`@("`@("`@
M("`@)&AE861E<B`](&-O=6YT*"1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI
M<RT^8W5R<F5N=$)I;F1I;F=="B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%LG;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT3W!E<F%T
M:6]N75LD=&AI<RT^;W!3=&%T=7-=6R=H96%D97)S)UTI+3$["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R
M96YT0FEN9&EN9UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6R=O<&5R871I;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1T
M:&ES+3YO<%-T871U<UU;)VAE861E<G,G75LD:&5A9&5R75LG9F%U;'0G72`]
M("1A='1R<SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=D;V-U;65N=&%T:6]N)SH*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@("`@("\O(&5R<F]R(2`@;F]T(&$@=F%L:60@96QE;65N="!I
M;G-I9&4@8FEN9&EN9PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(%-#2$5-05]74T1,.@H@("`@("`@("`@("`@("`@+R\@6%A8
M('9E<FEF>2!C;W)R96-T(&YA;65S<&%C90H@("`@("`@("`@("`@("`@+R\@
M9F]R(&YO=RP@9&5F875L="!I<R!T:&4@)W=S9&PG(&YA;65S<&%C90H@("`@
M("`@("`@("`@("`@+R\@;W1H97(@<&]S<VEB;&4@;F%M97-P86-E<R!I;F-L
M=61E('-M='`L(&AT='`L(&5T8RX@9F]R(&%L=&5R;F%T92!B:6YD:6YG<PH@
M("`@("`@("`@("`@("`@<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@("`@
M("`@("`@("`@(&-A<V4@)V]P97)A=&EO;B<Z"B`@("`@("`@("`@("`@("`@
M("`@+R\@<V5C="`R+C4*("`@("`@("`@("`@("`@("`@("`O+R!W<V1L.F]P
M97)A=&EO;B!A='1R:6)U=&5S.B!N86UE"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F-U<G)E;G1/<&5R871I;VX@/2`D871T<G-;)VYA;64G73L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M("=O=71P=70G.@H@("`@("`@("`@("`@("`@8V%S92`G:6YP=70G.@H@("`@
M("`@("`@("`@("`@8V%S92`G9F%U;'0G.@H@("`@("`@("`@("`@("`@("`@
M("\O('-E8W0@,BXU"B`@("`@("`@("`@("`@("`@("`@+R\@=W-D;#II;G!U
M="!A='1R:6)U=&5S.B!N86UE"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F]P4W1A='5S(#T@)'%N86UE+3YN86UE.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V1O8W5M96YT871I;VXG
M.@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@4T-(14U!7U=31$Q?2%144#H*("`@("`@("`@("`@("`@('-W:71C
M:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@("`@("!C87-E("=B:6YD
M:6YG)SH*("`@("`@("`@("`@("`@("`@("`O+R!S96-T(#0N-`H@("`@("`@
M("`@("`@("`@("`@("\O(&AT='`Z8FEN9&EN9R!A='1R:6)U=&5S.B!V97)B
M"B`@("`@("`@("`@("`@("`@("`@+R\@<&%R96YT.B!W<V1L.F)I;F1I;F<*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H
M:7,M/F-U<G)E;G1":6YD:6YG72`](&%R<F%Y7VUE<F=E*"1T:&ES+3YW<V1L
M+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==+"`D871T<G,I.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A
M<V4@)V]P97)A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`T
M+C4*("`@("`@("`@("`@("`@("`@("`O+R!H='1P.F]P97)A=&EO;B!A='1R
M:6)U=&5S.B!L;V-A=&EO;@H@("`@("`@("`@("`@("`@("`@("\O('!A<F5N
M=#H@=W-D;#IO<&5R871I;VX*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG75LG;W!E<F%T
M:6]N<R=="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N72`]
M("1A='1R<SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=U<FQ%;F-O9&5D)SH*("`@("`@("`@("`@("`@("`@
M("`O+R!S96-T(#0N-@H@("`@("`@("`@("`@("`@("`@("\O(&AT='`Z=7)L
M16YC;V1E9"!A='1R:6)U=&5S.B!L;V-A=&EO;@H@("`@("`@("`@("`@("`@
M("`@("\O('!A<F5N=#H@=W-D;#II;G!U="!W<V1L.F]U='!U="!E=&,N"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES
M+3YC=7)R96YT0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD=&AI<RT^;W!3=&%T
M=7-="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LG=7)I
M)UT@/2`G=7)L16YC;V1E9"<["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@8V%S92`G=7)L4F5P;&%C96UE;G0G.@H@("`@
M("`@("`@("`@("`@("`@("\O('-E8W0@-"XW"B`@("`@("`@("`@("`@("`@
M("`@+R\@:'1T<#IU<FQ297!L86-E;65N="!A='1R:6)U=&5S.B!L;V-A=&EO
M;@H@("`@("`@("`@("`@("`@("`@("\O('!A<F5N=#H@=W-D;#II;G!U="!W
M<V1L.F]U='!U="!E=&,N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)V]P97)A=&EO
M;G,G75LD=&AI<RT^;W!3=&%T=7-="B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R1T:&ES+3YC=7)R
M96YT3W!E<F%T:6]N75LG=7)I)UT@/2`G=7)L4F5P;&%C96UE;G0G.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)V1O8W5M96YT871I;VXG.@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@
M+R\@97)R;W(*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&-A<V4@4T-(14U!7TU)344Z"B`@("`@
M("`@("`@("`@("`O+R!S96-T(#4*("`@("`@("`@("`@("`@("\O(&%L;"!M
M:6UE('!A<G1S(&%R92!C:&EL9')E;B!O9B!W<V1L.FEN<'5T+"!W<V1L.F]U
M='!U="P@971C+@H@("`@("`@("`@("`@("`@+R\@=6YS=7!O<G1E9"!A<R!O
M9B!Y970*("`@("`@("`@("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE*2![
M"B`@("`@("`@("`@("`@("!C87-E("=C;VYT96YT)SH*("`@("`@("`@("`@
M("`@("`@("`O+R!S96-T(#4N,R!M:6UE.F-O;G1E;G0*("`@("`@("`@("`@
M("`@("`@("`O+R`\;6EM93IC;VYT96YT('!A<G0](FYM=&]K96XB/R!T>7!E
M/2)S=')I;F<B/R\^"B`@("`@("`@("`@("`@("`@("`@+R\@<&%R="!A='1R
M:6)U=&4@;VYL>2!R97%U:7)E9"!I9B!C;VYT96YT(&ES(&-H:6QD(&]F(&UU
M;'1I<&%R="!R96QA=&5D+`H@("`@("`@("`@("`@("`@("`@("\O("`@("`@
M("!I="!C;VYT86EN<R!T:&4@;F%M92!O9B!T:&4@<&%R=`H@("`@("`@("`@
M("`@("`@("`@("\O('1Y<&4@871T<FEB=71E(&-O;G1A:6YS('1H92!M:6UE
M('1Y<&4*("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I<&%R=%)E;&%T960G
M.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@-2XT(&UI;64Z;75L=&EP
M87)T4F5L871E9`H@("`@("`@("`@("`@("`@8V%S92`G<&%R="<Z"B`@("`@
M("`@("`@("`@("!C87-E("=M:6UE6&UL)SH*("`@("`@("`@("`@("`@("`@
M("`O+R!S96-T(#4N-B!M:6UE.FUI;658;6P*("`@("`@("`@("`@("`@("`@
M("`O+R`\;6EM93IM:6UE6&UL('!A<G0](FYM=&]K96XB/R\^"B`@("`@("`@
M("`@("`@("`@("`@+R\*("`@("`@("`@("`@("`@(&-A<V4@)V1O8W5M96YT
M871I;VXG.@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@+R\@97)R;W(*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&-A<V4@4T-(14U!7T1)344Z"B`@("`@("`@("`@("`@
M("`O+R!$24U%(&ES(&1E9FEN960@:6XZ"B`@("`@("`@("`@("`@("`O+R!H
M='1P.B\O9V]T9&]T;F5T+F-O;2]T96%M+WAM;%]W<W-P96-S+V1I;64O5U-$
M3"U%>'1E;G-I;VXM9F]R+41)344N:'1M"B`@("`@("`@("`@("`@("`O+R!A
M;&P@1$E-12!P87)T<R!A<F4@8VAI;&1R96X@;V8@=W-D;#II;G!U="P@=W-D
M;#IO=71P=70L(&5T8RX*("`@("`@("`@("`@("`@("\O('5N<W5P;W)T960@
M87,@;V8@>65T"B`@("`@("`@("`@("`@("!S=VET8V@@*"1Q;F%M92T^;F%M
M92D@>PH@("`@("`@("`@("`@("`@8V%S92`G;65S<V%G92<Z"B`@("`@("`@
M("`@("`@("`@("`@+R\@<V5C="`T+C$@9&EM93IM97-S86=E"B`@("`@("`@
M("`@("`@("`@("`@+R\@87!P96%R<R!I;B!B:6YD:6YG('-E8W1I;VX*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M
M/F-U<G)E;G1":6YD:6YG75LG9&EM92==(#T@)&%T=')S.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)W-E<G9I8V4G.@H@("`@("`@("`@("`D;G,@/2`D<6YA;64M/FYS(#\@)'1H
M:7,M/G=S9&PM/FYA;65S<&%C97-;)'%N86UE+3YN<UT@.B!30TA%34%?5U-$
M3#L*"B`@("`@("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@
M("`@("`@(&-A<V4@)W!O<G0G.@H@("`@("`@("`@("`@("`@+R\@<V5C="`R
M+C8@=W-D;#IP;W)T(&%T=')I8G5T97,Z(&YA;64@8FEN9&EN9PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F-U<G)E;G10;W)T(#T@)&%T=')S6R=N86UE)UT[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M
M/F-U<G)E;G1397)V:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=
M(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@+R\@6%A8(&AA8VL@=&\@9&5A
M;"!W:71H(&)I;F1I;F<@;F%M97-P86-E<PH@("`@("`@("`@("`@("`@)'%N
M(#TF(&YE=R!13F%M92@D871T<G-;)V)I;F1I;F<G72D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U<G)E;G1397)V
M:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=6R=B:6YD:6YG)UT@
M/2`D<6XM/FYA;64["B`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R
M=FEC97-;)'1H:7,M/F-U<G)E;G1397)V:6-E75LG<&]R=',G75LD=&AI<RT^
M8W5R<F5N=%!O<G1=6R=N86UE<W!A8V4G72`]("1Q;BT^;G,["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V%D9')E<W,G.@H@
M("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC
M=7)R96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG
M861D<F5S<R==(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@+R\@=VAA="!4
M65!%(&]F('!O<G0@:7,@:70_("!33T%0(&]R($A45%`_"B`@("`@("`@("`@
M("`@("`D;G,@/2`D<6YA;64M/FYS(#\@)'1H:7,M/G=S9&PM/FYA;65S<&%C
M97-;)'%N86UE+3YN<UT@.B!30TA%34%?5U-$3#L*("`@("`@("`@("`@("`@
M('-W:71C:"`H)&YS*2!["B`@("`@("`@("`@("`@("!C87-E(%-#2$5-05]7
M4T1,7TA45%`Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E
M<G9I8V5S6R1T:&ES+3YC=7)R96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M
M/F-U<G)E;G10;W)T75LG='EP92==/2=H='1P)SL*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E(%-#2$5-05]33T%0
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD
M=&AI<RT^8W5R<F5N=%-E<G9I8V5=6R=P;W)T<R==6R1T:&ES+3YC=7)R96YT
M4&]R=%U;)W1Y<&4G73TG<V]A<"<["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("`O+R!3:&]U;&1N)W0@:&%P<&5N+"!W92=L;"!A<W-U;64@4T]!4"X*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H
M:7,M/F-U<G)E;G1397)V:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O
M<G1=6R=T>7!E)UT])W-O87`G.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9&]C=6UE;G1A
M=&EO;B<Z"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+R\@5&]P(&QE=F5L(&5L96UE;G1S(&9O=6YD
M('5N9&5R('=S9&PZ9&5F:6YI=&EO;G,N"B`@("`@("`@<W=I=&-H("@D<6YA
M;64M/FYA;64I('L*("`@("`@("!C87-E("=I;7!O<G0G.@H@("`@("`@("`@
M("`O+R!S96-T(#(N,2XQ('=S9&PZ:6UP;W)T(&%T=')I8G5T97,Z(&YA;65S
M<&%C92!L;V-A=&EO;@H@("`@("`@("`@("!I9B`H*&ES<V5T*"1A='1R<ULG
M;&]C871I;VXG72D@?'P@:7-S970H)&%T=')S6R=S8VAE;6%,;V-A=&EO;B==
M*2D@)B8*("`@("`@("`@("`@("`@("%I<W-E="@D=&AI<RT^=W-D;"T^:6UP
M;W)T<ULD871T<G-;)VYA;65S<&%C92==72DI('L*("`@("`@("`@("`@("`@
M("1U<FD@/2!I<W-E="@D871T<G-;)VQO8V%T:6]N)UTI(#\@)&%T=')S6R=L
M;V-A=&EO;B==(#H@)&%T=')S6R=S8VAE;6%,;V-A=&EO;B==.PH@("`@("`@
M("`@("`@("`@)&QO8V%T:6]N(#T@0'!A<G-E7W5R;"@D=7)I*3L*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&QO8V%T:6]N6R=S8VAE;64G72DI('L*
M("`@("`@("`@("`@("`@("`@("`D8F%S92`]($!P87)S95]U<FPH)'1H:7,M
M/G5R:2D["B`@("`@("`@("`@("`@("`@("`@)'5R:2`]("1T:&ES+3YM97)G
M955R;"@D8F%S92P@)'5R:2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/FEM<&]R='-;)&%T=')S6R=N86UE<W!A
M8V4G75T@/2`D871T<G,["B`@("`@("`@("`@("`@("`D:6UP;W)T7W!A<G-E
M<E]C;&%S<R`](&=E=%]C;&%S<R@D=&AI<RD["B`@("`@("`@("`@("`@("`D
M:6UP;W)T7W!A<G-E<B`])B!N97<@)&EM<&]R=%]P87)S97)?8VQA<W,H)'5R
M:2P@)'1H:7,M/G=S9&PL("1T:&ES+3YD;V-S*3L*("`@("`@("`@("`@("`@
M(&EF("@D:6UP;W)T7W!A<G-E<BT^9F%U;'0I('L*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^=W-D;"T^:6UP;W)T<ULD871T<G-;)VYA;65S
M<&%C92==72D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E
M;G1);7!O<G0@/2`D871T<G-;)VYA;65S<&%C92==.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("\O($-O;G1I;G5E(&]N('1O('1H92`G='EP97,G(&-A
M<V4@+2!L86-K(&]F(&)R96%K.R!I<PH@("`@("`@("`@("`O+R!I;G1E;G1I
M;VYA;"X*"B`@("`@("`@8V%S92`G='EP97,G.@H@("`@("`@("`@("`O+R!S
M96-T(#(N,B!W<V1L.G1Y<&5S"B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@
M/2`G='EP97,G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M<V-H96UA)SH*("`@("`@("`@("`@+R\@5V4@8V%N(&AI="!T:&ES(&%T('1H
M92!T;W`@;&5V96P@:68@=V4G=F4@8F5E;B!A<VME9"!T;PH@("`@("`@("`@
M("`O+R!I;7!O<G0@86X@6%-$(&9I;&4N"B`@("`@("`@("`@(&EF("@A96UP
M='DH)&%T=')S6R=T87)G971.86UE<W!A8V4G72DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS8VAE;6$@/2`D=&AI<RT^=W-D;"T^9V5T3F%M97-P86-E
M071T<FEB=71E3F%M92@D871T<G-;)W1A<F=E=$YA;65S<&%C92==*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YS8VAE
M;6$@/2`D=&AI<RT^=W-D;"T^9V5T3F%M97-P86-E071T<FEB=71E3F%M92@D
M=&AI<RT^=W-D;"T^=&YS*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=(#T@87)R
M87DH*3L*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F5L96UE;G1S6R1T:&ES
M+3YS8VAE;6%=(#T@87)R87DH*3L*("`@("`@("`@("`@)'1H:7,M/G-C:&5M
M85]S=&%C:UM=(#T@)'%N86UE+3YN86UE.PH@("`@("`@("`@("`D=&AI<RT^
M<W1A='5S(#T@)W1Y<&5S)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`O+R!S96-T(#(N,R!W<V1L
M.FUE<W-A9V4@871T<FEB=71E<SH@;F%M92!C:&EL9')E;CIW<V1L.G!A<G0*
M("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=M97-S86=E)SL*("`@("`@
M("`@("`@:68@*&ES<V5T*"1A='1R<ULG;F%M92==*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F-U<G)E;G1-97-S86=E(#T@)&%T=')S6R=N86UE)UT[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^;65S<V%G97-;)'1H:7,M
M/F-U<G)E;G1-97-S86=E72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W!O<G14>7!E)SH*("`@
M("`@("`@("`@+R\@<V5C="`R+C0@=W-D;#IP;W)T5'EP90H@("`@("`@("`@
M("`O+R!A='1R:6)U=&5S.B!N86UE"B`@("`@("`@("`@("\O(&-H:6QD<F5N
M.B!W<V1L.F]P97)A=&EO;@H@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@
M)W!O<G14>7!E)SL*("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G10;W)T5'EP
M92`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@("`D=&AI<RT^=W-D;"T^
M<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=(#T@87)R87DH*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V)I;F1I;F<G.@H@
M("`@("`@("`@("`O+R!S96-T(#(N-2!W<V1L.F)I;F1I;F<@871T<FEB=71E
M<SH@;F%M92!T>7!E"B`@("`@("`@("`@("\O(&-H:6QD<F5N.B!W<V1L.F]P
M97)A=&EO;B!S;V%P.F)I;F1I;F<@:'1T<#IB:6YD:6YG"B`@("`@("`@("`@
M(&EF("@D<6YA;64M/FYS("8F("1Q;F%M92T^;G,@(3T@)'1H:7,M/G1N<RD@
M>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/G-T871U<R`]("=B:6YD:6YG)SL*("`@("`@("`@("`@
M)'1H:7,M/F-U<G)E;G1":6YD:6YG(#T@)&%T=')S6R=N86UE)UT["B`@("`@
M("`@("`@("1Q;B`])B!N97<@44YA;64H)&%T=')S6R=T>7!E)UTI.PH@("`@
M("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1"
M:6YD:6YG75LG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG75LG;F%M
M97-P86-E)UT@/2`D<6XM/FYS.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G<V5R=FEC92<Z"B`@("`@("`@("`@("\O('-E8W0@,BXW('=S
M9&PZ<V5R=FEC92!A='1R:6)U=&5S.B!N86UE(&-H:6QD<F5N.B!P;W)T<PH@
M("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%-E<G9I8V4@/2`D871T<G-;)VYA
M;64G73L*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES
M+3YC=7)R96YT4V5R=FEC95U;)W!O<G1S)UT@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D=&AI<RT^<W1A='5S(#T@)W-E<G9I8V4G.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G9&5F:6YI=&EO;G,G.@H@("`@("`@("`@
M("`O+R!S96,@,BXQ('=S9&PZ9&5F:6YI=&EO;G,*("`@("`@("`@("`@+R\@
M871T<FEB=71E<SH@;F%M92!T87)G971.86UE<W!A8V4@>&UL;G,Z*@H@("`@
M("`@("`@("`O+R!C:&EL9')E;CH@=W-D;#II;7!O<G0@=W-D;#IT>7!E<R!W
M<V1L.FUE<W-A9V4@=W-D;#IP;W)T5'EP92!W<V1L.F)I;F1I;F<@=W-D;#IS
M97)V:6-E"B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YD969I;FET:6]N(#T@
M)&%T=')S.PH@("`@("`@("`@("!F;W)E86-H("@D871T<G,@87,@)&ME>2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("AS=')S='(H)&ME>2P@
M)WAM;&YS.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1Q
M;B`])B!N97<@44YA;64H)&ME>2D["B`@("`@("`@("`@("`@("`@("`@+R\@
M6%A8(&YE960@=&\@<F5F86-T;W(@;G,@:&%N9&QI;F<N"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)'%N+3YN86UE72`]
M("1V86QU93L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^;G-;
M)'9A;'5E72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&ME>2`]/2`G=&%R9V5T3F%M97-P86-E)R!\?`H@("`@("`@("`@("`@("`@
M("`@("`@("!S=')C87-E8VUP*"1V86QU92Q33T%07U-#2$5-02D@/3T@,"D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V]A<&YS6UT@/2`D
M<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1V86QU92P@)'1H:7,M
M/E]834Q38VAE;6$I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^>'-D(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D;G,I("8F
M("1N<RD@>PH@("`@("`@("`@("`@("`@)&YA;65S<&%C92`]("=X;6QN<SHG
M("X@)&YS.PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^=W-D;"T^9&5F
M:6YI=&EO;ELD;F%M97-P86-E72D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")P87)S92!E<G)O<BP@;F\@
M;F%M97-P86-E(&9O<B`D;F%M97-P86-E(BP@)'1H:7,M/G5R:2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^=&YS(#T@)&YS
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(&5N9"UE;&5M96YT(&AA;F1L97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'!A<G-E<BP@)&YA;64I
M"B`@("!["B`@("`@("`@)'-T86-K<VEZ92`](&-O=6YT*"1T:&ES+3YE;&5M
M96YT7W-T86-K*3L*("`@("`@("!I9B`H)'-T86-K<VEZ92D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/F5L96UE;G1?<W1A8VM;)'-T86-K<VEZ92`M(#%=
M(#T]("=D969I;FET:6]N<R<I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M=&%T=7,@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G)A>5]P
M;W`H)'1H:7,M/F5L96UE;G1?<W1A8VLI.PH@("`@("`@('T*"B`@("`@("`@
M:68@*'-T<FES='(H)&YA;64L("=S8VAE;6$G*2D@>PH@("`@("`@("`@("!A
M<G)A>5]P;W`H)'1H:7,M/G-C:&5M85]S=&%C:RD["B`@("`@("`@("`@("1T
M:&ES+3YS8VAE;6$@/2`G)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI
M<RT^<V-H96UA*2!["B`@("`@("`@("`@(&%R<F%Y7W!O<"@D=&AI<RT^<V-H
M96UA7W-T86-K*3L*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YS8VAE
M;6%?<W1A8VLI(#P](#$I('L*("`@("`@("`@("`@("`@("\J($-O<G)E8W0@
M=&AE('1Y<&4@9F]R('-E<75E;F-E<R!W:71H(&UU;'1I<&QE"B`@("`@("`@
M("`@("`@("`@*B!E;&5M96YT<RX@*B\*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E*2`F)B!I<W-E="@D=&AI
M<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC
M=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UTI"B`@("`@("`@("`@("`@("`@
M("`@)B8@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA
M75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T]("=!<G)A
M>2<*("`@("`@("`@("`@("`@("`@("`F)B!A<G)A>5]K97E?97AI<W1S*"=E
M;&5M96YT<R<L("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C
M:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95TI"B`@("`@("`@("`@
M("`@("`@("`@)B8@8V]U;G0H)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD
M=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG96QE
M;65N=',G72D@/B`Q*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72`]("=3=')U8W0G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=')I
M<W1R*"1N86UE+"`G8V]M<&QE>%1Y<&4G*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP92`]("<G.PH@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S=&%C:RDI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$5L96UE;G0@/2!A
M<G)A>5]P;W`H)'1H:7,M/G-C:&5M85]E;&5M96YT7W-T86-K*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F-U<G)E;G1%;&5M96YT(#T@)R<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS96EF("AS=')I<W1R*"1N86UE+"`G96QE;65N="<I*2![
M"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/G-C:&5M85]E;&5M
M96YT7W-T86-K*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R
M96YT16QE;65N="`](&%R<F%Y7W!O<"@D=&AI<RT^<V-H96UA7V5L96UE;G1?
M<W1A8VLI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8W5R<F5N=$5L96UE;G0@/2`G)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($5L96UE;G0@8V]N=&5N="!H86YD;&5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C:&%R86-T97)$871A*"1P87)S97(L("1D871A*0H@("`@
M>PH@("`@("`@("\O(%-T;W)E('1H92!D;V-U;65N=&%T:6]N(&EN('1H92!7
M4T1,(&9I;&4N"B`@("`@("`@:68@*"1T:&ES+3YC=7)R96YT5&%G(#T]("=D
M;V-U;65N=&%T:6]N)RD@>PH@("`@("`@("`@("`D9&%T82`]('1R:6TH<')E
M9U]R97!L86-E*"<O7',K+R<L("<@)RP@)&1A=&$I*3L*("`@("`@("`@("`@
M:68@*"%S=')L96XH)&1A=&$I*2!["B`@("`@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/G-T
M871U<RD@>PH@("`@("`@("`@("!C87-E("=S97)V:6-E)SH*("`@("`@("`@
M("`@("`@("1P='(@/28@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC
M=7)R96YT4V5R=FEC95T["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)W!O<G14>7!E)SH*("`@("`@("`@("`@("`@("1P='(@
M/28@)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14
M>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;ET["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V)I;F1I;F<G.@H@("`@("`@
M("`@("`@("`@)'!T<B`])B`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M
M/F-U<G)E;G1":6YD:6YG73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G;65S<V%G92<Z"B`@("`@("`@("`@("`@("`D<'1R
M(#TF("1T:&ES+3YW<V1L+3YM97-S86=E<ULD=&AI<RT^8W5R<F5N=$UE<W-A
M9V5=.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=O<&5R871I;VXG.@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=T>7!E<R<Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP92D@)B8*("`@("`@("`@("`@("`@
M("`@("!I<W-E="@D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS
M8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^8W5R<F5N=$5L96UE;G0I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!T<B`])B`D=&AI<RT^=W-D;"T^8V]M
M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE
M>%1Y<&5=6R=E;&5M96YT<R==6R1T:&ES+3YC=7)R96YT16QE;65N=%T["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!T<B`])B`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-S
M970H)'!T<BDI('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!T<ELG
M9&]C=6UE;G1A=&EO;B==*2D@>PH@("`@("`@("`@("`@("`@("`@("1P=');
M)V1O8W5M96YT871I;VXG72`]("<G.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D<'1R6R=D;V-U;65N=&%T:6]N)UT@
M+CT@)R`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!T
M<ELG9&]C=6UE;G1A=&EO;B==("X]("1D871A.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@)'!A<G-E9"!I<R!A;B!A
M<G)A>2!R971U<FYE9"!B>2!P87)S95]U<FPH*2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@;65R9V55<FPH
M)'!A<G-E9"P@)'!A=&@I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D
M<&%R<V5D*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D=7)I(#T@)R<["B`@("`@("`@:68@*"%E;7!T>2@D<&%R
M<V5D6R=S8VAE;64G72DI('L*("`@("`@("`@("`@)'-E<"`]("AS=')T;VQO
M=V5R*"1P87)S961;)W-C:&5M92==*2`]/2`G;6%I;'1O)R`_("<Z)R`Z("<Z
M+R\G*3L*("`@("`@("`@("`@)'5R:2`]("1P87)S961;)W-C:&5M92==("X@
M)'-E<#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=P
M87-S)UTI*2!["B`@("`@("`@("`@("1U<FD@+CT@(B1P87)S961;=7-E<ETZ
M)'!A<G-E9%MP87-S74`B.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<&%R
M<V5D6R=U<V5R)UTI*2!["B`@("`@("`@("`@("1U<FD@+CT@(B1P87)S961;
M=7-E<EU`(CL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D<&%R<V5D
M6R=H;W-T)UTI*2!["B`@("`@("`@("`@("1U<FD@+CT@)'!A<G-E9%LG:&]S
M="==.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG<&]R
M="==*2D@>PH@("`@("`@("`@("`D=7)I("X]("(Z)'!A<G-E9%MP;W)T72([
M"B`@("`@("`@?0H@("`@("`@(&EF("@D<&%T:%LP72`A/2`G+R<@)B8@:7-S
M970H)'!A<G-E9%LG<&%T:"==*2D@>PH@("`@("`@("`@("!I9B`H)'!A<G-E
M9%LG<&%T:"==6W-T<FQE;B@D<&%R<V5D6R=P871H)UTI("T@,5T@(3T@)R\G
M*2!["B`@("`@("`@("`@("`@("`D<&%T:"`](&1I<FYA;64H)'!A<G-E9%LG
M<&%T:"==*2`N("<O)R`N("1P871H.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'!A=&@@/2`D<&%R<V5D6R=P871H)UT@+B`D<&%T
M:#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&%T:"`]("1T:&ES+3Y?
M;F]R;6%L:7IE*"1P871H*3L*("`@("`@("!]"B`@("`@("`@)'-E<"`]("1P
M871H6S!=(#T]("<O)R`_("<G(#H@)R\G.PH@("`@("`@("1U<FD@+CT@)'-E
M<"`N("1P871H.PH*("`@("`@("!R971U<FX@)'5R:3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?;F]R;6%L:7IE*"1P871H7W-T<BD*("`@('L*("`@("`@("`D
M<'=D(#T@)R<["B`@("`@("`@)'-T<D%R<B`]('!R96=?<W!L:70H)R\H7"\I
M+R<L("1P871H7W-T<BP@+3$L(%!214=?4U!,251?3D]?14U05%DI.PH@("`@
M("`@("1P=V1!<G(@/2`G)SL*("`@("`@("`D:B`](#`["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@8V]U;G0H)'-T<D%R<BD[("1I*RLI('L*("`@("`@
M("`@("`@:68@*"1S=')!<G);)&E=("$]("<@+BXG*2!["B`@("`@("`@("`@
M("`@("!I9B`H)'-T<D%R<ELD:5T@(3T@)R`N)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1P=V1!<G);)&I=(#T@)'-T<D%R<ELD:5T["B`@("`@("`@("`@
M("`@("`@("`@)&HK*SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<'=D07)R*3L*
M("`@("`@("`@("`@("`@("1J+2T["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@)'!3='(@/2!I;7!L;V1E*"<O)RP@)'!W9$%R<BD["B`@("`@
M("`@)'!W9"`]("AS=')L96XH)'!3='(I(#X@,"D@/R`H)R\G("X@)'!3='(I
M(#H@)R\G.PH@("`@("`@(')E='5R;B`D<'=D.PH@("`@?0H*?0H*+RHJ"B`J
M(%!A<G-E<R!T:&4@='EP97,@86YD(&UE=&AO9',@=7-E9"!I;B!W96(@<V5R
M=FEC92!O8FIE8W1S(&EN=&\@=&AE(&EN=&5R;F%L"B`J(&1A=&$@<W1R=6-T
M=7)E<R!U<V5D(&)Y(%-/05!?5U-$3"X*("H*("H@07-S=6UE<R!T:&4@4T]!
M4%]74T1,(&-L87-S(&ES('5N<&]P=6QA=&5D('1O('-T87)T('=I=&@N"B`J
M"B`J($!A=71H;W(@0VAR:7,@0V]E(#QI;F9O0&EN=&5L;&EG96YT<W1R96%M
M:6YG+F-O;3X*("HO"F-L87-S(%-/05!?5U-$3%]/8FIE8W1087)S97(@97AT
M96YD<R!33T%07T)A<V4*>PH@("`@+RHJ"B`@("`@*B!487)G970@;F%M97-P
M86-E(&9O<B!T:&4@5U-$3"!D;V-U;65N="!W:6QL(&AA=F4@=&AE(&9O;&QO
M=VEN9PH@("`@("H@<')E9FEX+@H@("`@("HO"B`@("!V87(@)'1N<U!R969I
M>"`]("=T;G,G.PH*("`@("\J*@H@("`@("H@4F5F97)E;F-E('1O('1H92!3
M3T%07U=31$P@;V)J96-T('1O('!O<'5L871E+@H@("`@("HO"B`@("!V87(@
M)'=S9&P@/2!N=6QL.PH*("`@("\J*B!#;VYS=')U8W1O<@H@("`@("H*("`@
M("`J($!P87)A;2`@)&]B:F5C=',@4F5F97)E;F-E('1O('1H92!O8FIE8W0@
M;W(@87)R87D@;V8@;V)J96-T<R!T;R!P87)S90H@("`@("H@0'!A<F%M("`D
M=W-D;"!2969E<F5N8V4@=&\@=&AE(%-/05!?5U-$3"!O8FIE8W0@=&\@<&]P
M=6QA=&4*("`@("`J($!P87)A;2`@)'1A<F=E=$YA;65S<&%C92!4:&4@=&%R
M9V5T(&YA;65S<&%C92!O9B!S8VAE;6$@='EP97,@971C+@H@("`@("H@0'!A
M<F%M("`D<V5R=FEC95]N86UE($YA;64@;V8@=&AE(%=31$P@/'-E<G9I8V4^
M"B`@("`@*B!`<&%R86T@("1S97)V:6-E7V1E<V,@3W!T:6]N86P@9&5S8W)I
M<'1I;VX@;V8@=&AE(%=31$P@/'-E<G9I8V4^"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%-/05!?5U-$3%]/8FIE8W1087)S97(H)B1O8FIE8W1S+"`F)'=S9&PL
M("1T87)G971.86UE<W!A8V4L("1S97)V:6-E7VYA;64L("1S97)V:6-E7V1E
M<V,@/2`G)RD*("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$
M3$]"2D5#5%!!4E-%4B<I.PH*("`@("`@("`D=&AI<RT^=W-D;"`]("8D=W-D
M;#L*"B`@("`@("`@+R\@4V5T('5P('1H92!33T%07U=31$P@;V)J96-T"B`@
M("`@("`@)'1H:7,M/E]I;FET:6%L:7-E*"1S97)V:6-E7VYA;64I.PH*("`@
M("`@("`O+R!087)S92!E86-H('=E8B!S97)V:6-E(&]B:F5C=`H@("`@("`@
M("1W<V1L7W)E9B`]("AI<U]A<G)A>2@D;V)J96-T<RD_("1O8FIE8W1S(#H@
M87)R87DH)B1O8FIE8W1S*2D["@H@("`@("`@(&9O<F5A8V@@*"1W<V1L7W)E
M9B!A<R`D<F5F7VET96TI('L*("`@("`@("`@("`@:68@*"%I<U]O8FIE8W0H
M)')E9E]I=&5M*2D*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"=);G9A;&ED('=E8B!S97)V:6-E(&]B:F5C="!P87-S
M960@=&\@;V)J96-T('!A<G-E<B<L("=U<FXZ)R`N(&=E=%]C;&%S<R@D;V)J
M96-T*2D["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]P87)S92@D<F5F7VET
M96TL("1T87)G971.86UE<W!A8V4L("1S97)V:6-E7VYA;64I("$]('1R=64I
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\O
M($)U:6QD(&)I;F1I;F=S(&9R;VT@86)S=')A8W0@9&%T82X*("`@("`@("!I
M9B`H)'1H:7,M/F9A=6QT(#T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M
M/E]G96YE<F%T94)I;F1I;F=S06YD4V5R=FEC97,H)'1A<F=E=$YA;65S<&%C
M92P@)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?9&5S8RD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA;&ES92!T:&4@4T]!4%]74T1,
M('1R964@*&1E<W1R=6-T:79E*2X*("`@("`J"B`@("`@*B!)9B!T:&4@;V)J
M96-T(&AA<R!A;')E861Y(&)E96X@:6YI=&EA;&ES960L('1H92!O;FQY(&5F
M9F5C=`H@("`@("H@=VEL;"!B92!T;R!C:&%N9V4@=&AE('1N<R!N86UE<W!A
M8V4@=&\@=&AE(&YE=R!S97)V:6-E(&YA;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M("`D<V5R=FEC95]N86UE($YA;64@;V8@=&AE(%=31$P@/'-E<G9I8V4^
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VEN:71I86QI<V4H)'-E<G9I8V5?;F%M92D*("`@('L*("`@("`@("`O+R!3
M970@=7`@=&AE(&)A<VEC(&YA;65S<&%C97,@=&AA="!A;&P@5U-$3"!D969I
M;FET:6]N<R!U<V4N"B`@("`@("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;
M)W=S9&PG72`](%-#2$5-05]74T1,.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@5U-$3"!L86YG=6%G90H@("`@("`@("1T:&ES
M+3YW<V1L+3YN86UE<W!A8V5S6R=S;V%P)UT@/2!30TA%34%?4T]!4#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%=31$P@4T]!
M4"!B:6YD:6YG<PH@("`@("`@("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1T
M:&ES+3YT;G-0<F5F:7A=(#T@)W5R;CHG("X@)'-E<G9I8V5?;F%M93L@("`@
M("`@("`@("`@("`@("\O(%1A<F=E="!N86UE<W!A8V4*("`@("`@("`D=&AI
M<RT^=W-D;"T^;F%M97-P86-E<ULG>'-D)UT@/2!A<G)A>5]S96%R8V@H)WAS
M9"<L("1T:&ES+3Y?;F%M97-P86-E<RD[("`@("`@("`@("`O+R!834P@4V-H
M96UA"B`@("`@("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)U-/05`M14Y#
M)UT@/2!A<G)A>5]S96%R8V@H)U-/05`M14Y#)RP@)'1H:7,M/E]N86UE<W!A
M8V5S*3L@+R\@4T]!4"!T>7!E<PH*("`@("`@("`O+R!86%@@4F5F86-T;W(@
M)&YA;65S<&%C92\D;G,@9F]R(%-H86YE(#HM*0H@("`@("`@('5N<V5T*"1T
M:&ES+3YW<V1L+3YN<ULG=7)N.B<@+B`D<V5R=FEC95]N86UE72D["B`@("`@
M("`@)'1H:7,M/G=S9&PM/FYS("L](&%R<F%Y7V9L:7`H)'1H:7,M/G=S9&PM
M/FYA;65S<&%C97,I.PH*("`@("`@("`O+R!);7!O<G1S(&%R92!N;W0@:6UP
M;&5M96YT960@:6X@5U-$3"!G96YE<F%T:6]N(&9R;VT@8VQA<W-E<RX*("`@
M("`@("`O+R`J*BH@/'=S9&PZ:6UP;W)T/B`J*BH*("`@('T*"B`@("`O*BH*
M("`@("`J(%!A<G-E<B`M('1A:V5S(&$@<VEN9VQE(&]B:F5C="!T;R!A9&0@
M=&\@=')E90H@("`@("H@*&YO;BUD97-T<G5C=&EV92DN"B`@("`@*@H@("`@
M("H@0'!A<F%M("`D;V)J96-T(%)E9F5R96YC92!T;R!T:&4@;V)J96-T('1O
M('!A<G-E"B`@("`@*B!`<&%R86T@("1S97)V:6-E7VYA;64@3F%M92!O9B!T
M:&4@5U-$3"`\<V5R=FEC93X*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]P87)S92@F)&]B:F5C="P@)'-C:&5M84YA;65S
M<&%C92P@)'-E<G9I8V5?;F%M92D*("`@('L*("`@("`@("`O+R!#<F5A=&4@
M;F%M97-P86-E('!R969I>"!F;W(@=&AE('-C:&5M80H@("`@("`@("\O(%A8
M6"!N;W0@=F5R>2!E;&5G86YT(#HM*`H*("`@("`@("!L:7-T*"1S8VA0<F5F
M:7@L("1F;V\I(#T@)'1H:7,M/E]G9714>7!E3G,H)WLG("X@)'-C:&5M84YA
M;65S<&%C92XG?2<I.PH@("`@("`@('5N<V5T*"1F;V\I.PH*("`@("`@("`O
M+R!087)S92!A;&P@=&AE('1Y<&5S(&1E9FEN960@8GD@=&AE(&]B:F5C="!I
M;B!W:&%T979E<@H@("`@("`@("\O('-C:&5M82!L86YG=6%G92!W92!A<F4@
M=7-I;F<@*&-U<G)E;G1L>2!?7W1Y<&5D968@87)R87ES*0H@("`@("`@("\O
M("HJ*B`\=W-D;#IT>7!E<SX@*BHJ"@H@("`@("`@(&9O<F5A8V@@*"1O8FIE
M8W0M/E]?='EP961E9B!A<R`D='EP94YA;64@/3X@)'1Y<&5686QU92D@>PH@
M("`@("`@("`@("`O+R!'970O8W)E871E(&YA;65S<&%C92!D969I;FET:6]N
M"@H@("`@("`@("`@("!L:7-T*"1N<U!R969I>"P@)'1Y<&5.86UE*2`]("1T
M:&ES+3Y?9V5T5'EP94YS*"1T>7!E3F%M92D["@H@("`@("`@("`@("`O+R!#
M<F5A=&4@='EP92!D969I;FET:6]N"@H@("`@("`@("`@("`D=&AI<RT^=W-D
M;"T^8V]M<&QE>%1Y<&5S6R1S8VA0<F5F:7A=6R1T>7!E3F%M95T@/2!A<G)A
M>2@G;F%M92<@/3X@)'1Y<&5.86UE*3L*("`@("`@("`@("`@)'1H:7-4>7!E
M(#TF("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'-C:%!R969I>%U;)'1Y
M<&5.86UE73L*"B`@("`@("`@("`@("\O($%C8V]R9&EN9R!T;R!$;6ET<FDG
M<R!D;V-U;65N=&%T:6]N+"!?7W1Y<&5D968@8V]M97,@:6X@='=O"B`@("`@
M("`@("`@("\O(&9L879O<G,Z"B`@("`@("`@("`@("\O($%R<F%Y(#T@87)R
M87DH87)R87DH(FET96TB(#T^(")V86QU92(I*0H@("`@("`@("`@("`O+R!3
M=')U8W0@/2!A<G)A>2@B:71E;3$B(#T^(")V86QU93$B+"`B:71E;3(B(#T^
M(")V86QU93(B+"`N+BXI"@H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1Y
M<&5686QU92DI('L*("`@("`@("`@("`@("`@(')E<V5T*"1T>7!E5F%L=64I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*&-U<G)E;G0H)'1Y<&56
M86QU92DI("8F(&-O=6YT*"1T>7!E5F%L=64I(#T](#$*("`@("`@("`@("`@
M("`@("`@("`F)B!C;W5N="AC=7)R96YT*"1T>7!E5F%L=64I*2`]/2`Q*2![
M"B`@("`@("`@("`@("`@("`@("`@+R\@270G<R!A;B!A<G)A>0H*("`@("`@
M("`@("`@("`@("`@("`D=&AI<U1Y<&5;)W1Y<&4G72`]("=!<G)A>2<["B`@
M("`@("`@("`@("`@("`@("`@<F5S970H8W5R<F5N="@D='EP959A;'5E*2D[
M"B`@("`@("`@("`@("`@("`@("`@;&ES="@D;G-0<F5F:7@L("1T>7!E3F%M
M92D@/2`D=&AI<RT^7V=E=%1Y<&5.<RAC=7)R96YT*&-U<G)E;G0H)'1Y<&56
M86QU92DI*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)VYA;65S
M<&%C92==(#T@)&YS4')E9FEX.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M5'EP95LG87)R87E4>7!E)UT@/2`D='EP94YA;64@+B`G6UTG.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2AC=7)R96YT*"1T>7!E5F%L
M=64I*2D@>PH@("`@("`@("`@("`@("`@("`@("\O($ET)W,@82!S=')U8W0*
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=T>7!E)UT@/2`G4W1R
M=6-T)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V]R9&5R)UT@
M/2`G86QL)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)VYA;65S
M<&%C92==(#T@)&YS4')E9FEX.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M5'EP95LG96QE;65N=',G72`](&%R<F%Y*"D["@H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1T>7!E5F%L=64@87,@)&5L96UE;G1.86UE(#T^("1E
M;&5M96YT5'EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1N
M<U!R969I>"P@)'1Y<&5.86UE*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1E;&5M
M96YT5'EP92D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES5'EP95LG
M96QE;65N=',G75LD96QE;65N=$YA;65=6R=N86UE)UT@/2`D96QE;65N=$YA
M;64["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES5'EP95LG96QE;65N
M=',G75LD96QE;65N=$YA;65=6R=T>7!E)UT@/2`D='EP94YA;64["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES5'EP95LG96QE;65N=',G75LD96QE
M;65N=$YA;65=6R=N86UE<W!A8V4G72`]("1N<U!R969I>#L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("\O($ET)W,@97)R;VYE;W5S"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E1H92!T>7!E
M(&1E9FEN:71I;VX@9F]R("1N<U!R969I>#HD='EP94YA;64@:7,@:6YV86QI
M9"XB+"`G=7)N.B<@+B!G971?8VQA<W,H)&]B:F5C="DI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M+R\@270G<R!E<G)O;F5O=7,*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*")4:&4@='EP92!D969I;FET:6]N(&9O<B`D
M;G-0<F5F:7@Z)'1Y<&5.86UE(&ES(&EN=F%L:60N(BP@)W5R;CHG("X@9V5T
M7V-L87-S*"1O8FIE8W0I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@0W)E871E(&%N(&5M<'1Y(&5L96UE;G0@87)R87D@=VET:"!T
M:&4@=&%R9V5T(&YA;65S<&%C90H@("`@("`@("\O('!R969I>"P@=&\@;6%T
M8V@@=&AE(')E<W5L=',@;V8@5U-$3"!P87)S:6YG+@H*("`@("`@("`D=&AI
M<RT^=W-D;"T^96QE;65N='-;)'-C:%!R969I>%T@/2!A<G)A>2@I.PH*("`@
M("`@("`O+R!0;W!U;&%T92!T<F5E('=I=&@@;65S<V%G92!I;F9O<FUA=&EO
M;@H@("`@("`@("\O("HJ*B`\=W-D;#IM97-S86=E/B`J*BH*"B`@("`@("`@
M9F]R96%C:"`H)&]B:F5C="T^7U]D:7-P871C:%]M87`@87,@)&]P97)A=&EO
M;DYA;64@/3X@)&UE<W-A9V5S*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M
M97-S86=E<R!A<R`D;65S<V%G951Y<&4@/3X@)&UE<W-A9V5087)T<RD@>PH@
M("`@("`@("`@("`@("`@=6YS970H)'1H:7--97-S86=E*3L*"B`@("`@("`@
M("`@("`@("!S=VET8V@@*"1M97-S86=E5'EP92D@>PH@("`@("`@("`@("`@
M("`@8V%S92`G:6XG.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YM97-S86=E<ULD;W!E<F%T:6]N3F%M92`N("=297%U97-T)UT@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES365S<V%G92`])B`D=&AI
M<RT^=W-D;"T^;65S<V%G97-;)&]P97)A=&EO;DYA;64@+B`G4F5Q=65S="==
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)V]U="<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/FUE<W-A9V5S6R1O<&5R871I;VY.86UE("X@)U)E<W!O;G-E)UT@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES365S<V%G92`])B`D=&AI
M<RT^=W-D;"T^;65S<V%G97-;)&]P97)A=&EO;DYA;64@+B`G4F5S<&]N<V4G
M73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("=A;&EA<R<Z"B`@("`@("`@("`@("`@("`@("`@+R\@1&\@;F]T
M:&EN9PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@+R\@17)R;W(@8V]N
M9&ET:6]N"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES365S<V%G
M92DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D;65S<V%G95!A
M<G1S(&%S("1P87)T3F%M92`]/B`D<&%R=%1Y<&4I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&ES="`H)&YS4')E9FEX+"`D='EP94YA;64I(#T@)'1H
M:7,M/E]G9714>7!E3G,H)'!A<G14>7!E*3L*"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES365S<V%G95LD<&%R=$YA;65=(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)'!A<G1.86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("1T>7!E3F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE<W!A8V4G(#T^
M("1N<U!R969I>`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%!O<'5L871E('1R964@=VET
M:"!P;W)T5'EP92!I;F9O<FUA=&EO;@H@("`@("`@("\O(%A86"!#=7)R96YT
M(&EM<&QE;65N=&%T:6]N(&]N;'D@<W5P<&]R=',@;VYE('!O<G14>7!E('1H
M870*("`@("`@("`O+R!E;F-O;7!A<W-E<R!A;&P@;V8@=&AE(&]P97)A=&EO
M;G,@879A:6QA8FQE+@H@("`@("`@("\O("HJ*B`\=W-D;#IP;W)T5'EP93X@
M*BHJ"@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G=S9&PM/G!O<G14>7!E
M<ULD<V5R=FEC95]N86UE("X@)U!O<G0G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/G!O<G14>7!E<ULD<V5R=FEC95]N86UE("X@)U!O<G0G72`]
M(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES4&]R=%1Y<&4@/28@
M)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD<V5R=FEC95]N86UE("X@)U!O<G0G
M73L*"B`@("`@("`@9F]R96%C:"`H)&]B:F5C="T^7U]D:7-P871C:%]M87`@
M87,@)&]P97)A=&EO;DYA;64@/3X@)&UE<W-A9V5S*2!["B`@("`@("`@("`@
M("1T:&ES4&]R=%1Y<&5;)&]P97)A=&EO;DYA;65=(#T@87)R87DH)VYA;64G
M(#T^("1O<&5R871I;VY.86UE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1M
M97-S86=E<R!A<R`D;65S<V%G951Y<&4@/3X@)&UE<W-A9V5087)T<RD@>PH@
M("`@("`@("`@("`@("`@<W=I=&-H("@D;65S<V%G951Y<&4I('L*("`@("`@
M("`@("`@("`@(&-A<V4@)VEN)SH*("`@("`@("`@("`@("`@("`@("`D=&AI
M<U!O<G14>7!E6R1O<&5R871I;VY.86UE75LG:6YP=70G72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G;65S<V%G92<@/3X@)&]P97)A=&EO
M;DYA;64@+B`G4F5Q=65S="<L"B`@("`@("`@("`@("`@("`@("`@("`@("=N
M86UE<W!A8V4G(#T^("1T:&ES+3YT;G-0<F5F:7@I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V]U="<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7-0;W)T5'EP95LD;W!E<F%T:6]N3F%M
M95U;)V]U='!U="==(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("=M97-S86=E)R`]/B`D;W!E<F%T:6]N3F%M92`N("=297-P;VYS92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE<W!A8V4G(#T^("1T:&ES+3YT
M;G-0<F5F:7@I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@86QL('1H
M92!A8G-T<F%C="!74T1,(&1A=&$@86YD(&)U:6QD(&-O;F-R971E(&)I;F1I
M;F=S(&%N9`H@("`@("H@<V5R=FEC97,@*&1E<W1R=6-T:79E*2X*("`@("`J
M"B`@("`@*B!86%@@0W5R<F5N="!I;7!L96UE;G1A=&EO;B!D:7-C87)D<R`D
M<V5R=FEC95]D97-C+@H@("`@("H*("`@("`J($!P87)A;2`@)'-C:&5M84YA
M;65S<&%C92!.86UE<W!A8V4@9F]R('1Y<&5S(&5T8RX*("`@("`J($!P87)A
M;2`@)'-E<G9I8V5?;F%M92!.86UE(&]F('1H92!74T1,(#QS97)V:6-E/@H@
M("`@("H@0'!A<F%M("`D<V5R=FEC95]D97-C($]P=&EO;F%L(&1E<V-R:7!T
M:6]N(&]F('1H92!74T1,(#QS97)V:6-E/@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G96YE<F%T94)I;F1I;F=S06YD
M4V5R=FEC97,H)'-C:&5M84YA;65S<&%C92P@)'-E<G9I8V5?;F%M92P@)'-E
M<G9I8V5?9&5S8R`]("<G*0H@("`@>PH@("`@("`@("\O(%!O<'5L871E('1R
M964@=VET:"!B:6YD:6YG<R!I;F9O<FUA=&EO;@H@("`@("`@("\O(%A86"!#
M=7)R96YT(&EM<&QE;65N=&%T:6]N(&]N;'D@<W5P<&]R=',@;VYE(&)I;F1I
M;F<@=&AA=`H@("`@("`@("\O(&UA=&-H97,@=&AE('-I;F=L92!P;W)T5'EP
M92!A;F0@86QL(&]F(&ET<R!O<&5R871I;VYS+@H@("`@("`@("\O(%A86"!)
M<R!T:&ES('1H92!C;W)R96-T('5S92!O9B`D<V-H96UA3F%M97-P86-E(&AE
M<F4_"B`@("`@("`@+R\@*BHJ(#QW<V1L.F)I;F1I;F<^("HJ*@H*("`@("`@
M("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'-E<G9I8V5?;F%M92`N("=":6YD
M:6YG)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`D<V5R
M=FEC95]N86UE("X@)U!O<G0G+`H@("`@("`@("`@("`@("`@)VYA;65S<&%C
M92<@/3X@)'1H:7,M/G1N<U!R969I>"P*("`@("`@("`@("`@("`@("=S='EL
M92<@/3X@)W)P8R<L"B`@("`@("`@("`@("`@("`G=')A;G-P;W)T)R`]/B!3
M0TA%34%?4T]!4%](5%10+`H@("`@("`@("`@("`@("`@)V]P97)A=&EO;G,G
M(#T^(&%R<F%Y*"DI.PH@("`@("`@("1T:&ES0FEN9&EN9R`])B`D=&AI<RT^
M=W-D;"T^8FEN9&EN9W-;)'-E<G9I8V5?;F%M92`N("=":6YD:6YG)UT["@H@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'-E<G9I
M8V5?;F%M92`N("=0;W)T)UT@87,@)&]P97)A=&EO;DYA;64@/3X@)&]P97)A
M=&EO;D1A=&$I('L*("`@("`@("`@("`@)'1H:7-":6YD:6YG6R=O<&5R871I
M;VYS)UU;)&]P97)A=&EO;DYA;65=(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`G<V]A<$%C=&EO;B<@/3X@)'-C:&5M84YA;65S<&%C92`N("<C)R`N("1O
M<&5R871I;VY.86UE+`H@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`D=&AI
M<T)I;F1I;F=;)W-T>6QE)UTI.PH*("`@("`@("`@("`@9F]R96%C:"`H87)R
M87DH)VEN<'5T)RP@)V]U='!U="<I(&%S("1M97-S86=E5'EP92D*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D;W!E<F%T:6]N1&%T85LD;65S<V%G951Y
M<&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES0FEN9&EN9ULG;W!E
M<F%T:6]N<R==6R1O<&5R871I;VY.86UE75LD;65S<V%G951Y<&5=(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E)R`]/B`G96YC
M;V1E9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M97-P86-E
M)R`]/B`D<V-H96UA3F%M97-P86-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V5N8V]D:6YG4W1Y;&4G(#T^(%-/05!?4T-(14U!7T5.0T]$24Y'
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%!O
M<'5L871E('1R964@=VET:"!S97)V:6-E(&EN9F]R;6%T:6]N"B`@("`@("`@
M+R\@6%A8($-U<G)E;G0@:6UP;&5M96YT871I;VX@<W5P<&]R=',@;VYE('-E
M<G9I8V4@=VAI8V@@9W)O=7!S"B`@("`@("`@+R\@86QL(&]F('1H92!P;W)T
M<R!T;V=E=&AE<BP@;VYE('!O<G0@<&5R(&)I;F1I;F<*("`@("`@("`O+R!8
M6%@@5VAA="!A8F]U="!H='1P<S\*("`@("`@("`O+R`J*BH@/'=S9&PZ<V5R
M=FEC93X@*BHJ"@H@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD<V5R
M=FEC95]N86UE("X@)U-E<G9I8V4G72`](&%R<F%Y*"=P;W)T<R<@/3X@87)R
M87DH*2D["B`@("`@("`@)'1H:7-397)V:6-E(#TF("1T:&ES+3YW<V1L+3YS
M97)V:6-E<ULD<V5R=FEC95]N86UE("X@)U-E<G9I8V4G75LG<&]R=',G73L*
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G=S9&PM/F)I;F1I;F=S(&%S("1B
M:6YD:6YG3F%M92`]/B`D8FEN9&EN9T1A=&$I('L*("`@("`@("`@("`@)'1H
M:7-397)V:6-E6R1B:6YD:6YG1&%T85LG='EP92==72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D8FEN9&EN9T1A=&%;)W1Y<&4G
M72P*("`@("`@("`@("`@("`@("`@("`G8FEN9&EN9R<@/3X@)&)I;F1I;F=.
M86UE+`H@("`@("`@("`@("`@("`@("`@("=N86UE<W!A8V4G(#T^("1T:&ES
M+3YT;G-0<F5F:7@L"B`@("`@("`@("`@("`@("`@("`@)V%D9')E<W,G(#T^
M(&%R<F%Y*"=L;V-A=&EO;B<@/3X*("`@("`@("`@("`@("`@("`@("`@("`@
M)VAT='`Z+R\G("X@)%]315)615);)U-%4E9%4E].04U%)UT@+B`D7U-%4E9%
M4ELG4$A07U-%3$8G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E
M="@D7U-%4E9%4ELG455%4EE?4U1224Y')UTI(#\@)S\G("X@)%]315)615);
M)U%515)97U-44DE.1R==(#H@)R<I*2P*("`@("`@("`@("`@("`@("`@("`G
M='EP92<@/3X@)W-O87`G*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E="!S
M97)V:6-E"B`@("`@("`@)'1H:7,M/G=S9&PM/G-E=%]S97)V:6-E*"1S97)V
M:6-E7VYA;64@+B`G4V5R=FEC92<I.PH@("`@("`@("1T:&ES+3YW<V1L+3YU
M<FD@/2`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULD=&AI<RT^=&YS4')E9FEX
M73L*"B`@("`@("`@+R\@0W)E871E(%=31$P@9&5F:6YI=&EO;@H@("`@("`@
M("\O("HJ*B`\=W-D;#ID969I;FET:6]N<SX@*BHJ"@H@("`@("`@("1T:&ES
M+3YW<V1L+3YD969I;FET:6]N(#T@87)R87DH"B`@("`@("`@("`@("`@("`G
M;F%M92<@/3X@)'-E<G9I8V5?;F%M92P*("`@("`@("`@("`@("`@("=T87)G
M971.86UE<W!A8V4G(#T^("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1T:&ES
M+3YT;G-0<F5F:7A=+`H@("`@("`@("`@("`@("`@)WAM;&YS)R`]/B!30TA%
M34%?5U-$3"D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YW<V1L+3YN86UE
M<W!A8V5S(&%S("1N<U!R969I>"`]/B`D;F%M97-P86-E*2!["B`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YD969I;FET:6]N6R=X;6QN<SHG("X@)&YS4')E
M9FEX72`]("1N86UE<W!A8V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@5&AI<R!F=6YC=&EO;B!I<R!A9&%P=&5D(&9R;VT@1&UI=')I(%8G
M<R!I;7!L96UE;G1A=&EO;B!O9@H@("`@("H@1$E30T\O5U-$3"!G96YE<F%T
M:6]N+B!)="!S97!A<F%T97,@;F%M97-P86-E(&9R;VT@='EP92!N86UE(&EN
M"B`@("`@*B!A(%]?='EP961E9B!K97D@86YD(&-R96%T97,@82!N97<@;F%M
M97-P86-E(&5N=')Y(&EN('1H92!74T1,"B`@("`@*B!S=')U8W1U<F4@:68@
M=&AE(&YA;65S<&%C92!H87,@;F]T(&)E96X@=7-E9"!B969O<F4N(%1H90H@
M("`@("H@;F%M97-P86-E('!R969I>"!A;F0@='EP92!N86UE(&%R92!R971U
M<FYE9"X@268@;F\@;F%M97-P86-E(&ES"B`@("`@*B!S<&5C:69I960L('AS
M9"!I<R!A<W-U;65D+@H@("`@("H*("`@("`J(%=E('=I;&P@;F]T(&YE960@
M=&AI<R!F=6YC=&EO;B!A;GEM;W)E(&]N8V4@7U]T>7!E9&5F(&ES"B`@("`@
M*B!E;&EM:6YA=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5'EP94YS
M*"1T>7!E*0H@("`@>PH@("`@("`@('!R96=?;6%T8VA?86QL*"(G7'LH+BHI
M7'TG<VTB+"`D='EP92P@)&TI.PH@("`@("`@(&EF("AI<W-E="@D;5LQ75LP
M72D@)B8@)&U;,5U;,%T@(3T@)R<I('L*("`@("`@("`@("`@:68@*"%A<G)A
M>5]K97E?97AI<W1S*"1M6S%=6S!=+"`D=&AI<RT^=W-D;"T^;G,I*2!["B`@
M("`@("`@("`@("`@("`D;G-?<')E9B`]("=N<R<@+B!C;W5N="@D=&AI<RT^
M=W-D;"T^;F%M97-P86-E<RD["B`@("`@("`@("`@("`@("`D=&AI<RT^=W-D
M;"T^;G-;)&U;,5U;,%U=(#T@)&YS7W!R968["B`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^;F%M97-P86-E<ULD;G-?<')E9ET@/2`D;5LQ75LP73L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D='EP96YS(#T@)'1H:7,M/G=S
M9&PM/FYS6R1M6S%=6S!=73L*("`@("`@("`@("`@)'1Y<&4@/2!E<F5G7W)E
M<&QA8V4H)&U;,%U;,%TL("<G+"`D='EP92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1Y<&5N<R`]("=X<V0G.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"1T>7!E;G,L("1T>7!E*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U-/05`O0VQI96YT+G!H<```````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#8Q,#<Q`#$P-3$U-#,Q,#4W`#`R,#`S-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T:&4@4T]!4"!C
M;&EE;G0N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V
M86EL86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E
M("`@(%-/05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA;&$@/&1I971R
M:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A=71H;W(@("`@
M(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@
M4$5!4B!A;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`875T:&]R("`@
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@("!-86EN=&5N
M86YC90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G
M4T]!4"]686QU92YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G
M.PIR97%U:7)E7V]N8V4@)U-/05`O5')A;G-P;W)T+G!H<"<["G)E<75I<F5?
M;VYC92`G4T]!4"]74T1,+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]&875L
M="YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O4&%R<V5R+G!H<"<["@HO+R!!
M<FYA=60Z('1H92!F;VQL;W=I;F<@8V]D92!W87,@=&%K96X@9G)O;2!$871A
M3V)J96-T(&%N9"!A9&%P=&5D('1O('-U:70*"B\O('1H:7,@=VEL;"!B92!H
M;W)R:69I8V%L;'D@<VQO=R$A(2$*+R\@3D]413H@3W9E<FQO860@4T5'1D%5
M3%13($].(%!(4#0@*R!:96YD($]P=&EM:7IE<@HO+R!T:&5S92!T=V\@87)E
M($)#+T9#(&AA;F1L97)S(&9O<B!C86QL(&EN(%!(4#0O-0H*:68@*"%C;&%S
M<U]E>&ES=',H)U-/05!?0VQI96YT7T]V97)L;V%D)RDI('L*("`@(&EF("AS
M=6)S='(H<&AP=F5R<VEO;B@I+"`P+"`Q*2`]/2`U*2!["B`@("`@("`@8VQA
M<W,@4T]!4%]#;&EE;G1?3W9E<FQO860@97AT96YD<R!33T%07T)A<V4@>PH@
M("`@("`@("`@("!F=6YC=&EO;B!?7V-A;&PH)&UE=&AO9"P@)&%R9W,I"B`@
M("`@("`@("`@('L*("`@("`@("`@("`@("`@("1R971U<FX@/2!N=6QL.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C86QL*"1M971H;V0L("1A<F=S+"`D
M<F5T=7)N*3L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I9B`H
M(69U;F-T:6]N7V5X:7-T<R@G8VQO;F4G*2D@>PH@("`@("`@("`@("!E=F%L
M*"=F=6YC=&EO;B!C;&]N92@D="D@>R!R971U<FX@)'0[('TG*3L*("`@("`@
M("!]"B`@("`@("`@979A;"@G"B`@("`@("`@("`@(&-L87-S(%-/05!?0VQI
M96YT7T]V97)L;V%D(&5X=&5N9',@4T]!4%]"87-E('L*("`@("`@("`@("`@
M("`@(&9U;F-T:6]N(%]?8V%L;"@D;65T:&]D+"`D87)G<RP@)B1R971U<FXI
M"B`@("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8V%L;"@D;65T:&]D+"`D87)G<RP@)')E='5R;BD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('TG*3L*("`@('T*?0H*+RHJ"B`J
M(%-/05`@0VQI96YT($-L87-S"B`J"B`J(%1H:7,@8VQA<W,@:7,@=&AE(&UA
M:6X@:6YT97)F86-E(&9O<B!M86MI;F<@<V]A<"!R97%U97-T<RX*("H*("H@
M8F%S:6,@=7-A9V4Z/&-O9&4^"B`J("`@)'-O87!C;&EE;G0@/2!N97<@4T]!
M4%]#;&EE;G0H('-T<FEN9R!P871H(%L@+"!B;V]L96%N('=S9&Q=("D["B`J
M("`@96-H;R`D<V]A<&-L:65N="T^8V%L;"@@<W1R:6YG(&UE=&AO9&YA;64@
M6R`L(&%R<F%Y('!A<F%M971E<G-=("D["B`J(#PO8V]D93X*("H*("H@3W)I
M9VEN86QL>2!B87-E9"!O;B!33T%0>#0@8GD@1&EE=')I8V@@07EA;&$*("H@
M:'1T<#HO+V1I971R:6-H+F=A;G@T+F-O;2]S;V%P>#0*("H*("H@0&%C8V5S
M<R`@('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@4VAA
M;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2
M(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@("!3=&EG($)A:VME;B`\<W-B0&9A
M<W0N;F\^($-O;G9E<G-I;VX@=&\@4$5!4@H@*B!`875T:&]R("`@1&EE=')I
M8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R
M"B`J+PIC;&%S<R!33T%07T-L:65N="!E>'1E;F1S(%-/05!?0VQI96YT7T]V
M97)L;V%D"GL*("`@("\J*@H@("`@("H@0V]M;75N:6-A=&EO;B!E;F1P;VEN
M="X*("`@("`J"B`@("`@*B!#=7)R96YT;'D@=&AE(&9O;&QO=VEN9R!T<F%N
M<W!O<G0@9F]R;6%T<R!A<F4@<W5P<&]R=&5D.@H@("`@("H@("T@2%144`H@
M("`@("H@("T@4TU44`H@("`@("H*("`@("`J($5X86UP;&4@96YD<&]I;G1S
M.@H@("`@("H@("!H='1P.B\O=W=W+F5X86UP;&4N8V]M+W-O87`O<V5R=F5R
M+G!H<`H@("`@("H@("!H='1P<SHO+W=W=RYE>&%M<&QE+F-O;2]S;V%P+W-E
M<G9E<BYP:'`*("`@("`J("`@;6%I;'1O.G-O87!`97AA;7!L92YC;VT*("`@
M("`J"B`@("`@*B!`<V5E("!33T%07T-L:65N="@I"B`@("`@*B!`=F%R("1?
M96YD<&]I;G0@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5N9'!O:6YT(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@4T]!4"!03U)4(&YA;64@=&AA="!I
M<R!U<V5D(&)Y('1H92!C;&EE;G0N"B`@("`@*@H@("`@("H@0'9A<B`D7W!O
M<G1.86UE('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P;W)T3F%M92`]("<G
M.PH*("`@("\J*@H@("`@("H@16YD<&]I;G0@='EP92!E+F<N("=W9'-L)RX*
M("`@("`J"B`@("`@*B!`=F%R("1?7V5N9'!O:6YT5'EP92!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?7V5N9'!O:6YT5'EP92`]("<G.PH*("`@("\J*@H@
M("`@("H@5&AE(')E8V5I=F5D('AM;"X*("`@("`J"B`@("`@*B!`=F%R("1X
M;6P@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D>&UL.PH*("`@("\J*@H@("`@
M("H@5&AE(&]U=&=O:6YG(&%N9"!I;F-O;6EN9R!D871A('-T<F5A;2!F;W(@
M9&5B=6=G:6YG+@H@("`@("H*("`@("`J($!V87(@)'=I<F4@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D=VER93L*("`@('9A<B`D7U]L87-T7W)E<75E<W0@
M/2!N=6QL.PH@("`@=F%R("1?7VQA<W1?<F5S<&]N<V4@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@3W!T:6]N<RX*("`@("`J"B`@("`@*B!`=F%R("1?7V]P
M=&EO;G,@87)R87D*("`@("`J+PH@("`@=F%R("1?7V]P=&EO;G,@/2!A<G)A
M>2@G=')A8V4G/3XP*3L*"B`@("`O*BH*("`@("`J(%1H92!C:&%R86-T97(@
M96YC;V1I;F<@=7-E9"!F;W(@6$U,('!A<G-E<BP@971C+@H@("`@("H*("`@
M("`J($!V87(@)%]E;F-O9&EN9R!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@87)R87D@;V8@4T]!4%](96%D97)S('1H870@=V4@87)E('-E
M;F1I;F<N"B`@("`@*@H@("`@("H@0'9A<B`D:&5A9&5R<T]U="!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&AE861E<G-/=70@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE(&AE861E<G,@=V4@<F5C:65V960@8F%C:R!I;B!T:&4@<F5S
M<&]N<V4N"B`@("`@*@H@("`@("H@0'9A<B`D:&5A9&5R<TEN(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D:&5A9&5R<TEN(#T@;G5L;#L*"B`@("`O*BH*("`@
M("`J($]P=&EO;G,@9F]R('1H92!(5%107U)E<75E<W0@8VQA<W,@*'-E92!(
M5%10+U)E<75E<W0N<&AP*2X*("`@("`J"B`@("`@*B!`=F%R("1?7W!R;WAY
M7W!A<F%M<R!A<G)A>0H@("`@("HO"B`@("!V87(@)%]?<')O>'E?<&%R86US
M(#T@87)R87DH*3L*"B`@("!V87(@)%]S;V%P7W1R86YS<&]R="`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5N
M9'!O:6YT("`@("!!;B!54DPN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=W-D
M;"`@("`@("`@5VAE=&AE<B!T:&4@96YD<&]I;G0@:7,@82!74T1,(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;W)T3F%M90H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P<F]X>5]P87)A;7,@($]P=&EO;G,@9F]R('1H92!(5%107U)E
M<75E<W0@8VQA<W,@*'-E90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($A45%`O4F5Q=65S="YP:'`I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%-/05!?0VQI96YT*"1E;F1P;VEN="P@)'=S9&P@/2!F86QS92P@)'!O<G1.
M86UE(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`D<')O>'E?
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?
M0F%S92@G0VQI96YT)RD["@H@("`@("`@("1T:&ES+3Y?96YD<&]I;G0@/2`D
M96YD<&]I;G0["B`@("`@("`@)'1H:7,M/E]P;W)T3F%M92`]("1P;W)T3F%M
M93L*("`@("`@("`D=&AI<RT^7U]P<F]X>5]P87)A;7,@/2`D<')O>'E?<&%R
M86US.PH*("`@("`@("`O+R!4:&ES(&AA8VL@<VAO=6QD('!E<FAA<',@8F4@
M<F5M;W9E9"!A<R!I="!M:6=H="!C875S92!U;F5X<&5C=&5D"B`@("`@("`@
M+R\@8F5H879I;W5R+@H@("`@("`@("1W<V1L(#T@)'=S9&P*("`@("`@("`@
M("`@/R`D=W-D;`H@("`@("`@("`@("`Z('-T<G1O;&]W97(H<W5B<W1R*"1E
M;F1P;VEN="P@+30I*2`]/2`G=W-D;"<["@H@("`@("`@("\O(&UA:V4@=F%L
M=65S"B`@("`@("`@:68@*"1W<V1L*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M7V5N9'!O:6YT5'EP92`]("=W<V1L)SL*("`@("`@("`@("`@+R\@:6YS=&%N
M=&EA=&4@=W-D;"!C;&%S<PH@("`@("`@("`@("`D=&AI<RT^7W=S9&P@/28@
M;F5W(%-/05!?5U-$3"@D=&AI<RT^7V5N9'!O:6YT+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U]P<F]X>5]P
M87)A;7,I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]W<V1L+3YF875L="D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI
M<RT^7W=S9&PM/F9A=6QT*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5S970H*0H@("`@>PH@("`@("`@("1T:&ES
M+3YX;6P@/2!N=6QL.PH@("`@("`@("1T:&ES+3YW:7)E(#T@;G5L;#L*("`@
M("`@("`D=&AI<RT^7U]L87-T7W)E<75E<W0@/2!N=6QL.PH@("`@("`@("1T
M:&ES+3Y?7VQA<W1?<F5S<&]N<V4@/2!N=6QL.PH@("`@("`@("1T:&ES+3YH
M96%D97)S26X@/2!N=6QL.PH@("`@("`@("1T:&ES+3YH96%D97)S3W5T(#T@
M;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&-H87)A8W1E
M<B!E;F-O9&EN9RX*("`@("`J"B`@("`@*B!,:6UI=&5D('1O("=55$8M."<L
M("=54U]!4T-)22<@86YD("=)4T\M.#@U.2TQ)RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@96YC
M;V1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!33T%07T9A=6QT
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971%;F-O9&EN9R@D
M96YC;V1I;F<I"B`@("!["B`@("`@("`@:68@*&EN7V%R<F%Y*"1E;F-O9&EN
M9RP@)'1H:7,M/E]E;F-O9&EN9W,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M96YC;V1I;F<@/2`D96YC;V1I;F<["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M)TEN=F%L:60@16YC;V1I;F<G*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@82!H96%D97(@=&\@=&AE(&5N=F5L;W!E+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0'!A<F%M(%-/05!?2&5A9&5R
M("1S;V%P7W9A;'5E("!!(%-/05!?2&5A9&5R(&]R(&%N(&%R<F%Y('=I=&@@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5L
M96UE;G1S("=N86UE)RP@)VYA;65S<&%C92<L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=M=7-T=6YD97)S=&%N9"<L(&%N9"`G
M86-T;W(G('1O('-E;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87,@82!H96%D97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$AE861E<B@F)'-O87!?=F%L=64I"B`@("!["B`@("`@("`@+R\@061D(&$@
M;F5W(&AE861E<B!T;R!T:&4@;65S<V%G92X*("`@("`@("!I9B`H:7-?82@D
M<V]A<%]V86QU92P@)U-/05!?2&5A9&5R)RDI('L*("`@("`@("`@("`@)'1H
M:7,M/FAE861E<G-/=71;72`])B`D<V]A<%]V86QU93L*("`@("`@("!](&5L
M<V5I9B`H:7-?87)R87DH)'-O87!?=F%L=64I*2!["B`@("`@("`@("`@("\O
M(&YA;64L('9A;'5E+"!N86UE<W!A8V4L(&UU<W1U;F1E<G-T86YD+"!A8W1O
M<@H@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<T]U=%M=(#TF(&YE=R!33T%0
M7TAE861E<B@D<V]A<%]V86QU95LP72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O
M87!?=F%L=65;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S;V%P7W9A;'5E6S)=+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]A
M<%]V86QU95LS72D[.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@<&%R86UE=&5R('!R;W9I
M9&5D('1O(&%D9$AE861E<B@I+B`@375S="!B92!A;B!A<G)A>2!O<B!A(%-/
M05!?2&5A9&5R+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-A;&QS(&$@;65T:&]D(&]N('1H92!33T%0(&5N9'!O:6YT+@H@("`@("H*
M("`@("`J(%1H92!N86UE<W!A8V4@<&%R86UE=&5R(&ES(&]V97)L;V%D960@
M=&\@86-C97!T(&%N(&%R<F%Y(&]F(&]P=&EO;G,*("`@("`J('1H870@8V%N
M(&-O;G1A:6X@9&%T82!N96-E<W-A<GD@9F]R('9A<FEO=7,@=')A;G-P;W)T
M<R!I9B!I="!I<R!U<V5D(&%S"B`@("`@*B!A;B!A<G)A>2P@:70@34%9(&-O
M;G1A:6X@82!N86UE<W!A8V4@=F%L=64@86YD(&$@<V]A<&%C=&EO;B!V86QU
M92X@($EF"B`@("`@*B!I="!I<R!O=F5R;&]A9&5D+"!T:&4@<V]A<&%C=&EO
M;B!P87)A;65T97(@:7,@:6=N;W)E9"!A;F0@35535"!B90H@("`@("H@<&QA
M8V5D(&EN('1H92!O<'1I;VYS(&%R<F%Y+B`@5&AI<R!I<R!D;VYE('1O('!R
M;W9I9&4@8F%C:W=A<F1S"B`@("`@*B!C;VUP871I8FEL:71Y('=I=&@@8W5R
M<F5N="!C;&EE;G1S+"!B=70@;6%Y(&)E(')E;6]V960@:6X@=&AE(&9U='5R
M92X*("`@("`J(%1H92!C=7)R96YT;'D@<W5P<&]R=&5D('9A;'5E<R!A<F4Z
M/'!R93X*("`@("`J("`@;F%M97-P86-E"B`@("`@*B`@('-O87!A8W1I;VX*
M("`@("`J("`@=&EM96]U="`H2%144"!S;V-K970@=&EM96]U="D*("`@("`J
M("`@=')A;G-F97(M96YC;V1I;F<@*%--5%`L($-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(&AE861E<BD*("`@("`J("`@9G)O;2`H4TU44"P@1G)O;3H@
M:&5A9&5R*0H@("`@("H@("!S=6)J96-T("A33510+"!3=6)J96-T.B!H96%D
M97(I"B`@("`@*B`@(&AE861E<G,@*%--5%`L(&AA<V@@;V8@97AT<F$@4TU4
M4"!H96%D97)S*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@
M("`@("`@("`@(%1H92!M971H;V0@=&\@8V%L;"X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("`@("`@("`@("`@5&AE(&UE=&AO9"!P87)A;65T97)S
M+@H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D;F%M97-P86-E("!.86UE
M<W!A8V4@;W(@:&%S:"!W:71H(&]P=&EO;G,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S;V%P06-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE(&UE=&AO9"!R97-U;'0@;W(@82!33T%07T9A=6QT(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F8V%L;"@D;65T:&]D+"`F)'!A<F%M<RP@
M)&YA;65S<&%C92`](&9A;'-E+"`D<V]A<$%C=&EO;B`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1T:&ES+3YH96%D97)S26X@/2!N=6QL.PH@("`@("`@("1T
M:&ES+3Y?7VQA<W1?<F5Q=65S="`](&YU;&P["B`@("`@("`@)'1H:7,M/E]?
M;&%S=%]R97-P;VYS92`](&YU;&P["B`@("`@("`@)'1H:7,M/G=I<F4@/2!N
M=6QL.PH@("`@("`@("1T:&ES+3YX;6P@/2!N=6QL.PH*("`@("`@("`D<V]A
M<%]D871A(#TF("1T:&ES+3Y?7V=E;F5R871E*"1M971H;V0L("1P87)A;7,L
M("1N86UE<W!A8V4L("1S;V%P06-T:6]N*3L*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D<V]A<%]D871A*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@D<V]A<%]D871A*3L*("`@("`@("!]"@H@
M("`@("`@("\O(%]?9V5N97)A=&4H*2!M87D@:&%V92!C:&%N9V5D('1H92!E
M;F1P;VEN="!I9B!T:&4@5U-$3"!H87,@;6]R90H@("`@("`@("\O('1H86X@
M;VYE('-E<G9I8V4L('-O('=E(&YE960@=&\@<V5E(&EF('=E(&YE960@=&\@
M9V5N97)A=&4@82!N97<*("`@("`@("`O+R!T<F%N<W!O<G0@=&\@:&]O:R!T
M;R!A(&1I9F9E<F5N="!54DDN("!3:6YC92!T:&4@=')A;G-P;W)T('!R;W1O
M8V]L"B`@("`@("`@+R\@8V%N(&%L<V\@8VAA;F=E+"!W92!N965D('1O(&=E
M="!A;B!E;G1I<F5L>2!N97<@;V)J96-T+B`@5&AI<R!C;W5L9`H@("`@("`@
M("\O('!R;V)A8FQY(&)E(&]P=&EM:7IE9"X*("`@("`@("!I9B`H(21T:&ES
M+3Y?<V]A<%]T<F%N<W!O<G0@?'P*("`@("`@("`@("`@)'1H:7,M/E]E;F1P
M;VEN="`A/2`D=&AI<RT^7W-O87!?=')A;G-P;W)T+3YU<FPI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S;V%P7W1R86YS<&]R="`])B!33T%07U1R86YS<&]R
M=#HZ9V5T5')A;G-P;W)T*"1T:&ES+3Y?96YD<&]I;G0I.PH@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7W-O87!?=')A;G-P;W)T*2D@
M>PH@("`@("`@("`@("`@("`@)&9A=6QT(#TF("1T:&ES+3Y?<V]A<%]T<F%N
M<W!O<G0["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O87!?=')A;G-P;W)T
M(#T@;G5L;#L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"1F875L="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^96YC;V1I;F<@/2`D=&AI
M<RT^7V5N8V]D:6YG.PH*("`@("`@("`O+R!396YD('1H92!M97-S86=E+@H@
M("`@("`@("1T<F%N<W!O<G1?;W!T:6]N<R`](&%R<F%Y7VUE<F=E7W)E8W5R
M<VEV92@D=&AI<RT^7U]P<F]X>5]P87)A;7,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P
M=&EO;G,I.PH@("`@("`@("1T:&ES+3YX;6P@/28@)'1H:7,M/E]S;V%P7W1R
M86YS<&]R="T^<V5N9"@D<V]A<%]D871A+"`D=')A;G-P;W)T7V]P=&EO;G,I
M.PH*("`@("`@("`O+R!3879E('1H92!W:7)E(&EN9F]R;6%T:6]N(&9O<B!D
M96)U9V=I;F<N"B`@("`@("`@:68@*"1T:&ES+3Y?7V]P=&EO;G-;)W1R86-E
M)UT@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?7VQA<W1?<F5Q=65S="`]
M)B`D=&AI<RT^7W-O87!?=')A;G-P;W)T+3YO=71G;VEN9U]P87EL;V%D.PH@
M("`@("`@("`@("`D=&AI<RT^7U]L87-T7W)E<W!O;G-E(#TF("1T:&ES+3Y?
M<V]A<%]T<F%N<W!O<G0M/FEN8V]M:6YG7W!A>6QO860["B`@("`@("`@("`@
M("1T:&ES+3YW:7)E(#TF("1T:&ES+3Y?7V=E=%]W:7)E*"D["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^7W-O87!?=')A;G-P;W)T+3YF875L="D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D
M=&AI<RT^>&UL*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?7V%T=&%C
M:&UE;G1S(#TF("1T:&ES+3Y?<V]A<%]T<F%N<W!O<G0M/F%T=&%C:&UE;G1S
M.PH@("`@("`@("1T:&ES+3Y?7W)E<W5L=%]E;F-O9&EN9R`]("1T:&ES+3Y?
M<V]A<%]T<F%N<W!O<G0M/G)E<W5L=%]E;F-O9&EN9SL*"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?7V]P=&EO;G-;)W)E<W5L="==*2`F)@H@("`@("`@
M("`@("`D=&AI<RT^7U]O<'1I;VYS6R=R97-U;'0G72`A/2`G<&%R<V4G*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^>&UL.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?7W!A<G-E*"1T:&ES+3YX;6PL("1T:&ES
M+3Y?7W)E<W5L=%]E;F-O9&EN9RP@)'1H:7,M/E]?871T86-H;65N=',I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A;B!O<'1I;VX@=&\@=7-E('=I
M=&@@=&AE('1R86YS<&]R="!L87EE<G,N"B`@("`@*@H@("`@("H@1F]R(&5X
M86UP;&4Z"B`@("`@*B`\8V]D93X*("`@("`J("1S;V%P8VQI96YT+3YS971/
M<'0H)V-U<FPG+"!#55),3U!47U9%4D)/4T4L(#$I"B`@("`@*B`\+V-O9&4^
M"B`@("`@*B!T;R!P87-S(&$@<W!E8VEF:6,@;W!T:6]N('1O(&-U<FP@:68@
M=7-I;F<@86X@4U-,(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C871E9V]R
M>2`@0V%T96=O<GD@=&\@=VAI8V@@=&AE(&]P=&EO;B!A<'!L:65S(&]R(&]P
M=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&YA;64N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@("`@06X@;W!T:6]N(&YA;64@
M:68@)&-A=&5G;W)Y(&ES(&$@8V%T96=O<GD@;F%M92P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!A;B!O<'1I;VX@=F%L=64@:68@)&-A=&5G
M;W)Y(&ES(&%N(&]P=&EO;B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=F%L=64@("`@($%N(&]P=&EO;B!V86QU92!I9B`D8V%T96=O<GD@:7,@82!C
M871E9V]R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&YA;64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P="@D8V%T96=O<GDL("1O<'1I
M;VXL("1V86QU92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1V86QU92DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7U]O
M<'1I;VYS6R1C871E9V]R>5TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7U]O<'1I;VYS6R1C871E9V]R>5T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)&-A=&5G;W)Y75LD;W!T
M:6]N72`]("1V86QU93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7U]O<'1I;VYS6R1C871E9V]R>5T@/2`D;W!T:6]N.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-A;&P@;65T:&]D('-U<'!O<G1I
M;F<@=&AE(&]V97)L;V%D(&5X=&5N<VEO;BX*("`@("`J"B`@("`@*B!)9B!T
M:&4@;W9E<FQO860@97AT96YS:6]N(&ES(&QO861E9"P@>6]U(&-A;B!C86QL
M('1H92!C;&EE;G0@8VQA<W,@=VET:`H@("`@("H@82!S;V%P(&UE=&AO9"!N
M86UE.@H@("`@("H@/&-O9&4^"B`@("`@*B`D<V]A<"`](&YE=R!33T%07T-L
M:65N="@N+BXN*3L*("`@("`J("1V86QU92`]("1S;V%P+3YG9713=&]C:U%U
M;W1E*"=-4T94)RD["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H
M;V0@("`@("`@(%1H92!M971H;V0@=&\@8V%L;"X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("`@("`@("`@5&AE(&UE=&AO9"!P87)A;65T97)S+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<F5T=7)N7W9A;'5E("!7:6QL(&=E="!T
M:&4@;65T:&]D)W,@<F5T=7)N('9A;'5E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%S<VEG;F5D+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@06QW87ES('1R=64N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]C86QL*"1M971H;V0L("1P87)A;7,L("8D<F5T=7)N7W9A;'5E*0H@("`@
M>PH@("`@("`@("\O($]V97)L;V%D:6YG(&QO=V5R8V%S97,@=&AE(&UE=&AO
M9"!N86UE+"!W92!N965D('1O(&QO;VL@:6YT;R!T:&4*("`@("`@("`O+R!W
M<V1L(&%N9"!T<GD@=&\@9FEN9"!T:&4@8V]R<F5C="!M971H;V0@;F%M92!T
M;R!G970@=&AE(&-O<G)E8W0*("`@("`@("`O+R!C87-E(&9O<B!T:&4@8V%L
M;"X*("`@("`@("!I9B`H)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?=W-D;"T^;6%T8VA-971H;V0H)&UE=&AO9"D["B`@("`@("`@?0H*
M("`@("`@("`D<F5T=7)N7W9A;'5E(#TF("1T:&ES+3YC86QL*"1M971H;V0L
M("1P87)A;7,I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F
M=6YC=&EO;B`F7U]G971L87-T<F5Q=65S="@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?7VQA<W1?<F5Q=65S=#L*("`@('T*"B`@("!F=6YC=&EO
M;B`F7U]G971L87-T<F5S<&]N<V4H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7U]L87-T7W)E<W!O;G-E.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?
M=7-E*"1U<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG=7-E
M)UT@/2`D=7-E.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?<W1Y;&4H)'-T>6QE
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@/2`D
M<W1Y;&4["B`@("!]"@H@("`@9G5N8W1I;VX@7U]T<F%C92@D;&5V96PI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG=')A8V4G72`]("1L979E
M;#L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]G96YE<F%T92@D;65T:&]D+"`F
M)'!A<F%M<RP@)&YA;65S<&%C92`](&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-O87!!8W1I;VX@/2!F86QS92D*("`@('L*("`@("`@("`D
M=&AI<RT^9F%U;'0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;
M)VEN<'5T)UT])W!A<G-E)SL*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=R
M97-U;'0G73TG<&%R<V4G.PH@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W!A
M<F%M971E<G,G72`](&9A;'-E.PH*("`@("`@("!I9B`H)'!A<F%M<R`F)B!G
M971T>7!E*"1P87)A;7,I("$]("=A<G)A>2<I('L*("`@("`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y*"1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&=E='1Y<&4H)&YA;65S<&%C92D@/3T@)V%R<F%Y)RD@>PH@("`@("`@("`@
M("!F;W)E86-H("@D;F%M97-P86-E(&%S("1O<'1N86UE(#T^("1O<'0I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;<W1R=&]L;W=E<B@D
M;W!T;F%M92E=(#T@)&]P=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]?;W!T:6]N<ULG;F%M97-P86-E)UTI*2!["B`@
M("`@("`@("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/E]?;W!T:6]N<ULG
M;F%M97-P86-E)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;F%M97-P86-E(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!792=L;"!P;&%C92`D<V]A<$%C
M=&EO;B!I;G1O(&]U<B!A<G)A>2!F;W(@=7-A9V4@:6X@=&AE"B`@("`@("`@
M("`@("\O('1R86YS<&]R="X*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N
M<ULG<V]A<&%C=&EO;B==(#T@)'-O87!!8W1I;VX["B`@("`@("`@("`@("1T
M:&ES+3Y?7V]P=&EO;G-;)VYA;65S<&%C92==(#T@)&YA;65S<&%C93L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7U]E;F1P;VEN=%1Y<&4@/3T@
M)W=S9&PG*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T4V-H96UA5F5R<VEO
M;B@D=&AI<RT^7W=S9&PM/GAS9"D["@H@("`@("`@("`@("`O+R!'970@<&]R
M="!N86UE+@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<&]R=$YA;64I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&]R=$YA;64@/2`D=&AI<RT^7W=S
M9&PM/F=E=%!O<G1.86UE*"1M971H;V0I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?<&]R=$YA;64I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@D=&AI<RT^7W!O<G1.86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@1V5T(&5N9'!O:6YT+@H@("`@("`@("`@("`D=&AI<RT^7V5N9'!O
M:6YT(#T@)'1H:7,M/E]W<V1L+3YG971%;F1P;VEN="@D=&AI<RT^7W!O<G1.
M86UE*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]E
M;F1P;VEN="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"1T:&ES+3Y?96YD<&]I;G0I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O+R!'970@;W!E<F%T:6]N(&1A=&$N"B`@("`@("`@
M("`@("1O<$1A=&$@/2`D=&AI<RT^7W=S9&PM/F=E=$]P97)A=&EO;D1A=&$H
M)'1H:7,M/E]P;W)T3F%M92P@)&UE=&AO9"D["@H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D;W!$871A*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&]P1&%T82D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&YA;65S<&%C92`]("1O<$1A=&%;)VYA;65S
M<&%C92==.PH@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==
M(#T@)&]P1&%T85LG<W1Y;&4G73L*("`@("`@("`@("`@)'1H:7,M/E]?;W!T
M:6]N<ULG=7-E)UT@/2`D;W!$871A6R=I;G!U="==6R=U<V4G73L*("`@("`@
M("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<V]A<&%C=&EO;B==(#T@)&]P1&%T
M85LG<V]A<$%C=&EO;B==.PH*("`@("`@("`@("`@+R\@4V5T(&EN<'5T('!A
M<F%M971E<G,N"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=I
M;G!U="==(#T]("=P87)S92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M7V]P=&EO;G-;)W!A<F%M971E<G,G72`]("1O<$1A=&%;)W!A<F%M971E<G,G
M73L*("`@("`@("`@("`@("`@("1N<&%R86US(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D;W!$871A6R=I;G!U="==6R=P87)T<R==
M*2`F)@H@("`@("`@("`@("`@("`@("`@(&-O=6YT*"1O<$1A=&%;)VEN<'5T
M)UU;)W!A<G1S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PH@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O<$1A=&%;)VEN<'5T)UU;
M)W!A<G1S)UT@87,@)&YA;64@/3X@)'!A<G0I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'AM;&YS(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@
M("1A='1R<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("\O
M($ES('1H92!N86UE(&$@8V]M<&QE>"!T>7!E/PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'!A<G1;)V5L96UE;G0G72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1X;6QN<R`]("1T:&ES+3Y?=W-D;"T^
M;F%M97-P86-E<ULD<&%R=%LG;F%M97-P86-E)UU=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!A<G0@/2`D=&AI<RT^7W=S9&PM/F5L96UE;G1S
M6R1P87)T6R=N86UE<W!A8V4G75U;)'!A<G1;)W1Y<&4G75T["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1P87)T6R=N86UE)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P87)A;7-;)&YA;65=*2!\?`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]W<V1L+3YG971$871A2&%N9&QE<B@D
M;F%M92P@)'!A<G1;)VYA;65S<&%C92==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YP87)A;7-;)&YA;65=(#TF("1P87)A;7-;)&YA;65=
M.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@5V4@;F]W(&9O<F-E(&%N(&%S<V]C:6%T
M:79E(&%R<F%Y(&9O<@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M<&%R86UE=&5R<R!I9B!U<VEN9R!74T1,+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E1H92!N
M86UE9"!P87)A;65T97(@)&YA;64@:7,@;F]T(&EN('1H92!C86QL('!A<F%M
M971E<G,N(BD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&=E='1Y<&4H)&YP87)A;7-;)&YA;65=*2`A
M/2`G;V)J96-T)R!\?`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES
M7V$H)&YP87)A;7-;)&YA;65=+"`G4T]!4%]686QU92<I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!4>7!E(&ES(&QI:V5L>2!A('%N86UE
M+"!S<&QI="!I="!A<&%R="P@86YD(&=E=`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@=&AE('1Y<&4@;F%M97-P86-E(&9R;VT@5U-$3"X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1Q;F%M92`])B!N97<@44YA;64H
M)'!A<G1;)W1Y<&4G72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)'%N86UE+3YN<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T>7!E7VYA;65S<&%C92`]("1T:&ES+3Y?=W-D;"T^;F%M97-P86-E
M<ULD<6YA;64M/FYS73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("AI<W-E="@D<&%R=%LG;F%M97-P86-E)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&5?;F%M97-P86-E(#T@)'1H
M:7,M/E]W<V1L+3YN86UE<W!A8V5S6R1P87)T6R=N86UE<W!A8V4G75T["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T>7!E7VYA;65S<&%C92`](&YU;&P[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<6YA;64M/FYA;65S<&%C92`]("1T>7!E7VYA;65S
M<&%C93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)'%N
M86UE+3YN86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!Q;F%M
M92`]("1N86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1X
M;6QN<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<6YA
M;64@/2`G>R<@+B`D>&UL;G,@+B`G?2<@+B`D;F%M93L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N<&%R86US6R1N86UE72`])B!N97<@4T]!4%]686QU92@D<'%N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1Q;F%M92T^9G%N*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YP87)A;7-;)&YA;65=+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A='1R<RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!74T1,(&9I>'5P<R!T;R!T:&4@4T]!4"!V
M86QU92X*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P
M87)A;7,@/28@)&YP87)A;7,["B`@("`@("`@("`@("`@("!U;G-E="@D;G!A
M<F%M<RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH4T]!4%]834Q?4T-(14U!
M7U9%4E-)3TXI.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5R:6%L:7IE('1H
M92!M97-S86=E+@H@("`@("`@("1T:&ES+3Y?<V5C=&EO;C4@/2`H:7-S970H
M)'1H:7,M/E]?;W!T:6]N<ULG=7-E)UTI("8F"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=U<V4G72`]/2`G;&ET97)A
M;"<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?7V]P=&EO;G-;)W-T
M>6QE)UTI('Q\"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE
M)UT@/3T@)W)P8R<I('L*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG
M<W1Y;&4G72`]("=R<&,G.PH@("`@("`@("`@("`D=&AI<RT^9&]C<&%R86US
M(#T@=')U93L*("`@("`@("`@("`@)&UQ;F%M92`])B!N97<@44YA;64H)&UE
M=&AO9"P@)&YA;65S<&%C92D["B`@("`@("`@("`@("1M971H;V1686QU92`]
M)B!N97<@4T]!4%]686QU92@D;7%N86UE+3YF<6XH*2P@)U-T<G5C="<L("1P
M87)A;7,I.PH@("`@("`@("`@("`D<V]A<%]M<V<@/28@)'1H:7,M/E]M86ME
M16YV96QO<&4H)&UE=&AO9%9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAE861E<G-/=70L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V5N8V]D:6YG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*"$D<&%R86US*2!["B`@("`@("`@
M("`@("`@("`D;7%N86UE(#TF(&YE=R!13F%M92@D;65T:&]D+"`D;F%M97-P
M86-E*3L*("`@("`@("`@("`@("`@("1M>6YU;&P@/2!N=6QL.PH@("`@("`@
M("`@("`@("`@)'!A<F%M<R`])B!N97<@4T]!4%]686QU92@D;7%N86UE+3YF
M<6XH*2P@)U-T<G5C="<L("1M>6YU;&PI.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]?;W!T:6]N<ULG:6YP=70G72`]/2`G<&%R<V4G*2!["B`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@
M("`@("`@("`@("`@("`D;G!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@)&ME>7,@/2!A<G)A>5]K97ES*"1P87)A;7,I.PH@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AG971T>7!E*"1P87)A;7-;)&M=*2`A/2`G
M;V)J96-T)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YP87)A
M;7-;72`])B!N97<@4T]!4%]686QU92@D:RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7-;)&M=*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M<&%R86US6UT@/28@)'!A<F%M<ULD:UT["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M<R`])B`D;G!A<F%M<SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=P87)A;65T97)S
M)UTI('L*("`@("`@("`@("`@("`@("`@("`D;7%N86UE(#TF(&YE=R!13F%M
M92@D;65T:&]D+"`D;F%M97-P86-E*3L*("`@("`@("`@("`@("`@("`@("`D
M<&%R86US(#TF(&YE=R!33T%07U9A;'5E*"1M<6YA;64M/F9Q;B@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U-T
M<G5C="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<V]A<%]M<V<@/28@)'1H:7,M/E]M86ME16YV
M96QO<&4H)'!A<F%M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S3W5T+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E
M;F-O9&EN9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G,I.PH@("`@("`@('T*("`@("`@
M("!U;G-E="@D=&AI<RT^:&5A9&5R<T]U="D["@H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'-O87!?;7-G*3L*("`@("`@("!]"@H@
M("`@("`@("\O($AA;F1L92!-24U%(&]R($1)344@96YC;V1I;F<N"B`@("`@
M("`@+R\@5$]$3SH@1$E-12!E;F-O9&EN9R!S:&]U;&0@;6]V92!T;R!T:&4@
M=')A;G-P;W)T+"!D;R!I="!H97)E(&9O<@H@("`@("`@("\O(&YO=R!A;F0@
M9F]R(&5A<V4@;V8@9V5T=&EN9R!I="!D;VYE+@H@("`@("`@(&EF("AC;W5N
M="@D=&AI<RT^7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@("`@:68@*"AI
M<W-E="@D=&AI<RT^7U]O<'1I;VYS6R=A='1A8VAM96YT<R==*2`F)@H@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)V%T=&%C:&UE;G1S)UT@
M/3T@)TUI;64G*2!\?`H@("`@("`@("`@("`@("`@:7-S970H)'1H:7,M/E]?
M;W!T:6]N<ULG36EM92==*2D@>PH@("`@("`@("`@("`@("`@)'-O87!?;7-G
M(#TF("1T:&ES+3Y?;6%K94UI;65-97-S86=E*"1S;V%P7VUS9RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V5N8V]D:6YG*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("\O(&1E9F%U;'0@:7,@9&EM90H@("`@("`@("`@("`@
M("`@)'-O87!?;7-G(#TF("1T:&ES+3Y?;6%K941)345-97-S86=E*"1S;V%P
M7VUS9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V5N8V]D:6YG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?7V]P=&EO;G-;)VAE861E<G,G75LG0V]N=&5N="U4>7!E
M)UT@/2`G87!P;&EC871I;VXO9&EM92<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'-O87!?
M;7-G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@26YS
M=&%N=&EA=&4@8VQI96YT+@H@("`@("`@(&EF("AI<U]A<G)A>2@D<V]A<%]M
M<V<I*2!["B`@("`@("`@("`@("1S;V%P7V1A=&$@/28@)'-O87!?;7-G6R=B
M;V1Y)UT["B`@("`@("`@("`@(&EF("AC;W5N="@D<V]A<%]M<V=;)VAE861E
M<G,G72DI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7U]O
M<'1I;VYS6R=H96%D97)S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]?;W!T:6]N<ULG:&5A9&5R<R==(#T@87)R87E?;65R9V4H)'1H:7,M
M/E]?;W!T:6]N<ULG:&5A9&5R<R==+"`D<V]A<%]M<V=;)VAE861E<G,G72D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?7V]P=&EO;G-;)VAE861E<G,G72`]("1S;V%P7VUS9ULG:&5A
M9&5R<R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'-O87!?9&%T82`])B`D<V]A<%]M
M<V<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-O87!?9&%T83L*("`@
M('T*"B`@("!F=6YC=&EO;B`F7U]P87)S92@F)')E<W!O;G-E+"`D96YC;V1I
M;F<L("8D871T86-H;65N=',I"B`@("!["B`@("`@("`@+R\@4&%R<V4@=&AE
M(')E<W!O;G-E+@H@("`@("`@("1R97-P;VYS92`])B!N97<@4T]!4%]087)S
M97(H)')E<W!O;G-E+"`D96YC;V1I;F<L("1A='1A8VAM96YT<RD["B`@("`@
M("`@:68@*"1R97-P;VYS92T^9F%U;'0I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E<W!O;G-E+3YF875L="D["B`@
M("`@("`@?0H*("`@("`@("`O+R!2971U<FX@87)R87D@;V8@<&%R86UE=&5R
M<RX*("`@("`@("`D<F5T=7)N(#TF("1R97-P;VYS92T^9V5T4F5S<&]N<V4H
M*3L*("`@("`@("`D:&5A9&5R<R`])B`D<F5S<&]N<V4M/F=E=$AE861E<G,H
M*3L*("`@("`@("!I9B`H)&AE861E<G,I('L*("`@("`@("`@("`@)'1H:7,M
M/FAE861E<G-);B`])B`D=&AI<RT^7U]D96-O9&5297-P;VYS92@D:&5A9&5R
M<RP@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M7V1E8V]D95)E<W!O;G-E*"1R971U<FXI.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9?7V1E8V]D95)E<W!O;G-E*"8D<F5S<&]N<V4L("1S:&EF="`]('1R=64I
M"B`@("!["B`@("`@("`@:68@*"$D<F5S<&]N<V4I('L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@
M=F%L:60@<F5S<&]N<V4N"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E
M<W!O;G-E*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O
M87!&875L="@D<F5S<&]N<V4I.PH@("`@("`@('T@96QS96EF("@A:7-?82@D
M<F5S<&]N<V4L("=S;V%P7W9A;'5E)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(D1I9&XG="!G970@4T]!4%]686QU
M92!O8FIE8W0@8F%C:R!F<F]M(&-L:65N="(I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@1&5C;V1E('1O(&YA=&EV92!P:'`@9&%T871Y<&4N"B`@("`@("`@
M)')E='5R;D%R<F%Y(#TF("1T:&ES+3Y?9&5C;V1E*"1R97-P;VYS92D["@H@
M("`@("`@("\O($9A=6QT/PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R
M971U<FY!<G)A>2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H)')E='5R;D%R<F%Y*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]O8FIE8W0H)')E='5R;D%R<F%Y*2`F)@H@("`@("`@("`@("!S
M=')C87-E8VUP*&=E=%]C;&%S<R@D<F5T=7)N07)R87DI+"`G<W1D0VQA<W,G
M*2`]/2`P*2!["B`@("`@("`@("`@("1R971U<FY!<G)A>2`](&=E=%]O8FIE
M8W1?=F%R<R@D<F5T=7)N07)R87DI.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?87)R87DH)')E='5R;D%R<F%Y*2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)')E='5R;D%R<F%Y6R=F875L=&-O9&4G72D@?'P*("`@("`@("`@("`@
M("`@(&ES<V5T*"1R971U<FY!<G)A>5LG4T]!4"U%3E8Z9F%U;'1C;V1E)UTI
M*2!["B`@("`@("`@("`@("`@("`D9F%U;'1C;V1E(#T@)&9A=6QT<W1R:6YG
M(#T@)&9A=6QT9&5T86EL(#T@)&9A=6QT86-T;W(@/2`G)SL*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1R971U<FY!<G)A>2!A<R`D:R`]/B`D=BD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1K+"`G9F%U;'1C;V1E
M)RDI("1F875L=&-O9&4@/2`D=CL*("`@("`@("`@("`@("`@("`@("!I9B`H
M<W1R:7-T<B@D:RP@)V9A=6QT<W1R:6YG)RDI("1F875L='-T<FEN9R`]("1V
M.PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1K+"`G9&5T86EL
M)RDI("1F875L=&1E=&%I;"`]("1V.PH@("`@("`@("`@("`@("`@("`@(&EF
M("AS=')I<W1R*"1K+"`G9F%U;'1A8W1O<B<I*2`D9F%U;'1A8W1O<B`]("1V
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&9A=6QT<W1R:6YG+"`D9F%U;'1D971A
M:6PL("1F875L=&%C=&]R+"`D9F%U;'1C;V1E*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`O+R!2971U<FX@87)R87D@;V8@<F5T=7)N('9A;'5E<RX*
M("`@("`@("`@("`@:68@*"1S:&EF="`F)B!C;W5N="@D<F5T=7)N07)R87DI
M(#T](#$I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>5]S:&EF="@D
M<F5T=7)N07)R87DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B`D<F5T=7)N07)R87D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T
M=7)N07)R87D["B`@("!]"@H@("`@9G5N8W1I;VX@7U]G971?=VER92@I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?7V]P=&EO;G-;)W1R86-E)UT@/B`P
M("8F"B`@("`@("`@("`@("@D=&AI<RT^7U]L87-T7W)E<75E<W0@?'P@)'1H
M:7,M/E]?;&%S=%]R97-P;VYS92DI('L*("`@("`@("`@("`@<F5T=7)N(")/
M551'3TE.1SI<;EQN(B`N"B`@("`@("`@("`@("`@("`D=&AI<RT^7U]L87-T
M7W)E<75E<W0@+@H@("`@("`@("`@("`@("`@(EQN7&Y)3D-/34E.1UQN7&XB
M("X*("`@("`@("`@("`@("`@('!R96=?<F5P;&%C92@B+SX\+R(L(CY<<EQN
M/"(L("1T:&ES+3Y?7VQA<W1?<F5S<&]N<V4I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-/05`O0F%S92YP:'``````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3(R,3,S`#$P-3$U-#,Q,#4W`#`Q
M-S0W,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&QO861S(&%L;"!R97%U:7)E9"!L
M:6)R87)I97,L(&1E9FEN97,@8V]N<W1A;G1S('5S960@86-R;W-S('1H90H@
M*B!33T%0('!A8VMA9V4L(&%N9"!D969I;F5S('1H92!B87-E(&-L87-S97,@
M=&AA="!M;W-T(&]T:&5R(&-L87-S97,@;V8@=&AI<PH@*B!P86-K86=E(&5X
M=&5N9"X*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H
M('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A
M:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@
M("`@4T]!4`H@*B!`875T:&]R("`@("!$:65T<FEC:"!!>6%L82`\9&EE=')I
M8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("H@0&%U=&AO<B`@("`@
M4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!0
M14%2(&%N9"!M;W)E"B`J($!A=71H;W(@("`@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/B`@($UA:6YT96YA;F-E"B`J($!A=71H;W(@("`@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^("`@("`@($UA:6YT96YA
M;F-E"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*+RHJ"B`J(%-/05!?3T)*
M14-47U-44E5#5"!M86ME<R!014%2.CI33T%0('5S92!O8FIE8W1S(&9O<B!3
M3T%0('-T<G5C='5R97,@<F%T:&5R"B`J('1H86X@87)R87ES+B`@5&AI<R!H
M87,@8F5E;B!D;VYE('1O('!R;W9I9&4@82!C;&]S97(@;6%T8V@@=&\@<&AP
M+7-O87`N("!)9@H@*B!T:&4@;VQD(&)E:&%V:6]U<B!I<R!N965D960L('-E
M="!T;R!F86QS92X@(%1H92!O;&0@8F5H879I;W5R(&ES"B`J(&1E<')E8V%T
M960N"B`J"B`J($!G;&]B86P@8F]O;"`D1TQ/0D%,4ULG4T]!4%]/0DI%0U1?
M4U1254-4)UT*("HO"B1'3$]"04Q36R=33T%07T]"2D5#5%]35%)50U0G72`]
M('1R=64["@HO*BH*("H@4T]!4%]205=?0T].5D525"!M86ME<R!014%2.CI3
M3T%0(&%T=&5M<'0@=&\@9&5T97)M:6YE('=H870@4T]!4"!T>7!E(&$@4$A0
M"B`J('-T<FEN9R!#3U5,1"!B92X@(%1H:7,@;6%Y(')E<W5L="!I;B!S;&EG
M:'1L>2!B971T97(@:6YT97)O<&5R86)I;&ET>2!W:&5N"B`J('EO=2!A<F4@
M;F]T('5S:6YG(%=31$PL(&%N9"!A<F4@8F5I;F<@;&%Z>2!A;F0@;F]T('5S
M:6YG(%-/05!?5F%L=64@=&\*("H@9&5F:6YE('1Y<&5S(&9O<B!Y;W5R('9A
M;'5E<RX*("H*("H@0&=L;V)A;"!B;V]L("1'3$]"04Q36R=33T%07U)!5U]#
M3TY615)4)UT*("HO"B1'3$]"04Q36R=33T%07U)!5U]#3TY615)4)UT@/2!F
M86QS93L*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR97%U:7)E7V]N8V4@
M)U-/05`O5'EP92]D871E5&EM92YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O
M5'EP92]H97A":6YA<GDN<&AP)SL*"B\O(&]P=&EO;F%L(&9E871U<F5S"B1'
M3$]"04Q36R=33T%07V]P=&EO;G,G72`](&%R<F%Y*"D["@I`:6YC;'5D95]O
M;F-E("=-86EL+VUI;65087)T+G!H<"<["D!I;F-L=61E7V]N8V4@)TUA:6PO
M;6EM941E8V]D92YP:'`G.PII9B`H8VQA<W-?97AI<W1S*"=-86EL7VUI;650
M87)T)RDI('L*("`@("1'3$]"04Q36R=33T%07V]P=&EO;G,G75LG36EM92==
M(#T@,3L*("`@(&1E9FEN92@G34%)3%]-24U%4$%25%]#4DQ&)RP@(EQR7&XB
M*3L*?0H*0&EN8VQU9&5?;VYC92`G3F5T+T1)344N<&AP)SL*:68@*&-L87-S
M7V5X:7-T<R@G3F5T7T1)345?365S<V%G92<I*2!["B`@("`D1TQ/0D%,4ULG
M4T]!4%]O<'1I;VYS)UU;)T1)344G72`](#$["GT*"B\J*@H@*B!%;F%B;&4@
M9&5B=6=G:6YG(&EN9F]R;6%T:6]N/PH@*@H@*B!`9VQO8F%L(&)O;VP@)$=,
M3T)!3%-;)U-/05!?1$5"54<G70H@*B!`;F%M92`D4T]!4%]$14)51PH@*B\*
M)$=,3T)!3%-;)U-/05!?1$5"54<G72`](&9A;'-E.PH*:68@*"%F=6YC=&EO
M;E]E>&ES=',H)W9E<G-I;VY?8V]M<&%R92<I('Q\"B`@("!V97)S:6]N7V-O
M;7!A<F4H<&AP=F5R<VEO;B@I+"`G-"XQ)RP@)SPG*2D@>PH@("`@9&EE*")R
M97%U:7)E<R!02%`@-"XQ(&]R(&AI9VAE<EQN(BD["GT*:68@*'9E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C$G+"`G/CTG*2`F)@H@("`@=F5R
M<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,B<L("<\)RDI('L*("`@
M(&1E9FEN92@G1DQ/050G+"`G9&]U8FQE)RD["GT@96QS92!["B`@("!D969I
M;F4H)T9,3T%4)RP@)V9L;V%T)RD["GT*"FEF("@A9&5F:6YE9"@G24Y&)RDI
M('L*("`@(&1E9FEN92@G24Y&)RP@,2XX93,P-RD["GT*:68@*"%D969I;F5D
M*"=.04XG*2D@>PH@("`@9&5F:6YE*"=.04XG+"`P+C`I.PI]"@ID969I;F4H
M)U-/05!?3$E"4D%265]615)324].)RP@)S`N."XP4D,T)RD["F1E9FEN92@G
M4T]!4%],24)205)97TY!344G+"`@("`G4$5!4BU33T%0(#`N."XP4D,T+61E
M=F5L)RD["@HO+R!3970@<V-H96UA('9E<G-I;VXN"F1E9FEN92@G4T]!4%]8
M34Q?4T-(14U!7U9%4E-)3TXG+"`@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O
M6$U,4V-H96UA)RD["F1E9FEN92@G4T]!4%]834Q?4T-(14U!7TE.4U1!3D-%
M)RP@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E
M)RD["F1E9FEN92@G4T]!4%]834Q?4T-(14U!7S$Y.3DG+"`@("`@)VAT='`Z
M+R]W=W<N=S,N;W)G+S$Y.3DO6$U,4V-H96UA)RD["F1E9FEN92@G4T]!4%]3
M0TA%34$G+"`@("`@("`@("`@("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N
M;W)G+W=S9&PO<V]A<"\G*3L*9&5F:6YE*"=33T%07U-#2$5-05]%3D-/1$E.
M1R<L("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;F-O
M9&EN9R\G*3L*9&5F:6YE*"=33T%07T5.5D5,3U`G+"`@("`@("`@("`@("`G
M:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;G9E;&]P92\G*3L*
M"F1E9FEN92@G4T-(14U!7T1)4T-/)RP@("`@("`@("`@("`@)VAT='`Z+R]S
M8VAE;6%S+GAM;'-O87`N;W)G+V1I<V-O+R<I.PID969I;F4H)U-#2$5-05]$
M25-#3U]30TPG+"`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R
M9R]D:7-C;R]S8VPO)RD["@ID969I;F4H)U-#2$5-05]33T%0)RP@("`@("`@
M("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W<V1L+W-O87`O
M)RD["F1E9FEN92@G4T-(14U!7U-/05!?2%144"<L("`@("`@("`@)VAT='`Z
M+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O:'1T<"<I.PID969I;F4H)U-#
M2$5-05]74T1,7TA45%`G+"`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS
M;V%P+F]R9R]W<V1L+VAT='`O)RD["F1E9FEN92@G4T-(14U!7TU)344G+"`@
M("`@("`@("`@("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W=S9&PO
M;6EM92\G*3L*9&5F:6YE*"=30TA%34%?5U-$3"<L("`@("`@("`@("`@("`G
M:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O=W-D;"\G*3L*9&5F:6YE*"=3
M0TA%34%?1$E-12<L("`@("`@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL
M<V]A<"YO<F<O=W,O,C`P,B\P-"]D:6UE+W=S9&PO)RD["F1E9FEN92@G4T-(
M14U!7T-/3E1%3E0G+"`@("`@("`@("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O
M87`N;W)G+W=S+S(P,#(O,#0O8V]N=&5N="UT>7!E+R<I.PID969I;F4H)U-#
M2$5-05]2148G+"`@("`@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS
M;V%P+F]R9R]W<R\R,#`R+S`T+W)E9F5R96YC92\G*3L*"F1E9FEN92@G4T]!
M4%]$149!54Q47T5.0T]$24Y')RP@("=55$8M."<I.PH*:68@*"%F=6YC=&EO
M;E]E>&ES=',H)VES7V$G*2D@>PH@("`@9G5N8W1I;VX@:7-?82@F)&]B:F5C
M="P@)&-L87-S7VYA;64I"B`@("!["B`@("`@("`@:68@*'-T<G1O;&]W97(H
M9V5T7V-L87-S*"1O8FIE8W0I*2`]/2`D8VQA<W-?;F%M92D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&ES
M7W-U8F-L87-S7V]F*"1O8FIE8W0L("1C;&%S<U]N86UE*3L*("`@('T*?0H*
M:68@*"%C;&%S<U]E>&ES=',H)W-T9$-L87-S)RDI('L*("`@("\J(%!(4#4@
M9&]E<VXG="!D969I;F4@=&AI<S\@*B\*("`@(&-L87-S('-T9$-L87-S('L*
M("`@("`@("!F=6YC=&EO;B!?7V-O;G-T<G5C=&]R*"D@>WT*("`@('T*?0H*
M8VQA<W,@4T]!4%]"87-E7T]B:F5C="!E>'1E;F1S(%!%05(*>PH@("`@+RHJ
M"B`@("`@*B!3=&]R92!D96)U9V=I;F<@:6YF;W)M871I;VX@:6X@)%]D96)U
M9U]D871A/PH@("`@("H*("`@("`J($!S964@)&1E8G5G7V1A=&$L(%-/05!?
M0F%S90H@("`@("H@0'9A<B!B;V]L96%N("1?9&5B=6=?9FQA9PH@("`@("HO
M"B`@("!V87(@)%]D96)U9U]F;&%G(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!3=')I;F<@8V]N=&%I;FEN9R!D96)U9V=I;F<@:6YF;W)M871I;VX@:68@
M)%]D96)U9U]F;&%G(&ES('1R=64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S964@)&1E8G5G7V9L86<L(%-/05!?0F%S90H@("`@
M("H@0'9A<B!S=')I;F<@)%]D96)U9U]D871A"B`@("`@*B\*("`@('9A<B`D
M7V1E8G5G7V1A=&$@/2`G)SL*"B`@("`O*BH*("`@("`J(%-U<'!O<G1E9"!E
M;F-O9&EN9W,L(&QI;6ET960@8GD@6$U,(&5X=&5N<VEO;BX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y("1?96YC;V1I;F=S"B`@("`@*B\*("`@('9A<B`D
M7V5N8V]D:6YG<R`](&%R<F%Y*"=)4T\M.#@U.2TQ)RP@)U53+4%30TE))RP@
M)U541BTX)RD["@H@("`@+RHJ"B`@("`@*B!&875L="!C;V1E+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG("1?;7EF875L=&-O9&4*("`@("`J+PH@("`@
M=F%R("1?;7EF875L=&-O9&4@/2`G)SL*"B`@("`O*BH*("`@("`J(%)E8V5N
M="!014%27T5R<F]R(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R(%!%05)?
M17)R;W(@)&9A=6QT"B`@("`@*B\*("`@('9A<B`D9F%U;'0@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'-E
M92`D9&5B=6=?9&%T82P@7V1E8G5G*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F875L=&-O9&4@($5R<F]R(&-O9&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%-/05!?0F%S95]/8FIE8W0H)&9A=6QT8V]D92`]("=#;&EE;G0G
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;7EF875L=&-O9&4@/2`D9F%U;'1C
M;V1E.PH@("`@("`@("1T:&ES+3Y?9&5B=6=?9FQA9R`]("1'3$]"04Q36R=3
M3T%07T1%0E5')UT["B`@("`@("`@<&%R96YT.CI014%2*"=33T%07T9A=6QT
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!286ES97,@82!33T%0(&5R<F]R
M+@H@("`@("H*("`@("`J(%!L96%S92!R969E<B!T;R!T:&4@4T]!4"!D969I
M;FET:6]N(&9O<B!A;B!I;7!R97-S:6]N(&]F('=H870@82!C97)T86EN"B`@
M("`@*B!P87)A;65T97(@<W1A;F1S(&9O<BX*("`@("`J"B`@("`@*B!5<V4@
M)&1E8G5G7V9L86<@=&\@<W1O<F4@97)R;W)S('1O('1H92!M96UB97(@=F%R
M:6%B;&4@)&1E8G5G7V1A=&$*("`@("`J"B`@("`@*B!`<V5E("1D96)U9U]F
M;&%G+"`D9&5B=6=?9&%T82P@4T]!4%]&875L=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F=\;V)J96-T("1S='(@($5R<F]R(&UE<W-A9V4@;W(@;V)J
M96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5T86EL("`@("`@1&5T86EL
M960@97)R;W(@;65S<V%G92X*("`@("`J($!P87)A;2!S=')I;F<@)&%C=&]R
M55))"B`@("`@*B!`<&%R86T@;6EX960@)&-O9&4*("`@("`J($!P87)A;2!M
M:7AE9"`D;6]D90H@("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<VMI<&US9PH@("`@("HO"B`@("!F=6YC=&EO
M;B`F7W)A:7-E4V]A<$9A=6QT*"1S='(L("1D971A:6P@/2`G)RP@)&%C=&]R
M55))(#T@)R<L("1C;V1E(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU;&PL("1S:VEP
M;7-G(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@4&%S<R!T:')O=6=H('!R
M979I;W5S(&9A=6QT<RX*("`@("`@("`D:7-?:6YS=&%N8V4@/2!I<W-E="@D
M=&AI<RD["B`@("`@("`@:68@*&ES7V]B:F5C="@D<W1R*2D@>PH@("`@("`@
M("`@("`D9F%U;'0@/28@)'-T<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H(21C;V1E*2!["B`@("`@("`@("`@("`@("`D8V]D92`]("1I
M<U]I;G-T86YC92`_("1T:&ES+3Y?;7EF875L=&-O9&4@.B`G0VQI96YT)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D9F%U;'0@/28@;F5W(%-/05!?
M1F%U;'0H)'-T<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;V1E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%C=&]R55))+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E=&%I;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M;V1E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&]P=&EO;G,I.PH@("`@("`@('T*("`@("`@("!I9B`H)&ES7VEN
M<W1A;F-E*2!["B`@("`@("`@("`@("1T:&ES+3YF875L="`])B`D9F%U;'0[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9A=6QT.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]?:7-F875L="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YF875L="`A/2!N=6QL.PH@("`@?0H*("`@(&9U;F-T:6]N("9?7V=E
M=&9A=6QT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F9A=6QT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('-T<FEN9R!T;R!T:&4@9&5B
M=6<@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@
M($1E8G5G9VEN9R!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5B
M=6<H)'-T<FEN9RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]D96)U9U]F
M;&%G*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&5B=6=?9&%T82`N/2!G971?
M8VQA<W,H)'1H:7,I("X@)SH@)R`N"B`@("`@("`@("`@("`@("!S=')?<F5P
M;&%C92@G/B<L("(^7')<;B(L("1S=')I;F<I("X@(EQN(CL*("`@("`@("!]
M"B`@("!]"@I]"@HO*BH*("H@0V]M;6]N(&)A<V4@8VQA<W,@;V8@86QL(%-/
M05`@8VQA<W-E<RX*("H*("H@0&%C8V5S<R`@('!U8FQI8PH@*B!`<&%C:V%G
M92`@4T]!4`H@*B!`875T:&]R("`@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP
M+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J+PIC;&%S
M<R!33T%07T)A<V4@97AT96YD<R!33T%07T)A<V5?3V)J96-T"GL*("`@('9A
M<B`D7UA-3%-C:&5M82`](&%R<F%Y*"=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q
M+UA-3%-C:&5M82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:'1T
M<#HO+W=W=RYW,RYO<F<O,3DY.2]834Q38VAE;6$G*3L*("`@('9A<B`D7UA-
M3%-C:&5M859E<G-I;VX@/2`G:'1T<#HO+W=W=RYW,RYO<F<O,C`P,2]834Q3
M8VAE;6$G.PH*("`@("\O(&QO860@='EP97,@:6YT;R!T>7!E;6%P(&%R<F%Y
M"B`@("!V87(@)%]T>7!E;6%P(#T@87)R87DH"B`@("`@("`@)VAT='`Z+R]W
M=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W-T<FEN9R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=B;V]L96%N
M)R`]/B`G8F]O;&5A;B<L"B`@("`@("`@("`@("=F;&]A="<@/3X@1DQ/050L
M"B`@("`@("`@("`@("=D;W5B;&4G(#T^($9,3T%4+`H@("`@("`@("`@("`G
M9&5C:6UA;"<@/3X@1DQ/050L"B`@("`@("`@("`@("=D=7)A=&EO;B<@/3X@
M)VEN=&5G97(G+`H@("`@("`@("`@("`G9&%T951I;64G(#T^("=S=')I;F<G
M+`H@("`@("`@("`@("`G=&EM92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@
M("=D871E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V=996%R36]N=&@G
M(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V=996%R)R`]/B`G:6YT96=E
M<B<L"B`@("`@("`@("`@("=G36]N=&A$87DG(#T^("=I;G1E9V5R)RP*("`@
M("`@("`@("`@)V=$87DG(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V=-
M;VYT:"<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G:&5X0FEN87)Y)R`]
M/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V)A<V4V-$)I;F%R>2<@/3X@)W-T
M<FEN9R<L"B`@("`@("`@("`@("\O(&1E<FEV960@9&%T871Y<&5S"B`@("`@
M("`@("`@("=N;W)M86QI>F5D4W1R:6YG)R`]/B`G<W1R:6YG)RP*("`@("`@
M("`@("`@)W1O:V5N)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)VQA;F=U
M86=E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)TY-5$]+14XG(#T^("=S
M=')I;F<G+`H@("`@("`@("`@("`G3DU43TM%3E,G(#T^("=S=')I;F<G+`H@
M("`@("`@("`@("`G3F%M92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=.
M0TYA;64G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G240G(#T^("=S=')I
M;F<G+`H@("`@("`@("`@("`G2412148G(#T^("=S=')I;F<G+`H@("`@("`@
M("`@("`G24121493)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)T5.5$E4
M62<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=%3E1)5$E%4R<@/3X@)W-T
M<FEN9R<L"B`@("`@("`@("`@("=I;G1E9V5R)R`]/B`G:6YT96=E<B<L"B`@
M("`@("`@("`@("=N;VY0;W-I=&EV94EN=&5G97(G(#T^("=I;G1E9V5R)RP*
M("`@("`@("`@("`@)VYE9V%T:79E26YT96=E<B<@/3X@)VEN=&5G97(G+`H@
M("`@("`@("`@("`G;&]N9R<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G
M:6YT)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=S:&]R="<@/3X@)VEN
M=&5G97(G+`H@("`@("`@("`@("`G8GET92<@/3X@)W-T<FEN9R<L"B`@("`@
M("`@("`@("=N;VY.96=A=&EV94EN=&5G97(G(#T^("=I;G1E9V5R)RP*("`@
M("`@("`@("`@)W5N<VEG;F5D3&]N9R<@/3X@)VEN=&5G97(G+`H@("`@("`@
M("`@("`G=6YS:6=N961);G0G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@
M)W5N<VEG;F5D4VAO<G0G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)W5N
M<VEG;F5D0GET92<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G<&]S:71I
M=F5);G1E9V5R)R`@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G86YY5'EP
M92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=A;GE54DDG(#T^("=S=')I
M;F<G+`H@("`@("`@("`@("`G44YA;64G(#T^("=S=')I;F<G"B`@("`@("`@
M*2P*("`@("`@("`G:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]834Q38VAE;6$G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:30G(#T^("=I;G1E9V5R)RP*("`@
M("`@("`@("`@)VEN="<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G8F]O
M;&5A;B<@/3X@)V)O;VQE86XG+`H@("`@("`@("`@("`G<W1R:6YG)R`]/B`G
M<W1R:6YG)RP*("`@("`@("`@("`@)V1O=6)L92<@/3X@1DQ/050L"B`@("`@
M("`@("`@("=F;&]A="<@/3X@1DQ/050L"B`@("`@("`@("`@("=D871E5&EM
M92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=T:6UE26YS=&%N="<@/3X@
M)W-T<FEN9R<L"B`@("`@("`@("`@("=B87-E-C1":6YA<GDG(#T^("=S=')I
M;F<G+`H@("`@("`@("`@("`G8F%S938T)R`]/B`G<W1R:6YG)RP*("`@("`@
M("`@("`@)W5R+71Y<&4G(#T^("=S=')I;F<G"B`@("`@("`@*2P*("`@("`@
M("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;F-O9&EN9R\G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G8F%S938T)R`]/B`G<W1R:6YG)RP*
M("`@("`@("`@("`@)V%R<F%Y)R`]/B`G87)R87DG+`H@("`@("`@("`@("`G
M07)R87DG(#T^("=A<G)A>2<L"B`@("`@("`@("`@("=3=')U8W0G(#T^("=A
M<G)A>2<I"B`@("`I.PH*("`@("\J*@H@("`@("H@1&5F875L="!C;&%S<R!N
M86UE('1O('5S92!F;W(@9&5C;V1E9"!R97-P;VYS92!O8FIE8W1S+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG("1?9&5F875L=$]B:F5C=$-L87-S;F%M
M90H@("`@("HO"B`@("!V87(@)%]D969A=6QT3V)J96-T0VQA<W-N86UE(#T@
M)W-T9$-L87-S)SL*"B`@("`O+R!,;V%D(&YA;65S<&%C92!54DES(&EN=&\@
M86X@87)R87D@;V8@55))(#T^('!R969I>"X*("`@('9A<B`D7VYA;65S<&%C
M97,["B`@("!V87(@)%]N86UE<W!A8V4["@H@("`@=F%R("1?>&UL16YT:71I
M97,@/2!A<G)A>2@G)B<@/3X@)R9A;7`[)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)SPG(#T^("<F;'0[)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)SXG(#T^("<F9W0[)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(B<B(#T^("<F87!O<SLG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B<@/3X@)R9Q=6]T.R<I.PH*("`@('9A<B`D7V1O
M8V]N=F5R<VEO;B`](&9A;'-E.PH*("`@('9A<B`D7U]A='1A8VAM96YT<R`]
M(&%R<F%Y*"D["@H@("`@=F%R("1?=W-D;"`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!4<G5E(&EF('=E('5S92!S96-T:6]N(#4@96YC;V1I;F<L(&]R(&9A
M;'-E(&EF('1H:7,@:7,@;&ET97)A;"X*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X@)%]S96-T:6]N-0H@("`@("HO"B`@("!V87(@)%]S96-T:6]N-2`]
M('1R=64["@H@("`@+R\@2&%N9&QE('1Y<&4@=&\@8VQA<W,@;6%P<&EN9RX*
M("`@('9A<B`D7V%U=&]?=')A;G-L871I;VX@/2!F86QS93L*("`@('9A<B`D
M7W1Y<&5?=')A;G-L871I;VX@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'-E92`D9&5B=6=?9&%T82P@
M7V1E8G5G*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F875L=&-O
M9&4@($5R<F]R(&-O9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?0F%S
M92@D9F%U;'1C;V1E(#T@)T-L:65N="<I"B`@("!["B`@("`@("`@<&%R96YT
M.CI33T%07T)A<V5?3V)J96-T*"1F875L=&-O9&4I.PH@("`@("`@("1T:&ES
M+3Y?<F5S971.86UE<W!A8V5S*"D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M<V5T3F%M97-P86-E<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]N86UE<W!A
M8V5S(#T@87)R87DH"B`@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS
M;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R<@/3X@)U-/05`M14Y6)RP*("`@("`@
M("`@("`@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA)R`]/B`G
M>'-D)RP*("`@("`@("`@("`@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,
M4V-H96UA+6EN<W1A;F-E)R`]/B`G>'-I)RP*("`@("`@("`@("`@)VAT='`Z
M+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O)R`]/B`G4T]!
M4"U%3D,G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('-C:&5M
M82!V97)S:6]N('5S960@:6X@=&AE(%-/05`@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S964@)%]834Q38VAE;6$*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8VAE;6%697)S:6]N("!4
M:&4@<V-H96UA('9E<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S9713
M8VAE;6%697)S:6]N*"1S8VAE;6%697)S:6]N*0H@("`@>PH@("`@("`@(&EF
M("@A:6Y?87)R87DH)'-C:&5M859E<G-I;VXL("1T:&ES+3Y?6$U,4V-H96UA
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@B=6YS=7!O<G1E9"!834Q38VAE;6$@)'-C:&5M859E<G-I;VXB*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]834Q38VAE;6%697)S:6]N(#T@)'-C
M:&5M859E<G-I;VX["B`@("`@("`@)'1M<$Y3(#T@87)R87E?9FQI<"@D=&AI
M<RT^7VYA;65S<&%C97,I.PH@("`@("`@("1T;7!.4ULG>'-D)UT@/2`D=&AI
M<RT^7UA-3%-C:&5M859E<G-I;VX["B`@("`@("`@)'1M<$Y36R=X<VDG72`]
M("1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO;B`N("<M:6YS=&%N8V4G.PH@("`@
M("`@("1T:&ES+3Y?;F%M97-P86-E<R`](&%R<F%Y7V9L:7`H)'1M<$Y3*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?9V5T3F%M97-P86-E4')E9FEX*"1N<RD*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]N86UE<W!A8V4@)B8@)&YS(#T]
M("1T:&ES+3Y?;F%M97-P86-E*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*
M("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F%M97-P86-E
M<ULD;G-=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]N86UE<W!A
M8V5S6R1N<UT["B`@("`@("`@?0H@("`@("`@("1P<F5F:7@@/2`G;G,G("X@
M8V]U;G0H)'1H:7,M/E]N86UE<W!A8V5S*3L*("`@("`@("`D=&AI<RT^7VYA
M;65S<&%C97-;)&YS72`]("1P<F5F:7@["B`@("`@("`@<F5T=7)N("1P<F5F
M:7@["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=$YA;65S<&%C949O<E!R969I
M>"@D<')E9FEX*0H@("`@>PH@("`@("`@("1F;&EP<&5D(#T@87)R87E?9FQI
M<"@D=&AI<RT^7VYA;65S<&%C97,I.PH@("`@("`@(&EF("AI<W-E="@D9FQI
M<'!E9%LD<')E9FEX72DI('L*("`@("`@("`@("`@<F5T=7)N("1F;&EP<&5D
M6R1P<F5F:7A=.PH@("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@
M('T*"B`@("!F=6YC=&EO;B!?:7-3;V%P5F%L=64H)B1V86QU92D*("`@('L*
M("`@("`@("!R971U<FX@:7-?82@D=F%L=64L("=33T%07U9A;'5E)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W-E<FEA;&EZ959A;'5E*"8D=F%L=64L("1N
M86UE(#T@)R<L("1T>7!E(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5L3F%M97-P86-E(#T@;G5L;"P@)'1Y<&5.86UE<W!A8V4@
M/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS
M(#T@87)R87DH*2P@)&%T=')I8G5T97,@/2!A<G)A>2@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A<G1Y<&4@/2`G)RD*("`@('L*("`@("`@
M("`D;F%M97-P86-E<R`](&%R<F%Y*"D["B`@("`@("`@)&%R<F%Y5'EP92`]
M("1A<G)A>5]D97!T:"`]("1X;6QO=71?=F%L=64@/2!N=6QL.PH@("`@("`@
M("1T>7!E4')E9FEX(#T@)&5L4')E9FEX(#T@)'AM;&]U=%]O9F9S970@/2`D
M>&UL;W5T7V%R<F%Y5'EP92`]("<G.PH@("`@("`@("1X;6QO=71?='EP92`]
M("1X;6QN<R`]("1P='EP92`]("1A<G)A>5]T>7!E7VYS(#T@)R<["@H@("`@
M("`@(&EF("@A)&YA;64@?'P@:7-?;G5M97)I8R@D;F%M92DI('L*("`@("`@
M("`@("`@)&YA;64@/2`G:71E;2<["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@(&QI<W0H)'!T>7!E+"`D87)R
M87E4>7!E+"`D87)R87E?='EP95]N<RP@)&%R<F%Y7V1E<'1H*0H@("`@("`@
M("`@("`@("`@/2`D=&AI<RT^7W=S9&PM/F=E=%-C:&5M851Y<&4H)'1Y<&4L
M("1N86UE+"`D='EP94YA;65S<&%C92D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(21A<G)A>51Y<&4I('L*("`@("`@("`@("`@)&%R<F%Y5'EP92`]("1A
M<G1Y<&4["B`@("`@("`@?0H@("`@("`@(&EF("@A)'!T>7!E*2!["B`@("`@
M("`@("`@("1P='EP92`]("1T:&ES+3Y?9V5T5'EP92@D=F%L=64I.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21T>7!E*2!["B`@("`@("`@("`@("1T>7!E
M(#T@)'!T>7!E.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T<F-A<V5C;7`H
M)'!T>7!E+"`G4W1R=6-T)RD@/3T@,"!\?`H@("`@("`@("`@("!S=')C87-E
M8VUP*"1T>7!E+"`G4W1R=6-T)RD@/3T@,"D@>PH@("`@("`@("`@("`O+R!3
M=')U8W0*("`@("`@("`@("`@)'9A<G,@/2!N=6QL.PH@("`@("`@("`@("!I
M9B`H:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@("`@("`@("`@("1V87)S
M(#T@9V5T7V]B:F5C=%]V87)S*"1V86QU92D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=F%R<R`]("8D=F%L=64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V87)S*2D@>PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=F%R<RD@87,@)&LI
M('L*("`@("`@("`@("`@("`@("`@("`O+R!(:61E('!R:79A=&4@=F%R<RX*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&M;,%T@/3T@)U\G*2!C;VYT:6YU
M93L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1V87)S6R1K
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)'9A<G-;
M)&M=+"`G4T]!4%]686QU92<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D>&UL;W5T7W9A;'5E("X]("1V87)S6R1K72T^<V5R:6%L:7IE*"1T
M:&ES*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%A86"!G970@=&AE(&UE;6)E<G,@
M86YD('-E<FEA;&EZ92!T:&5M(&EN<W1E860*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(&-O;G9E<G1I;F<@=&\@86X@87)R87D@:7,@;6]R92!O
M=F5R:&5A9"!T:&%N('=E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!S:&]U;&0@<F5A;&QY(&1O+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'AM;&]U=%]V86QU92`N/2`D=&AI<RT^7W-E<FEA;&EZ959A;'5E*&=E
M=%]O8FIE8W1?=F%R<R@D=F%R<ULD:UTI+"`D:RP@9F%L<V4L("1T:&ES+3Y?
M<V5C=&EO;C4@/R!N=6QL(#H@)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1X;6QO=71?=F%L=64@+CT@)'1H:7,M
M/E]S97)I86QI>F5686QU92@D=F%R<ULD:UTL("1K+"!F86QS92P@)'1H:7,M
M/E]S96-T:6]N-2`_(&YU;&P@.B`D96Q.86UE<W!A8V4I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS96EF("AS=')C87-E8VUP*"1P='EP92P@)T%R<F%Y)RD@
M/3T@,"!\?`H@("`@("`@("`@("`@("`@("!S=')C87-E8VUP*"1T>7!E+"`G
M07)R87DG*2`]/2`P*2!["B`@("`@("`@("`@("\O($%R<F%Y+@H@("`@("`@
M("`@("`D='EP94YA;65S<&%C92`](%-/05!?4T-(14U!7T5.0T]$24Y'.PH@
M("`@("`@("`@("`D;W)I9U]T>7!E(#T@)'1Y<&4["B`@("`@("`@("`@("1T
M>7!E(#T@)T%R<F%Y)SL*("`@("`@("`@("`@)&YU;71Y<&5S(#T@,#L*("`@
M("`@("`@("`@+R\@6%A8('1H:7,@=VEL;"!B92!S;&]W(&]N(&QA<F=E<B!A
M<G)A>7,N("!"87-I8V%L;'DL(&ET(&9L871T96YS"B`@("`@("`@("`@("\O
M(&%R<F%Y<R!T;R!A;&QO=R!U<R!T;R!S97)I86QI>F4@;75L=&DM9&EM96YS
M:6]N86P@87)R87ES+B`@5V4*("`@("`@("`@("`@+R\@;VYL>2!D;R!T:&ES
M(&EF(&%R<F%Y5'EP92!I<R!S970L('=H:6-H('=I;&P@='EP:6-A;&QY(&]N
M;'D*("`@("`@("`@("`@+R\@:&%P<&5N(&EF('=E(&%R92!U<VEN9R!74T1,
M"B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9FQA='1E;B==*2!\
M?`H@("`@("`@("`@("`@("`@*"1A<G)A>51Y<&4@)B8*("`@("`@("`@("`@
M("`@("`H<W1R8VAR*"1A<G)A>51Y<&4L("<L)RD@?'P@<W1R<W1R*"1A<G)A
M>51Y<&4L("==6R<I*2DI('L*("`@("`@("`@("`@("`@("1N=6UT>7!E<R`]
M("1T:&ES+3Y?;75L=&E!<G)A>51Y<&4H)'9A;'5E+"`D87)R87E4>7!E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D87)?<VEZ92P@)'AM;&]U=%]V86QU92D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1A<G)A>5]T>7!E(#T@)&%R<F%Y7W1Y<&5?<')E9FEX
M(#T@)R<["B`@("`@("`@("`@(&EF("@D;G5M='EP97,@(3T@,2D@>PH@("`@
M("`@("`@("`@("`@)&%R<F%Y5'EP95%.86UE(#TF(&YE=R!13F%M92@D87)R
M87E4>7!E*3L*("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D87)R87E4
M>7!E44YA;64M/FYA;64["B`@("`@("`@("`@("`@("`D87)R87E?='EP97,@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&%R<F%Y7W9A;"`](&YU;&P[
M"@H@("`@("`@("`@("`@("`@+R\@4V5R:6%L:7IE(&5A8V@@87)R87D@96QE
M;65N="X*("`@("`@("`@("`@("`@("1A<E]S:7IE(#T@8V]U;G0H)'9A;'5E
M*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D87)R87E?
M=F%L*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?:7-3;V%P
M5F%L=64H)&%R<F%Y7W9A;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&%R<F%Y7W1Y<&4@/2`D87)R87E?=F%L+3YT>7!E.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D87)R87E?='EP97-;)&%R<F%Y7W1Y<&5=(#T@,3L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5?;G,@/2`D87)R87E?
M=F%L+3YT>7!E7VYA;65S<&%C93L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'AM;&]U=%]V86QU92`N/2`D=&AI<RT^7W-E<FEA;&EZ959A;'5E*"1A<G)A
M>5]V86PL("1A<G)A>5]V86PM/FYA;64L("1A<G)A>5]T>7!E+"`D87)R87E?
M='EP95]N<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&4@/2`D=&AI<RT^7V=E=%1Y
M<&4H)&%R<F%Y7W9A;"D["B`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A
M>5]T>7!E<ULD87)R87E?='EP95T@/2`Q.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D>&UL;W5T7W9A;'5E("X]("1T:&ES+3Y?<V5R:6%L:7IE5F%L=64H
M)&%R<F%Y7W9A;"P@)VET96TG+"`D87)R87E?='EP92P@)'1H:7,M/E]S96-T
M:6]N-2`_(&YU;&P@.B`D96Q.86UE<W!A8V4I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D>&UL
M;W5T7V]F9G-E="`]("<@4T]!4"U%3D,Z;V9F<V5T/2);,%TB)SL*("`@("`@
M("`@("`@("`@(&EF("@A)&%R<F%Y5'EP92D@>PH@("`@("`@("`@("`@("`@
M("`@("1N=6UT>7!E<R`](&-O=6YT*"1A<G)A>5]T>7!E<RD["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1N=6UT>7!E<R`]/2`Q*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D87)R87E?='EP93L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@57-I;F<@
M86YY5'EP92!I<R!M;W)E(&EN=&5R;W!E<F%B;&4N"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1A<G)A>5]T>7!E(#T]("=3=')U8W0G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1A<G)A>5]T>7!E(#T@)R<["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1A<G)A>5]T>7!E(#T]("=!<G)A>2<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y5'EP92`]("=A;GE4>7!E
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5?<')E9FEX
M(#T@)WAS9"<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"$D87)R87E4>7!E*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D87)R87E4>7!E(#T@)&%R<F%Y7W1Y<&4[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"$D87)R87E4>7!E('Q\("1N=6UT>7!E<R`^(#$I('L*("`@("`@
M("`@("`@("`@("\O(%-H;W5L9"!R969E<F5N8V4@=VAA="!S8VAE;6$@=V4G
M<F4@=7-I;F<N"B`@("`@("`@("`@("`@("`D87)R87E4>7!E(#T@)WAS9#IA
M;GE4>7!E)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&EF("@D87)R87E?='EP95]N<RD@>PH@("`@("`@("`@("`@("`@("`@("1A
M<G)A>5]T>7!E7W!R969I>"`]("1T:&ES+3Y?9V5T3F%M97-P86-E4')E9FEX
M*"1A<G)A>5]T>7!E7VYS*3L*("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D=&AI<RT^7W1Y<&5M87!;)'1H:7,M/E]834Q38VAE;6%697)S:6]N
M75LD87)R87E4>7!E72DI('L*("`@("`@("`@("`@("`@("`@("`D87)R87E?
M='EP95]P<F5F:7@@/2`D=&AI<RT^7VYA;65S<&%C97-;)'1H:7,M/E]834Q3
M8VAE;6%697)S:6]N73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@D87)R87E?='EP95]P<F5F:7@I('L*("`@("`@("`@("`@("`@
M("`@("`D87)R87E4>7!E(#T@)&%R<F%Y7W1Y<&5?<')E9FEX("X@)SHG("X@
M)&%R<F%Y5'EP93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'AM;&]U=%]A<G)A>51Y<&4@/2`G(%-/05`M14Y#.F%R
M<F%Y5'EP93TB)R`N("1A<G)A>51Y<&4["B`@("`@("`@("`@(&EF("@D87)R
M87E?9&5P=&@@(3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&%R<F%Y7V1E<'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`@("`@)'AM;&]U=%]A<G)A>51Y<&4@+CT@)UM=)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D>&UL;W5T7V%R<F%Y
M5'EP92`N/2`B6R1A<E]S:7IE75PB(CL*("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/E]I<U-O87!686QU92@D=F%L=64I*2!["B`@("`@("`@("`@("1X;6QO
M=71?=F%L=64@/28@)'9A;'5E+3YS97)I86QI>F4H)'1H:7,I.PH@("`@("`@
M('T@96QS96EF("@D='EP92`]/2`G<W1R:6YG)RD@>PH@("`@("`@("`@("`D
M>&UL;W5T7W9A;'5E(#T@:'1M;'-P96-I86QC:&%R<R@D=F%L=64I.PH@("`@
M("`@('T@96QS96EF("@D='EP92`]/2`G<F%W<W1R:6YG)RD@>PH@("`@("`@
M("`@("`D>&UL;W5T7W9A;'5E(#TF("1V86QU93L*("`@("`@("!](&5L<V5I
M9B`H)'1Y<&4@/3T@)V)O;VQE86XG*2!["B`@("`@("`@("`@("1X;6QO=71?
M=F%L=64@/2`D=F%L=64@/R`G=')U92<@.B`G9F%L<V4G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1X;6QO=71?=F%L=64@/28@)'9A;'5E.PH@
M("`@("`@('T*"B`@("`@("`@+R\@061D(&YA;65S<&%C97,N"B`@("`@("`@
M:68@*"1E;$YA;65S<&%C92D@>PH@("`@("`@("`@("`D96Q0<F5F:7@@/2`D
M=&AI<RT^7V=E=$YA;65S<&%C95!R969I>"@D96Q.86UE<W!A8V4I.PH@("`@
M("`@("`@("!I9B`H)&5L4')E9FEX*2!["B`@("`@("`@("`@("`@("`D>&UL
M;W5T7VYA;64@/2`B)&5L4')E9FEX.B1N86UE(CL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1X;6QO=71?;F%M92`]("1N86UE.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'AM
M;&]U=%]N86UE(#T@)&YA;64["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1Y
M<&5.86UE<W!A8V4I('L*("`@("`@("`@("`@)'1Y<&50<F5F:7@@/2`D=&AI
M<RT^7V=E=$YA;65S<&%C95!R969I>"@D='EP94YA;65S<&%C92D["B`@("`@
M("`@("`@(&EF("@D='EP95!R969I>"D@>PH@("`@("`@("`@("`@("`@)'AM
M;&]U=%]T>7!E(#T@(B1T>7!E4')E9FEX.B1T>7!E(CL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1X;6QO=71?='EP92`]("1T>7!E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1T>7!E("8F"B`@
M("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?='EP96UA<%LD=&AI<RT^
M7UA-3%-C:&5M859E<G-I;VY=6R1T>7!E72DI('L*("`@("`@("`@("`@)'1Y
M<&50<F5F:7@@/2`D=&AI<RT^7VYA;65S<&%C97-;)'1H:7,M/E]834Q38VAE
M;6%697)S:6]N73L*("`@("`@("`@("`@:68@*"1T>7!E4')E9FEX*2!["B`@
M("`@("`@("`@("`@("`D>&UL;W5T7W1Y<&4@/2`B)'1Y<&50<F5F:7@Z)'1Y
M<&4B.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'AM
M;&]U=%]T>7!E(#T@)'1Y<&4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O($AA;F1L92!A9&1I=&EO;F%L(&%T=')I8G5T97,N"B`@("`@
M("`@)'AM;%]A='1R(#T@)R<["B`@("`@("`@:68@*&-O=6YT*"1A='1R:6)U
M=&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D
M:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@)&MQ;B`])B!N97<@44YA;64H
M)&LI.PH@("`@("`@("`@("`@("`@)'9Q;B`])B!N97<@44YA;64H)'8I.PH@
M("`@("`@("`@("`@("`@)'AM;%]A='1R("X]("<@)R`N("1K<6XM/F9Q;B@I
M("X@)STB)R`N("1V<6XM/F9Q;B@I("X@)R(G.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!3=&]R92!T:&4@871T86-H;65N="!F;W(@
M;6EM92!E;F-O9&EN9RX*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V%T
M=&%C:&UE;G0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]?871T86-H;65N
M='-;72`]("1O<'1I;VYS6R=A='1A8VAM96YT)UT["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1H:7,M/E]S96-T:6]N-2D@>PH@("`@("`@("`@("!I9B`H
M)'AM;&]U=%]T>7!E*2!["B`@("`@("`@("`@("`@("`D>&UL;W5T7W1Y<&4@
M/2`B('AS:3IT>7!E/5PB)'AM;&]U=%]T>7!E7"(B.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1X;6QO=71?=F%L=64I*2!["B`@
M("`@("`@("`@("`@("`D>&UL(#T@(EQR7&X\)'AM;&]U=%]N86UE)'AM;&]U
M=%]T>7!E)'AM;&YS)'AM;&]U=%]A<G)A>51Y<&4B("X*("`@("`@("`@("`@
M("`@("`@("`B)'AM;%]A='1R('AS:3IN:6P]7")T<G5E7"(O/B(["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D>&UL(#T@(EQR7&X\
M)'AM;&]U=%]N86UE)'AM;&]U=%]T>7!E)'AM;&YS)'AM;&]U=%]A<G)A>51Y
M<&4B("X*("`@("`@("`@("`@("`@("`@("`B)'AM;&]U=%]O9F9S970D>&UL
M7V%T='(^)'AM;&]U=%]V86QU93PO)'AM;&]U=%]N86UE/B(["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H:7-?;G5L
M;"@D>&UL;W5T7W9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)'AM;"`](")<
M<EQN/"1X;6QO=71?;F%M921X;6QN<R1X;6Q?871T<B\^(CL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1X;6P@/2`B7')<;CPD>&UL
M;W5T7VYA;64D>&UL;G,D>&UL7V%T='(^(B`N"B`@("`@("`@("`@("`@("`@
M("`@)'AM;&]U=%]V86QU92`N("(\+R1X;6QO=71?;F%M93XB.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'AM;#L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@4$A0('1Y<&4@=&\@82!33T%0
M('1Y<&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('9A;'5E('1O(&EN
M<W!E8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!V86QU
M92=S(%-/05`@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1Y<&4H
M)B1V86QU92D*("`@('L*("`@("`@("!G;&]B86P@)%-/05!?3T)*14-47U-4
M4E5#5"P@)%-/05!?4D%77T-/3E9%4E0["@H@("`@("`@("1T>7!E(#T@9V5T
M='EP92@D=F%L=64I.PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@
M("!C87-E("=O8FIE8W0G.@H@("`@("`@("`@("!I9B`H:7-?82@D=F%L=64L
M("=S;V%P7W9A;'5E)RDI('L*("`@("`@("`@("`@("`@("1T>7!E(#T@)'9A
M;'5E+3YT>7!E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1Y<&4@/2`G4W1R=6-T)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`G87)R87DG.@H@("`@("`@("`@("`O
M+R!(87-H97,@87)E(&%L=V%Y<R!H86YD;&5D(&%S('-T<G5C=',N"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7VES2&%S:"@D=F%L=64I*2!["B`@("`@("`@
M("`@("`@("`D='EP92`]("=3=')U8W0G.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&%R7W-I>F4@/2!C;W5N="@D=F%L=64I.PH@
M("`@("`@("`@("`@("`@<F5S970H)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("1K97DQ(#T@:V5Y*"1V86QU92D["B`@("`@("`@("`@("`@("!I9B`H)&%R
M7W-I>F4@/B`P("8F(&ES7V$H)&ME>3$L("=33T%07U9A;'5E)RDI('L*("`@
M("`@("`@("`@("`@("`@("`O+R!&25A-13H@9F]R(&YO;BUW<V1L('-T<G5C
M=',@=&AA="!A<F4@86QL('1H92!S86UE('1Y<&4*("`@("`@("`@("`@("`@
M("`@("`D:V5Y,B`](&ME>2@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D87)?<VEZ92`^(#$@)B8*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I<U-O87!686QU92@D:V5Y,2D@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I<U-O87!686QU92@D:V5Y,BD@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@)&ME>3$M/FYA;64@(3T@)&ME>3(M/FYA;64I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5&AI<R!I<R!A('-T<G5C
M="P@;F]T(&%N(&%R<F%Y+@H@("`@("`@("`@("`@("`@("`@("`@("`D='EP
M92`]("=3=')U8W0G.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R<F%Y)SL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R<F%Y)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G:6YT96=E<B<Z"B`@("`@("`@8V%S92`G;&]N9R<Z"B`@("`@
M("`@("`@("1T>7!E(#T@)VEN="<["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=B;V]L96%N)SH*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@)V1O=6)L92<Z"B`@("`@("`@("`@("\O(&1O=6)L92!I<R!D
M97!R96-A=&5D(&EN(%!(4"`T+C(@86YD(&QA=&5R+@H@("`@("`@("`@("`D
M='EP92`]("=F;&]A="<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=N=6QL)SH*("`@("`@("`@("`@)'1Y<&4@/2`G)SL*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-T<FEN9R<Z"B`@("`@("`@("`@
M(&EF("@D4T]!4%]205=?0T].5D525"D@>PH@("`@("`@("`@("`@("`@:68@
M*&ES7VYU;65R:6,H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AS=')S='(H)'9A;'5E+"`G+B<I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T>7!E(#T@)V9L;V%T)SL*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("=I;G0G.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@:68@*%-/05!?5'EP95]H97A":6YA<GDZ
M.FES7VAE>&)I;B@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T>7!E(#T@)VAE>$)I;F%R>2<["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?:7-"
M87-E-C0H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1Y<&4@/2`G8F%S938T0FEN87)Y)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D="`]
M)B!N97<@4T]!4%]4>7!E7V1A=&54:6UE*"1V86QU92D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&1T+3YT;U5N:7AT:6UE*"D@(3T@+3$I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("=D
M871E5&EM92<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]M=6QT:4%R<F%Y5'EP92@F)'9A;'5E+"`F)'1Y<&4L("8D<VEZ92P@
M)B1X;6PI"B`@("!["B`@("`@("`@)'-Z(#T@8V]U;G0H)'9A;'5E*3L*("`@
M("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`O+R!3
M965M<R!W92!H879E(&$@;75L=&D@9&EM96YS:6]N86P@87)R87DL(&9I9W5R
M92!I="!O=70@:68@=V4*("`@("`@("`@("`@+R\@9&\N"B`@("`@("`@("`@
M("1C(#T@8V]U;G0H)'9A;'5E*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;75L
M=&E!<G)A>51Y<&4H)'9A;'5E6R1I72P@)'1Y<&4L("1S:7IE+"`D>&UL*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1S:7IE*2!["B`@("`@
M("`@("`@("`@("`D<VEZ92`]("1S>BX@)RPG("X@)'-I>F4["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<VEZ92`]("1S>CL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D=F%L=64I*2!["B`@
M("`@("`@("`@("`@("`D='EP92`]("1V86QU92T^='EP93L*("`@("`@("`@
M("`@("`@("1X;6P@+CT@)'9A;'5E+3YS97)I86QI>F4H)'1H:7,I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D=&AI
M<RT^7V=E=%1Y<&4H)'9A;'5E*3L*("`@("`@("`@("`@("`@("1X;6P@+CT@
M)'1H:7,M/E]S97)I86QI>F5686QU92@D=F%L=64L("=I=&5M)RP@)'1Y<&4I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1S:7IE(#T@;G5L
M;#L*"B`@("`@("`@<F5T=7)N(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('=H971H97(@82!S=')I;F<@:7,@8F%S938T(&5N8V]D960@9&%T
M82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('-T
M<FEN9R!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE('-P96-I9FEE9"!V86QU92!S965M<R!T;R!B92!B87-E
M-C0@96YC;V1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7VES0F%S938T*"8D
M=F%L=64I"B`@("!["B`@("`@("`@)&P@/2!S=')L96XH)'9A;'5E*3L*("`@
M("`@("!I9B`H)&PI('L*("`@("`@("`@("`@<F5T=7)N("1V86QU95LD;"`M
M(#%=(#T]("<])R`F)@H@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+UM!
M+5IA+7H]7"]<*UTK+R<L("1V86QU92D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE
M=&AE<B!A('1Y<&4@:7,@82!B87-E-C0@='EP92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T>7!E("!!('1Y<&4@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('1Y<&4@;F%M92!I<R!A
M(&)A<V4V-"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:7-"87-E-C14
M>7!E*"1T>7!E*0H@("`@>PH@("`@("`@(')E='5R;B`D='EP92`]/2`G8F%S
M938T)R!\?"`D='EP92`]/2`G8F%S938T0FEN87)Y)SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!A;B!A<G)A>2!I<R!A(&AA<V@N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A("!!;B!A<G)A>2!T;R!C
M:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('-P96-I9FEE9"!A<G)A>2!I<R!A(&AA<V@N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]I<TAA<V@H)B1A*0H@("`@>PH@("`@("`@("\O($D@<F5A;&QY
M(&1I<VQI:V4@:&%V:6YG('1O(&QO;W`@=&AR;W5G:"!T:&ES(&EN(%!(4"!C
M;V1E+"!R96%L;'D*("`@("`@("`O+R!L87)G92!A<G)A>7,@=VEL;"!B92!S
M;&]W+B`@5V4@;F5E9"!A($,@9G5N8W1I;VX@=&\@9&\@=&AI<RX*("`@("`@
M("`D;F%M97,@/2!A<G)A>2@I.PH@("`@("`@("1I="`](#`["B`@("`@("`@
M9F]R96%C:"`H)&$@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@+R\@0VAE
M8VMI;F<@=&AE('1Y<&4@:7,@9F%S=&5R('1H86X@<F5G97AP+@H@("`@("`@
M("`@("`D="`](&=E='1Y<&4H)&LI.PH@("`@("`@("`@("!I9B`H)'0@(3T@
M)VEN=&5G97(G*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?:7-3;V%P5F%L=64H)'8I*2![
M"B`@("`@("`@("`@("`@("`D;F%M97-;)'8M/FYA;65=(#T@,3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`O+R!)9B!S;VUE;VYE(&AA<R!A(&QA<F=E
M(&AA<V@@=&AE>2!S:&]U;&0@<F5A;&QY(&)E(&1E9FEN:6YG('1H90H@("`@
M("`@("`@("`O+R!T>7!E+@H@("`@("`@("`@("!I9B`H)&ET*RL@/B`Q,"D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!C;W5N="@D;F%M97,I/C$["B`@
M("!]"@H@("`@9G5N8W1I;VX@)E]U;E]H=&UL96YT:71I97,H)'-T<FEN9RD*
M("`@('L*("`@("`@("`D=')A;G-?=&)L(#T@9V5T7VAT;6Q?=')A;G-L871I
M;VY?=&%B;&4H2%1-3%]%3E1)5$E%4RD["B`@("`@("`@)'1R86YS7W1B;"`]
M(&%R<F%Y7V9L:7`H)'1R86YS7W1B;"D["B`@("`@("`@<F5T=7)N('-T<G1R
M*"1S=')I;F<L("1T<F%N<U]T8FPI.PH@("`@?0H*("`@(&9U;F-T:6]N("9?
M9&5C;V1E*"8D<V]A<'9A;"D*("`@('L*("`@("`@("!G;&]B86P@)%-/05!?
M3T)*14-47U-44E5#5#L*"B`@("`@("`@:68@*"$D=&AI<RT^7VES4V]A<%9A
M;'5E*"1S;V%P=F%L*2D@>PH@("`@("`@("`@("!R971U<FX@)'-O87!V86P[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1S;V%P=F%L+3YV86QU92DI
M('L*("`@("`@("`@("`@:68@*"133T%07T]"2D5#5%]35%)50U0@)B8@)'-O
M87!V86PM/G1Y<&4@(3T@)T%R<F%Y)RD@>PH@("`@("`@("`@("`@("`@)&-L
M87-S;F%M92`]("1T:&ES+3Y?9&5F875L=$]B:F5C=$-L87-S;F%M93L*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1Y<&5?=')A;G-L871I
M;VY;)'-O87!V86PM/G1Q;BT^9G%N*"E=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("\O(%1H:7,@=VEL;"!F;W)C92!A;B!E<G)O<B!I;B!02%`@:68@=&AE
M(&-L87-S(&1O97,@;F]T"B`@("`@("`@("`@("`@("`@("`@+R\@97AI<W0N
M"B`@("`@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("1T:&ES+3Y?='EP
M95]T<F%N<VQA=&EO;ELD<V]A<'9A;"T^='%N+3YF<6XH*5T["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]T>7!E7W1R86YS;&%T
M:6]N6R1S;V%P=F%L+3YT>7!E72DI('L*("`@("`@("`@("`@("`@("`@("`O
M+R!4:&ES('=I;&P@9F]R8V4@86X@97)R;W(@:6X@4$A0(&EF('1H92!C;&%S
M<R!D;V5S(&YO=`H@("`@("`@("`@("`@("`@("`@("\O(&5X:7-T+@H@("`@
M("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D=&AI<RT^7W1Y<&5?=')A
M;G-L871I;VY;)'-O87!V86PM/G1Y<&5=.PH@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1T:&ES+3Y?875T;U]T<F%N<VQA=&EO;BD@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)'-O87!V86PM/G1Y<&4I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D<V]A<'9A
M;"T^='EP93L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M
M/E]W<V1L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@)'1H:7,M
M/E]W<V1L+3YG971#;VUP;&5X5'EP94YA;65&;W)%;&5M96YT*"1S;V%P=F%L
M+3YN86UE+"`D<V]A<'9A;"T^;F%M97-P86-E*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1T("8F(&-L87-S7V5X:7-T<R@D="DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D=#L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R971U<FX@/28@;F5W
M("1C;&%S<VYA;64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<F5T=7)N(#T@87)R87DH*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&-O=6YT97(@/2`Q.PH@("`@("`@("`@("`D:7-S=')U8W0@/2`A
M)%-/05!?3T)*14-47U-44E5#5"!\?"`A:7-?87)R87DH)')E='5R;BD["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1S;V%P=F%L+3YV86QU92!A<R`D:71E;2D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D<F5T=7)N*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W=S9&PI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@1V5T('1H:7,@8VAI;&0G<R!74T1,(&EN
M9F]R;6%T:6]N+@H@("`@("`@("`@("`@("`@("`@("`@("`O+R`O)'-O87!V
M86PM/FYS+R1S;V%P=F%L+3YT>7!E+R1I=&5M+3YN<R\D:71E;2T^;F%M90H@
M("`@("`@("`@("`@("`@("`@("`@("`D8VAI;&1?='EP92`]("1T:&ES+3Y?
M=W-D;"T^9V5T0V]M<&QE>%1Y<&5#:&EL9%1Y<&4H"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]A<'9A;"T^;F%M97-P86-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-O87!V86PM/FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:71E;2T^;F%M97-P86-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&ET96TM/FYA;64I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H)&-H:6QD7W1Y<&4I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I=&5M+3YT>7!E(#T@)&-H:6QD7W1Y<&4["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@:68@*"$D:7-S=')U8W0@?'P@)&ET96TM/G1Y
M<&4@/3T@)T%R<F%Y)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)')E='5R;BT^>R1I=&5M+3YN86UE?2D@)B8*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&ES7V]B:F5C="@D<F5T=7)N+3Y[)&ET96TM/FYA
M;65]*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^
M>R1I=&5M+3YN86UE?2`])B`D=&AI<RT^7V1E8V]D92@D:71E;2D["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<F5T=7)N+3Y[
M)&ET96TM/FYA;65]*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:7-?87)R87DH)')E='5R;BT^>R1I=&5M+3YN86UE?2DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/GLD:71E;2T^;F%M
M97U;72`])B`D=&AI<RT^7V1E8V]D92@D:71E;2D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D<F5T=7)N*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;EM=(#TF("1T:&ES+3Y?
M9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/GLD:71E
M;2T^;F%M97T@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*&ES<V5T*"1R971U<FXM/GLD:71E;2T^;F%M97TI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1I<W-T<G5C="`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H8V]U;G0H9V5T7V]B:F5C=%]V87)S*"1R971U<FXI
M*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9"`])B`D
M=&AI<RT^7V1E8V]D92@D:71E;2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5T=7)N(#T@87)R87DH)')E='5R;BT^>R1I=&5M+3YN86UE?2P@
M)&0I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&0@/28@)'1H:7,M/E]D96-O9&4H)&ET
M96TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^>R1I
M=&5M+3YN86UE?2`](&%R<F%Y*"1R971U<FXM/GLD:71E;2T^;F%M97TL("1D
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM
M/GLD:71E;2T^;F%M97T@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O+R!3970@
M=&AE(&%T=')I8G5T97,@87,@;65M8F5R<R!I;B!T:&4@8VQA<W,N"B`@("`@
M("`@("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)')E='5R;BP@)U]?
M<V5T7V%T=')I8G5T92<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1S;V%P=F%L+3YA='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N
M8U]A<G)A>2AA<G)A>2@F)')E='5R;BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?7W-E=%]A='1R
M:6)U=&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"1K97DL("1V86QU92DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'-O
M87!V86PM/F%R<F%Y5'EP92`F)B`D=&AI<RT^7VES4V]A<%9A;'5E*"1I=&5M
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]I<T)A
M<V4V-%1Y<&4H)&ET96TM/G1Y<&4I("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`A)'1H:7,M/E]I<T)A<V4V-%1Y<&4H)'-O87!V86PM/F%R<F%Y
M5'EP92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($1E8V]D
M92!T:&4@=F%L=64@:68@=V4G<F4@;&]S:6YG('1H92!B87-E-C0*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O('1Y<&4@:6YF;W)M871I;VXN"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E;2T^=F%L=64@/2!B87-E
M-C1?9&5C;V1E*"1I=&5M+3YV86QU92D["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&ET96TM/G1Y<&4@/2`D
M<V]A<'9A;"T^87)R87E4>7!E.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(21I<W-T<G5C="D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5T=7)N6UT@/28@)'1H:7,M/E]D96-O9&4H)&ET
M96TI.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<F5T
M=7)N6R1I=&5M+3YN86UE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&ES<W1R=6-T(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@("`@("1D
M(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E='5R;B`](&%R<F%Y*"1R971U<FY;)&ET96TM/FYA;65=+"`D
M9"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E='5R;ELD:71E;2T^;F%M95T@/28@)'1H:7,M/E]D
M96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("1R
M971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-O87!V86PM/G1Y<&4@
M/3T@)V)O;VQE86XG*2!["B`@("`@("`@("`@(&EF("@D<V]A<'9A;"T^=F%L
M=64@(3T@)S`G("8F"B`@("`@("`@("`@("`@("!S=')C87-E8VUP*"1S;V%P
M=F%L+3YV86QU92P@)V9A;'-E)RD@(3T@,"D@>PH@("`@("`@("`@("`@("`@
M)'-O87!V86PM/G9A;'5E(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1S;V%P=F%L+3YV86QU92`](&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1S;V%P=F%L+3YT>7!E("8F
M"B`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?='EP96UA<%M33T%0
M7UA-3%]30TA%34%?5D524TE/3EU;)'-O87!V86PM/G1Y<&5=*2D@>PH@("`@
M("`@("`@("`O+R!)9B!W92!C86XL('-E="!V87)I86)L92!T>7!E+@H@("`@
M("`@("`@("!S971T>7!E*"1S;V%P=F%L+3YV86QU92P*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W1Y<&5M87!;4T]!4%]834Q?4T-(14U!7U9%4E-)
M3TY=6R1S;V%P=F%L+3YT>7!E72D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'1H:7,M/E]I<T)A<V4V-%1Y<&4H)'-O87!V86PM/G1Y<&4I*2!["B`@("`@
M("`@("`@(')E='5R;B!B87-E-C1?9&5C;V1E*"1S;V%P=F%L+3YV86QU92D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1S;V%P=F%L
M+3YV86QU93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S('1H92!33T%0(&5N=F5L;W!E('=I=&@@=&AE(%-/05`@96YV96QO<"!D
M871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;0H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1E;F-O9&EN9PH@("`@("H@0'!A<F%M(&%R<F%Y
M("1O<'1I;VYS"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J
M+PH@("`@9G5N8W1I;VX@)E]M86ME16YV96QO<&4H)B1M971H;V0L("8D:&5A
M9&5R<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F-O9&EN9R`]
M(%-/05!?1$5&055,5%]%3D-/1$E.1RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("`D<VUS
M9R`]("1H96%D97)?>&UL(#T@)&YS7W-T<FEN9R`]("<G.PH*("`@("`@("!I
M9B`H)&AE861E<G,I('L*("`@("`@("`@("`@)&,@/2!C;W5N="@D:&5A9&5R
M<RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`D:&5A9&5R7WAM;"`N/2`D:&5A9&5R<ULD:5TM
M/G-E<FEA;&EZ92@D=&AI<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&AE861E<E]X;6P@/2`B/%-/05`M14Y6.DAE861E<CY<<EQN)&AE861E<E]X
M;6Q<<EQN/"]33T%0+45.5CI(96%D97(^7')<;B(["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=I;G!U="==*2!\?"`D;W!T:6]N
M<ULG:6YP=70G72`]/2`G<&%R<V4G*2!["B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D;65T:&]D*2D@>PH@("`@("`@("`@("`@("`@)&,@/2!C;W5N="@D
M;65T:&]D*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)'-M<V<@+CT@)&UE=&AO
M9%LD:5TM/G-E<FEA;&EZ92@D=&AI<RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<VUS9R`])B`D
M;65T:&]D+3YS97)I86QI>F4H)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'-M<V<@/28@)&UE=&AO9#L*("`@
M("`@("!]"B`@("`@("`@)&)O9'D@/2`B/%-/05`M14Y6.D)O9'D^7')<;B(@
M+B`D<VUS9R`N(")<<EQN/"]33T%0+45.5CI";V1Y/EQR7&XB.PH*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@87,@)&L@/3X@)'8I('L*
M("`@("`@("`@("`@)&YS7W-T<FEN9R`N/2`B('AM;&YS.B1V/5PB)&M<(EQR
M7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]N86UE<W!A8V4I
M('L*("`@("`@("`@("`@)&YS7W-T<FEN9R`N/2`B('AM;&YS/5PB>R1T:&ES
M+3Y?;F%M97-P86-E?5PB7')<;B(["B`@("`@("`@?0H*("`@("`@("`O*B!)
M9B`G=7-E)R`]/2`G;&ET97)A;"<L('=E(&1O(&YO="!P=70@:6X@=&AE(&5N
M8V]D:6YG4W1Y;&4N("!4:&ES(&ES"B`@("`@("`@("H@9&5N;W1E9"!B>2`D
M=&AI<RT^7W-E8W1I;VXU(&)E:6YG(&9A;'-E+B`@)W5S92<@8V%N(&)E(&1E
M9FEN960@870@80H@("`@("`@("`J(&UO<F4@9W)A;G5L87(@;&5V96P@=&AA
M;B!W92!A<F4@9&5A;&EN9R!W:71H(&AE<F4L('-O('1H:7,@9&]E<R!N;W0*
M("`@("`@("`@*B!W;W)K(&9O<B!A;&P@<V5R=FEC97,N("HO"B`@("`@("`@
M)'AM;"`]("(\/WAM;"!V97)S:6]N/5PB,2XP7"(@96YC;V1I;F<]7"(D96YC
M;V1I;F=<(C\^7')<;EQR7&XB+@H@("`@("`@("`@("`B/%-/05`M14Y6.D5N
M=F5L;W!E("1N<U]S=')I;F<B+@H@("`@("`@("`@("`H)'1H:7,M/E]S96-T
M:6]N-2`_("<@4T]!4"U%3E8Z96YC;V1I;F=3='EL93TB)R`N(%-/05!?4T-(
M14U!7T5.0T]$24Y'("X@)R(G(#H@)R<I+@H@("`@("`@("`@("`B/EQR7&XB
M+@H@("`@("`@("`@("`B)&AE861E<E]X;6PD8F]D>3PO4T]!4"U%3E8Z16YV
M96QO<&4^7')<;B(["@H@("`@("`@(')E='5R;B`D>&UL.PH@("`@?0H*("`@
M(&9U;F-T:6]N("9?;6%K94UI;65-97-S86=E*"8D>&UL+"`D96YC;V1I;F<@
M/2!33T%07T1%1D%53%1?14Y#3T1)3D<I"B`@("!["B`@("`@("`@9VQO8F%L
M("133T%07V]P=&EO;G,["@H@("`@("`@(&EF("@A:7-S970H)%-/05!?;W!T
M:6]N<ULG36EM92==*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R
M86ES95-O87!&875L="@G36EM92!I<R!N;W0@:6YS=&%L;&5D)RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!%;F-O9&4@86YY(&%T=&%C:&UE;G1S+@H@("`@
M("`@("\O(%-E92!H='1P.B\O=W=W+G<S+F]R9R]44B]33T%0+6%T=&%C:&UE
M;G1S"B`@("`@("`@+R\@3F]W('=E(&AA=F4@=&\@;6EM92!E;F-O9&4@=&AE
M(&UE<W-A9V4N"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=C;VYT96YT7W1Y
M<&4G(#T^("=M=6QT:7!A<G0O<F5L871E9#L@='EP93UT97AT+WAM;"<I.PH@
M("`@("`@("1M<V<@/28@;F5W($UA:6Q?;6EM95!A<G0H)R<L("1P87)A;7,I
M.PH*("`@("`@("`O+R!!9&0@=&AE('AM;"!P87)T+@H@("`@("`@("1P87)A
M;7-;)V-O;G1E;G1?='EP92==(#T@)W1E>'0O>&UL)SL*("`@("`@("`D<&%R
M86US6R=C:&%R<V5T)UT@/2`D96YC;V1I;F<["B`@("`@("`@)'!A<F%M<ULG
M96YC;V1I;F<G72`]("=B87-E-C0G.PH@("`@("`@("1M<V<M/F%D9%-U8E!A
M<G0H)'AM;"P@)'!A<F%M<RD["@H@("`@("`@("\O($%D9"!T:&4@871T86-H
M96UE;G1S"B`@("`@("`@)&,@/2!C;W5N="@D=&AI<RT^7U]A='1A8VAM96YT
M<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@
M("`@("`@("`@)&%T=&%C:&UE;G0@/28@)'1H:7,M/E]?871T86-H;65N='-;
M)&E=.PH@("`@("`@("`@("`D;7-G+3YA9&13=6)087)T*"1A='1A8VAM96YT
M6R=B;V1Y)UTL("1A='1A8VAM96YT*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;7-G+3YE;F-O9&4H*3L*("`@('T*"B`@("`O+R!43T1/.B!T:&ES
M(&YE961S('1O(&)E('5S960@9G)O;2!T:&4@5')A;G-P;W)T('-Y<W1E;2X*
M("`@(&9U;F-T:6]N("9?;6%K941)345-97-S86=E*"8D>&UL*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D4T]!4%]O<'1I;VYS.PH*("`@("`@("!I9B`H(6ES
M<V5T*"133T%07V]P=&EO;G-;)T1)344G72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)T1)344@:7,@;F]T(&EN<W1A
M;&QE9"<I.PH@("`@("`@('T*"B`@("`@("`@+R\@16YC;V1E(&%N>2!A='1A
M8VAM96YT<RX*("`@("`@("`O+R!3964@:'1T<#HO+W-E87)C:"YI971F+F]R
M9R]I;G1E<FYE="UD<F%F=',O9')A9G0M;FEE;'-E;BUD:6UE+7-O87`M,#`N
M='AT"B`@("`@("`@+R\@3F]W('=E(&AA=F4@=&\@1$E-12!E;F-O9&4@=&AE
M(&UE<W-A9V4*("`@("`@("`D9&EM92`])B!N97<@3F5T7T1)345?365S<V%G
M92@I.PH@("`@("`@("1M<V<@/28@)&1I;64M/F5N8V]D941A=&$H)'AM;"P@
M4T]!4%]%3E9%3$]0+"!N=6QL+"!.151?1$E-15]465!%7U5222D["@H@("`@
M("`@("\O($%D9"!T:&4@871T86-H;65N=',N"B`@("`@("`@)&,@/2!C;W5N
M="@D=&AI<RT^7U]A='1A8VAM96YT<RD["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@)&%T=&%C:&UE;G0@/28@
M)'1H:7,M/E]?871T86-H;65N='-;)&E=.PH@("`@("`@("`@("`D;7-G("X]
M("1D:6UE+3YE;F-O9&5$871A*"1A='1A8VAM96YT6R=B;V1Y)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1;
M)V-O;G1E;G1?='EP92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A='1A8VAM96YT6R=C:60G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!.151?1$E-15]465!%7TU%1$E!*3L*
M("`@("`@("!]"B`@("`@("`@)&US9R`N/2`D9&EM92T^96YD365S<V%G92@I
M.PH*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("!F=6YC=&EO;B!?
M9&5C;V1E36EM94UE<W-A9V4H)B1D871A+"`F)&AE861E<G,L("8D871T86-H
M;65N=',I"B`@("!["B`@("`@("`@9VQO8F%L("133T%07V]P=&EO;G,["@H@
M("`@("`@(&EF("@A:7-S970H)%-/05!?;W!T:6]N<ULG36EM92==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=-:6UE(%5N<W5P
M<&]R=&5D+"!I;G-T86QL(%!%05(Z.DUA:6PZ.DUI;64G+"`G)RP@)R<L("=3
M97)V97(G*3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)'!A<F%M<ULG:6YC;'5D95]B;V1I97,G72`]('1R=64["B`@("`@("`@
M)'!A<F%M<ULG9&5C;V1E7V)O9&EE<R==("`]('1R=64["B`@("`@("`@)'!A
M<F%M<ULG9&5C;V1E7VAE861E<G,G72`]('1R=64["@H@("`@("`@("\O($QA
M;64@=&AI;F<@=&\@:&%V92!T;R!D;R!F;W(@9&5C;V1I;F<N"B`@("`@("`@
M)&1E8V]D97(@/28@;F5W($UA:6Q?;6EM941E8V]D92@D9&%T82D["B`@("`@
M("`@)'-T<G5C='5R92`]("1D96-O9&5R+3YD96-O9&4H)'!A<F%M<RD["@H@
M("`@("`@(&EF("AI<W-E="@D<W1R=6-T=7)E+3YB;V1Y*2D@>PH@("`@("`@
M("`@("`D9&%T82`]("1S=')U8W1U<F4M/F)O9'D["B`@("`@("`@("`@("1H
M96%D97)S(#T@)'-T<G5C='5R92T^:&5A9&5R<SL*"B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!](&5L<V5I9B`H:7-S970H)'-T<G5C='5R92T^<&%R
M=',I*2!["B`@("`@("`@("`@("1D871A(#T@)'-T<G5C='5R92T^<&%R='-;
M,%TM/F)O9'D["B`@("`@("`@("`@("1H96%D97)S(#T@87)R87E?;65R9V4H
M)'-T<G5C='5R92T^:&5A9&5R<RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1R=6-T=7)E+3YP87)T<ULP72T^:&5A9&5R<RD["B`@
M("`@("`@("`@(&EF("AC;W5N="@D<W1R=6-T=7)E+3YP87)T<RD@/B`Q*2![
M"B`@("`@("`@("`@("`@("`D;6EM95]P87)T<R`](&%R<F%Y7W-P;&EC92@D
M<W1R=6-T=7)E+3YP87)T<RPQ*3L*("`@("`@("`@("`@("`@("\O(%!R97!A
M<F4@=&AE('!A<G1S(&9O<B!T:&4@4T]!4"!P87)S97(N"@H@("`@("`@("`@
M("`@("`@)&,@/2!C;W5N="@D;6EM95]P87)T<RD["B`@("`@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("1P(#TF("1M:6UE7W!A<G1S6R1I73L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'`M/FAE861E<G-;)V-O;G1E;G0M;&]C871I;VXG
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5$]$3SH@;6]D:69Y
M(&QO8V%T:6]N('!E<B!3=T$@;F]T92!S96-T:6]N(#,*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@:'1T<#HO+W=W=RYW,RYO<F<O5%(O4T]!4"UA='1A
M8VAM96YT<PH@("`@("`@("`@("`@("`@("`@("`@("`D871T86-H;65N='-;
M)'`M/FAE861E<G-;)V-O;G1E;G0M;&]C871I;VXG75T@/2`D<"T^8F]D>3L*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8VED(#T@)V-I9#HG("X@<W5B<W1R*"1P+3YH96%D97)S6R=C
M;VYT96YT+6ED)UTL(#$L("TR*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&%T=&%C:&UE;G1S6R1C:61=(#T@)'`M/F)O9'D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"=-:6UE('!A<G-I;F<@97)R;W(G+"`G)RP@)R<L("=3
M97)V97(G*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9&5C;V1E1$E-14UE<W-A
M9V4H)B1D871A+"`F)&AE861E<G,L("8D871T86-H;65N=',I"B`@("!["B`@
M("`@("`@9VQO8F%L("133T%07V]P=&EO;G,["@H@("`@("`@(&EF("@A:7-S
M970H)%-/05!?;W!T:6]N<ULG1$E-12==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%(%5N<W5P<&]R=&5D+"!I;G-T86QL
M(%!%05(Z.DYE=#HZ1$E-12<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O+R!4:&ES(%-(3U5,
M1"!B92!M;W9E9"!T;R!T:&4@=')A;G-P;W)T(&QA>65R+"!E+F<N(%!(4"!I
M='-E;&8@<VAO=6QD"B`@("`@("`@+R\@:&%N9&QE('!A<G-I;F<@1$E-12`[
M*0H@("`@("`@("1D:6UE(#TF(&YE=R!.971?1$E-15]-97-S86=E*"D["B`@
M("`@("`@)&5R<B`]("1D:6UE+3YD96-O9&5$871A*"1D871A*3L*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"=&86EL960@=&\@9&5C;V1E('1H92!$24U%
M(&UE<W-A9V4A)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"B`@("`@("`@:68@*'-T<F-A<V5C;7`H)&1I;64M
M/G!A<G1S6S!=6R=T>7!E)UTL(%-/05!?14Y614Q/4"D@(3T@,"D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%(')E8V]R9"`Q
M(&ES(&YO="!A(%-/05`@96YV96QO<"$G+"`G)RP@)R<L("=397)V97(G*3L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@
M/2`D9&EM92T^<&%R='-;,%U;)V1A=&$G73L*("`@("`@("`O+R!&86ME(&ET
M(&9O<B!N;W<N"B`@("`@("`@)&AE861E<G-;)V-O;G1E;G0M='EP92==(#T@
M)W1E>'0O>&UL)SL*("`@("`@("`D8R`](&-O=6YT*"1D:6UE+3YP87)T<RD[
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@("`@
M("`@("`@)'!A<G0@/28@)&1I;64M/G!A<G1S6R1I73L*("`@("`@("`@("`@
M+R\@5V4@;F5E9"!T;R!H86YD;&4@55)))W,@8F5T=&5R+@H@("`@("`@("`@
M("`D:60@/2!S=')N8VUP*"1P87)T6R=I9"==+"`G8VED.B<L(#0I"B`@("`@
M("`@("`@("`@("`_("=C:60Z)R`N("1P87)T6R=I9"=="B`@("`@("`@("`@
M("`@("`Z("1P87)T6R=I9"==.PH@("`@("`@("`@("`D871T86-H;65N='-;
M)&ED72`]("1P87)T6R=D871A)UT["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]?<V5T7W1Y<&5?=')A;G-L871I;VXH)'1Y<&4L("1C;&%S<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1Q(#TF(&YE=R!13F%M92@D='EP92D[
M"B`@("`@("`@:68@*"$D8VQA<W,I('L*("`@("`@("`@("`@)&-L87-S(#T@
M)'1Q+3YN86UE.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W1Y<&5?=')A
M;G-L871I;VY;)'1Y<&5=/21C;&%S<SL*("`@('T*"GT*"B\J*@H@*B!#;&%S
M<R!U<V5D('1O(&AA;F1L92!13D%-12!V86QU97,@:6X@6$U,+@H@*@H@*B!`
M86-C97-S("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H;W(@
M("!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O
M(%!%05(@86YD('5P9&%T97,*("HO"F-L87-S(%%.86UE"GL*("`@('9A<B`D
M;F%M92`]("<G.PH@("`@=F%R("1N<R`]("<G.PH@("`@=F%R("1N86UE<W!A
M8V4])R<["@H@("`@9G5N8W1I;VX@44YA;64H)&YA;64L("1N86UE<W!A8V4@
M/2`G)RD*("`@('L*("`@("`@("!I9B`H)&YA;64@)B8@)&YA;65;,%T@/3T@
M)WLG*2!["B`@("`@("`@("`@('!R96=?;6%T8V@H)R]<>R@N*C\I7'TH+BHI
M+R<L("1N86UE+"`D;2D["B`@("`@("`@("`@("1T:&ES+3YN86UE(#T@)&U;
M,ET["B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D;5LQ73L*("`@
M("`@("!](&5L<V5I9B`H<W5B<W1R7V-O=6YT*"1N86UE+"`G.B<I(#T](#$I
M('L*("`@("`@("`@("`@)',@/2!E>'!L;V1E*"<Z)RP@)&YA;64I.PH@("`@
M("`@("`@("`D<R`](&%R<F%Y7W)E=F5R<V4H)',I.PH@("`@("`@("`@("`D
M=&AI<RT^;F%M92`]("1S6S!=.PH@("`@("`@("`@("`D=&AI<RT^;G,@/2`D
M<ULQ73L*("`@("`@("`@("`@)'1H:7,M/FYA;65S<&%C92`]("1N86UE<W!A
M8V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FYA;64@
M/2`D;F%M93L*("`@("`@("`@("`@)'1H:7,M/FYA;65S<&%C92`]("1N86UE
M<W!A8V4["B`@("`@("`@?0H*("`@("`@("`O+R!!(&QI='1L92!M;W)E(&UA
M9VEC('1H86X@<VAO=6QD(&)E(&EN(&$@<6YA;64N"B`@("`@("`@)'`@/2!S
M=')P;W,H)'1H:7,M/FYA;64L("=;)RD["B`@("`@("`@:68@*"1P*2!["B`@
M("`@("`@("`@("\O(%1/1$\Z($YE960@=&\@<F4M97AA;6EN92!T:&ES(&QO
M9VEC(&QA=&5R+@H@("`@("`@("`@("`O+R!#:&]P(&]F9B!;72X*("`@("`@
M("`@("`@)'1H:7,M/F%R<F%Y4VEZ92`](&5X<&QO9&4H)RPG+"!S=6)S='(H
M)'1H:7,M/FYA;64L("1P("L@,2P@+21P("T@,BDI.PH@("`@("`@("`@("`D
M=&AI<RT^87)R87E);F9O(#T@<W5B<W1R*"1T:&ES+3YN86UE+"`D<"D["B`@
M("`@("`@("`@("1T:&ES+3YN86UE(#T@<W5B<W1R*"1T:&ES+3YN86UE+"`P
M+"`D<"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&9Q;B@I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YN86UE<W!A8V4I('L*("`@("`@("`@
M("`@<F5T=7)N("=[)R`N("1T:&ES+3YN86UE<W!A8V4@+B`G?2<@+B`D=&AI
M<RT^;F%M93L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/FYS*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;G,@+B`G.B<@+B`D=&AI<RT^;F%M93L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YN86UE.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U-/05`O1&ES8V\N<&AP````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#,V,30T`#$P-3$U-#,Q,#4W`#`Q-S8V-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T:&4@1$E30T\@
M<V5R=F5R+"!P<F]V:61I;F<@1$E33R!A;F0@5U-$3`H@*B!S97)V:6-E<RX*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T
M:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE
M(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@
M*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!
M4`H@*B!`875T:&]R("`@("!$;6ET<FD@5FEN;V=R861O=B`\9&EM:71R:4!V
M:6YO9W)A9&]V+F1E/@H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@("`@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR
M97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PH*8VQA<W,@4T]!4%]$25-#
M3U]397)V97(@97AT96YD<R!33T%07T)A<V5?3V)J96-T('L*"B`@("!V87(@
M)&YA;65S<&%C97,@("`@(#T@87)R87DH4T-(14U!7U=31$P@/3X@)W=S9&PG
M+"!30TA%34%?4T]!4"`]/B`G<V]A<"<I.PH@("`@=F%R("1I;7!O<G1?;G,@
M("`@("`](&%R<F%Y*"D["B`@("!V87(@)'=S9&P@("`@("`@("`@(#T@)R<[
M"B`@("!V87(@)&1I<V-O("`@("`@("`@(#T@)R<["B`@("!V87(@)%]W<V1L
M("`@("`@("`@(#T@87)R87DH*3L*("`@('9A<B`D7V1I<V-O("`@("`@("`@
M/2!A<G)A>2@I.PH@("`@=F%R("1?<V5R=FEC95]N86UE("`]("<G.PH@("`@
M=F%R("1?<V5R=FEC95]N<R`@("`]("<G.PH@("`@=F%R("1?<V5R=FEC95]D
M97-C("`]("<G.PH@("`@=F%R("1?<&]R=&YA;64@("`@("`]("<G.PH@("`@
M=F%R("1?8FEN9&EN9VYA;64@("`]("<G.PH@("`@=F%R("1S;V%P7W-E<G9E
M<B`@("`]($Y53$P["@H*("`@(&9U;F-T:6]N(%-/05!?1$E30T]?4V5R=F5R
M*"1S;V%P7W-E<G9E<BP@)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?9&5S8R`]
M("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EM<&]R=%]N
M<R`](&YU;&PI"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V5?3V)J
M96-T*"=397)V97(G*3L*"B`@("`@("`@:68@*"`A:7-?;V)J96-T*"1S;V%P
M7W-E<G9E<BD*("`@("`@("`@("`@?'P@(6=E=%]C;&%S<R@D<V]A<%]S97)V
M97(I(#T]("=S;V%P7W-E<G9E<B<I(')E='5R;CL*"B`@("`@("`@)'1H:7,M
M/E]S97)V:6-E7VYA;64@/2`D<V5R=FEC95]N86UE.PH@("`@("`@("1T:&ES
M+3Y?<V5R=FEC95]N<R`](")U<FXZ)'-E<G9I8V5?;F%M92(["B`@("`@("`@
M)'1H:7,M/E]S97)V:6-E7V1E<V,@/2`D<V5R=FEC95]D97-C.PH@("`@("`@
M("1T:&ES+3YI;7!O<G1?;G,@/2!I<W-E="@D:6UP;W)T7VYS*2`_("1I;7!O
M<G1?;G,@.B`D=&AI<RT^:6UP;W)T7VYS.PH@("`@("`@("1T:&ES+3YS;V%P
M7W-E<G9E<B`]("1S;V%P7W-E<G9E<CL*("`@("`@("`D=&AI<RT^:&]S="`]
M(&ES<V5T*"1?4T525D526R=(5%107TA/4U0G72D@/R`D7U-%4E9%4ELG2%14
M4%](3U-4)UT@.B`G;&]C86QH;W-T)SL*("`@('T*"B`@("!F=6YC=&EO;B!G
M971$25-#3R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]G96YE<F%T95]$25-#
M3R@I.PH@("`@("`@(')E='5R;B`D=&AI<RT^9&ES8V\["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T5U-$3"@I"B`@("!["B`@("`@("`@)'1H:7,M/E]G96YE
M<F%T95]74T1,*"D["B`@("`@("`@<F5T=7)N("1T:&ES+3YW<V1L.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]G96YE<F%T95]$25-#3R@I"B`@("!["B`@("`@
M("`@+R\@1$E30T\*("`@("`@("`D=&AI<RT^7V1I<V-O6R=D:7-C;SID:7-C
M;W9E<GDG75LG871T<B==6R=X;6QN<SID:7-C;R==(#T@4T-(14U!7T1)4T-/
M.PH@("`@("`@("1T:&ES+3Y?9&ES8V];)V1I<V-O.F1I<V-O=F5R>2==6R=A
M='1R)UU;)WAM;&YS.G-C;"==(#T@4T-(14U!7T1)4T-/7U-#3#L*("`@("`@
M("`D=&AI<RT^7V1I<V-O6R=D:7-C;SID:7-C;W9E<GDG75LG<V-L.F-O;G1R
M86-T4F5F)UU;)V%T='(G75LG<F5F)UT@/0H@("`@("`@("`@("`H87)R87E?
M:V5Y7V5X:7-T<R@G2%144%,G+"`D7U-%4E9%4BD@)B8@)%]315)615);)TA4
M5%!3)UT@/3T@)V]N)RD*("`@("`@("`@("`@/R`G:'1T<',Z+R\G("X@)'1H
M:7,M/FAO<W0@+B`D7U-%4E9%4ELG4$A07U-%3$8G72`N("<_=W-D;"<*("`@
M("`@("`@("`@.B`G:'1T<#HO+R<@("X@)'1H:7,M/FAO<W0@+B`D7U-%4E9%
M4ELG4$A07U-%3$8G72`N("<_=W-D;"<["@H@("`@("`@("\O(&=E;F5R871E
M(&1I<V-O('AM;`H@("`@("`@("1T:&ES+3Y?9V5N97)A=&5?1$E30T]?6$U,
M*"1T:&ES+3Y?9&ES8V\I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G96YE<F%T
M95]74T1,*"D*("`@('L*("`@("`@("`O+R!74T1,"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1T:&ES+3YS;V%P7W-E<G9E<BT^7VYA;65S<&%C97,I*2!["B`@
M("`@("`@("`@("\O(&YE960@=&\@9V5T.B!T>7!E;G,L('AS9"`F(%-/05`M
M14Y#"B`@("`@("`@("`@("1F;&EP<&5D(#T@87)R87E?9FQI<"@D=&AI<RT^
M<V]A<%]S97)V97(M/E]N86UE<W!A8V5S*3L*("`@("`@("`@("`@)'1H:7,M
M/FYA;65S<&%C97-;)'1H:7,M/E]S97)V:6-E7VYS72`]("=T;G,G.PH@("`@
M("`@("`@("`D=&AI<RT^;F%M97-P86-E<ULD9FQI<'!E9%LG>'-D)UU=(#T@
M)WAS9"<["B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V5S6R1F;&EP<&5D
M6R=33T%0+45.0R==72`]("=33T%0+45.0R<["B`@("`@("`@?0H*("`@("`@
M("`O+R!$149)3DE424].4PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI
M=&EO;G,G75LG871T<B==6R=N86UE)UT@/2`D=&AI<RT^7W-E<G9I8V5?;F%M
M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)V%T='(G
M75LG=&%R9V5T3F%M97-P86-E)UT@/2`D=&AI<RT^7W-E<G9I8V5?;G,["B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/FYA;65S<&%C97,@87,@)&YS(#T^("1P
M<F5F:7@I('L*("`@("`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N
M<R==6R=A='1R)UU;)WAM;&YS.B<@+B`D<')E9FEX72`]("1N<SL*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=A='1R
M)UU;)WAM;&YS)UT@/2!30TA%34%?5U-$3#L*"B`@("`@("`@+R\@26UP;W)T
M(&YA;65S<&%C97,N(%-E96US('1O(&YO="!W;W)K('EE=#H@=W-D;"YE>&4@
M9F]M("Y.150@8V%N)W0*("`@("`@("`O+R!H86YD;&4@:6UP;W)T960@8V]M
M<&QE=&4@=W-D;"UD969I;FET:6]N<RX*("`@("`@("!I9B`H8V]U;G0H)'1H
M:7,M/FEM<&]R=%]N<RDI('L*("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^:6UP;W)T7VYS(&%S("1?;G,@/3X@)%]L
M;V-A=&EO;BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I
M;FET:6]N<R==6R=I;7!O<G0G75LD:5U;)V%T='(G75LG;&]C871I;VXG72`]
M("1?;&]C871I;VX["B`@("`@("`@("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E
M9FEN:71I;VYS)UU;)VEM<&]R="==6R1I75LG871T<B==6R=N86UE<W!A8V4G
M72`]("1?;G,["B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G
M75LG='EP97,G75LG871T<B==6R=X;6QN<R==/2=H='1P.B\O<V-H96UA<RYX
M;6QS;V%P+F]R9R]W<V1L+R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I
M;FET:6]N<R==6R=T>7!E<R==6R=S8VAE;6$G73UA<G)A>2@I.PH*("`@("`@
M("`O+R!0;&%C96AO;&1E<B!F;W(@;65S<V%G97,*("`@("`@("`D=&AI<RT^
M7W=S9&Q;)V1E9FEN:71I;VYS)UU;)VUE<W-A9V4G72`](&%R<F%Y*"D["@H@
M("`@("`@("\O(%!/4E1465!%+4Y!344*("`@("`@("`D=&AI<RT^7W!O<G1N
M86UE(#T@)'1H:7,M/E]S97)V:6-E7VYA;64@+B`G4&]R="<["B`@("`@("`@
M)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=P;W)T5'EP92==6R=A='1R
M)UU;)VYA;64G72`]("1T:&ES+3Y?<&]R=&YA;64["@H@("`@("`@("\O($))
M3D1)3D<M3D%-10H@("`@("`@("1T:&ES+3Y?8FEN9&EN9VYA;64@/2`D=&AI
M<RT^7W-E<G9I8V5?;F%M92`N("=":6YD:6YG)SL*("`@("`@("`D=&AI<RT^
M7W=S9&Q;)V1E9FEN:71I;VYS)UU;)V)I;F1I;F<G75LG871T<B==6R=N86UE
M)UT@/2`D=&AI<RT^7V)I;F1I;F=N86UE.PH@("`@("`@("1T:&ES+3Y?=W-D
M;%LG9&5F:6YI=&EO;G,G75LG8FEN9&EN9R==6R=A='1R)UU;)W1Y<&4G72`]
M("=T;G,Z)R`N("1T:&ES+3Y?<&]R=&YA;64["B`@("`@("`@)'1H:7,M/E]W
M<V1L6R=D969I;FET:6]N<R==6R=B:6YD:6YG)UU;)W-O87`Z8FEN9&EN9R==
M6R=A='1R)UU;)W-T>6QE)UT@/2`G<G!C)SL*("`@("`@("`D=&AI<RT^7W=S
M9&Q;)V1E9FEN:71I;VYS)UU;)V)I;F1I;F<G75LG<V]A<#IB:6YD:6YG)UU;
M)V%T='(G75LG=')A;G-P;W)T)UT@/2!30TA%34%?4T]!4%](5%10.PH*("`@
M("`@("`O+R!315)624-%"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET
M:6]N<R==6R=S97)V:6-E)UU;)V%T='(G75LG;F%M92==(#T@)'1H:7,M/E]S
M97)V:6-E7VYA;64@+B`G4V5R=FEC92<["B`@("`@("`@)'1H:7,M/E]W<V1L
M6R=D969I;FET:6]N<R==6R=S97)V:6-E)UU;)V1O8W5M96YT871I;VXG75LG
M871T<B==(#T@)R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N
M<R==6R=S97)V:6-E)UU;)V1O8W5M96YT871I;VXG72`](&AT;6QE;G1I=&EE
M<R@D=&AI<RT^7W-E<G9I8V5?9&5S8RD["B`@("`@("`@)'1H:7,M/E]W<V1L
M6R=D969I;FET:6]N<R==6R=S97)V:6-E)UU;)W!O<G0G75LG871T<B==6R=N
M86UE)UT@/2`D=&AI<RT^7W!O<G1N86UE.PH@("`@("`@("1T:&ES+3Y?=W-D
M;%LG9&5F:6YI=&EO;G,G75LG<V5R=FEC92==6R=P;W)T)UU;)V%T='(G75LG
M8FEN9&EN9R==(#T@)W1N<SHG("X@)'1H:7,M/E]B:6YD:6YG;F%M93L*("`@
M("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W-E<G9I8V4G75LG
M<&]R="==6R=S;V%P.F%D9')E<W,G75LG871T<B==6R=L;V-A=&EO;B==(#T*
M("`@("`@("`@("`@*&%R<F%Y7VME>5]E>&ES=',H)TA45%!3)RP@)%]315)6
M15(I("8F("1?4T525D526R=(5%104R==(#T]("=O;B<I"B`@("`@("`@("`@
M(#\@)VAT='!S.B\O)R`N("1T:&ES+3YH;W-T("X@)%]315)615);)U!(4%]3
M14Q&)UT*("`@("`@("`@("`@.B`G:'1T<#HO+R<@("X@)'1H:7,M/FAO<W0@
M+B`D7U-%4E9%4ELG4$A07U-%3$8G73L*"B`@("`@("`@+R\*("`@("`@("`D
M9&ES<&%T8VA?:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/G-O87!?<V5R=F5R
M+3YD:7-P871C:%]O8FIE8W1S*3L*("`@("`@("`D9&,@/2!C;W5N="@D9&ES
M<&%T8VA?:V5Y<RD["B`@("`@("`@9F]R("@D9&D@/2`P.R`D9&D@/"`D9&,[
M("1D:2LK*2!["B`@("`@("`@("`@("1N86UE<W!A8V4@/2`D9&ES<&%T8VA?
M:V5Y<ULD9&E=.PH@("`@("`@("`@("`D;F%M97-P86-E7V]B:F5C=',@/28@
M)'1H:7,M/G-O87!?<V5R=F5R+3YD:7-P871C:%]O8FIE8W1S6R1N86UE<W!A
M8V5=.PH@("`@("`@("`@("`D;V,@/2!C;W5N="@D;F%M97-P86-E7V]B:F5C
M=',I.PH@("`@("`@("`@("!F;W(@*"1O:2`](#`[("1O:2`\("1O8SL@)&]I
M*RLI('L*("`@("`@("`@("`@("`@("1O8FIE8W0@/2`D;F%M97-P86-E7V]B
M:F5C='-;)&]I73L*("`@("`@("`@("`@("`@("\O('1Y<&5S(&1E9FEN:71I
M;VYS"B`@("`@("`@("`@("`@("`D=&AI<RT^861D4V-H96UA1G)O;4UA<"@D
M;V)J96-T+3Y?7W1Y<&5D968I.PH@("`@("`@("`@("`@("`@+R\@34534T%'
M15,*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1-971H;V1S1G)O;4UA<"@D
M;V)J96-T+3Y?7V1I<W!A=&-H7VUA<"P@)&YA;65S<&%C92P@9V5T7V-L87-S
M*"1O8FIE8W0I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H:7-S970H)'-E<G9E<BT^9&ES<&%T8VA?;6%P*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^861D365T:&]D<T9R;VU-87`H)'-E<G9E<BT^9&ES<&%T8VA?
M;6%P+"`D;F%M97-P86-E*3L*("`@("`@("!]"@H@("`@("`@("\O(&=E;F5R
M871E('=S9&P*("`@("`@("`D=&AI<RT^7V=E;F5R871E7U=31$Q?6$U,*"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@)E]G97138VAE;6$H)&YA;65S<&%C92D*
M("`@('L*("`@("`@("`O+R!30TA%34$*("`@("`@("`D8R`](&-O=6YT*"1T
M:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG='EP97,G75LG<V-H96UA)UTI
M.PH@("`@("`@(&9O<B@D:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG='EP97,G
M75LG<V-H96UA)UU;)&E=6R=A='1R)UU;)W1A<F=E=$YA;65S<&%C92==(#T]
M("1N86UE<W!A8V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S)UU;)W-C:&5M82==6R1I73L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9&]N)W0@:&%V
M92!T:&ES(&YA;65S<&%C90H@("`@("`@("1S8VAE;6$@/2!A<G)A>2@I.PH@
M("`@("`@("1S8VAE;6%;)V%T='(G72`](&%R<F%Y*"D["B`@("`@("`@)'-C
M:&5M85LG8V]M<&QE>%1Y<&4G72`](&%R<F%Y*"D["B`@("`@("`@)'-C:&5M
M85LG871T<B==6R=X;6QN<R==(#T@87)R87E?<V5A<F-H*"=X<V0G+"1T:&ES
M+3YN86UE<W!A8V5S*3L*("`@("`@("`D<V-H96UA6R=A='1R)UU;)W1A<F=E
M=$YA;65S<&%C92==(#T@)&YA;65S<&%C93L*("`@("`@("`D=&AI<RT^7W=S
M9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S)UU;)W-C:&5M82==6UT@/28@)'-C
M:&5M83L*"B`@("`@("`@<F5T=7)N("1S8VAE;6$["B`@("!]"@H@("`@9G5N
M8W1I;VX@861D4V-H96UA1G)O;4UA<"@F)&UA<"D*("`@('L*("`@("`@("!I
M9B`H(21M87`I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)&UA<"!A<R`D7W1Y<&5?;F%M92`]/B`D7W1Y<&5?
M9&5F*2!["B`@("`@("`@("`@(&QI<W0H)'1Y<&5N<RPD='EP92D@/2`D=&AI
M<RT^7V=E=%1Y<&5.<R@D7W1Y<&5?;F%M92D["B`@("`@("`@("`@(&EF("@D
M='EP96YS(#T]("=X<V0G*2!["B`@("`@("`@("`@("`@("`O+R!C86YN;W0@
M861D('1O('AS9"P@;&5T<R!U<V4@;65T:&]D7VYA;65S<&%C90H@("`@("`@
M("`@("`@("`@)'1Y<&5N<R`]("=T;G,G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1S8VAE;6$@/28@)'1H:7,M/E]G97138VAE;6$H87)R87E?<V5A
M<F-H*"1T>7!E;G,L("1T:&ES+3YN86UE<W!A8V5S*2D["B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]I9D-O;7!L97A4>7!E17AI<W1S*"1S8VAE;6%;)V-O
M;7!L97A4>7!E)UTL("1T>7!E*2D@>PH@("`@("`@("`@("`@("`@)&-T>7!E
M(#TF("1S8VAE;6%;)V-O;7!L97A4>7!E)UU;73L*("`@("`@("`@("`@("`@
M("1C='EP95LG871T<B==6R=N86UE)UT@/2`D='EP93L*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1?='EP95]D968@87,@)%]V87)N86UE(#T^("1?=F%R
M='EP92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?:6YT*"1?=F%R
M;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D7W9A<G1Y
M<&5N<RPD7W9A<G1Y<&4I(#T@)'1H:7,M/E]G9714>7!E3G,H)%]V87)T>7!E
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>7!E6R=A;&PG75LG871T
M<B==(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@("1E;"`])B`D8W1Y
M<&5;)V%L;"==6R=E;&5M96YT)UU;73L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&5L6R=A='1R)UU;)VYA;64G72`]("1?=F%R;F%M93L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&5L6R=A='1R)UU;)W1Y<&4G72`]("1?=F%R='EP
M96YS("X@)SHG("X@)%]V87)T>7!E.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1C='EP95LG8V]M<&QE
M>$-O;G1E;G0G75LG871T<B==(#T@)R<["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C='EP95LG8V]M<&QE>$-O;G1E;G0G75LG<F5S=')I8W1I;VXG75LG
M871T<B==6R=B87-E)UT@/2`G4T]!4"U%3D,Z07)R87DG.PH@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D7W9A<G1Y<&4@87,@)&%R<F%Y7W9A
M<B`]/B`D87)R87E?='EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;&ES="@D7W9A<G1Y<&5N<RP@)%]V87)T>7!E*2`]("1T:&ES+3Y?9V5T
M5'EP94YS*"1A<G)A>5]T>7!E*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C='EP95LG8V]M<&QE>$-O;G1E;G0G75LG<F5S=')I8W1I;VXG75LG
M871T<FEB=71E)UU;)V%T='(G75LG<F5F)UT@/2`G4T]!4"U%3D,Z87)R87E4
M>7!E)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C='EP95LG8V]M
M<&QE>$-O;G1E;G0G75LG<F5S=')I8W1I;VXG75LG871T<FEB=71E)UU;)V%T
M='(G75LG=W-D;#IA<G)A>51Y<&4G72`]("1?=F%R='EP96YS("X@)SHG("X@
M)%]V87)T>7!E("X@)UM=)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!A9&1-971H
M;V1S1G)O;4UA<"@F)&UA<"P@)&YA;65S<&%C92P@)&-L87-S;F%M92`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"$D;6%P*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1M87`@87,@)&UE
M=&AO9%]N86UE(#T^("1M971H;V1?='EP97,I('L*("`@("`@("`@("`@:68@
M*&%R<F%Y7VME>5]E>&ES=',H)VYA;65S<&%C92<L("1M971H;V1?='EP97,I
M*2!["B`@("`@("`@("`@("`@("`D;65T:&]D7VYA;65S<&%C92`]("1M971H
M;V1?='EP97-;)VYA;65S<&%C92==.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&UE=&AO9%]N86UE<W!A8V4@/2`D;F%M97-P86-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O($E.4%54"B`@("`@("`@
M("`@(&EF("AI<W-E="@D;65T:&]D7W1Y<&5S6R=I;B==*2`F)B!I<U]A<G)A
M>2@D;65T:&]D7W1Y<&5S6R=I;B==*2D@>PH@("`@("`@("`@("`@("`@)&EN
M<'5T7VUE<W-A9V4@/28@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=M
M97-S86=E)UU;73L*("`@("`@("`@("`@("`@("1I;G!U=%]M97-S86=E6R=A
M='1R)UU;)VYA;64G72`]("1M971H;V1?;F%M92`N("=297%U97-T)SL*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1M971H;V1?='EP97-;)VEN)UT@87,@
M)&YA;64@/3X@)'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("!L:7-T*"1T
M>7!E;G,L("1T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1T>7!E*3L*("`@
M("`@("`@("`@("`@("`@("`D<&%R="`])B`D:6YP=71?;65S<V%G95LG<&%R
M="==6UT["B`@("`@("`@("`@("`@("`@("`@)'!A<G1;)V%T='(G75LG;F%M
M92==(#T@)&YA;64["B`@("`@("`@("`@("`@("`@("`@)'!A<G1;)V%T='(G
M75LG='EP92==(#T@)'1Y<&5N<R`N("<Z)R`N("1T>7!E.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!/5510550*
M("`@("`@("`@("`@:68@*&ES<V5T*"1M971H;V1?='EP97-;)V]U="==*2`F
M)B!I<U]A<G)A>2@D;65T:&]D7W1Y<&5S6R=O=70G72DI('L*("`@("`@("`@
M("`@("`@("1O=71P=71?;65S<V%G92`])B`D=&AI<RT^7W=S9&Q;)V1E9FEN
M:71I;VYS)UU;)VUE<W-A9V4G75M=.PH@("`@("`@("`@("`@("`@)&]U='!U
M=%]M97-S86=E6R=A='1R)UU;)VYA;64G72`]("1M971H;V1?;F%M92`N("=2
M97-P;VYS92<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D;65T:&]D7W1Y
M<&5S6R=O=70G72!A<R`D;F%M92`]/B`D='EP92D@>PH@("`@("`@("`@("`@
M("`@("`@(&QI<W0H)'1Y<&5N<RP@)'1Y<&4I(#T@)'1H:7,M/E]G9714>7!E
M3G,H)'1Y<&4I.PH@("`@("`@("`@("`@("`@("`@("1P87)T(#TF("1O=71P
M=71?;65S<V%G95LG<&%R="==6UT["B`@("`@("`@("`@("`@("`@("`@)'!A
M<G1;)V%T='(G75LG;F%M92==(#T@)&YA;64["B`@("`@("`@("`@("`@("`@
M("`@)'!A<G1;)V%T='(G75LG='EP92==(#T@)'1Y<&5N<R`N("<Z)R`N("1T
M>7!E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!03U)45%E015,*("`@("`@("`@("`@)&]P97)A=&EO;B`])B`D
M=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W!O<G14>7!E)UU;)V]P97)A
M=&EO;B==6UT["B`@("`@("`@("`@("1O<&5R871I;VY;)V%T='(G75LG;F%M
M92==(#T@)&UE=&AO9%]N86UE.PH*("`@("`@("`@("`@+R\@24Y0550*("`@
M("`@("`@("`@)&]P97)A=&EO;ELG:6YP=70G75LG871T<B==6R=M97-S86=E
M)UT@/2`G=&YS.B<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)&EN
M<'5T7VUE<W-A9V5;)V%T='(G75LG;F%M92==.PH*("`@("`@("`@("`@+R\@
M3U544%54"B`@("`@("`@("`@("1O<&5R871I;VY;)V]U='!U="==6R=A='1R
M)UU;)VUE<W-A9V4G72`]("=T;G,Z)PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D;W5T<'5T7VUE<W-A9V5;)V%T='(G75LG;F%M92==.PH*("`@
M("`@("`@("`@+R\@0DE.1$E.1PH@("`@("`@("`@("`D8FEN9&EN9R`])B`D
M=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)V)I;F1I;F<G75LG;W!E<F%T
M:6]N)UU;73L*("`@("`@("`@("`@)&)I;F1I;F=;)V%T='(G75LG;F%M92==
M(#T@)&UE=&AO9%]N86UE.PH@("`@("`@("`@("`D86-T:6]N(#T@)&UE=&AO
M9%]N86UE<W!A8V4@+B`G(R<@+B`H)&-L87-S;F%M92`_("1C;&%S<VYA;64@
M+B`G(R<@.B`G)RD@+B`D;65T:&]D7VYA;64["B`@("`@("`@("`@("1B:6YD
M:6YG6R=S;V%P.F]P97)A=&EO;B==6R=A='1R)UU;)W-O87!!8W1I;VXG72`]
M("1A8W1I;VX["@H@("`@("`@("`@("`O+R!)3E!55`H@("`@("`@("`@("`D
M8FEN9&EN9ULG:6YP=70G75LG871T<B==(#T@)R<["B`@("`@("`@("`@("1B
M:6YD:6YG6R=I;G!U="==6R=S;V%P.F)O9'DG75LG871T<B==6R=U<V4G72`]
M("=E;F-O9&5D)SL*("`@("`@("`@("`@)&)I;F1I;F=;)VEN<'5T)UU;)W-O
M87`Z8F]D>2==6R=A='1R)UU;)VYA;65S<&%C92==(#T@)&UE=&AO9%]N86UE
M<W!A8V4["B`@("`@("`@("`@("1B:6YD:6YG6R=I;G!U="==6R=S;V%P.F)O
M9'DG75LG871T<B==6R=E;F-O9&EN9U-T>6QE)UT@/2!33T%07U-#2$5-05]%
M3D-/1$E.1SL*"B`@("`@("`@("`@("\O($]55%!55`H@("`@("`@("`@("`D
M8FEN9&EN9ULG;W5T<'5T)UU;)V%T='(G72`]("<G.PH@("`@("`@("`@("`D
M8FEN9&EN9ULG;W5T<'5T)UU;)W-O87`Z8F]D>2==6R=A='1R)UU;)W5S92==
M(#T@)V5N8V]D960G.PH@("`@("`@("`@("`D8FEN9&EN9ULG;W5T<'5T)UU;
M)W-O87`Z8F]D>2==6R=A='1R)UU;)VYA;65S<&%C92==(#T@)&UE=&AO9%]N
M86UE<W!A8V4["B`@("`@("`@("`@("1B:6YD:6YG6R=O=71P=70G75LG<V]A
M<#IB;V1Y)UU;)V%T='(G75LG96YC;V1I;F=3='EL92==(#T@4T]!4%]30TA%
M34%?14Y#3T1)3D<["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]G
M96YE<F%T95]$25-#3U]834PH)&1I<V-O7V%R<F%Y*0H@("`@>PH@("`@("`@
M("1D:7-C;R`]("<\/WAM;"!V97)S:6]N/2(Q+C`B/SXG.PH@("`@("`@(&9O
M<F5A8V@@*"1D:7-C;U]A<G)A>2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@)&1I<V-O("X]("1T:&ES+3Y?87)R87E4;TYO9&4H)&ME>2PD=F%L
M*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F1I<V-O(#T@)&1I<V-O.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]G96YE<F%T95]74T1,7UA-3"@I"B`@("![
M"B`@("`@("`@)'=S9&P@/2`G/#]X;6P@=F5R<VEO;CTB,2XP(C\^)SL*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W=S9&P@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@("1W<V1L("X]("1T:&ES+3Y?87)R87E4;TYO9&4H)&ME
M>2P@)'9A;"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YW<V1L(#T@)'=S
M9&P["B`@("!]"@H@("`@9G5N8W1I;VX@7V%R<F%Y5&].;V1E*"1N;V1E7VYA
M;64@/2`G)RP@)&%R<F%Y*0H@("`@>PH@("`@("`@("1R971U<FX@/2`G)SL*
M("`@("`@("!I9B`H:7-?87)R87DH)&%R<F%Y*2D@>PH@("`@("`@("`@("`O
M+R!W92!H879E(&$@;F]D92!I9B!T:&5R92=S(&ME>2`G871T<B<*("`@("`@
M("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V%T='(G+"1A<G)A>2DI('L*
M("`@("`@("`@("`@("`@("1R971U<FX@+CT@(CPD;F]D95]N86UE(CL*("`@
M("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D87)R87E;)V%T='(G72DI('L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D87)R87E;)V%T='(G72!A
M<R`D871T<E]N86UE(#T^("1A='1R7W9A;'5E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1R971U<FX@+CT@(B`D871T<E]N86UE/5PB)&%T=')?=F%L
M=65<(B(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("\O('5N<V5T("=A='1R)R!A;F0@<')O8V5E
M9"!O=&AE<B!C:&EL9',N+BX*("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A
M>5LG871T<B==*3L*"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&%R<F%Y
M*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D:2`](#`["B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1C:&EL9%]N;V1E7VYA
M;64@/3X@)&-H:6QD7VYO9&5?=F%L=64I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E='5R;B`N/2`D:2`]/2`P(#\@(CY<;B(@.B`G)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E='5R;B`N/2`D=&AI<RT^7V%R<F%Y5&].
M;V1E*"1C:&EL9%]N;V1E7VYA;64L)&-H:6QD7VYO9&5?=F%L=64I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N("X]("(\+R1N;V1E7VYA
M;64^7&XB.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D<F5T=7)N("X]("(@+SY<;B(["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!W92!H
M879E(&YO("=A='1R)R!K97D@:6X@87)R87D@+2!S;R!I="=S(&QI<W0@;V8@
M;F]D97,@=VET:`H@("`@("`@("`@("`@("`@+R\@=&AE('-A;64@;F%M92`N
M+BX*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D8VAI;&1?
M;F]D95]N86UE(#T^("1C:&EL9%]N;V1E7W9A;'5E*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E='5R;B`N/2`D=&AI<RT^7V%R<F%Y5&].;V1E*"1N;V1E
M7VYA;64L)&-H:6QD7VYO9&5?=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M)&%R<F%Y(&ES(&YO="!A;B!A<G)A>0H@("`@("`@("`@("!I9B`H)&%R<F%Y
M("$])R<I('L*("`@("`@("`@("`@("`@("\O(&%N9"!I=',@;F]T(&5M<'1Y
M"B`@("`@("`@("`@("`@("`D<F5T=7)N("X]("(\)&YO9&5?;F%M93XD87)R
M87D\+R1N;V1E7VYA;64^7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@+R\@86YD(&ET<R!E;7!T>2XN+@H@("`@("`@("`@("`@
M("`@)')E='5R;B`N/2`B/"1N;V1E7VYA;64@+SY<;B(["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@
M("`@9G5N8W1I;VX@7V=E=%1Y<&5.<R@D='EP92D*("`@('L*("`@("`@("!P
M<F5G7VUA=&-H7V%L;"@B)UQ[*"XJ*5Q])W-M(BP@)'1Y<&4L("1M*3L*("`@
M("`@("!I9B`H:7-S970H)&U;,5U;,%TI("8F("1M6S%=6S!=("$]("<G*2![
M"B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D;5LQ75LP72PD
M=&AI<RT^;F%M97-P86-E<RDI('L*("`@("`@("`@("`@("`@("1N<U]P<F5F
M(#T@)VYS)R`N(&-O=6YT*"1T:&ES+3YN86UE<W!A8V5S*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YN86UE<W!A8V5S6R1M6S%=6S!=72`]("1N<U]P<F5F
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==
M6R=A='1R)UU;)WAM;&YS.B<@+B`D;G-?<')E9ET@/2`D;5LQ75LP73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D='EP96YS(#T@)'1H:7,M/FYA;65S
M<&%C97-;)&U;,5U;,%U=.PH@("`@("`@("`@("`D='EP92`](&5R96=?<F5P
M;&%C92@D;5LP75LP72PG)RPD='EP92D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1Y<&5N<R`]("=X<V0G.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@87)R87DH)'1Y<&5N<RPD='EP92D["B`@("!]"@H@("`@9G5N8W1I
M;VX@7VEF0V]M<&QE>%1Y<&5%>&ES=',H)'1Y<&5S07)R87DL("1T>7!E7VYA
M;64I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T>7!E<T%R<F%Y*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D='EP97-!<G)A>2!A<R`D:6YD97@@
M/3X@)'1Y<&5?9&%T82D@>PH@("`@("`@("`@("`@("`@:68@*"1T>7!E<T%R
M<F%Y6R1I;F1E>%U;)V%T='(G75LG;F%M92==(#T]("1T>7!E7VYA;64I('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]33T%0+T9A=6QT+G!H<```````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,#`U,@`Q,#4Q-30S,3`U-P`P,3<V-C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T:&4@4T]!4%]&875L="!C;&%S
M<RP@=7-E9"!F;W(@86QL(&5R<F]R(&]B:F5C=',@:6X@=&AI<PH@*B!P86-K
M86=E+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I
M;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@
M("!33T%0"B`J($!A=71H;W(@("`@($1I971R:6-H($%Y86QA(#QD:65T<FEC
M:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B!`875T:&]R("`@("!3
M:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%
M05(@86YD(&UO<F4*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^("`@36%I;G1E;F%N8V4*("H@0&%U=&AO<B`@("`@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX@("`@("`@36%I;G1E;F%N
M8V4*("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4H)U!%
M05(N<&AP)RD["@HO*BH*("H@4T]!4%]&875L=`H@*B!014%2.CI%<G)O<B!W
M<F%P<&5R('5S960@=&\@;6%T8V@@4T]!4"!&875L=',@=&\@4$5!4B!%<G)O
M<G,*("H*("H@0'!A8VMA9V4@(%-/05`*("H@0&%C8V5S<R`@('!U8FQI8PH@
M*B!`875T:&]R("`@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^
M("`@4&]R="!T;R!014%2(&%N9"!M;W)E"B`J($!A=71H;W(@("!$:65T<FEC
M:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*
M("HO"F-L87-S(%-/05!?1F%U;'0@97AT96YD<R!014%27T5R<F]R"GL*("`@
M(`H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H@"B`@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!M97-S86=E('-T<FEN9R!F;W(@9F%U;'0*("`@
M("`J($!P87)A;2`@("!M:7AE9"`@('1H92!F875L=&-O9&4*("`@("`J($!P
M87)A;2`@("!M:7AE9"`@('-E92!014%2.CI%4E)/4B`*("`@("`J($!P87)A
M;2`@("!M:7AE9"`@('-E92!014%2.CI%4E)/4B`*("`@("`J($!P87)A;2`@
M("!A<G)A>2`@('1H92!U<V5R:6YF;R!A<G)A>2!I<R!U<V5D('1O('!A<W,@
M:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("!33T%0(&%C=&]R(&%N
M9"!D971A:6P@9F]R('1H92!F875L=`H@("`@("HO"B`@("!F=6YC=&EO;B!3
M3T%07T9A=6QT*"1F875L='-T<FEN9R`]("=U;FMN;W=N(&5R<F]R)RP@)&9A
M=6QT8V]D92`]("=#;&EE;G0G+"`D9F%U;'1A8W1O<CU.54Q,+"`D9&5T86EL
M/4Y53$PL("1M;V1E(#T@;G5L;"P@)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ4$5!4E]%<G)O<B@D9F%U;'1S=')I;F<L("1F875L
M=&-O9&4L("1M;V1E+"`D;W!T:6]N<RP@)&1E=&%I;"D["B`@("`@("`@:68@
M*"1F875L=&%C=&]R*2`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@@/2`D
M9F%U;'1A8W1O<CL*("`@('T*("`@(`H@("`@+RHJ"B`@("`@*B!M97-S86=E
M"B`@("`@*@H@("`@("H@<F5T=7)N<R!A(%-/05!?365S<V%G92!C;&%S<R!T
M:&%T(&-A;B!B92!S96YT(&%S(&$@<V5R=F5R(')E<W!O;G-E"B`@("`@*@H@
M("`@("H@0')E='5R;B!33T%07TUE<W-A9V4@"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!M97-S86=E*"D*("`@('L*("`@
M("`@("`D;7-G(#TF(&YE=R!33T%07T)A<V4H*3L*("`@("`@("`D<&%R86US
M(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6UT@/28@;F5W(%-/05!?5F%L
M=64H)V9A=6QT8V]D92<L("=13F%M92<L("=33T%0+45.5CHG+B1T:&ES+3YC
M;V1E*3L*("`@("`@("`D<&%R86US6UT@/28@;F5W(%-/05!?5F%L=64H)V9A
M=6QT<W1R:6YG)RP@)W-T<FEN9R<L("1T:&ES+3YM97-S86=E*3L*("`@("`@
M("`D<&%R86US6UT@/28@;F5W(%-/05!?5F%L=64H)V9A=6QT86-T;W(G+"`G
M86YY55)))RP@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX*3L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F)A8VMT<F%C92DI('L*("`@("`@("`@("`@
M)'!A<F%M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=D971A:6PG+"`G<W1R:6YG
M)RP@)'1H:7,M/F)A8VMT<F%C92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'!A<F%M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=D971A:6PG+"`G
M<W1R:6YG)RP@)'1H:7,M/G5S97)I;F9O*3L*("`@("`@("!]"B`@("`@("`@
M"B`@("`@("`@)&UE=&AO9%9A;'5E(#TF(&YE=R!33T%07U9A;'5E*"=[)RY3
M3T%07T5.5D5,3U`N)WU&875L="<L("=3=')U8W0G+"`D<&%R86US*3L*("`@
M("`@("`D:&5A9&5R<R`]($Y53$P["B`@("`@("`@<F5T=7)N("1M<V<M/E]M
M86ME16YV96QO<&4H)&UE=&AO9%9A;'5E+"`D:&5A9&5R<RD["B`@("!]"B`@
M("`*("`@("\J*@H@("`@("H@9V5T1F%U;'0*("`@("`J"B`@("`@*B!R971U
M<FYS(&$@<VEM<&QE(&YA=&EV92!P:'`@87)R87D@8V]N=&%I;FEN9R!T:&4@
M9F%U;'0@9&%T80H@("`@("H*("`@("`J($!R971U<FX@87)R87D@"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971&875L
M="@I"B`@("!["B`@("`@("`@9VQO8F%L("133T%07T]"2D5#5%]35%)50U0[
M"B`@("`@("`@:68@*"133T%07T]"2D5#5%]35%)50U0I('L*("`@("`@("`@
M("`@)&9A=6QT(#TF(&YE=R!S=&1#;&%S<R@I.PH@("`@("`@("`@("`D9F%U
M;'0M/F9A=6QT8V]D92`]("1T:&ES+3YC;V1E.PH@("`@("`@("`@("`D9F%U
M;'0M/F9A=6QT<W1R:6YG(#T@)'1H:7,M/FUE<W-A9V4["B`@("`@("`@("`@
M("1F875L="T^9F%U;'1A8W1O<B`]("1T:&ES+3YE<G)O<E]M97-S86=E7W!R
M969I>#L*("`@("`@("`@("`@)&9A=6QT+3YD971A:6P@/2`D=&AI<RT^=7-E
M<FEN9F\["B`@("`@("`@("`@(')E='5R;B`D9F%U;'0["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=F875L=&-O
M9&4G(#T^("1T:&ES+3YC;V1E+`H@("`@("`@("`@("`@("`@)V9A=6QT<W1R
M:6YG)R`]/B`D=&AI<RT^;65S<V%G92P*("`@("`@("`@("`@("`@("=F875L
M=&%C=&]R)R`]/B`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@L"B`@("`@
M("`@("`@("`@("`G9&5T86EL)R`]/B`D=&AI<RT^=7-E<FEN9F\*("`@("`@
M("`@("`@*3L*("`@('T*("`@(`H@("`@+RHJ"B`@("`@*B!G971!8W1O<@H@
M("`@("H*("`@("`J(')E='5R;G,@=&AE(%-/05`@86-T;W(@9F]R('1H92!F
M875L=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(`H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06-T;W(H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F
M:7@["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@9V5T1&5T86EL"B`@("`@
M*@H@("`@("H@<F5T=7)N<R!T:&4@9F%U;'0@9&5T86EL"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G971$971A:6PH*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^=7-E<FEN9F\["B`@("!]"B`@("`*?0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/
M05`O4&%R<V5R+G!H<```````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#0V,#4P`#$P-3$U-#,Q,#4W`#`R,#`U-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AI
M<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T:&4@4T]!4"!M97-S86=E
M('!A<G-E<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA
M9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!$:65T<FEC:"!!>6%L82`\9&EE
M=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("H@0&%U=&AO<B`@
M("`@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T
M;R!014%2(&%N9"!M;W)E"B`J($!A=71H;W(@("`@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/B`@($UA:6YT96YA;F-E"B`J($!A=71H;W(@
M("`@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^("`@("`@($UA:6YT
M96YA;F-E"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*<F5Q=6ER95]O;F-E
M("=33T%0+T)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+U9A;'5E+G!H
M<"<["@HO*BH*("H@4T]!4"!087)S97(*("H*("H@5&AI<R!C;&%S<R!I<R!U
M<V5D(&)Y(%-/05`Z.DUE<W-A9V4@86YD(%-/05`Z.E-E<G9E<B!T;R!P87)S
M92!S;V%P"B`J('!A8VME=',N($]R:6=I;F%L;'D@8F%S960@;VX@4T]!4'@T
M(&)Y($1I971R:6-H($%Y86QA"B`J(&AT='`Z+R]D:65T<FEC:"YG86YX-"YC
M;VTO<V]A<'@T"B`J"B`J($!A8V-E<W,@<'5B;&EC"B`J($!P86-K86=E(%-/
M05`*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/B!#
M;VYV97)S:6]N('1O(%!%05(@86YD('5P9&%T97,*("H@0&%U=&AO<B!$:65T
M<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H
M;W(*("HO"F-L87-S(%-/05!?4&%R<V5R(&5X=&5N9',@4T]!4%]"87-E"GL*
M("`@('9A<B`D<W1A='5S(#T@)R<["B`@("!V87(@)'!O<VET:6]N(#T@,#L*
M("`@('9A<B`D<&]S7W-T870@/2`P.PH@("`@=F%R("1D97!T:"`](#`["B`@
M("!V87(@)&1E9F%U;'1?;F%M97-P86-E(#T@)R<["B`@("!V87(@)&UE<W-A
M9V4@/2!A<G)A>2@I.PH@("`@=F%R("1D97!T:%]A<G)A>2`](&%R<F%Y*"D[
M"B`@("!V87(@)'!R979I;W5S7V5L96UE;G0@/2`G)SL*("`@('9A<B`D<V]A
M<')E<W!O;G-E(#T@;G5L;#L*("`@('9A<B`D<V]A<&AE861E<G,@/2!N=6QL
M.PH@("`@=F%R("1P87)E;G0@/2`P.PH@("`@=F%R("1R;V]T7W-T<G5C=%]N
M86UE(#T@87)R87DH*3L*("`@('9A<B`D:&5A9&5R7W-T<G5C=%]N86UE(#T@
M87)R87DH*3L*("`@('9A<B`D8W5R96YT7W)O;W1?<W1R=6-T7VYA;64@/2`G
M)SL*("`@('9A<B`D96YT:71I97,@/2!A<G)A>2`H("<F)R`]/B`G)F%M<#LG
M+"`G/"<@/3X@)R9L=#LG+"`G/B<@/3X@)R9G=#LG+"`B)R(@/3X@)R9A<&]S
M.R<L("<B)R`]/B`G)G%U;W0[)R`I.PH@("`@=F%R("1R;V]T7W-T<G5C="`]
M(&%R<F%Y*"D["B`@("!V87(@)&AE861E<E]S=')U8W0@/2!A<G)A>2@I.PH@
M("`@=F%R("1C=7)E;G1?<F]O=%]S=')U8W0@/2`P.PH@("`@=F%R("1R969E
M<F5N8V5S(#T@87)R87DH*3L*("`@('9A<B`D;F5E9%]R969E<F5N8V5S(#T@
M87)R87DH*3L*("`@('9A<B`D6$U,4V-H96UA5F5R<VEO;CL*("`@('9A<B`D
M8F]D>41E<'1H.R`O+R!U<V5D('1O(&AA;F1L92!N;VXM<F]O="!E;&5M96YT
M<R!B969O<F4@<F]O="!B;V1Y(&5L96UE;G0*"B`@("`O*BH*("`@("`J(%-/
M05!?4&%R<V5R(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!X;6P@8V]N=&5N=`H@("`@("H@0'!A<F%M('-T<FEN9R!X;6P@8VAA
M<F%C=&5R(&5N8V]D:6YG+"!D969A=6QT<R!T;R`G551&+3@G"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%-/05!?4&%R<V5R*"8D>&UL+"`D96YC;V1I;F<@/2!3
M3T%07T1%1D%53%1?14Y#3T1)3D<L("1A='1A8VAM96YT<R`](&YU;&PI"B`@
M("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)U!A<G-E<B<I.PH@("`@
M("`@("1T:&ES+3Y?<V5T4V-H96UA5F5R<VEO;BA33T%07UA-3%]30TA%34%?
M5D524TE/3BD["@H@("`@("`@("1T:&ES+3YA='1A8VAM96YT<R`]("1A='1A
M8VAM96YT<SL*"B`@("`@("`@+R\@0VAE8VL@=&AE('AM;"!T86<@9F]R(&5N
M8V]D:6YG+@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O/%P_>&UL6UX^72ME
M;F-O9&EN9UQS*C\]7',J/RA<)RA;7EPG72HI7"=\(BA;7B)=*BDB*5M>/ETJ
M/UM</UT^+R<L("1X;6PL("1M*2D@>PH@("`@("`@("`@("`D96YC;V1I;F<@
M/2!S=')T;W5P<&5R*"1M6S)=(#\@)&U;,ET@.B`D;5LS72D["B`@("`@("`@
M?0H*("`@("`@("`O+R!$971E<FUI;F5S('=H97)E(&EN('1H92!M97-S86=E
M('=E(&%R90H@("`@("`@("\O("AE;G9E;&]P92QH96%D97(L8F]D>2QM971H
M;V0I+B!#:&5C:R!W:&5T:&5R(&-O;G1E;G0@:&%S"B`@("`@("`@+R\@8F5E
M;B!R96%D+@H@("`@("`@(&EF("@A96UP='DH)'AM;"DI('L*("`@("`@("`@
M("`@+R\@4')E<&%R92!T:&4@>&UL('!A<G-E<BX*("`@("`@("`@("`@)'!A
M<G-E<B`]('AM;%]P87)S97)?8W)E871E*"1E;F-O9&EN9RD["B`@("`@("`@
M("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D<&%R<V5R+"!834Q?3U!424].
M7T-!4T5?1D],1$E.1RP@,"D["B`@("`@("`@("`@('AM;%]S971?;V)J96-T
M*"1P87)S97(L("1T:&ES*3L*("`@("`@("`@("`@>&UL7W-E=%]E;&5M96YT
M7VAA;F1L97(H)'!A<G-E<BP@)W-T87)T16QE;65N="<L("=E;F1%;&5M96YT
M)RD["B`@("`@("`@("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE
M<B@D<&%R<V5R+"`G8VAA<F%C=&5R1&%T82<I.PH*("`@("`@("`@("`@+R\@
M4V]M92!L86UE('-O87`@:6UP;&5M96YT871I;VYS(&%D9"!N=6QL(&)Y=&5S
M(&%T('1H90H@("`@("`@("`@("`O+R!E;F0@;V8@=&AE('-O87`@<W1R96%M
M+"!A;F0@97AP870@8VAO86MS(&]N('1H870N"B`@("`@("`@("`@(&EF("@D
M>&UL6W-T<FQE;B@D>&UL*2`M(#%=(#T](#`I('L*("`@("`@("`@("`@("`@
M("1X;6P@/2!T<FEM*"1X;6PI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!087)S92!T:&4@6$U,(&9I;&4N"B`@("`@("`@("`@(&EF("@A>&UL
M7W!A<G-E*"1P87)S97(L("1X;6PL('1R=64I*2!["B`@("`@("`@("`@("`@
M("`D97)R(#T@<W!R:6YT9B@G6$U,(&5R<F]R(&]N(&QI;F4@)60@8V]L("5D
M(&)Y=&4@)60@)7,G+`H@("`@("`@("`@("`@("`@("`@('AM;%]G971?8W5R
M<F5N=%]L:6YE7VYU;6)E<B@D<&%R<V5R*2P*("`@("`@("`@("`@("`@("`@
M("!X;6Q?9V5T7V-U<G)E;G1?8V]L=6UN7VYU;6)E<B@D<&%R<V5R*2P*("`@
M("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?8GET95]I;F1E>"@D
M<&%R<V5R*2P*("`@("`@("`@("`@("`@("`@("!X;6Q?97)R;W)?<W1R:6YG
M*'AM;%]G971?97)R;W)?8V]D92@D<&%R<V5R*2DI.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@D97)R+&AT;6QS<&5C:6%L8VAA
M<G,H)'AM;"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('AM;%]P87)S
M97)?9G)E92@D<&%R<V5R*3L*("`@("`@("!]"B`@("!]"@H*("`@("\J*@H@
M("`@("H@9&]M=6QT:0H@("`@("H@<F5C=7)S92!T;R!B=6EL9"!A(&UU;'1I
M+61I;2!A<G)A>2P@=7-E9"!B>2!B=6EL9%)E<W!O;G-E"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O;75L
M=&DH)&0L("8D87(L("8D<BP@)B1V+"`D860],"D*("`@('L*("`@("`@("!I
M9B`H)&0I('L*("`@("`@("`@("`@)'1H:7,M/F1O;75L=&DH)&0M,2P@)&%R
M+"`D<ELD87);)&%D75TL("1V+"`D860K,2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'(@/2`D=CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!B=6EL9%)E<W!O;G-E"B`@("`@*B!L;V]P('1H<F]U9V@@;7-G
M+"!B=6EL9&EN9R!R97-P;VYS92!S=')U8W1U<F5S"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="!P;W-I=&EO;@H@("`@("H@0')E='5R;B!33T%07U9A;'5E
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F)U:6QD4F5S<&]N<V4H)'!O<RD*("`@('L*("`@("`@("`D<F5S<&]N<V4@
M/2!N=6QL.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@("1C:&EL9')E;B`](&5X
M<&QO9&4H)WPG+"`D=&AI<RT^;65S<V%G95LD<&]S75LG8VAI;&1R96XG72D[
M"@H@("`@("`@("`@("!F;W)E86-H("@D8VAI;&1R96X@87,@)&,@/3X@)&-H
M:6QD7W!O<RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YM97-S86=E
M6R1C:&EL9%]P;W-=6R=T>7!E)UT@(3T@;G5L;"D@>PH@("`@("`@("`@("`@
M("`@("`@("1R97-P;VYS95M=(#TF("1T:&ES+3YB=6EL9%)E<W!O;G-E*"1C
M:&EL9%]P;W,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=A<G)A>5-I>F4G+"`D
M=&AI<RT^;65S<V%G95LD<&]S72DI('L*("`@("`@("`@("`@("`@("1A<F1E
M<'1H(#T@8V]U;G0H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y4VEZ92==
M*3L*("`@("`@("`@("`@("`@(&EF("@D87)D97!T:"`^(#$I('L*("`@("`@
M("`@("`@("`@("`@("`D87(@/2!A<G)A>5]P860H87)R87DH*2P@)&%R9&5P
M=&@L(#`I.PH@("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI
M<W1S*"=A<G)A>4]F9G-E="<L("1T:&ES+3YM97-S86=E6R1P;W-=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D87)D
M97!T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%R
M6R1I72`K/2`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E/9F9S970G75LD
M:5T["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&5L8R`](&-O=6YT*"1R97-P
M;VYS92D["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&5L8SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!R96-U
M<G-E('1O(&)U:6QD(&$@;75L=&DM9&EM96YS:6]N86P@87)R87D*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F1O;75L=&DH)&%R9&5P=&@L("1A
M<BP@)&YE=W)E<W`L("1R97-P;VYS95LD:5TI.PH*("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@:6YC<F5M96YT(&]U<B!A<G)A>2!P;VEN=&5R<PH@("`@
M("`@("`@("`@("`@("`@("`@("`D860@/2`D87)D97!T:"`M(#$["B`@("`@
M("`@("`@("`@("`@("`@("`@("1A<ELD861=*RL["B`@("`@("`@("`@("`@
M("`@("`@("`@('=H:6QE("@D860@/B`P("8F("1A<ELD861=(#X]("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=A<G)A>5-I>F4G75LD861=*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D87);)&%D72`](#`["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D860M+3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1A<ELD861=*RL["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)')E
M<W!O;G-E(#T@)&YE=W)E<W`["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T)UTI("8F
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)V%R<F%Y3V9F<V5T)UU;,%T@/B`P*2!["B`@("`@("`@("`@("`@("`@
M("`@+R\@8VAE8VL@9F]R('!A9&1I;F<*("`@("`@("`@("`@("`@("`@("`D
M<&%D(#T@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T)UU;,%T@
M*R!C;W5N="@D<F5S<&]N<V4I("H@+3$["B`@("`@("`@("`@("`@("`@("`@
M)')E<W!O;G-E(#T@87)R87E?<&%D*"1R97-P;VYS92P@)'!A9"P@;G5L;"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O($)U:6QD(&%T=')I8G5T97,N"B`@("`@("`@)&%T=')S(#T@
M87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^;65S<V%G95LD<&]S
M75LG871T<G,G72!A<R`D871N(#T^("1A='8I('L*("`@("`@("`@("`@:68@
M*"%S=')S='(H)&%T;BP@)WAM;&YS)RD@)B8*("`@("`@("`@("`@("`@("%S
M=')P;W,H)&%T;BP@)SHG*2D@>PH@("`@("`@("`@("`@("`@)&%T=')S6R1A
M=&Y=(#T@)&%T=CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@061D(&-U<G)E;G0@;F]D92=S('9A;'5E+@H@("`@("`@(&EF("@D<F5S
M<&]N<V4I('L*("`@("`@("`@("`@)&YQ;B`])B!N97<@46YA;64H)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)VYA;64G72P@)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)VYA;65S<&%C92==*3L*("`@("`@("`@("`@)'1Q;B`])B!N97<@46YA;64H
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&4G72P@)'1H:7,M/FUE<W-A9V5;
M)'!O<UU;)W1Y<&5?;F%M97-P86-E)UTI.PH@("`@("`@("`@("`D<F5S<&]N
M<V4@/28@;F5W(%-/05!?5F%L=64H)&YQ;BT^9G%N*"DL("1T<6XM/F9Q;B@I
M+"`D<F5S<&]N<V4L("1A='1R<RD["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E4>7!E)UTI*2!["B`@("`@("`@
M("`@("`@("`D<F5S<&]N<V4M/F%R<F%Y5'EP92`]("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=A<G)A>51Y<&4G73L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1N<6X@/28@;F5W(%%N86UE*"1T:&ES+3YM
M97-S86=E6R1P;W-=6R=N86UE)UTL("1T:&ES+3YM97-S86=E6R1P;W-=6R=N
M86UE<W!A8V4G72D["B`@("`@("`@("`@("1T<6X@/28@;F5W(%%N86UE*"1T
M:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UTL("1T:&ES+3YM97-S86=E6R1P
M;W-=6R=T>7!E7VYA;65S<&%C92==*3L*("`@("`@("`@("`@)')E<W!O;G-E
M(#TF(&YE=R!33T%07U9A;'5E*"1N<6XM/F9Q;B@I+"`D='%N+3YF<6XH*2P@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UTL("1A='1R<RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!H86YD;&4@:&5A9&5R(&%T=')I8G5T92!T:&%T
M('=E(&YE960*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G86-T;W(G
M+"`D=&AI<RT^;65S<V%G95LD<&]S72DI('L*("`@("`@("`@("`@)')E<W!O
M;G-E+3YA8W1O<B`]("1T:&ES+3YM97-S86=E6R1P;W-=6R=A8W1O<B==.PH@
M("`@("`@('T*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G;75S=%5N
M9&5R<W1A;F0G+"`D=&AI<RT^;65S<V%G95LD<&]S72DI('L*("`@("`@("`@
M("`@)')E<W!O;G-E+3YM=7-T=6YD97)S=&%N9"`]("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=M=7-T56YD97)S=&%N9"==.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@<W1A<G1%
M;&5M96YT"B`@("`@*B!S=&%R="UE;&5M96YT(&AA;F1L97(@=7-E9"!W:71H
M('AM;"!P87)S97(*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1P87)S97(L("1N86UE
M+"`D871T<G,I"B`@("!["B`@("`@("`@+R\@<&]S:71I;VX@:6X@82!T;W1A
M;"!N=6UB97(@;V8@96QE;65N=',L('-T87)T:6YG(&9R;VT@,`H@("`@("`@
M("\O('5P9&%T92!C;&%S<R!L979E;"!P;W,*("`@("`@("`D<&]S(#T@)'1H
M:7,M/G!O<VET:6]N*RL["@H@("`@("`@("\O(&%N9"!S970@;6EN90H@("`@
M("`@("1T:&ES+3YM97-S86=E6R1P;W-=(#T@87)R87DH*3L*("`@("`@("`D
M=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)R<["B`@("`@("`@)'1H
M:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&5?;F%M97-P86-E)UT@/2`G)SL*("`@
M("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG8V1A=&$G72`]("<G.PH@("`@
M("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=P;W,G72`]("1P;W,["B`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)VED)UT@/2`G)SL*"B`@("`@("`@
M+R\@<&%R96YT+V-H:6QD+V1E<'1H(&1E=&5R;6EN871I;VYS"@H@("`@("`@
M("\O(&1E<'1H(#T@:&]W(&UA;GD@;&5V96QS(')E;6]V960@9G)O;2!R;V]T
M/PH@("`@("`@("\O('-E="!M:6YE(&%S(&-U<G)E;G0@9VQO8F%L(&1E<'1H
M(&%N9"!I;F-R96UE;G0@9VQO8F%L(&1E<'1H('9A;'5E"B`@("`@("`@)'1H
M:7,M/FUE<W-A9V5;)'!O<UU;)V1E<'1H)UT@/2`D=&AI<RT^9&5P=&@K*SL*
M"B`@("`@("`@+R\@96QS92!A9&0@<V5L9B!A<R!C:&EL9"!T;R!W:&]E=F5R
M('1H92!C=7)R96YT('!A<F5N="!I<PH@("`@("`@(&EF("@D<&]S("$](#`I
M('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YM97-S86=E6R1T:&ES
M+3YP87)E;G1=6R=C:&EL9')E;B==*2D*("`@("`@("`@("`@("`@("1T:&ES
M+3YM97-S86=E6R1T:&ES+3YP87)E;G1=6R=C:&EL9')E;B==("X](")\)'!O
M<R(["B`@("`@("`@("`@(&5L<V4*("`@("`@("`@("`@("`@("1T:&ES+3YM
M97-S86=E6R1T:&ES+3YP87)E;G1=6R=C:&EL9')E;B==(#T@)'!O<SL*("`@
M("`@("!]"@H@("`@("`@("\O('-E="!M>2!P87)E;G0*("`@("`@("`D=&AI
M<RT^;65S<V%G95LD<&]S75LG<&%R96YT)UT@/2`D=&AI<RT^<&%R96YT.PH*
M("`@("`@("`O+R!S970@<V5L9B!A<R!C=7)R96YT('9A;'5E(&9O<B!T:&ES
M(&1E<'1H"B`@("`@("`@)'1H:7,M/F1E<'1H7V%R<F%Y6R1T:&ES+3YD97!T
M:%T@/2`D<&]S.PH@("`@("`@("\O('-E="!S96QF(&%S(&-U<G)E;G0@<&%R
M96YT"B`@("`@("`@)'1H:7,M/G!A<F5N="`]("1P;W,["B`@("`@("`@)'%N
M86UE(#TF(&YE=R!13F%M92@D;F%M92D["B`@("`@("`@+R\@<V5T('-T871U
M<PH@("`@("`@(&EF("AS=')C87-E8VUP*"=E;G9E;&]P92<L("1Q;F%M92T^
M;F%M92D@/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@)V5N
M=F5L;W!E)SL*("`@("`@("!](&5L<V5I9B`H<W1R8V%S96-M<"@G:&5A9&5R
M)RP@)'%N86UE+3YN86UE*2`]/2`P*2!["B`@("`@("`@("`@("1T:&ES+3YS
M=&%T=7,@/2`G:&5A9&5R)SL*("`@("`@("`@("`@)'1H:7,M/FAE861E<E]S
M=')U8W1?;F%M95M=(#T@)'1H:7,M/F-U<F5N=%]R;V]T7W-T<G5C=%]N86UE
M(#T@)'%N86UE+3YN86UE.PH@("`@("`@("`@("`D=&AI<RT^:&5A9&5R7W-T
M<G5C=%M=(#T@)'1H:7,M/F-U<F5N=%]R;V]T7W-T<G5C="`]("1P;W,["B`@
M("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G4W1R
M=6-T)SL*("`@("`@("!](&5L<V5I9B`H<W1R8V%S96-M<"@G8F]D>2<L("1Q
M;F%M92T^;F%M92D@/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S
M(#T@)V)O9'DG.PH@("`@("`@("`@("`D=&AI<RT^8F]D>41E<'1H(#T@)'1H
M:7,M/F1E<'1H.PH*("`@("`@("`O+R!3970@;65T:&]D"B`@("`@("`@?2!E
M;'-E:68@*"1T:&ES+3YS=&%T=7,@/3T@)V)O9'DG*2!["B`@("`@("`@("`@
M("\O($ES('1H:7,@96QE;65N="!A;&QO=V5D('1O(&)E(&$@<F]O=#\*("`@
M("`@("`@("`@+R\@6%A8('1H:7,@;F5E9',@=&\@8F4@;W!T:6UI>F5D+"!W
M92!L;V]P('1H<F]U9V@@871T<G,@='=I8V4@;F]W+@H@("`@("`@("`@("`D
M8V%N7W)O;W0@/2`D=&AI<RT^9&5P=&@@/3T@)'1H:7,M/F)O9'E$97!T:"`K
M(#$["B`@("`@("`@("`@(&EF("@D8V%N7W)O;W0I('L*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1K97DL("<Z<F]O="<I("8F
M("$D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-A;E]R;V]T
M(#T@1D%,4T4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&-A;E]R;V]T
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@)VUE=&AO9"<[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<F]O=%]S=')U8W1?;F%M95M=(#T@
M)'1H:7,M/F-U<F5N=%]R;V]T7W-T<G5C=%]N86UE(#T@)'%N86UE+3YN86UE
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G)O;W1?<W1R=6-T6UT@/2`D=&AI
M<RT^8W5R96YT7W)O;W1?<W1R=6-T(#T@)'!O<SL*("`@("`@("`@("`@("`@
M("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G4W1R=6-T)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4V5T(&UY('-T871U
M<RX*("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG<W1A='5S)UT@/2`D
M=&AI<RT^<W1A='5S.PH*("`@("`@("`O+R!3970@;F%M92X*("`@("`@("`D
M=&AI<RT^;65S<V%G95LD<&]S75LG;F%M92==(#T@:'1M;'-P96-I86QC:&%R
M<R@D<6YA;64M/FYA;64I.PH*("`@("`@("`O+R!3970@871T<FEB=71E<RX*
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG871T<G,G72`]("1A='1R
M<SL*"B`@("`@("`@+R\@3&]O<"!T:')O=6=H(&%T=')I8G5T97,L(&QO9V=I
M;F<@;G,@86YD('1Y<&4@9&5C;&%R871I;VYS+@H@("`@("`@(&9O<F5A8V@@
M*"1A='1R<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`O+R!)
M9B!N<R!D96-L87)A=&EO;G,L(&%D9"!T;R!C;&%S<R!L979E;"!A<G)A>2!O
M9B!V86QI9`H@("`@("`@("`@("`O+R!N86UE<W!A8V5S+@H@("`@("`@("`@
M("`D:W%N(#TF(&YE=R!13F%M92@D:V5Y*3L*("`@("`@("`@("`@:68@*"1K
M<6XM/FYS(#T]("=X;6QN<R<I('L*("`@("`@("`@("`@("`@("1P<F5F:7@@
M/2`D:W%N+3YN86UE.PH*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D
M=F%L=64L("1T:&ES+3Y?6$U,4V-H96UA*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<V5T4V-H96UA5F5R<VEO;B@D=F%L=64I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F%M97-P86-E
M<ULD=F%L=65=(#T@)'!R969I>#L*"B`@("`@("`@("`@("\O(%-E="!M971H
M;V0@;F%M97-P86-E+@H@("`@("`@("`@("!](&5L<V5I9B`H)&ME>2`]/2`G
M>&UL;G,G*2!["B`@("`@("`@("`@("`@("`D<6YA;64M/FYS(#T@)'1H:7,M
M/E]G971.86UE<W!A8V50<F5F:7@H)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("1Q;F%M92T^;F%M97-P86-E(#T@)'9A;'5E.PH@("`@("`@("`@("!](&5L
M<V5I9B`H)&MQ;BT^;F%M92`]/2`G86-T;W(G*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;65S<V%G95LD<&]S75LG86-T;W(G72`]("1V86QU93L*("`@
M("`@("`@("`@?2!E;'-E:68@*"1K<6XM/FYA;64@/3T@)VUU<W15;F1E<G-T
M86YD)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)VUU<W15;F1E<G-T86YD)UT@/2`D=F%L=64["@H@("`@("`@("`@("`O+R!)
M9B!I="=S(&$@='EP92!D96-L87)A=&EO;BP@<V5T('1Y<&4N"B`@("`@("`@
M("`@('T@96QS96EF("@D:W%N+3YN86UE(#T]("=T>7!E)RD@>PH@("`@("`@
M("`@("`@("`@)'9Q;B`])B!N97<@44YA;64H)'9A;'5E*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`D=G%N+3YN
M86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y
M<&5?;F%M97-P86-E)UT@/2`D=&AI<RT^7V=E=$YA;65S<&%C949O<E!R969I
M>"@D=G%N+3YN<RD["B`@("`@("`@("`@("`@("`O+R!3:&]U;&0@9&\@<V]M
M971H:6YG(&AE<F4@=VET:"!T:&4@;F%M97-P86-E(&]F"B`@("`@("`@("`@
M("`@("`O+R!S<&5C:69I960@='EP93\*"B`@("`@("`@("`@('T@96QS96EF
M("@D:W%N+3YN86UE(#T]("=A<G)A>51Y<&4G*2!["B`@("`@("`@("`@("`@
M("`D=G%N(#TF(&YE=R!13F%M92@D=F%L=64I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&4G72`]("=!<G)A>2<["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'9Q;BT^87)R87E3:7IE*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>5-I
M>F4G72`]("1V<6XM/F%R<F%Y4VEZ93L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>51Y<&4G
M72`]("1V<6XM/FYA;64["@H@("`@("`@("`@("!](&5L<V5I9B`H)&MQ;BT^
M;F%M92`]/2`G;V9F<V5T)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE
M<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T)UT@/2!S<&QI="@G+"<L('-U8G-T
M<B@D=F%L=64L(#$L('-T<FQE;B@D=F%L=64I("T@,BDI.PH*("`@("`@("`@
M("`@?2!E;'-E:68@*"1K<6XM/FYA;64@/3T@)VED)RD@>PH@("`@("`@("`@
M("`@("`@+R\@4V%V92!I9"!T;R!R969E<F5N8V4@87)R87DN"B`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5F97)E;F-E<ULD=F%L=65=(#T@)'!O<SL*("`@
M("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=I9"==(#T@)'9A
M;'5E.PH*("`@("`@("`@("`@?2!E;'-E:68@*"1K<6XM/FYA;64@/3T@)VAR
M968G*2!["B`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6S!=(#T]("<C)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1R968@/2!S=6)S='(H)'9A;'5E+"`Q
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/G)E9F5R
M96YC97-;)')E9ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(&-D
M871A+"!T>7!E+"!I;G9A;"X*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M9E]P;W,@/2`D=&AI<RT^<F5F97)E;F-E<ULD<F5F73L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UT@
M/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C:&EL9')E;B==.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG8V1A
M=&$G72`]("8D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;)V-D871A)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T
M>7!E)UT@/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=T>7!E)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A
M<G)A>5-I>F4G72`]("8D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;)V%R<F%Y
M4VEZ92==.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G
M95LD<&]S75LG87)R87E4>7!E)UT@/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P
M;W-=6R=A<G)A>51Y<&4G73L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!2979E<G-E(')E9F5R96YC
M92P@<W1O<F4@:6X@)VYE960@<F5F97)E;F-E)RX*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^;F5E9%]R969E<F5N8V5S6R1R
M969=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FYE
M961?<F5F97)E;F-E<ULD<F5F72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FYE
M961?<F5F97)E;F-E<ULD<F5F75M=(#T@)'!O<SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M
M/F%T=&%C:&UE;G1S6R1V86QU95TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@/2`D=&AI<RT^871T86-H
M;65N='-;)'9A;'5E73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`O+R!3964@:68@;F%M97-P86-E(&ES(&1E
M9FEN960@:6X@=&%G+@H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=X
M;6QN<SHG("X@)'%N86UE+3YN<RP@)&%T=')S*2D@>PH@("`@("`@("`@("`D
M;F%M97-P86-E(#T@)&%T=')S6R=X;6QN<SHG("X@)'%N86UE+3YN<UT["B`@
M("`@("`@?2!E;'-E:68@*"1Q;F%M92T^;G,@)B8@(21Q;F%M92T^;F%M97-P
M86-E*2!["B`@("`@("`@("`@("1N86UE<W!A8V4@/2`D=&AI<RT^7V=E=$YA
M;65S<&%C949O<E!R969I>"@D<6YA;64M/FYS*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!'970@;F%M97-P86-E+@H@("`@("`@("`@("`D
M;F%M97-P86-E(#T@)'%N86UE+3YN86UE<W!A8V4@/R`D<6YA;64M/FYA;65S
M<&%C92`Z("1T:&ES+3YD969A=6QT7VYA;65S<&%C93L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)VYA;65S<&%C92==(#T@)&YA
M;65S<&%C93L*("`@("`@("`D=&AI<RT^9&5F875L=%]N86UE<W!A8V4@/2`D
M;F%M97-P86-E.PH@("`@?0H*("`@("\J*@H@("`@("H@96YD16QE;65N=`H@
M("`@("H@96YD+65L96UE;G0@:&%N9&QE<B!U<V5D('=I=&@@>&UL('!A<G-E
M<@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!E;F1%;&5M96YT*"1P87)S97(L("1N86UE*0H@("`@>PH@("`@
M("`@("\O(%!O<VET:6]N(&]F(&-U<G)E;G0@96QE;65N="!I<R!E<75A;"!T
M;R!T:&4@;&%S="!V86QU92!L969T"B`@("`@("`@+R\@:6X@9&5P=&A?87)R
M87D@9F]R(&UY(&1E<'1H+@H@("`@("`@("1P;W,@/2`D=&AI<RT^9&5P=&A?
M87)R87E;)'1H:7,M/F1E<'1H73L*"B`@("`@("`@+R\@0G)I;F<@9&5P=&@@
M9&]W;B!A(&YO=&-H+@H@("`@("`@("1T:&ES+3YD97!T:"TM.PH@("`@("`@
M("1Q;F%M92`])B!N97<@44YA;64H)&YA;64I.PH*("`@("`@("`O+R!'970@
M='EP92!I9B!N;W0@97AP;&EC:71L>2!D96-L87)E9"!I;B!A;B!X<VDZ='EP
M92!A='1R:6)U=&4N"B`@("`@("`@+R\@6%A8(&-H96-K(&]N(&EN=&5G<F%T
M:6YG('=S9&P@=F%L:61A=&EO;B!H97)E"B`@("`@("`@:68@*"1T:&ES+3YM
M97-S86=E6R1P;W-=6R=T>7!E)UT@/3T@)R<I('L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YM97-S86=E6R1P;W-=6R=C:&EL9')E;B==*2D@>PH@
M("`@("`@("`@("`@("`@+RH@=&AI<R!I<R!S;&]W+"!N965D('1O(&QO;VL@
M870@<V]M92!F87-T97(@;65T:&]D"B`@("`@("`@("`@("`@("`D8VAI;&1R
M96X@/2!E>'!L;V1E*"=\)RP@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD
M<F5N)UTI.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1C:&EL9')E;BD@
M/B`R("8F"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)&-H
M:6QD<F5N6S%=75LG;F%M92==(#T]("1T:&ES+3YM97-S86=E6R1C:&EL9')E
M;ELR75U;)VYA;64G72D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G
M95LD<&]S75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@("`@("!]
M*B\*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E
M)UT@/2`G4W1R=6-T)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1P87)E;G0@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG<&%R96YT
M)UT["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FUE<W-A9V5;)'!A<F5N
M=%U;)W1Y<&4G72`]/2`G07)R87DG("8F"B`@("`@("`@("`@("`@("`@(&%R
M<F%Y7VME>5]E>&ES=',H)V%R<F%Y5'EP92<L("1T:&ES+3YM97-S86=E6R1P
M87)E;G1=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=T>7!E)UT@/2`D=&AI<RT^;65S<V%G95LD<&%R96YT75LG87)R
M87E4>7!E)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G<W1R
M:6YG)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+R\@268@=&%G('=E(&%R92!C=7)R96YT;'D@8VQO<VEN
M9R!I<R!T:&4@;65T:&]D('=R87!P97(N"B`@("`@("`@:68@*"1P;W,@/3T@
M)'1H:7,M/F-U<F5N=%]R;V]T7W-T<G5C="D@>PH@("`@("`@("`@("`D=&AI
M<RT^<W1A='5S(#T@)V)O9'DG.PH@("`@("`@('T@96QS96EF("@D<6YA;64M
M/FYA;64@/3T@)T)O9'DG('Q\("1Q;F%M92T^;F%M92`]/2`G2&5A9&5R)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@)V5N=F5L;W!E)SL*("`@
M("`@("!]"@H@("`@("`@("\O(%-E="!P87)E;G0@8F%C:R!T;R!M>2!P87)E
M;G0N"B`@("`@("`@)'1H:7,M/G!A<F5N="`]("1T:&ES+3YM97-S86=E6R1P
M;W-=6R=P87)E;G0G73L*"B`@("`@("`@+R\@2&%N9&QE(&%N>2!R979E<G-E
M(')E9F5R96YC97,@;F]W+@H@("`@("`@("1I9')E9B`]("1T:&ES+3YM97-S
M86=E6R1P;W-=6R=I9"==.PH*("`@("`@("!I9B`H)&ED<F5F("$]("<G("8F
M(&%R<F%Y7VME>5]E>&ES=',H)&ED<F5F+"`D=&AI<RT^;F5E9%]R969E<F5N
M8V5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;F5E9%]R969E
M<F5N8V5S6R1I9')E9ET@87,@)')E9E]P;W,I('L*("`@("`@("`@("`@("`@
M("\O(%A86"!I<R!T:&ES('-T=69F('1H97)E(&%L<F5A9'D_"B`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;)V-H:6QD<F5N)UT@
M/2`F)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UT["B`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;)V-D871A)UT@/2`F
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;)W1Y<&4G72`]("8D=&AI<RT^
M;65S<V%G95LD<&]S75LG='EP92==.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)')E9E]P;W-=6R=A<G)A>5-I>F4G72`]("8D=&AI<RT^;65S
M<V%G95LD<&]S75LG87)R87E3:7IE)UT["B`@("`@("`@("`@("`@("`D=&AI
M<RT^;65S<V%G95LD<F5F7W!O<UU;)V%R<F%Y5'EP92==(#T@)B1T:&ES+3YM
M97-S86=E6R1P;W-=6R=A<G)A>51Y<&4G73L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(&-H87)A8W1E<D1A=&$*("`@
M("`J(&5L96UE;G0@8V]N=&5N="!H86YD;&5R('5S960@=VET:"!X;6P@<&%R
M<V5R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-H87)A8W1E<D1A=&$H)'!A<G-E<BP@)&1A=&$I"B`@("![
M"B`@("`@("`@)'!O<R`]("1T:&ES+3YD97!T:%]A<G)A>5LD=&AI<RT^9&5P
M=&A=.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65S<V%G95LD<&]S75LG
M8V1A=&$G72DI('L*("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)V-D871A)UT@+CT@)&1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@/2`D9&%T83L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!G971297-P;VYS90H@("`@
M("H*("`@("`J(')E='5R;G,@86X@87)R87D@;V8@<F5S<&]N<V5S"B`@("`@
M*B!A9G1E<B!P87)S:6YG(&$@<V]A<"!M97-S86=E+"!U<V4@=&AI<R!T;R!G
M970@=&AE(')E<W!O;G-E"B`@("`@*@H@("`@("H@0')E='5R;B`@(&%R<F%Y
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T4F5S<&]N<V4H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M<F]O=%]S=')U8W1;,%TI("8F"B`@("`@("`@("`@("1T:&ES+3YR;V]T7W-T
M<G5C=%LP72D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F)U:6QD4F5S
M<&]N<V4H)'1H:7,M/G)O;W1?<W1R=6-T6S!=*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(F-O=6QD;B=T(&)U
M:6QD(')E<W!O;G-E(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!G971(96%D
M97)S"B`@("`@*@H@("`@("H@<F5T=7)N<R!A;B!A<G)A>2!O9B!H96%D97(@
M<F5S<&]N<V5S"B`@("`@*B!A9G1E<B!P87)S:6YG(&$@<V]A<"!M97-S86=E
M+"!U<V4@=&AI<R!T;R!G970@=&AE(')E<W!O;G-E"B`@("`@*@H@("`@("H@
M0')E='5R;B`@(&%R<F%Y"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B`F9V5T2&5A9&5R<R@I"B`@("!["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YH96%D97)?<W1R=6-T6S!=*2`F)@H@("`@("`@("`@
M("`D=&AI<RT^:&5A9&5R7W-T<G5C=%LP72D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F)U:6QD4F5S<&]N<V4H)'1H:7,M/FAE861E<E]S=')U8W1;
M,%TI.PH@("`@("`@('T*"B`@("`@("`@+R\@5V4@9&]N)W0@9F%U;'0@:68@
M=&AE<F4@87)E(&YO(&AE861E<G,@=&AA="!C86X@8F4@:&%N9&QE9`H@("`@
M("`@("\O(&)Y('1H92!A<'`@:68@;F5C97-S87)Y+@H@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@9&5C;V1E16YT:71I97,*
M("`@("`J"B`@("`@*B!R96UO=F5S(&5N=&ET:65S(&9R;VT@=&5X=`H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<*("`@("`J($!R971U<FX@("!S=')I
M;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96-O9&5%;G1I=&EE<R@D=&5X="D*("`@('L*("`@("`@("`D=')A;G-?
M=&)L(#T@87)R87E?9FQI<"@D=&AI<RT^96YT:71I97,I.PH@("`@("`@(')E
M='5R;B!S=')T<B@D=&5X="P@)'1R86YS7W1B;"D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O1&%T92\`````````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$V,C(Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]$871E+TAU;6%N+G!H<```````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S0V-``Q,#4Q-30S,3`U
M-P`P,C`P,3,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S
M:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*+R\*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#4@06QL86X@2V5N="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS
M92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H
M("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@
M?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@06QL86X@2V5N="`\86QL86Y`
M;&]D97-T;VYE+F-O+GIA/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HO*BH*("H@0VQA<W,@
M=&\@8V]N=F5R="!D871E('-T<FEN9W,@8F5T=V5E;B!'<F5G;W)I86X@86YD
M($AU;6%N(&-A;&5N9&%R(&9O<FUA=',*("H*("H@5&AE($AU;6%N($-A;&5N
M9&%R(&9O<FUA="!H87,@8F5E;B!P<F]P;W-E9"!B>2!38V]T="!&;&%N<V)U
M<F<@86YD(&-A;B!B90H@*B!E>'!L86EN960@87,@9F]L;&]W<SH*("H@(%1H
M92!Y96%R(&ES(&UA9&4@=7`@;V8@,3,@;6]N=&AS"B`J("!%86-H(&UO;G1H
M(&AA<R`R."!D87ES"B`J("!#;W5N=&EN9R!O9B!M;VYT:',@<W1A<G1S(&9R
M;VT@,"`H>F5R;RD@<V\@=&AE(&UO;G1H<R!W:6QL(')U;B!F<F]M(#`@=&\@
M,3(*("H@($YE=R!996%R<R!D87D@*#`P*2!I<R!A(&UO;G1H;&5S<R!D87D*
M("H@($YO=&4Z($QE87`@665A<G,@87)E(&YO="!Y970@86-C;W5N=&5D(&9O
M<B!I;B!T:&4@2'5M86X@0V%L96YD87(@<WES=&5M"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($!C871E9V]R>2`@($1A=&4@86YD(%1I;64*
M("H@0'!A8VMA9V4@("`@1&%T90H@*B!`875T:&]R("`@("!!;&QA;B!+96YT
M(#QA;&QA;D!L;V1E<W1O;F4N8V\N>F$^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!!;&QA;B!+96YT"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E
M;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!.97<@0E-$
M($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($AU;6%N+G!H<"QV
M(#$N-2`R,#`U+S$Q+S$U(#`P.C$V.C0P('!A:F]Y92!%>'`@)`H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`
M<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,PH@
M*B\*"B\J*@H@*B!#;&%S<R!T;R!C;VYV97)T(&1A=&4@<W1R:6YG<R!B971W
M965N($=R96=O<FEA;B!A;F0@2'5M86X@8V%L96YD87(@9F]R;6%T<PH@*@H@
M*B!4:&4@2'5M86X@0V%L96YD87(@9F]R;6%T(&AA<R!B965N('!R;W!O<V5D
M(&)Y(%-C;W1T($9L86YS8G5R9R!A;F0@8V%N(&)E"B`J(&5X<&QA:6YE9"!A
M<R!F;VQL;W=S.@H@*B`@5&AE('EE87(@:7,@;6%D92!U<"!O9B`Q,R!M;VYT
M:',*("H@($5A8V@@;6]N=&@@:&%S(#(X(&1A>7,*("H@($-O=6YT:6YG(&]F
M(&UO;G1H<R!S=&%R=',@9G)O;2`P("AZ97)O*2!S;R!T:&4@;6]N=&AS('=I
M;&P@<G5N(&9R;VT@,"!T;R`Q,@H@*B`@3F5W(%EE87)S(&1A>2`H,#`I(&ES
M(&$@;6]N=&AL97-S(&1A>0H@*B`@3F]T93H@3&5A<"!996%R<R!A<F4@;F]T
M('EE="!A8V-O=6YT960@9F]R(&EN('1H92!(=6UA;B!#86QE;F1A<B!S>7-T
M96T*("H*("H@0&%U=&AO<B`@("`@06QL86X@2V5N="`\86QL86Y`;&]D97-T
M;VYE+F-O+GIA/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@06QL86X@2V5N
M=`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W($)31"!,:6-E;G-E"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XV"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,PH@*B\*8VQA<W,@1&%T
M95](=6UA;@I["B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I871I
M=F4@87)R87D@8V]N=&%I;FEN9R!T:&4@8V]N=F5R=&5D(&1A=&4@:6YF;W)M
M871I;VX*("`@("`J(&EN("=(=6UA;B!#86QE;F1A<B<@9F]R;6%T+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G0@9&%Y(&EN($1$(&9O<FUA="P@9&5F875L
M="!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="!M;VYT:"!I
M;B!-32!F;W)M870L(&1E9F%U;'0@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="!Y96%R(&EN($-#65D@9F]R;6%T+"!D969A=6QT('1O
M(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!A<W-O8VEA=&EV92!A<G)A>2@*
M("`@("`J("`@("`@("`@("`@("`@:&1O;2P@("`@("`@+R\@2'5M86X@1&%Y
M($]F($UO;G1H+"!S=&%R=&EN9R!A="`Q"B`@("`@*B`@("`@("`@("`@("`@
M(&AD;W<L("`@("`@("\O($AU;6%N($1A>2!/9B!7965K+"!S=&%R=&EN9R!A
M="`Q"B`@("`@*B`@("`@("`@("`@("`@(&AW;VTL("`@("`@("\O($AU;6%N
M(%=E96L@;V8@36]N=&@L('-T87)T:6YG(&%T(#$*("`@("`J("`@("`@("`@
M("`@("`@:'=O>2P@("`@("`@+R\@2'5M86X@5V5E:R!O9B!996%R+"!S=&%R
M=&EN9R!A="`Q"B`@("`@*B`@("`@("`@("`@("`@(&AM;WDL("`@("`@("\O
M($AU;6%N($UO;G1H(&]F(%EE87(L('-T87)T:6YG(&%T(#`*("`@("`J("`@
M("`@("`@("`@("`@*0H@("`@("H*("`@("`J($EF('1H92!D87D@:7,@3F5W
M(%EE87)S($1A>2P@=&AE(&9U;F-T:6]N('=I;&P@<F5T=7)N"B`@("`@*B`B
M:&1O;2(@/3X@(#`*("`@("`J(")H9&]W(B`]/B`@,`H@("`@("H@(FAW;VTB
M(#T^("`P"B`@("`@*B`B:'=O>2(@/3X@(#`*("`@("`J(")H;6]Y(B`]/B`M
M,0H@("`@("H@(%-I;F-E(#`@:7,@82!V86QI9"!M;VYT:"!N=6UB97(@=6YD
M97(@=&AE($AU;6%N($-A;&5N9&%R+"!)(&AA=F4@;&5F=`H@("`@("H@('1H
M92!M;VYT:"!A<R`M,2!F;W(@3F5W(%EE87)S($1A>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9W)E9V]R:6%N5&](=6UA;B@D9&%Y/3`L("1M;VYT:#TP+"`D
M>65A<CTP*0H@("`@>PH@("`@("`@("\J"B`@("`@("`@("H@0VAE8VL@=&\@
M<V5E(&EF(&%N>2!O9B!T:&4@87)G=6UE;G1S(&%R92!E;7!T>0H@("`@("`@
M("`J($EF('1H97D@87)E('1H96X@<&]P=6QA=&4@=&AE("1D871E:6YF;R!A
M<G)A>0H@("`@("`@("`J(%1H96X@8VAE8VL@=&\@<V5E('=H:6-H(&%R9W5M
M96YT<R!A<F4@96UP='D@86YD(&9I;&P*("`@("`@("`@*B!T:&]S92!W:71H
M('1H92!C=7)R96YT(&1A=&4@:6YF;PH@("`@("`@("`J+PH@("`@("`@(&EF
M("@H96UP='DH)&1A>2D@?'P@*&5M<'1Y*"1M;VYT:"DI('Q\(&5M<'1Y*"1Y
M96%R*2DI('L*("`@("`@("`@("`@)&1A=&5I;F9O(#T@9V5T9&%T92AT:6UE
M*"DI.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@
M("`@("`@("`@)&1A>2`]("1D871E:6YF;ULB;61A>2)=.PH@("`@("`@('T*
M("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N
M=&@@/2`D9&%T96EN9F];(FUO;B)=.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@)&1A=&5I;F9O
M6R)Y96%R(ET["B`@("`@("`@?0H@("`@("`@("\J"B`@("`@("`@("H@5V4@
M;F5E9"!T;R!K;F]W(&AO=R!M86YY(&1A>7,@:6YT;R!T:&4@>65A<B!W92!A
M<F4*("`@("`@("`@*B\*("`@("`@("`D9&%T96EN9F\@/2!G971D871E*&UK
M=&EM92@P+"`P+"`P+"`D;6]N=&@L("1D87DL("1Y96%R*2D["B`@("`@("`@
M)&1A>6]F>65A<B`]("1D871E:6YF;ULB>61A>2)=.PH@("`@("`@("\J"B`@
M("`@("`@("H@2'5M86X@0V%L96YD87(@<W1A<G1S(&%T(#`@9F]R(&UO;G1H
M<R!A;F0@=&AE(&9I<G-T(&1A>2!O9B!T:&4@>65A<@H@("`@("`@("`J(&ES
M(&1E<VEG;F%T960@,#`L('-O('=E(&YE960@=&\@<W1A<G0@;W5R(&1A>2!O
M9B!T:&4@>65A<B!A="`P(&9O<@H@("`@("`@("`J('1H97-E(&-A;&-U;&%T
M:6]N<RX*("`@("`@("`@*B!!;'-O+"!T:&4@9&%Y(&]F('1H92!M;VYT:"!I
M<R!C86QC=6QA=&5D('=I=&@@82!M;V1U;'5S(&]F(#(X+@H@("`@("`@("`J
M($)E8V%U<V4@82!D87D@:7,@,C@@9&%Y<RP@=&AE(&QA<W0@9&%Y(&]F('1H
M92!M;VYT:"!W;W5L9"!H879E(&$*("`@("`@("`@*B!R96UA:6YD97(@;V8@
M,"!A;F0@;F]T(#(X(&%S(&ET('-H;W5L9"!B92X@($1E8W)E;65N=&EN9R`D
M9&%Y;V9Y96%R"B`@("`@("`@("H@9V5T<R!A<F]U;F0@=&AI<RX*("`@("`@
M("`@*B\*("`@("`@("`D9&%Y;V9Y96%R+2T["B`@("`@("`@+RH*("`@("`@
M("`@*B`R."!D87ES(&EN(&$@;6]N=&@N+BX*("`@("`@("`@*B\*("`@("`@
M("`D:'5M86Y-;VYT:$]F665A<B`](&9L;V]R*"1D87EO9GEE87(@+R`R."D[
M"B`@("`@("`@+RH*("`@("`@("`@*B!)9B!W92!A<F4@:6X@=&AE(&9I<G-T
M(&UO;G1H('1H96X@=&AE(&1A>2!O9B!T:&4@;6]N=&@@:7,@)&1A>6]F>65A
M<@H@("`@("`@("`J(&5L<V4@=V4@;F5E9"!T;R!F:6YD('1H92!M;V1U;'5S
M(&]F(#(X+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D:'5M86Y-;VYT:$]F
M665A<B`]/2`P*2!["B`@("`@("`@("`@("1H=6UA;D1A>4]F36]N=&@@/2`D
M9&%Y;V9Y96%R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H=6UA
M;D1A>4]F36]N=&@@/2`H)&1A>6]F>65A<BD@)2`R.#L*("`@("`@("!]"B`@
M("`@("`@+RH*("`@("`@("`@*B!$87D@;V8@=&AE('=E96L@:7,@;6]D=6QU
M<R`W"B`@("`@("`@("HO"B`@("`@("`@)&AU;6%N1&%Y3V97965K(#T@)&1A
M>6]F>65A<B`E(#<["B`@("`@("`@+RH*("`@("`@("`@*B!792!C86X@;F]W
M(&EN8W)E;65N="`D9&%Y;V9Y96%R(&)A8VL@=&\@:70G<R!C;W)R96-T('9A
M;'5E(&9O<@H@("`@("`@("`J('1H92!R96UA:6YD97(@;V8@=&AE(&-A;&-U
M;&%T:6]N<PH@("`@("`@("`J+PH@("`@("`@("1D87EO9GEE87(K*SL*("`@
M("`@("`O*@H@("`@("`@("`J("1H=6UA;D1A>4]F36]N=&@@;F5E9',@=&\@
M8F4@:6YC<F5M96YT960@;F]W("T@<F5C86QL('1H870@=V4@9G5D9V5D"B`@
M("`@("`@("H@:70@82!B:70@8GD@9&5C<F5M96YT:6YG("1D87EO9GEE87(@
M96%R;&EE<@H@("`@("`@("`J(%-A;64@9V]E<R!F;W(@)&AU;6%N1&%Y3V97
M965K"B`@("`@("`@("HO"B`@("`@("`@)&AU;6%N1&%Y3V9-;VYT:"LK.PH@
M("`@("`@("1H=6UA;D1A>4]F5V5E:RLK.PH@("`@("`@("\J"B`@("`@("`@
M("H@5V5E:R!O9B!T:&4@;6]N=&@@:7,@9&%Y(&]F('1H92!M;VYT:"!D:79I
M9&5D(&)Y(#<L(')O=6YD960@=7`*("`@("`@("`@*B!386UE(&9O<B!W965K
M(&]F('1H92!Y96%R+"!B=70@=7-E("1D87EO9GEE87(@:6YS=&5A9"`D:'5M
M86Y$87E/9DUO;G1H"B`@("`@("`@("HO"B`@("`@("`@)&AU;6%N5V5E:T]F
M36]N=&@@/2!C96EL*"1H=6UA;D1A>4]F36]N=&@@+R`W*3L*("`@("`@("`D
M:'5M86Y7965K3V9996%R(#T@8V5I;"@D9&%Y;V9Y96%R("\@-RD["B`@("`@
M("`@+RH*("`@("`@("`@*B!2971U<FX@86X@87-S;V-I871I=F4@87)R87D@
M;V8@=&AE('9A;'5E<PH@("`@("`@("`J+PH@("`@("`@(')E='5R;B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@(FAD;VTB(#T^("1H=6UA;D1A>4]F
M36]N=&@L"B`@("`@("`@("`@("`@("`@("`@(")H9&]W(B`]/B`D:'5M86Y$
M87E/9E=E96LL"B`@("`@("`@("`@("`@("`@("`@(")H=V]M(B`]/B`D:'5M
M86Y7965K3V9-;VYT:"P*("`@("`@("`@("`@("`@("`@("`@(FAW;WDB(#T^
M("1H=6UA;E=E96M/9EEE87(L"B`@("`@("`@("`@("`@("`@("`@(")H;6]Y
M(B`]/B`D:'5M86Y-;VYT:$]F665A<B`I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!U;FEX('1I;65S=&%M<"!F;W(@82!G:79E;B!(=6UA;B!#
M86QE;F1A<B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="!D87D@:6X@
M1$0@9F]R;6%T"B`@("`@*B!`<&%R86T@:6YT(&UO;G1H(&EN($U-(&9O<FUA
M=`H@("`@("H@0'!A<F%M(&EN="!Y96%R(&EN($-#65D@9F]R;6%T+"!D969A
M=6QT('1O(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@=6YI>"!T:6UE
M<W1A;7`@;V8@9&%T90H@("`@("HO"B`@("!F=6YC=&EO;B!(=6UA;E1O1W)E
M9V]R:6%N*"1D87DL("1M;VYT:"P@)'EE87(],"D*("`@('L*("`@("`@("`O
M*@H@("`@("`@("`J($-H96-K('1O('-E92!I9B!T:&4@>65A<B!H87,@8F5E
M;B!P87-S960@=&AR;W5G:"X*("`@("`@("`@*B!)9B!N;W0@9V5T(&-U<G)E
M;G0@>65A<@H@("`@("`@("`J+PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI
M('L*("`@("`@("`@("`@)&1A=&5I;F9O(#T@9V5T9&%T92AT:6UE*"DI.PH@
M("`@("`@("`@("`D>65A<B`]("1D871E:6YF;ULB>65A<B)=.PH@("`@("`@
M('T*("`@("`@("`O*@H@("`@("`@("`J(%=E(&YE960@=&\@9V5T('1H92!D
M87D@;V8@=&AE('EE87(@=&AA="!W92!A<F4@8W5R<F5N=&QY(&%T('-O('1H
M870*("`@("`@("`@*B!W92!C86X@=V]R:R!O=70@=&AE($=R96=O<FEA;B!-
M;VYT:"!A;F0@9&%Y"B`@("`@("`@("HO"B`@("`@("`@)$1A>4]F665A<B`]
M("1M;VYT:"`J(#(X.PH@("`@("`@("1$87E/9EEE87(@*ST@)&1A>3L*("`@
M("`@("`O*@H@("`@("`@("`J($AU;6%N($-A;&5N9&%R('-T87)T<R!A="`P
M+"!S;R!W92!N965D('1O(&EN8W)E;65N="`D1&%Y3V9996%R"B`@("`@("`@
M("H@=&\@=&%K92!I;G1O(&%C8V]U;G0@=&AE(&1A>2`P,`H@("`@("`@("`J
M+PH@("`@("`@("1$87E/9EEE87(K*SL*("`@("`@("`O*@H@("`@("`@("`J
M('1H92!M:W1I;64H*2!F=6YC=&EO;B!W:6QL(&-O<G)E8W1L>2!C86QC=6QA
M=&4@=&AE(&1A=&4@9F]R(&]U="!O9@H@("`@("`@("`J(')A;F=E('9A;'5E
M<RP@<V\@<'5T=&EN9R`D1&%Y3V9996%R(&EN<W1E860@;V8@=&AE(&1A>2!O
M9B!T:&4@;6]N=&@*("`@("`@("`@*B!W:6QL('=O<FL@9FEN92X*("`@("`@
M("`@*B\*("`@("`@("`D1W)E9V]R:6%N5&EM95-T86UP(#T@;6MT:6UE*#`L
M(#`L(#`L(#$L("1$87E/9EEE87(L("1Y96%R*3L*("`@("`@("!R971U<FX@
M)$=R96=O<FEA;E1I;653=&%M<#L*("`@('T*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1&%T92]3
M<&%N+G!H<```````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-S4U-#$`,3`U,34T,S$P-3<`,#$W-C0T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z
M("HO"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`U("!,96%N9')O($QU8V%R96QL82P@4&EE
M<G)E+4%L86EN($IO>64@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE9"`@?`HO+R!\
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@=V]R;&0M=VED
M92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!N97<@
M0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@?"!T;R!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES=',N<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z
M($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("!0:65R<F4M06QA:6X@
M2F]Y92`\<&%J;WEE0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"B\J*@H@*B!'
M96YE<FEC('1I;64@<W!A;B!H86YD;&EN9R!C;&%S<R!F;W(@4$5!4@H@*@H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!`8V%T96=O<GD@("!$871E
M(&%N9"!4:6UE"B`J($!P86-K86=E("`@($1A=&4*("H@0&%U=&AO<B`@("`@
M3&5A;F1R;R!,=6-A<F5L;&$@/&QL=6-A>$!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J;WEE0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!,96%N9')O($QU8V%R96QL82P@4&EE<G)E
M+4%L86EN($IO>64*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U
M<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC
M96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4W!A;BYP:'`L=B`Q+C@@
M,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1A=&4*("H@0'-I;F-E
M("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0*("HO"@HO
M*BH*("H@1V5T('1H92!$871E(&-L87-S"B`J+PIR97%U:7)E7V]N8V4@)T1A
M=&4N<&AP)SL*"B\J*@H@*B!'970@=&AE($1A=&5?0V%L8R!C;&%S<PH@*B\*
M<F5Q=6ER95]O;F-E("=$871E+T-A;&,N<&AP)SL*"B\J*@H@*B!.;VX@3G5M
M97)I8R!397!A<F%T960@5F%L=65S("A.3E-6*2!);G!U="!&;W)M870N"B`J
M"B`J($EN<'5T(&9O<FUA="!G=65S<V5D(&9R;VT@<V]M971H:6YG(&QI:V4@
M=&AI<SH*("H@9&%Y<SQS97`^:&]U<G,\<V5P/FUI;G5T97,\<V5P/G-E8V]N
M9',*("H@5VAE<F4@/'-E<#X@:7,@86YY('%U86YT:71Y(&]F(&YO;B!N=6UE
M<FEC(&-H87)S+B!)9B!N;R!V86QU97,@87)E"B`J(&=I=F5N+"!T:6UE('-P
M86X@:7,@<V5T('1O('IE<F\L(&EF(&]N92!V86QU92!I<R!G:79E;BP@:70G
M<R!U<V5D(&9O<@H@*B!H;W5R<RP@:68@='=O('9A;'5E<R!A<F4@9VEV96X@
M:70G<R!U<V5D(&9O<B!H;W5R<R!A;F0@;6EN=71E<R!A;F0@:68*("H@=&AR
M964@=F%L=65S(&%R92!G:79E;BP@:70G<R!U<V5D(&9O<B!H;W5R<RP@;6EN
M=71E<R!A;F0@<V5C;VYD<RX\8G(^"B`J($5X86UP;&5S.CQB<CX*("H@)R<@
M("`@("`@("`@("`@("`@("`@+3X@,"P@,"P@,"P@,"`H9&%Y<RP@:&]U<G,L
M(&UI;G5T97,L('-E8V]N9',I/&)R/@H@*B`G,3(G("`@("`@("`@("`@("`@
M("`M/B`P+"`Q,BP@,"P@,`H@*B`G,3(N,S`G("`@("`@("`@("`@("`M/B`P
M+"`Q,BP@,S`L(#`\8G(^"B`J("<Q,CHS,#HQ."<@("`@("`@("`@("T^(#`L
M(#$R+"`S,"P@,3@\8G(^"B`J("<S+3$R+3,P+3$X)R`@("`@("`@("T^(#,L
M(#$R+"`S,"P@,3@\8G(^"B`J("<S(&1A>7,L(#$R+3,P+3$X)R`@("T^(#,L
M(#$R+"`S,"P@,3@\8G(^"B`J("<Q,CHS,"!W:71H(#$X('-E8W,G("T^(#`L
M(#$R+"`S,"P@,3@\8G(^"B`J"B`J($!C;VYS="!I;G0*("HO"F1E9FEN92@G
M1$%415]34$%.7TE.4%547T9/4DU!5%].3E-6)RP@,2D["@HO*BH*("H@1&5F
M875L="!T:6UE(&9O<FUA="!W:&5N(&-O;G9E<G1I;F<@=&\@82!S=')I;F<N
M"B`J"B`J($!G;&]B86P@<W1R:6YG"B`J+PHD1TQ/0D%,4ULG7T1!5$5?4U!!
M3E]&3U)-050G72`@/2`G)4,G.PH*+RHJ"B`J($1E9F%U;'0@=&EM92!F;W)M
M870@=VAE;B!C;VYV97)T:6YG(&9R;VT@82!S=')I;F<N"B`J"B`J($!G;&]B
M86P@;6EX960*("HO"B1'3$]"04Q36R=?1$%415]34$%.7TE.4%547T9/4DU!
M5"==(#T@1$%415]34$%.7TE.4%547T9/4DU!5%].3E-6.PH*+RHJ"B`J($=E
M;F5R:6,@=&EM92!S<&%N(&AA;F1L:6YG(&-L87-S(&9O<B!014%2"B`J"B`J
M($!A=71H;W(@("`@($QE86YD<F\@3'5C87)E;&QA(#QL;'5C87A`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0*("H*("H@0'1O9&\@("`@("`@
M1V5T(&%N9"!S970@9&5F875L="!L;V-A;"!I;G!U="!A;F0@;W5T<'5T(&9O
M<FUA=',_"B`J+PIC;&%S<R!$871E7U-P86X@>PH*("`@("\J*@H@("`@("H@
M0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1D87D["@H@("`@+RHJ"B`@("`@
M*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&AO=7(["@H@("`@+RHJ"B`@
M("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&UI;G5T93L*"B`@("`O
M*BH*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D<V5C;VYD.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0W)E
M871E<R!T:&4@=&EM92!S<&%N(&]B:F5C="!C86QL:6YG('1H92!S970H*2!M
M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`D=&EM92`@(%1I
M;64@<W!A;B!E>'!R97-S:6]N+@H@("`@("H@0'!A<F%M("!M:7AE9"`D9F]R
M;6%T($9O<FUA="!S=')I;F<@=&\@<V5T(&ET(&9R;VT@82!S=')I;F<@;W(@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V5C;VYD(&1A=&4@
M<V5T(&ET(&9R;VT@82!D871E(&1I9F8N"B`@("`@*@H@("`@("H@0'-E92`@
M("!S970H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@1&%T95]3<&%N*"1T:6UE(#T@,"P@)&9O<FUA="`](&YU;&PI"B`@
M("!["B`@("`@("`@)'1H:7,M/G-E="@D=&EM92P@)&9O<FUA="D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@<W!A;B!T;R!A(&YE=R!V
M86QU92!I;B!A("=S;6%R="<@=V%Y+@H@("`@("H*("`@("`J(%-E=',@=&AE
M('1I;64@<W!A;B!D97!E;F1I;F<@;VX@=&AE(&%R9W5M96YT('1Y<&5S+"!C
M86QL:6YG"B`@("`@*B!T;R!T:&4@87!P<F]P<FEA=&4@<V5T1G)O;5AX>"@I
M(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D("1T:6UE("`@
M5&EM92!S<&%N(&5X<')E<W-I;VXN"B`@("`@*B!`<&%R86T@(&UI>&5D("1F
M;W)M870@1F]R;6%T('-T<FEN9R!T;R!S970@:70@9G)O;2!A('-T<FEN9R!O
M<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S96-O;F0@9&%T
M92!S970@:70@9G)O;2!A(&1A=&4@9&EF9BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VP@('1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@*B!`<V5E
M("`@('-E=$9R;VU/8FIE8W0H*0H@("`@("H@0'-E92`@("!S971&<F]M07)R
M87DH*0H@("`@("H@0'-E92`@("!S971&<F]M4W1R:6YG*"D*("`@("`J($!S
M964@("`@<V5T1G)O;5-E8V]N9',H*0H@("`@("H@0'-E92`@("!S971&<F]M
M1&%T941I9F8H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T*"1T:6UE(#T@,"P@)&9O<FUA="`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7V$H)'1I;64L("=D871E7W-P86XG*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F-O<'DH)'1I;64I.PH@("`@("`@('T@
M96QS96EF("AI<U]A*"1T:6UE+"`G9&%T92<I(&%N9"!I<U]A*"1F;W)M870L
M("=D871E)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M
M1&%T941I9F8H)'1I;64L("1F;W)M870I.PH@("`@("`@('T@96QS96EF("AI
M<U]A<G)A>2@D=&EM92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS
M971&<F]M07)R87DH)'1I;64I.PH@("`@("`@('T@96QS96EF("AI<U]S=')I
M;F<H)'1I;64I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O
M;5-T<FEN9R@D=&EM92P@)&9O<FUA="D["B`@("`@("`@?2!E;'-E:68@*&ES
M7VEN="@D=&EM92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971&
M<F]M4V5C;VYD<R@D=&EM92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971&<F]M4V5C;VYD<R@P*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@<W!A;B!F<F]M
M(&%N(&%R<F%Y+@H@("`@("H*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R
M;VT@86X@87)R87DN($%N>2!V86QU92!C86X@8F4@82!F;&]A="`H8G5T(&ET
M"B`@("`@*B!H87,@;F\@<V5N<V4@:6X@<V5C;VYD<RDL(&9O<B!E>&%M<&QE
M(&%R<F%Y*#(S+C4L(#(P+"`P*2!I<PH@("`@("H@:6YT97)P<F5T960@87,@
M,C,@:&]U<G,L("XU*C8P("L@,C`@/2`U,"!M:6YU=&5S(&%N9"`P('-E8V]N
M9',N"B`@("`@*@H@("`@("H@0'!A<F%M("!A<G)A>2`D=&EM92!)=&5M<R!A
M<F4@8V]U;G1E9"!F<F]M(')I9VAT('1O(&QE9G0N($9I<G-T"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@(&ET96T@:7,@9F]R('-E8V]N9',L('-E8V]N
M9"!F;W(@;6EN=71E<RP@=&AI<F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@9F]R(&AO=7)S(&%N9"!F;W5R=&@@9F]R(&1A>7,N($EF('1H97)E(&%R
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("!L97-S(&ET96US('1H86X@
M-"P@>F5R;R`H,"D@:7,@87-S=6UE9"!F;W(@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@(&%B<V5N="!V86QU97,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L("!4<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1G)O;4%R<F%Y
M*"1T:6UE*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)'1I;64I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M)'1M<#$@/2!N97<@1&%T95]3<&%N.PH@("`@("`@(&EF("@A)'1M<#$M/G-E
M=$9R;VU396-O;F1S*$!A<G)A>5]P;W`H)'1I;64I*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T;7`R(#T@;F5W
M($1A=&5?4W!A;CL*("`@("`@("!I9B`H(21T;7`R+3YS971&<F]M36EN=71E
M<RA`87)R87E?<&]P*"1T:6UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D=&UP,2T^861D*"1T;7`R*3L*("`@
M("`@("!I9B`H(21T;7`R+3YS971&<F]M2&]U<G,H0&%R<F%Y7W!O<"@D=&EM
M92DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@)'1M<#$M/F%D9"@D=&UP,BD["B`@("`@("`@:68@*"$D=&UP,BT^
M<V5T1G)O;41A>7,H0&%R<F%Y7W!O<"@D=&EM92DI*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)'1M<#$M/F%D9"@D
M=&UP,BD["B`@("`@("`@<F5T=7)N("1T:&ES+3YC;W!Y*"1T;7`Q*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!S
M=')I;F<@8F%S960@;VX@86X@:6YP=70@9F]R;6%T+@H@("`@("H*("`@("`J
M(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!S=')I;F<@8F%S960@;VX@86X@
M:6YP=70@9F]R;6%T+B!4:&ES(&ES"B`@("`@*B!S;VUE(&QI:V4@82!M:7@@
M;V8@9F]R;6%T*"D@;65T:&]D(&%N9"!S<V-A;F8H*2!02%`@9G5N8W1I;VXN
M(%1H90H@("`@("H@97)R;W(@8VAE8VMI;F<@86YD('9A;&ED871I;VX@;V8@
M=&AI<R!F=6YC=&EO;B!I<R!V97)Y('!R:6UI=&EV92P*("`@("`J('-O('EO
M=2!S:&]U;&0@8F4@8V%R969U;&P@=VAE;B!U<VEN9R!I="!W:71H('5N:VYO
M=VX@)'1I;64@<W1R:6YG<RX*("`@("`J(%=I=&@@=&AI<R!M971H;V0@>6]U
M(&%R92!A<W-I9VYI;F<@9&%Y+"!H;W5R+"!M:6YU=&4@86YD('-E8V]N9`H@
M("`@("H@=F%L=65S+"!A;F0@=&AE(&QA<W0@=F%L=65S(&%R92!U<V5D+B!4
M:&ES(&UE86YS('1H870@:68@>6]U('5S90H@("`@("H@<V]M971H:6YG(&QI
M:V4@<V5T1G)O;5-T<FEN9R@G,3`L(#(P)RP@)R5(+"`E:"<I('EO=7(@=&EM
M92!S<&%N"B`@("`@*B!W;W5L9"!B92`R,"!H;W5R<R!L;VYG+B!!;&QW87ES
M(')E;65M8F5R('1H870@=&AI<R!M971H;V0@<V5T"B`@("`@*B`\8CYA;&P\
M+V(^('1H92!V86QU97,L('-O(&EF('EO=2!H860@82`D=&EM92!S<&%N(#,P
M(&UI;G5T97,@;&]N9PH@("`@("H@86YD('EO=2!M86ME("1T:6UE+3YS971&
M<F]M4W1R:6YG*"<R,"!H;W5R<R<L("<E2"!H;W5R<R<I+"`D=&EM90H@("`@
M("H@<W!A;B!W;W5L9"!B92`R,"!H;W5R<R!L;VYG("AA;F0@;F]T(#(P(&AO
M=7)S(&%N9"`S,"!M:6YU=&5S*2X*("`@("`J($EN<'5T(&9O<FUA="!O<'1I
M;VYS.CQB<CX*("`@("`J("`\8V]D93XE0SPO8V]D93X@1&%Y<R!W:71H('1I
M;64L('-A;64@87,@(B5$+"`E2#HE33HE4R(N/&)R/@H@("`@("H@(#QC;V1E
M/B5D/"]C;V1E/B!4;W1A;"!D87ES(&%S(&$@9FQO870@;G5M8F5R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("@R(&1A>7,L(#$R(&AO=7)S(#T@,BXU(&1A
M>7,I+CQB<CX*("`@("`J("`\8V]D93XE1#PO8V]D93X@1&%Y<R!A<R!A(&1E
M8VEM86P@;G5M8F5R+CQB<CX*("`@("`J("`\8V]D93XE93PO8V]D93X@5&]T
M86P@:&]U<G,@87,@82!F;&]A="!N=6UB97(*("`@("`J("`@("`@("`@("`@
M("`@("`@*#$@9&%Y+"`R(&AO=7)S+"`S,"!M:6YU=&5S(#T@,C8N-2!H;W5R
M<RDN/&)R/@H@("`@("H@(#QC;V1E/B5F/"]C;V1E/B!4;W1A;"!M:6YU=&5S
M(&%S(&$@9FQO870@;G5M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("@R
M(&UI;G5T97,L(#,P('-E8V]N9',@/2`R+C4@;6EN=71E<RDN/&)R/@H@("`@
M("H@(#QC;V1E/B5G/"]C;V1E/B!4;W1A;"!S96-O;F1S(&%S(&$@9&5C:6UA
M;"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#(@;6EN=71E<RP@
M,S`@<V5C;VYD<R`](#DP('-E8V]N9',I+CQB<CX*("`@("`J("`\8V]D93XE
M:#PO8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N=6UB97(N/&)R/@H@("`@("H@
M(#QC;V1E/B5(/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L(&YU;6)E<B!L:6UI
M=&5D('1O(#(@9&EG:71S+CQB<CX*("`@("`J("`\8V]D93XE;3PO8V]D93X@
M36EN=71E<R!A<R!A(&1E8VEM86P@;G5M8F5R+CQB<CX*("`@("`J("`\8V]D
M93XE33PO8V]D93X@36EN=71E<R!A<R!A(&1E8VEM86P@;G5M8F5R(&QI;6ET
M960@=&\@,B!D:6=I=',N/&)R/@H@("`@("H@(#QC;V1E/B5N/"]C;V1E/B!.
M97=L:6YE(&-H87)A8W1E<B`H7&XI+CQB<CX*("`@("`J("`\8V]D93XE<#PO
M8V]D93X@16ET:&5R("=A;2<@;W(@)W!M)R!D97!E;F1I;F<@;VX@=&AE('1I
M;64N($EF("=P;2<*("`@("`J("`@("`@("`@("`@("`@("`@:7,@9&5T96-T
M960@:70@861D<R`Q,B!H;W5R<R!T;R!T:&4@<F5S=6QT:6YG('1I;64*("`@
M("`J("`@("`@("`@("`@("`@("`@<W!A;B`H=VET:&]U="!A;GD@8VAE8VMS
M*2X@5&AI<R!I<R!C87-E"B`@("`@*B`@("`@("`@("`@("`@("`@(&EN<V5N
M<VET:79E+CQB<CX*("`@("`J("`\8V]D93XE<CPO8V]D93X@5&EM92!I;B!A
M;2]P;2!N;W1A=&EO;BP@<V%M92!A<R`B)4@Z)4TZ)5,@)7`B+CQB<CX*("`@
M("`J("`\8V]D93XE4CPO8V]D93X@5&EM92!I;B`R-"UH;W5R(&YO=&%T:6]N
M+"!S86UE(&%S("(E2#HE32(N/&)R/@H@("`@("H@(#QC;V1E/B5S/"]C;V1E
M/B!396-O;F1S(&%S(&$@9&5C:6UA;"!N=6UB97(N/&)R/@H@("`@("H@(#QC
M;V1E/B53/"]C;V1E/B!396-O;F1S(&%S(&$@9&5C:6UA;"!N=6UB97(@;&EM
M:71E9"!T;R`R(&1I9VET<RX\8G(^"B`@("`@*B`@/&-O9&4^)70\+V-O9&4^
M(%1A8B!C:&%R86-T97(@*%QT*2X\8G(^"B`@("`@*B`@/&-O9&4^)50\+V-O
M9&4^($-U<G)E;G0@=&EM92!E<75I=F%L96YT+"!S86UE(&%S("(E2#HE33HE
M4R(N/&)R/@H@("`@("H@(#QC;V1E/B4E/"]C;V1E/B!,:71E<F%L("<E)RX\
M8G(^"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)'1I;64@("!3=')I
M;F<@9G)O;2!W:&5R92!T;R!G970@=&AE('1I;64@<W!A;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@("`J($!P87)A
M;2`@<W1R:6YG("1F;W)M870@1F]R;6%T('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VP@("!4<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1G)O
M;5-T<FEN9R@D=&EM92P@)&9O<FUA="`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&ES7VYU;&PH)&9O<FUA="DI('L*("`@("`@("`@("`@)&9O<FUA="`]
M("1'3$]"04Q36R=?1$%415]34$%.7TE.4%547T9/4DU!5"==.PH@("`@("`@
M('T*("`@("`@("`O+R!)9B!F;W)M870@:7,@82!S=')I;F<L(&ET('!A<G-E
M<R!T:&4@<W1R:6YG(&9O<FUA="X*("`@("`@("!I9B`H:7-?<W1R:6YG*"1F
M;W)M870I*2!["B`@("`@("`@("`@("1S='(@/2`G)SL*("`@("`@("`@("`@
M)'9A<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D<&T@/2`G86TG.PH@("`@
M("`@("`@("`D9&%Y(#T@)&AO=7(@/2`D;6EN=71E(#T@)'-E8V]N9"`](#`[
M"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE;B@D9F]R;6%T
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&-H87(@/2`D9F]R;6%T>R1I
M?3L*("`@("`@("`@("`@("`@(&EF("@D8VAA<B`]/2`G)2<I('L*("`@("`@
M("`@("`@("`@("`@("`D;F5X=&-H87(@/2`D9F]R;6%T>RLK)&E].PH@("`@
M("`@("`@("`@("`@("`@('-W:71C:"`H)&YE>'1C:&%R*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V,G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-T<B`N/2`G)60L("5D.B5D.B5D)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<G,L("=D87DG+"`G:&]U<B<L("=M:6YU=&4G
M+"`G<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G0R<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9"P@)3)D.B4R9#HE,F0G
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R<RP@)V1A>2<L("=H
M;W5R)RP@)VUI;G5T92<L("=S96-O;F0G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("=D)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R5F
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A
M<G,L("=D87DG*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=$)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R5D)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=D87DG*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=E)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S='(@+CT@)R5F)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7W!U<V@H)'9A<G,L("=H;W5R)RD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`G9B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E
M9B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V
M87)S+"`G;6EN=71E)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G9R<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9B<["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G<V5C;VYD
M)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1R("X]("<E9"<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G:&]U<B<I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)T@G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T
M<B`N/2`G)3)D)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7W!U<V@H)'9A<G,L("=H;W5R)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G;2<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9"<["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G
M;6EN=71E)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G32<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<W1R("X]("<E,F0G.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)VUI;G5T92<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)VXG.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T<B`N/2`B7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W`G.@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)3)S)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=P
M;2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)W(G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-T<B`N/2`G)3)D.B4R9#HE,F0@)3)S)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<G,L("=H;W5R)RP@)VUI;G5T92<L
M("=S96-O;F0G+"`G<&TG*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=2)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R4R9#HE,F0G.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@
M)VAO=7(G+"`G;6EN=71E)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G<R<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9"<["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G<V5C
M;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`G4R<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<W1R("X]("<E,F0G.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)W-E8V]N9"<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)W0G.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T<B`N/2`B7'0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)U0G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)3)D.B4R9#HE,F0G
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R
M<RP@)VAO=7(G+"`G;6EN=71E)RP@)W-E8V]N9"<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)R4G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N
M/2`B)2(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S='(@+CT@)&-H87(@+B`D;F5X=&-H87(["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D<W1R("X]("1C:&%R.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1V86QS(#T@<W-C86YF
M*"1T:6UE+"`D<W1R*3L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;',@87,@
M)&D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES7VYU;&PH)'9A
M;"DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D)'9A<G-;)&E=(#T@)'9A
M;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D
M<&TL("=P;2<I(#T](#`I('L*("`@("`@("`@("`@("`@("1H;W5R("L](#$R
M.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R8V%S96-M<"@D<&TL("=A;2<I
M("$](#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<V5T1G)O;4%R<F%Y*&%R<F%Y
M*"1D87DL("1H;W5R+"`D;6EN=71E+"`D<V5C;VYD*2D["B`@("`@("`@+R\@
M268@9F]R;6%T(&ES(&$@:6YT96=E<BP@:70@=7-E<R!A('!R961E9FEN960@
M9F]R;6%T"B`@("`@("`@+R\@9&5T96-T:6]N(&UE=&AO9"X*("`@("`@("!]
M(&5L<V5I9B`H:7-?:6YT96=E<B@D9F]R;6%T*2D@>PH@("`@("`@("`@("!S
M=VET8V@@*"1F;W)M870I('L*("`@("`@("`@("`@("`@(&-A<V4@1$%415]3
M4$%.7TE.4%547T9/4DU!5%].3E-6.@H@("`@("`@("`@("`@("`@("`@("1T
M:6UE(#T@<')E9U]S<&QI="@G+UQ$*R\G+"`D=&EM92D["B`@("`@("`@("`@
M("`@("`@("`@<W=I=&-H("AC;W5N="@D=&EM92DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971&<F]M07)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH,"P@,"P@,"P@,"DI.PH@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@P+"`D=&EM95LP72P@,"P@
M,"DI.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@P+"`D
M=&EM95LP72P@)'1I;65;,5TL(#`I*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`S.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YS971&<F]M07)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH,"P@)'1I;65;,%TL("1T:6UE6S%=+"`D=&EM95LR
M72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M07)R
M87DH)'1I;64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE
M('1I;64@<W!A;B!F<F]M(&$@=&]T86P@;G5M8F5R(&]F('-E8V]N9',N"B`@
M("`@*@H@("`@("H@0'!A<F%M("!I;G0@("1S96-O;F1S(%1O=&%L(&YU;6)E
M<B!O9B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"!4<G5E
M(&]N('-U8V-E<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T1G)O;5-E8V]N9',H)'-E8V]N9',I"B`@
M("!["B`@("`@("`@:68@*"1S96-O;F1S(#P@,"D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1S96,@(#T@:6YT=F%L
M*"1S96-O;F1S*3L*("`@("`@("`D;6EN("`](&9L;V]R*"1S96,@+R`V,"D[
M"B`@("`@("`@)&AO=7(@/2!F;&]O<B@D;6EN("\@-C`I.PH@("`@("`@("1D
M87D@(#T@:6YT=F%L*&9L;V]R*"1H;W5R("\@,C0I*3L*("`@("`@("`D=&AI
M<RT^<V5C;VYD(#T@)'-E8R`E(#8P.PH@("`@("`@("1T:&ES+3YM:6YU=&4@
M/2`D;6EN("4@-C`["B`@("`@("`@)'1H:7,M/FAO=7(@("`]("1H;W5R("4@
M,C0["B`@("`@("`@)'1H:7,M/F1A>2`@("`]("1D87D["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@
M<W!A;B!F<F]M(&$@=&]T86P@;G5M8F5R(&]F(&UI;G5T97,N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!F;&]A="`D;6EN=71E<R!4;W1A;"!N=6UB97(@;V8@
M;6EN=71E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@
M<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971&<F]M36EN=71E<R@D;6EN=71E<RD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU396-O;F1S*')O=6YD*"1M
M:6YU=&5S("H@-C`I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@
M=&EM92!S<&%N(&9R;VT@82!T;W1A;"!N=6UB97(@;V8@:&]U<G,N"B`@("`@
M*@H@("`@("H@0'!A<F%M("!F;&]A="`D:&]U<G,@5&]T86P@;G5M8F5R(&]F
M(&AO=7)S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5')U92!O;B!S
M=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$9R;VU(;W5R<R@D:&]U<G,I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971&<F]M4V5C;VYD<RAR;W5N9"@D:&]U<G,@
M*B`S-C`P*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@
M<W!A;B!F<F]M(&$@=&]T86P@;G5M8F5R(&]F(&1A>7,N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!F;&]A="`D9&%Y<R!4;W1A;"!N=6UB97(@;V8@9&%Y<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@<W5C8V5S<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!S971&<F]M1&%Y<R@D9&%Y<RD*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G-E=$9R;VU396-O;F1S*')O=6YD*"1D87ES("H@.#8T,#`I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@<W!A;B!F<F]M('1H92!E
M;&%P<V5D('1I;64@8F5T=V5E;B!T=V\@9&%T97,N"B`@("`@*@H@("`@("H@
M4V5T('1H92!S<&%N(&9R;VT@=&AE(&5L87!S960@=&EM92!B971W965N('1W
M;R!D871E<RX@5&AE('1I;64@<W!A;@H@("`@("H@:7,@86QL=V%Y<R!P;W-I
M=&EV92P@<V\@=&AE(&1A=&4G<R!O<F1E<B!I<R!N;W0@:6UP;W)T86YT+@H@
M("`@("H*("`@("`J($!P87)A;2`@;V)J96-T($1A=&4@)&1A=&4Q($9I<G-T
M($1A=&4N"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E("1D871E,B!396-O
M;F0@1&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@
M<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971&<F]M1&%T941I9F8H)&1A=&4Q+"`D9&%T93(I
M"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1D871E,2P@)V1A=&4G*2!O<B`A
M:7-?82@D9&%T93(L("=D871E)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D9&%T93$M/G1O551#*"D["B`@("`@
M("`@)&1A=&4R+3YT;U540R@I.PH@("`@("`@(&EF("@D9&%T93$M/F%F=&5R
M*"1D871E,BDI('L*("`@("`@("`@("`@;&ES="@D9&%T93$L("1D871E,BD@
M/2!A<G)A>2@D9&%T93(L("1D871E,2D["B`@("`@("`@?0H@("`@("`@("1D
M87ES(#T@1&%T95]#86QC.CID871E1&EF9B@*("`@("`@("`@("`@)&1A=&4Q
M+3YG971$87DH*2P@)&1A=&4Q+3YG971-;VYT:"@I+"`D9&%T93$M/F=E=%EE
M87(H*2P*("`@("`@("`@("`@)&1A=&4R+3YG971$87DH*2P@)&1A=&4R+3YG
M971-;VYT:"@I+"`D9&%T93(M/F=E=%EE87(H*0H@("`@("`@("D["B`@("`@
M("`@)&AO=7)S(#T@)&1A=&4R+3YG971(;W5R*"D@+2`D9&%T93$M/F=E=$AO
M=7(H*3L*("`@("`@("`D;6EN<R`@/2`D9&%T93(M/F=E=$UI;G5T92@I("T@
M)&1A=&4Q+3YG971-:6YU=&4H*3L*("`@("`@("`D<V5C<R`@/2`D9&%T93(M
M/F=E=%-E8V]N9"@I("T@)&1A=&4Q+3YG971396-O;F0H*3L*("`@("`@("`D
M=&AI<RT^<V5T1G)O;5-E8V]N9',H"B`@("`@("`@("`@("1D87ES("H@.#8T
M,#`@*R`D:&]U<G,@*B`S-C`P("L@)&UI;G,@*B`V,"`K("1S96-S"B`@("`@
M("`@*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@86YO=&AE<B!T:6UE(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@)'1I
M;64@4V]U<F-E('1I;64@<W!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L("`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O<'DH)'1I;64I
M"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1I;64L("=D871E7W-P86XG*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V5C;VYD(#T@)'1I;64M/G-E8V]N9#L*
M("`@("`@("`@("`@)'1H:7,M/FUI;G5T92`]("1T:6UE+3YM:6YU=&4["B`@
M("`@("`@("`@("1T:&ES+3YH;W5R("`@/2`D=&EM92T^:&]U<CL*("`@("`@
M("`@("`@)'1H:7,M/F1A>2`@("`]("1T:6UE+3YD87D["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:6UE('-P86X@<')E='1Y('!R:6YT:6YG("AS:6UI;&%R('1O($1A=&4Z.F9O
M<FUA="@I*2X*("`@("`J"B`@("`@*B!&;W)M871S('1H92!T:6UE('-P86X@
M:6X@=&AE(&=I=F5N(&9O<FUA="P@<VEM:6QA<B!T;PH@("`@("H@<W1R9G1I
M;64H*2!A;F0@1&%T93HZ9F]R;6%T*"DN/&)R/@H@("`@("H@/&)R/@H@("`@
M("H@1F]R;6%T=&EN9R!O<'1I;VYS.CQB<CX*("`@("`J("`\8V]D93XE0SPO
M8V]D93X@1&%Y<R!W:71H('1I;64L('-A;64@87,@(B5$+"`E2#HE33HE4R(N
M/&)R/@H@("`@("H@(#QC;V1E/B5D/"]C;V1E/B!4;W1A;"!D87ES(&%S(&$@
M9FQO870@;G5M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("@R(&1A>7,L
M(#$R(&AO=7)S(#T@,BXU(&1A>7,I+CQB<CX*("`@("`J("`\8V]D93XE1#PO
M8V]D93X@1&%Y<R!A<R!A(&1E8VEM86P@;G5M8F5R+CQB<CX*("`@("`J("`\
M8V]D93XE93PO8V]D93X@5&]T86P@:&]U<G,@87,@82!F;&]A="!N=6UB97(*
M("`@("`J("`@("`@("`@("`@("`@("`@*#$@9&%Y+"`R(&AO=7)S+"`S,"!M
M:6YU=&5S(#T@,C8N-2!H;W5R<RDN/&)R/@H@("`@("H@(#QC;V1E/B5%/"]C
M;V1E/B!4;W1A;"!H;W5R<R!A<R!A(&1E8VEM86P@;G5M8F5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("@Q(&1A>2P@,B!H;W5R<RP@-#`@;6EN=71E<R`]
M(#(V(&AO=7)S*2X\8G(^"B`@("`@*B`@/&-O9&4^)68\+V-O9&4^(%1O=&%L
M(&UI;G5T97,@87,@82!F;&]A="!N=6UB97(*("`@("`J("`@("`@("`@("`@
M("`@("`@*#(@;6EN=71E<RP@,S`@<V5C;VYD<R`](#(N-2!M:6YU=&5S*2X\
M8G(^"B`@("`@*B`@/&-O9&4^)48\+V-O9&4^(%1O=&%L(&UI;G5T97,@87,@
M82!D96-I;6%L(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("`H,2!H
M;W5R+"`R(&UI;G5T97,L(#0P('-E8V]N9',@/2`V,B!M:6YU=&5S*2X\8G(^
M"B`@("`@*B`@/&-O9&4^)6<\+V-O9&4^(%1O=&%L('-E8V]N9',@87,@82!D
M96-I;6%L(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("`H,B!M:6YU
M=&5S+"`S,"!S96-O;F1S(#T@.3`@<V5C;VYD<RDN/&)R/@H@("`@("H@(#QC
M;V1E/B5H/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L(&YU;6)E<B`H,"!T;R`R
M,RDN/&)R/@H@("`@("H@(#QC;V1E/B5(/"]C;V1E/B!(;W5R<R!A<R!D96-I
M;6%L(&YU;6)E<B`H,#`@=&\@,C,I+CQB<CX*("`@("`J("`\8V]D93XE:3PO
M8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N=6UB97(@;VX@,3(M:&]U<B!C;&]C
M:PH@("`@("H@("`@("`@("`@("`@("`@("`H,2!T;R`Q,BDN/&)R/@H@("`@
M("H@(#QC;V1E/B5)/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L(&YU;6)E<B!O
M;B`Q,BUH;W5R(&-L;V-K"B`@("`@*B`@("`@("`@("`@("`@("`@("@P,2!T
M;R`Q,BDN/&)R/@H@("`@("H@(#QC;V1E/B5M/"]C;V1E/B!-:6YU=&5S(&%S
M(&$@9&5C:6UA;"!N=6UB97(@*#`@=&\@-3DI+CQB<CX*("`@("`J("`\8V]D
M93XE33PO8V]D93X@36EN=71E<R!A<R!A(&1E8VEM86P@;G5M8F5R("@P,"!T
M;R`U.2DN/&)R/@H@("`@("H@(#QC;V1E/B5N/"]C;V1E/B!.97=L:6YE(&-H
M87)A8W1E<B`H7&XI+CQB<CX*("`@("`J("`\8V]D93XE<#PO8V]D93X@16ET
M:&5R("=A;2<@;W(@)W!M)R!D97!E;F1I;F<@;VX@=&AE('1I;64N/&)R/@H@
M("`@("H@(#QC;V1E/B50/"]C;V1E/B!%:71H97(@)T%-)R!O<B`G4$TG(&1E
M<&5N9&EN9R!O;B!T:&4@=&EM92X\8G(^"B`@("`@*B`@/&-O9&4^)7(\+V-O
M9&4^(%1I;64@:6X@86TO<&T@;F]T871I;VXL('-A;64@87,@(B5).B5-.B53
M("5P(BX\8G(^"B`@("`@*B`@/&-O9&4^)5(\+V-O9&4^(%1I;64@:6X@,C0M
M:&]U<B!N;W1A=&EO;BP@<V%M92!A<R`B)4@Z)4TB+CQB<CX*("`@("`J("`\
M8V]D93XE<SPO8V]D93X@4V5C;VYD<R!A<R!A(&1E8VEM86P@;G5M8F5R("@P
M('1O(#4Y*2X\8G(^"B`@("`@*B`@/&-O9&4^)5,\+V-O9&4^(%-E8V]N9',@
M87,@82!D96-I;6%L(&YU;6)E<B`H,#`@=&\@-3DI+CQB<CX*("`@("`J("`\
M8V]D93XE=#PO8V]D93X@5&%B(&-H87)A8W1E<B`H7'0I+CQB<CX*("`@("`J
M("`\8V]D93XE5#PO8V]D93X@0W5R<F5N="!T:6UE(&5Q=6EV86QE;G0L('-A
M;64@87,@(B5(.B5-.B53(BX\8G(^"B`@("`@*B`@/&-O9&4^)24\+V-O9&4^
M($QI=&5R86P@)R4G+CQB<CX*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`D9F]R;6%T(%1H92!F;W)M870@<W1R:6YG(&9O<B!R971U<FYE9"!T:6UE
M('-P86XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@5&AE('1I;64@
M<W!A;B!I;B!S<&5C:69I960@9F]R;6%T+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<FUA="@D9F]R;6%T
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D9F]R;6%T*2D@
M>PH@("`@("`@("`@("`D9F]R;6%T(#T@)$=,3T)!3%-;)U]$051%7U-004Y?
M1D]234%4)UT["B`@("`@("`@?0H@("`@("`@("1O=71P=70@/2`G)SL*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&9O<FUA="D[("1I*RLI
M('L*("`@("`@("`@("`@)&-H87(@/2`D9F]R;6%T>R1I?3L*("`@("`@("`@
M("`@:68@*"1C:&%R(#T]("<E)RD@>PH@("`@("`@("`@("`@("`@)&YE>'1C
M:&%R(#T@)&9O<FUA='LK*R1I?3L*("`@("`@("`@("`@("`@('-W:71C:"`H
M)&YE>'1C:&%R*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G0R<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<E9"P@)3`R9#HE,#)D.B4P,F0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1A>2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUI;G5T92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS96-O;F0*("`@("`@("`@("`@
M("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G9"<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/G1O1&%Y<R@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C
M87-E("=$)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D
M=&AI<RT^9&%Y.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!C87-E("=E)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^=&](;W5R<R@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=%)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!F;&]O
M<B@D=&AI<RT^=&](;W5R<R@I*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G9B<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/G1O36EN=71E<R@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("!C87-E("=&)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!F;&]O<B@D=&AI<RT^=&]-:6YU=&5S*"DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=G)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI
M<RT^=&]396-O;F1S*"D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YH;W5R.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=()SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I
M;G1F*"<E,#)D)RP@)'1H:7,M/FAO=7(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=I)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&AO=7(@/0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*"1T:&ES+3YH;W5R("L@,2D@/B`Q,B`_"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`M(#$R(#H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]("@D:&]U<B`]/2`P*2`_(#$R(#H@
M)&AO=7(["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)TDG.@H@("`@("`@("`@("`@("`@("`@("`@
M("`D:&]U<B`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H)'1H:7,M
M/FAO=7(@*R`Q*2`^(#$R(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YH;W5R("T@,3(@.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FAO=7(["B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@<W!R:6YT9B@G)3`R9"<L("1H;W5R/3TP(#\@,3(@.B`D:&]U<BD[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]("1T:&ES+3YM:6YU=&4["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)TTG.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H)R4P,F0G+"1T
M:&ES+3YM:6YU=&4I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!C87-E("=N)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2`B7&XB.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=P)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^:&]U<B`^
M/2`Q,B`_("=P;2<@.B`G86TG.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=0)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^:&]U<B`^/2`Q,B`_
M("=032<@.B`G04TG.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!C87-E("=R)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)&AO=7(@/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*"1T:&ES+3YH;W5R("L@,2D@/B`Q,B`_"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^:&]U<B`M(#$R(#H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YH;W5R.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]('-P<FEN=&8H"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G)3`R9#HE,#)D.B4P,F0@)7,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&AO=7(]/3`@/R`@,3(@.B`D:&]U<BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM:6YU=&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5C;VYD+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FAO=7(@/CT@,3(@/R`G<&TG(#H@)V%M)PH@
M("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=2)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R4P,F0Z)3`R9"<L("1T:&ES+3YH
M;W5R+"`D=&AI<RT^;6EN=71E"B`@("`@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)W,G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]("1T:&ES+3YS96-O;F0["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)U,G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H)R4P,F0G+"`D
M=&AI<RT^<V5C;VYD*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G="<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@(EQT(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G5"<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<E,#)D.B4P,F0Z)3`R9"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<BP@)'1H:7,M
M/FUI;G5T92P@)'1H:7,M/G-E8V]N9`H@("`@("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!C87-E("<E)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`B)2(["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@)&-H87(@+B`D;F5X=&-H87(["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1C:&%R.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N=F5R="!T:6UE('-P86X@=&\@<V5C;VYD<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="!4:6UE('-P86X@87,@86X@:6YT96=E<B!N=6UB97(@
M;V8@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!T;U-E8V]N9',H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9&%Y("H@.#8T,#`@*R`D=&AI<RT^:&]U<B`J(#,V,#`@
M*PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E("H@-C`@*R`D=&AI<RT^<V5C
M;VYD.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T:6UE('-P86X@
M=&\@;6EN=71E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&9L;V%T(%1I;64@
M<W!A;B!A<R!A(&1E8VEM86P@;G5M8F5R(&]F(&UI;G5T97,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]-
M:6YU=&5S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1A>2`J(#$T
M-#`@*R`D=&AI<RT^:&]U<B`J(#8P("L@)'1H:7,M/FUI;G5T92`K"B`@("`@
M("`@("`@("1T:&ES+3YS96-O;F0@+R`V,#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G0@=&EM92!S<&%N('1O(&AO=7)S+@H@("`@("H*("`@("`J
M($!R971U<FX@9FQO870@5&EM92!S<&%N(&%S(&$@9&5C:6UA;"!N=6UB97(@
M;V8@:&]U<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@=&](;W5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YD87D@*B`R-"`K("1T:&ES+3YH;W5R("L@)'1H:7,M/FUI;G5T
M92`O(#8P("L*("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`O(#,V,#`["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1I;64@<W!A;B!T;R!D87ES
M+@H@("`@("H*("`@("`J($!R971U<FX@9FQO870@5&EM92!S<&%N(&%S(&$@
M9&5C:6UA;"!N=6UB97(@;V8@9&%Y<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T;T1A>7,H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^9&%Y("L@)'1H:7,M/FAO=7(@+R`R-"`K
M("1T:&ES+3YM:6YU=&4@+R`Q-#0P("L*("`@("`@("`@("`@)'1H:7,M/G-E
M8V]N9"`O(#@V-#`P.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('1I
M;64@<W!A;BX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P
M86X@)'1I;64@5&EM92!S<&%N('1O(&%D9"X*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)'1I;64I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M4V5C;VYD<R@*("`@
M("`@("`@("`@)'1H:7,M/G1O4V5C;VYD<R@I("L@)'1I;64M/G1O4V5C;VYD
M<R@I"B`@("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-U8G1R86-T
M<R!A('1I;64@<W!A;BX*("`@("`J"B`@("`@*B!3=6)T<F%C=',@82!T:6UE
M('-P86XN($EF('1H92!T:6UE('-P86X@=&\@<W5B=')A8W0@:7,@;&%R9V5R
M"B`@("`@*B!T:&%N('1H92!O<FEG:6YA;"P@=&AE(')E<W5L="!I<R!Z97)O
M("AT:&5R92=S(&YO('-E;G-E(&EN"B`@("`@*B!N96=A=&EV92!T:6UE('-P
M86YS*2X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@
M)'1I;64@5&EM92!S<&%N('1O('-U8G1R86-T+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-U8G1R86-T*"1T
M:6UE*0H@("`@>PH@("`@("`@("1S=6(@/2`D=&AI<RT^=&]396-O;F1S*"D@
M+2`D=&EM92T^=&]396-O;F1S*"D["B`@("`@("`@:68@*"1S=6(@/"`P*2![
M"B`@("`@("`@("`@("1T:&ES+3YS971&<F]M4V5C;VYD<R@P*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T1G)O;5-E8V]N9',H
M)'-U8BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&5L;',@
M:68@=&EM92!S<&%N(&ES(&5Q=6%L('1O("1T:6UE+@H@("`@("H*("`@("`J
M($!P87)A;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM92!4:6UE('-P86X@=&\@
M8V]M<&%R92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@("!4<G5E
M(&EF('1H92!T:6UE('-P86YS(&%R92!E<75A;"X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!E<75A;"@D=&EM
M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1O4V5C;VYD<R@I(#T]
M("1T:6UE+3YT;U-E8V]N9',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1E
M;&QS(&EF('1H:7,@=&EM92!S<&%N(&ES(&=R96%T97(@;W(@97%U86P@=&AA
M;B`D=&EM92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P
M86X@)'1I;64@5&EM92!S<&%N('1O(&-O;7!A<F4@=&\N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L("`@5')U92!I9B!T:&ES('1I;64@<W!A;B!I<R!G
M<F5A=&5R(&]R(&5Q=6%L('1H86X@)'1I;64N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9W)E871E<D5Q=6%L
M*"1T:6UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^=&]396-O;F1S
M*"D@/CT@)'1I;64M/G1O4V5C;VYD<R@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&5L;',@:68@=&AI<R!T:6UE('-P86X@:7,@;&]W97(@;W(@97%U86P@
M=&AA;B`D=&EM92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E
M7U-P86X@)'1I;64@5&EM92!S<&%N('1O(&-O;7!A<F4@=&\N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L("`@5')U92!I9B!T:&ES('1I;64@<W!A;B!I
M<R!L;W=E<B!O<B!E<75A;"!T:&%N("1T:6UE+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO=V5R17%U86PH
M)'1I;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT;U-E8V]N9',H
M*2`\/2`D=&EM92T^=&]396-O;F1S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!496QL<R!I9B!T:&ES('1I;64@<W!A;B!I<R!G<F5A=&5R('1H86X@)'1I
M;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T
M:6UE(%1I;64@<W!A;B!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"`@(%1R=64@:68@=&AI<R!T:6UE('-P86X@:7,@9W)E871E
M<B!T:&%N("1T:6UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=R96%T97(H)'1I;64I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YT;U-E8V]N9',H*2`^("1T:6UE+3YT;U-E8V]N
M9',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1E;&QS(&EF('1H:7,@=&EM
M92!S<&%N(&ES(&QO=V5R('1H86X@)'1I;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE(%1I;64@<W!A;B!T;R!C;VUP
M87)E('1O+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@(%1R=64@:68@
M=&AI<R!T:6UE('-P86X@:7,@;&]W97(@=&AA;B`D=&EM92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;W=E
M<B@D=&EM92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1O4V5C;VYD
M<R@I(#P@)'1I;64M/G1O4V5C;VYD<R@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]M<&%R97,@='=O('1I;64@<W!A;G,N"B`@("`@*@H@("`@("H@0V]M
M<&%R97,@='=O('1I;64@<W!A;G,N(%-U:71A8FQE(&9O<B!U<V4@:6X@<V]R
M=&EN9R!F=6YC=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@
M1&%T95]3<&%N("1T:6UE,2!4:&4@9FER<W0@=&EM92!S<&%N+@H@("`@("H@
M0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE,B!4:&4@<V5C;VYD('1I
M;64@<W!A;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@("`P(&EF('1H
M92!T:6UE('-P86YS(&%R92!E<75A;"P@+3$@:68@=&EM93$@:7,@;&]W97(*
M("`@("`J("`@("`@("`@("`@("`@('1H86X@=&EM93(L(#$@:68@=&EM93$@
M:7,@9W)E871E<B!T:&%N('1I;64R+@H@("`@("H*("`@("`J($!S=&%T:6,*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;7!A<F4H)'1I;64Q+"`D=&EM93(I"B`@("!["B`@("`@("`@:68@*"1T:6UE
M,2T^97%U86PH)'1I;64R*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!](&5L<V5I9B`H)'1I;64Q+3YL;W=E<B@D=&EM93(I*2!["B`@("`@
M("`@("`@(')E='5R;B`M,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M96QL<R!I9B!T:&4@=&EM92!S<&%N(&ES(&5M<'1Y("AZ97)O(&QE;F=T:"DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%1R=64@:7,@:70G<R!E;7!T
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-%;7!T>2@I"B`@("!["B`@("`@
M("`@<F5T=7)N("$D=&AI<RT^9&%Y("8F("$D=&AI<RT^:&]U<B`F)B`A)'1H
M:7,M/FUI;G5T92`F)B`A)'1H:7,M/G-E8V]N9#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@9&5F875L="!I;G!U="!F;W)M870N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!M:7AE9"`D9F]R;6%T($YE=R!D969A=6QT(&EN<'5T
M(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%!R979I;W5S
M(&1E9F%U;'0@:6YP=70@9F]R;6%T+@H@("`@("H*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5F875L=$EN<'5T1F]R;6%T*"1F
M;W)M870I"B`@("!["B`@("`@("`@)&]L9"`]("1'3$]"04Q36R=?1$%415]3
M4$%.7TE.4%547T9/4DU!5"==.PH@("`@("`@("1'3$]"04Q36R=?1$%415]3
M4$%.7TE.4%547T9/4DU!5"==(#T@)&9O<FUA=#L*("`@("`@("!R971U<FX@
M)&]L9#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@9&5F875L="!I
M;G!U="!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!$969A
M=6QT(&EN<'5T(&9O<FUA="X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1);G!U=$9O<FUA="@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?1$%415]34$%.7TE.4%547T9/
M4DU!5"==.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!D969A=6QT
M(&9O<FUA="X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D("1F;W)M870@
M3F5W(&1E9F%U;'0@9F]R;6%T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@4')E=FEO=7,@9&5F875L="!F;W)M870N"B`@("`@*@H@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971$969A=6QT1F]R;6%T*"1F
M;W)M870I"B`@("!["B`@("`@("`@)&]L9"`]("1'3$]"04Q36R=?1$%415]3
M4$%.7T9/4DU!5"==.PH@("`@("`@("1'3$]"04Q36R=?1$%415]34$%.7T9/
M4DU!5"==(#T@)&9O<FUA=#L*("`@("`@("!R971U<FX@)&]L9#L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@9&5F875L="!F;W)M870N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"!$969A=6QT(&9O<FUA="X*("`@("`J
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U
M;'1&;W)M870H*0H@("`@>PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7T1!
M5$5?4U!!3E]&3U)-050G73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!C;W!Y(&]F('1H92!O8FIE8W0@*'=O<FMA<G)O=6YD(&9O<B!02%`U
M(&9O<G=A<F0@8V]M<&%T:6)I;&ET>2DN"B`@("`@*@H@("`@("H@0')E='5R
M;B!O8FIE8W0@1&%T95]3<&%N($-O<'D@;V8@=&AE(&]B:F5C="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7U]C;&]N92@I('L*("`@("`@("`D8R`](&=E=%]C
M;&%S<R@D=&AI<RD["B`@("`@("`@)',@/2!N97<@)&,["B`@("`@("`@)',M
M/F1A>2`@("`]("1T:&ES+3YD87D["B`@("`@("`@)',M/FAO=7(@("`]("1T
M:&ES+3YH;W5R.PH@("`@("`@("1S+3YM:6YU=&4@/2`D=&AI<RT^;6EN=71E
M.PH@("`@("`@("1S+3YS96-O;F0@/2`D=&AI<RT^<V5C;VYD.PH@("`@("`@
M(')E='5R;B`D<SL*("`@('T*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1&%T92]4:6UE6F]N92YP
M:'``````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T-C,S-S,`
M,3`U,34T,S$P-3<`,#(P-3`Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T
M86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`U($)A8F$@0G5E:&QE<BP@4&EE<G)E+4%L86EN($IO>64@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('1H92!.97<@
M0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE9"`@?`HO+R!\('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B
M;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@=V]R;&0M=VED92UW96(@870@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B
M<V0M;&EC96YS92YP:'`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!N97<@0E-$;&EC96YS
M92!A;F0@87)E('5N86)L92`@('P*+R\@?"!T;R!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@
M("`@("!\"B\O('P@<&5A<BUD979`;&ES=',N<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($)A8F$@0G5E
M:&QE<B`\8F%B84!B86)A>BYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@("`@("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J
M;WEE0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"B\J*@H@*B!4:6UE6F]N92!R
M97!R97-E;G1A=&EO;B!C;&%S<RP@86QO;F<@=VET:"!T:6UE('IO;F4@:6YF
M;W)M871I;VX@9&%T80H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!`8V%T96=O<GD@("!$871E(&%N9"!4:6UE"B`J($!P86-K86=E("`@($1A
M=&4*("H@0&%U=&AO<B`@("`@0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O
M;3X*("H@0&%U=&AO<B`@("`@4&EE<G)E+4%L86EN($IO>64@/'!A:F]Y94!P
M:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@0F%B82!"=65H;&5R
M+"!0:65R<F4M06QA:6X@2F]Y90H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W
M($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!4:6UE6F]N
M92YP:'`L=B`Q+C$Q(#(P,#4O,3$O,34@,#`Z,38Z-#`@<&%J;WEE($5X<"`D
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$
M871E"B`J+PH*+RHJ"B`J(%1I;65:;VYE(')E<')E<V5N=&%T:6]N(&-L87-S
M+"!A;&]N9R!W:71H('1I;64@>F]N92!I;F9O<FUA=&EO;B!D871A"B`J"B`J
M(%1H92!D969A=6QT('1I;65Z;VYE(&ES('-E="!F<F]M('1H92!F:7)S="!V
M86QI9"!T:6UE>F]N92!I9"!F;W5N9`H@*B!I;B!O;F4@;V8@=&AE(&9O;&QO
M=VEN9R!P;&%C97,L(&EN('1H:7,@;W)D97(Z"B`J("`@*R!G;&]B86P@)%]$
M051%7U1)345:3TY%7T1%1D%53%0*("H@("`K('-Y<W1E;2!E;G9I<F]N;65N
M="!V87)I86)L92!02%!?5%H*("H@("`K('-Y<W1E;2!E;G9I<F]N;65N="!V
M87)I86)L92!46@H@*B`@("L@=&AE(')E<W5L="!O9B!D871E*"=4)RD*("H*
M("H@268@;F\@=F%L:60@=&EM97IO;F4@:60@:7,@9F]U;F0L('1H92!D969A
M=6QT('1I;65Z;VYE(&ES('-E="!T;R`G551#)RX*("H@66]U(&UA>2!A;'-O
M(&UA;G5A;&QY('-E="!T:&4@9&5F875L="!T:6UE>F]N92!B>2!P87-S:6YG
M(&$@=F%L:60@:60@=&\*("H@1&%T95]4:6UE6F]N93HZ<V5T1&5F875L="@I
M+@H@*@H@*B!4:&ES(&-L87-S(&EN8VQU9&5S('1I;64@>F]N92!D871A("AF
M<F]M('IO;F5I;F9O*2!I;B!T:&4@9F]R;2!O9B!A"B`J(&=L;V)A;"!A<G)A
M>2P@)%]$051%7U1)345:3TY%7T1!5$$N"B`J"B`J($!A=71H;W(@("`@($)A
M8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!.
M97<@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C8*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1A
M=&4*("HO"F-L87-S($1A=&5?5&EM95IO;F4*>PH@("`@+RHJ"B`@("`@*B!4
M:6UE(%IO;F4@240@;V8@=&AI<R!T:6UE('IO;F4*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D:60["B`@("`O*BH*("`@("`J($QO;F<@
M3F%M92!O9B!T:&ES('1I;64@>F]N92`H:64@0V5N=')A;"!3=&%N9&%R9"!4
M:6UE*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1L;VYG
M;F%M93L*("`@("\J*@H@("`@("H@4VAO<G0@3F%M92!O9B!T:&ES('1I;64@
M>F]N92`H:64@0U-4*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1S:&]R=&YA;64["B`@("`O*BH*("`@("`J('1R=64@:68@=&AI<R!T
M:6UE('IO;F4@;V)S97)V97,@9&%Y;&EG:'0@<V%V:6YG<R!T:6UE"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1H87-D<W0["B`@("`O
M*BH*("`@("`J($135"!,;VYG($YA;64@;V8@=&AI<R!T:6UE('IO;F4*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9'-T;&]N9VYA;64[
M"B`@("`O*BH*("`@("`J($135"!3:&]R="!.86UE(&]F('1H:7,@=&EM97IO
M;F4*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9'-T<VAO
M<G1N86UE.PH@("`@+RHJ"B`@("`@*B!O9F9S970L(&EN(&UI;&QI<V5C;VYD
M<RP@;V8@=&AI<R!T:6UE>F]N90H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@
M("`@=F%R("1O9F9S970["@H@("`@+RHJ"B`@("`@*B!3>7-T96T@1&5F875L
M="!4:6UE(%IO;F4*("`@("`J($!V87(@;V)J96-T($1A=&5?5&EM95IO;F4*
M("`@("`J+PH@("`@=F%R("1D969A=6QT.PH*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0W)E871E<R!A(&YE=R!$871E.CI4
M:6UE6F]N92!O8FIE8W0L(')E<')E<V5N=&EN9R!T:&4@=&EM92!Z;VYE"B`@
M("`@*B!S<&5C:69I960@:6X@)&ED+B`@268@=&AE('-U<'!L:65D($E$(&ES
M(&EN=F%L:60L('1H92!C<F5A=&5D"B`@("`@*B!T:6UE('IO;F4@:7,@551#
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"!T:&4@=&EM92!Z;VYE(&ED"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="!$871E7U1I;65:;VYE('1H92!N97<@1&%T95]4:6UE6F]N92!O8FIE
M8W0*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T95]4:6UE6F]N92@D:60I"B`@
M("!["B`@("`@("`@9VQO8F%L("1?1$%415]424U%6D].15]$051!.PH@("`@
M("`@(&EF*$1A=&5?5&EM95IO;F4Z.FES5F%L:61)1"@D:60I*2!["B`@("`@
M("`@("`@("1T:&ES+3YI9"`]("1I9#L*("`@("`@("`@("`@)'1H:7,M/FQO
M;F=N86UE(#T@)%]$051%7U1)345:3TY%7T1!5$%;)&ED75LG;&]N9VYA;64G
M73L*("`@("`@("`@("`@)'1H:7,M/G-H;W)T;F%M92`]("1?1$%415]424U%
M6D].15]$051!6R1I9%U;)W-H;W)T;F%M92==.PH@("`@("`@("`@("`D=&AI
M<RT^;V9F<V5T(#T@)%]$051%7U1)345:3TY%7T1!5$%;)&ED75LG;V9F<V5T
M)UT["B`@("`@("`@("`@(&EF*"1?1$%415]424U%6D].15]$051!6R1I9%U;
M)VAA<V1S="==*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^:&%S9'-T(#T@
M=')U93L*("`@("`@("`@("`@("`@("1T:&ES+3YD<W1L;VYG;F%M92`]("1?
M1$%415]424U%6D].15]$051!6R1I9%U;)V1S=&QO;F=N86UE)UT["B`@("`@
M("`@("`@("`@("`D=&AI<RT^9'-T<VAO<G1N86UE(#T@)%]$051%7U1)345:
M3TY%7T1!5$%;)&ED75LG9'-T<VAO<G1N86UE)UT["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^:&%S9'-T(#T@9F%L<V4[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^9'-T;&]N9VYA;64@/2`D=&AI<RT^
M;&]N9VYA;64["B`@("`@("`@("`@("`@("`D=&AI<RT^9'-T<VAO<G1N86UE
M(#T@)'1H:7,M/G-H;W)T;F%M93L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3YI9"`]("=55$,G.PH@("`@("`@
M("`@("`D=&AI<RT^;&]N9VYA;64@/2`D7T1!5$5?5$E-15I/3D5?1$%405LD
M=&AI<RT^:61=6R=L;VYG;F%M92==.PH@("`@("`@("`@("`D=&AI<RT^<VAO
M<G1N86UE(#T@)%]$051%7U1)345:3TY%7T1!5$%;)'1H:7,M/FED75LG<VAO
M<G1N86UE)UT["B`@("`@("`@("`@("1T:&ES+3YH87-D<W0@/2`D7T1!5$5?
M5$E-15I/3D5?1$%405LD=&AI<RT^:61=6R=H87-D<W0G73L*("`@("`@("`@
M("`@)'1H:7,M/F]F9G-E="`]("1?1$%415]424U%6D].15]$051!6R1T:&ES
M+3YI9%U;)V]F9G-E="==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!A(%1I;65:;VYE(&]B:F5C="!R97!R97-E;G1I;F<@=&AE
M('-Y<W1E;2!D969A=6QT('1I;64@>F]N90H@("`@("H*("`@("`J(%)E='5R
M;B!A(%1I;65:;VYE(&]B:F5C="!R97!R97-E;G1I;F<@=&AE('-Y<W1E;2!D
M969A=6QT('1I;64@>F]N92P*("`@("`J('=H:6-H(&ES(&EN:71I86QI>F5D
M(&1U<FEN9R!T:&4@;&]A9&EN9R!O9B!4:6UE6F]N92YP:'`N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;V)J96-T($1A
M=&5?5&EM95IO;F4@=&AE(&1E9F%U;'0@=&EM92!Z;VYE"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$1E9F%U;'0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M7T1!5$5?5$E-15I/3D5?1$5&055,5#L*("`@("`@("!R971U<FX@;F5W($1A
M=&5?5&EM95IO;F4H)%]$051%7U1)345:3TY%7T1%1D%53%0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@<WES=&5M(&1E9F%U;'0@=&EM92!Z
M;VYE('1O('1H92!T:6UE('IO;F4@:6X@)&ED"B`@("`@*@H@("`@("H@4V5T
M<R!T:&4@<WES=&5M(&1E9F%U;'0@=&EM92!Z;VYE('1O('1H92!T:6UE('IO
M;F4@:6X@)&ED"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!P87)A;2!S=')I;F<@)&ED('1H92!T:6UE('IO;F4@:60@=&\@=7-E"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'0H)&ED*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$5&055,5#L*("`@("`@("!I
M9BA$871E7U1I;65:;VYE.CII<U9A;&ED240H)&ED*2D@>PH@("`@("`@("`@
M("`D7T1!5$5?5$E-15I/3D5?1$5&055,5"`]("1I9#L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!497-T<R!I9B!G:79E;B!I9"!I<R!R97!R
M97-E;G1E9"!I;B!T:&4@)%]$051%7U1)345:3TY%7T1!5$$@=&EM92!Z;VYE
M(&1A=&$*("`@("`J"B`@("`@*B!497-T<R!I9B!G:79E;B!I9"!I<R!R97!R
M97-E;G1E9"!I;B!T:&4@)%]$051%7U1)345:3TY%7T1!5$$@=&EM92!Z;VYE
M(&1A=&$*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A
M<F%M('-T<FEN9R`D:60@=&AE(&ED('1O('1E<W0*("`@("`J($!R971U<FX@
M8F]O;&5A;B!T<G5E(&EF('1H92!S=7!P;&EE9"!)1"!I<R!V86QI9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<U9A;&ED240H)&ED*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$%403L*("`@("`@("!I9BAI<W-E
M="@D7T1!5$5?5$E-15I/3D5?1$%405LD:61=*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@27,@
M=&AI<R!T:6UE('IO;F4@97%U86P@=&\@86YO=&AE<@H@("`@("H*("`@("`J
M(%1E<W1S('1O('-E92!I9B!T:&ES('1I;64@>F]N92!I<R!E<75A;"`H:61S
M(&UA=&-H*0H@("`@("H@=&\@82!G:79E;B!$871E7U1I;65:;VYE(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M(&]B:F5C="!$871E7U1I;65:;VYE("1T>B!T:&4@=&EM97IO;F4@=&\@=&5S
M=`H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AI<R!T:6UE('IO
M;F4@:7,@97%U86P@=&\@=&AE('-U<'!L:65D('1I;64@>F]N90H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<T5Q=6%L*"1T>BD*("`@('L*("`@("`@("!I9BAS
M=')C87-E8VUP*"1T:&ES+3YI9"P@)'1Z+3YI9"D@/3T@,"D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@27,@=&AI<R!T:6UE('IO;F4@97%U:79A;&5N="!T;R!A;F]T:&5R"B`@
M("`@*@H@("`@("H@5&5S=',@=&\@<V5E(&EF('1H:7,@=&EM92!Z;VYE(&ES
M(&5Q=6EV86QE;G0@=&\*("`@("`J(&$@9VEV96X@=&EM92!Z;VYE(&]B:F5C
M="X@($5Q=6EV86QE;F-E(&EN('1H:7,@8V]N=&5X=`H@("`@("H@:7,@9&5F
M:6YE9"!B>2!T:&4@='=O('1I;64@>F]N97,@:&%V:6YG(&%N(&5Q=6%L(')A
M=PH@("`@("H@;V9F<V5T(&%N9"!A;B!E<75A;"!S971T:6YG(&]F(")H87-D
M<W0B+B`@5&AI<R!I<R!N;W0@=')U90H@("`@("H@97%U:79A;&5N8V4L(&%S
M('1H92!T=V\@=&EM92!Z;VYE<R!M87D@:&%V92!D:69F97)E;G0@<G5L97,*
M("`@("`J(&9O<B!T:&4@;V)S97)V86YC92!O9B!$4U0L(&)U="!T:&ES(&EM
M<&QE;65N=&%T:6]N(&1O97,@;F]T"B`@("`@*B!K;F]W($135"!R=6QE<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B
M:F5C="!$871E7U1I;65:;VYE("1T>B!T:&4@=&EM97IO;F4@;V)J96-T('1O
M('1E<W0*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@=&EM
M92!Z;VYE(&ES(&5Q=6EV86QE;G0@=&\@=&AE('-U<'!L:65D('1I;64@>F]N
M90H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5Q=6EV86QE;G0H)'1Z*0H@("`@
M>PH@("`@("`@(&EF*"1T:&ES+3YO9F9S970@/3T@)'1Z+3YO9F9S970@)B8@
M)'1H:7,M/FAA<V1S="`]/2`D='HM/FAA<V1S="D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T<G5E(&EF('1H:7,@>F]N92!O8G-E<G9E<R!D87EL:6=H="!S879I
M;F=S('1I;64*("`@("`J"B`@("`@*B!2971U<FYS('1R=64@:68@=&AI<R!Z
M;VYE(&]B<V5R=F5S(&1A>6QI9VAT('-A=FEN9W,@=&EM90H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U
M92!I9B!T:&ES('1I;64@>F]N92!H87,@1%-4"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AA<T1A>6QI9VAT5&EM92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YH87-D<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@9VEV
M96X@9&%T92]T:6UE(&EN($135"!F;W(@=&AI<R!T:6UE('IO;F4*("`@("`J
M"B`@("`@*B!!='1E;7!T<R!T;R!D971E<FUI;F4@:68@82!G:79E;B!$871E
M(&]B:F5C="!R97!R97-E;G1S(&$@9&%T92]T:6UE"B`@("`@*B!T:&%T(&ES
M(&EN($135"!F;W(@=&AI<R!T:6UE('IO;F4N("!705).24Y'4SH@=&AI<R!B
M87-I8V%L;'D@871T96UP=',@=&\*("`@("`J(")T<FEC:R(@=&AE('-Y<W1E
M;2!I;G1O('1E;&QI;F<@=7,@:68@=V4G<F4@:6X@1%-4(&9O<B!A(&=I=F5N
M('1I;64@>F]N92X*("`@("`J(%1H:7,@=7-E<R!P=71E;G8H*2!W:&EC:"!M
M87D@;F]T('=O<FL@:6X@<V%F92!M;V1E+"!A;F0@<F5L:65S(&]N('5N:7@@
M=&EM90H@("`@("H@=VAI8V@@:7,@;VYL>2!V86QI9"!F;W(@9&%T97,@9G)O
M;2`Q.3<P('1O('XR,#,X+B`@5&AI<R!R96QI97,@;VX@=&AE"B`@("`@*B!U
M;F1E<FQY:6YG($]3(&-A;&QS+"!S;R!I="!M87D@;F]T('=O<FL@;VX@5VEN
M9&]W<R!O<B!O;B!A('-Y<W1E;2!W:&5R90H@("`@("H@>F]N96EN9F\@:7,@
M;F]T(&EN<W1A;&QE9"!O<B!C;VYF:6=U<F5D('!R;W!E<FQY+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A
M=&4@)&1A=&4@=&AE(&1A=&4O=&EM92!T;R!T97-T"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@=')U92!I9B!T:&ES(&1A=&4@:7,@:6X@1%-4(&9O<B!T:&ES
M('1I;64@>F]N90H@("`@("HO"B`@("!F=6YC=&EO;B!I;D1A>6QI9VAT5&EM
M92@D9&%T92D*("`@('L*("`@("`@("`D96YV7W1Z(#T@(B(["B`@("`@("`@
M:68H9V5T96YV*")46B(I*2!["B`@("`@("`@("`@("1E;G9?='H@/2!G971E
M;G8H(E1:(BD["B`@("`@("`@?0H@("`@("`@('!U=&5N=B@B5%H](BXD=&AI
M<RT^:60I.PH@("`@("`@("1L=&EM92`](&QO8V%L=&EM92@D9&%T92T^9V5T
M5&EM92@I+"!T<G5E*3L*("`@("`@("!P=71E;G8H(E1:/2(N)&5N=E]T>BD[
M"B`@("`@("`@<F5T=7)N("1L=&EM95LG=&U?:7-D<W0G73L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!T:&4@1%-4(&]F9G-E="!F;W(@=&AI<R!T:6UE
M('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS('1H92!$4U0@;V9F<V5T(&]F
M('1H:7,@=&EM92!Z;VYE+"!I;B!M:6QL:7-E8V]N9',L"B`@("`@*B!I9B!T
M:&4@>F]N92!O8G-E<G9E<R!$4U0L('IE<F\@;W1H97)W:7-E+B`@0W5R<F5N
M=&QY('1H90H@("`@("H@1%-4(&]F9G-E="!I<R!H87)D+6-O9&5D('1O(&]N
M92!H;W5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N(&EN="!T:&4@1%-4(&]F9G-E="P@:6X@;6EL;&ES96-O;F1S(&]R
M('IE<F\@:68@=&AE('IO;F4@9&]E<R!N;W0@;V)S97)V92!$4U0*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T1%-44V%V:6YG<R@I"B`@("!["B`@("`@("`@
M:68H)'1H:7,M/FAA<V1S="D@>PH@("`@("`@("`@("!R971U<FX@,S8P,#`P
M,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE($135"UC;W)R
M96-T960@;V9F<V5T('1O(%540R!F;W(@=&AE(&=I=F5N(&1A=&4*("`@("`J
M"B`@("`@*B!!='1E;7!T<R!T;R!G970@=&AE(&]F9G-E="!T;R!55$,@9F]R
M(&$@9VEV96X@9&%T92]T:6UE+"!T86MI;F<@:6YT;PH@("`@("H@86-C;W5N
M="!D87EL:6=H="!S879I;F=S('1I;64L(&EF('1H92!T:6UE('IO;F4@;V)S
M97)V97,@:70@86YD(&EF"B`@("`@*B!I="!I<R!I;B!E9F9E8W0N("!0;&5A
M<V4@<V5E('1H92!705).24Y'4R!O;B!$871E.CI4:6UE6F]N93HZ:6Y$87EL
M:6=H=%1I;64H*2X*("`@("`J"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!P87)A;2!O8FIE8W0@1&%T92`D9&%T92!T:&4@1&%T92!T
M;R!T97-T"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@8V]R<F5C=&5D(&]F9G-E
M="!T;R!55$,@:6X@;6EL;&ES96-O;F1S"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$]F9G-E="@D9&%T92D*("`@('L*("`@("`@("!I9B@D=&AI<RT^:6Y$
M87EL:6=H=%1I;64H)&1A=&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;V9F<V5T("L@)'1H:7,M/F=E=$135%-A=FEN9W,H*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]F9G-E=#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L:7-T
M(&]F('9A;&ED('1I;64@>F]N92!I9"!S=')I;F=S"B`@("`@*@H@("`@("H@
M4F5T=7)N<R!T:&4@;&ES="!O9B!V86QI9"!T:6UE('IO;F4@:60@<W1R:6YG
M<PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(&%N(&%R<F%Y(&]F('-T<FEN9W,@=VET:"!T:&4@=F%L:60@=&EM
M92!Z;VYE($E$<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971!=F%I;&%B;&5)
M1',H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$%4
M03L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D7T1!5$5?5$E-15I/3D5?
M1$%402D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!I9"!F
M;W(@=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS('1H92!T
M:6UE('IO;F4@:60@(&9O<B!T:&ES('1I;64@>F]N92P@:2YE+B`B06UE<FEC
M82]#:&EC86=O(@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R!T:&4@:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T240H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^:60["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L;VYG(&YA;64@9F]R('1H
M:7,@=&EM92!Z;VYE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@;&]N9R!N
M86UE(&9O<B!T:&ES('1I;64@>F]N92P*("`@("`J(&DN92X@(D-E;G1R86P@
M4W1A;F1A<F0@5&EM92(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B!S=')I;F<@=&AE(&QO;F<@;F%M90H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971,;VYG3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YL;VYG;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('-H;W)T(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE"B`@("`@*@H@
M("`@("H@4F5T=7)N<R!T:&4@<VAO<G0@;F%M92!F;W(@=&AI<R!T:6UE('IO
M;F4L(&DN92X@(D-35"(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B!S=')I;F<@=&AE('-H;W)T(&YA;64*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4VAO<G1.86UE*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G-H;W)T;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE($135"!L;VYG(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE"B`@
M("`@*@H@("`@("H@4F5T=7)N<R!T:&4@1%-4(&QO;F<@;F%M92!F;W(@=&AI
M<R!T:6UE('IO;F4L(&DN92X@(D-E;G1R86P@1&%Y;&EG:'0@5&EM92(*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!S=')I
M;F<@=&AE(&1A>6QI9VAT('-A=FEN9W,@=&EM92!L;VYG(&YA;64*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T1%-43&]N9TYA;64H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^9'-T;&]N9VYA;64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!$4U0@<VAO<G0@;F%M92!F;W(@=&AI<R!T:6UE
M('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS('1H92!$4U0@<VAO<G0@;F%M
M92!F;W(@=&AI<R!T:6UE('IO;F4L(&DN92X@(D-$5"(*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!S=')I;F<@=&AE(&1A
M>6QI9VAT('-A=FEN9W,@=&EM92!S:&]R="!N86UE"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$135%-H;W)T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YD<W1S:&]R=&YA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!R87<@*&YO;BU$4U0M8V]R<F5C=&5D*2!O9F9S970@9G)O
M;2!55$,O1TU4(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*("`@("`J(%)E
M='5R;G,@=&AE(')A=R`H;F]N+4135"UC;W)R96-T960I(&]F9G-E="!F<F]M
M(%540R]'350@9F]R('1H:7,@=&EM92!Z;VYE"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!O9F9S970L(&EN
M(&UI;&QI<V5C;VYD<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971287=/9F9S
M970H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;V9F<V5T.PH@("`@
M?0I]"@H*+R\*+R\@5&EM92!:;VYE($1A=&$*+R\@(&]F9G-E="!I<R!I;B!M
M:6QI<V5C;VYD<PHO+PHD1TQ/0D%,4ULG7T1!5$5?5$E-15I/3D5?1$%402==
M(#T@87)R87DH"B`@("`G171C+T=-5"LQ,B<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+30S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"TQ,CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TQ,CHP
M,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4
M*S$Q)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3$Q.C`P)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1TU4+3$Q.C`P)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)TU)5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W0@
M4V%M;V$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T%P:6$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=797-T(%-A;6]A(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=74U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4&%C:69I8R]-:61W87DG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=386UO82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G4U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A
M8VEF:6,O3FEU92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYI=64@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TY55"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U!A9V]?4&%G;R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U-A;6]A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=34U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4&%C:69I8R]386UO82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-A;6]A
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=34U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G55,O4V%M;V$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=386UO82!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G4U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O061A:R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)TAA=V%I:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G2$%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=(87=A:6DM06QE=71I86X@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TA!
M1%0G("DL"B`@("`G06UE<FEC82]!=&MA)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M2&%W86EI+4%L975T:6%N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=(05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TAA=V%I:2U!;&5U=&EA;B!$87EL
M:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2$%$5"<@
M*2P*("`@("=%=&,O1TU4*S$P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3$P
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3$P.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TA35"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TAA=V%I:2!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G2%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O1F%K86]F;R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1O
M:V5L874@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1+5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TAO;F]L
M=6QU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&%W86EI(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]*;VAN<W1O;B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TAA=V%I:2!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G2%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U!A8VEF:6,O4F%R;W1O;F=A)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V]O:R!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-+
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC
M+U1A:&ET:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1A:&ET:2!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G5$%(5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+TA35#$P)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G2&%W86EI(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=(4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G55,O06QE=71I86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(87=A:6DM06QE
M=71I86X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TA!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G2&%W86EI+4%L975T:6%N($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=(0414)R`I+`H@("`@)U53
M+TAA=V%I:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TAA=V%I:2!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2%-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O36%R<75E<V%S)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S0R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36%R<75E<V%S(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=-05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%35"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L87-K82!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04M35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T%+1%0G("DL"B`@("`G06UE<FEC82]!;F-H;W)A9V4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QA<VMA($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!2T14)R`I
M+`H@("`@)T%M97)I8V$O2G5N96%U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G06QA
M<VMA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!
M2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T%L87-K82!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G04M$5"<@*2P*("`@("=!;65R:6-A+TYO;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QA<VMA($1A
M>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!2T14
M)R`I+`H@("`@)T%M97)I8V$O66%K=71A="<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%L87-K82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G04M35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G171C+T=-5"LY
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`Y.C`P)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4+3`Y.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U!A8VEF:6,O1V%M8FEE<B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=A;6)I97(@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=!
M350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M
M5B]94U0Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1V%M8FEE<B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1T%-5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+UE35#E91%0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QA<VMA($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!2T14)R`I+`H@("`@)U53
M+T%L87-K82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L87-K82!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04M35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!
M;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T%+1%0G("DL"B`@("`G06UE<FEC82]$87=S;VXG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T%M
M97)I8V$O16YS96YA9&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T%M97)I8V$O3&]S7T%N9V5L97,G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14
M)R`I+`H@("`@)T%M97)I8V$O5&EJ=6%N82<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G06UE<FEC82]6
M86YC;W5V97(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G4$14)R`I+`H@("`@)T%M97)I8V$O5VAI=&5H;W)S92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@
M("`G0V%N861A+U!A8VEF:6,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T-A;F%D82]9=6MO;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL
M"B`@("`G171C+T=-5"LX)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`X.C`P
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`X.C`P)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUE>&EC;R]"86IA3F]R=&4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14
M)R`I+`H@("`@)U!35"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=01%0G("DL"B`@("`G4%-4.%!$5"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G4&%C
M:69I8R]0:71C86ER;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!I=&-A:7)N(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]04U0X
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G4&ET8V%I<FX@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+U!35#A01%0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@
M)U53+U!A8VEF:6,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G4$14)R`I+`H@("`@)U53+U!A8VEF:6,M3F5W)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@1&%Y;&EG:'0@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@
M("=!;65R:6-A+T)O:7-E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O0V%M8G)I9&=E
M7T)A>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U
M;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+T-H:6AU86AU82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@
M("=!;65R:6-A+T1A=W-O;E]#<F5E:R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO
M=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE
M<FEC82]$96YV97(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=-1%0G("DL"B`@("`G06UE<FEC82]%9&UO;G1O;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@
M*2P*("`@("=!;65R:6-A+TAE<FUO<VEL;&\G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%M97)I8V$O26YU=FEK)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O36%Z871L86XG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-
M1%0G("DL"B`@("`G06UE<FEC82]0:&]E;FEX)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!;65R:6-A+U-H:7!R;V-K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A
M:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O665L;&]W
M:VYI9F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO
M=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=-1%0G("DL"B`@("`G0V%N861A+TUO=6YT86EN)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@
M)T5T8R]'350K-R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP-SHP,"<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP-SHP,"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=-4U0G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G35-4-TU$
M5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A
M:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)TU$5"<@*2P*("`@("=-97AI8V\O0F%J85-U<B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=.879A
M:F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT
M86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=-1%0G("DL"B`@("`G4$Y4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A
M:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6
M+TU35#<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O35-4-TU$5"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@
M*2P*("`@("=54R]!<FEZ;VYA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A
M:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=54R]-;W5N
M=&%I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U
M;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+T)E;&EZ92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+T-A;F-U;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R
M86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G06UE<FEC82]#:&EC86=O
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$
M5"<@*2P*("`@("=!;65R:6-A+T-O<W1A7U)I8V$G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82]%;%]386QV861O<B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+T=U871E;6%L82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TUA;F%G
M=6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]-96YO;6EN964G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@
M("`@)T%M97)I8V$O365R:61A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=!;65R:6-A+TUE>&EC;U]#
M:71Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O36]N=&5R<F5Y)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*
M("`@("=!;65R:6-A+TYO<G1H7T1A:V]T82]#96YT97(G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M
M97)I8V$O4F%I;GE?4FEV97(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M97)I8V$O4F%N:VEN7TEN
M;&5T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T5$5"<@*2P*("`@("=!;65R:6-A+U)E9VEN82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!;65R:6-A+U-W:69T7T-U<G)E;G0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE
M<FEC82]496=U8VEG86QP82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U=I
M;FYI<&5G)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-$5"<@*2P*("`@("=#4U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT
M<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T-35#9#1%0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@
M("`@)T-A;F%D82]#96YT<F%L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=#86YA9&$O16%S="U387-K
M871C:&5W86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V%N861A+U-A<VMA=&-H97=A
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=#:&EL92]%87-T97))<VQA;F0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97(@27,N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%05-35"<@*2P*("`@
M("=%=&,O1TU4*S8G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#8Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#8Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G365X:6-O+T=E;F5R86PG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4&%C:69I8R]%87-T97(G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97(@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=%05-35"<@*2P*("`@("=086-I9FEC+T=A
M;&%P86=O<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=A;&%P86=O<R!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1T%,5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+T-35#8G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4WES=&5M5B]#4U0V0T14)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=54R]#96YT<F%L)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@
M*2P*("`@("=!;65R:6-A+T)O9V]T82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O
M;&]M8FEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#3U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]#87EM
M86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]$971R;VET)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@
M("=!;65R:6-A+T5I<G5N97!E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G06-R92!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1F]R=%]787EN92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T=R86YD7U1U<FLG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@
M)T%M97)I8V$O1W5A>6%Q=6EL)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16-U861O
M<B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O2&%V86YA)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@
M*2P*("`@("=!;65R:6-A+TEN9&EA;F$O26YD:6%N87!O;&ES)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O26YD:6%N82]+;F]X)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%M97)I8V$O26YD:6%N82]-87)E;F=O)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%M97)I8V$O26YD:6%N82]6979A>2<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+TEN9&EA;F%P;VQI<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TEQ
M86QU:70G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S
M=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G1414)R`I+`H@("`@)T%M97)I8V$O2F%M86EC82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+TME;G1U8VMY+TQO=6ES=FEL;&4G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M
M97)I8V$O2V5N='5C:WDO36]N=&EC96QL;R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]+
M;F]X7TE.)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O3&EM82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U!E<G4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U!%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+TQO=6ES=FEL;&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O36]N=')E86PG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414
M)R`I+`H@("`@)T%M97)I8V$O3F%S<V%U)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+TYE
M=U]9;W)K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+TYI<&EG;VXG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M
M97)I8V$O4&%N86UA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4&%N9VYI
M<G1U;F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S
M=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G1414)R`I+`H@("`@)T%M97)I8V$O4&]R="UA=2U0<FEN8V4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]0;W)T;U]!8W)E)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G06-R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M4FEO7T)R86YC;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X
M,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%C<F4@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%#5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U1H=6YD97)?0F%Y)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@
M("="<F%Z:6PO06-R92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%C<F4@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%#5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=#86YA9&$O16%S=&5R;B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G
M0W5B82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT
M<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#1%0G("DL"B`@("`G15-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=%4U0U1414)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@
M("=%=&,O1TU4*S4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#4Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#4Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2454)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TIA;6%I8V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]%4U0U)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U-Y<W1E;58O15-4-45$5"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G55,O16%S
M="U);F1I86YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U53+T5A<W1E<FXG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@
M("`@)U53+TEN9&EA;F$M4W1A<FME)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U53+TUI
M8VAI9V%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+T%N9W5I;&QA)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+T%N=&EG=6$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!
M=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M
M97)I8V$O07)U8F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O07-U;F-I
M;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=087)A9W5A>2!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4%E4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A<F%G=6%Y(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4%E35"<@*2P*
M("`@("=!;65R:6-A+T)A<F)A9&]S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L
M86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+T)O85]6:7-T82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%M87IO;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O0V%R86-A
M<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U9E;F5Z=65L82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5D54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%M97)I8V$O0W5I86)A)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G06UA>F]N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G06UA>F]N(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G04U35"<@*2P*("`@("=!;65R:6-A+T-U
M<F%C86\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1&]M:6YI8V$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O1VQA8V5?0F%Y)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!=&QA;G1I8R!$87EL:6=H="!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@
M)T%M97)I8V$O1V]O<V5?0F%Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT
M:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=!=&QA;G1I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T%M97)I8V$O1W)E;F%D
M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]'=6%D96QO=7!E)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+T=U>6%N82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=U>6%N82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1UE4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M2&%L:69A>"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M071L86YT:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T%$5"<@*2P*("`@("=!;65R:6-A+TQA7U!A>B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T)O;&EV:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T)/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+TUA;F%U<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%M87IO;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O36%R=&EN
M:7%U92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]-;VYT<V5R<F%T)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U!O<G1?;V9?4W!A:6XG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%M97)I8V$O4&]R=&]?5F5L:&\G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!;6%Z;VX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+U!U97)T;U]2:6-O)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+U-A;G1I86=O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;&4@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-,5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#:&EL
M92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-,
M4U0G("DL"B`@("`G06UE<FEC82]386YT;U]$;VUI;F=O)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+U-T7TMI='1S)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+U-T7TQU8VEA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U-T
M7U1H;VUA<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]3=%]6:6YC96YT
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U1H=6QE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+U1O<G1O;&$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!
M=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M
M97)I8V$O5FER9VEN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A+U!A
M;&UE<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6QE(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#3%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0VAI;&4@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#3%-4)R`I+`H@("`@
M)T%T;&%N=&EC+T)E<FUU9&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I
M8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T%T;&%N=&EC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=!1%0G("DL"B`@("`G071L86YT:6,O4W1A;FQE
M>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T9A;&ML86YD($ES+B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1DM4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T9A;&ML86YD($ES
M+B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T9+
M4U0G("DL"B`@("`G0G)A>FEL+U=E<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!
M;6%Z;VX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#86YA
M9&$O071L86YT:6,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T%T;&%N=&EC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=!1%0G("DL"B`@("`G0VAI;&4O0V]N=&EN96YT86PG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#:&EL92!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0TQ4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T-H:6QE(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0TQ35"<@*2P*("`@("=%=&,O1TU4
M*S0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#0Z,#`G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350M,#0Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4%)4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT
M:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6
M+T%35#0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O05-4-$%$5"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G071L86YT:6,@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%$5"<@
M*2P*("`@("=!;65R:6-A+U-T7TIO:&YS)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3(V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M3F5W9F]U;F1L86YD(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=.4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G3F5W9F]U;F1L86YD($1A>6QI9VAT(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=.1%0G("DL"B`@("`G
M0TY4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3(V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W9F]U;F1L86YD(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M3F5W9F]U;F1L86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=.1%0G("DL"B`@("`G0V%N861A+TYE=V9O=6YD;&%N9"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$R-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TYE=V9O=6YD;&%N9"!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3E-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYE=V9O
M=6YD;&%N9"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G3D14)R`I+`H@("`@)T%'5"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R
M9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05)4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O07)A
M9W5A:6YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)A>FEL(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E)35"<@*2P*
M("`@("=!;65R:6-A+T)E;&5M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]"=65N;W-?06ER
M97,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!<F=E;G1I;F4@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+T-A=&%M87)C82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M
M97)I8V$O0V%Y96YN92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9R96YC:"!'=6EA
M;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=&5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T-O<F1O8F$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!<F=E;G1I;F4@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+T9O<G1A;&5Z82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T)R87II;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0E)4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T)R87II;"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G06UE<FEC82]';V1T:&%B)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!'<F5E;FQA;F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U='5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($=R
M965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)U='4U0G("DL"B`@("`G06UE<FEC82]*=6IU>2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M
M97)I8V$O36%C96EO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)A>FEL
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E)3
M5"<@*2P*("`@("=!;65R:6-A+TUE;F1O>F$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!<F=E;G1I;F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%2
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+TUI<75E;&]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&EE<G)E("8@36EQ=65L
M;VX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!-
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G4&EE<G)E("8@36EQ=65L;VX@1&%Y;&EG:'0@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!-1%0G("DL"B`@("`G06UE
M<FEC82]-;VYT979I9&5O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G57)U9W5A>2!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G55E4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4&%R86UA<FEB;R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U-U<FEN86UE(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=34E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]296-I9F4G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="
M<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)25"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("="4E-4)R`I+`H@("`@)T%M97)I8V$O4F]S87)I;R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%M97)I8V$O4V%O7U!A=6QO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A
M>FEL(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G0G)A>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0E)35"<@*2P*("`@("="150G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="
M<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)25"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("="4E-4)R`I+`H@("`@)T)R87II;"]%87-T)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0G)A>FEL(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("="4E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G0G)A>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0E)35"<@*2P*("`@("=%=&,O1TU4*S,G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='350M,#,Z,#`G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350M,#,Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82].;W)O;FAA)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=&
M97)N86YD;R!D92!.;W)O;FAA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=&3E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M071L86YT:6,O4V]U=&A?1V5O<F=I82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V]U
M=&@@1V5O<F=I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T)R87II;"]$94YO<F]N:&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TW,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9E<FYA;F1O
M(&1E($YO<F]N:&$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T9.
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4
M*S(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TW,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP,CHP,"<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=-5"TP,CHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+U-C;W)E<V)Y<W5N9"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!'<F5E;FQA;F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T5'5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($=R965N;&%N9"!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5'4U0G
M("DL"B`@("`G071L86YT:6,O07IO<F5S)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!
M>F]R97,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%:3U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G07IO<F5S(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G05I/4U0G("DL"B`@("`G071L86YT:6,O0V%P95]697)D92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V%P92!697)D92!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0U94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T5T8R]'350K,2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`Q
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`Q.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]!8FED:F%N
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+T%C8W)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T)A;6%K;R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%F<FEC82]"86YJ=6PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0FES<V%U)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+T-A<V%B;&%N8V$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%
M=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]#;VYA
M:W)Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G069R:6-A+T1A:V%R)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC
M:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T5L7T%A
M:75N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!9G)I8V$O1G)E971O=VXG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E
M96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O
M3&]M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%F<FEC82]-;VYR;W9I82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E
M;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82].
M;W5A:V-H;W1T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T]U86=A9&]U9V]U)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M069R:6-A+U-A;U]4;VUE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+U1I;6)U:W1U)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82]$86YM87)K<VAA=FXG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H
M($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=&QA;G1I8R]#86YA
M<GDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E
M86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=7
M15-4)R`I+`H@("`@)T%T;&%N=&EC+T9A97)O92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T
M97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G071L86YT
M:6,O36%D96ER82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5V5S=&5R
M;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)U=%4U0G("DL"B`@("`G071L86YT:6,O4F5Y:VIA=FEK)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G071L86YT:6,O4W1?2&5L96YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G16ER92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)TER:7-H(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G25-4)R`I+`H@("`@)T5T8R]'350G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M*S`P.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T
M8R]'350K,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G171C+T=-5"TP)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP,#HP,"<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4,"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("='350K,#`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#`Z
M,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=R
M965N=VEC:"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T5T8R]50U0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V]O<F1I;F%T
M960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=5
M5$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+U54
M0R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=%=&,O56YI=F5R<V%L)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O
M;W)D:6YA=&5D(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T5T8R]:=6QU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D:6YA=&5D(%5N:79E<G-A;"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G551#)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5U<F]P92]"96QF87-T)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G0G)I=&ES:"!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)35"<@*2P*("`@("=%=7)O<&4O
M1'5B;&EN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G27)I<V@@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=)4U0G("DL"B`@
M("`G175R;W!E+TQI<V)O;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G175R;W!E+TQO;F1O;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T)R:71I<V@@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("="4U0G("DL"B`@("`G1T(G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("="<FET:7-H(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E-4)R`I+`H@("`@)T="+45I
M<F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("="<FET:7-H(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E-4)R`I+`H@("`@
M)T=-5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T=-5#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T=R965N=VEC:"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEC96QA
M;F0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=0;W)T=6=A;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G54-4)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-O;W)D:6YA=&5D(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U540R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV97)S86P@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=5;FEV97)S86PG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=55$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G5T54)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($5U
M<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G5T535"<@*2P*("`@("=:=6QU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D:6YA=&5D
M(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G551#
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]!
M;&=I97)S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0F%N9W5I)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%F<FEC82]"<F%Z>F%V:6QL92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=7
M97-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I
M8V$O0V5U=&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T%F<FEC82]$;W5A;&$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+TMI;G-H87-A)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E
M<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC
M82],86=O<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3&EB<F5V:6QL92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!9G)I8V$O3'5A;F1A)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E
M<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC
M82]-86QA8F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TYD:F%M96YA)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%F<FEC82].:6%M97DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S
M=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7
M050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A
M+U!O<G1O+4YO=F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+U1U;FES)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!9G)I8V$O5VEN9&AO96LG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=7050G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T%35"<@*2P*("`@("=!<F-T
M:6,O3&]N9WEE87)B>65N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=!=&QA;G1I8R]*86Y?
M36%Y96XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!'<F5E;FQA;F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5'5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T
M97)N($=R965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5'4U0G("DL"B`@("`G0T54)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=#
M15-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@5&EM92(L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^(")#96YT<F%L
M($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0T535"<@*2P*("`@("=%0U0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5T8R]'
M350M,2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#$Z,#`G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350K,#$Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G175R;W!E+T%M<W1E<F1A;2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@
M("`G175R;W!E+T%N9&]R<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%
M=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]"96QG
M<F%D92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+T)E<FQI;B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL
M"B`@("`G175R;W!E+T)R871I<VQA=F$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]"<G5S<V5L<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+T)U9&%P97-T)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P
M96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0T535"<@*2P*("`@("=%=7)O<&4O0V]P96YH86=E;B<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@
M("`G175R;W!E+T=I8G)A;'1A<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+TQJ
M=6)L:F%N82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+TQU>&5M8F]U<F<G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E
M86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#
M15-4)R`I+`H@("`@)T5U<F]P92]-861R:60G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U
M<F]P92]-86QT82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+TUO;F%C;R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%
M4U0G("DL"B`@("`G175R;W!E+T]S;&\G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]087)I<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U!R86=U92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G
M("DL"B`@("`G175R;W!E+U)O;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]3
M86Y?36%R:6YO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#
M96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4V%R86IE=F\G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E
M86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#
M15-4)R`I+`H@("`@)T5U<F]P92]3:V]P:F4G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U
M<F]P92]3=&]C:VAO;&TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]4:7)A;F4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#15-4)R`I+`H@("`@)T5U<F]P92]6861U>B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G
M175R;W!E+U9A=&EC86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]6:65N;F$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#15-4)R`I+`H@("`@)T5U<F]P92]787)S87<G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@
M)T5U<F]P92]:86=R96(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]:=7)I8V@G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#15-4)R`I+`H@("`@)TU%5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-:61D;&4@
M175R;W!E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G36ED9&QE($5U<F]P92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)TU%4U0G("DL"B`@("`G4&]L86YD)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@
M*2P*("`@("=!4E0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A
M;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%F<FEC82]";&%N='ER92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L($%F<FEC86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!9G)I8V$O0G5J=6UB=7)A)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%F<FEC82]#86ER;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G069R:6-A+T=A8F]R;VYE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%F<FEC82](87)A<F4G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M069R:6-A+TIO:&%N;F5S8G5R9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3;W5T:"!!
M9G)I8V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U-!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R
M:6-A+TMI9V%L:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($%F<FEC86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3'5B=6UB87-H:2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L($%F<FEC86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!9G)I8V$O3'5S86MA)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F
M<FEC82]-87!U=&\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUA<V5R=2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=3;W5T:"!!9G)I8V$@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U-!4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUB86)A;F4G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G4V]U=&@@069R:6-A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=305-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%F<FEC82]4<FEP;VQI)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+T%M;6%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T
M97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G14535"<@*2P*("`@("=!<VEA+T)E:7)U="<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL
M"B`@("`G07-I82]$86UA<V-U<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G07-I82]'87IA
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U
M<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G14535"<@*2P*("`@("=!<VEA+TES=&%N8G5L)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@
M("=!<VEA+TIE<G5S86QE;2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)<W)A96P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=)<W)A96P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)TE$5"<@*2P*("`@("=!<VEA+TYI8V]S:6$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I
M+`H@("`@)T%S:6$O5&5L7T%V:78G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27-R865L
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G27-R865L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=)1%0G("DL"B`@("`G0T%4)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T5%5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R
M;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T5%4U0G("DL"B`@("`G16=Y<'0G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5T
M8R]'350M,B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#(Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350K,#(Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G175R;W!E+T%T:&5N<R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@
M("`G175R;W!E+T)U8VAA<F5S="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+T-H
M:7-I;F%U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T
M97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O<&4O2&5L<VEN:VDG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4
M)R`I+`H@("`@)T5U<F]P92])<W1A;F)U;"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R
M;W!E+TMA;&EN:6YG<F%D)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R
M;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O<&4O2VEE=B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T5%4U0G("DL"B`@("`G175R;W!E+TUI;G-K)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%
M=7)O<&4O3FEC;W-I82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+U)I9V$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E
M86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M15-4)R`I+`H@("`@)T5U<F]P92]3:6UF97)O<&]L)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@
M("=%=7)O<&4O4V]F:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]486QL:6YN
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O5&ER87-P;VPG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@
M("`@)T5U<F]P92]5>FAG;W)O9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+U9I
M;&YI=7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T5U<F]P92]:87!O<F]Z:'EE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1453
M5"<@*2P*("`@("=)<W)A96PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27-R865L(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G27-R865L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=)1%0G("DL"B`@("`G3&EB>6$G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U1U<FME>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S
M=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5%4U0G("DL"B`@("`G069R:6-A+T%D9&ES7T%B86)A)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!9G)I8V$O07-M97)A)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M9G)I8V$O1&%R7V5S7U-A;&%A;2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T1J
M:6)O=71I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O2V%M<&%L82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+TMH87)T;W5M)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I
M8V$O36]G861I<VAU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3F%I<F]B:2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]3>6]W82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G4WEO=V$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-9
M3U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!
M9&5N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!<F%B:6$@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T)A9VAD860G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%R86)I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T%R86)I82!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T%S:6$O
M0F%H<F%I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]+=7=A:70G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T%R86)I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O46%T87(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R86)I82!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4FEY861H
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!<F%B:6$@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=%050G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]'350M
M,R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`P)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4*S`S.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T5U<F]P92]-;W-C;W<G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TUO<V-O=R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G35-+)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)TUO<V-O=R!$87EL:6=H="!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G35-$)R`I+`H@("`@)TEN9&EA;B]!;G1A
M;F%N87)I=F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN9&EA;B]#;VUO<F\G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TEN9&EA;B]-87EO='1E)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=7+5-5
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=-;W-C;W<@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU32R<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W-C;W<@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU31"<@
M*2P*("`@("=!<VEA+U)I>6%D:#@W)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K
M,#,Z,#<G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]2:7EA9&@X
M."<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%S:6$O4FEY861H.#DG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"LP,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,SHP
M-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-:61E87-T
M+U)I>6%D:#@W)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,3(R
M-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#,Z,#<G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G36ED96%S="]2:7EA9&@X."<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)TUI9&5A<W0O4FEY861H.#DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP
M,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,SHP-R<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U1E:')A;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3(V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G27)A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G25)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)TER86X@4W5M97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)TE24U0G("DL"B`@("`G27)A;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3(V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G27)A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G25)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)TER86X@4W5M97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)TE24U0G("DL"B`@("`G07-I82]!<71A=2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G07%T874@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07%T874@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!45135"<@*2P*("`@("=!<VEA
M+T)A:W4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%Z97)B86EJ86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%:5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!>F5R8F%I:F%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G05I3
M5"<@*2P*("`@("=!<VEA+T1U8F%I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='=6QF
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]-=7-C
M870G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=U;&8@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!<VEA+U1B:6QI<VDG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=E;W)G:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("='96]R9VEA(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G1T535"<@*2P*("`@("=!<VEA+UEE<F5V86XG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%R;65N:6$@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=!<FUE;FEA(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04U35"<@*2P*("`@("=%=&,O
M1TU4+30G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-#HP,"<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=-5"LP-#HP,"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O4V%M87)A)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=386UA<F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-!
M350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G4V%M87)A(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G4T%-4U0G("DL"B`@("`G26YD:6%N+TUA:&4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U-E>6-H96QL97,@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U-#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=);F1I86XO36%U<FET:75S)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-
M875R:71I=7,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU55"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO4F5U
M;FEO;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4F5U;FEO;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4D54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)TY%5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)M96YI82!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%R
M;65N:6$@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=!35-4)R`I+`H@("`@)T%S:6$O2V%B=6PG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$V,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%F9VAA;FES=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!
M1E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!
M<71O8F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%Q=&]B92!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G05%45"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!<71O8F4@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!45135"<@*2P*
M("`@("=!<VEA+T%S:&=A8F%T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4=7)K;65N
M:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1-5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T%S:&MH86)A
M9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G5'5R:VUE;FES=&%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=4350G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G07-I82]":7-H:V5K)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=+:7)G:7IS=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+
M1U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G2VER9VEZ<W1A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)TM'4U0G("DL"B`@("`G07-I82]$=7-H86YB
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G5&%J:6MI<W1A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5$I4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%S:6$O2V%R86-H:2<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M4&%K:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!+5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U-A;6%R
M:V%N9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5'5R:VUE;FES=&%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=4350G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G07-I82]487-H:V5N="<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G57IB96MI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G55I4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S
M:6$O665K871E<FEN8G5R9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G665K871E<FEN
M8G5R9R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G645+5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=996MA=&5R:6YB=7)G(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G645+4U0G("DL"B`@("`G171C+T=-5"TU)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='350K,#4Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350K,#4Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G26YD:6%N+TME<F=U96QE;B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1G)E
M;F-H(%-O=71H97)N("8@06YT87)C=&EC($QA;F1S(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=41E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G26YD:6%N+TUA;&1I=F5S)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=-86QD:79E<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3594
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!,5"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4&%K:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U!+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+T-A;&-U='1A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q.3@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=);F1I82!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TE35"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3DX,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G26YD:6$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TE35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+TMA=&UA;F1U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R,#<P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.97!A
M;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3E!4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%N=&%R8W1I8V$O36%W<V]N
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=-87=S;VX@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TU!5U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06YT87)C=&EC82]6;W-T;VLG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U9O<W1O:R!T:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5D]35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T%L;6%T
M>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G06QM82U!=&$@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%,350G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QM82U!=&$@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!3$U35"<@*2P*
M("`@("=!<VEA+T-O;&]M8F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-R:2!,86YK
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3$M4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O1&%C8V$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T)A;F=L861E<V@@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T)$5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+T1H86MA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="86YG;&%D97-H
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="1%0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82].;W9O<VEB:7)S:R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G3F]V;W-I8FER<VL@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)TY/5E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3F]V;W-I8FER<VL@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=.3U935"<@
M*2P*("`@("=!<VEA+T]M<VLG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T]M<VL@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T]-4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3VUS
M:R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T]-
M4U-4)R`I+`H@("`@)T%S:6$O5&AI;6)U)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="
M:'5T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)45"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U1H:6UP:'4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T)H=71A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0E14)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T)$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0F%N9VQA9&5S:"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0D14)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]'350M-B<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1TU4*S`V.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M*S`V.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN
M9&EA;B]#:&%G;W,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TEN9&EA;B!/8V5A;B!4
M97)R:71O<GD@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE/5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U)A;F=O
M;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(S-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TUY86YM87(@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)TU-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=);F1I86XO0V]C;W,G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(S-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O
M8V]S($ES;&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-#
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T
M:6-A+T1A=FES)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=$879I<R!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1$%65"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!<VEA+T)A;F=K;VLG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)TEN9&]C:&EN82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M24-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O
M2&]V9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&]V9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G2$]65"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!<VEA+TIA:V%R=&$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E
M<W0@26YD;VYE<VEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7
M250G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]+
M<F%S;F]Y87)S:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2W)A<VYO>6%R<VL@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM2050G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G2W)A
M<VYO>6%R<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=+4D%35"<@*2P*("`@("=!<VEA+U!H;F]M7U!E;F@G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TEN9&]C:&EN82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G24-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%S:6$O4&]N=&EA;F%K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T($EN9&]N
M97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5TE4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4V%I9V]N)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=);F1O8VAI;F$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TE#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+U9I96YT:6%N92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G26YD
M;V-H:6YA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)0U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-5"TW)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='350K,#<Z,#`G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350K,#<Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G26YD:6%N+T-H<FES=&UA<R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0VAR:7-T;6%S($ES;&%N9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0UA4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U93
M5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G26YD;V-H:6YA(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=)0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06YT87)C=&EC82]#87-E>2<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G5V5S=&5R;B!3=&%N9&%R9"!4:6UE("A!=7-T<F%L:6$I)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%S:6$O0G)U;F5I)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="
M<G5N96D@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T).5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T-H;VYG<6EN
M9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!<VEA+T-H=6YG:VEN9R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0VAI;F$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!<VEA+TAA<F)I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+TAO;F=?2V]N9R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G2&]N9R!+;VYG(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=(2U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07-I82])<FMU='-K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)<FMU
M='-K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4DM4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TER:W5T<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=)4DM35"<@*2P*("`@("=!<VEA+TMA<VAG87(G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G07-I82]+=6%L85],=6UP=7(G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA
M;&%Y<VEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-650G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]+=6-H:6YG
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=-86QA>7-I82!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35E4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O36%C86\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6YA
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]-86YI
M;&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U!H:6QI<'!I;F5S(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=02%0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G07-I82]3:&%N9VAA:2<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0VAI;F$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M<VEA+U-I;F=A<&]R92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4VEN9V%P;W)E(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=31U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]486EP96DG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G07-I82]5:G5N9U]086YD86YG)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M96YT<F%L($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0TE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S
M:6$O56QA86YB86%T87(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U5L86%N8F%A=&%R
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=53$%4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O56QA;E]"871O<B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G56QA86YB86%T87(@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U5,050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G07-I82]5<G5M<6DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H
M:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A
M;&EA+U!E<G1H)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N(%-T86YD87)D
M(%1I;64@*$%U<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A
M;&EA+U=E<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@4W1A;F1A<F0@
M5&EM92`H075S=')A;&EA*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#5%0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G171C+T=-5"TX)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K
M,#@Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#@Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2&]N9VMO;F<G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TAO;F<@2V]N9R!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G2$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!20R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3:6YG87!O<F4G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U-I;F=A<&]R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4T=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%S:6$O0VAO:6)A;'-A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAO:6)A;'-A
M;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TA/5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T1I;&DG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W0@5&EM;W(@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U105"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+TIA>6%P=7)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T($EN
M9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14E4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4'EO;F=Y
M86YG)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=+;W)E82!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G2U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4V5O=6PG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)TMO<F5A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=+4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]4;VMY;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2F%P86X@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TI35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+UEA:W5T<VLG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)UEA:W5T<VL@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)UE!2U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G66%K='-K(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G64%+4U0G("DL"B`@("`G171C+T=-
M5"TY)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#DZ,#`G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350K,#DZ,#`G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G2E-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=*87!A;B!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2E-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TIA<&%N)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=*87!A;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G2E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U!A8VEF:6,O4&%L874G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A
M;&%U(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=05U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4D]+)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=+;W)E82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%#5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S0R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4
M:6UE("A.;W)T:&5R;B!497)R:71O<GDI)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%U<W1R86QI82]!9&5L86ED92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L:6$I)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@4W5M;65R(%1I
M;64@*%-O=71H($%U<W1R86QI82DG+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#4U0G("DL"B`@("`G075S=')A;&EA+T)R;VME;E](:6QL)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64@*%-O=71H($%U
M<W1R86QI82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@4W5M;65R(%1I;64@*%-O=71H
M($%U<W1R86QI82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0U-4)R`I+`H@("`@)T%U<W1R86QI82]$87)W:6XG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92`H3F]R=&AE
M<FX@5&5R<FET;W)Y*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O
M3F]R=&@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM
M92`H3F]R=&AE<FX@5&5R<FET;W)Y*2<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M=7-T<F%L:6$O4V]U=&@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA*2<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L(%-U;6UE<B!4:6UE("A3
M;W5T:"!!=7-T<F%L:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0U-4)R`I+`H@("`@)T%U<W1R86QI82]986YC;W=I;FYA)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64@*%-O=71H($%U<W1R86QI
M82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@4W5M;65R(%1I;64@*%-O=71H($%U<W1R
M86QI82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0U-4)R`I+`H@("`@)T%%5"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R;B!3=&%N9&%R9"!4:6UE("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M;65R
M(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%4U0G("DL"B`@("`G06YT87)C=&EC82]$=6UO;G1$57)V:6QL
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1'5M;VYT+61<)U5R=FEL;&4@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T1$550G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]386MH86QI;B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4V%K:&%L:6X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U-!2U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G4V%K:&%L:6X@4W5M;65R(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=304M35"<@*2P*("`@("=!<VEA+U9L
M861I=F]S=&]K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=6;&%D:79O<W1O:R!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5DQ!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=6;&%D
M:79O<W1O:R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)U9,05-4)R`I+`H@("`@)T%U<W1R86QI82]!0U0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S
M*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T
M97)N(%-U;6UE<B!4:6UE("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82]"<FES
M8F%N92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE
M("A1=65E;G-L86YD*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O
M0V%N8F5R<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@
M5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A.97<@4V]U
M=&@@5V%L97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I
M+`H@("`@)T%U<W1R86QI82](;V)A<G0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W1A;F1A<F0@5&EM92`H5&%S;6%N:6$I)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M;65R(%1I;64@
M*%1A<VUA;FEA*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@
M*2P*("`@("=!=7-T<F%L:6$O3&EN9&5M86XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H475E96YS;&%N9"DG+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G075S=')A;&EA+TUE;&)O=7)N92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A6:6-T;W)I82DG+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM
M97(@5&EM92`H5FEC=&]R:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82].4U<G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N
M(%-U;6UE<B!4:6UE("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82]1=65E;G-L
M86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@
M*%%U965N<VQA;F0I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82]3
M>61N97DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM
M92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A.97<@4V]U=&@@
M5V%L97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@
M("`@)T%U<W1R86QI82]487-M86YI82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R;B!3=&%N9&%R9"!4:6UE("A487-M86YI82DG+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H
M5&%S;6%N:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I
M+`H@("`@)T%U<W1R86QI82]6:6-T;W)I82<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!3=&%N9&%R9"!4:6UE("A6:6-T;W)I82DG+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM
M92`H5FEC=&]R:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4
M)R`I+`H@("`@)T5T8R]'350M,3`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LQ
M,#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ,#HP,"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T=U86TG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-H86UO<G)O(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#:%-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O4&]R=%]-;W)E<V)Y)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=087!U82!.97<@1W5I;F5A(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=01U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4&%C:69I8R]386EP86XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-H86UO<G)O(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#:%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U!A8VEF:6,O5')U:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5')U:R!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G5%)55"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+UEA<"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G66%P(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=905!4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI
M82],2$DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,W.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TQO860@2&]W92!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3$A35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=,
M;V%D($AO=V4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=,2%-4)R`I+`H@("`@)T%U<W1R86QI82],;W)D7TAO=V4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,W.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TQO860@2&]W92!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G3$A35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=,;V%D($AO=V4@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=,2%-4)R`I
M+`H@("`@)T%S:6$O36%G861A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%G861A
M;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34%'5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=-86=A9&%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G34%'4U0G("DL"B`@("`G171C+T=-5"TQ,2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1TU4*S$Q.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M*S$Q.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A
M8VEF:6,O169A=&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,Y
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U9A;G5A='4@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U955"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T=U861A;&-A;F%L)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=3;VQO;6]N($ES+B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4T)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O2V]S<F%E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=+;W-R
M864@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM/4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R].;W5M96$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TYE=R!#86QE9&]N:6$@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TY#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=086-I9FEC+U!O;F%P92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G4&]N87!E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=03TY4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-35"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4V]L;VUO;B!)<RX@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U-"5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=086-I9FEC+TYO<F9O;&LG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#0Q-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYO
M<F9O;&L@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY&5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A+TUC
M375R9&\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)TYE=R!:96%L86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=.6D14)R`I+`H@("`@)T%N=&%R8W1I8V$O4V]U=&A?4&]L
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY:4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3F5W
M(%IE86QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)TY:1%0G("DL"B`@("`G07-I82]!;F%D>7(G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%N861Y<B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M04Y!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=!;F%D>7(@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=!3D%35"<@*2P*("`@("=!<VEA+TMA;6-H871K
M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G4&5T<F]P879L;W9S:RU+86UC:&%T<VMI
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=01514)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)U!E=')O<&%V;&]V<VLM2V%M8VAA='-K:2!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)U!%5%-4)R`I+`H@("`@)T5T8R]'350M
M,3(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LQ,CHP,"<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=-5"LQ,CHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=+=V%J86QE:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA
M<G-H86QL($ES;&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TU(5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.4U0G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYE=R!:
M96%L86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=.6D14)R`I+`H@("`@)TY:)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.97<@
M6F5A;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3EI35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3EI$5"<@*2P*("`@("=086-I
M9FEC+T%U8VML86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T
M,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3EI35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=.97<@6F5A;&%N9"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G3EI$5"<@*2P*("`@("=086-I9FEC+T9I:FDG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T9I:FD@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T9*5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=086-I9FEC+T9U;F%F=71I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4=79A
M;'4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U165"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TMW86IA;&5I
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G36%R<VAA;&P@27-L86YD<R!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G34A4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O36%J=7)O)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=-87)S:&%L;"!)<VQA;F1S(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-2%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4&%C:69I8R].875R=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F%U<G4@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY25"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U1A<F%W82<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1VEL8F5R="!)<RX@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=)3%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G4&%C:69I8R]786ME)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=786ME
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=704M4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O5V%L;&ES)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=786QL:7,@)B!&=71U;F$@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U=&5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=.6BU#2$%4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T-3DP,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&%T
M:&%M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M2$%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=#:&%T:&%M($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=#2$%$5"<@*2P*("`@("=086-I9FEC+T-H
M871H86TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0U.3`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H871H86T@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-(05-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-H
M871H86T@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-(0414)R`I+`H@("`@)T5T8R]'350M,3,G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#0V.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=-5"LQ,SHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ
M,SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I
M9FEC+T5N9&5R8G5R>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-#8X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&AO96YI>"!)<RX@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!(3U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]4;VYG871A<'4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U1O;F=A(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=43U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G171C+T=-5"TQ-"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-3`T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S$T.C`P
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$T.C`P)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O2VER:71I;6%T
M:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-3`T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G3&EN92!)<RX@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)TQ)3E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G1TU4+3$R.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4
M+3$R.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3$R.C`P)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=-5"TQ,3HP,"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"TQ,3HP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"TQ,3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=797-T(%-A;6]A(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=797-T(%-A;6]A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4V%M;V$@
M4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-A;6]A(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=34U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3FEU92!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G3FEU92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G3E54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TAA=V%I:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G2&%W86EI+4%L975T:6%N(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=(05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TAA=V%I:2U!;&5U=&EA
M;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M2$%$5"<@*2P*("`@("='350M,3`Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350M,3`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,3`Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2&%W86EI(%-T
M86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS
M-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(87=A:6D@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=4;VME;&%U(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=4;VME;&%U(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=42U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G0V]O:R!)<RX@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;VL@
M27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#2U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5&%H:71I(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=486AI=&D@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U1!2%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G36%R<75E<V%S(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TS-#(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-87)Q
M=65S87,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU!4E0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06QA<VMA(%-T86YD
M87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M06QA<VMA($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=!2T14)R`I+`H@("`@)T=-5"TP.3HP,"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=-5"TP.3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP
M.3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='86UB
M:65R(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='86UB:65R(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='04U4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL
M"B`@("`G1TU4+3`X.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`X.C`P
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`X.C`P)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!I=&-A:7)N(%-T86YD87)D
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0:71C86ER;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUO=6YT86EN(%-T86YD87)D(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT
M86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=-1%0G("DL"B`@("`G1TU4+3`W.C`P)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1TU4+3`W.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`W.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-E;G1R86P@
M4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#1%0G("DL"B`@("`G16%S=&5R;B!3=&%N9&%R9"!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=%87-T97(@27,N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97(@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=%05-35"<@*2P*("`@("='350M,#8Z,#`G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("='350M,#8Z,#`G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350M,#8Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G1V%L87!A9V]S(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("='86QA<&%G;W,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=!
M3%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V]L;VUB
M:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;&]M8FEA(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#3U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06-R92!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G06-R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5C=6%D;W(@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5C=6%D;W(@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=097)U(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=097)U
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0150G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4+3`U.C`P)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1TU4+3`U.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4+3`U.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T%T;&%N=&EC($1A>6QI9VAT(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!1%0G("DL"B`@("`G4&%R86=U
M87D@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A<F%G=6%Y(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=0650G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%R86=U87D@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=065-4
M)R`I+`H@("`@)T%M87IO;B!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G06UA>F]N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G5F5N97IU96QA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=696YE>G5E
M;&$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U9%5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='=7EA;F$@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=U>6%N82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1UE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T)O;&EV:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)O;&EV:6$@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)/5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#:&EL92!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0VAI;&4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-,5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=#:&EL92!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T-,4U0G("DL"B`@("`G1F%L:VQA;F0@27,N
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=&86QK;&%N9"!)<RX@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T9+5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=&86QK;&%N
M9"!)<RX@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=&2U-4)R`I+`H@("`@)T=-5"TP-#HP,"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"TP-#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP-#HP
M,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.97=F;W5N
M9&QA;F0@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$R-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=V9O
M=6YD;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)TYE=V9O=6YD;&%N9"!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3D14)R`I+`H@("`@)T%R9V5N
M=&EN92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)G96YT:6YE(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G0G)A>FEL(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T9R96YC:"!'=6EA;F$@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9R96YC:"!'=6EA;F$@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=&5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=797-T97)N($=R965N;&%N9"!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!'<F5E;FQA;F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U='5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($=R
M965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)U='4U0G("DL"B`@("`G4&EE<G)E("8@36EQ=65L;VX@4W1A;F1A<F0@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!I97)R92`F($UI<75E;&]N(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=035-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)U!I97)R92`F($UI<75E;&]N($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=03414)R`I+`H@("`@)U5R=6=U87D@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U5R=6=U87D@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U595"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=3=7)I;F%M92!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G4W5R:6YA;64@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-2
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='350M,#,Z
M,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#,Z,#`G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350M,#,Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G1F5R;F%N9&\@9&4@3F]R;VYH82!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=&97)N86YD;R!D92!.;W)O;FAA(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=&3E0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4V]U=&@@1V5O<F=I82!3=&%N9&%R9"!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=3;W5T:"!'96]R9VEA(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4+3`R.C`P)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='350M,#(Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M
M,#(Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G16%S
M=&5R;B!'<F5E;FQA;F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M($=R965N;&%N9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14=4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@1W)E96YL86YD(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14=35"<@*2P*("`@("=!>F]R97,@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07IO<F5S(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!6D]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%Z;W)E<R!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%:3U-4)R`I+`H@
M("`@)T-A<&4@5F5R9&4@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V%P92!6
M97)D92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U94)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=-5"TP,3HP,"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4+3`Q.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4+3`Q.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T=R965N=VEC:"!-96%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW
M:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=797-T97)N($5U
M<F]P96%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U=E<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=715-4)R`I+`H@("`@)T=-5"LP,#HP,"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350K,#`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#`Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V]O<F1I;F%T
M960@56YI=F5R<V%L(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V]O<F1I;F%T960@56YI
M=F5R<V%L(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=55$,G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V5N=')A;"!%=7)O
M<&5A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#
M96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=797-T97)N($%F<FEC86X@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($%F
M<FEC86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=705-4)R`I+`H@("`@)T=-5"LP,3HP,"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350K,#$Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#$Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36ED9&QE($5U
M<F]P92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUI9&1L92!%=7)O<&4@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-:61D
M;&4@175R;W!E(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G34535"<@*2P*("`@("=%87-T97)N($5U<F]P96%N(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E
M86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M15-4)R`I+`H@("`@)T-E;G1R86P@069R:6-A;B!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U-O=71H($%F<FEC82!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U-O=71H($%F<FEC82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=)<W)A96P@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=)<W)A96P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TE35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=)<W)A96P@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)TE$5"<@*2P*("`@("='350K,#(Z,#`G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1TU4*S`R.C`P)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4*S`R.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T5A<W1E<FX@069R:6-A;B!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=3>6]W82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3>6]W82!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4UE/5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!<F%B:6$@4W1A;F1A<F0@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G1TU4*S`S.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K
M,#,Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36]S8V]W(%-T86YD
M87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO<V-O=R!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-+)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO
M<V-O=R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G35-$)R`I+`H@("`@)T=-5"LP,SHP-R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1TU4*S`S.C`W)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`S.C`W
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TER86X@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3(V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G27)A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G25)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TER86X@4W5M97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE24U0G("DL"B`@("`G07%T874@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07%T874@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07%T874@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!45135"<@*2P*("`@
M("=!>F5R8F%I:F%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%Z97)B86EJ
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%:5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=!>F5R8F%I:F%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G05I35"<@*2P*("`@("='=6QF(%-T86YD87)D(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=U;&8@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("='96]R9VEA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=E
M;W)G:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("='96]R9VEA(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G1T535"<@*2P*("`@("=!<FUE;FEA(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T%R;65N:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=!<FUE;FEA(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G04U35"<@*2P*("`@("='350K,#0Z,#`G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-#HP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"LP-#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=386UA<F$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V%M
M87)A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=304U4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)U-A;6%R82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)U-!35-4)R`I+`H@("`@)U-E>6-H96QL97,@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G4V5Y8VAE;&QE<R!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G4T-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)TUA=7)I=&EU<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-875R:71I
M=7,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU55"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=2975N:6]N(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U)E=6YI;VX@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U)%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9F=H86YI<W1A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q-C(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!9F=H
M86YI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0494)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%Q=&]B92!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!<71O8F4@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07%T;V)E(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G05%44U0G("DL"B`@("`G
M5'5R:VUE;FES=&%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1U<FMM96YI
M<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5$U4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TMI<F=I>G-T86X@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G2VER9VEZ<W1A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G2T=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TMI<F=I>G-T86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=+1U-4)R`I
M+`H@("`@)U1A:FEK:7-T86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5&%J
M:6MI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5$I4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A:VES=&%N(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U!A:VES=&%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=02U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G57IB96MI<W1A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=5>F)E:VES=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=5
M6E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G665K871E
M<FEN8G5R9R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=996MA=&5R:6YB=7)G
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=914M4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)UEE:V%T97)I;F)U<F<@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=914M35"<@*2P*("`@("='350K,#4Z,#`G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=-5"LP-3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"LP-3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=&<F5N8V@@4V]U=&AE<FX@)B!!;G1A<F-T:6,@3&%N9',@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1G)E;F-H(%-O=71H97)N("8@06YT87)C=&EC($QA
M;F1S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=41E0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36%L9&EV97,@5&EM92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36%L9&EV97,@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TU65"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=);F1I82!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q.3@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=);F1I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G25-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TYE
M<&%L(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(P-S`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE<&%L(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=.4%0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G36%W<V]N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TUA=W-O;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34%75"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=6;W-T;VL@=&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G5F]S=&]K('1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=63U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%L;6$M071A(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L
M;6$M071A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!3$U4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T%L;6$M071A(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G04Q-4U0G("DL"B`@("`G4W)I($QA;FMA(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U-R:2!,86YK82!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G3$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T)A;F=L861E<V@@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0F%N
M9VQA9&5S:"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0D14)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TYO=F]S:6)I<G-K
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYO=F]S:6)I<G-K(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=.3U94)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYO=F]S:6)I
M<G-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M3D]64U0G("DL"B`@("`G3VUS:R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=/
M;7-K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=/35-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T]M<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=/35-35"<@*2P*("`@("=":'5T86X@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0FAU=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="
M5%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4*S`V
M.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#8Z,#`G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350K,#8Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G26YD:6%N($]C96%N(%1E<G)I=&]R>2!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=);F1I86X@3V-E86X@5&5R<FET;W)Y(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)3U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G37EA;FUA<B!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R,S0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=->6%N;6%R(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V]C
M;W,@27-L86YD<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R,S0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;V-O<R!)<VQA
M;F1S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#0U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1&%V:7,@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1&%V:7,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T1!5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G26YD;V-H:6YA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TEN9&]C:&EN
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G24-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TAO=F0@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G2&]V9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G2$]65"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=7
M97-T($EN9&]N97-I82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T($EN
M9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5TE4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TMR87-N;WEA<G-K
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TMR87-N;WEA<G-K(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=+4D%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TMR87-N;WEA
M<G-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M2U)!4U0G("DL"B`@("`G1TU4*S`W.C`P)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350K,#<Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#<Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0VAR:7-T;6%S
M($ES;&%N9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R
M-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:')I<W1M87,@27-L
M86YD(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#6%0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5V5S=&5R;B!3=&%N9&%R
M9"!4:6UE("A!=7-T<F%L:6$I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N
M(%-T86YD87)D(%1I;64@*$%U<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=74U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G0G)U;F5I(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)R=6YE:2!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0DY4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T-H:6YA(%-T86YD87)D(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G2&]N9R!+;VYG(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TAO;F<@2V]N9R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2$M4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TER:W5T<VL@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27)K=71S:R!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G25)+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=)<FMU='-K(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G25)+4U0G("DL
M"B`@("`G36%L87ES:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%L87ES
M:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU95"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=0:&EL:7!P:6YE<R!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=0:&EL:7!P:6YE<R!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4$A4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U-I;F=A<&]R92!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=3:6YG87!O<F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-'
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#96YT<F%L
M($EN9&]N97-I82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($EN
M9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TE4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U5L86%N8F%A=&%R
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U5L86%N8F%A=&%R(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=53$%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T=-5"LP.#HP,"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G1TU4*S`X.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`X
M.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-H;VEB
M86QS86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAO:6)A;'-A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TA/5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=%87-T(%1I;6]R(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W0@5&EM;W(@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U105"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=%87-T($EN9&]N97-I82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M14E4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TMO<F5A
M(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TMO<F5A(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2F%P86X@4W1A;F1A<F0@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2F%P86X@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TI35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=986MU='-K(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)UEA:W5T<VL@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)UE!2U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G66%K='-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G64%+4U0G("DL"B`@("`G1TU4*S`Y.C`P)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='350K,#DZ,#`G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350K,#DZ,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G4&%L874@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%L874@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!75"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#96YT<F%L(%-T86YD87)D(%1I
M;64@*$YO<G1H97)N(%1E<G)I=&]R>2DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@4W1A;F1A<F0@5&EM92`H3F]R=&AE<FX@5&5R<FET;W)Y*2<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=#96YT<F%L(%-T86YD87)D(%1I;64@*%-O=71H
M($%U<W1R86QI82DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A
M<F0@5&EM92`H4V]U=&@@075S=')A;&EA*2<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L(%-U;6UE<B!4:6UE("A3;W5T
M:"!!=7-T<F%L:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0U-4
M)R`I+`H@("`@)T-E;G1R86P@4W1A;F1A<F0@5&EM92`H4V]U=&@@075S=')A
M;&EA+TYE=R!3;W5T:"!786QE<RDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R
M86P@4W1A;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA+TYE=R!3;W5T:"!7
M86QE<RDG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0V5N=')A;"!3=6UM97(@5&EM92`H4V]U=&@@075S=')A;&EA+TYE=R!3;W5T
M:"!786QE<RDG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#4U0G("DL
M"B`@("`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A.97<@4V]U=&@@5V%L97,I
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@*$YE
M=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H3F5W(%-O=71H(%=A;&5S
M*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@*2P*("`@("=$
M=6UO;G0M9%PG57)V:6QL92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=$=6UO
M;G0M9%PG57)V:6QL92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1$155"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=386MH
M86QI;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=386MH86QI;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T%+5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=386MH86QI
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U-!
M2U-4)R`I+`H@("`@)U9L861I=F]S=&]K(%1I;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U9L861I=F]S=&]K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=63$%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)U9L861I=F]S=&]K(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5DQ!4U0G("DL"B`@("`G16%S=&5R
M;B!3=&%N9&%R9"!4:6UE("A1=65E;G-L86YD*2<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A1=65E;G-L86YD*2<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=%87-T97)N(%-T86YD87)D(%1I;64@*%1A<VUA;FEA
M*2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A4
M87-M86YI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=6UM97(@5&EM92`H5&%S;6%N:6$I)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T5A<W1E<FX@4W1A;F1A
M<F0@5&EM92`H5FEC=&]R:6$I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M(%-T86YD87)D(%1I;64@*%9I8W1O<FEA*2<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A6:6-T
M;W)I82DG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%4U0G("DL"B`@
M("`G1TU4*S$P.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,3`Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350K,3`Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0VAA;6]R<F\@4W1A;F1A<F0@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0VAA;6]R<F\@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-H4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%P=6$@3F5W($=U:6YE82!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=087!U82!.97<@1W5I;F5A(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=01U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G5')U:R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4
M<G5K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=44E54)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)UEA<"!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=987`@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)UE!4%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M3&]A9"!(;W=E(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,W.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TQO
M860@2&]W92!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3$A35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=,;V%D($AO=V4@4W5M;65R(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=,2%-4)R`I+`H@("`@)TUA9V%D86X@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%G861A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G34%'5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-86=A9&%N(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G34%'4U0G("DL
M"B`@("`G1TU4*S$Q.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,3$Z,#`G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,3$Z,#`G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5F%N=6%T=2!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=686YU871U(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=6550G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4V]L;VUO;B!)<RX@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V]L;VUO
M;B!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-"5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=+;W-R864@5&EM92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G2V]S<F%E(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=+3U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TYE=R!#86QE9&]N:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M3F5W($-A;&5D;VYI82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M3D-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!O;F%P
M92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0;VYA<&4@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U!/3E0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G3F]R9F]L:R!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`T,30P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=.;W)F;VQK(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.1E0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3F5W(%IE86QA
M;F0@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W(%IE86QA
M;F0@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY:
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)TY:1%0G("DL"B`@("`G06YA9'ER(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T%N861Y<B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G04Y!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!;F%D>7(@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!3D%35"<@*2P*("`@
M("=0971R;W!A=FQO=G-K+4MA;6-H871S:VD@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G4&5T<F]P879L;W9S:RU+86UC:&%T<VMI(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=01514)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!E=')O<&%V;&]V<VLM
M2V%M8VAA='-K:2!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)U!%5%-4)R`I+`H@("`@)T=-5"LQ,CHP,"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1TU4*S$R.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M*S$R.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUA
M<G-H86QL($ES;&%N9',@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%R<VAA
M;&P@27-L86YD<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34A4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T9I:FD@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1FEJ:2!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1DI4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U1U=F%L=2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4=79A;'4@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U165"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.875R=2!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=.875R=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=I
M;&)E<G0@27,N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=I;&)E<G0@27,N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='24Q4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U=A:V4@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5V%K92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5T%+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=7
M86QL:7,@)B!&=71U;F$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V%L;&ES
M("8@1G5T=6YA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=71E0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0VAA=&AA;2!3
M=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T
M-3DP,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&%T:&%M(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#2$%35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#:&%T:&%M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#2$%$5"<@*2P*("`@("='350K,3,Z,#`G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=-5"LQ,SHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"LQ,SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=0:&]E;FEX($ES+B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`T-C@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0:&]E;FEX
M($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$A/5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=4;VYG82!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T-C@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=4;VYG82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5$]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T=-5"LQ-#HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-3`T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S$T.C`P)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$T.C`P)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TQI;F4@27,N(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#4P-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TQI;F4@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=,24Y4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`HI
M.PH*+R\*+R\@26YI=&EA;&EZ92!D969A=6QT('1I;65Z;VYE"B\O("!&:7)S
M="!T<GD@7T1!5$5?5$E-15I/3D5?1$5&055,5"!G;&]B86PL"B\O("!T:&5N
M(%!(4%]46B!E;G9I<F]N;65N="!V87(L('1H96X@5%H@96YV:7)O;FUE;G0@
M=F%R"B\O"FEF*&ES<V5T*"1?1$%415]424U%6D].15]$149!54Q4*0H@("`@
M)B8@1&%T95]4:6UE6F]N93HZ:7-686QI9$E$*"1?1$%415]424U%6D].15]$
M149!54Q4*0HI('L*("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U;'0H)%]$
M051%7U1)345:3TY%7T1%1D%53%0I.PI](&5L<V5I9B`H9V5T96YV*"=02%!?
M5%HG*2`F)B!$871E7U1I;65:;VYE.CII<U9A;&ED240H9V5T96YV*"=02%!?
M5%HG*2DI('L*("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U;'0H9V5T96YV
M*"=02%!?5%HG*2D["GT@96QS96EF("AG971E;G8H)U1:)RD@)B8@1&%T95]4
M:6UE6F]N93HZ:7-686QI9$E$*&=E=&5N=B@G5%HG*2DI('L*("`@($1A=&5?
M5&EM95IO;F4Z.G-E=$1E9F%U;'0H9V5T96YV*"=46B<I*3L*?2!E;'-E:68@
M*$1A=&5?5&EM95IO;F4Z.FES5F%L:61)1"AD871E*"=4)RDI*2!["B`@("!$
M871E7U1I;65:;VYE.CIS971$969A=6QT*&1A=&4H)U0G*2D["GT@96QS92![
M"B`@("!$871E7U1I;65:;VYE.CIS971$969A=6QT*"=55$,G*3L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O1&%T92]#86QC+G!H<```````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R,#`R-3``,3`U,34T,S$P-3<`
M,#$W-3<P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U
M($)A8F$@0G5E:&QE<BP@4&EE<G)E+4%L86EN($IO>64@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L
M(%1H870@:7,@8G5N9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@
M("`@('P*+R\@?"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T
M<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP
M:'`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N
M86)L92`@('P*+R\@?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@
M<&5A<BUD979`;&ES=',N<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($)A8F$@0G5E:&QE<B`\8F%B84!B
M86)A>BYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@("`@("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J;WEE0'!H<"YN970^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*"B\J*@H@*B!#86QC=6QA=&5S+"!M86YI<'5L871E
M<R!A;F0@<F5T<FEE=F5S(&1A=&5S"B`J"B`J($ET(&1O97,@;F]T(')E;'D@
M;VX@,S(M8FET('-Y<W1E;2!T:6UE('-T86UP<RP@<V\@:70@=V]R:W,@9&%T
M97,*("H@8F5F;W)E(#$Y-S`@86YD(&%F=&5R(#(P,S@N"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($!C871E9V]R>2`@($1A=&4@86YD(%1I
M;64*("H@0'!A8VMA9V4@("`@1&%T90H@*B!`875T:&]R("`@("!-;VYT92!/
M:')T(#QM;VYT94!I<W!I+FYE=#X*("H@0&%U=&AO<B`@("`@4&EE<G)E+4%L
M86EN($IO>64@/'!A:F]Y94!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3DM,C`P-2`@36]N=&4@3VAR="P@4&EE<G)E+4%L86EN($IO>64L($1A
M;FEE;"!#;VYV:7-S;W(*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@
M3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0V%L8RYP:'`L=B`Q
M+C,S(#(P,#4O,3$O,34@,#`Z,38Z,SD@<&%J;WEE($5X<"`D"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XR"B`J
M+PH*:68@*"%D969I;F5D*"=$051%7T-!3$-?0D5'24Y?5T5%2T1!62<I*2![
M"B`@("`O*BH*("`@("`J($1E9FEN97,@=VAA="!D87D@<W1A<G1S('1H92!W
M965K"B`@("`@*@H@("`@("H@36]N9&%Y("@Q*2!I<R!T:&4@:6YT97)N871I
M;VYA;"!S=&%N9&%R9"X*("`@("`J(%)E9&5F:6YE('1H:7,@=&\@,"!I9B!Y
M;W4@=V%N="!W965K<R!T;R!B96=I;B!O;B!3=6YD87DN"B`@("`@*B\*("`@
M(&1E9FEN92@G1$%415]#04Q#7T)%1TE.7U=%14M$05DG+"`Q*3L*?0H*:68@
M*"%D969I;F5D*"=$051%7T-!3$-?1D]234%4)RDI('L*("`@("\J*@H@("`@
M("H@5&AE(&1E9F%U;'0@=F%L=64@9F]R(&5A8V@@;65T:&]D)W,@)&9O<FUA
M="!P87)A;65T97(*("`@("`J"B`@("`@*B!4:&4@9&5F875L="!I<R`G)5DE
M;25D)RX@(%1O(&]V97)R:61E('1H:7,@9&5F875L="P@9&5F:6YE"B`@("`@
M*B!T:&ES(&-O;G-T86YT(&)E9F]R92!I;F-L=61I;F<@0V%L8RYP:'`N"B`@
M("`@*@H@("`@("H@0'-I;F-E($-O;G-T86YT(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-2XP"B`@("`@*B\*("`@(&1E9FEN92@G1$%415]#04Q#7T9/
M4DU!5"<L("<E625M)60G*3L*?0H*+RHJ"B`J($-A;&-U;&%T97,L(&UA;FEP
M=6QA=&5S(&%N9"!R971R:65V97,@9&%T97,*("H*("H@270@9&]E<R!N;W0@
M<F5L>2!O;B`S,BUB:70@<WES=&5M('1I;64@<W1A;7!S+"!S;R!I="!W;W)K
M<R!D871E<PH@*B!B969O<F4@,3DW,"!A;F0@869T97(@,C`S."X*("H*("H@
M0&%U=&AO<B`@("`@36]N=&4@3VAR="`\;6]N=&5`:7-P:2YN970^"B`J($!A
M=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*
M("H@0&-O<'ER:6=H="`@,3DY.2P@,C`P,BP@,C`P,R!I<W!I"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D
M+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M4F5L96%S93H@,2XT+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+T1A=&4*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XR"B`J+PIC;&%S<R!$871E7T-A;&,*>PH@
M("`@+RHJ"B`@("`@*B!&;W)M871S('1H92!D871E(&EN('1H92!G:79E;B!F
M;W)M870L(&UU8V@@;&EK92!S=')F;70H*0H@("`@("H*("`@("`J(%1H:7,@
M9G5N8W1I;VX@:7,@=7-E9"!T;R!A;&QE=FEA=&4@=&AE('!R;V)L96T@=VET
M:"`S,BUB:70@;G5M8F5R<R!F;W(*("`@("`J(&1A=&5S('!R92`Q.3<P(&]R
M('!O<W0@,C`S."P@87,@<W1R9FUT*"D@:&%S(&]N(&UO<W0@<WES=&5M<RX*
M("`@("`J($UO<W0@;V8@=&AE(&9O<FUA='1I;F<@;W!T:6]N<R!A<F4@8V]M
M<&%T:6)L92X*("`@("`J"B`@("`@*B!&;W)M871T:6YG(&]P=&EO;G,Z"B`@
M("`@*B`\<')E/@H@("`@("H@)6$@("!A8F)R979I871E9"!W965K9&%Y(&YA
M;64@*%-U;BP@36]N+"!4=64I"B`@("`@*B`E02`@(&9U;&P@=V5E:V1A>2!N
M86UE("A3=6YD87DL($UO;F1A>2P@5'5E<V1A>2D*("`@("`J("5B("`@86)B
M<F5V:6%T960@;6]N=&@@;F%M92`H2F%N+"!&96(L($UA<BD*("`@("`J("5"
M("`@9G5L;"!M;VYT:"!N86UE("A*86YU87)Y+"!&96)R=6%R>2P@36%R8V@I
M"B`@("`@*B`E9"`@(&1A>2!O9B!M;VYT:"`H<F%N9V4@,#`@=&\@,S$I"B`@
M("`@*B`E92`@(&1A>2!O9B!M;VYT:"P@<VEN9VQE(&1I9VET("AR86YG92`P
M('1O(#,Q*0H@("`@("H@)44@("!N=6UB97(@;V8@9&%Y<R!S:6YC92!U;G-P
M96-I9FEE9"!E<&]C:"`H:6YT96=E<BD*("`@("`J("`@("`@("`H)44@:7,@
M=7-E9G5L(&9O<B!P87-S:6YG(&$@9&%T92!I;B!A(%523"!A<PH@("`@("H@
M("`@("`@(&%N(&EN=&5G97(@=F%L=64N(%1H96X@<VEM<&QY('5S90H@("`@
M("H@("`@("`@(&1A>7-4;T1A=&4H*2!T;R!C;VYV97)T(&)A8VL@=&\@82!D
M871E+BD*("`@("`J("5J("`@9&%Y(&]F('EE87(@*')A;F=E(#`P,2!T;R`S
M-C8I"B`@("`@*B`E;2`@(&UO;G1H(&%S(&1E8VEM86P@;G5M8F5R("AR86YG
M92`Q('1O(#$R*0H@("`@("H@)6X@("!N97=L:6YE(&-H87)A8W1E<B`H7&XI
M"B`@("`@*B`E="`@('1A8B!C:&%R86-T97(@*%QT*0H@("`@("H@)7<@("!W
M965K9&%Y(&%S(&1E8VEM86P@*#`@/2!3=6YD87DI"B`@("`@*B`E52`@('=E
M96L@;G5M8F5R(&]F(&-U<G)E;G0@>65A<BP@9FER<W0@<W5N9&%Y(&%S(&9I
M<G-T('=E96L*("`@("`J("5Y("`@>65A<B!A<R!D96-I;6%L("AR86YG92`P
M,"!T;R`Y.2D*("`@("`J("59("`@>65A<B!A<R!D96-I;6%L(&EN8VQU9&EN
M9R!C96YT=7)Y("AR86YG92`P,#`P('1O(#DY.3DI"B`@("`@*B`E)2`@(&QI
M=&5R86P@)R4G"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H"B`@("`@*B!`
M<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:`H@("`@("H@0'!A<F%M
M(&EN="`@("`D>65A<B`@("!T:&4@>65A<BX@(%5S92!T:&4@8V]M<&QE=&4@
M>65A<B!I;G-T96%D(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@=7-E(#(P,#4L(&YO
M="`P-2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($1O(&YO="!A
M9&0@;&5A9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O(#$P,#`N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!F;W)M870@<W1R:6YG"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D
M97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A=&5&;W)M870H
M)&1A>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="D*("`@('L*("`@("`@("!I
M9B`H(41A=&5?0V%L8SHZ:7-686QI9$1A=&4H)&1A>2P@)&UO;G1H+"`D>65A
M<BDI('L*("`@("`@("`@("`@)'EE87(@(#T@1&%T95]#86QC.CID871E3F]W
M*"<E62<I.PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@("`@("1D87D@("`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)60G*3L*("`@("`@("!]"@H@("`@("`@("1O=71P=70@/2`G)SL*
M"B`@("`@("`@9F]R("@D<W1R<&]S(#T@,#L@)'-T<G!O<R`\('-T<FQE;B@D
M9F]R;6%T*3L@)'-T<G!O<RLK*2!["B`@("`@("`@("`@("1C:&%R(#T@<W5B
M<W1R*"1F;W)M870L("1S=')P;W,L(#$I.PH@("`@("`@("`@("!I9B`H)&-H
M87(@/3T@)R4G*2!["B`@("`@("`@("`@("`@("`D;F5X=&-H87(@/2!S=6)S
M='(H)&9O<FUA="P@)'-T<G!O<R`K(#$L(#$I.PH@("`@("`@("`@("`@("`@
M<W=I=&-H*"1N97AT8VAA<BD@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)V$G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?
M0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE*"1D87DL("1M;VYT:"P@)'EE87(I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("!C87-E("=!)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!$871E7T-A;&,Z.F=E=%=E96MD87E&=6QL;F%M92@D9&%Y+"`D
M;6]N=&@L("1Y96%R*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G8B<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CIG971-;VYT:$%B8G)N
M86UE*"1M;VYT:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)T(G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T36]N=&A&=6QL;F%M
M92@D;6]N=&@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!C87-E("=D)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D)RP@)&1A>2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)V4G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M("1D87D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)T4G.@H@("`@("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"`D;6]N
M=&@L("1Y96%R*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G:B<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CIJ=6QI86Y$871E*"1D87DL
M("1M;VYT:"P@)'EE87(I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D)RP@)&UO;G1H
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G;B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@(EQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G="<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@(EQT(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G=R<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CID
M87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)U4G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L
M8SHZ=V5E:T]F665A<B@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G>2<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W5B
M<W1R*"1Y96%R+"`R+"`R*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G62<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@)'EE87(["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)R4G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("<E)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D8VAA<BXD;F5X=&-H87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<W1R<&]S*RL["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]("1C:&%R.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5'5R;G,@82!T=V\@9&EG:70@>65A<B!I;G1O(&$@9F]U<B!D
M:6=I="!Y96%R"B`@("`@*@H@("`@("H@1G)O;2`G-3$@=&\@)SDY(&ES(&EN
M('1H92`Q.3`P)W,L(&]T:&5R=VES92!I="=S(&EN('1H92`R,#`P)W,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@,B!D:6=I
M="!Y96%R"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92`T(&1I
M9VET('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D969A=6QT0V5N='5R>2@D
M>65A<BD*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1Y96%R*2`]/2`Q*2![
M"B`@("`@("`@("`@("1Y96%R(#T@)S`G("X@)'EE87(["B`@("`@("`@?0H@
M("`@("`@(&EF("@D>65A<B`^(#4P*2!["B`@("`@("`@("`@(')E='5R;B`G
M,3DG("X@)'EE87(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("<R,"<@+B`D>65A<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!A(&1A=&4@=&\@;G5M8F5R(&]F(&1A>7,@<VEN8V4@
M82!D:7-T86YT('5N<W!E8VEF:65D(&5P;V-H"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(N("!5<V4@=&AE(&-O;7!L
M971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%+F<N('5S92`R,#`U
M+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!$;R!N
M;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@=&AE(&YU;6)E<B!O9B!D
M87ES('-I;F-E('1H92!$871E7T-A;&,@97!O8V@*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!D871E5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I"B`@("!["B`@
M("`@("`@)&-E;G1U<GD@/2`H:6YT*7-U8G-T<B@D>65A<BP@,"P@,BD["B`@
M("`@("`@)'EE87(@/2`H:6YT*7-U8G-T<B@D>65A<BP@,BP@,BD["B`@("`@
M("`@:68@*"1M;VYT:"`^(#(I('L*("`@("`@("`@("`@)&UO;G1H("T](#,[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO;G1H("L](#D["B`@
M("`@("`@("`@(&EF("@D>65A<BD@>PH@("`@("`@("`@("`@("`@)'EE87(M
M+3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1Y96%R
M(#T@.3D["B`@("`@("`@("`@("`@("`D8V5N='5R>2`M+3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AF;&]O<B@H,30V,#DW
M("H@)&-E;G1U<GDI("\@-"`I("L*("`@("`@("`@("`@("`@(&9L;V]R*"@Q
M-#8Q("H@)'EE87(I("\@-"`I("L*("`@("`@("`@("`@("`@(&9L;V]R*"@Q
M-3,@*B`D;6]N=&@@*R`R*2`O(#4@*2`K"B`@("`@("`@("`@("`@("`D9&%Y
M("L@,3<R,3$Q.2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!N
M=6UB97(@;V8@9&%Y<R!T;R!A(&1I<W1A;G0@=6YS<&5C:69I960@97!O8V@*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87ES("`@('1H92!N=6UB
M97(@;V8@9&%Y<R!S:6YC92!T:&4@1&%T95]#86QC(&5P;V-H"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H
M;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@9&%Y<U1O1&%T92@D9&%Y<RP@)&9O<FUA="`]($1!
M5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@)&1A>7,@("`M/2`Q-S(Q
M,3$Y.PH@("`@("`@("1C96YT=7)Y(#T@9FQO;W(H*#0@*B`D9&%Y<R`M(#$I
M("\@,30V,#DW*3L*("`@("`@("`D9&%Y<R`@("`](&9L;V]R*#0@*B`D9&%Y
M<R`M(#$@+2`Q-#8P.3<@*B`D8V5N='5R>2D["B`@("`@("`@)&1A>2`@("`@
M/2!F;&]O<B@D9&%Y<R`O(#0I.PH*("`@("`@("`D>65A<B`@("`](&9L;V]R
M*"@T("H@)&1A>2`K("`S*2`O(#$T-C$I.PH@("`@("`@("1D87D@("`@(#T@
M9FQO;W(H-"`J("1D87D@*R`@,R`M(#$T-C$@*B`D>65A<BD["B`@("`@("`@
M)&1A>2`@("`@/2!F;&]O<B@H)&1A>2`K("`T*2`O(#0I.PH*("`@("`@("`D
M;6]N=&@@("`](&9L;V]R*"@U("H@)&1A>2`M(#,I("\@,34S*3L*("`@("`@
M("`D9&%Y("`@("`](&9L;V]R*#4@*B`D9&%Y("T@,R`M(#$U,R`J("1M;VYT
M:"D["B`@("`@("`@)&1A>2`@("`@/2!F;&]O<B@H)&1A>2`K("`U*2`O("`U
M*3L*"B`@("`@("`@:68@*"1M;VYT:"`\(#$P*2!["B`@("`@("`@("`@("1M
M;VYT:"`K/3,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO;G1H
M("T].3L*("`@("`@("`@("`@:68@*"1Y96%R*RL@/3T@.3DI('L*("`@("`@
M("`@("`@("`@("1Y96%R(#T@,#L*("`@("`@("`@("`@("`@("1C96YT=7)Y
M*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C96YT=7)Y
M(#T@<W!R:6YT9B@G)3`R9"<L("1C96YT=7)Y*3L*("`@("`@("`D>65A<B`@
M("`]('-P<FEN=&8H)R4P,F0G+"`D>65A<BD["B`@("`@("`@<F5T=7)N($1A
M=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y+"`D;6]N=&@L("1C96YT=7)Y("X@
M)'EE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R
M=',@9G)O;2!'<F5G;W)I86X@665A<BU-;VYT:"U$87D@=&\@25-/(%EE87(M
M5V5E:TYU;6)E<BU7965K1&%Y"B`@("`@*@H@("`@("H@57-E<R!)4T\@.#8P
M,2!D969I;FET:6]N<RX@($%L9V]R:71H;2!B>2!2:6-K($UC0V%R='DL(#$Y
M.3D@870*("`@("`J(&AT='`Z+R]P97)S;VYA;"YE8W4N961U+VUC8V%R='ER
M+TE33W=D04Q'+G1X="`N"B`@("`@*B!4<F%N<V-R:6)E9"!T;R!02%`@8GD@
M2F5S=7,@32X@0V%S=&%G;F5T=&\N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("H@0'!A
M<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I
M;G0@("`@)'EE87(@("`@=&AE('EE87(N("!5<V4@=&AE(&-O;7!L971E('EE
M87(@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%+F<N('5S92`R,#`U+"!N;W0@
M,#4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!$;R!N;W0@861D
M(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!)4T\@665A<BU7
M965K3G5M8F5R+5=E96M$87D@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M9W)E9V]R:6%N5&])4T\H)&1A>2P@)&UO;G1H+"`D>65A<BD@>PH@("`@("`@
M("1M;G1H(#T@87)R87D@*#`L(#,Q+"`U.2P@.3`L(#$R,"P@,34Q+"`Q.#$L
M(#(Q,BP@,C0S+"`R-S,L(#,P-"P@,S,T*3L*("`@("`@("`D>5]I<VQE87`@
M/2!$871E7T-A;&,Z.FES3&5A<%EE87(H)'EE87(I.PH@("`@("`@("1Y7S%?
M:7-L96%P(#T@1&%T95]#86QC.CII<TQE87!996%R*"1Y96%R("T@,2D["B`@
M("`@("`@)&1A>5]O9E]Y96%R7VYU;6)E<B`]("1D87D@*R`D;6YT:%LD;6]N
M=&@@+2`Q73L*("`@("`@("!I9B`H)'E?:7-L96%P("8F("1M;VYT:"`^(#(I
M('L*("`@("`@("`@("`@)&1A>5]O9E]Y96%R7VYU;6)E<BLK.PH@("`@("`@
M('T*("`@("`@("`O+R!F:6YD($IA;B`Q('=E96MD87D@*&UO;F1A>2`](#$L
M('-U;F1A>2`](#<I"B`@("`@("`@)'EY(#T@*"1Y96%R("T@,2D@)2`Q,#`[
M"B`@("`@("`@)&,@/2`H)'EE87(@+2`Q*2`M("1Y>3L*("`@("`@("`D9R`]
M("1Y>2`K(&EN='9A;"@D>7D@+R`T*3L*("`@("`@("`D:F%N,5]W965K9&%Y
M(#T@,2`K(&EN='9A;"@H*"@H)&,@+R`Q,#`I("4@-"D@*B`U*2`K("1G*2`E
M(#<I.PH@("`@("`@("\O('=E96MD87D@9F]R('EE87(M;6]N=&@M9&%Y"B`@
M("`@("`@)&@@/2`D9&%Y7V]F7WEE87)?;G5M8F5R("L@*"1J86XQ7W=E96MD
M87D@+2`Q*3L*("`@("`@("`D=V5E:V1A>2`](#$@*R!I;G1V86PH*"1H("T@
M,2D@)2`W*3L*("`@("`@("`O+R!F:6YD(&EF(%D@32!$(&9A;&QS(&EN(%EE
M87).=6UB97(@62TQ+"!7965K3G5M8F5R(#4R(&]R"B`@("`@("`@:68@*"1D
M87E?;V9?>65A<E]N=6UB97(@/#T@*#@@+2`D:F%N,5]W965K9&%Y*2`F)B`D
M:F%N,5]W965K9&%Y(#X@-"E["B`@("`@("`@("`@("1Y96%R;G5M8F5R(#T@
M)'EE87(@+2`Q.PH@("`@("`@("`@("!I9B`H)&IA;C%?=V5E:V1A>2`]/2`U
M('Q\("@D:F%N,5]W965K9&%Y(#T](#8@)B8@)'E?,5]I<VQE87`I*2!["B`@
M("`@("`@("`@("`@("`D=V5E:VYU;6)E<B`](#4S.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'=E96MN=6UB97(@/2`U,CL*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Y96%R
M;G5M8F5R(#T@)'EE87(["B`@("`@("`@?0H@("`@("`@("\O(&9I;F0@:68@
M62!-($0@9F%L;',@:6X@665A<DYU;6)E<B!9*S$L(%=E96M.=6UB97(@,0H@
M("`@("`@(&EF("@D>65A<FYU;6)E<B`]/2`D>65A<BD@>PH@("`@("`@("`@
M("!I9B`H)'E?:7-L96%P*2!["B`@("`@("`@("`@("`@("`D:2`](#,V-CL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I(#T@,S8U
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@H)&D@+2`D9&%Y7V]F
M7WEE87)?;G5M8F5R*2`\("@T("T@)'=E96MD87DI*2!["B`@("`@("`@("`@
M("`@("`D>65A<FYU;6)E<BLK.PH@("`@("`@("`@("`@("`@)'=E96MN=6UB
M97(@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O(&9I
M;F0@:68@62!-($0@9F%L;',@:6X@665A<DYU;6)E<B!9+"!7965K3G5M8F5R
M(#$@=&AR;W5G:"`U,PH@("`@("`@(&EF("@D>65A<FYU;6)E<B`]/2`D>65A
M<BD@>PH@("`@("`@("`@("`D:B`]("1D87E?;V9?>65A<E]N=6UB97(@*R`H
M-R`M("1W965K9&%Y*2`K("@D:F%N,5]W965K9&%Y("T@,2D["B`@("`@("`@
M("`@("1W965K;G5M8F5R(#T@:6YT=F%L*"1J("\@-RD["B`@("`@("`@("`@
M(&EF("@D:F%N,5]W965K9&%Y(#X@-"D@>PH@("`@("`@("`@("`@("`@)'=E
M96MN=6UB97(M+3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O
M+R!P=70@:70@86QL('1O9V5T:&5R"B`@("`@("`@:68@*"1W965K;G5M8F5R
M(#P@,3`I('L*("`@("`@("`@("`@)'=E96MN=6UB97(@/2`G,"<N)'=E96MN
M=6UB97(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D>65A<FYU;6)E<B`N
M("<M)R`N("1W965K;G5M8F5R("X@)RTG("X@)'=E96MD87D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&IU;&EA;B!D871E(&]F('1H92!G
M:79E;B!S96%S;VX*("`@("`J"B`@("`@*B!!9&%P=&5D(&9R;VT@<')E=FEO
M=7,@=V]R:R!I;B!*879A(&)Y($IA;65S($UA<FL@2&%M:6QT;VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5A<V]N("!T:&4@<V5A<V]N('1O
M(&=E="!T:&4@9&%T92!F;W(Z(%9%4DY!3$5154E.3U@L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!354U-15)33TQ35$E#12P@055454U.04Q%
M455)3D]8+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@;W(@5TE.
M5$524T],4U1)0T4*("`@("`J($!P87)A;2!S=')I;F<@)'EE87(@("`@=&AE
M('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870N("!-=7-T(&)E(&)E='=E96X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("TQ,#`P0D,@86YD(#,P
M,#!!1"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&9L;V%T("!T:&4@:G5L:6%N
M(&1A=&4@=&AE('-E87-O;B!S=&%R=',@;VX*("`@("`J"B`@("`@*B!`875T
M:&]R($IA;65S($UA<FL@2&%M:6QT;VX@/&UH86UI;'1O;D!Q=V5S="YN970^
M"B`@("`@*B!`875T:&]R(%)O8F5R="!"=71L97(@/')O8D!M87AW96QL8W)E
M96LN;W)G/@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&%T95-E87-O;B@D<V5A<V]N+"`D>65A
M<B`](#`I('L*("`@("`@("!I9B`H)'EE87(@/3T@)R<I('L*("`@("`@("`@
M("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("@H)'EE87(@/CT@+3$P,#`I("8F("@D>65A<B`\/2`Q
M,#`P*2D@>PH@("`@("`@("`@("`D>2`]("1Y96%R("\@,3`P,"XP.PH@("`@
M("`@("`@("!S=VET8V@@*"1S96%S;VXI('L*("`@("`@("`@("`@("`@(&-A
M<V4@)U9%4DY!3$5154E.3U@G.@H@("`@("`@("`@("`@("`@("`@("1J=6QI
M86YD871E(#T@*"@H*"@H*"TP+C`P,#<Q("H@)'DI("T@,"XP,#$Q,2D@*B`D
M>2D@*R`P+C`V,3,T*2`J("1Y*2`K(#,V-3(T,BXQ,S<T*2`J("1Y*2`K(#$W
M,C$Q,SDN,CDQ.#D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E("=354U-15)33TQ35$E#12<Z"B`@("`@("`@("`@
M("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H*"@H,"XP,#`R-2`J("1Y*2`K
M(#`N,#`Y,#<I("H@)'DI("T@,"XP-3,R,RD@*B`D>2D@*R`S-C4R-#$N-S(U
M-C(I("H@)'DI("L@,3<R,3(S,RXR-30P,3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)T%55%5-3D%,15%524Y/
M6"<Z"B`@("`@("`@("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H*"@H
M,"XP,#`W-"`J("1Y*2`M(#`N,#`R.3<I("H@)'DI("T@,"XQ,38W-RD@*B`D
M>2D@*R`S-C4R-#(N-#DU-3@I("H@)'DI("L@,3<R,3,R-2XW,#0U-3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M)U=)3E1%4E-/3%-424-%)SH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H*"@H+3`N,#`P
M,#8@*B`D>2D@+2`P+C`P.3,S*2`J("1Y*2`M(#`N,#`W-CDI("H@)'DI("L@
M,S8U,C0R+C@X,C4W*2`J("1Y*2`K(#$W,C$T,30N,SDY.#<["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V5I9B`H*"1Y96%R(#X@,3`P,"D@)B8@*"1Y
M96%R(#P](#,P,#`I*2!["B`@("`@("`@("`@("1Y(#T@*"1Y96%R("T@,C`P
M,"D@+R`Q,#`P.PH@("`@("`@("`@("!S=VET8V@@*"1S96%S;VXI('L*("`@
M("`@("`@("`@("`@(&-A<V4@)U9%4DY!3$5154E.3U@G.@H@("`@("`@("`@
M("`@("`@("`@("1J=6QI86YD871E(#T@*"@H*"@H*"TP+C`P,#4W("H@)'DI
M("T@,"XP,#0Q,2D@*B`D>2D@*R`P+C`U,38Y*2`J("1Y*2`K(#,V-3(T,BXS
M-S0P-"D@*B`D>2D@*R`R-#4Q-C(S+C@P.3@T.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G4U5-34524T],4U1)
M0T4G.@H@("`@("`@("`@("`@("`@("`@("1J=6QI86YD871E(#T@*"@H*"@H
M*"TP+C`P,#,@*B`D>2D@*R`P+C`P.#@X*2`J("1Y*2`K(#`N,#`S,C4I("H@
M)'DI("L@,S8U,C0Q+C8R-C`S*2`J("1Y*2`K(#(T-3$W,38N-38W-C<["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M("=!551534Y!3$5154E.3U@G.@H@("`@("`@("`@("`@("`@("`@("1J=6QI
M86YD871E(#T@*"@H*"@H*#`N,#`P-S@@*B`D>2D@*R`P+C`P,S,W*2`J("1Y
M*2`M(#`N,3$U-S4I("H@)'DI("L@,S8U,C0R+C`Q-S8W*2`J("1Y*2`K(#(T
M-3$X,3`N,C$W,34["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E("=724Y415)33TQ35$E#12<Z"B`@("`@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("1J=6QI86YD871E
M(#T@*"@H*"@H*#`N,#`P,S(@*B`D>2D@+2`P+C`P.#(S*2`J("1Y*2`M(#`N
M,#8R,C,I("H@)'DI("L@,S8U,C0R+C<T,#0Y*2`J("1Y*2`K(#(T-3$Y,#`N
M,#4Y-3(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1J=6QI86YD871E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@8W5R<F5N="!L;V-A;"!D871E"B`@("`@*@H@("`@("H@3D]413H@5&AI
M<R!F=6YC=&EO;B!R971R:65V97,@=&AE(&QO8V%L(&1A=&4@=7-I;F<@<W1R
M9G1I;64H*2P*("`@("`J('=H:6-H(&UA>2!O<B!M87D@;F]T(&)E(#,R+6)I
M="!S869E(&]N('EO=7(@<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F
M;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!T:&4@8W5R<F5N="!D871E(&EN('1H92!S<&5C:69I960@9F]R;6%T"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&%T94YO=R@D9F]R;6%T(#T@1$%415]#04Q#
M7T9/4DU!5"D*("`@('L*("`@("`@("!R971U<FX@<W1R9G1I;64H)&9O<FUA
M="P@=&EM92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&-U<G)E;G0@;&]C86P@>65A<B!I;B!F;W)M870@0T-960H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@8W5R<F5N="!Y96%R(&EN(&9O=7(@
M9&EG:70@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T665A<B@I"B`@
M("!["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@;&]C
M86P@;6]N=&@@:6X@9F]R;6%T($U-"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!C=7)R96YT(&UO;G1H(&EN('1W;R!D:6=I="!F;W)M870*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:"@I"B`@("!["B`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@;&]C86P@9&%Y(&EN(&9O
M<FUA="!$1`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@8W5R
M<F5N="!D87D@;V8@=&AE(&UO;G1H(&EN('1W;R!D:6=I="!F;W)M870*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G971$87DH*0H@("`@>PH@("`@("`@(')E='5R
M;B!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&YU;6)E<B!O9B!D87ES('-I;F-E(#,Q($1E8V5M8F5R
M(&]F('EE87(@8F5F;W)E(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@
M("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R
M(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C
M86P@>65A<@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@:G5L:6%N
M(&1A=&4@9F]R('1H92!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@:G5L:6%N
M1&%T92@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@("1D87ES(#T@87)R
M87DH,"P@,S$L(#4Y+"`Y,"P@,3(P+"`Q-3$L(#$X,2P@,C$R+"`R-#,L(#(W
M,RP@,S`T+"`S,S0I.PH@("`@("`@("1J=6QI86X@/2`H)&1A>7-;)&UO;G1H
M("T@,5T@*R`D9&%Y*3L*("`@("`@("!I9B`H)&UO;G1H(#X@,B`F)B!$871E
M7T-A;&,Z.FES3&5A<%EE87(H)'EE87(I*2!["B`@("`@("`@("`@("1J=6QI
M86XK*SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1J=6QI86X["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!F=6QL('=E96MD87D@;F%M
M92!F;W(@=&AE(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT
M:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H
M"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O
M=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A
M<@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9G5L;"!N86UE
M(&]F('1H92!D87D@;V8@=&AE('=E96L*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M9717965K9&%Y1G5L;&YA;64H)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R
M(#T@,"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@
M("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@
M("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y
M(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@
M("`D=V5E:V1A>5]N86UE<R`]($1A=&5?0V%L8SHZ9V5T5V5E:T1A>7,H*3L*
M("`@("`@("`D=V5E:V1A>2`]($1A=&5?0V%L8SHZ9&%Y3V97965K*"1D87DL
M("1M;VYT:"P@)'EE87(I.PH@("`@("`@(')E='5R;B`D=V5E:V1A>5]N86UE
M<ULD=V5E:V1A>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!A8F)R979I871E9"!W965K9&%Y(&YA;64@9F]R('1H92!G:79E;B!D871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y
M(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@
M("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@
M("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F
M875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!I;G0@
M("`@)&QE;F=T:"`@=&AE(&QE;F=T:"!O9B!A8F)R979I871I;VX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&%B8G)E=FEA=&5D(&YA;64@
M;V8@=&AE(&1A>2!O9B!T:&4@=V5E:PH@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A=&5?0V%L8SHZ
M9V5T5V5E:V1A>49U;&QN86UE*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5V5E:V1A>4%B8G)N86UE*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`]
M(#`L("1L96YG=&@@/2`S*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A
M<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2![
M"B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@
M("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!S=6)S='(H1&%T95]#86QC.CIG9717965K
M9&%Y1G5L;&YA;64H)&1A>2P@)&UO;G1H+"`D>65A<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`P+"`D;&5N9W1H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&9U;&P@;6]N=&@@;F%M92!F;W(@=&AE(&=I=F5N(&UO
M;G1H"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@
M;6]N=&@*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&9U;&P@
M;F%M92!O9B!T:&4@;6]N=&@*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT
M:$9U;&QN86UE*"1M;VYT:"D*("`@('L*("`@("`@("`D;6]N=&@@/2`H:6YT
M*21M;VYT:#L*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@
M("`@("`D;6]N=&@@/2`H:6YT*41A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*
M("`@("`@("!]"B`@("`@("`@)&UO;G1H7VYA;65S(#T@1&%T95]#86QC.CIG
M971-;VYT:$YA;65S*"D["B`@("`@("`@<F5T=7)N("1M;VYT:%]N86UE<ULD
M;6]N=&A=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@86)B
M<F5V:6%T960@;6]N=&@@;F%M92!F;W(@=&AE(&=I=F5N(&UO;G1H"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@*("`@
M("`J($!P87)A;2!I;G0@("`@)&QE;F=T:"`@=&AE(&QE;F=T:"!O9B!A8F)R
M979I871I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&%B
M8G)E=FEA=&5D(&YA;64@;V8@=&AE(&UO;G1H"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S964@1&%T95]#
M86QC.CIG971-;VYT:$9U;&QN86UE"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$UO;G1H06)B<FYA;64H)&UO;G1H+"`D;&5N9W1H(#T@,RD*("`@('L*("`@
M("`@("`D;6]N=&@@/2`H:6YT*21M;VYT:#L*("`@("`@("!I9B`H96UP='DH
M)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=6)S='(H
M1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE*"1M;VYT:"DL(#`L("1L96YG
M=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M97)I
M8R!M;VYT:"!F<F]M('1H92!M;VYT:"!N86UE(&]R(&%N(&%B<F5V:6%T:6]N
M"B`@("`@*@H@("`@("H@0F]T:"!!=6=U<W0@86YD($%U9R!W;W5L9"!R971U
M<FX@."X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;VYT:"`@=&AE
M(&YA;64@;V8@=&AE(&UO;G1H('1O(&5X86UI;F4N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@($-A<V4@:6YS96YS:71I=F4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!T:&4@;6]N=&@G<R!N=6UB97(*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-;VYT:$9R;VU&=6QL3F%M92@D;6]N=&@I"B`@
M("!["B`@("`@("`@)&UO;G1H(#T@<W1R=&]L;W=E<B@D;6]N=&@I.PH@("`@
M("`@("1M;VYT:',@/2!$871E7T-A;&,Z.F=E=$UO;G1H3F%M97,H*3L*("`@
M("`@("!W:&EL92AL:7-T*"1I9"P@)&YA;64I(#T@96%C:"@D;6]N=&AS*2D@
M>PH@("`@("`@("`@("!I9B`H97)E9R@D;6]N=&@L('-T<G1O;&]W97(H)&YA
M;64I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@,#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@;6]N=&@@;F%M97,*("`@
M("`J"B`@("`@*B!5<V5D('1O('1A:V4@861V86YT86=E(&]F('1H92!S971L
M;V-A;&4@9G5N8W1I;VX@=&\@<F5T=7)N"B`@("`@*B!L86YG=6%G92!S<&5C
M:69I8R!M;VYT:"!N86UE<RX*("`@("`J"B`@("`@*B!43T1/.B!C86-H92!V
M86QU97,@=&\@<V]M92!G;&]B86P@87)R87D@=&\@879O:60@<')E9F]R;6%C
M90H@("`@("H@:&ET<R!W:&5N(&-A;&QE9"!M;W)E('1H86X@;VYC92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N<R!A<G)A>2`@86X@87)R87D@;V8@;6]N=&@@
M;F%M97,*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:$YA;65S*"D*("`@
M('L*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"`Q,SL@)&DK*RD@>PH@("`@
M("`@("`@("`D;6]N=&AS6R1I72`]('-T<F9T:6UE*"<E0B<L(&UK=&EM92@P
M+"`P+"`P+"`D:2P@,2P@,C`P,2DI.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&UO;G1H<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@
M87)R87D@;V8@=V5E:R!D87ES"B`@("`@*@H@("`@("H@57-E9"!T;R!T86ME
M(&%D=F%N=&%G92!O9B!T:&4@<V5T;&]C86QE(&9U;F-T:6]N('1O"B`@("`@
M*B!R971U<FX@;&%N9W5A9V4@<W!E8VEF:6,@=V5E:R!D87ES+@H@("`@("H*
M("`@("`J(%1/1$\Z(&-A8VAE('9A;'5E<R!T;R!S;VUE(&=L;V)A;"!A<G)A
M>2!T;R!A=F]I9"!P<F5F;W)M86-E"B`@("`@*B!H:71S('=H96X@8V%L;&5D
M(&UO<F4@=&AA;B!O;F-E+@H@("`@("H*("`@("`J($!R971U<FYS(&%R<F%Y
M("!A;B!A<G)A>2!O9B!W965K(&1A>2!N86UE<PH@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%=E96M$87ES*"D*("`@('L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`W.R`D:2LK*2!["B`@("`@("`@("`@("1W965K9&%Y<ULD:5T@/2!S
M=')F=&EM92@G)4$G+"!M:W1I;64H,"P@,"P@,"P@,2P@)&DL(#(P,#$I*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1W965K9&%Y<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@9&%Y(&]F('=E96L@9F]R(&=I=F5N(&1A
M=&4@*#`@/2!3=6YD87DI"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D
M9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!T:&4@9&%Y
M(&EN('1H92!W965K"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&%Y3V97965K*"1D
M87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M
M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC
M.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@:68@*"1M;VYT:"`^(#(I('L*
M("`@("`@("`@("`@)&UO;G1H("T](#(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&UO;G1H("L](#$P.PH@("`@("`@("`@("`D>65A<BTM.PH@
M("`@("`@('T*"B`@("`@("`@)&1A>2`]("AF;&]O<B@H,3,@*B`D;6]N=&@@
M+2`Q*2`O(#4I("L*("`@("`@("`@("`@("`@("1D87D@*R`H)'EE87(@)2`Q
M,#`I("L*("`@("`@("`@("`@("`@(&9L;V]R*"@D>65A<B`E(#$P,"D@+R`T
M*2`K"B`@("`@("`@("`@("`@("!F;&]O<B@H)'EE87(@+R`Q,#`I("\@-"D@
M+2`R("H*("`@("`@("`@("`@("`@(&9L;V]R*"1Y96%R("\@,3`P*2`K(#<W
M*3L*"B`@("`@("`@)'=E96MD87E?;G5M8F5R(#T@)&1A>2`M(#<@*B!F;&]O
M<B@D9&%Y("\@-RD["B`@("`@("`@<F5T=7)N("1W965K9&%Y7VYU;6)E<CL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=V5E:R!O9B!T:&4@>65A
M<BP@9FER<W0@4W5N9&%Y(&ES(&9I<G-T(&1A>2!O9B!F:7)S="!W965K"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F
M('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@
M("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D
M>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@=&AE(&YU;6)E<B!O9B!T:&4@=V5E:R!I;B!T:&4@>65A<@H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=E96M/9EEE87(H)&1A>2`](#`L("1M;VYT:"`]
M(#`L("1Y96%R(#T@,"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I
M*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E
M62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@
M("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@
M("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@
M('T*("`@("`@("`D:7-O("`@(#T@1&%T95]#86QC.CIG<F5G;W)I86Y4;TE3
M3R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`D<&%R=',@(#T@97AP
M;&]D92@G+2<L("1I<V\I.PH@("`@("`@("1W965K7VYU;6)E<B`](&EN='9A
M;"@D<&%R='-;,5TI.PH@("`@("`@(')E='5R;B`D=V5E:U]N=6UB97(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('%U87)T97(@;V8@=&AE('EE
M87(@9F]R(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@
M("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@
M('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@
M("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@
M9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F('1H92!Q
M=6%R=&5R(&EN('1H92!Y96%R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<75A<G1E
M<D]F665A<B@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE
M87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@("1Y96%R7W%U
M87)T97(@/2!I;G1V86PH*"1M;VYT:"`M(#$I("\@,R`K(#$I.PH@("`@("`@
M(')E='5R;B`D>65A<E]Q=6%R=&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEN9"!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&=I=F5N(&UO;G1H"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L
M(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M
M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA
M="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!D87ES('1H92!M;VYT:"!H
M87,*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!D87ES26Y-;VYT:"@D;6]N=&@@/2`P
M+"`D>65A<B`](#`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@
M>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@
M("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1Y96%R(#T](#$U.#(@)B8@)&UO;G1H
M(#T](#$P*2!["B`@("`@("`@("`@(')E='5R;B`R,3L@("\O($]C=&]B97(@
M,34X,B!O;FQY(&AA9"`Q<W0M-'1H(&%N9"`Q-71H+3,Q<W0*("`@("`@("!]
M"@H@("`@("`@(&EF("@D;6]N=&@@/3T@,BD@>PH@("`@("`@("`@("!I9B`H
M1&%T95]#86QC.CII<TQE87!996%R*"1Y96%R*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(#(Y.PH@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B`R.#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M96EF("@D;6]N=&@@/3T@-"!O<B`D;6]N=&@@/3T@-B!O<B`D;6]N=&@@/3T@
M.2!O<B`D;6]N=&@@/3T@,3$I('L*("`@("`@("`@("`@<F5T=7)N(#,P.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`S,3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UB97(@
M;V8@<F]W<R!O;B!A(&-A;&5N9&%R(&UO;G1H"B`@("`@*@H@("`@("H@57-E
M9G5L(&9O<B!D971E<FUI;FEN9R!T:&4@;G5M8F5R(&]F(')O=W,@=VAE;B!D
M:7-P;&%Y:6YG(&$@='EP:6-A;`H@("`@("H@;6]N=&@@8V%L96YD87(N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L
M(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M
M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA
M="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!W965K<R!T:&4@;6]N=&@@
M:&%S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=V5E:W-);DUO;G1H*"1M;VYT:"`]
M(#`L("1Y96%R(#T@,"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I
M*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E
M62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@
M("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD[
M"B`@("`@("`@?0H@("`@("`@("1&1$]-(#T@1&%T95]#86QC.CIF:7)S=$]F
M36]N=&A7965K9&%Y*"1M;VYT:"P@)'EE87(I.PH@("`@("`@(&EF("A$051%
M7T-!3$-?0D5'24Y?5T5%2T1!63T],2`F)B`D1D1/33T],"D@>PH@("`@("`@
M("`@("`D9FER<W1?=V5E:U]D87ES(#T@-R`M("1&1$]-("L@1$%415]#04Q#
M7T)%1TE.7U=%14M$05D["B`@("`@("`@("`@("1W965K<R`](#$["B`@("`@
M("`@?2!E;'-E:68@*$1!5$5?0T%,0U]"14=)3E]7145+1$%9/3TP("8F("1&
M1$]-(#T](#8I('L*("`@("`@("`@("`@)&9I<G-T7W=E96M?9&%Y<R`](#<@
M+2`D1D1/32`K($1!5$5?0T%,0U]"14=)3E]7145+1$%9.PH@("`@("`@("`@
M("`D=V5E:W,@/2`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M:7)S=%]W965K7V1A>7,@/2!$051%7T-!3$-?0D5'24Y?5T5%2T1!62`M("1&
M1$]-.PH@("`@("`@("`@("`D=V5E:W,@/2`P.PH@("`@("`@('T*("`@("`@
M("`D9FER<W1?=V5E:U]D87ES("4](#<["B`@("`@("`@<F5T=7)N(&-E:6PH
M*$1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BD*("`@("`@
M("`@("`@("`@("`@("`@+2`D9FER<W1?=V5E:U]D87ES*2`O(#<I("L@)'=E
M96MS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&%N(&%R<F%Y('=I
M=&@@9&%Y<R!I;B!W965K"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D
M9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T
M:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@)'=E96M;)'=E96MD87E="B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0V%L96YD87)7965K*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A
M<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]
M($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y
M96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI
M('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E
M;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@
M("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@
M("`@("!]"@H@("`@("`@("1W965K7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@
M("`@+R\@9&%T92!F;W(@=&AE(&-O;'5M;B!O9B!W965K"@H@("`@("`@("1C
M=7)R7V1A>2`]($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH)&1A>2P@)&UO;G1H
M+"`D>65A<BPG)44G*3L*"B`@("`@("`@9F]R("@D8V]U;G1E<B`](#`[("1C
M;W5N=&5R(#P](#8[("1C;W5N=&5R*RLI('L*("`@("`@("`@("`@)'=E96M?
M87)R87E;)&-O=6YT97)=(#T@1&%T95]#86QC.CID87ES5&]$871E*"1C=7)R
M7V1A>2P@)&9O<FUA="D["B`@("`@("`@("`@("1C=7)R7V1A>2LK.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'=E96M?87)R87D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@82!S970@;V8@87)R87ES('1O(&-O;G-T<G5C
M="!A(&-A;&5N9&%R(&UO;G1H(&9O<B!T:&4@9VEV96X@9&%T90H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@
M("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R
M;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("1M
M;VYT:%LD<F]W75LD8V]L70H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A;&5N
M9&%R36]N=&@H)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@
M("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*
M("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N
M=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H*("`@
M("`@("`D;6]N=&A?87)R87D@/2!A<G)A>2@I.PH*("`@("`@("`O+R!D871E
M(&9O<B!T:&4@9FER<W0@<F]W+"!F:7)S="!C;VQU;6X@;V8@8V%L96YD87(@
M;6]N=&@*("`@("`@("!I9B`H1$%415]#04Q#7T)%1TE.7U=%14M$05D@/3T@
M,2D@>PH@("`@("`@("`@("!I9B`H1&%T95]#86QC.CIF:7)S=$]F36]N=&A7
M965K9&%Y*"1M;VYT:"P@)'EE87(I(#T](#`I('L*("`@("`@("`@("`@("`@
M("1C=7)R7V1A>2`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@G,#$G+"`D;6]N
M=&@L("1Y96%R*2`M(#8["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D8W5R<E]D87D@/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)S`Q
M)RP@)&UO;G1H+"`D>65A<BD*("`@("`@("`@("`@("`@("`@("`M($1A=&5?
M0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A>2@D;6]N=&@L("1Y96%R*2`K(#$[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8W5R<E]D87D@/2`H1&%T95]#86QC.CID871E5&]$87ES*"<P,2<L("1M;VYT
M:"P@)'EE87(I"B`@("`@("`@("`@("`@("`M($1A=&5?0V%L8SHZ9FER<W1/
M9DUO;G1H5V5E:V1A>2@D;6]N=&@L("1Y96%R*2D["B`@("`@("`@?0H*("`@
M("`@("`O+R!N=6UB97(@;V8@9&%Y<R!I;B!T:&ES(&UO;G1H"B`@("`@("`@
M)&1A>7-);DUO;G1H(#T@1&%T95]#86QC.CID87ES26Y-;VYT:"@D;6]N=&@L
M("1Y96%R*3L*"B`@("`@("`@)'=E96MS26Y-;VYT:"`]($1A=&5?0V%L8SHZ
M=V5E:W-);DUO;G1H*"1M;VYT:"P@)'EE87(I.PH@("`@("`@(&9O<B`H)')O
M=U]C;W5N=&5R(#T@,#L@)')O=U]C;W5N=&5R(#P@)'=E96MS26Y-;VYT:#L@
M)')O=U]C;W5N=&5R*RLI('L*("`@("`@("`@("`@9F]R("@D8V]L=6UN7V-O
M=6YT97(@/2`P.R`D8V]L=6UN7V-O=6YT97(@/#T@-CL@)&-O;'5M;E]C;W5N
M=&5R*RLI('L*("`@("`@("`@("`@("`@("1M;VYT:%]A<G)A>5LD<F]W7V-O
M=6YT97)=6R1C;VQU;6Y?8V]U;G1E<ET@/0H@("`@("`@("`@("`@("`@("`@
M("`@("!$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&-U<G)?9&%Y("P@)&9O<FUA
M="D["B`@("`@("`@("`@("`@("`D8W5R<E]D87DK*SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M;VYT:%]A<G)A>3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A('-E="!O9B!A<G)A>7,@=&\@
M8V]N<W1R=6-T(&$@8V%L96YD87(@>65A<B!F;W(@=&AE(&=I=F5N(&1A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R
M(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&-U<G)E;G0@;&]C86P@
M>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG
M(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`D>65A<ELD;6]N=&A=6R1R;W==6R1C;VQ=
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V%L96YD87)996%R*"1Y96%R(#T@
M,"P@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"@H@("`@("`@("1Y96%R
M7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@9F]R("@D8W5R<E]M;VYT:"`]
M(#`[("1C=7)R7VUO;G1H(#P](#$Q.R`D8W5R<E]M;VYT:"LK*2!["B`@("`@
M("`@("`@("1Y96%R7V%R<F%Y6R1C=7)R7VUO;G1H72`]"B`@("`@("`@("`@
M("`@("`@("`@1&%T95]#86QC.CIG971#86QE;F1A<DUO;G1H*"1C=7)R7VUO
M;G1H("L@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'EE87(L("1F;W)M870I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1Y96%R7V%R<F%Y.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!D871E(&]F(&1A>2!B969O<F4@9VEV96X@9&%T90H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P
M87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@
M("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M
M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O
M=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@
M:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<')E
M=D1A>2@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@
M("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y
M96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#
M86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("`D9&%Y<R`]
M($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*
M("`@("`@("!R971U<FX@1&%T95]#86QC.CID87ES5&]$871E*"1D87ES("T@
M,2P@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A
M=&4@;V8@9&%Y(&%F=&5R(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@
M("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R
M(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C
M86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R
M:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I
M<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1$87DH)&1A>2`]
M(#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@
M("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M
M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC
M.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@)&1A>7,@/2!$871E7T-A;&,Z
M.F1A=&54;T1A>7,H)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@<F5T
M=7)N($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9&%Y<R`K(#$L("1F;W)M870I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H92!P
M<F5V:6]U<R!W965K9&%Y+"!S:VEP<&EN9R!F<F]M($UO;F1A>2!T;R!&<FED
M87D*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D
M87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y
M"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F
M875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT
M("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O
M<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!R9797965K9&%Y*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A
M<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%4
M15]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I
M*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E
M62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@
M("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@
M("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@
M('T*("`@("`@("`D9&%Y<R`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y
M+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("!I9B`H1&%T95]#86QC.CID87E/
M9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD@/3T@,2D@>PH@("`@("`@("`@
M("`D9&%Y<R`M/2`S.PH@("`@("`@('T@96QS96EF("A$871E7T-A;&,Z.F1A
M>4]F5V5E:R@D9&%Y+"`D;6]N=&@L("1Y96%R*2`]/2`P*2!["B`@("`@("`@
M("`@("1D87ES("T](#(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&1A>7,@+3T@,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1A=&5?0V%L
M8SHZ9&%Y<U1O1&%T92@D9&%Y<RP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&YE>'0@=V5E:V1A>2!O9B!G
M:79E;B!D871E+"!S:VEP<&EN9R!F<F]M"B`@("`@*B!&<FED87D@=&\@36]N
M9&%Y"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@
M9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A
M>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN
M="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S
M=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F
M;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!N97AT5V5E:V1A>2@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE
M87(@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!
M5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R
M*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G
M)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*
M("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I
M.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@
M("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@
M("!]"B`@("`@("`@)&1A>7,@/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A
M>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@:68@*$1A=&5?0V%L8SHZ9&%Y
M3V97965K*"1D87DL("1M;VYT:"P@)'EE87(I(#T](#4I('L*("`@("`@("`@
M("`@)&1A>7,@*ST@,SL*("`@("`@("!](&5L<V5I9B`H1&%T95]#86QC.CID
M87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD@/3T@-BD@>PH@("`@("`@
M("`@("`D9&%Y<R`K/2`R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1D87ES("L](#$["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$871E7T-A
M;&,Z.F1A>7-4;T1A=&4H)&1A>7,L("1F;W)M870I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H92!P<F5V:6]U<R!S<&5C:69I
M8R!D87D@;V8@=&AE('=E96L*("`@("`J(&9R;VT@=&AE(&=I=F5N(&1A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT(&1A>2!O9B!W965K+"`P/5-U;F1A
M>0H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H
M92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@
M0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A
M<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!B;V]L("`@)&]N
M3W)"969O<F4@(&EF('1R=64@86YD(&1A>7,@87)E('-A;64L(')E='5R;G,@
M8W5R<F5N="!D87D*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE
M('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@
M9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!P<F5V1&%Y3V97
M965K*"1D;W<L("1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?
M1D]234%4+"`D;VY/<D)E9F]R92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D
M87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R5D)RD["B`@("`@("`@?0H@("`@("`@("1D87ES(#T@1&%T95]#86QC.CID
M871E5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@("1C=7)R
M7W=E96MD87D@/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N=&@L
M("1Y96%R*3L*("`@("`@("!I9B`H)&-U<G)?=V5E:V1A>2`]/2`D9&]W*2![
M"B`@("`@("`@("`@(&EF("@A)&]N3W)"969O<F4I('L*("`@("`@("`@("`@
M("`@("1D87ES("T](#<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I
M9B`H)&-U<G)?=V5E:V1A>2`\("1D;W<I('L*("`@("`@("`@("`@)&1A>7,@
M+3T@-R`M("@D9&]W("T@)&-U<G)?=V5E:V1A>2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&1A>7,@+3T@)&-U<G)?=V5E:V1A>2`M("1D;W<[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A>7-4;T1A
M=&4H)&1A>7,L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!D871E(&]F('1H92!N97AT('-P96-I9FEC(&1A>2!O9B!T:&4@=V5E
M:PH@("`@("H@9G)O;2!T:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P
M87)A;2!I;G0@("`@)&1O=R`@("`@=&AE(&1A>2!O9B!T:&4@=V5E:R`H,"`]
M(%-U;F1A>2D*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A
M>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*
M("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@
M("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@8F]O
M;"`@("1O;D]R069T97(@(&EF('1R=64@86YD(&1A>7,@87)E('-A;64L(')E
M='5R;G,@8W5R<F5N="!D87D*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA
M="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U
M='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I
M;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!N97AT
M1&%Y3V97965K*"1D;W<L("1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`]
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%
M7T-!3$-?1D]234%4+"`D;VY/<D%F=&5R(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#
M86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)60G*3L*("`@("`@("!]"@H@("`@("`@("1D87ES(#T@1&%T95]#
M86QC.CID871E5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@
M("1C=7)R7W=E96MD87D@/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D
M;6]N=&@L("1Y96%R*3L*"B`@("`@("`@:68@*"1C=7)R7W=E96MD87D@/3T@
M)&1O=RD@>PH@("`@("`@("`@("!I9B`H(21O;D]R069T97(I('L*("`@("`@
M("`@("`@("`@("1D87ES("L](#<["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H)&-U<G)?=V5E:V1A>2`^("1D;W<I('L*("`@("`@("`@("`@
M)&1A>7,@*ST@-R`M("@D8W5R<E]W965K9&%Y("T@)&1O=RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&1A>7,@*ST@)&1O=R`M("1C=7)R7W=E
M96MD87D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@1&%T95]#86QC.CID
M87ES5&]$871E*"1D87ES+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@9&%T92!O9B!T:&4@<')E=FEO=7,@<W!E8VEF:6,@9&%Y
M(&]F('1H92!W965K"B`@("`@*B!O;B!O<B!B969O<F4@=&AE(&=I=F5N(&1A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D;W<@("`@('1H92!D
M87D@;V8@=&AE('=E96L@*#`@/2!3=6YD87DI"B`@("`@*B!`<&%R86T@:6YT
M("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT
M:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H
M"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O
M=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A
M<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN
M9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O
M<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('!R979$87E/9E=E96M/;D]R0F5F
M;W)E*"1D;W<L("1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@
M1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#
M86QC.CIP<F5V1&%Y3V97965K*"1D;W<L("1D87DL("1M;VYT:"P@)'EE87(L
M("1F;W)M870L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T
M92!O9B!T:&4@;F5X="!S<&5C:69I8R!D87D@;V8@=&AE('=E96L*("`@("`J
M(&]N(&]R(&%F=&5R('1H92!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN="`@("`D9&]W("`@("!T:&4@9&%Y(&]F('1H92!W965K("@P(#T@
M4W5N9&%Y*0H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y
M(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@
M("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@
M("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F
M875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I
M;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M
M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!N97AT1&%Y3V97965K3VY/<D%F=&5R*"1D;W<L("1D87D@/2`P+"`D
M;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@
M>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.FYE>'1$87E/9E=E96LH)&1O
M=RP@)&1A>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1FEN9"!T:&4@;6]N=&@@9&%Y(&]F('1H92!B96=I;FYI
M;F<@;V8@=V5E:R!F;W(@9VEV96X@9&%T92P*("`@("`J('5S:6YG($1!5$5?
M0T%,0U]"14=)3E]7145+1$%9"B`@("`@*@H@("`@("H@0V%N(')E='5R;B!W
M965K9&%Y(&]F('!R978@;6]N=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N
M=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT
M:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F
M;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE
M87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I
M;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F
M;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!B96=I;D]F5V5E:R@D9&%Y(#T@
M,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#
M86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@)'1H:7-?=V5E:V1A>2`]
M($1A=&5?0V%L8SHZ9&%Y3V97965K*"1D87DL("1M;VYT:"P@)'EE87(I.PH@
M("`@("`@("1I;G1E<G9A;"`]("@W("T@1$%415]#04Q#7T)%1TE.7U=%14M$
M05D@*R`D=&AI<U]W965K9&%Y*2`E(#<["B`@("`@("`@<F5T=7)N($1A=&5?
M0V%L8SHZ9&%Y<U1O1&%T92A$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@
M)&UO;G1H+"`D>65A<BD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("T@)&EN=&5R=F%L+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9I;F0@=&AE(&UO;G1H(&1A>2!O9B!T:&4@96YD(&]F('=E96L@
M9F]R(&=I=F5N(&1A=&4L"B`@("`@*B!U<VEN9R!$051%7T-!3$-?0D5'24Y?
M5T5%2T1!60H@("`@("H*("`@("`J($-A;B!R971U<FX@=V5E:V1A>2!O9B!F
M;VQL;W=I;F<@;6]N=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D
M9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T
M:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!E;F1/9E=E96LH)&1A>2`](#`L("1M;VYT
M:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@
M>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<U]W965K9&%Y(#T@1&%T95]#86QC
M.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@)&EN
M=&5R=F%L(#T@*#8@*R!$051%7T-!3$-?0D5'24Y?5T5%2T1!62`M("1T:&ES
M7W=E96MD87DI("4@-SL*("`@("`@("!R971U<FX@1&%T95]#86QC.CID87ES
M5&]$871E*$1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y
M96%R*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D
M:6YT97)V86PL("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN
M9"!T:&4@;6]N=&@@9&%Y(&]F('1H92!B96=I;FYI;F<@;V8@=V5E:R!B969O
M<F4@9VEV96X@9&%T92P*("`@("`J('5S:6YG($1!5$5?0T%,0U]"14=)3E]7
M145+1$%9"B`@("`@*@H@("`@("H@0V%N(')E='5R;B!W965K9&%Y(&]F('!R
M978@;6]N=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@
M("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N
M=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A
M<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O
M<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P
M87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO
M=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!B96=I;D]F4')E=E=E96LH)&1A>2`](#`L("1M;VYT
M:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#
M86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D
M9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W
M*"<E9"<I.PH@("`@("`@('T*"B`@("`@("`@)&1A=&4@/2!$871E7T-A;&,Z
M.F1A>7-4;T1A=&4H1&%T95]#86QC.CID871E5&]$87ES*"1D87DM-RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D>65A<BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R59)6TE9"<I
M.PH*("`@("`@("`D<')E=E]W965K7WEE87(@(#T@<W5B<W1R*"1D871E+"`P
M+"`T*3L*("`@("`@("`D<')E=E]W965K7VUO;G1H(#T@<W5B<W1R*"1D871E
M+"`T+"`R*3L*("`@("`@("`D<')E=E]W965K7V1A>2`@(#T@<W5B<W1R*"1D
M871E+"`V+"`R*3L*"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ8F5G:6Y/
M9E=E96LH)'!R979?=V5E:U]D87DL("1P<F5V7W=E96M?;6]N=&@L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R979?=V5E:U]Y
M96%R+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@=&AE
M(&UO;G1H(&1A>2!O9B!T:&4@8F5G:6YN:6YG(&]F('=E96L@869T97(@9VEV
M96X@9&%T92P*("`@("`J('5S:6YG($1!5$5?0T%,0U]"14=)3E]7145+1$%9
M"B`@("`@*@H@("`@("H@0V%N(')E='5R;B!W965K9&%Y(&]F('!R978@;6]N
M=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@
M9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A
M>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN
M="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S
M=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F
M;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!B96=I;D]F3F5X=%=E96LH)&1A>2`](#`L("1M;VYT:"`](#`L
M("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@
M>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I
M.PH@("`@("`@('T*"B`@("`@("`@)&1A=&4@/2!$871E7T-A;&,Z.F1A>7-4
M;T1A=&4H1&%T95]#86QC.CID871E5&]$87ES*"1D87D@*R`W+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;6]N=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Y96%R*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)5DE;25D)RD["@H@
M("`@("`@("1N97AT7W=E96M?>65A<B`@/2!S=6)S='(H)&1A=&4L(#`L(#0I
M.PH@("`@("`@("1N97AT7W=E96M?;6]N=&@@/2!S=6)S='(H)&1A=&4L(#0L
M(#(I.PH@("`@("`@("1N97AT7W=E96M?9&%Y("`@/2!S=6)S='(H)&1A=&4L
M(#8L(#(I.PH*("`@("`@("!R971U<FX@1&%T95]#86QC.CIB96=I;D]F5V5E
M:R@D;F5X=%]W965K7V1A>2P@)&YE>'1?=V5E:U]M;VYT:"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5X=%]W965K7WEE87(L
M("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&1A=&4@
M;V8@9FER<W0@9&%Y(&]F(&UO;G1H(&]F(&=I=F5N(&1A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@
M("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA
M="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H
M92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A=&5?
M0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"D*("`@("`J($!D97!R96-A=&5D
M($UE=&AO9"!D97!R96-A=&5D(&EN(%)E;&5A<V4@,2XU+C`*("`@("`J+PH@
M("`@9G5N8W1I;VX@8F5G:6Y/9DUO;G1H*"1M;VYT:"`](#`L("1Y96%R(#T@
M,"P@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M
M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC
M.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1&%T
M95]#86QC.CID871E1F]R;6%T*"<P,2<L("1M;VYT:"P@)'EE87(L("1F;W)M
M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H
M92!F:7)S="!D87D@;V8@<')E=FEO=7,@;6]N=&@@;V8@9VEV96X@9&%T90H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O
M9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@
M("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@
M)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T
M('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE
M(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S964@1&%T95]#
M86QC.CIB96=I;D]F36]N=&A">5-P86XH*0H@("`@("H@0&1E<')E8V%T960@
M365T:&]D(&1E<')E8V%T960@:6X@4F5L96%S92`Q+C4N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!B96=I;D]F4')E=DUO;G1H*"1D87D@/2`P+"`D;6]N=&@@
M/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D
M87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R5D)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D;6]N=&@@/B`Q*2!["B`@
M("`@("`@("`@("1M;VYT:"TM.PH@("`@("`@("`@("`D9&%Y(#T@,3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D>65A<BTM.PH@("`@("`@("`@
M("`D;6]N=&@@/2`Q,CL*("`@("`@("`@("`@)&1A>2`@(#T@,3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y
M+"`D;6]N=&@L("1Y96%R+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@9&%T92!O9B!T:&4@;&%S="!D87D@;V8@<')E=FEO=7,@
M;6]N=&@@9F]R(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT
M:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H
M"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O
M=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A
M<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN
M9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O
M<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B!`<V5E($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@I
M"B`@("`@*B!`9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E9"!I;B!296QE
M87-E(#$N-2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N9$]F4')E=DUO;G1H
M*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@
M("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*
M("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N
M=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T
M95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M)&UO;G1H(#X@,2D@>PH@("`@("`@("`@("`D;6]N=&@M+3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D>65A<BTM.PH@("`@("`@("`@("`D;6]N
M=&@@/2`Q,CL*("`@("`@("!]"B`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ
M9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BD["B`@("`@("`@<F5T=7)N($1A
M=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y+"`D;6]N=&@L("1Y96%R+"`D9F]R
M;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!B
M96=I;B!O9B!N97AT(&UO;G1H(&]F(&=I=F5N(&1A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@
M:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H
M92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T
M:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H
M92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A=&5?0V%L8SHZ8F5G:6Y/
M9DUO;G1H0GE3<&%N*"D*("`@("`J($!D97!R96-A=&5D($UE=&AO9"!D97!R
M96-A=&5D(&EN(%)E;&5A<V4@,2XU+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M8F5G:6Y/9DYE>'1-;VYT:"@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@
M/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@
M1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE
M87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W
M*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@
M>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@
M("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&UO;G1H(#P@,3(I('L*("`@("`@("`@("`@
M)&UO;G1H*RL["B`@("`@("`@("`@("1D87D@/2`Q.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1Y96%R*RL["B`@("`@("`@("`@("1M;VYT:"`]
M(#$["B`@("`@("`@("`@("1D87D@/2`Q.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"1D87DL("1M;VYT:"P@)'EE
M87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D
M871E(&]F('1H92!L87-T(&1A>2!O9B!N97AT(&UO;G1H(&]F(&=I=F5N(&1A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D
M87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y
M"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F
M875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT
M("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O
M<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A
M=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@I"B`@("`@*B!`9&5P<F5C871E
M9"!-971H;V0@9&5P<F5C871E9"!I;B!296QE87-E(#$N-2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N9$]F3F5X=$UO;G1H*"1D87D@/2`P+"`D;6]N=&@@
M/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC
M.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y
M*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E
M9"<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&UO;G1H(#P@,3(I('L*("`@
M("`@("`@("`@)&UO;G1H*RL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'EE87(K*SL*("`@("`@("`@("`@)&UO;G1H(#T@,3L*("`@("`@("!]
M"B`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H
M+"`D>65A<BD["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA
M="@D9&%Y+"`D;6]N=&@L("1Y96%R+"`D9F]R;6%T*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@9FER<W0@9&%Y(&]F('1H
M92!M;VYT:"!I;B!T:&4@;G5M8F5R(&]F(&UO;G1H<PH@("`@("H@9G)O;2!T
M:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&UO
M;G1H<R`@=&AE(&YU;6)E<B!O9B!M;VYT:',@9G)O;2!T:&4@9&%T92!P<F]V
M:61E9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%!O<VET:79E
M(&YU;6)E<G,@9V\@:6YT;R!T:&4@9G5T=7)E+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@3F5G871I=F4@;G5M8F5R<R!G;R!I;G1O('1H92!P
M87-T+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@,"!I<R!T:&4@
M;6]N=&@@<')E<V5N=&5D(&EN("1M;VYT:"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C
M86P@;6]N=&@*("`@("`J($!P87)A;2!S=')I;F<@)'EE87(@("`@=&AE('EE
M87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!C=7)R96YT(&QO8V%L('EE87(*
M("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I
M8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M
M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I
M8PH@("`@("H@0'-I;F-E("!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XU+C`*("`@("`J+PH@("`@9G5N8W1I;VX@8F5G:6Y/9DUO;G1H0GE3
M<&%N*"1M;VYT:',@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,
M0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@
M("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@
M("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&UO;G1H<R`^(#`I('L*("`@("`@("`@("`@
M+R\@9G5T=7)E(&UO;G1H"B`@("`@("`@("`@("1T;7!?;6\@/2`D;6]N=&@@
M*R`D;6]N=&AS.PH@("`@("`@("`@("`D;6]N=&@@(#T@)'1M<%]M;R`E(#$R
M.PH@("`@("`@("`@("!I9B`H)&UO;G1H(#T](#`I('L*("`@("`@("`@("`@
M("`@("1M;VYT:"`](#$R.PH@("`@("`@("`@("`@("`@)'EE87(@/2`D>65A
M<B`K(&9L;V]R*"@D=&UP7VUO("T@,2D@+R`Q,BD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D>65A<B`]("1Y96%R("L@9FQO;W(H
M)'1M<%]M;R`O(#$R*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O('!A<W0@;W(@<')E<V5N="!M;VYT:`H@("`@("`@
M("`@("`D=&UP7VUO(#T@)&UO;G1H("L@)&UO;G1H<SL*("`@("`@("`@("`@
M:68@*"1T;7!?;6\@/B`P*2!["B`@("`@("`@("`@("`@("`O+R!S86UE('EE
M87(*("`@("`@("`@("`@("`@("1M;VYT:"`]("1T;7!?;6\["B`@("`@("`@
M("`@('T@96QS96EF("@D=&UP7VUO(#T](#`I('L*("`@("`@("`@("`@("`@
M("\O('!R:6]R(&1E8PH@("`@("`@("`@("`@("`@)&UO;G1H(#T@,3(["B`@
M("`@("`@("`@("`@("`D>65A<BTM.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@+R\@<V]M92!T:6UE(&EN(&$@<')I;W(@>65A<@H@
M("`@("`@("`@("`@("`@)&UO;G1H(#T@,3(@*R`H)'1M<%]M;R`E(#$R*3L*
M("`@("`@("`@("`@("`@("1Y96%R("`]("1Y96%R("L@9FQO;W(H)'1M<%]M
M;R`O(#$R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@1&%T95]#86QC.CID871E1F]R;6%T*#$L("1M;VYT:"P@)'EE87(L("1F
M;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F
M('1H92!L87-T(&1A>2!O9B!T:&4@;6]N=&@@:6X@=&AE(&YU;6)E<B!O9B!M
M;VYT:',*("`@("`J(&9R;VT@=&AE(&=I=F5N(&1A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1M;VYT:',@('1H92!N=6UB97(@;V8@;6]N=&AS
M(&9R;VT@=&AE(&1A=&4@<')O=FED960N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!0;W-I=&EV92!N=6UB97)S(&=O(&EN=&\@=&AE(&9U='5R
M92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($YE9V%T:79E(&YU
M;6)E<G,@9V\@:6YT;R!T:&4@<&%S="X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(#`@:7,@=&AE(&UO;G1H('!R97-E;G1E9"!I;B`D;6]N=&@N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;VYT:"`@('1H92!M;VYT:"P@9&5F
M875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D
M969A=6QT(&ES('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M
M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O
M=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@
M:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S:6YC92`@365T:&]D(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5N9$]F36]N=&A">5-P86XH)&UO;G1H<R`](#`L("1M;VYT:"`](#`L
M("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M
M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E
M3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&UO;G1H<R`^(#`I
M('L*("`@("`@("`@("`@+R\@9G5T=7)E(&UO;G1H"B`@("`@("`@("`@("1T
M;7!?;6\@/2`D;6]N=&@@*R`D;6]N=&AS.PH@("`@("`@("`@("`D;6]N=&@@
M(#T@)'1M<%]M;R`E(#$R.PH@("`@("`@("`@("!I9B`H)&UO;G1H(#T](#`I
M('L*("`@("`@("`@("`@("`@("1M;VYT:"`](#$R.PH@("`@("`@("`@("`@
M("`@)'EE87(@/2`D>65A<B`K(&9L;V]R*"@D=&UP7VUO("T@,2D@+R`Q,BD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D>65A<B`]
M("1Y96%R("L@9FQO;W(H)'1M<%]M;R`O(#$R*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O('!A<W0@;W(@<')E<V5N
M="!M;VYT:`H@("`@("`@("`@("`D=&UP7VUO(#T@)&UO;G1H("L@)&UO;G1H
M<SL*("`@("`@("`@("`@:68@*"1T;7!?;6\@/B`P*2!["B`@("`@("`@("`@
M("`@("`O+R!S86UE('EE87(*("`@("`@("`@("`@("`@("1M;VYT:"`]("1T
M;7!?;6\["B`@("`@("`@("`@('T@96QS96EF("@D=&UP7VUO(#T](#`I('L*
M("`@("`@("`@("`@("`@("\O('!R:6]R(&1E8PH@("`@("`@("`@("`@("`@
M)&UO;G1H(#T@,3(["B`@("`@("`@("`@("`@("`D>65A<BTM.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@<V]M92!T:6UE(&EN
M(&$@<')I;W(@>65A<@H@("`@("`@("`@("`@("`@)&UO;G1H(#T@,3(@*R`H
M)'1M<%]M;R`E(#$R*3L*("`@("`@("`@("`@("`@("1Y96%R("`]("1Y96%R
M("L@9FQO;W(H)'1M<%]M;R`O(#$R*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*$1A=&5?
M0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;6]N=&@L("1Y96%R+"`D9F]R
M;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@=&AE(&1A>2!O9B!T
M:&4@=V5E:R!F;W(@=&AE(&9I<G-T(&]F('1H92!M;VYT:"!O9B!G:79E;B!D
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@
M0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET
M(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@=V5E:V1A>2!F;W(@=&AE
M(&9I<G-T(&1A>2P@,#U3=6YD87D*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!F:7)S
M=$]F36]N=&A7965K9&%Y*"1M;VYT:"`](#`L("1Y96%R(#T@,"D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R
M(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!$871E7T-A;&,Z.F1A>4]F5V5E:R@G,#$G+"`D;6]N=&@L("1Y96%R
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T97,@=&AE(&1A=&4@
M;V8@=&AE($YT:"!W965K9&%Y(&]F('1H92!M;VYT:"P*("`@("`J('-U8V@@
M87,@=&AE('-E8V]N9"!3871U<F1A>2!O9B!*86YU87)Y(#(P,#`*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("`@("1W965K("`@('1H92!N=6UB97(@;V8@
M=&AE('=E96L@=&\@9V5T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`H,2`](&9I<G-T+"!E=&,N("!!;'-O(&-A;B!B92`G;&%S="<N*0H@("`@
M("H@0'!A<F%M(&EN="`@("`D9&]W("`@("!T:&4@9&%Y(&]F('1H92!W965K
M("@P(#T@4W5N9&%Y*0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE
M87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I
M;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R
M<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T
M("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T
M<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN
M('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($Y7965K
M9&%Y3V9-;VYT:"@D=V5E:RP@)&1O=RP@)&UO;G1H+"`D>65A<BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/
M4DU!5"D*("`@('L*("`@("`@("!I9B`H:7-?;G5M97)I8R@D=V5E:RDI('L*
M("`@("`@("`@("`@)$1/5S%D87D@/2`H)'=E96L@+2`Q*2`J(#<@*R`Q.PH@
M("`@("`@("`@("`D1$]7,2`@("`]($1A=&5?0V%L8SHZ9&%Y3V97965K*"1$
M3U<Q9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`@("`@)'=D871E("`@
M/2`H)'=E96L@+2`Q*2`J(#<@*R`Q("L@*#<@*R`D9&]W("T@)$1/5S$I("4@
M-SL*("`@("`@("`@("`@:68@*"1W9&%T92`^($1A=&5?0V%L8SHZ9&%Y<TEN
M36]N=&@H)&UO;G1H+"`D>65A<BDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`M,3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B!$871E7T-A;&,Z.F1A=&5&;W)M870H)'=D871E+"`D;6]N=&@L("1Y
M96%R+"`D9F]R;6%T*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF
M("@D=V5E:R`]/2`G;&%S="<@)B8@)&1O=R`\(#<I('L*("`@("`@("`@("`@
M)&QA<W1D87D@/2!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"1M;VYT:"P@)'EE
M87(I.PH@("`@("`@("`@("`D;&%S=&1O=R`]($1A=&5?0V%L8SHZ9&%Y3V97
M965K*"1L87-T9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`@("`@)&1I
M9F8@("`@/2`D9&]W("T@)&QA<W1D;W<["B`@("`@("`@("`@(&EF("@D9&EF
M9B`^(#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A
M=&5&;W)M870H)&QA<W1D87D@+2`H-R`M("1D:69F*2P@)&UO;G1H+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D>65A
M<BP@)&9O<FUA="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"1L87-T9&%Y("L@
M)&1I9F8L("1M;VYT:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'EE87(L("1F;W)M870I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!F;W(@
M=F%L:60@9&%T92P@9F%L<V4@9F]R(&EN=F%L:60@9&%T90H@("`@("H*("`@
M("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N
M=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H"B`@
M("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@57-E('1H
M92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U
M<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@
M,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!I<U9A;&ED1&%T92@D9&%Y+"`D;6]N=&@L("1Y96%R*0H@
M("`@>PH@("`@("`@(&EF("@D>65A<B`\(#`@?'P@)'EE87(@/B`Y.3DY*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M:68@*"%C:&5C:V1A=&4H)&UO;G1H+"`D9&%Y+"`D>65A<BDI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!F;W(@
M82!L96%P('EE87(L(&5L<V4@9F%L<V4*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@57-E('1H92!C;VUP;&5T92!Y
M96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@;F]T
M(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@1&\@;F]T(&%D
M9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P,"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!I
M<TQE87!996%R*"1Y96%R(#T@,"D*("`@('L*("`@("`@("!I9B`H96UP='DH
M)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E
M3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UQ$+R<L("1Y96%R*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@(&EF("@D>65A<B`\(#$P,#`I('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H)'EE87(@
M/"`Q-3@R*2!["B`@("`@("`@("`@("\O('!R92!'<F5G;W)I;R!824E)("T@
M,34X,@H@("`@("`@("`@("!R971U<FX@*"1Y96%R("4@-"`]/2`P*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!P;W-T($=R96=O<FEO(%A)
M24D@+2`Q-3@R"B`@("`@("`@("`@(')E='5R;B`H*"1Y96%R("4@-"`]/2`P
M*2`F)B`H)'EE87(@)2`Q,#`@(3T@,"DI('Q\("@D>65A<B`E(#0P,"`]/2`P
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S
M(&EF(&=I=F5N(&1A=&4@:7,@82!F=71U<F4@9&%T92!F<F]M(&YO=PH@("`@
M("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T
M:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@
M57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@
M12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I
M;W(@=&\@,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!I<T9U='5R941A=&4H)&1A>2P@)&UO;G1H+"`D
M>65A<BD*("`@('L*("`@("`@("`D=&AI<U]Y96%R("`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)5DG*3L*("`@("`@("`D=&AI<U]M;VYT:"`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("`D=&AI<U]D87D@("`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)60G*3L*"B`@("`@("`@:68@*"1Y96%R(#X@)'1H
M:7-?>65A<BD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V5I9B`H)'EE87(@/3T@)'1H:7-?>65A<BD@>PH@("`@("`@("`@("!I
M9B`H)&UO;G1H(#X@)'1H:7-?;6]N=&@I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H)&UO;G1H(#T]("1T
M:&ES7VUO;G1H*2!["B`@("`@("`@("`@("`@("!I9B`H)&1A>2`^("1T:&ES
M7V1A>2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@:68@9VEV96X@9&%T92!I<R!A('!A<W0@9&%T92!F<F]M(&YO=PH@("`@
M("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T
M:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@
M57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@
M12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I
M;W(@=&\@,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!I<U!A<W1$871E*"1D87DL("1M;VYT:"P@)'EE
M87(I"B`@("!["B`@("`@("`@)'1H:7-?>65A<B`@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R59)RD["B`@("`@("`@)'1H:7-?;6]N=&@@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5M)RD["B`@("`@("`@)'1H:7-?9&%Y("`@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5D)RD["@H@("`@("`@(&EF("@D>65A<B`\("1T:&ES
M7WEE87(I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E
M;'-E:68@*"1Y96%R(#T]("1T:&ES7WEE87(I('L*("`@("`@("`@("`@:68@
M*"1M;VYT:"`\("1T:&ES7VUO;G1H*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"1M;VYT:"`]/2`D=&AI
M<U]M;VYT:"D@>PH@("`@("`@("`@("`@("`@:68@*"1D87D@/"`D=&AI<U]D
M87DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&YU
M;6)E<B!O9B!D87ES(&)E='=E96X@='=O(&=I=F5N(&1A=&5S"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN="`@("`D9&%Y,2`@("!T:&4@9&%Y(&]F('1H92!M
M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@Q("!T:&4@;6]N=&@*
M("`@("`J($!P87)A;2!I;G0@("`@)'EE87(Q("`@=&AE('EE87(N("!5<V4@
M=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%+F<N
M('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO<B!T
M;R`Q,#`P+@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y,B`@("!T:&4@9&%Y
M(&]F('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@R("!T
M:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(R("`@=&AE('EE
M87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I
M;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R
M<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T
M:&4@86)S;VQU=&4@;G5M8F5R(&]F(&1A>7,@8F5T=V5E;B!T:&4@='=O(&1A
M=&5S+@H@("`@("H@("`@("`@("`@("`@("!)9B!A;B!E<G)O<B!O8V-U<G,L
M("TQ(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A=&5$:69F
M*"1D87DQ+"`D;6]N=&@Q+"`D>65A<C$L("1D87DR+"`D;6]N=&@R+"`D>65A
M<C(I"B`@("!["B`@("`@("`@:68@*"%$871E7T-A;&,Z.FES5F%L:61$871E
M*"1D87DQ+"`D;6]N=&@Q+"`D>65A<C$I*2!["B`@("`@("`@("`@(')E='5R
M;B`M,3L*("`@("`@("!]"B`@("`@("`@:68@*"%$871E7T-A;&,Z.FES5F%L
M:61$871E*"1D87DR+"`D;6]N=&@R+"`D>65A<C(I*2!["B`@("`@("`@("`@
M(')E='5R;B`M,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&%B<RA$871E
M7T-A;&,Z.F1A=&54;T1A>7,H)&1A>3$L("1M;VYT:#$L("1Y96%R,2D*("`@
M("`@("`@("`@("`@("`@("T@1&%T95]#86QC.CID871E5&]$87ES*"1D87DR
M+"`D;6]N=&@R+"`D>65A<C(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O
M;7!A<F5S('1W;R!D871E<PH@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@
M)&1A>3$@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I
M;G0@("`@)&UO;G1H,2`@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@
M("1Y96%R,2`@('1H92!Y96%R+B`@57-E('1H92!C;VUP;&5T92!Y96%R(&EN
M<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A
M8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@1&\@;F]T(&%D9"!L96%D
M:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P,"X*("`@("`J($!P87)A
M;2!I;G0@("`@)&1A>3(@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@*("`@("`J
M($!P87)A;2!I;G0@("`@)&UO;G1H,B`@=&AE(&UO;G1H"B`@("`@*B!`<&%R
M86T@:6YT("`@("1Y96%R,B`@('1H92!Y96%R+B`@57-E('1H92!C;VUP;&5T
M92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@
M;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@1&\@;F]T
M(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P,"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@,"!I9B!T:&4@9&%T97,@87)E(&5Q
M=6%L+B`Q(&EF(&1A=&4@,2!I<R!L871E<BP@+3$@:68*("`@("`J("`@("`@
M("`@("`@("`@9&%T92`Q(&ES(&5A<FQI97(N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]M<&%R941A=&5S*"1D87DQ+"`D;6]N=&@Q+"`D>65A<C$L("1D87DR
M+"`D;6]N=&@R+"`D>65A<C(I"B`@("!["B`@("`@("`@)&YD87ES,2`]($1A
M=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y,2P@)&UO;G1H,2P@)'EE87(Q*3L*
M("`@("`@("`D;F1A>7,R(#T@1&%T95]#86QC.CID871E5&]$87ES*"1D87DR
M+"`D;6]N=&@R+"`D>65A<C(I.PH@("`@("`@(&EF("@D;F1A>7,Q(#T]("1N
M9&%Y<S(I('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`H)&YD87ES,2`^("1N9&%Y<S(I(#\@,2`Z("TQ.PH@("`@
M?0I]"@H_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]02%!5;FET+P``````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`U-P`P,38V,S,`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N
M:70O1U5)+P``````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`Q-S(U-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$A056YI="]'54DO2%1-3"YP:'``````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$R,3<`,3`U,34T,S$P-3<`,#(P-3,T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@
M*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S
M(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D
M:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O
M;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I
M<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B
M;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@
M("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O
M9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO
M;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E
M<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O
M<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S
M(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!3
M3T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@
M04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/
M4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,
M24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/
M4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#
M3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL
M($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)
M3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"
M4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7
M159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2
M(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))
M4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&
M5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@
M3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@
M0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!7;VQF<F%M($MR
M:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@*B!`8V]P>7)I9VAT("`R
M,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C
M92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@2%1-3"YP:'`L=B`Q+C$Y(#(P,#4O
M,3$O,3`@,#DZ-#<Z,34@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC
M92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO
M"@HO*BH*("H@2%1-3"!'54DN"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*
M("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!7;VQF<F%M
M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@*B!`8V]P>7)I9VAT
M("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM
M8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O
M=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS
M90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@
M*B\*8VQA<W,@4$A056YI=%]'54E?2%1-3`I["B`@("!V87(@)%]S=6ET97,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@*B!T:&4@8W5R<F5N="!I;7!L96UE
M;G1A=&EO;B!O9B!02%!5;FET(&ES(&1E<VEG;F5D"B`@("`J('1H:7,@=V%Y
M('1H870@861D:6YG(&$@<W5I=&4@=&\@86YO=&AE<B!S=6ET92!O;FQY"B`@
M("`J(&=R86)S(&%L;"!T:&4@=&5S=',@86YD(&%D9',@=&AE;2!T;R!T:&4@
M<W5I=&4L('-O('EO=0H@("`@*B!H879E(&YO(&-H86YC92!T;R!F:6YD(&]U
M="!W:&EC:"!T97-T(&=O97,@=VET:"!W:&EC:"!S=6ET90H@("`@*B!T:&5R
M969O<F4@>6]U(&-A;B!S:6UP;'D@<&%S<R!A;B!A<G)A>2!O9B!S=6ET97,@
M=&\@=&AI<R!C;VYS=')U8W1O<B!H97)E"B`@("`J"B`@("`J($!P87)A;2`@
M87)R87D@("!4:&4@<W5I=&5S('1O(&)E('1E<W1E9"X@268@;F]T(&=I=F5N
M+"!T:&5N('EO=2!M:6=H=`H@("`@*B`@("`@("`@("`@("`@("`@8F4@=7-I
M;F<@=&AE(%-E='5P1&5C;W)A=&]R+"!W:&EC:"!D971E8W1S('1H96T@875T
M;VUA=&EC86QL>0H@("`@*B`@("`@("`@("`@("`@("`@=VAE;B!C86QL:6YG
M(&=E=%-U:71E<T9R;VU$:7(H*0H@("`@*B\*("`@(&9U;F-T:6]N(%!(4%5N
M:71?1U5)7TA434PH)'-U:71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D<W5I=&5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-U:71E<R`](&%R<F%Y*"1S=6ET97,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?<W5I=&5S(#T@)'-U:71E<SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`J($%D9"!S=6ET97,@=&\@=&AE($=520H@
M("`@*@H@("`@*B!`<&%R86T@(&]B:F5C="`@=&AI<R!S:&]U;&0@8F4@86X@
M:6YS=&%N8V4@;V8@4$A056YI=%]497-T4W5I=&4*("`@("HO"B`@("!F=6YC
M=&EO;B!A9&13=6ET97,H)'-U:71E<RD*("`@('L*("`@("`@("`D=&AI<RT^
M7W-U:71E<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?<W5I=&5S+"1S=6ET97,I
M.PH@("`@?0H*("`@("\J*@H@("`@*B!T:&ES('!R:6YT<R!T:&4@2%1-3"!C
M;V1E('-T<F%I9VAT(&]U=`H@("`@*@H@("`@*B\*("`@(&9U;F-T:6]N('-H
M;W<H*0H@("`@>PH@("`@("`@("1R97%U97-T("`@(#T@)%]215%515-4.PH@
M("`@("`@("1S:&]W4&%S<V5D(#T@1D%,4T4["B`@("`@("`@)'-U8FUI='1E
M9"`@/2!`)')E<75E<W1;)W-U8FUI='1E9"==.PH*("`@("`@("!I9B`H)'-U
M8FUI='1E9"D@>PH@("`@("`@("`@("`D<VAO=U!A<W-E9"`]($`D<F5Q=65S
M=%LG<VAO=T]+)UT@/R!44E5%(#H@1D%,4T4["B`@("`@("`@?0H*("`@("`@
M("`D<W5I=&5297-U;'1S(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]S=6ET97,@87,@)&%3=6ET92D@>PH@("`@("`@("`@("`D85-U
M:71E4F5S=6QT(#T@87)R87DH*3L*"B`@("`@("`@("`@("\O(')E;6]V92!T
M:&4@9FER<W0@9&ER96-T;W)Y)W,@;F%M92!F<F]M('1H92!T97-T+7-U:71E
M(&YA;64L('-I;F-E(&ET"B`@("`@("`@("`@("\O(&UO<W1L>2!I<R!S;VUE
M=&AI;F<@;&EK92`G=&5S=',G(&]R(&%L:6ME"B`@("`@("`@("`@("1R96UO
M=F%B;&50<F5F:7@@/2!E>'!L;V1E*"=?)RPD85-U:71E+3YG971.86UE*"DI
M.PH@("`@("`@("`@("`D85-U:71E4F5S=6QT6R=N86UE)UT@/2!S=')?<F5P
M;&%C92@D<F5M;W9A8FQE4')E9FEX6S!=+B=?)RP@)R<L("1A4W5I=&4M/F=E
M=$YA;64H*2D["@H@("`@("`@("`@("!I9B`H)'-U8FUI='1E9"`F)B!I<W-E
M="@D<F5Q=65S=%LD85-U:71E4F5S=6QT6R=N86UE)UU=*2D@>PH@("`@("`@
M("`@("`@("`@)')E<W5L="`](%!(4%5N:70Z.G)U;B@D85-U:71E*3L*"B`@
M("`@("`@("`@("`@("`D85-U:71E4F5S=6QT6R=C;W5N=',G75LG<G5N)UT@
M/2`D<F5S=6QT+3YR=6Y#;W5N="@I.PH@("`@("`@("`@("`@("`@)&%3=6ET
M95)E<W5L=%LG8V]U;G1S)UU;)V5R<F]R)UT@/2`D<F5S=6QT+3YE<G)O<D-O
M=6YT*"D["B`@("`@("`@("`@("`@("`D85-U:71E4F5S=6QT6R=C;W5N=',G
M75LG9F%I;'5R92==(#T@)')E<W5L="T^9F%I;'5R94-O=6YT*"D["@H@("`@
M("`@("`@("`@("`@)&%3=6ET95)E<W5L=%LG<F5S=6QT<R==(#T@)'1H:7,M
M/E]P<F5P87)E4F5S=6QT*"1R97-U;'0L)'-H;W=087-S960I.PH*("`@("`@
M("`@("`@("`@("1P97(@/2`Q,#`O)')E<W5L="T^<G5N0V]U;G0H*3L*("`@
M("`@("`@("`@("`@("1F86EL960@/2`H)'!E<BHD<F5S=6QT+3YE<G)O<D-O
M=6YT*"DI*R@D<&5R*B1R97-U;'0M/F9A:6QU<F5#;W5N="@I*3L*("`@("`@
M("`@("`@("`@("1A4W5I=&5297-U;'1;)W!E<F-E;G0G72`](')O=6YD*#$P
M,"TD9F%I;&5D+#(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&%3=6ET95)E<W5L=%LG861D26YF;R==(#T@)TY/5"!%6$5#551%
M1"<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=6ET95)E<W5L='-;
M72`]("1A4W5I=&5297-U;'0["B`@("`@("`@?0H*("`@("`@("`D9FEN86Q;
M)VYA;64G72`]("=/5D5204Q,(%)%4U5,5"<["B`@("`@("`@)&9I;F%L6R=C
M;W5N=',G72`](&%R<F%Y*"D["B`@("`@("`@)&9I;F%L6R=P97)C96YT)UT@
M/2`P.PH@("`@("`@("1N=6U%>&5C=71E9%1E<W1S(#T@,#L*"B`@("`@("`@
M9F]R96%C:"`H)'-U:71E4F5S=6QT<R!A<R`D85-U:71E4F5S=6QT*2!["B`@
M("`@("`@("`@(&EF("AS:7IE;V8H0"1A4W5I=&5297-U;'1;)V-O=6YT<R==
M*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%3=6ET95)E<W5L=%LG
M8V]U;G1S)UT@87,@)&ME>3T^)&%#;W5N="D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&9I;F%L6R=C;W5N=',G75LD:V5Y72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I;F%L6R=C;W5N=',G75LD:V5Y72`]
M(#`["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@
M("`D9FEN86Q;)V-O=6YT<R==6R1K97E=("L]("1A0V]U;G0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<W-E="@D9FEN86Q;)V-O=6YT<R==6R=R=6XG72DI('L*("`@("`@("`@
M("`@)'!E<B`](#$P,"\D9FEN86Q;)V-O=6YT<R==6R=R=6XG73L*("`@("`@
M("`@("`@)&9A:6QE9"`]("@D<&5R*B1F:6YA;%LG8V]U;G1S)UU;)V5R<F]R
M)UTI*R@D<&5R*B1F:6YA;%LG8V]U;G1S)UU;)V9A:6QU<F4G72D["B`@("`@
M("`@("`@("1F:6YA;%LG<&5R8V5N="==(#T@<F]U;F0H,3`P+21F86EL960L
M,BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9I;F%L6R=P97)C
M96YT)UT@/2`P.PH@("`@("`@('T*"B`@("`@("`@87)R87E?=6YS:&EF="@D
M<W5I=&5297-U;'1S+"1F:6YA;"D["@H@("`@("`@(&EN8VQU9&4@)U!(4%5N
M:70O1U5)+TA434PN='!L)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<')E<&%R
M95)E<W5L="@D<F5S=6QT+"1S:&]W4&%S<V5D*0H@("`@>PH@("`@("`@("1R
M970@/2!A<G)A>2@I.PH@("`@("`@("1F86EL=7)E<R`]("1R97-U;'0M/F9A
M:6QU<F5S*"D["@H@("`@("`@(&9O<F5A8V@H)&9A:6QU<F5S(&%S("1A1F%I
M;'5R92D@>PH@("`@("`@("`@("`D<F5T6R=F86EL=7)E<R==6UT@/2`D=&AI
M<RT^7W!R97!A<F5&86EL=7)E*"1A1F%I;'5R92D["B`@("`@("`@?0H*("`@
M("`@("`D97)R;W)S(#T@)')E<W5L="T^97)R;W)S*"D["@H@("`@("`@(&9O
M<F5A8V@H)&5R<F]R<R!A<R`D845R<F]R*2!["B`@("`@("`@("`@("1R971;
M)V5R<F]R<R==6UT@/2`D=&AI<RT^7W!R97!A<F5%<G)O<G,H)&%%<G)O<BD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'-H;W=087-S960I('L*("`@("`@
M("`@("`@)'!A<W-E9"`]("1R97-U;'0M/G!A<W-E9%1E<W1S*"D["@H@("`@
M("`@("`@("!F;W)E86-H*"1P87-S960@87,@)&%087-S960I('L*("`@("`@
M("`@("`@("`@("1R971;)W!A<W-E9"==6UT@/2`D=&AI<RT^7W!R97!A<F50
M87-S961497-T<R@D85!A<W-E9"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P
M<F5P87)E1F%I;'5R92@D9F%I;'5R92D*("`@('L*("`@("`@("`D=&5S="`]
M("1F86EL=7)E+3YF86EL961497-T*"D["B`@("`@("`@)')E=%LG=&5S=$YA
M;64G72`]("1T97-T+3YG971.86UE*"D["B`@("`@("`@)&5X8V5P=&EO;B`]
M("1F86EL=7)E+3YT:')O=VY%>&-E<'1I;VXH*3L*"B`@("`@("`@+R\@82!S
M97)I86QI>F5D('-T<FEN9R!S=&%R=',@=VET:"!A("=C:&%R86-T97(Z9&5C
M:6UA;#I[)PH@("`@("`@("\O(&EF('-O('=E('1R>2!T;R!U;G-E<FEA;&EZ
M92!I=`H@("`@("`@("\O('1H:7,@<&EE8V4@;V8@=&AE(')E9W5L87(@97AP
M<F5S<VEO;B!I<R!F;W(@9&5T96-T:6YG(&$@<V5R:6%L:7IE9`H@("`@("`@
M("\O('1Y<&4@;&EK92`G83HS.B<@9F]R(&%N(&%R<F%Y('=I=&@@=&AR964@
M96QE;65N="!O<B!A;B!O8FIE8W0@:2YE+B`G3SHQ,CHB8VQA<W,B.C,G"B`@
M("`@("`@)'-E<FEA;&EZ960@/2`G*%QW.EQD*SHH/SHB6UXB72LB.EQD*SHI
M/UQ[+BI<?2DG.PH*("`@("`@("`O+R!3<&%C97,@;6EG:'0@;6%K92!A(&1I
M9F8L('-O('=E('-H86QL('-H;W<@=&AE;2!P<F]P97)L>2`H<VEN8V4@80H@
M("`@("`@("\O('5S97(@86=E;G0@:6=N;W)E<R!T:&5M*2X*("`@("`@("!I
M9B`H<')E9U]M871C:"@G+UXH+BHI97AP96-T960@)R`N("1S97)I86QI>F5D
M("X@)RP@86-T=6%L("<@+B`D<V5R:6%L:7IE9"`N("<D+W-5)RP@)&5X8V5P
M=&EO;BP@)&UA=&-H97,I*2!["B`@("`@("`@("`@(&]B7W-T87)T*"D["B`@
M("`@("`@("`@('!R:6YT7W(H=6YS97)I86QI>F4H)&UA=&-H97-;,ETI*3L*
M("`@("`@("`@("`@)')E=%LG97AP96-T960G72`](&AT;6QS<&5C:6%L8VAA
M<G,H)&UA=&-H97-;,5TI("X@(CQP<F4^(B`N(&AT;6QS<&5C:6%L8VAA<G,H
M<G1R:6TH;V)?9V5T7V-O;G1E;G1S*"DI*2`N("(\+W!R93XB.PH@("`@("`@
M("`@("`O+R!);7!R;W9E9"!C;VUP871I8FEL:71Y+"!O8E]C;&5A;B@I('=O
M=6QD(&)E(%!(4"`^/2`T+C(N,"!O;FQY+@H@("`@("`@("`@("!O8E]E;F1?
M8VQE86XH*3L*"B`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@("`@
M('!R:6YT7W(H=6YS97)I86QI>F4H)&UA=&-H97-;,UTI*3L*("`@("`@("`@
M("`@)')E=%LG86-T=6%L)UT@/2!H=&UL<W!E8VEA;&-H87)S*"1M871C:&5S
M6S%=*2`N("(\<')E/B(@+B!H=&UL<W!E8VEA;&-H87)S*')T<FEM*&]B7V=E
M=%]C;VYT96YT<R@I*2D@+B`B/"]P<F4^(CL*("`@("`@("`@("`@;V)?96YD
M7V-L96%N*"D["B`@("`@("`@?0H*("`@("`@("!E;'-E(&EF("AP<F5G7VUA
M=&-H*"<O7B@N*BEE>'!E8W1E9"`H+BHI+"!A8W1U86P@*"XJ*20O<U4G+"`D
M97AC97!T:6]N+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)')E=%LG97AP
M96-T960G72`](&YL,F)R*'-T<E]R97!L86-E*"(@(BP@(B9N8G-P.R(L(&AT
M;6QS<&5C:6%L8VAA<G,H)&UA=&-H97-;,5T@+B`D;6%T8VAE<ULR72DI*3L*
M("`@("`@("`@("`@)')E=%LG86-T=6%L)UT@/2!N;#)B<BAS=')?<F5P;&%C
M92@B("(L("(F;F)S<#LB+"!H=&UL<W!E8VEA;&-H87)S*"1M871C:&5S6S%=
M("X@)&UA=&-H97-;,UTI*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E=%LG;65S<V%G92==(#T@;FPR8G(H<W1R7W)E<&QA8V4H(B`B+"`B
M)FYB<W`[(BP@:'1M;'-P96-I86QC:&%R<R@D97AC97!T:6]N*2DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W!R97!A<F5087-S961497-T<R@D<&%S<V5D*0H@("`@>PH@("`@("`@
M("1R971;)W1E<W1.86UE)UT@/2`D<&%S<V5D+3YG971.86UE*"D["B`@("`@
M("`@<F5T=7)N("1R970["B`@("!]"@H@("`@9G5N8W1I;VX@7W!R97!A<F5%
M<G)O<B@D97)R;W(I"B`@("!["B`@("`@("`@)')E=%LG=&5S=$YA;64G72`]
M("1E<G)O<BT^9V5T3F%M92@I.PH@("`@("`@("1R971;)VUE<W-A9V4G72`]
M("1E<G)O<BT^=&]3=')I;F<H*3L*("`@("`@("!R971U<FX@)')E=#L*("`@
M('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*
M("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD
M97(M<#H@;FEL"B`J($5N9#H*("HO"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]02%!5;FET+T=522](5$U,+G1P;```````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-3`R,P`Q,#4Q-30S,3`U
M-P`P,C`U-#(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&AT;6P^"B`@("`\:&5A9#X*("`@("`@("`\4U193$4@='EP93TB
M=&5X="]C<W,B/@H*("`@("`@("`@("`@8F]D>2P@=&0@>PH@("`@("`@("`@
M("`@("`@8F%C:V=R;W5N9"UC;VQO<CH@;&EG:'1G<F5Y.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!T86)L92YO=71L:6YE+"!O=71L:6YE1F%I;'5R
M92!["B`@("`@("`@("`@("`@("!B86-K9W)O=6YD+6-O;&]R.B!B;&%C:SL*
M("`@("`@("`@("`@("`@(&)O<F1E<BUW:61T:#H@,7!X.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!T9"!["B`@("`@("`@("`@("`@("!P861D:6YG
M.B`R<'@["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('1H('L*("`@("`@
M("`@("`@("`@('1E>'0M86QI9VXZ(&QE9G0["B`@("`@("`@("`@("`@("!C
M;VQO<CH@=VAI=&4["B`@("`@("`@("`@("`@("!B86-K9W)O=6YD+6-O;&]R
M.B!B;&%C:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+G-U8V-E<W,@
M>PH@("`@("`@("`@("`@("`@8F%C:V=R;W5N9"UC;VQO<CH@;&EG:'1G<F5E
M;CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+F9A:6QU<F4@>PH@("`@
M("`@("`@("`@("`@8F%C:V=R;W5N9"UC;VQO<CH@;W)A;F=E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("YI;F9O('L*("`@("`@("`@("`@("`@('!A
M9&1I;F<Z(#)P>#L*("`@("`@("`@("`@("`@(&-O;&]R.B!O<F%N9V4["B`@
M("`@("`@("`@('T*"B`@("`@("`@/"]35%E,13X*("`@(#PO:&5A9#X*("`@
M(#QB;V1Y/@H@("`@("`@(#QF;W)M(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%
M4E9%4ELG4$A07U-%3$8G72`_/B(@;65T:&]D/2)P;W-T(B!N86UE/2)O<'1I
M;VYS1F]R;2(^"B`@("`@("`@("`@(#QT86)L92!A;&EG;CTB8V5N=&5R(B!C
M;&%S<STB;W5T;&EN92(@=VED=&@](C<P)2(^"B`@("`@("`@("`@("`@("`\
M='(^"B`@("`@("`@("`@("`@("`@("`@/'1H(&-O;'-P86X](C$P(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@3W!T:6]N<PH@("`@("`@("`@("`@("`@
M("`@(#PO=&@^"B`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@
M("`@/'1R/@H@("`@("`@("`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(Q,"(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QI;G!U="!T>7!E/2)C:&5C:V)O
M>"(@;VY#;&EC:STB=6Y#:&5C:T%L;"@I(B!N86UE/2)A;&Q#:&5C:V5D(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@*'5N*6-H96-K(&%L;`H@("`@("`@
M("`@("`@("`@("`@("`@("`F;F)S<#L@)FYB<W`["B`@("`@("`@("`@("`@
M("`@("`@("`@('-H;W<@3TL@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)S:&]W3TLB(#P_<&AP(&5C:&\@0"1R97%U97-T6R=S:&]W3TLG73\G8VAE
M8VME9"<Z)R<_/CX*("`@("`@("`@("`@("`@("`@("`@("`@)FYB<W`[("9N
M8G-P.PH@("`@("`@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB<W5B
M;6ET(B!N86UE/2)S=6)M:71T960B('9A;'5E/2)R=6X@=&5S=',B/@H@("`@
M("`@("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@("`\+W1R/@H*
M("`@("`@("`@("`@("`@(#P_<&AP(&9O<F5A8V@H)'-U:71E4F5S=6QT<R!A
M<R`D85)E<W5L="DZ(#\^"B`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\=&@@8V]L<W!A;CTB,3`B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N
M86UE/2(\/W!H<"!E8VAO("1A4F5S=6QT6R=N86UE)UT@/SXB(#P_<&AP(&5C
M:&\@0"1R97%U97-T6R1A4F5S=6QT6R=N86UE)UU=/R=C:&5C:V5D)SHG)R`_
M/CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C:&\@)&%2
M97-U;'1;)VYA;64G72`_/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)FYB<W`["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!I9B`H
M:7-S970H)&%297-U;'1;)V%D9$EN9F\G72DI.B`_/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QF;VYT(&-L87-S/2)I;F9O(CX\/W!H<"!E
M8VAO($`D85)E<W5L=%LG861D26YF;R==(#\^/"]F;VYT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/#]P:'`@96YD:68@/SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]T:#X*("`@("`@("`@("`@("`@("`@("`\+W1R/@H*
M("`@("`@("`@("`@("`@("`@("`\/W!H<"!I9BA`)&%297-U;'1;)W!E<F-E
M;G0G72DZ(#\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(Q,"(@;F]W<F%P
M/2)N;W=R87`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QT
M86)L92!S='EL93TB=VED=&@Z,3`P)3L@<&%D9&EN9SHR<'@[(B!C96QL<W!A
M8VEN9STB,"(@8V5L;'-P86X](C`B(&-E;&QP861D:6YG/2(P(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'1D('=I9'1H/2(\/W!H
M<"!E8VAO("1A4F5S=6QT6R=P97)C96YT)UT@/SXE(B!C;&%S<STB<W5C8V5S
M<R(@86QI9VX](F-E;G1E<B(@<W1Y;&4](G!A9&1I;F<Z,#LB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C
M:&\@)&%297-U;'1;)W!E<F-E;G0G73\D85)E<W5L=%LG<&5R8V5N="==+B<E
M)SHG)R`_/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QT9"!W:61T:#TB/#]P:'`@96-H;R`Q,#`M)&%297-U;'1;)W!E<F-E
M;G0G72`_/B4B(&-L87-S/2)F86EL=7)E(B!A;&EG;CTB8V5N=&5R(B!S='EL
M93TB<&%D9&EN9SHP.R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/#]P:'`@96-H;R`H,3`P+21A4F5S=6QT6R=P97)C
M96YT)UTI/R@Q,#`M)&%297-U;'1;)W!E<F-E;G0G72XG)2<I.B<G(#\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+W1D/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+W1R/@H@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5N9&EF(#\^
M"@H@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF*$`D85)E<W5L=%LG8V]U
M;G1S)UTI.B`_/@H@("`@("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,3`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&9O<F5A8V@H)&%2
M97-U;'1;)V-O=6YT<R==(&%S("1A0V]U;G0]/B1V86QU92DZ(#\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C:&\@)&%#
M;W5N="`_/G,@/2`\/W!H<"!E8VAO("1V86QU92`_/B`F;F)S<#L@)FYB<W`[
M("9N8G-P.R`F;F)S<#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\/W!H<"!E;F1F;W)E86-H(#\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@
M("`@("`@("`@("`@("`@(#P_<&AP(&5N9&EF(#\^"@H@("`@("`@("`@("`@
M("`@("`@(#P_<&AP(&EF*&ES<V5T*"1A4F5S=6QT6R=R97-U;'1S)UU;)V9A
M:6QU<F5S)UTI("8F('-I>F5O9B@D85)E<W5L=%LG<F5S=6QT<R==6R=F86EL
M=7)E<R==*2D*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D85)E
M<W5L=%LG<F5S=6QT<R==6R=F86EL=7)E<R==(&%S("1A1F%I;'5R92DZ(#\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QT9"!C;&%S<STB9F%I;'5R92(^/#]P:'`@96-H;R`D
M849A:6QU<F5;)W1E<W1.86UE)UT@/SX\+W1D/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'1D(&-L87-S/2)F86EL=7)E(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\/W!H<"!I9BAI<W-E="@D849A:6QU<F5;
M)VUE<W-A9V4G72D@)B8@)&%&86EL=7)E6R=M97-S86=E)UTI.B`_/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO("1A
M1F%I;'5R95LG;65S<V%G92==(#\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/#]P:'`@96QS93H@/SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'1A8FQE(&-L87-S/2)O=71L:6YE1F%I;'5R92(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\='(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'1D/F5X<&5C=&5D/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\=&0^/#]P:'`@96-H;R`D849A:6QU<F5;)V5X
M<&5C=&5D)UT@/SX\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]T<CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\=&0^86-T=6%L/"]T9#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\=&0^/#]P:'`@96-H
M;R`D849A:6QU<F5;)V%C='5A;"==(#\^/"]T9#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/#]P:'`@96YD:68@/SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/#]P:'`@96YD9F]R96%C:"`_
M/@H*("`@("`@("`@("`@("`@("`@("`\/W!H<"!I9BAI<W-E="@D85)E<W5L
M=%LG<F5S=6QT<R==6R=E<G)O<G,G72D@)B8@<VEZ96]F*"1A4F5S=6QT6R=R
M97-U;'1S)UU;)V5R<F]R<R==*2D*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"@D85)E<W5L=%LG<F5S=6QT<R==6R=E<G)O<G,G72!A<R`D845R
M<F]R*3H@/SX*("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'1D(&-L87-S/2)F86EL=7)E(CX\/W!H
M<"!E8VAO("1A17)R;W);)W1E<W1.86UE)UT@/SX\+W1D/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'1D(&-L87-S/2)F86EL=7)E(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO("1A17)R;W);
M)VUE<W-A9V4G72`_/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T
M9#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@("`@
M("`@("`@("`\/W!H<"!E;F1F;W)E86-H(#\^"@H@("`@("`@("`@("`@("`@
M("`@(#P_<&AP(&EF*&ES<V5T*"1A4F5S=6QT6R=R97-U;'1S)UU;)W!A<W-E
M9"==*2`F)B!S:7IE;V8H)&%297-U;'1;)W)E<W5L=',G75LG<&%S<V5D)UTI
M*0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"1A4F5S=6QT6R=R
M97-U;'1S)UU;)W!A<W-E9"==(&%S("1A4&%S<V5D*3H@/SX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'1D(&-L87-S/2)S=6-C97-S(CX\/W!H<"!E8VAO("1A4&%S<V5D6R=T
M97-T3F%M92==(#\^/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QT9"!C;&%S<STB<W5C8V5S<R(^/&(^3TL\+V(^/"]T9#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@("`@("`@("`@("`\/W!H
M<"!E;F1F;W)E86-H(#\^"@H@("`@("`@("`@("`@("`@/#]P:'`@96YD9F]R
M96%C:"`_/@H@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@(#PO9F]R;3X*
M"B`@("`@("`@/'-C<FEP=#X*("`@("`@("`@("`@=F%R(&%L;%-U:71E3F%M
M97,@/2!N97<@07)R87DH*3L*("`@("`@("`@("`@/#]P:'`@9F]R96%C:"@D
M<W5I=&5297-U;'1S(&%S("1A4F5S=6QT*3H@/SX*("`@("`@("`@("`@("`@
M(&%L;%-U:71E3F%M97-;86QL4W5I=&5.86UE<RYL96YG=&A=(#T@(CP_<&AP
M(&5C:&\@)&%297-U;'1;)VYA;64G72`_/B(["B`@("`@("`@("`@(#P_<&AP
M(&5N9&9O<F5A8V@@/SX*("`@("`@("`@("`@9G5N8W1I;VX@=6Y#:&5C:T%L
M;"@I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(%]C:&5C:V5D(#T@
M9&]C=6UE;G0N;W!T:6]N<T9O<FTN86QL0VAE8VME9"YC:&5C:V5D.PH@("`@
M("`@("`@("`@("`@9F]R("AI/3`[:3QA;&Q3=6ET94YA;65S+FQE;F=T:#MI
M*RLI('L*("`@("`@("`@("`@("`@("`@("!D;V-U;65N="YO<'1I;VYS1F]R
M;5MA;&Q3=6ET94YA;65S6VE=72YC:&5C:V5D(#T@7V-H96-K960["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`\+W-C<FEP=#X*
M"B`@("`\+V)O9'D^"CPO:'1M;#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]02%!5;FET+T=522]3971U<$1E8V]R871O<BYP:'``````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-C4V,0`Q,#4Q-30S,3`U-P`P,C(W-#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O
M<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B
M0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V
M960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N
M9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I
M;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG
M(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T
M:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P
M>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D
M:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H
M92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@
M*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L
M<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@
M*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@
M;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@
M8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E
M9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@
M<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%
M($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].
M5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)
M140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@
M5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519
M($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(
M5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@
M0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%
M($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@
M4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J
M($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(
M15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H
M24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.
M"B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@
M159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(
M($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G
M92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@
M/'=O;&9R86U`:W)I97-I;F<N9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P
M-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!3971U<$1E8V]R871O<BYP:'`L=B`Q+C$U(#(P
M,#4O,3$O,3`@,#DZ-#<Z,34@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*
M("HO"@HO*BH*("H@5&AI<R!D96-O<F%T;W(@86-T=6%L;'D@:G5S="!A9&1S
M('1H92!F=6YC=&EO;F%L:71Y('1O(')E860@=&AE"B`J('1E<W0M<W5I=&4@
M8VQA<W-E<R!F<F]M(&$@9VEV96X@9&ER96-T;W)Y(&%N9"!I;G-T86YC:6%T
M92!T:&5M"B`J(&%U=&]M871I8V%L;'DL('5S92!I="!A<R!G:79E;B!I;B!T
M:&4@97AA;7!L92!B96QO=RX*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J("1G
M=6D@/2!N97<@4$A056YI=%]'54E?4V5T=7!$96-O<F%T;W(H;F5W(%!(4%5N
M:71?1U5)7TA434PH*2D["B`J("1G=6DM/F=E=%-U:71E<T9R;VU$:7(H)R]P
M871H+W1O+V1I<B]T97-T<R<L)RXJ7"YP:'`D)RQA<G)A>2@G:6YD97@N<&AP
M)RPG<W%L+G!H<"<I*3L*("H@)&=U:2T^<VAO=R@I.PH@*B`_/@H@*B`\+V-O
M9&4^"B`J"B`J(%1H92!E>&%M<&QE(&-A;&QS('1H:7,@8VQA<W,@86YD('1E
M;&QS(&ET('1O.@H@*@H@*B`@("T@9FEN9"!A;&P@9FEL92!U;F1E<B!T:&4@
M9&ER96-T;W)Y("]P871H+W1O+V1I<B]T97-T<PH@*B`@("T@9F]R(&9I;&5S
M+"!W:&EC:"!E;F0@=VET:"`G+G!H<"<@*'1H:7,@:7,@82!P:65C92!O9B!A
M(')E9V5X<"P@=&AA="=S('=H>2!T:&4@+B!I<R!E<V-A<&5D*0H@*B`@("T@
M86YD('1O(&5X8VQU9&4@=&AE(&9I;&5S("=I;F1E>"YP:'`G(&%N9"`G<W%L
M+G!H<"<*("H@("`M(&%N9"!I;F-L=61E(&%L;"!T:&4@9FEL97,@=&AA="!A
M<F4@;&5F="!I;B!T:&4@=&5S=',N"B`J"B`J($=I=F5N('1H870@=&AE('!A
M=&@@*'1H92!F:7)S="!P87)A;65T97(I(&5N9',@=VET:"`G=&5S=',G(&ET
M('=I;&P@8F4@87-S=6UE9`H@*B!T:&%T('1H92!C;&%S<V5S(&%R92!N86UE
M9"!T97-T<U\J('=H97)E("H@:7,@=&AE(&1I<F5C=&]R>2!P;'5S('1H92!F
M:6QE;F%M92P*("H@86-C;W)D:6YG('1O(%!%05(@<W1A;F1A<F1S+@H@*@H@
M*B!3;R!T:&%T.@H@*@H@*B`@("T@)W1E<W1-92YP:'`G(&EN('1H92!D:7(@
M)W1E<W1S)R!B:6QL(&)E(&%S<W5M960@=&\@8V]N=&%I;B!A(&-L87-S('1E
M<W1S7W1E<W1-90H@*B`@("T@)R]M;W)E=&5S=',O851E<W0N<&AP)R!S:&]U
M;&0@8V]N=&%I;B!A(&-L87-S("=T97-T<U]M;W)E=&5S='-?851E<W0G"B`J
M"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI
M=`H@*B!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR
M:65S:6YG+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N
M($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D
M+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI=%]'54E?
M4V5T=7!$96-O<F%T;W(*>PH@("`@+RHJ"B`@("`J"B`@("`J"B`@("`J+PH@
M("`@9G5N8W1I;VX@4$A056YI=%]'54E?4V5T=7!$96-O<F%T;W(H)B1G=6DI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]G=6D@/2`F)&=U:3L*("`@('T*"B`@
M("`O*BH*("`@("H@("!J=7-T(&9O<G=A<F1I;F<@=&AE(&%C=&EO;B!T;R!T
M:&4@9&5C;W)A=&5D(&-L87-S+@H@("`@*@H@("`@*B\*("`@(&9U;F-T:6]N
M('-H;W<H)'-H;W=087-S960]5%)512D*("`@('L*("`@("`@("`D=&AI<RT^
M7V=U:2T^<VAO=R@D<VAO=U!A<W-E9"D["B`@("!]"@H@("`@+RHJ"B`@("`J
M(%-E='5P('1E<W0@<W5I=&5S('1H870@8V%N(&)E(&9O=6YD(&EN('1H92!G
M:79E;B!D:7)E8W1O<GD*("`@("H@57-I;F<@=&AE('-E8V]N9"!P87)A;65T
M97(@>6]U(&-A;B!A;'-O(&-H;V]S92!A('-U8G-E=',@;V8@=&AE(&9I;&5S
M(&9O=6YD"B`@("`J(&EN('1H92!G:79E;B!D:7)E8W1O<GDN($DN92X@;VYL
M>2!A;&P@=&AE(&9I;&5S('1H870@8V]N=&%I;B`G7U5N:71497-T7R<L"B`@
M("`J(&EN(&]R9&5R('1O(&1O('1H:7,@<VEM<&QY(&-A;&P@:70@;&EK92!T
M:&ES.@H@("`@*B`\8V]D93YG9713=6ET97-&<F]M1&ER*"1D:7(L)RXJ7U5N
M:71497-T7RXJ)RD\+V-O9&4^+@H@("`@*B!4:&5R92!Y;W4@8V%N(&%L<F5A
M9'D@<V5E('1H870@=&AE('!A='1E<FX@:7,@8G5I;'0@9F]R('1H92!U<V4@
M=VET:&EN(&$@<F5G=6QA<B!E>'!R97-S:6]N+@H@("`@*@H@("`@*B!`<&%R
M86T@('-T<FEN9R`@=&AE(&1I<F5C=&]R>2!W:&5R92!T;R!S96%R8V@@9F]R
M('1E<W0M<W5I=&4@9FEL97,*("`@("H@0'!A<F%M("!S=')I;F<@('1H92!P
M871T97)N("AA(')E9V5X<"D@8GD@=VAI8V@@=&\@9FEN9"!T:&4@9FEL97,*
M("`@("H@0'!A<F%M("!A<G)A>2`@(&%N(&%R<F%Y(&]F(&9I;&4@;F%M97,@
M=&AA="!S:&%L;"!B92!E>&-L=61E9`H@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-U:71E<T9R;VU$:7(H)&1I<BP@)&9I;&5N86UE4&%T=&5R;B`]("<G+"`D
M97AC;'5D92`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1D:7)[<W1R
M;&5N*"1D:7(I+3%](#T]($1)4D5#5$]265]315!!4D%43U(I('L*("`@("`@
M("`@("`@)&1I<B`]('-U8G-T<B@D9&ER+"`P+"`M,2D["B`@("`@("`@?0H*
M("`@("`@("`D9FEL97,@/2`D=&AI<RT^7V=E=$9I;&5S*')E86QP871H*"1D
M:7(I+"`D9FEL96YA;650871T97)N+"`D97AC;'5D92P@<F5A;'!A=&@H)&1I
M<B`N("<O+BXG*2D["B`@("`@("`@87-O<G0H)&9I;&5S*3L*"B`@("`@("`@
M9F]R96%C:"`H)&9I;&5S(&%S("1C;&%S<TYA;64@/3X@)&%&:6QE*2!["B`@
M("`@("`@("`@(&EN8VQU9&5?;VYC92@D849I;&4I.PH*("`@("`@("`@("`@
M:68@*&-L87-S7V5X:7-T<R@D8VQA<W-.86UE*2D@>PH@("`@("`@("`@("`@
M("`@)'-U:71E<UM=(#TF(&YE=R!02%!5;FET7U1E<W13=6ET92@D8VQA<W-.
M86UE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('1R
M:6=G97)?97)R;W(H(B1C;&%S<TYA;64@8V]U;&0@;F]T(&)E(&9O=6YD(&EN
M("1D:7(D849I;&4A(BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?9W5I+3YA9&13=6ET97,H)'-U:71E<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`J(%1H:7,@;65T:&]D('-E87)C:&5S(')E8W5R<VEV96QY
M('1H<F]U9V@@=&AE(&1I<F5C=&]R:65S"B`@("`J('1O(&9I;F0@86QL('1H
M92!F:6QE<R!T:&%T('-H86QL(&)E(&%D9&5D('1O('1H92!B92!V:7-I8FQE
M+@H@("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R`@=&AE('!A=&@@=VAE<F4@
M9FEN9"!T:&4@9FEL97,*("`@("H@0'!A<F%M("!S<G1I;F<@('1H92!S=')I
M;F<@<&%T=&5R;B!B>2!W:&EC:"!T;R!F:6YD('1H92!F:6QE<PH@("`@*B!`
M<&%R86T@('-T<FEN9R`@=&AE(&9I;&4@;F%M97,@=&\@8F4@97AC;'5D960*
M("`@("H@0'!A<F%M("!S=')I;F<@('1H92!R;V]T(&1I<F5C=&]R>2P@=VAI
M8V@@<V5R=F5S(&%S('1H92!P<F5F:7@@=&\@=&AE(&9U;&QY('%U86QI9FEE
M9"!F:6QE;F%M90H@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T1FEL97,H)&1I<BP@)&9I;&5N86UE4&%T=&5R;BP@)&5X
M8VQU9&4L("1R;V]T1&ER*0H@("`@>PH@("`@("`@("1F:6QE<R`](&%R<F%Y
M*"D["@H@("`@("`@(&EF("@D9'`@/2!O<&5N9&ER*"1D:7(I*2!["B`@("`@
M("`@("`@('=H:6QE("A&04Q312`A/3T@*"1F:6QE(#T@<F5A9&1I<B@D9'`I
M*2D@>PH@("`@("`@("`@("`@("`@)&9I;&5N86UE(#T@)&1I<B`N($1)4D5#
M5$]265]315!!4D%43U(@+B`D9FEL93L*("`@("`@("`@("`@("`@("1M871C
M:"`@("`](%12544["@H@("`@("`@("`@("`@("`@:68@*"1F:6QE;F%M95!A
M='1E<FX@)B8@(7!R96=?;6%T8V@H(GXD9FEL96YA;650871T97)N?B(L("1F
M:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@("1M871C:"`]($9!3%-%.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AS:7IE;V8H
M)&5X8VQU9&4I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5X
M8VQU9&4@87,@)&%%>&-L=61E*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')P;W,H)&9I;&4L("1A17AC;'5D92D@(3T]($9!3%-%*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;6%T8V@@/2!&04Q313L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<U]F:6QE*"1F:6QE;F%M
M92D@)B8@)&UA=&-H*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]('-T
M<E]R97!L86-E*"1R;V]T1&ER+"`G)RP@)&9I;&5N86UE*3L*"B`@("`@("`@
M("`@("`@("`@("`@:68@*'-T<G!O<R@D=&UP+"!$25)%0U1/4EE?4T5005)!
M5$]2*2`]/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&UP(#T@
M<W5B<W1R*"1T;7`L(#$I.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D=&UP+"`G+R<I(#T]/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T;7`@/2!S=6)S='(H)'1M<"P@
M,2D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@
M("`D8VQA<W-.86UE(#T@<W1R7W)E<&QA8V4H1$E214-43U)97U-%4$%2051/
M4BP@)U\G+"`D=&UP*3L*("`@("`@("`@("`@("`@("`@("`D8VQA<W-.86UE
M(#T@8F%S96YA;64H)&-L87-S3F%M92P@)RYP:'`G*3L*"B`@("`@("`@("`@
M("`@("`@("`@)&9I;&5S6R1C;&%S<TYA;65=(#T@)&9I;&5N86UE.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@D9FEL92`A/2`G
M+B<@)B8@)&9I;&4@(3T@)RXN)R`F)B!I<U]D:7(H)&9I;&5N86UE*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE
M<RP@)'1H:7,M/E]G971&:6QE<R@D9FEL96YA;64L("1F:6QE;F%M95!A='1E
M<FXL("1E>&-L=61E+"`D<F]O=$1I<BDI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!C;&]S961I<B@D9'`I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@('T*?0H*+RH*("H@
M3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO
M9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J
M($5N9#H*("HO"C\^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!(4%5N:70O1U5)+T=T:RYP:'``````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#4T,S(W`#$P-3$U-#,Q,#4W`#`R,#4R-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@
M0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\
M<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E
M<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@
M86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2
M961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@
M=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I
M86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J
M"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N
M;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA
M>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I
M=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I
M8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#
M3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U0
M3$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%
M1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))
M1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@
M*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/
M4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*
M("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4
M("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@
M24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%
M+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K
M86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V-O='0@36%T=&]C:W,@
M/'-C;W1T0&-R:7-S8V]T="YC;VT^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P
M-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!'=&LN<&AP+'8@,2XV(#(P,#4O,3$O,3`@,#DZ
M-#<Z,34@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XR+C`*("HO"@II9B`H(69U
M;F-T:6]N7V5X:7-T<R@G:7-?82<I*2!["B`@("!R97%U:7)E7V]N8V4@)U!(
M4"]#;VUP870O1G5N8W1I;VXO:7-?82YP:'`G.PI]"@HO*BH*("H@1U1+($=5
M22!I;G1E<F9A8V4@9F]R(%!(4%5N:70N"B`J"B`J(%1H:7,@8VQA<W,@:7,@
M82!02%`@<&]R="!O9B!J=6YI="YA=W1U:2YT97-T<G5N;F5R+B!$;V-U;65N
M=&%T:6]N"B`J(&9O<B!J=6YI="YA=W1U:2YT97-T<G5N;F5R(&-A;B!B92!F
M;W5N9"!A=`H@*B!H='1P.B\O:G5N:70N<V]U<F-E9F]R9V4N;F5T"B`J"B`J
M($1U92!T;R!T:&4@;&EM:71A=&EO;G,@;V8@4$A0-"!A;F0@4$A0+4=T:RP@
M=&AI<R!C;&%S<R!C86X@;F]T"B`J(&1U<&QI8V%T92!A;&P@;V8@=&AE(&9U
M;F-T:6]N86QI='D@;V8@=&AE($I5;FET($=522X@4V]M92!O9B!T:&4*("H@
M=&AI;F=S('1H:7,@8VQA<W,@8V%N;F]T(&1O(&EN8VQU9&4Z"B`J("T@4F5L
M;V%D:6YG('1H92!C;&%S<R!F;W(@96%C:"!R=6X*("H@+2!3=&]P<&EN9R!T
M:&4@=&5S="!I;B!P<F]G<F5S<PH@*@H@*B!4;R!U<V4@<VEM<&QY(&EN=&%N
M=&EA=&4@=&AE(&-L87-S(&%N9"!C86QL(&UA:6XH*0H@*B`D9W1K(#TF(&YE
M=R!02%!5;FET7T=525]'=&L["B`J("1G=&LM/FUA:6XH*3L*("H*("H@3VYC
M92!T:&4@=VEN9&]W(&AA<R!F:6YI<VAE9"!L;V%D:6YG+"!Y;W4@8V%N(&5N
M=&5R('1H92!N86UE(&]F"B`J(&$@8VQA<W,@=&AA="!H87,@8F5E;B!L;V%D
M960@*&EN8VQU9&4O<F5Q=6ER92!S;VUE('=H97)E(&EN('EO=7(*("H@8V]D
M92P@;W(@>6]U(&-A;B!P87-S('1H92!N86UE(&]F('1H92!F:6QE(&-O;G1A
M:6YI;F<@=&AE(&-L87-S+@H@*@H@*B!9;W4@8V%N(&%L<V\@;&]A9"!C;&%S
M<V5S('5S:6YG('1H92!3971U<$1E8V]R871O<B!C;&%S<RX*("H@<F5Q=6ER
M95]O;F-E("=02%!5;FET+T=522]3971U<$1E8V]R871O<BYP:'`G.PH@*B!R
M97%U:7)E7V]N8V4@)U!(4%5N:70O1U5)+T=T:RYP:'`G.PH@*B`D9W5I(#T@
M;F5W(%!(4%5N:71?1U5)7U-E='5P1&5C;W)A=&]R*&YE=R!02%!5;FET7T=5
M25]'=&LH*2D["B`J("1G=6DM/F=E=%-U:71E<T9R;VU$:7(H)R]P871H+W1O
M+W1E<W0G+"<N*EPN<&AP)"<L87)R87DH)VEN9&5X+G!H<"<L)W-Q;"YP:'`G
M*2D["B`J("1G=6DM/G-H;W<H*3L*("H*("H*("H@0&-A=&5G;W)Y("`@5&5S
M=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-C
M;W1T($UA='1O8VMS(#QS8V]T=$!C<FES<V-O='0N8V]M/@H@*B!`8V]P>7)I
M9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E
M;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC
M96YS90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(N
M,`H@*B!`=&]D;R`@("`@("!!;&QO=R!F:6QE(&1R;W`N("A'=&M?1FEL941R
M;W`I"B`J+PIC;&%S<R!02%!5;FET7T=525]'=&L@>PH*("`@("\J*@H@("`@
M("H@5&AE(&UA:6X@9W1K('=I;F1O=PH@("`@("H@0'9A<B!O8FIE8W0*("`@
M("`J+PH@("`@=F%R("1G=6D["B`@("`O*BH*("`@("`J(%1H92!T97AT(&5N
M=')Y('1H870@8V]N=&%I;G,@=&AE(&YA;64@;V8@=&AE"B`@("`@*B!F:6QE
M('1H870@:&]L9',@=&AE('1E<W0H<RDO<W5I=&4H<RDN"B`@("`@*B!`=F%R
M(&]B:F5C=`H@("`@("HO"B`@("!V87(@)'-U:71E1FEE;&0["B`@("`O*BH*
M("`@("`J(%1H92!L86)E;"!T:&%T('-H;W=S('1H92!N=6UB97(@;V8@=&5S
M=',@=&AA=`H@("`@("H@=V5R92!R=6XN"B`@("`@*B!`=F%R(&]B:F5C=`H@
M("`@("HO"B`@("!V87(@)&YU;6)E<D]F4G5N<SL*("`@("\J*@H@("`@("H@
M5&AE(&QA8F5L('1H870@<VAO=W,@=&AE(&YU;6)E<B!O9B!E<G)O<G,@=&AA
M=`H@("`@("H@=V5R92!E;F-O=6YT97)E9"X*("`@("`J($!V87(@;V)J96-T
M"B`@("`@*B\*("`@('9A<B`D;G5M8F5R3V9%<G)O<G,["B`@("`O*BH*("`@
M("`J(%1H92!L86)E;"!T:&%T('-H;W=S('1H92!N=6UB97(@;V8@9F%I;'5R
M97,*("`@("`J('1H870@=V5R92!E;F-O=6YT97)E9"X*("`@("`J($!V87(@
M;V)J96-T"B`@("`@*B\*("`@('9A<B`D;G5M8F5R3V9&86EL=7)E<SL*("`@
M("\J*@H@("`@("H@5&AE(&QA8F5L(&9O<B!R97!O<G1I;F<@=7-E<B!M97-S
M86=E<RX*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D<W1A
M='5S3&EN93L*("`@("\J*@H@("`@("H@5&AE('1E>'0@87)E82!F;W(@<F5P
M;W)T:6YG(&UE<W-A9V5S(&9R;VT@<W5C8V5S<V9U;`H@("`@("H@=&5S="!R
M=6YS+B`H;F]T(&YE8V5S<V%R:6QY('-U8V-E<W-F=6P@=&5S=',I"B`@("`@
M*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)')E<&]R=$%R96$["B`@
M("`O*BH*("`@("`J(%1H92!T97AT(&%R96$@9F]R(')E<&]R=&EN9R!E<G)O
M<G,@96YC;W5N=&5R960@=VAE;@H@("`@("H@<G5N;FEN9R!T97-T<RX*("`@
M("`J($!V87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D9'5M<$%R96$["B`@
M("`O*BH*("`@("`J(%1H92!P<F]G<F5S<R!B87(@:6YD:6-A=&]R+B!3:&]W
M<R!T:&4@<&5R8V5N=&%G92!O9@H@("`@("H@<&%S<V5D('1E<W1S+@H@("`@
M("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1P<F]G<F5S<SL*("`@
M("\J*@H@("`@("H@02!C:&5C:V)O>"!F;W(@=&AE('5S97(@=&\@:6YD:6-A
M=&4@=VAE=&AE<B!O<B!N;W0@=&AE>0H@("`@("H@=V]U;&0@;&EK92!T;R!S
M964@<F5S=6QT<R!F<F]M(&%L;"!T97-T<R!O<B!J=7-T(&9A:6QU<F5S+@H@
M("`@("H@0&]B:F5C=`H@("`@("HO"B`@("!V87(@)'-H;W=087-S960["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!4:&4@
M8V]N<W1R=6-T;W(@8VAE8VMS(&9O<B!T:&4@9W1K(&5X=&5N<VEO;B!A;F0@
M;&]A9',@:70*("`@("`J(&EF(&YE961E9"X@5&AE;B!I="!C<F5A=&5S('1H
M92!'54DN(%1H92!'54D@:7,@;F]T('-H;W=N"B`@("`@*B!N;W(@:7,@=&AE
M(&UA:6X@9W1K(&QO;W`@<W1A<G1E9"!U;G1I;"!M86EN*"D@:7,@8V%L;&5D
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@
M(&YO;F4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!02%!5;FET7T=525]'=&LH*0H@("`@>PH@("`@("`@("\O($-H96-K(&9O
M<B!P:'`M9W1K(&5X=&5N<VEO;BX*("`@("`@("!I9B`H(65X=&5N<VEO;E]L
M;V%D960H)V=T:R<I*2!["B`@("`@("`@("`@(&1L*"`G<&AP7V=T:RXG("X@
M4$A07U-(3$E"7U-51D9)6"D["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A
M=&4@=&AE(&EN=&5R9F%C92!B=70@9&]N)W0@<W1A<G0@=&AE(&QO;W`*("`@
M("`@("`D=&AI<RT^7V-R96%T955)*"D["B`@("!]"B`@("`O*BH*("`@("`J
M(%-T87)T('1H92!M86EN(&=T:R!L;V]P+@H@("`@("H*("`@("`J(&UA:6XH
M*2!F:7)S="!S971S('1H92!D969A=6QT('-T871E(&]F('1H92!S:&]W4&%S
M<V5D"B`@("`@*B!C:&5C:R!B;W@N($YE>'0@86QL('=I9&=E=',@=&AA="!A
M<F4@<&%R="!O9B!T:&4@1U5)"B`@("`@*B!A<F4@<VAO=VXN($9I;F%L;'D@
M=&AE(&UA:6X@9W1K(&QO;W`@:7,@<W1A<G1E9"X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!B;V]L96%N("1S:&]W4&%S
M<V5D"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M;6%I;B@D<VAO=U!A<W-E9"`]('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M
M/G-H;W=087-S960M/G-E=%]A8W1I=F4H)'-H;W=087-S960I.PH@("`@("`@
M("1T:&ES+3YG=6DM/G-H;W=?86QL*"D["@H@("`@("`@(&=T:SHZ;6%I;B@I
M.PH@("`@?0H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE('5S97(@:6YT97)F
M86-E+@H@("`@("H*("`@("`J(%1H92!U<V5R(&EN=&5R9F%C92!I<R!P<F5T
M='D@<VEM<&QE+B!)="!C;VYS:7-T<R!O9B!A"B`@("`@*B!M96YU+"!T97AT
M(&5N=')Y+"!R=6X@8G5T=&]N+"!S;VUE(&QA8F5L<RP@82!P<F]G<F5S<PH@
M("`@("H@:6YD:6-A=&]R+"!A;F0@82!C;W5P;&4@;V8@87)E87,@9F]R(&YO
M=&EF:6-A=&EO;B!O9@H@("`@("H@86YY(&UE<W-A9V5S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!N;VYE"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T955)
M*"D*("`@('L*("`@("`@("`O+R!#<F5A=&4@82!W:6YD;W<N"B`@("`@("`@
M)'=I;F1O=R`])B!N97<@1W1K5VEN9&]W.PH@("`@("`@("1W:6YD;W<M/G-E
M=%]T:71L92@G4$A056YI="!'=&LG*3L*("`@("`@("`D=VEN9&]W+3YS971?
M=7-I>F4H-#`P+"`M,2D["@H@("`@("`@("\O($-R96%T92!T:&4@;6%I;B!B
M;W@N"B`@("`@("`@)&UA:6Y";W@@/28@;F5W($=T:U9";W@["B`@("`@("`@
M)'=I;F1O=RT^861D*"1M86EN0F]X*3L*"B`@("`@("`@+R\@4W1A<G0@=VET
M:"!T:&4@;65N=2X*("`@("`@("`D;6%I;D)O>"T^<&%C:U]S=&%R="@D=&AI
M<RT^7V-R96%T94UE;G4H*2D["@H@("`@("`@("\O(%1H96X@861D('1H92!S
M=6ET92!F:65L9"!E;G1R>2X*("`@("`@("`D;6%I;D)O>"T^<&%C:U]S=&%R
M="@D=&AI<RT^7V-R96%T95-U:71E16YT<GDH*2D["@H@("`@("`@("\O(%1H
M96X@861D('1H92!R97!O<G0@;&%B96QS+@H@("`@("`@("1M86EN0F]X+3YP
M86-K7W-T87)T*"1T:&ES+3Y?8W)E871E4F5P;W)T3&%B96QS*"DI.PH*("`@
M("`@("`O+R!.97AT(&%D9"!T:&4@<')O9W)E<W,@8F%R+@H@("`@("`@("1M
M86EN0F]X+3YP86-K7W-T87)T*"1T:&ES+3Y?8W)E871E4')O9W)E<W-"87(H
M*2D["@H@("`@("`@("\O(%1H96X@861D('1H92!R97!O<G0@87)E82!A;F0@
M=&AE(&1U;7`@87)E82X*("`@("`@("`D;6%I;D)O>"T^<&%C:U]S=&%R="@D
M=&AI<RT^7V-R96%T95)E<&]R=$%R96%S*"DI.PH*("`@("`@("`O+R!&:6YI
M<V@@;V9F('=I=&@@=&AE('-T871U<R!L:6YE+@H@("`@("`@("1M86EN0F]X
M+3YP86-K7W-T87)T*"1T:&ES+3Y?8W)E871E4W1A='5S3&EN92@I*3L*"B`@
M("`@("`@+R\@0V]N;F5C="!T:&4@9&5S=')O>2!S:6=N86PN"B`@("`@("`@
M)'=I;F1O=RT^8V]N;F5C=%]O8FIE8W0H)V1E<W1R;WDG+"!A<G)A>2@G9W1K
M)RP@)VUA:6Y?<75I="<I*3L*"B`@("`@("`@+R\@07-S:6=N('1H92!M96UB
M97(N"B`@("`@("`@)'1H:7,M/F=U:2`])B`D=VEN9&]W.PH@("`@?0H@("`@
M+RHJ"B`@("`@*B!#<F5A=&4@=&AE(&UE;G4N"B`@("`@*@H@("`@("H@5&AE
M(&UE;G4@:7,@=F5R>2!S:6UP;&4N($ET(&%N(&5X:70@;65N=2!I=&5M+"!W
M:&EC:"!E>&ET<PH@("`@("H@=&AE(&%P<&QI8V%T:6]N+"!A;F0@86X@86)O
M=70@;65N=2!I=&5M+"!W:&EC:"!S:&]W<R!S;VUE"B`@("`@*B!B87-I8R!I
M;F9O<FUA=&EO;B!A8F]U="!T:&4@87!P;&EC871I;VX@:71S96QF+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!N;VYE
M"B`@("`@*B!`<F5T=7)N("9O8FIE8W0@5&AE($=T:TUE;G5"87(*("`@("`J
M+PH@("`@9G5N8W1I;VX@)E]C<F5A=&5-96YU*"D*("`@('L*("`@("`@("`O
M+R!#<F5A=&4@=&AE(&UE;G4@8F%R+@H@("`@("`@("1M96YU0F%R(#TF(&YE
M=R!'=&M-96YU0F%R.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(&UA:6X@*&]N
M;'DI(&UE;G4@:71E;2X*("`@("`@("`D<&AP2&5A9&5R(#TF(&YE=R!'=&M-
M96YU271E;2@G4$A056YI="<I.PH*("`@("`@("`O+R!!9&0@=&AE(&UE;G4@
M:71E;2!T;R!T:&4@;65N=2!B87(N"B`@("`@("`@)&UE;G5"87(M/F%P<&5N
M9"@D<&AP2&5A9&5R*3L*"B`@("`@("`@+R\@0W)E871E('1H92!02%!5;FET
M(&UE;G4N"B`@("`@("`@)'!H<$UE;G4@/28@;F5W($=T:TUE;G4["@H@("`@
M("`@("\O($%D9"!T:&4@;65N=2!I=&5M<PH@("`@("`@("1A8F]U="`])B!N
M97<@1W1K365N=4ET96TH)T%B;W5T+BXN)RD["B`@("`@("`@)&%B;W5T+3YC
M;VYN96-T*"=A8W1I=F%T92<L(&%R<F%Y*"8D=&AI<RP@)V%B;W5T)RDI.PH@
M("`@("`@("1P:'!-96YU+3YA<'!E;F0H)&%B;W5T*3L*"B`@("`@("`@)&5X
M:70@/28@;F5W($=T:TUE;G5)=&5M*"=%>&ET)RD["B`@("`@("`@)&5X:70M
M/F-O;FYE8W1?;V)J96-T*"=A8W1I=F%T92<L(&%R<F%Y*"=G=&LG+"`G;6%I
M;E]Q=6ET)RDI.PH@("`@("`@("1P:'!-96YU+3YA<'!E;F0H)&5X:70I.PH*
M("`@("`@("`O+R!#;VUP;&5T92!T:&4@;65N=2X*("`@("`@("`D<&AP2&5A
M9&5R+3YS971?<W5B;65N=2@D<&AP365N=2D["@H@("`@("`@(')E='5R;B`D
M;65N=4)A<CL*("`@('T*("`@("\J*@H@("`@("H@0W)E871E('1H92!S=6ET
M92!E;G1R>2!A;F0@<F5L871E9"!W:61G971S+@H@("`@("H*("`@("`J(%1H
M92!S=6ET92!E;G1R>2!H87,@<V]M92!S=7!P;W)T:6YG(&-O;7!O;F5N=',@
M<W5C:"!A<R!A"B`@("`@*B!L86)E;"P@=&AE('-H;W<@<&%S<V5D(&-H96-K
M(&)O>"!A;F0@=&AE(')U;B!B=71T;VXN($%L;`H@("`@("H@;V8@=&AE<V4@
M:71E;7,@87)E('!A8VME9"!I;G1O('1W;R!N97-T960@8F]X97,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*
M("`@("`J($!R971U<FX@)F]B:F5C="!!(&)O>"!T:&%T(&-O;G1A:6YS(&%L
M;"!O9B!T:&4@<W5I=&4@96YT<GD@<&EE8V5S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F7V-R96%T95-U:71E16YT<GDH*0H@("`@>PH@("`@("`@("\O($-R
M96%T92!T:&4@;W5T97)M;W-T(&)O>"X*("`@("`@("`D;W5T97)";W@@("`@
M("`@("`])B!N97<@1W1K5D)O>#L*"B`@("`@("`@+R\@0W)E871E('1H92!S
M=6ET92!L86)E;"P@8F]X+"!A;F0@9FEE;&0N"B`@("`@("`@)'-U:71E3&%B
M96P@("`@("`@/28@;F5W($=T:TQA8F5L*"=497-T(&-L87-S(&YA;64Z)RD[
M"B`@("`@("`@)'-U:71E0F]X("`@("`@("`@/28@;F5W($=T:TA";W@["B`@
M("`@("`@)'1H:7,M/G-U:71E1FEE;&0@/28@;F5W($=T:T5N=')Y.PH@("`@
M("`@("1T:&ES+3YS=6ET949I96QD+3YS971?=&5X="@D<W5I=&5.86UE("$]
M($Y53$P@/R`D<W5I=&5.86UE(#H@)R<I.PH*("`@("`@("`O+R!#<F5A=&4@
M=&AE(&)U='1O;B!T:&4@=7-E<B!W:6QL('5S92!T;R!S=&%R="!T:&4@=&5S
M="X*("`@("`@("`D<G5N0G5T=&]N(#TF(&YE=R!'=&M"=71T;VXH)U)U;B<I
M.PH@("`@("`@("1R=6Y"=71T;VXM/F-O;FYE8W1?;V)J96-T*"=C;&EC:V5D
M)RP@87)R87DH)B1T:&ES+"`G<G5N)RDI.PH*("`@("`@("`O+R!#<F5A=&4@
M=&AE(&-H96-K(&)O>"!T:&%T(&QE=',@=&AE('5S97(@<VAO=R!O;FQY(&9A
M:6QU<F5S+@H@("`@("`@("1T:&ES+3YS:&]W4&%S<V5D(#TF(&YE=R!'=&M#
M:&5C:T)U='1O;B@G4VAO=R!P87-S960@=&5S=',G*3L*"B`@("`@("`@+R\@
M061D('1H92!C;VUP;VYE;G1S('1O('1H96ER(')E<W!E8W1I=F4@8F]X97,N
M"B`@("`@("`@)'-U:71E3&%B96PM/G-E=%]A;&EG;FUE;G0H,"P@,"D["B`@
M("`@("`@)&]U=&5R0F]X+3YP86-K7W-T87)T*"1S=6ET94QA8F5L*3L*("`@
M("`@("`D;W5T97)";W@M/G!A8VM?<W1A<G0H)'-U:71E0F]X*3L*("`@("`@
M("`D;W5T97)";W@M/G!A8VM?<W1A<G0H)'1H:7,M/G-H;W=087-S960I.PH*
M("`@("`@("`D<W5I=&5";W@M/G!A8VM?<W1A<G0H)'1H:7,M/G-U:71E1FEE
M;&0I.PH@("`@("`@("1S=6ET94)O>"T^<&%C:U]S=&%R="@D<G5N0G5T=&]N
M*3L*"B`@("`@("`@<F5T=7)N("1O=71E<D)O>#L*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T92!T:&4@;&%B96QS('1H870@=&5L;"!T:&4@=7-E<B!W
M:&%T(&AA<R!H87!P96YE9"X*("`@("`J"B`@("`@*B!4:&5R92!A<F4@=&AR
M964@;&%B96QS+"!O;F4@96%C:"!F;W(@=&]T86P@<G5N<RP@97)R;W)S(&%N
M9`H@("`@("H@9F%I;'5R97,N(%1H97)E(&ES(&%L<V\@;VYE(&QA8F5L(&9O
M<B!E86-H(&]F('1H97-E('1H870*("`@("`J(&1E<V-R:6)E<R!W:&%T('1H
M92!L86)E;"!I<RX@270@8V]U;&0@8F4@9&]N92!W:71H(&]N92!L86)E;`H@
M("`@("H@:6YS=&5A9"!O9B!T=V\@8G5T('1H870@=V]U;&0@;6%K92!U<&1A
M=&5S(&UU8V@@:&%R9&5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N("9O8FIE8W0@
M02!B;W@@8V]N=&%I;FEN9R!T:&4@;&%B96QS+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F7V-R96%T95)E<&]R=$QA8F5L<R@I"B`@("!["B`@("`@("`@+R\@
M0W)E871E(&$@8F]X('1O(&AO;&0@979E<GET:&EN9RX*("`@("`@("`D;&%B
M96Q";W@@("`@("`@("`])B!N97<@1W1K2$)O>#L*"B`@("`@("`@+R\@0W)E
M871E('1H92!N;VXM=7!D871E9"!L86)E;',N"B`@("`@("`@)&YU;6)E<D]F
M4G5N<R`@("`@/28@;F5W($=T:TQA8F5L*"=2=6YS.B<I.PH@("`@("`@("1N
M=6UB97)/9D5R<F]R<R`@(#TF(&YE=R!'=&M,86)E;"@G17)R;W)S.B<I.PH@
M("`@("`@("1N=6UB97)/9D9A:6QU<F5S(#TF(&YE=R!'=&M,86)E;"@G1F%I
M;'5R97,Z)RD["@H@("`@("`@("\O($-R96%T92!T:&4@;&%B96QS('1H870@
M=VEL;"!B92!U<&1A=&5D+@H@("`@("`@("\O(%1H97-E(&%R92!A<W-S:6=N
M960@=&\@;65M8F5R<R!T;R!M86ME(&ET(&5A<VEE<B!T;PH@("`@("`@("\O
M('-E="!T:&5I<B!V86QU97,@;&%T97(N"B`@("`@("`@)'1H:7,M/FYU;6)E
M<D]F4G5N<R`@("`@/28@;F5W($=T:TQA8F5L*#`I.PH@("`@("`@("1T:&ES
M+3YN=6UB97)/9D5R<F]R<R`@(#TF(&YE=R!'=&M,86)E;"@P*3L*("`@("`@
M("`D=&AI<RT^;G5M8F5R3V9&86EL=7)E<R`])B!N97<@1W1K3&%B96PH,"D[
M"@H@("`@("`@("\O(%!A8VL@979E<GET:&EN9R!I;BX*("`@("`@("`D;&%B
M96Q";W@M/G!A8VM?<W1A<G0H)&YU;6)E<D]F4G5N<RD["B`@("`@("`@)&QA
M8F5L0F]X+3YP86-K7W-T87)T*"1T:&ES+3YN=6UB97)/9E)U;G,I.PH@("`@
M("`@("1L86)E;$)O>"T^<&%C:U]S=&%R="@D;G5M8F5R3V9%<G)O<G,I.PH@
M("`@("`@("1L86)E;$)O>"T^<&%C:U]S=&%R="@D=&AI<RT^;G5M8F5R3V9%
M<G)O<G,I.PH@("`@("`@("1L86)E;$)O>"T^<&%C:U]S=&%R="@D;G5M8F5R
M3V9&86EL=7)E<RD["B`@("`@("`@)&QA8F5L0F]X+3YP86-K7W-T87)T*"1T
M:&ES+3YN=6UB97)/9D9A:6QU<F5S*3L*"B`@("`@("`@<F5T=7)N("1L86)E
M;$)O>#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@<W5C8V5S
M<R]F86EL=7)E(&EN9&EC871O<BX*("`@("`J"B`@("`@*B!!($=T:U!R;V=R
M97-S0F%R(&ES('5S960@=&\@=FES=6%L;'D@:6YD:6-A=&4@:&]W(&UA;GD*
M("`@("`J('1E<W1S('=E<F4@<W5C8V5S<V9U;"!C;VUP87)E9"!T;R!H;W<@
M;6%N>2!W97)E(&YO="X@5&AE"B`@("`@*B!P<F]G<F5S<R!B87(@<VAO=W,@
M=&AE('!E<F-E;G1A9V4@;V8@<W5C8V5S<R!A;F0@=VEL;`H@("`@("H@8VAA
M;F=E(&9R;VT@9W)E96X@=&\@<F5D(&EF('1H97)E(&%R92!A;GD@9F%I;'5R
M97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@(&YO;F4*("`@("`J($!R971U<FX@)F]B:F5C="!4:&4@<')O9W)E<W,@
M8F%R"B`@("`@*B\*("`@(&9U;F-T:6]N("9?8W)E871E4')O9W)E<W-"87(H
M*0H@("`@>PH@("`@("`@("\O($-R96%T92!T:&4@<')O9W)E<W,@8F%R+@H@
M("`@("`@("1T:&ES+3YP<F]G<F5S<R`])B!N97<@1W1K4')O9W)E<W-"87(H
M;F5W($=T:T%D:G5S=&UE;G0H,"P@,"P@,2P@+C$L(#$L(#`I*3L*"B`@("`@
M("`@+R\@4V5T('1H92!P<F]G<F5S<R!B87(@=&\@<')I;G0@=&AE('!E<F-E
M;G1A9V4N"B`@("`@("`@)'1H:7,M/G!R;V=R97-S+3YS971?<VAO=U]T97AT
M*'1R=64I.PH*("`@("`@("!R971U<FX@)'1H:7,M/G!R;V=R97-S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!R97!O<G0@=&5X="!A<F5A
M<RX*("`@("`J"B`@("`@*B!4:&4@<F5P;W)T(&%R96$@8V]N<VES=',@;V8@
M;VYE('1E>'0@87)E82!F;W(@9F%I;'5R97,L(&]N90H@("`@("H@=&5X="!A
M<F5A(&9O<B!E<G)O<G,@86YD(&]N92!L86)E;"!F;W(@:61E;G1I9FEC871I
M;VX@<'5R<&]S97,N"B`@("`@*B!!;&P@=&AR964@=VED9V5T<R!A<F4@<&%C
M:V5D(&EN=&\@82!B;W@N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@)F]B:F5C="!4
M:&4@8F]X(&-O;G1A:6YI;F<@=&AE(')E<&]R="!A<F5A<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)E]C<F5A=&5297!O<G1!<F5A<R@I"B`@("!["B`@("`@
M("`@+R\@0W)E871E('1H92!C;VYT86EN:6YG(&)O>"X*("`@("`@("`D<F5P
M;W)T0F]X(#TF(&YE=R!'=&M60F]X.PH*("`@("`@("`O+R!#<F5A=&4@=&AE
M(&ED96YT:69I8V%T:6]N(&QA8F5L"B`@("`@("`@)')E<&]R=$QA8F5L(#TF
M(&YE=R!'=&M,86)E;"@G17)R;W)S(&%N9"!&86EL=7)E<SHG*3L*("`@("`@
M("`D<F5P;W)T3&%B96PM/G-E=%]A;&EG;FUE;G0H,"P@,"D["@H@("`@("`@
M("\O($-R96%T92!T:&4@<V-R;VQL960@=VEN9&]W<R!F;W(@=&AE('1E>'0@
M87)E87,N"B`@("`@("`@)')E<&]R=%-C<F]L;"`])B!N97<@1W1K4V-R;VQL
M9617:6YD;W<["B`@("`@("`@)&1U;7!38W)O;&P@("`])B!N97<@1W1K4V-R
M;VQL9617:6YD;W<["@H@("`@("`@("\O($UA:V4@=&AE('-C<F]L;"!A<F5A
M<R!B:6<@96YO=6=H+@H@("`@("`@("1R97!O<G138W)O;&PM/G-E=%]U<VEZ
M92@M,2P@,34P*3L*("`@("`@("`D9'5M<%-C<F]L;"T^<V5T7W5S:7IE*"TQ
M+"`Q-3`I.PH*("`@("`@("`O+R!/;FQY('-H;W<@=&AE('9E<G1I8V%L('-C
M<F]L;"!B87(@=VAE;B!N965D960N"B`@("`@("`@+R\@3F5V97(@<VAO=R!T
M:&4@:&]R:7IO;G1A;"!S8W)O;&P@8F%R+@H@("`@("`@("1R97!O<G138W)O
M;&PM/G-E=%]P;VQI8WDH1U1+7U!/3$E#65].159%4BP@1U1+7U!/3$E#65]!
M551/34%424,I.PH@("`@("`@("1D=6UP4V-R;VQL+3YS971?<&]L:6-Y*$=4
M2U]03TQ)0UE?3D5615(L($=42U]03TQ)0UE?05543TU!5$E#*3L*"B`@("`@
M("`@+R\@0W)E871E('1H92!T97AT(&%R96%S+@H@("`@("`@("1T:&ES+3YR
M97!O<G1!<F5A(#TF(&YE=R!'=&M497AT.PH@("`@("`@("1T:&ES+3YD=6UP
M07)E82`])B!N97<@1W1K5&5X=#L*"B`@("`@("`@+R\@1&]N)W0@;&5T('=O
M<F1S(&=E="!B<F]K96XN"B`@("`@("`@)'1H:7,M/G)E<&]R=$%R96$M/G-E
M=%]W;W)D7W=R87`H=')U92D["B`@("`@("`@)'1H:7,M/F1U;7!!<F5A+3YS
M971?=V]R9%]W<F%P*'1R=64I.PH*("`@("`@("`O+R!086-K(&5V97)Y=&AI
M;F<@:6XN"B`@("`@("`@)')E<&]R=$)O>"T^<&%C:U]S=&%R="@D<F5P;W)T
M3&%B96PI.PH@("`@("`@("1R97!O<G138W)O;&PM/F%D9"@D=&AI<RT^<F5P
M;W)T07)E82D["B`@("`@("`@)')E<&]R=$)O>"T^<&%C:U]S=&%R="@D<F5P
M;W)T4V-R;VQL*3L*("`@("`@("`D9'5M<%-C<F]L;"T^861D*"1T:&ES+3YD
M=6UP07)E82D["B`@("`@("`@)')E<&]R=$)O>"T^<&%C:U]S=&%R="@D9'5M
M<%-C<F]L;"D["@H@("`@("`@(')E='5R;B`D<F5P;W)T0F]X.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E(&$@<W1A='5S(&QA8F5L+@H@("`@("H*
M("`@("`J($$@<W1A='5S(&QI;F4@870@=&AE(&)O='1O;2!O9B!T:&4@87!P
M;&EC871I;VX@:7,@=7-E9`H@("`@("H@=&\@;F]T:69Y('1H92!U<V5R(&]F
M(&YO;BUT97-T(')E;&%T960@;65S<V%G97,@<W5C:"!A<PH@("`@("H@9F%I
M;'5R97,@;&]A9&EN9R!A('1E<W0@<W5I=&4N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U
M<FX@)F]B:F5C="!4:&4@<W1A='5S(&QA8F5L+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F7V-R96%T95-T871U<TQI;F4H*0H@("`@>PH@("`@("`@("\O($-R
M96%T92!T:&4@<W1A='5S(&QA8F5L+@H@("`@("`@("1T:&ES+3YS=&%T=7-,
M:6YE(#TF(&YE=R!'=&M,86)E;"@G)RD["B`@("`@("`@)'1H:7,M/G-T871U
M<TQI;F4M/G-E=%]A;&EG;FUE;G0H,"P@,"D["@H@("`@("`@(')E='5R;B`D
M=&AI<RT^<W1A='5S3&EN93L*("`@('T*"B`@("`O*BH*("`@("`J(%-H;W<@
M82!P;W!U<"!W:71H(&EN9F]R;6%T:6]N(&%B;W5T('1H92!A<'!L:6-A=&EO
M;BX*("`@("`J"B`@("`@*B!4:&4@<&]P=7`@<VAO=6QD('-H;W<@:6YF;W)M
M871I;VX@86)O=70@=&AE('9E<G-I;VXL"B`@("`@*B!T:&4@875T:&]R+"!T
M:&4@;&EC96YS92P@=VAE<F4@=&\@9V5T('1H92!L871E<W0*("`@("`J('9E
M<G-I;VX@86YD(&$@<VAO<G0@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E
M='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*
M("`@("`@("`O+R!#<F5A=&4@=&AE(&YE=R!W:6YD;W<N"B`@("`@("`@)&%B
M;W5T(#TF(&YE=R!'=&M7:6YD;W<["B`@("`@("`@)&%B;W5T+3YS971?=&ET
M;&4H)T%B;W5T(%!(4%5N:70@1U5)($=T:R<I.PH@("`@("`@("1A8F]U="T^
M<V5T7W5S:7IE*#(U,"P@+3$I.PH*("`@("`@("`O+R!0=70@='=O('9B;WAE
M<R!I;B!T:&4@:&)O>"X*("`@("`@("`D=D)O>"`])B!N97<@1W1K5D)O>#L*
M("`@("`@("`D86)O=70M/F%D9"@D=D)O>"D["@H@("`@("`@("\O($-R96%T
M92!T:&4@;&%B96QS+@H@("`@("`@("1V97)S:6]N("`@("`])B!N97<@1W1K
M3&%B96PH(B!697)S:6]N.B`Q+C`B*3L*("`@("`@("`D;&EC96YS92`@("`@
M/28@;F5W($=T:TQA8F5L*"(@3&EC96YS93H@4$A0($QI8V5N<V4@=C,N,"(I
M.PH@("`@("`@("1W:&5R92`@("`@("`])B!N97<@1W1K3&%B96PH(B!$;W=N
M;&]A9"!F<F]M.B!H='1P.B\O<&5A<BYP:'`N;F5T+U!(4%5N:70O(BD["B`@
M("`@("`@)'5N:71!=71H("`@(#TF(&YE=R!'=&M,86)E;"@B(%!(4%5N:70@
M075T:&]R.B!396)A<W1I86X@0F5R9VUA;B(I.PH@("`@("`@("1G=&M!=71H
M("`@("`])B!N97<@1W1K3&%B96PH(B!'=&L@1U5)($%U=&AO<CH@4V-O='0@
M36%T=&]C:W,B*3L*"B`@("`@("`@+R\@06QI9VX@979E<GET:&EN9R!T;R!T
M:&4@;&5F=`H@("`@("`@("1W:&5R92T^<V5T7V%L:6=N;65N="@P+"`N-2D[
M"B`@("`@("`@)'9E<G-I;VXM/G-E=%]A;&EG;FUE;G0H,"P@+C4I.PH@("`@
M("`@("1L:6-E;G-E+3YS971?86QI9VYM96YT*#`L("XU*3L*("`@("`@("`D
M9W1K075T:"T^<V5T7V%L:6=N;65N="@P+"`N-2D["B`@("`@("`@)'5N:71!
M=71H+3YS971?86QI9VYM96YT*#`L("XU*3L*"B`@("`@("`@+R\@4&%C:R!E
M=F5R>71H:6YG(&EN=&\@=&AE('9";W@["B`@("`@("`@)'9";W@M/G!A8VM?
M<W1A<G0H)'9E<G-I;VXI.PH@("`@("`@("1V0F]X+3YP86-K7W-T87)T*"1L
M:6-E;G-E*3L*("`@("`@("`D=D)O>"T^<&%C:U]S=&%R="@D=VAE<F4I.PH@
M("`@("`@("1V0F]X+3YP86-K7W-T87)T*"1U;FET075T:"D["B`@("`@("`@
M)'9";W@M/G!A8VM?<W1A<G0H)&=T:T%U=&@I.PH*("`@("`@("`O+R!#;VYN
M96-T('1H92!D97-T<F]Y('-I9VYA;"X*("`@("`@("`D86)O=70M/F-O;FYE
M8W0H)V1E<W1R;WDG+"!A<G)A>2@G9W1K)RP@)W1R=64G*2D["@H@("`@("`@
M("\O(%-H;W<@=&AE(&=O;V1S+@H@("`@("`@("1A8F]U="T^<VAO=U]A;&PH
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO860@=&AE('1E<W0@<W5I=&4N
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@=')I97,@=&\@;&]A9"!T97-T
M('-U:71E(&)A<V5D(&]N('1H92!U<V5R"B`@("`@*B!I;F9O+B!)9B!T:&4@
M=7-E<B!P87-S97,@=&AE(&YA;64@;V8@82!T97-T<R!S=6ET92P@:70*("`@
M("`J(&ES(&EN<W1A;G1I871E9"!A;F0@82!N97<@;V)J96-T(&ES(')E='5R
M;F5D+B!)9B!T:&4*("`@("`J('5S97(@<&%S<V5S(&$@9FEL92!T:&%T(&-O
M;G1A:6YS(&$@=&5S="!S=6ET92P@=&AE(&-L87-S"B`@("`@*B!I<R!I;G-T
M86YT:6%T960@86YD(&$@;F5W(&]B:F5C="!I<R!R971U<FYE9"X@268@=&AE
M('5S97(*("`@("`J('!A<W-E<R!A(&9I;&4@=&AA="!C;VYT86EN<R!A('1E
M<W0@8V%S92P@=&AE('1E<W0@8V%S92!I<PH@("`@("H@<&%S<V5D('1O(&$@
M;F5W('1E<W0@<W5I=&4@86YD('1H92!N97<@<W5I=&4@;V)J96-T(&ES"B`@
M("`@*B!R971U<FYE9"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'!A<F%M("!S=')I;F<@(%1H92!F:6QE('1H870@8V]N=&%I;G,@
M82!T97-T(&-A<V4O<W5I=&4@;W(@=&AE(&-L87-S;F%M92X*("`@("`J($!R
M971U<FX@)F]B:F5C="!4:&4@;F5W('1E<W0@<W5I=&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9L;V%D5&5S="@F)&9I;&4I"B`@("!["B`@("`@("`@+R\@
M0VAE8VL@=&\@<V5E(&EF(&$@8VQA<W,@;F%M92!W87,@9VEV96XN"B`@("`@
M("`@:68@*&ES7V$H)&9I;&4L("=02%!5;FET7U1E<W13=6ET92<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D9FEL93L*("`@("`@("!](&5L<V5I9B`H8VQA
M<W-?97AI<W1S*"1F:6QE*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!(4%5N:70O5&5S=%-U:71E+G!H<"<["B`@("`@("`@("`@(')E='5R;B!N
M97<@4$A056YI=%]497-T4W5I=&4H)&9I;&4I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@0VAE8VL@=&AA="!T:&4@9FEL92!E>&ES=',N"B`@("`@("`@:68@
M*"%`:7-?<F5A9&%B;&4H)&9I;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<VAO=U-T871U<R@G0V%N;F]T(&9I;F0@9FEL93H@)R`N("1F:6QE*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]S:&]W4W1A='5S*"=,;V%D:6YG('1E<W0@<W5I=&4N+BXG*3L*"B`@
M("`@("`@+R\@26YS=&%N=&EA=&4@=&AE(&-L87-S+@H@("`@("`@("\O($EF
M('1H92!P871H(&ES("]P871H+W1O+W1E<W0O5&5S=$-L87-S+G!H<`H@("`@
M("`@("\O('1H92!C;&%S<R!N86UE('-H;W5L9"!B92!T97-T7U1E<W1#;&%S
M<PH@("`@("`@(')E<75I<F5?;VYC92`D9FEL93L*("`@("`@("`D8VQA<W-.
M86UE(#T@<W1R7W)E<&QA8V4H1$E214-43U)97U-%4$%2051/4BP@)U\G+"`D
M9FEL92D["B`@("`@("`@)&-L87-S3F%M92`]('-U8G-T<B@D8VQA<W-.86UE
M+"`P+"!S=')P;W,H)&-L87-S3F%M92P@)RXG*2D["@H@("`@("`@(')E<75I
M<F5?;VYC92`G4$A056YI="]497-T4W5I=&4N<&AP)SL*("`@("`@("!R971U
M<FX@;F5W(%!(4%5N:71?5&5S=%-U:71E*"1C;&%S<TYA;64I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4G5N('1H92!T97-T('-U:71E+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(')U;G,@=&AE('1E<W0@<W5I=&4@86YD('5P9&%T
M97,@=&AE(&UE<W-A9V5S"B`@("`@*B!F;W(@=&AE('5S97(N(%=H96X@9FEN
M:7-H960@:70@8VAA;F=E<R!T:&4@<W1A='5S(&QI;F4*("`@("`J('1O("=4
M97-T($-O;7!L971E)PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!R=6Y497-T*"D*("`@('L*("`@("`@("`O+R!.;W1I
M9GD@=&AE('5S97(@=&AA="!T:&4@=&5S="!I<R!R=6YN:6YG+@H@("`@("`@
M("1T:&ES+3Y?<VAO=U-T871U<R@G4G5N;FEN9R!497-T+BXN)RD["@H@("`@
M("`@("\O(%)U;B!T:&4@=&5S="X*("`@("`@("`D<F5S=6QT(#T@4$A056YI
M=#HZ<G5N*"1T:&ES+3YS=6ET92D["@H@("`@("`@("\O(%5P9&%T92!T:&4@
M;&%B96QS+@H@("`@("`@("1T:&ES+3Y?<V5T3&%B96Q686QU92@D=&AI<RT^
M;G5M8F5R3V92=6YS+"`@("`@)')E<W5L="T^<G5N0V]U;G0H*2D["B`@("`@
M("`@)'1H:7,M/E]S971,86)E;%9A;'5E*"1T:&ES+3YN=6UB97)/9D5R<F]R
M<RP@("`D<F5S=6QT+3YE<G)O<D-O=6YT*"DI.PH@("`@("`@("1T:&ES+3Y?
M<V5T3&%B96Q686QU92@D=&AI<RT^;G5M8F5R3V9&86EL=7)E<RP@)')E<W5L
M="T^9F%I;'5R94-O=6YT*"DI.PH*("`@("`@("`O+R!5<&1A=&4@=&AE('!R
M;V=R97-S(&)A<BX*("`@("`@("`D=&AI<RT^7W5P9&%T95!R;V=R97-S*"1R
M97-U;'0M/G)U;D-O=6YT*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT+3YE<G)O<D-O=6YT*"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT+3YF86EL=7)E0V]U;G0H*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@+R\@4VAO=R!T
M:&4@97)R;W)S+@H@("`@("`@("1T:&ES+3Y?<VAO=T9A:6QU<F5S*"1R97-U
M;'0M/F5R<F]R<R@I+"`D=&AI<RT^9'5M<$%R96$I.PH*("`@("`@("`O+R!3
M:&]W('1H92!M97-S86=E<R!F<F]M('1H92!T97-T<RX*("`@("`@("!I9B`H
M)'1H:7,M/G-H;W=087-S960M/F=E=%]A8W1I=F4H*2D@>PH@("`@("`@("`@
M("`O+R!3:&]W(&9A:6QU<F5S(&%N9"!S=6-C97-S+@H@("`@("`@("`@("`D
M=&AI<RT^7W-H;W=!;&PH)')E<W5L="P@)'1H:7,M/G)E<&]R=$%R96$I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%-H;W<@;VYL>2!F86EL
M=7)E<RX*("`@("`@("`@("`@)'1H:7,M/E]S:&]W1F%I;'5R97,H)')E<W5L
M="T^9F%I;'5R97,H*2P@)'1H:7,M/G)E<&]R=$%R96$I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@57!D871E('1H92!S=&%T=7,@;65S<V%G92X*("`@("`@
M("`D=&AI<RT^7W-H;W=3=&%T=7,H)U1E<W0@8V]M<&QE=&4G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E="!T:&4@=&5X="!O9B!A(&QA8F5L+@H@("`@
M("H*("`@("`J($-H86YG92!T:&4@=&5X="!O9B!A(&=I=F5N(&QA8F5L+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!W
M:61G970@("8D;&%B96P@5&AE(&QA8F5L('=H;W-E('9A;'5E(&ES('1O(&)E
M(&-H86YG960N"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)'9A;'5E("!4:&4@
M;F5W('1E>'0@;V8@=&AE(&QA8F5L+@H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]S971,86)E;%9A;'5E*"8D;&%B96PL("1V
M86QU92D*("`@('L*("`@("`@("`D;&%B96PM/G-E=%]T97AT*"1V86QU92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@;6%I;B!W;W)K(&]F('1H92!A
M<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!,;V%D('1H92!T97-T('-U:71E
M(&%N9"!T:&5N(&5X96-U=&4@=&AE('1E<W1S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U
M<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!R=6XH*0H@("`@>PH@("`@
M("`@("\O($QO860@=&AE('1E<W0@<W5I=&4N"B`@("`@("`@)'1H:7,M/G-U
M:71E(#TF("1T:&ES+3YL;V%D5&5S="@D=&AI<RT^<W5I=&5&:65L9"T^9V5T
M7W1E>'0H*2D["@H@("`@("`@("\O($-H96-K('1O(&UA:V4@<W5R92!T:&4@
M<W5I=&4@=V%S(&QO861E9"!P<F]P97)L>2X*("`@("`@("!I9B`H(6ES7V]B
M:F5C="@D=&AI<RT^<W5I=&4I*2!["B`@("`@("`@("`@("\O(%)A:7-E(&%N
M(&5R<F]R+@H@("`@("`@("`@("`D=&AI<RT^7W-H;W=3=&%T=7,H)T-O=6QD
M(&YO="!L;V%D('1E<W0@<W5I=&4N)RD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("\O(%)U;B!T:&4@=&5S=',N"B`@
M("`@("`@)'1H:7,M/G)U;E1E<W0H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%5P9&%T92!T:&4@<W1A='5S(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)'-T871U<R!4
M:&4@;F5W(&UE<W-A9V4N"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-H;W=3=&%T=7,H)'-T871U<RD*("`@('L*("`@("`@
M("`D=&AI<RT^<W1A='5S3&EN92T^<V5T7W1E>'0H)'-T871U<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!;&EA<R!F;W(@;6%I;B@I"B`@("`@*@H@("`@
M("H@0'-E92!M86EN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H;W<H)'-H;W=0
M87-S960@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3YM86EN*"1S:&]W
M4&%S<V5D*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-U:71E('1O
M('1H92!T97-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!R97%U
M:7)E(&)Y(%-E='5P1&5C;W)A=&]R+B!)="!A9&1S(&$*("`@("`J('-U:71E
M('1O('1H92!T:&4@8W5R<F5N="!S970@;V8@<W5I=&5S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@(&]B:F5C="`D=&5S
M=%-U:71E(%1H92!S=6ET92!T;R!A9&0N"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D4W5I=&5S*"1T97-T4W5I=&4I"B`@
M("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D=&5S=%-U:71E*2D@>PH@("`@
M("`@("`@("!S971T>7!E*"1T97-T4W5I=&4L("=A<G)A>2<I.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)'1E<W13=6ET92!A<R`D<W5I=&4I('L*
M"B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3YS=6ET92P@)U!(4%5N:71?
M5&5S=%-U:71E)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=6ET92T^
M861D5&5S=%-U:71E*"1S=6ET92T^9V5T3F%M92@I*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=6ET92`])B`D=&AI
M<RT^;&]A9%1E<W0H)'-U:71E*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@4V5T('1H92!S=6ET92!F:65L9"X*("`@("`@("`@("`@)'1E>'0@
M/2`D=&AI<RT^<W5I=&5&:65L9"T^9V5T7W1E>'0H*3L*("`@("`@("`@("`@
M:68@*&5M<'1Y*"1T97AT*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-U
M:71E1FEE;&0M/G-E=%]T97AT*"1T:&ES+3YS=6ET92T^9V5T3F%M92@I*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-H;W<@86QL('1E<W0@;65S<V%G97,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&]B:F5C="`@5&AE(%1E<W1297-U
M;'0@9G)O;2!T:&4@=&5S="!S=6ET92X*("`@("`J($!R971U<FX@=F]I9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<VAO=T%L;"@F)')E<W5L="D*("`@('L*
M("`@("`@("`O+R!#;&5A<B!T:&4@87)E82!F:7)S="X*("`@("`@("`D=&AI
M<RT^<F5P;W)T07)E82T^9&5L971E7W1E>'0H,"P@+3$I.PH@("`@("`@("1T
M:&ES+3YR97!O<G1!<F5A+3YI;G-E<G1?=&5X="@D<F5S=6QT+3YT;U-T<FEN
M9R@I+"`P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-H;W<@9F%I;'5R92]E
M<G)O<B!M97-S86=E<R!I;B!T:&4@9VEV96X@=&5X="!A<F5A+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!O8FIE8W0@
M("8D<F5S=6QT<R!4:&4@<F5S=6QT<R!O9B!T:&4@=&5S="X*("`@("`J($!P
M87)A;2`@=VED9V5T("`F)&%R96$@("`@5&AE(&%R96$@=&\@<VAO=R!T:&4@
M<F5S=6QT<R!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-H;W=&86EL=7)E
M<R@F)')E<W5L=',L("8D87)E82D*("`@('L*("`@("`@("`D87)E82T^9&5L
M971E7W1E>'0H,"P@+3$I.PH@("`@("`@(&9O<F5A8V@@*&%R<F%Y7W)E=F5R
M<V4H)')E<W5L=',L('1R=64I(&%S("1R97-U;'0I('L*("`@("`@("`@("`@
M)&%R96$M/FEN<V5R=%]T97AT*"1R97-U;'0M/G1O4W1R:6YG*"DL(#`I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!T:&4@<')O
M9W)E<W,@:6YD:6-A=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'!A<F%M("!I;G1E9V5R("1R=6YS"B`@("`@*B!`<&%R86T@
M(&EN=&5G97(@)&5R<F]R<PH@("`@("H@0'!A<F%M("!I;G1E9V5R("1F86EL
M=7)E<PH@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]U<&1A=&50<F]G<F5S<R@D<G5N<RP@)&5R<F]R<RP@)&9A:6QU<F5S*0H@
M("`@>PH@("`@("`@("1P97)C96YT86=E(#T@,2`M("@H)&5R<F]R<R`K("1F
M86EL=7)E<RD@+R`D<G5N<RD["B`@("`@("`@)'1H:7,M/G!R;V=R97-S+3YS
M971?<&5R8V5N=&%G92@D<&5R8V5N=&%G92D["B`@("!]"GT*"B\J"B`J($QO
M8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F
M<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%
M;F0Z"B`J+PH_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="]297!E871E9%1E<W0N
M<&AP````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`V,C(`,3`U,34T
M,S$P-3<`,#(Q-S,S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0
M(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@
M*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A
M;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I
M=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D
M('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J
M"B`J("`@*B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R
M971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES
M(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I
M;65R+@H@*B`*("H@("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R
M;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N
M9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@
M(&1I<W1R:6)U=&EO;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@
M4V5B87-T:6%N($)E<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@
M("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M
M;W1E('!R;V1U8W1S(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R
M92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*
M("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))
M1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!
M3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@
M0E54($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453
M($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)4
M24-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(
M04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%
M($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y4
M04PL(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!
M1T53("A)3D-,541)3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]3
M4R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$52
M4E505$E/3BD@2$]7159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@
M3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,
M24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]4
M2$525TE312D@05))4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%
M($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@
M4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@
M(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@
M("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N
M;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)E
M<&5A=&5D5&5S="YP:'`L=B`Q+C$S(#(P,#4O,3$O,3`@,#DZ-#<Z,30@<V5B
M87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"@IR97%U:7)E7V]N8V4@)U!(
M4%5N:70O5&5S=$1E8V]R871O<BYP:'`G.PH*+RHJ"B`J($$@1&5C;W)A=&]R
M('1H870@<G5N<R!A('1E<W0@<F5P96%T961L>2X*("H*("H@2&5R92!I<R!A
M;B!E>&%M<&QE.@H@*@H@*B`\8V]D93X*("H@/#]P:'`*("H@<F5Q=6ER95]O
M;F-E("=02%!5;FET+G!H<"<["B`J(')E<75I<F5?;VYC92`G4$A056YI="]2
M97!E871E9%1E<W0N<&AP)SL*("H*("H@8VQA<W,@36%T:%1E<W0@97AT96YD
M<R!02%!5;FET7U1E<W1#87-E('L*("H@("`@('9A<B`D9E9A;'5E,3L*("H@
M("`@('9A<B`D9E9A;'5E,CL*("H*("H@("`@(&9U;F-T:6]N($UA=&A497-T
M*"1N86UE*2!["B`J("`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$-A<V4H
M)&YA;64I.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@<V5T57`H*2![
M"B`J("`@("`@("`@)'1H:7,M/F9686QU93$@/2`R.PH@*B`@("`@("`@("1T
M:&ES+3YF5F%L=64R(#T@,SL*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N
M('1E<W1!9&0H*2!["B`J("`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H)'1H
M:7,M/F9686QU93$@*R`D=&AI<RT^9E9A;'5E,B`]/2`U*3L*("H@("`@('T*
M("H@?0H@*@H@*B`D<W5I=&4@/2!N97<@4$A056YI=%]497-T4W5I=&4["B`J
M"B`J("1S=6ET92T^861D5&5S="@*("H@("!N97<@4$A056YI=%]297!E871E
M9%1E<W0H"B`J("`@("!N97<@36%T:%1E<W0H)W1E<W1!9&0G*2P*("H@("`@
M(#$P"B`J("`@*0H@*B`I.PH@*@H@*B`D<F5S=6QT(#T@4$A056YI=#HZ<G5N
M*"1S=6ET92D["B`J('!R:6YT("1R97-U;'0M/G1O4W1R:6YG*"D["B`J(#\^
M"B`J(#PO8V]D93X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C
M:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT
M("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM
M8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O
M=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS
M90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@
M*B\*8VQA<W,@4$A056YI=%]297!E871E9%1E<W0@97AT96YD<R!02%!5;FET
M7U1E<W1$96-O<F%T;W(@>PH@("`@+RHJ"B`@("`@*B!`=F%R("`@(&EN=&5G
M97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T
M:6UE<U)E<&5A="`](#$["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M("!I
M;G1E9V5R"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!02%!5;FET7U)E<&5A=&5D5&5S="@F)'1E<W0L("1T:6UE<U)E<&5A
M="`](#$I('L*("`@("`@("`D=&AI<RT^4$A056YI=%]497-T1&5C;W)A=&]R
M*"1T97-T*3L*("`@("`@("`D=&AI<RT^7W1I;65S4F5P96%T(#T@)'1I;65S
M4F5P96%T.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]U;G1S('1H92!N=6UB
M97(@;V8@=&5S="!C87-E<R!T:&%T"B`@("`@*B!W:6QL(&)E(')U;B!B>2!T
M:&ES('1E<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=%1E
M<W1#87-E<R@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T:6UE<U)E<&5A
M="`J("1T:&ES+3Y?=&5S="T^8V]U;G1497-T0V%S97,H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)U;G,@=&AE(&1E8V]R871E9"!T97-T(&%N9"!C;VQL
M96-T<R!T:&4*("`@("`J(')E<W5L="!I;B!A(%1E<W1297-U;'0N"B`@("`@
M*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N*"8D
M<F5S=6QT*2!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M/E]T
M:6UE<U)E<&5A=#L@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^7W1E<W0M
M/G)U;B@D<F5S=6QT*3L*("`@("`@("!]"B`@("!]"GT*"B\J"B`J($QO8V%L
M('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T
M.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z
M"B`J+PH_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]02%!5;FET+U-K96QE=&]N+G!H<```````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#(P-0`Q,#4Q-30S,3`U-P`P,C$Q
M,S$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T
M"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H
M=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@
M<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M
M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@
M9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@
M*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P
M<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R
M(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T
M:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@
M0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U
M=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C
M=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3
M(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$52
M4R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3
M($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J
M($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%52
M4$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J
M($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/
M4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!3
M54)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@
M3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!
M4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E4
M62!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@
M*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-C;W1T($UA
M='1O8VMS(#QS8V]T=$!C<FES<V-O='0N8V]M/@H@*B!`8V]P>7)I9VAT("`R
M,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C
M92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4VME;&5T;VXN<&AP+'8@,2XX(#(P
M,#4O,3$O,3`@,#DZ-#<Z,30@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XQ+C`*
M("HO"@HO*BH*("H@0VQA<W,@9F]R(&-R96%T:6YG(&$@4$A056YI=%]497-T
M0V%S92!S:V5L971O;B!F:6QE+@H@*@H@*B!4:&ES(&-L87-S('=I;&P@=&%K
M92!A(&-L87-S;F%M92!A<R!A('!A<F%M971E<B!O;B!C;VYS=')U8W1I;VX@
M86YD('=I;&P*("H@8W)E871E(&$@4$A0(&9I;&4@=&AA="!C;VYT86EN<R!T
M:&4@<VME;&5T;VX@;V8@82!02%!5;FET7U1E<W1#87-E"B`J('-U8F-L87-S
M+B!4:&4@=&5S="!C87-E('=I;&P@8V]N=&%I;B!A('1E<W0@9F]R96%C:"!M
M971H;V0@;V8@=&AE(&-L87-S+@H@*B!-971H;V1S(&]F('1H92!P87)E;G0@
M8VQA<W,@=VEL;"P@8GD@9&5F875L="P@8F4@97AC;'5D960@9G)O;2!T:&4@
M=&5S=`H@*B!C;&%S<RX@4&%S<VEN9R!A;F0@;W!T:6]N86P@8V]N<W1R=6-T
M:6]N('!A<F%M971E<B!W:6QL(&EN8VQU9&4@=&AE;2X*("H*("H@17AA;7!L
M90H@*@H@*B`@(#P_<&AP"B`J("`@<F5Q=6ER95]O;F-E("=02%!5;FET+U-K
M96QE=&]N+G!H<"<["B`J("`@)'!S(#T@;F5W(%!(4%5N:71?4VME;&5T;VXH
M)U!(4%5N:71?4VME;&5T;VXG+"`G4$A056YI="]3:V5L971O;BYP:'`G*3L*
M("H*("H@("`O+R!'96YE<F%T92!T:&4@=&5S="!C;&%S<RX*("H@("`O+R!$
M969A=6QT('-E='1I;F=S('=I;&P@;F]T(&EN8VQU9&4@86YY('!A<F5N="!C
M;&%S<R!M971H;V1S+"!B=70*("H@("`O+R!W:6QL(&EN8VQU9&4@<')I=F%T
M92!M971H;V1S+@H@*B`@("1P<RT^8W)E871E5&5S=$-L87-S*"D["B`J"B`J
M("`@+R\@5W)I=&4@=&AE(&YE=R!T97-T(&-L87-S('1O(&9I;&4N"B`J("`@
M+R\@0GD@9&5F875L="P@8V]D92!T;R!R=6X@=&AE('1E<W0@=VEL;"!B92!I
M;F-L=61E9"X*("H@("`D<',M/G=R:71E5&5S=$-L87-S*"D["B`J("`@/SX*
M("H*("H@3F]W(&]P96X@=&AE('-K96QE=&]N(&-L87-S(&%N9"!F:6QL(&EN
M('1H92!D971A:6QS+@H@*B!)9B!Y;W4@<G5N('1H92!T97-T(&%S(&ES+"!A
M;&P@=&5S=',@=VEL;"!F86EL(&%N9`H@*B!Y;W4@=VEL;"!S964@<&QE;G1Y
M(&]F('5N9&5F:6YE9"!C;VYS=&%N="!E<G)O<G,N"B`J"B`J($!C871E9V]R
M>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R
M("`@("!38V]T="!-871T;V-K<R`\<V-O='1`8W)I<W-C;W1T+F-O;3X*("H@
M0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`
M<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@
M0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N
M:70*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XQ+C`*("HO"F-L87-S(%!(4%5N:71?4VME;&5T;VX@>PH@("`@+RHJ
M"B`@("`@*B!0871H('1O('1H92!C;&%S<R!F:6QE('1O(&-R96%T92!A('-K
M96QE=&]N(&9O<BX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D8VQA<W-0871H.PH*("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE
M(&-L87-S"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&-L
M87-S3F%M93L*"B`@("`O*BH*("`@("`J(%!A=&@@=&\@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92!N965D960@8GD@8VQA<W,@=&\@=&5S="X*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D8V]N9FEG1FEL93L*"B`@("`O
M*BH*("`@("`J(%=H971H97(@;W(@;F]T('1O(&EN8VQU9&4@=&AE(&UE=&AO
M9',@;V8@=&AE('!A<F5N="!C;&%S<R!W:&5N('1E<W1I;F<N"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1I;F-L=61E4&%R96YT<SL*
M"B`@("`O*BH*("`@("`J(%=H971H97(@;W(@;F]T('1O('1E<W0@<')I=F%T
M92!M971H;V1S+@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D:6YC;'5D95!R:79A=&4["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5S="!C
M;&%S<R!T:&%T('=I;&P@8F4@8W)E871E9"X*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D=&5S=$-L87-S.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N(%-E=',@=&AE(&-L87-S(&UE;6)E<G,@86YD(&-H96-K
M('1H870@=&AE(&-L87-S"B`@("`@*B!T;R!T97-T(&ES(&%C8V5S<VEB;&4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@
M<W1R:6YG("`D8VQA<W-.86UE"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&-L
M87-S4&%T:`H@("`@("H@0'!A<F%M("!B;V]L96%N("1I;F-L=61E4&%R96YT
M<R!7:&5T97(@=&\@:6YC;'5D92!T:&4@<&%R96YT)W,@;65T:&]D<R!I;B!T
M:&4@=&5S="X*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!02%!5;FET7U-K96QE=&]N*"1C;&%S<TYA;64L("1C;&%S<U!A=&@L
M("1I;F-L=61E4&%R96YT<R`]($9!3%-%+"`D:6YC;'5D95!R:79A=&4@/2!4
M4E5%*2!["B`@("`@("`@+R\@4V5T('5P('1H92!M96UB97)S+@H@("`@("`@
M(&EF("A`:7-?<F5A9&%B;&4H)&-L87-S4&%T:"DI('L*("`@("`@("`@("`@
M)'1H:7,M/F-L87-S3F%M92`]("1C;&%S<TYA;64["B`@("`@("`@("`@("1T
M:&ES+3YC;&%S<U!A=&@@/2`D8VQA<W-0871H.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?:&%N9&QE17)R;W)S*"1C;&%S<U!A=&@@
M+B`G(&ES(&YO="!R96%D86)L92X@0V%N;F]T(&-R96%T92!T97-T(&-L87-S
M+B<I.PH@("`@("`@('T*"B`@("`@("`@+R\@1&\@=V4@=V%N="!T;R!I;F-L
M=61E('!A<F5N="!M971H;V1S/PH@("`@("`@("1T:&ES+3YI;F-L=61E4&%R
M96YT<R`]("1I;F-L=61E4&%R96YT<SL*"B`@("`@("`@+R\@1&\@=V4@=V%N
M="!T;R!A;&QO=R!P<FEV871E(&UE=&AO9',_"B`@("`@("`@)'1H:7,M/FEN
M8VQU9&50<FEV871E(#T@)&EN8VQU9&50<FEV871E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5&AE(&-L87-S('1O('1E<W0@;6%Y(')E<75I<F4@82!S<&5C
M:6%L(&-O;F9I9R!F:6QE(&)E9F]R92!I="!C86X@8F4*("`@("`J(&EN<W1A
M;G1I871E9"X@5&AI<R!M971H;V0@;&5T<R!Y;W4@<V5T('1H870@9FEL92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!S
M=')I;F<@)&-O;F9I9U!A=&@*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971#;VYF:6=&:6QE*"1C;VYF:6=&:6QE*2!["B`@
M("`@("`@+R\@0VAE8VL@=&AA="!T:&4@9FEL92!I<R!R96%D86)L90H@("`@
M("`@(&EF("A`:7-?<F5A9&%B;&4H)&-O;F9I9T9I;&4I*2!["B`@("`@("`@
M("`@("1T:&ES+3YC;VYF:6=&:6QE(#T@)&-O;F9I9T9I;&4["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]H86YD;&5%<G)O<G,H)&-O
M;F9I9T9I;&4@+B`G(&ES(&YO="!R96%D86)L92X@0V%N;F]T(&-R96%T92!T
M97-T(&-L87-S+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-R96%T92!T:&4@8V]D92!T:&%T('=I;&P@8F4@=&AE('-K96QE=&]N(&]F
M('1H92!T97-T(&-A<V4N"B`@("`@*@H@("`@("H@5&AE('1E<W0@8V%S92!M
M=7-T(&AA=F4@82!C;'-S(&1E9FEN:71I;VXL(&]N92!V87(L(&$@8V]N<W1R
M=6-T;W(*("`@("`J('-E=%5P+"!T96%R1&]W;BP@86YD(&UE=&AO9',N($]P
M=&EO;F%L;'D@86YD(&)Y(&1E9F%U;'0@=&AE(&-O9&4*("`@("`J('1O(')U
M;B!T:&4@=&5S="!I<R!A9&1E9"!W:&5N('1H92!C;&%S<R!I<R!W<FET=&5N
M('1O(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-R96%T951E<W1#;&%S<R@I('L*("`@("`@("`O+R!);G-T
M86YT:6%T92!T:&4@;V)J96-T+@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M8V]N9FEG1FEL92DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1T:&ES
M+3YC;VYF:6=&:6QE.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M("1T:&ES+3YC;&%S<U!A=&@["@H@("`@("`@("\O($=E="!T:&4@;65T:&]D
M<RX*("`@("`@("`D8VQA<W--971H;V1S(#T@9V5T7V-L87-S7VUE=&AO9',H
M)'1H:7,M/F-L87-S3F%M92D["@H@("`@("`@("\O(%)E;6]V92!T:&4@<&%R
M96YT(&UE=&AO9',@:68@;F5E9&5D+@H@("`@("`@(&EF("@A)'1H:7,M/FEN
M8VQU9&5087)E;G1S*2!["B`@("`@("`@("`@("1P87)E;G1-971H;V1S(#T@
M9V5T7V-L87-S7VUE=&AO9',H9V5T7W!A<F5N=%]C;&%S<R@D=&AI<RT^8VQA
M<W-.86UE*2D["@H@("`@("`@("`@("!I9B`H8V]U;G0H)'!A<F5N=$UE=&AO
M9',I*2!["B`@("`@("`@("`@("`@("`D8VQA<W--971H;V1S(#T@87)R87E?
M9&EF9B@D8VQA<W--971H;V1S+"`D<&%R96YT365T:&]D<RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!T:&4@8VQA<W,@
M9&5F:6YI=&EO;BP@8V]N<W1R=6-T;W(L('-E=%5P(&%N9"!T96%R1&]W;BX*
M("`@("`@("`D=&AI<RT^7V-R96%T941E9FEN:71I;VXH*3L*("`@("`@("`D
M=&AI<RT^7V-R96%T94-O;G-T<G5C=&]R*"D["B`@("`@("`@)'1H:7,M/E]C
M<F5A=&539715<%1E87)$;W=N*"D["@H@("`@("`@(&EF("AC;W5N="@D8VQA
M<W--971H;V1S*2D@>PH@("`@("`@("`@("`O+R!&;W)E86-H(&UE=&AO9"!C
M<F5A=&4@82!T97-T(&-A<V4N"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;&%S
M<TUE=&AO9',@87,@)&UE=&AO9"D@>PH@("`@("`@("`@("`@("`@+R\@56YL
M97-S(&ET(&ES('1H92!C;VYS=')U8W1O<BX*("`@("`@("`@("`@("`@(&EF
M("AS=')C87-E8VUP*"1T:&ES+3YC;&%S<TYA;64L("1M971H;V0I("$]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("\O($-H96-K(&9O<B!P<FEV871E(&UE
M=&AO9',N"B`@("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN8VQU9&50
M<FEV871E("8F('-T<G!O<R@D;65T:&]D+"`G7R<I(#T]/2`P*2!["B`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W)E871E
M365T:&]D*"1M971H;V0I.PH@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M($9I;FES(&]F9B!T:&4@8VQA<W,N"B`@("`@("`@)'1H:7,M/E]F:6YI<VA#
M;&%S<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!C;&%S
M<R!D969I;FET:6]N+@H@("`@("H*("`@("`J(%1H92!D969I;FET:6]N(&-O
M;G-I<W0@;V8@82!H96%D97(@8V]M;65N="P@<F5Q=6ER92!S=&%T;65N=`H@
M("`@("H@9F]R(&=E='1I;F<@=&AE(%!(4%5N:70@9FEL92P@=&AE(&%C='5A
M;"!C;&%S<R!D969I;FET:6]N+`H@("`@("H@86YD('1H92!D969I;FET:6]N
M(&]F('1H92!C;&%S<R!M96UB97(@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@
M06QL(&]F('1H92!C;V1E(&YE961E9"!F;W(@=&AE(&YE=R!C;&%S<R!I<R!S
M=&]R960@:6X@=&AE"B`@("`@*B!T97-T0VQA<W,@;65M8F5R+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!N;VYE"B`@
M("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T
M941E9FEN:71I;VXH*2!["B`@("`@("`@+R\@0W)E871E(&AE861E<B!C;VUM
M96YT+@H@("`@("`@("1T:&ES+3YT97-T0VQA<W,@/0H@("`@("`@("`@(B\J
M*EQN(B`N"B`@("`@("`@("`B("H@4$A056YI="!T97-T(&-A<V4@9F]R("(@
M+B`D=&AI<RT^8VQA<W-.86UE("X@(EQN(B`N"B`@("`@("`@("`B("H@7&XB
M("X*("`@("`@("`@("(@*B!4:&4@;65T:&]D('-K96QE=&]N<R!B96QO=R!N
M965D('1O(&)E(&9I;&QE9"!I;B!W:71H(%QN(B`N"B`@("`@("`@("`B("H@
M<F5A;"!D871A('-O('1H870@=&AE('1E<W1S('=I;&P@<G5N(&-O<G)E8W1L
M>2X@4F5P;&%C92!<;B(@+@H@("`@("`@("`@(B`J(&%L;"!%6%!%0U1%1%]6
M04P@86YD(%!!4D%-('-T<FEN9W,@=VET:"!R96%L(&1A=&$N(%QN(B`N"B`@
M("`@("`@("`B("H@7&XB("X*("`@("`@("`@("(@*B!#<F5A=&5D('=I=&@@
M4$A056YI=%]3:V5L971O;B!O;B`B("X@9&%T92@G62UM+60G*2`N(")<;B(@
M+@H@("`@("`@("`@(B`J+UQN(CL*"B`@("`@("`@+R\@061D('1H92!R97%U
M:7)E('-T871E;65N=',N"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S<R`N/2`B
M<F5Q=6ER95]O;F-E("=02%!5;FET+G!H<"<[7&XB.PH*("`@("`@("`O+R!!
M9&0@=&AE(&-L87-S(&1E9FEN:71I;VX@86YD('9A<FEA8FQE(&1E9FEN:71I
M;VXN"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S<R`N/0H@("`@("`@("`@(F-L
M87-S("(@+B`D=&AI<RT^8VQA<W-.86UE("X@(E1E<W0@97AT96YD<R!02%!5
M;FET7U1E<W1#87-E('M<;EQN(B`N"B`@("`@("`@("`B("`@('9A<B!<)"(@
M+B`D=&AI<RT^8VQA<W-.86UE("X@(CM<;EQN(CL*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T92!T:&4@8VQA<W,@8V]N<W1R=6-T;W(N("A02%`T('-T
M>6QE*0H@("`@("H*("`@("`J(%1H92!C;VYS=')U8W1O<B!S:6UP;'D@8V%L
M;',@=&AE(%!(4%5N:71?5&5S=$-A<V4@;65T:&]D+@H@("`@("H@5&AI<R!C
M;V1E(&ES('1A:V5N(&9R;VT@=&AE(%!(4%5N:70@9&]C=6UE;G1A=&EO;BX*
M("`@("`J"B`@("`@*B!!;&P@;V8@=&AE(&-O9&4@;F5E9&5D(&9O<B!T:&4@
M;F5W(&-L87-S(&ES('-T;W)E9"!I;B!T:&4*("`@("`J('1E<W1#;&%S<R!M
M96UB97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8W)E871E0V]N<W1R=6-T;W(H*2!["B`@("`@("`@+R\@0W)E
M871E('1H92!T97-T(&-L87-S(&-O;G-T<G5C=&]R+@H@("`@("`@("1T:&ES
M+3YT97-T0VQA<W,N/0H@("`@("`@("`@(B`@("!F=6YC=&EO;B`B("X@)'1H
M:7,M/F-L87-S3F%M92`N(")497-T*%PD;F%M92E<;B(@+@H@("`@("`@("`@
M(B`@("![7&XB("X*("`@("`@("`@("(@("`@("`@(%PD=&AI<RT^4$A056YI
M=%]497-T0V%S92A<)&YA;64I.UQN(B`N"B`@("`@("`@("`B("`@('U<;EQN
M(CL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!S9715<"!A;F0@=&5A
M<D1O=VX@;65T:&]D<RX*("`@("`J"B`@("`@*B!4:&4@<V5T57`@;65T:&]D
M(&-R96%T97,@=&AE(&EN<W1A;F-E(&]F('1H92!O8FIE8W0@=&\@=&5S="X*
M("`@("`J(%1H92!T96%R1&]W;B!M971H;V0@<F5L96%S97,@=&AE(&EN<W1A
M;F-E+@H@("`@("H@5&AI<R!C;V1E(&ES('1A:V5N(&9R;VT@=&AE(%!(4%5N
M:70@9&]C=6UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!!;&P@;V8@=&AE(&-O
M9&4@;F5E9&5D(&9O<B!T:&4@;F5W(&-L87-S(&ES('-T;W)E9"!I;B!T:&4*
M("`@("`J('1E<W1#;&%S<R!M96UB97(N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E4V5T57!496%R1&]W
M;B@I('L*("`@("`@("`O+R!#<F5A=&4@=&AE('-E=%5P(&UE=&AO9"X*("`@
M("`@("`D=&AI<RT^=&5S=$-L87-S("X]"B`@("`@("`@("`B("`@(&9U;F-T
M:6]N('-E=%5P*"E<;B(@+@H@("`@("`@("`@(B`@("![7&XB.PH*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9T9I;&4I*2!["B`@("`@("`@("`@
M("1T:&ES+3YT97-T0VQA<W,@+CT*("`@("`@("`@("`@(B`@("`@("`@<F5Q
M=6ER95]O;F-E("<B("X@)'1H:7,M/F-O;F9I9T9I;&4@+B`B)SM<;B(["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^=&5S=$-L87-S("X]"B`@("`@("`@
M("`B("`@("`@("!R97%U:7)E7V]N8V4@)R(@+B`D=&AI<RT^8VQA<W-0871H
M("X@(B<[7&XB("X*("`@("`@("`@("(@("`@("`@(%PD=&AI<RT^(B`N("1T
M:&ES+3YC;&%S<TYA;64@+B`B(#TF(&YE=R`B("X@)'1H:7,M/F-L87-S3F%M
M92`N("(H4$%204TI.UQN(B`N"B`@("`@("`@("`B("`@('U<;EQN(CL*"B`@
M("`@("`@+R\@0W)E871E('1H92!T96%R1&]W;B!M971H;V0N"B`@("`@("`@
M)'1H:7,M/G1E<W1#;&%S<R`N/0H@("`@("`@("`@(B`@("!F=6YC=&EO;B!T
M96%R1&]W;B@I7&XB("X*("`@("`@("`@("(@("`@>UQN(B`N"B`@("`@("`@
M("`B("`@("`@("!U;G-E="A<)'1H:7,M/B(@+B`D=&AI<RT^8VQA<W-.86UE
M("X@(BD[7&XB("X*("`@("`@("`@("(@("`@?5QN7&XB.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E(&$@8F%S:6,@<VME;&5T;VX@9F]R('1E<W0@
M;65T:&]D<RX*("`@("`J"B`@("`@*B!4:&ES(&-O9&4@:7,@=&%K96X@9G)O
M;2!T:&4@4$A056YI="!D;V-U;65N=&%T:6]N+@H@("`@("H*("`@("`J($%L
M;"!O9B!T:&4@8V]D92!N965D960@9F]R('1H92!N97<@8VQA<W,@:7,@<W1O
M<F5D(&EN('1H90H@("`@("H@=&5S=$-L87-S(&UE;6)E<BX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@
M("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5-
M971H;V0H)&UE=&AO9$YA;64I('L*("`@("`@("`O+R!#<F5A=&4@82!T97-T
M(&UE=&AO9"X*("`@("`@("`D=&AI<RT^=&5S=$-L87-S("X]"B`@("`@("`@
M("`B("`@(&9U;F-T:6]N('1E<W0B("X@)&UE=&AO9$YA;64@+B`B*"E<;B(@
M+@H@("`@("`@("`@(B`@("![7&XB("X*("`@("`@("`@("(@("`@("`@(%PD
M<F5S=6QT("`@/2!<)'1H:7,M/B(@+B`D=&AI<RT^8VQA<W-.86UE("X@(BT^
M(B`N("1M971H;V1.86UE("X@(BA005)!32D[7&XB("X*("`@("`@("`@("(@
M("`@("`@(%PD97AP96-T960@/2!%6%!%0U1%1%]604P[7&XB("X*("`@("`@
M("`@("(@("`@("`@(%PD=&AI<RT^87-S97)T17%U86QS*%PD97AP96-T960L
M(%PD<F5S=6QT*3M<;B(@+@H@("`@("`@("`@(B`@("!]7&Y<;B(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&0@=&AE(&-L;W-I;F<@8G)A8V4@;F5E9&5D
M(&9O<B!A('!R;W!E<B!C;&%S<R!D969I;FET:6]N+@H@("`@("H*("`@("`J
M($%L;"!O9B!T:&4@8V]D92!N965D960@9F]R('1H92!N97<@8VQA<W,@:7,@
M<W1O<F5D(&EN('1H90H@("`@("H@=&5S=$-L87-S(&UE;6)E<BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F:6YI
M<VA#;&%S<R@I('L*("`@("`@("`O+R!#;&]S92!O9F8@=&AE(&-L87-S+@H@
M("`@("`@("1T:&ES+3YT97-T0VQA<W,N/2`B?5QN(CL*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T92!T:&4@8V]D92!T:&%T('=I;&P@86-T=6%L;'D@
M<G5N('1H92!T97-T+@H@("`@("H*("`@("`J(%1H:7,@8V]D92!I<R!A9&1E
M9"!B>2!D969A=6QT('-O('1H870@=&AE('1E<W0@8V%N(&)E(')U;@H@("`@
M("H@:G5S="!B>2!R=6YN:6YG('1H92!F:6QE+B!4;R!H879E(&ET(&YO="!A
M9&1E9"!P87-S(&9A;'-E"B`@("`@*B!A<R!T:&4@<V5C;VYD('!A<F%M971E
M<B!T;R!T:&4@=W)I=&5497-T0VQA<W,@;65T:&]D+@H@("`@("H@5&AI<R!C
M;V1E(&ES('1A:V5N(&9R;VT@=&AE(%!(4%5N:70@9&]C=6UE;G1A=&EO;BX*
M("`@("`J"B`@("`@*B!!;&P@;V8@=&AE(&-O9&4@;F5E9&5D(&9O<B!T:&4@
M;F5W(&-L87-S(&ES('-T;W)E9"!I;B!T:&4*("`@("`J('1E<W1#;&%S<R!M
M96UB97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8W)E871E5&5S="@I('L*("`@("`@("`O+R!#<F5A=&4@82!C
M86QL('1O('1H92!T97-T+@H@("`@("`@("1T97-T(#T*("`@("`@("`@("(O
M+R!2=6YN:6YG('1H92!T97-T+EQN(B`N"B`@("`@("`@("`B7"1S=6ET92`@
M/2!N97<@4$A056YI=%]497-T4W5I=&4H)R(@+B`D=&AI<RT^8VQA<W-.86UE
M("X@(E1E<W0G*3M<;B(@+@H@("`@("`@("`@(EPD<F5S=6QT(#T@4$A056YI
M=#HZ<G5N*%PD<W5I=&4I.UQN(B`N"B`@("`@("`@("`B96-H;R!<)')E<W5L
M="T^=&]3=')I;F<H*3M<;B(["@H@("`@("`@(')E='5R;B`D=&5S=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%=R:71E('1H92!T97-T(&-L87-S('1O(&9I
M;&4N"B`@("`@*@H@("`@("H@5&AI<R!W:6QL('=R:71E('1H92!T97-T(&-L
M87-S(&-R96%T960@=7-I;F<@=&AE(&-R96%T951E<W1#;&%S<PH@("`@("H@
M;65T:&]D('1O(&$@9FEL92!C86QL960@/&-L87-S3F%M93Y497-T+G!H<"X@
M0GD@9&5F875L="!T:&4@9FEL90H@("`@("H@:7,@=W)I='1E;B!T;R!T:&4@
M8W5R<F5N="!D:7)E8W1O<GD@86YD('=I;&P@:&%V92!C;V1E('1O(')U;@H@
M("`@("H@=&AE('1E<W0@87!P96YD960@=&\@=&AE(&)O='1O;2!O9B!T:&4@
M9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A
M<F%M("!S=')I;F<@("1D97-T:6YA=&EO;B!4:&4@9&ER96-T;W)Y('1O('=R
M:71E('1H92!F:6QE('1O+@H@("`@("H@0'!A<F%M("!B;V]L96%N("1A9&14
M97-T("`@("!7:&5T97(@=&\@861D('1H92!T97-T(')U;FYI;F<@8V]D92X*
M("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M951E<W1#;&%S<R@D9&5S=&EN871I;VX@/2`G+B\G+"`D861D5&5S="`](%12
M544I('L*("`@("`@("`O+R!#:&5C:R!F;W(@<V]M971H:6YG('1O('=R:71E
M('1O(&9I;&4N"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=&5S=$-L87-S
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAA;F1L945R<F]R<R@G3F]T:6YG
M('1O('=R:71E+B<L(%!(4%537U=!4DY)3D<I.PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`O+R!/<&5N('1H92!D97-T:6YA=&EO
M;B!F:6QE+@H@("`@("`@("1F<"`](&9O<&5N*"1D97-T:6YA=&EO;B`N("1T
M:&ES+3YC;&%S<TYA;64@+B`G5&5S="YP:'`G+"`G=R<I.PH@("`@("`@(&9W
M<FET92@D9G`L("(\/W!H<%QN(BD["@H@("`@("`@("\O(%=R:71E('1H92!T
M97-T(&-L87-S+@H@("`@("`@(&9W<FET92@D9G`L("1T:&ES+3YT97-T0VQA
M<W,I.PH*("`@("`@("`O+R!!9&0@=&AE(&-A;&P@=&\@=&5S="!T:&4@8VQA
M<W,@:6X@=&AE(&9I;&4@:68@=V4@=V5R92!A<VME9"!T;RX*("`@("`@("!I
M9B`H)&%D9%1E<W0I('L*("`@("`@("`@("`@9G=R:71E*"1F<"P@)'1H:7,M
M/E]C<F5A=&5497-T*"DI.PH@("`@("`@('T*"B`@("`@("`@+R\@0VQO<V4@
M=&AE(&9I;&4N"B`@("`@("`@9G=R:71E*"1F<"P@(C\^7&XB*3L*("`@("`@
M("!F8VQO<V4H)&9P*3L*("`@('T*"B`@("`O*BH*("`@("`J($5R<F]R(&AA
M;F1L97(N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@<VAO=6QD(&)E(')E
M=W)I='1E;B!T;R!U<V4@=&AE('!R969E<F5D(&5R<F]R"B`@("`@*B!H86YD
M;&EN9R!M971H;V0N("A014%27T5R<F]R4W1A8VLI"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&UE<W-A
M9V4@5&AE(&5R<F]R(&UE<W-A9V4N"B`@("`@*B!`<&%R86T@(&EN=&5G97(@
M)'1Y<&4@("`@06X@:6YD:6-A=&EO;B!O9B!T:&4@<V5V97)I='D@;V8@=&AE
M(&5R<F]R+@H@("`@("H@0')E='5R;B!V;VED("`@("`@("`@("`@($-O9&4@
M;6%Y(&-A=7-E(%!(4"!T;R!E>&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M:&%N9&QE17)R;W)S*"1M97-S86=E+"`D='EP92`]($5?55-%4E]%4E)/4BD@
M>PH@("`@("`@("\O($9O<B!N;W<@:G5S="!E8VAO('1H92!M97-S86=E+@H@
M("`@("`@(&5C:&\@)&UE<W-A9V4["@H@("`@("`@("\O($-H96-K('1O('-E
M92!I9B!W92!S:&]U;&0@<75I="X*("`@("`@("!I9B`H)'1Y<&4@/3T@15]5
M4T527T524D]2*2!["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@("`@
M?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@
M*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E
M<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1#87-E
M+G!H<```````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C,Q,@`Q
M,#4Q-30S,3`U-P`P,C$P-3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@
M*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U
M+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T
M:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@
M;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O
M=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE
M=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M
M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L
M('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I
M<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R
M>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@
M("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I
M;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@
M*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M
M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*
M("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R
M('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O
M9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S
M:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#
M3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@
M04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$
M24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!
M3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!
M(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%
M3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/
M4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#
M241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,
M($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!0
M4D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@
M*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@
M24Y415)255!424].*2!(3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(
M14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#
M"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@
M3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(
M12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(
M10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G
M;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H
M;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E
M<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI
M8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@5&5S=$-A<V4N<&AP+'8@,2XR,2`R,#`U+S$Q+S$P(#`Y.C0W.C$T('-E
M8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PH*<F5Q=6ER95]O;F-E("=0
M2%!5;FET+T%S<V5R="YP:'`G.PIR97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S
M=%)E<W5L="YP:'`G.PH*+RHJ"B`J($$@5&5S=$-A<V4@9&5F:6YE<R!T:&4@
M9FEX='5R92!T;R!R=6X@;75L=&EP;&4@=&5S=',N"B`J"B`J(%1O(&1E9FEN
M92!A(%1E<W1#87-E"B`J"B`J("`@,2D@26UP;&5M96YT(&$@<W5B8VQA<W,@
M;V8@4$A056YI=%]497-T0V%S92X*("H@("`R*2!$969I;F4@:6YS=&%N8V4@
M=F%R:6%B;&5S('1H870@<W1O<F4@=&AE('-T871E(&]F('1H92!F:7AT=7)E
M+@H@*B`@(#,I($EN:71I86QI>F4@=&AE(&9I>'1U<F4@<W1A=&4@8GD@;W9E
M<G)I9&EN9R!S9715<"@I+@H@*B`@(#0I($-L96%N+75P(&%F=&5R(&$@=&5S
M="!B>2!O=F5R<FED:6YG('1E87)$;W=N*"DN"B`J"B`J($5A8V@@=&5S="!R
M=6YS(&EN(&ET<R!O=VX@9FEX='5R92!S;R!T:&5R92!C86X@8F4@;F\@<VED
M92!E9F9E8W1S"B`J(&%M;VYG('1E<W0@<G5N<RX*("H*("H@2&5R92!I<R!A
M;B!E>&%M<&QE.@H@*@H@*B`\8V]D93X*("H@/#]P:'`*("H@8VQA<W,@36%T
M:%1E<W0@97AT96YD<R!02%!5;FET7U1E<W1#87-E('L*("H@("`@('9A<B`D
M9E9A;'5E,3L*("H@("`@('9A<B`D9E9A;'5E,CL*("H*("H@("`@(&9U;F-T
M:6]N($UA=&A497-T*"1N86UE*2!["B`J("`@("`@("`@)'1H:7,M/E!(4%5N
M:71?5&5S=$-A<V4H)&YA;64I.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I
M;VX@<V5T57`H*2!["B`J("`@("`@("`@)'1H:7,M/F9686QU93$@/2`R.PH@
M*B`@("`@("`@("1T:&ES+3YF5F%L=64R(#T@,SL*("H@("`@('T*("H@?0H@
M*B`_/@H@*B`\+V-O9&4^"B`J"B`J($9O<B!E86-H('1E<W0@:6UP;&5M96YT
M(&$@;65T:&]D('=H:6-H(&EN=&5R86-T<R!W:71H('1H92!F:7AT=7)E+@H@
M*B!697)I9GD@=&AE(&5X<&5C=&5D(')E<W5L=',@=VET:"!A<W-E<G1I;VYS
M('-P96-I9FEE9"!B>2!C86QL:6YG"B`J(&%S<V5R="!W:71H(&$@8F]O;&5A
M;BX*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J(&9U;F-T:6]N('1E<W1087-S
M*"D@>PH@*B`@("`@)'1H:7,M/F%S<V5R=%1R=64H)'1H:7,M/F9686QU93$@
M*R`D=&AI<RT^9E9A;'5E,B`]/2`U*3L*("H@?0H@*B`_/@H@*B`\+V-O9&4^
M"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A0
M56YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U
M(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E
M/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@0VQA
M<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L87-S(%!(
M4%5N:71?5&5S=$-A<V4@97AT96YD<R!02%!5;FET7T%S<V5R="!["B`@("`O
M*BH*("`@("`J($!V87(@("`@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7V9A:6QE9"`]($9!3%-%.PH*("`@("\J
M*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('1E<W0@8V%S92X*("`@("`J"B`@
M("`@*B!`=F%R("`@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7VYA;64@/2`G)SL*"B`@("`O*BH*("`@("`J(%!(
M4%5N:71?5&5S=%)E<W5L="!O8FIE8W0*("`@("`J"B`@("`@*B!`=F%R("`@
M(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W)E<W5L=#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!T97-T
M(&-A<V4@=VET:"!T:&4@9VEV96X@;F%M92X*("`@("`J"B`@("`@*B!`<&%R
M86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@4$A056YI=%]497-T0V%S92@D;F%M92`]($9!3%-%*2!["B`@
M("`@("`@:68@*"1N86UE("$]/2!&04Q312D@>PH@("`@("`@("`@("`D=&AI
M<RT^<V5T3F%M92@D;F%M92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@0V]U;G1S('1H92!N=6UB97(@;V8@=&5S="!C87-E<R!E>&5C=71E
M9"!B>2!R=6XH5&5S=%)E<W5L="!R97-U;'0I+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]U;G1497-T0V%S97,H*2!["B`@("`@("`@<F5T=7)N
M(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N86UE(&]F(&$@
M5&5S=$-A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H
M*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F%M93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)U;G,@=&AE('1E<W0@8V%S92!A;F0@8V]L;&5C=',@=&AE
M(')E<W5L=',@:6X@82!G:79E;B!497-T4F5S=6QT(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0')E='5R;B!O8FIE8W0*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(')U
M;B@F)')E<W5L="D@>PH@("`@("`@("1T:&ES+3Y?<F5S=6QT(#T@)B1R97-U
M;'0["B`@("`@("`@)'1H:7,M/E]R97-U;'0M/G)U;B@D=&AI<RD["@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)U;G,@=&AE(&)A<F4@=&5S="!S97%U96YC92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y"87)E
M*"D@>PH@("`@("`@("1T:&ES+3YS9715<"@I.PH@("`@("`@("1T:&ES+3YR
M=6Y497-T*"D["B`@("`@("`@)'1H:7,M/G1E87)$;W=N*"D["B`@("`@("`@
M)'1H:7,M/G!A<W,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($]V97)R:61E
M('1O(')U;B!T:&4@=&5S="!A;F0@87-S97)T(&ET<R!S=&%T92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!R=6Y497-T*"D@>PH@("`@("`@(&-A;&Q?=7-E<E]F=6YC*`H@("`@("`@
M("`@87)R87DH"B`@("`@("`@("`@("8D=&AI<RP*("`@("`@("`@("`@)'1H
M:7,M/E]N86UE"B`@("`@("`@("`I"B`@("`@("`@*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE(&YA;64@;V8@82!497-T0V%S92X*("`@("`J
M"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3F%M92@D;F%M92D@>PH@("`@("`@
M("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@=&5S="!C
M87-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I('L*
M("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S(&$@9&5F875L="!497-T4F5S=6QT(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F-R96%T95)E<W5L="@I('L*("`@("`@("!R
M971U<FX@;F5W(%!(4%5N:71?5&5S=%)E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($9A:6QS(&$@=&5S="!W:71H('1H92!G:79E;B!M97-S86=E+@H@
M("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!R
M;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!F86EL*"1M97-S86=E(#T@
M)R<I('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B86-K
M=')A8V4G*2D@>PH@("`@("`@("`@("`D=')A8V4@/2!D96)U9U]B86-K=')A
M8V4H*3L*"B`@("`@("`@("`@(&EF("AI<W-E="@D=')A8V5;)S$G75LG9FEL
M92==*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@
M("`@("`@("`@("`@("`@("`B)7,@:6X@)7,Z)7,B+`H*("`@("`@("`@("`@
M("`@("`@)&UE<W-A9V4L"B`@("`@("`@("`@("`@("`@("1T<F%C95LG,2==
M6R=F:6QE)UTL"B`@("`@("`@("`@("`@("`@("1T<F%C95LG,2==6R=L:6YE
M)UT*("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?<F5S=6QT+3YA9&1&86EL=7)E*"1T:&ES+"`D
M;65S<V%G92D["B`@("`@("`@)'1H:7,M/E]F86EL960@/2!44E5%.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4&%S<V5S(&$@=&5S="X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!P87-S
M*"D@>PH@("`@("`@(&EF("@A)'1H:7,M/E]F86EL960I('L*("`@("`@("`@
M("`@)'1H:7,M/E]R97-U;'0M/F%D9%!A<W-E9%1E<W0H)'1H:7,I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=7`@=&AE(&9I>'1U
M<F4L(&9O<B!E>&%M<&QE+"!O<&5N(&$@;F5T=V]R:R!C;VYN96-T:6]N+@H@
M("`@("H@5&AI<R!M971H;V0@:7,@8V%L;&5D(&)E9F]R92!A('1E<W0@:7,@
M97AE8W5T960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!S9715<"@I('L@
M+RH@86)S=')A8W0@*B\@?0H*("`@("\J*@H@("`@("H@5&5A<G,@9&]W;B!T
M:&4@9FEX='5R92P@9F]R(&5X86UP;&4L(&-L;W-E(&$@;F5T=V]R:R!C;VYN
M96-T:6]N+@H@("`@("H@5&AI<R!M971H;V0@:7,@8V%L;&5D(&%F=&5R(&$@
M=&5S="!I<R!E>&5C=71E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('1E
M87)$;W=N*"D@>R`O*B!A8G-T<F%C="`J+R!]"GT*"B\J"B`J($QO8V%L('9A
M<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T
M"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J
M+PH_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=$1E
M8V]R871O<BYP:'``````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-C8V
M`#$P-3$U-#,Q,#4W`#`R,C$S-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ
M"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P
M,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB
M=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET
M:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P
M<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@
M;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E
M(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC
M92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@
M9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN
M87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@
M*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A
M=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE
M"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H92!N
M86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI
M<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@
M;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H:7,@
M<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI
M<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%
M($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3($E3
M(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%2
M4D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%
M5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4($]73D52($]2($-/3E1224)5
M5$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)
M3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)
M04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@5$\L
M(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[
M"B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D53
M4R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!3ED@
M5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U12
M24,*("H@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#
M12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/550@3T8@
M5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@
M5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T
M96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U
M=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@
M0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!497-T1&5C;W)A=&]R+G!H<"QV(#$N,3<@,C`P-2\Q,2\Q,"`P.3HT
M-SHQ-"!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*"G)E<75I<F5?
M;VYC92`G4$A056YI="]497-T0V%S92YP:'`G.PIR97%U:7)E7V]N8V4@)U!(
M4%5N:70O5&5S=%-U:71E+G!H<"<["@II9B`H(69U;F-T:6]N7V5X:7-T<R@G
M:7-?82<I*2!["B`@("!R97%U:7)E7V]N8V4@)U!(4"]#;VUP870O1G5N8W1I
M;VXO:7-?82YP:'`G.PI]"@HO*BH*("H@02!$96-O<F%T;W(@9F]R(%1E<W1S
M+@H@*@H@*B!5<V4@5&5S=$1E8V]R871O<B!A<R!T:&4@8F%S92!C;&%S<R!F
M;W(@9&5F:6YI;F<@;F5W"B`J('1E<W0@9&5C;W)A=&]R<RX@5&5S="!D96-O
M<F%T;W(@<W5B8VQA<W-E<R!C86X@8F4@:6YT<F]D=6-E9`H@*B!T;R!A9&0@
M8F5H879I;W5R(&)E9F]R92!O<B!A9G1E<B!A('1E<W0@:7,@<G5N+@H@*@H@
M*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*
M("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A
M<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET
M7U1E<W1$96-O<F%T;W(@>PH@("`@+RHJ"B`@("`@*B!4:&4@5&5S="!T;R!B
M92!D96-O<F%T960N"B`@("`@*@H@("`@("H@0'9A<B`@("!O8FIE8W0*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@('9A<B`D7W1E<W0@
M/2!.54Q,.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%!(4%5N:71?5&5S=$1E8V]R871O<B@F)'1E
M<W0I('L*("`@("`@("!I9B`H:7-?;V)J96-T*"1T97-T*2`F)@H@("`@("`@
M("`@("`H:7-?82@D=&5S="P@)U!(4%5N:71?5&5S=$-A<V4G*2!\?`H@("`@
M("`@("`@("`@:7-?82@D=&5S="P@)U!(4%5N:71?5&5S=%-U:71E)RDI*2![
M"@H@("`@("`@("`@("`D=&AI<RT^7W1E<W0@/2`F)'1E<W0["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!T:&4@=&5S="!A;F0@8V]L
M;&5C=',@=&AE"B`@("`@*B!R97-U;'0@:6X@82!497-T4F5S=6QT+@H@("`@
M("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!B87-I8U)U;B@F)')E<W5L="D@>PH@
M("`@("`@("1T:&ES+3Y?=&5S="T^<G5N*"1R97-U;'0I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]U;G1S('1H92!N=6UB97(@;V8@=&5S="!C87-E<R!T
M:&%T"B`@("`@*B!W:6QL(&)E(')U;B!B>2!T:&ES('1E<W0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=%1E<W1#87-E<R@I('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]T97-T+3YC;W5N=%1E<W1#87-E<R@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=&5S="!T;R!B92!R=6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971497-T*"D@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W1E<W0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2=6YS('1H92!D96-O<F%T960@=&5S="!A;F0@8V]L;&5C=',@=&AE"B`@
M("`@*B!R97-U;'0@:6X@82!497-T4F5S=6QT+@H@("`@("H*("`@("`J($!P
M87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%B
M<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;B@F)')E<W5L="D@>R`O
M*B!A8G-T<F%C="`J+R!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R
M:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!T97-T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]T97-T+3YT;U-T<FEN9R@I.PH@("`@?0I]"@HO*@H@*B!,;V-A;"!V
M87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@
M-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@
M*B\*/SX*````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T1F%I;'5R92YP:'``
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<V,S(`,3`U,34T,S$P
M-3<`,#(Q-C`P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E
M<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!
M;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H
M870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J
M("`@*B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A
M:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M+@H@*B`*("H@("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M
M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I
M8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG
M(&1I<V-L86EM97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O
M<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I
M<W1R:6)U=&EO;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B
M87-T:6%N($)E<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C
M;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E
M('!R;V1U8W1S(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W
M:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*
M("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4
M($A/3$1%4E,@04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@
M15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54
M($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&
M($U%4D-(04Y404))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)424-5
M3$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,
M(%1(10H@*B!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)
M04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL
M(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53
M("A)3D-,541)3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%
M3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/
M1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E50
M5$E/3BD@2$]7159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@
M3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"
M24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$52
M5TE312D@05))4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&
M(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]3
M4TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E
M<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!3
M96)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*
M("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\
M<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H
M<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E<W1&
M86EL=7)E+G!H<"QV(#$N,3,@,C`P-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I
M86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*"B\J*@H@*B!!(%1E<W1&86EL=7)E
M(&-O;&QE8W1S(&$@9F%I;&5D('1E<W0@=&]G971H97(@=VET:"!T:&4@8V%U
M9VAT(&5X8V5P=&EO;BX*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`
M<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"
M97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I
M9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E
M;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC
M96YS90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N
M,`H@*B\*8VQA<W,@4$A056YI=%]497-T1F%I;'5R92!["B`@("`O*BH*("`@
M("`J($!V87(@("`@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?9F%I;&5D5&5S=#L*"B`@("`O*BH*("`@("`J($!V
M87(@("`@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?=&AR;W=N17AC97!T:6]N.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T<R!A(%1E<W1&86EL=7)E('=I=&@@=&AE(&=I=F5N('1E<W0@86YD
M(&5X8V5P=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@
M("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%!(4%5N:71?5&5S=$9A:6QU<F4H)B1F86EL9614
M97-T+"`F)'1H<F]W;D5X8V5P=&EO;BD@>PH@("`@("`@("1T:&ES+3Y?9F%I
M;&5D5&5S="`@("`@(#T@)B1F86EL961497-T.PH@("`@("`@("1T:&ES+3Y?
M=&AR;W=N17AC97!T:6]N(#T@)B1T:')O=VY%>&-E<'1I;VX["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'971S('1H92!F86EL960@=&5S="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F9A:6QE9%1E<W0H*2!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9F%I;&5D5&5S=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E=',@=&AE('1H<F]W;B!E>&-E<'1I;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9T:')O=VY%>&-E<'1I;VXH*2!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=&AR;W=N17AC97!T:6]N.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('-H;W)T(&1E<V-R:7!T:6]N(&]F('1H92!F86EL=7)E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I('L*("`@
M("`@("!R971U<FX@<W!R:6YT9B@*("`@("`@("`@(")497-T0V%S92`E<RT^
M)7,H*2!F86EL960Z("5S7&XB+`H*("`@("`@("`@(&=E=%]C;&%S<R@D=&AI
M<RT^7V9A:6QE9%1E<W0I+`H@("`@("`@("`@)'1H:7,M/E]F86EL961497-T
M+3YG971.86UE*"DL"B`@("`@("`@("`D=&AI<RT^7W1H<F]W;D5X8V5P=&EO
M;@H@("`@("`@("D["B`@("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*
M("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N
M9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI
M="]497-T3&ES=&5N97(N<&AP````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3$P-C4`,3`U,34T,S$P-3<`,#(Q-S<Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z
M("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@*&,I
M(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM
M8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2
M961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O
M<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R
M;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS
M"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R:6)U=&EO;G,@;V8@<V]U
M<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@
M("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J(%)E9&ES=')I8G5T:6]N
M<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P
M>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X*("H@("`@('1H92!D
M;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@
M=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*("H*("H@("`J($YE:71H
M97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M86YN(&YO<B!T:&4@;F%M
M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@
M96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960*("H@("`@(&9R
M;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T
M96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%
M1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24PH@
M*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)
M15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N
M($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.15(@3U(@
M0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%
M0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(@0T].
M4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L"B`J($)55"!.3U0@3$E-
M251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!3
M15)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2
M($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4@H@*B!#0553140@04Y$
M($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E12
M04-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.
M14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3@H@*B!!3ED@5T%9
M($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@248@0416
M25-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J
M"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI
M=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S
M=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E
M8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N
M<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z(%1E<W1,:7-T96YE<BYP:'`L=B`Q+C$R(#(P,#4O,3$O
M,3`@,#DZ-#<Z,34@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"@HO
M*BH*("H@02!,:7-T96YE<B!F;W(@=&5S="!P<F]G<F5S<RX*("H*("H@2&5R
M92!I<R!A;B!E>&%M<&QE.@H@*@H@*B`\8V]D93X*("H@/#]P:'`*("H@<F5Q
M=6ER95]O;F-E("=02%!5;FET+G!H<"<["B`J(')E<75I<F5?;VYC92`G4$A0
M56YI="]497-T3&ES=&5N97(N<&AP)SL*("H*("H@8VQA<W,@36%T:%1E<W0@
M97AT96YD<R!02%!5;FET7U1E<W1#87-E('L*("H@("`@('9A<B`D9E9A;'5E
M,3L*("H@("`@('9A<B`D9E9A;'5E,CL*("H*("H@("`@(&9U;F-T:6]N($UA
M=&A497-T*"1N86UE*2!["B`J("`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S
M=$-A<V4H)&YA;64I.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@<V5T
M57`H*2!["B`J("`@("`@("`@)'1H:7,M/F9686QU93$@/2`R.PH@*B`@("`@
M("`@("1T:&ES+3YF5F%L=64R(#T@,SL*("H@("`@('T*("H*("H@("`@(&9U
M;F-T:6]N('1E<W1!9&0H*2!["B`J("`@("`@("`@)'1H:7,M/F%S<V5R=%1R
M=64H)'1H:7,M/F9686QU93$@*R`D=&AI<RT^9E9A;'5E,B`]/2`T*3L*("H@
M("`@('T*("H@?0H@*@H@*B!C;&%S<R!->4QI<W1E;F5R(&5X=&5N9',@4$A0
M56YI=%]497-T3&ES=&5N97(@>PH@*B`@("`@9G5N8W1I;VX@861D17)R;W(H
M)B1T97-T+"`F)'0I('L*("H@("`@("`@("!P<FEN="`B37E,:7-T96YE<CHZ
M861D17)R;W(H*2!C86QL960N7&XB.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N
M8W1I;VX@861D1F%I;'5R92@F)'1E<W0L("8D="D@>PH@*B`@("`@("`@('!R
M:6YT(")->4QI<W1E;F5R.CIA9&1&86EL=7)E*"D@8V%L;&5D+EQN(CL*("H@
M("`@('T*("H*("H@("`@(&9U;F-T:6]N(&5N9%1E<W0H)B1T97-T*2!["B`J
M("`@("`@("`@<')I;G0@(DUY3&ES=&5N97(Z.F5N9%1E<W0H*2!C86QL960N
M7&XB.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@<W1A<G1497-T*"8D
M=&5S="D@>PH@*B`@("`@("`@('!R:6YT(")->4QI<W1E;F5R.CIS=&%R=%1E
M<W0H*2!C86QL960N7&XB.PH@*B`@("`@?0H@*B!]"B`J"B`J("1S=6ET92`]
M(&YE=R!02%!5;FET7U1E<W13=6ET93L*("H@)'-U:71E+3YA9&1497-T*&YE
M=R!-871H5&5S="@G=&5S=$%D9"<I*3L*("H*("H@)')E<W5L="`](&YE=R!0
M2%!5;FET7U1E<W1297-U;'0["B`J("1R97-U;'0M/F%D9$QI<W1E;F5R*&YE
M=R!->4QI<W1E;F5R*3L*("H*("H@)'-U:71E+3YR=6XH)')E<W5L="D["B`J
M('!R:6YT("1R97-U;'0M/G1O4W1R:6YG*"D["B`J(#\^"B`J(#PO8V]D93X*
M("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5
M;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B
M87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A0
M56YI=%]497-T3&ES=&5N97(@>PH@("`@+RHJ"B`@("`@*B!!;B!E<G)O<B!O
M8V-U<G)E9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@
M0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@861D17)R;W(H)B1T97-T
M+"`F)'0I('L@+RIA8G-T<F%C="`J+R!]"@H@("`@+RHJ"B`@("`@*B!!(&9A
M:6QU<F4@;V-C=7)R960N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*
M("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$9A:6QU
M<F4H)B1T97-T+"`F)'0I('L@+RIA8G-T<F%C="`J+R!]"@H@("`@+RHJ"B`@
M("`@*B!!('1E<W0@96YD960N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE
M8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`86)S=')A8W0*("`@
M("`J+PH@("`@9G5N8W1I;VX@96YD5&5S="@F)'1E<W0I('L@+RIA8G-T<F%C
M="`J+R!]"@H@("`@+RHJ"B`@("`@*B!!('1E<W0@<W1A<G1E9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!S=&%R=%1E
M<W0H)B1T97-T*2![("\J86)S=')A8W0@*B\@?0I]"@HO*@H@*B!,;V-A;"!V
M87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@
M-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@
M*B\*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!(4%5N:70O5&5S=%)E<W5L="YP:'``````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(P-3(P`#$P-3$U-#,Q,#4W`#`R,30U-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*B!V:6TZ
M('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B
M<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P>7)I
M9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B
M87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E9"X*
M("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I
M;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@
M87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N
M9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I;VYS
M(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG
M:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD
M('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I<W1R
M:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B
M;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J("`@
M("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R
M;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J("`@
M*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N;W(@
M=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B92!U
M<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`J
M("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO
M<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@
M4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"
M551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!7
M05)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%1"!43RP@
M5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$
M($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#
M3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4($]7
M3D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L
M($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL
M($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"550@
M3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/
M1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&
M2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@0T%5
M4T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)
M3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4("A)3D-,
M541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*("H@
M04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.
M($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-
M04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@
M(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS
M8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M
M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N
M;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R
M9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!497-T4F5S=6QT+G!H<"QV(#$N,3@@,C`P
M-2\Q,2\Q,"`P.3HT-SHQ-2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@
M*B\*"G)E<75I<F5?;VYC92`G4$A056YI="]497-T1F%I;'5R92YP:'`G.PIR
M97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S=$QI<W1E;F5R+G!H<"<["@II9B`H
M(69U;F-T:6]N7V5X:7-T<R@G:7-?82<I*2!["B`@("!R97%U:7)E7V]N8V4@
M)U!(4"]#;VUP870O1G5N8W1I;VXO:7-?82YP:'`G.PI]"@HO*BH*("H@02!4
M97-T4F5S=6QT(&-O;&QE8W1S('1H92!R97-U;'1S(&]F(&5X96-U=&EN9R!A
M('1E<W0@8V%S92X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C
M:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT
M("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM
M8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O
M=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS
M90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@
M*B\*8VQA<W,@4$A056YI=%]497-T4F5S=6QT('L*("`@("\J*@H@("`@("H@
M0'9A<B`@("!A<G)A>0H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J
M+PH@("`@=F%R("1?97)R;W)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($!V87(@("`@87)R87D*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*B\*("`@('9A<B`D7V9A:6QU<F5S(#T@87)R87DH*3L*"B`@("`@+RHJ"B`@
M("`@*B!`=F%R("`@(&%R<F%Y"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("HO"B`@("!V87(@)%]L:7-T96YE<G,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0'9A<B`@("!A<G)A>0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J+PH@("`@=F%R("1?<&%S<V5D5&5S=',@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0'9A<B`@("!I;G1E9V5R"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("HO"B`@("!V87(@)%]R=6Y497-T<R`](#`["@H@
M("`@+RHJ"B`@("`@*B!`=F%R("`@(&)O;VQE86X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]S=&]P(#T@1D%,4T4["@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&%N(&5R<F]R('1O('1H92!L:7-T(&]F(&5R<F]R
M<RX*("`@("`J(%1H92!P87-S960@:6X@97AC97!T:6]N(&-A=7-E9"!T:&4@
M97)R;W(N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P
M87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1%<G)O<B@F)'1E<W0L("8D="D@>PH@("`@("`@("1T
M:&ES+3Y?97)R;W)S6UT@/2!N97<@4$A056YI=%]497-T1F%I;'5R92@D=&5S
M="P@)'0I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H
M:7,M/E]L:7-T96YE<G,I.R`D:2LK*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;&ES=&5N97)S6R1I72T^861D17)R;W(H)'1E<W0L("1T*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@9F%I;'5R92!T;R!T:&4@
M;&ES="!O9B!F86EL=7)E<RX*("`@("`J(%1H92!P87-S960@:6X@97AC97!T
M:6]N(&-A=7-E9"!T:&4@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&]B:F5C=`H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$9A:6QU<F4H)B1T97-T
M+"`F)'0I('L*("`@("`@("`D=&AI<RT^7V9A:6QU<F5S6UT@/2!N97<@4$A0
M56YI=%]497-T1F%I;'5R92@D=&5S="P@)'0I.PH*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]L:7-T96YE<G,I.R`D:2LK*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&5N97)S6R1I72T^861D1F%I;'5R
M92@D=&5S="P@)'0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E9VES=&5R<R!A(%1E<W1,:7-T96YE<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D3&ES=&5N97(H)B1L:7-T96YE<BD@>PH@("`@("`@(&EF
M("AI<U]O8FIE8W0H)&QI<W1E;F5R*2`F)@H@("`@("`@("`@("!I<U]A*"1L
M:7-T96YE<BP@)U!(4%5N:71?5&5S=$QI<W1E;F5R)RDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]L:7-T96YE<G-;72`]("8D;&ES=&5N97(["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('!A<W-E9"!T97-T('1O
M('1H92!L:7-T(&]F('!A<W-E9"!T97-T<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D4&%S<V5D5&5S="@F)'1E<W0I('L*("`@("`@("`D=&AI
M<RT^7W!A<W-E9%1E<W1S6UT@/2`F)'1E<W0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);F9O<FUS('1H92!R97-U;'0@=&AA="!A('1E<W0@=V%S(&-O;7!L
M971E9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@96YD5&5S="@F)'1E
M<W0I('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M
M/E]L:7-T96YE<G,I.R`D:2LK*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&ES
M=&5N97)S6R1I72T^96YD5&5S="@D=&5S="D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&1E=&5C=&5D(&5R
M<F]R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]U;G0H
M*2!["B`@("`@("`@<F5T=7)N('-I>F5O9B@D=&AI<RT^7V5R<F]R<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N($5N=6UE<F%T:6]N(&9O
M<B!T:&4@97)R;W)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9E<G)O
M<G,H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97)R;W)S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&1E=&5C=&5D(&9A
M:6QU<F5S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9F%I;'5R94-O
M=6YT*"D@>PH@("`@("`@(')E='5R;B!S:7IE;V8H)'1H:7,M/E]F86EL=7)E
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N($5N=6UE<F%T
M:6]N(&9O<B!T:&4@9F%I;'5R97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A:6QU<F5S*"D@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V9A:6QU
M<F5S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!%;G5M97)A
M=&EO;B!F;W(@=&AE('!A<W-E9"!T97-T<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B`F<&%S<V5D5&5S=',H*2!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%S<V5D5&5S=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G)E9VES
M=&5R<R!A(%1E<W1,:7-T96YE<BX*("`@("`J(%1H:7,@<F5Q=6ER97,@=&AE
M(%IE;F0@16YG:6YE(#(@*'1O('=O<FL@<')O<&5R;'DI+@H@("`@("H*("`@
M("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!R96UO=F5,:7-T96YE<B@F)&QI<W1E;F5R*2![
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?;&ES
M=&5N97)S*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]L:7-T
M96YE<G-;)&E=(#T]/2`D;&ES=&5N97(I('L*("`@("`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?;&ES=&5N97)S6R1I72D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2=6YS(&$@5&5S=$-A<V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;B@F)'1E<W0I('L*("`@
M("`@("`D=&AI<RT^<W1A<G1497-T*"1T97-T*3L*("`@("`@("`D=&AI<RT^
M7W)U;E1E<W1S*RL["B`@("`@("`@)'1E<W0M/G)U;D)A<F4H*3L*("`@("`@
M("`D=&AI<RT^96YD5&5S="@D=&5S="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'971S('1H92!N=6UB97(@;V8@<G5N('1E<W1S+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<G5N0V]U;G0H*2!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<G5N5&5S=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@
M=VAE=&AE<B!T:&4@=&5S="!R=6X@<VAO=6QD('-T;W`N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<VAO=6QD
M4W1O<"@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S=&]P.PH@("`@?0H*
M("`@("\J*@H@("`@("H@26YF;W)M<R!T:&4@<F5S=6QT('1H870@82!T97-T
M('=I;&P@8F4@<W1A<G1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C
M=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M<W1A<G1497-T*"8D=&5S="D@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M('-I>F5O9B@D=&AI<RT^7VQI<W1E;F5R<RD[("1I*RLI('L*("`@("`@("`@
M("`@)'1H:7,M/E]L:7-T96YE<G-;)&E=+3YS=&%R=%1E<W0H)'1E<W0I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA<FMS('1H870@=&AE
M('1E<W0@<G5N('-H;W5L9"!S=&]P+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W`H*2!["B`@("`@("`@
M)'1H:7,M/E]S=&]P(#T@5%)513L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!(5$U,(')E<')E<V5N=&%T:6]N(&]F('1H92!T97-T(')E<W5L
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&](5$U,*"D@>PH@("`@
M("`@(')E='5R;B`G/'!R93XG("X@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^
M=&]3=')I;F<H*2D@+B`G/"]P<F4^)SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!T97AT(')E<')E<V5N=&%T:6]N(&]F('1H92!T97-T(')E
M<W5L="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H*2![
M"B`@("`@("`@)')E<W5L="`]("<G.PH*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7W!A<W-E9%1E<W1S(&%S("1P87-S961497-T*2!["B`@("`@("`@("`@
M("1R97-U;'0@+CT@<W!R:6YT9B@*("`@("`@("`@("`@("`B5&5S=$-A<V4@
M)7,M/B5S*"D@<&%S<V5D7&XB+`H*("`@("`@("`@("`@("!G971?8VQA<W,H
M)'!A<W-E9%1E<W0I+`H@("`@("`@("`@("`@("1P87-S961497-T+3YG971.
M86UE*"D*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?9F%I;'5R97,@87,@)&9A:6QE9%1E<W0I('L*("`@("`@
M("`@("`@)')E<W5L="`N/2`D9F%I;&5D5&5S="T^=&]3=')I;F<H*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H92!E;G1I<F4@=&5S="!W87,@
M<W5C8V5S<V9U;"!O<B!N;W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!W87-3=6-C97-S9G5L*"D@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M7V5R<F]R<RD@)B8@96UP='DH)'1H:7,M/E]F86EL=7)E<RDI('L*("`@("`@
M("`@("`@<F5T=7)N(%12544["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N($9!3%-%.PH@("`@("`@('T*("`@('T*?0H*+RH*("H@3&]C
M86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S
M970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N
M9#H*("HO"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O
M5&5S=%-U:71E+G!H<```````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$U,C8T`#$P-3$U-#,Q,#4W`#`R,3,P,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A
M;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J
M+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R
M,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D
M:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M
M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI
M='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@
M*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C
M92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@
M(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@
M:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER
M:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A
M;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C
M=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I
M=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R
M('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S
M(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N
M9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M
M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N
M('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@
M0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@
M(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453
M+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)
M140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*
M("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)
M3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4($]73D52($]2($-/
M3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4
M+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%
M455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4
M140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T52
M5DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"
M55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/
M3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#
M5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'
M3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/
M550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3
M140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@
M*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*
M("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A
M<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@
M($-64SH@)$ED.B!497-T4W5I=&4N<&AP+'8@,2XQ-R`R,#`U+S$Q+S$P(#`Y
M.C0W.C$U('-E8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PH*<F5Q=6ER
M95]O;F-E("=02%!5;FET+U1E<W1#87-E+G!H<"<["@HO*BH*("H@02!497-T
M4W5I=&4@:7,@82!#;VUP;W-I=&4@;V8@5&5S=',N($ET(')U;G,@82!C;VQL
M96-T:6]N(&]F('1E<W0@8V%S97,N"B`J"B`J($AE<F4@:7,@86X@97AA;7!L
M92!U<VEN9R!T:&4@9'EN86UI8R!T97-T(&1E9FEN:71I;VXN"B`J"B`J(#QC
M;V1E/@H@*B`\/W!H<`H@*B`D<W5I=&4@/2!N97<@4$A056YI=%]497-T4W5I
M=&4H*3L*("H@)'-U:71E+3YA9&1497-T*&YE=R!-871H5&5S="@G=&5S=%!A
M<W,G*2D["B`J(#\^"B`J(#PO8V]D93X*("H*("H@06QT97)N871I=F5L>2P@
M82!497-T4W5I=&4@8V%N(&5X=')A8W0@=&AE('1E<W1S('1O(&)E(')U;B!A
M=71O;6%T:6-A;&QY+@H@*B!4;R!D;R!S;R!Y;W4@<&%S<R!T:&4@8VQA<W-N
M86UE(&]F('EO=7(@5&5S=$-A<V4@8VQA<W,@=&\@=&AE(%1E<W13=6ET90H@
M*B!C;VYS=')U8W1O<BX*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J("1S=6ET
M92`](&YE=R!497-T4W5I=&4H)V-L87-S;F%M92<I.PH@*B`_/@H@*B`\+V-O
M9&4^"B`J"B`J(%1H:7,@8V]N<W1R=6-T;W(@8W)E871E<R!A('-U:71E('=I
M=&@@86QL('1H92!M971H;V1S('-T87)T:6YG('=I=&@*("H@(G1E<W0B('1H
M870@=&%K92!N;R!A<F=U;65N=',N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I
M;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A
M<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@
M0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`
M<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@
M0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N
M:70*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XP+C`*("HO"F-L87-S(%!(4%5N:71?5&5S=%-U:71E('L*("`@("\J
M*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('1E<W0@<W5I=&4N"B`@("`@*@H@
M("`@("H@0'9A<B`@("!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]N86UE(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@=&5S=',@:6X@=&AE('1E<W0@<W5I=&4N"B`@("`@*@H@("`@("H@0'9A
M<B`@("!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7W1E<W1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=',@82!497-T4W5I=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE
M9`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M4$A056YI=%]497-T4W5I=&4H)'1E<W0@/2!&04Q312D@>PH@("`@("`@(&EF
M("@D=&5S="`A/3T@1D%,4T4I('L*("`@("`@("`@("`@)'1H:7,M/G-E=$YA
M;64H)'1E<W0I.PH@("`@("`@("`@("`D=&AI<RT^861D5&5S=%-U:71E*"1T
M97-T*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@
M=&5S="!T;R!T:&4@<W5I=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE
M8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9%1E<W0H)B1T97-T*2!["B`@("`@("`@)'1H:7,M/E]T97-T<UM=(#T@
M)B1T97-T.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!T:&4@=&5S=',@
M9G)O;2!T:&4@9VEV96X@8VQA<W,@=&\@=&AE('-U:71E+@H@("`@("H*("`@
M("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1497-T4W5I=&4H)'1E<W1#;&%S<RD@>PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)'1E<W1#;&%S<RDI('L*("`@("`@
M("`@("`@)&UE=&AO9',@("`@("`@/2!G971?8VQA<W-?;65T:&]D<R@D=&5S
M=$-L87-S*3L*("`@("`@("`@("`@)'!A<F5N=$-L87-S97,@/2!A<G)A>2AS
M=')T;VQO=V5R*"1T97-T0VQA<W,I*3L*("`@("`@("`@("`@)'!A<F5N=$-L
M87-S("`@/2`D=&5S=$-L87-S.PH*("`@("`@("`@("`@=VAI;&4H:7-?<W1R
M:6YG*"1P87)E;G1#;&%S<R`](&=E=%]P87)E;G1?8VQA<W,H)'!A<F5N=$-L
M87-S*2DI('L*("`@("`@("`@("`@("`@("1P87)E;G1#;&%S<V5S6UT@/2`D
M<&%R96YT0VQA<W,["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1M971H;V1S(&%S("1M971H;V0I('L*("`@("`@("`@("`@("`@(&EF
M("AS=6)S='(H)&UE=&AO9"P@,"P@-"D@/3T@)W1E<W0G("8F"B`@("`@("`@
M("`@("`@("`@("`@(6EN7V%R<F%Y*"1M971H;V0L("1P87)E;G1#;&%S<V5S
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&1497-T*&YE=R`D
M=&5S=$-L87-S*"1M971H;V0I*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O=6YT
M<R!T:&4@;G5M8F5R(&]F('1E<W0@8V%S97,@=&AA="!W:6QL(&)E(')U;B!B
M>2!T:&ES('1E<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N
M=%1E<W1#87-E<R@I('L*("`@("`@("`D8V]U;G0@/2`P.PH*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7W1E<W1S(&%S("1T97-T*2!["B`@("`@("`@("`@
M("1C;W5N="`K/2`D=&5S="T^8V]U;G1497-T0V%S97,H*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8V]U;G0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!N86UE(&]F('1H92!S=6ET92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T3F%M92@I('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!T:&4@=&5S
M=',@86YD(&-O;&QE8W1S('1H96ER(')E<W5L="!I;B!A(%1E<W1297-U;'0N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;B@F)')E<W5L="D@>PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^7W1E<W1S
M*2`F)B`A)')E<W5L="T^<VAO=6QD4W1O<"@I.R`D:2LK*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?=&5S='-;)&E=+3YR=6XH)')E<W5L="D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!A('1E<W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y4
M97-T*"8D=&5S="P@)B1R97-U;'0I('L*("`@("`@("`D=&5S="T^<G5N*"1R
M97-U;'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;F%M92!O
M9B!T:&4@<W5I=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$YA
M;64H)&YA;64I('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1E<W0@870@=&AE(&=I
M=F5N(&EN9&5X+@H@("`@("H*("`@("`J($!P87)A;2`@:6YT96=E<@H@("`@
M("H@0')E='5R;B!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9T97-T070H)&EN9&5X*2!["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?=&5S='-;)&EN9&5X72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=&5S='-;)&EN9&5X73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F('1E<W1S(&EN
M('1H:7,@<W5I=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T97-T
M0V]U;G0H*2!["B`@("`@("`@<F5T=7)N('-I>F5O9B@D=&AI<RT^7W1E<W1S
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1E<W1S(&%S
M(&%N(&5N=6UE<F%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9T
M97-T<R@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T97-T<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S=')I;F<@<F5P<F5S96YT871I
M;VX@;V8@=&AE('1E<W0@<W5I=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1O4W1R:6YG*"D@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*?0H*
M+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB
M87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@
M;FEL"B`J($5N9#H*("HO"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O07-S97)T+G!H<```````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(W,C,T`#$P-3$U-#,Q
M,#4W`#`R,#8Q,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT
M('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!6
M97)S:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S
M=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@
M06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD
M('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H
M;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T
M:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@
M*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T
M86EN('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<BX*("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@
M;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T
M:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O
M;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D
M:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E
M8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@
M8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T
M92!P<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@
M=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J
M"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(
M5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9
M($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)5
M5"!.3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/
M1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#
M54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,
M3"!42$4*("H@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,
M24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,
M+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%
M4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-
M14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@
M3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)5
M4%1)3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&
M($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!
M0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%
M4E=)4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/
M1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/
M4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!4
M97-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP
M:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!!<W-E
M<G0N<&AP+'8@,2XR.2`R,#`U+S$Q+S$P(#`Y.C0W.C$T('-E8F%S=&EA;B!%
M>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N,"XP"B`J+PH*+RHJ"B`J($$@<V5T(&]F(&%S<V5R="!M
M971H;V1S+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E
M("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN
M(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P
M,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G
M;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E
M+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@
M("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PIC
M;&%S<R!02%!5;FET7T%S<V5R="!["B`@("`O*BH*("`@("`J($!V87(@("`@
M8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7VQO;W-E;'E4>7!E9"`]($9!3%-%.PH*("`@("\J*@H@("`@("H@07-S
M97)T<R!T:&%T(&$@:&%Y<W1A8VL@8V]N=&%I;G,@82!N965D;&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M("!M:7AE9`H@("`@("H@0'!A<F%M("!M:7AE9`H@
M("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<VEN8V4@($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1#;VYT86EN<R@D;F5E
M9&QE+"`D:&%Y<W1A8VLL("1M97-S86=E(#T@)R<I('L*("`@("`@("!I9B`H
M:7-?<W1R:6YG*"1N965D;&4I("8F(&ES7W-T<FEN9R@D:&%Y<W1A8VLI*2![
M"B`@("`@("`@("`@("1T:&ES+3YA<W-E<G14<G5E*'-T<G!O<R@D:&%Y<W1A
M8VLL("1N965D;&4I("$]/2!&04Q312P@)&UE<W-A9V4I.PH@("`@("`@('T*
M"B`@("`@("`@96QS92!I9B`H:7-?87)R87DH)&AA>7-T86-K*2`F)B`A:7-?
M;V)J96-T*"1N965D;&4I*2!["B`@("`@("`@("`@("1T:&ES+3YA<W-E<G14
M<G5E*&EN7V%R<F%Y*"1N965D;&4L("1H87ES=&%C:RDL("1M97-S86=E*3L*
M("`@("`@("!]"@H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M9F%I;"@G56YS=7!P;W)T960@<&%R86UE=&5R('!A<W-E9"!T;R!A<W-E<G1#
M;VYT86EN<R@I+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($%S<V5R=',@=&AA="!A(&AA>7-T86-K(&1O97,@;F]T(&-O;G1A:6X@82!N
M965D;&4N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9`H@("`@("H@0'!A
M<F%M("!M:7AE9`H@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@($UE=&AO9"!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1.
M;W1#;VYT86EN<R@D;F5E9&QE+"`D:&%Y<W1A8VLL("1M97-S86=E(#T@)R<I
M('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1N965D;&4I("8F(&ES7W-T<FEN
M9R@D:&%Y<W1A8VLI*2!["B`@("`@("`@("`@("1T:&ES+3YA<W-E<G1&86QS
M92AS=')P;W,H)&AA>7-T86-K+"`D;F5E9&QE*2`A/3T@1D%,4T4L("1M97-S
M86=E*3L*("`@("`@("!]"@H@("`@("`@(&5L<V4@:68@*&ES7V%R<F%Y*"1H
M87ES=&%C:RD@)B8@(6ES7V]B:F5C="@D;F5E9&QE*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^87-S97)T1F%L<V4H:6Y?87)R87DH)&YE961L92P@)&AA>7-T
M86-K*2P@)&UE<W-A9V4I.PH@("`@("`@('T*"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YF86EL*"=5;G-U<'!O<G1E9"!P87)A;65T97(@
M<&%S<V5D('1O(&%S<V5R=$YO=$-O;G1A:6YS*"DN)RD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T:&%T('1W;R!V87)I86)L
M97,@87)E(&5Q=6%L+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960*("`@
M("`J($!P87)A;2`@;6EX960*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@
M*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!A<W-E<G1%<75A;',H)&5X<&5C=&5D+"`D86-T=6%L
M+"`D;65S<V%G92`]("<G+"`D9&5L=&$@/2`P*2!["B`@("`@("`@:68@*"AI
M<U]A<G)A>2@D86-T=6%L*2`@)B8@:7-?87)R87DH)&5X<&5C=&5D*2D@?'P*
M("`@("`@("`@("`@*&ES7V]B:F5C="@D86-T=6%L*2`F)B!I<U]O8FIE8W0H
M)&5X<&5C=&5D*2DI('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1A8W1U
M86PI("8F(&ES7V%R<F%Y*"1E>'!E8W1E9"DI('L*("`@("`@("`@("`@("`@
M(&MS;W)T*"1A8W1U86PI.PH@("`@("`@("`@("`@("`@:W-O<G0H)&5X<&5C
M=&5D*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M;&]O<V5L>51Y<&5D*2!["B`@("`@("`@("`@("`@("`D86-T=6%L("`@/2`D
M=&AI<RT^7V-O;G9E<G14;U-T<FEN9R@D86-T=6%L*3L*("`@("`@("`@("`@
M("`@("1E>'!E8W1E9"`]("1T:&ES+3Y?8V]N=F5R=%1O4W1R:6YG*"1E>'!E
M8W1E9"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1A8W1U86P@("`]
M('-E<FEA;&EZ92@D86-T=6%L*3L*("`@("`@("`@("`@)&5X<&5C=&5D(#T@
M<V5R:6%L:7IE*"1E>'!E8W1E9"D["@H@("`@("`@("`@("`D;65S<V%G92`]
M('-P<FEN=&8H"B`@("`@("`@("`@("`@)R5S97AP96-T960@)7,L(&%C='5A
M;"`E<R<L"@H@("`@("`@("`@("`@("%E;7!T>2@D;65S<V%G92D@/R`D;65S
M<V%G92`N("<@)R`Z("<G+`H@("`@("`@("`@("`@("1E>'!E8W1E9"P*("`@
M("`@("`@("`@("`D86-T=6%L"B`@("`@("`@("`@("D["@H@("`@("`@("`@
M("!I9B`H)&%C='5A;"`A/3T@)&5X<&5C=&5D*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!E;'-E:68@*&ES7VYU;65R:6,H)&%C='5A
M;"D@)B8@:7-?;G5M97)I8R@D97AP96-T960I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@("`@("`G)7-E>'!E8W1E9"`E
M<R5S+"!A8W1U86P@)7,G+`H*("`@("`@("`@("`@("`A96UP='DH)&UE<W-A
M9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G)RP*("`@("`@("`@("`@("`D97AP
M96-T960L"B`@("`@("`@("`@("`@*"1D96QT82`A/2`P*2`_("@G*R\M("<@
M+B`D9&5L=&$I(#H@)R<L"B`@("`@("`@("`@("`@)&%C='5A;`H@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@:68@*"$H)&%C='5A;"`^/2`H)&5X<&5C
M=&5D("T@)&1E;'1A*2`F)B`D86-T=6%L(#P]("@D97AP96-T960@*R`D9&5L
M=&$I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF86EL*"1M
M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@
M("`@("`G)7-E>'!E8W1E9"`E<RP@86-T=6%L("5S)RP*"B`@("`@("`@("`@
M("`@(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<L"B`@
M("`@("`@("`@("`@)&5X<&5C=&5D+`H@("`@("`@("`@("`@("1A8W1U86P*
M("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&EF("@D86-T=6%L("$]/2`D
M97AP96-T960I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I
M;"@D;65S<V%G92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H870@='=O('9A<FEA8FQE<R!R969E
M<F5N8V4@=&AE('-A;64@;V)J96-T+@H@("`@("H@5&AI<R!R97%U:7)E<R!T
M:&4@6F5N9"!%;F=I;F4@,B!T;R!W;W)K+@H@("`@("H*("`@("`J($!P87)A
M;2`@;V)J96-T"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M
M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`9&5P<F5C
M871E9`H@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1386UE*"1E>'!E8W1E
M9"P@)&%C='5A;"P@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@(&EF("@A=F5R
M<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP)RP@)SX])RDI('L*
M("`@("`@("`@("`@)'1H:7,M/F9A:6PH)V%S<V5R=%-A;64H*2!O;FQY('=O
M<FMS('=I=&@@4$A0(#X](#4N,"XP+B<I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"AI<U]O8FIE8W0H)&5X<&5C=&5D*2!\?"!I<U]N=6QL*"1E>'!E8W1E
M9"DI("8F"B`@("`@("`@("`@("AI<U]O8FIE8W0H)&%C='5A;"D@("!\?"!I
M<U]N=6QL*"1A8W1U86PI*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]('-P
M<FEN=&8H"B`@("`@("`@("`@("`@)R5S97AP96-T960@='=O('9A<FEA8FQE
M<R!T;R!R969E<F5N8V4@=&AE('-A;64@;V)J96-T)RP*"B`@("`@("`@("`@
M("`@(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<*("`@
M("`@("`@("`@*3L*"B`@("`@("`@("`@(&EF("@D97AP96-T960@(3T]("1A
M8W1U86PI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D
M;65S<V%G92D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^9F%I;"@G56YS=7!P;W)T960@<&%R86UE=&5R('!A
M<W-E9"!T;R!A<W-E<G1386UE*"DN)RD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@07-S97)T<R!T:&%T('1W;R!V87)I86)L97,@9&\@;F]T
M(')E9F5R96YC92!T:&4@<V%M92!O8FIE8W0N"B`@("`@*B!4:&ES(')E<75I
M<F5S('1H92!:96YD($5N9VEN92`R('1O('=O<FLN"B`@("`@*@H@("`@("H@
M0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`
M<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!D
M97!R96-A=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&%S<V5R=$YO=%-A;64H
M)&5X<&5C=&5D+"`D86-T=6%L+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@
M:68@*"%V97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-2XP+C`G+"`G
M/CTG*2D@>PH@("`@("`@("`@("`D=&AI<RT^9F%I;"@G87-S97)T3F]T4V%M
M92@I(&]N;'D@=V]R:W,@=VET:"!02%`@/CT@-2XP+C`N)RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H*&ES7V]B:F5C="@D97AP96-T960I('Q\(&ES7VYU
M;&PH)&5X<&5C=&5D*2D@)B8*("`@("`@("`@("`@*&ES7V]B:F5C="@D86-T
M=6%L*2`@('Q\(&ES7VYU;&PH)&%C='5A;"DI*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@("`@("`G)7-E>'!E8W1E9"!T
M=V\@=F%R:6%B;&5S('1O(')E9F5R96YC92!D:69F97)E;G0@;V)J96-T<R<L
M"@H@("`@("`@("`@("`@("%E;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N
M("<@)R`Z("<G"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!I9B`H)&5X
M<&5C=&5D(#T]/2`D86-T=6%L*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F9A:6PH)U5N<W5P<&]R=&5D
M('!A<F%M971E<B!P87-S960@=&\@87-S97)T3F]T4V%M92@I+B<I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A('9A
M<FEA8FQE(&ES(&YO="!.54Q,+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX
M960*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1.;W1.=6QL*"1A8W1U86PL
M("1M97-S86=E(#T@)R<I('L*("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H
M"B`@("`@("`@("`G)7-E>'!E8W1E9"!.3U0@3E5,3"P@86-T=6%L($Y53$PG
M+`H*("`@("`@("`@("%E;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N("<@
M)R`Z("<G"B`@("`@("`@*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)&%C='5A
M;"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF86EL*"1M97-S86=E
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H
M870@82!V87)I86)L92!I<R!.54Q,+@H@("`@("H*("`@("`J($!P87)A;2`@
M;6EX960*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1.=6QL*"1A8W1U86PL
M("1M97-S86=E(#T@)R<I('L*("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H
M"B`@("`@("`@("`G)7-E>'!E8W1E9"!.54Q,+"!A8W1U86P@3D]4($Y53$PG
M+`H*("`@("`@("`@("%E;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N("<@
M)R`Z("<G"B`@("`@("`@*3L*"B`@("`@("`@:68@*"%I<U]N=6QL*"1A8W1U
M86PI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G
M92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T
M:&%T(&$@8V]N9&ET:6]N(&ES('1R=64N"B`@("`@*@H@("`@("H@0'!A<F%M
M("!B;V]L96%N"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T5')U92@D8V]N
M9&ET:6]N+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@)&UE<W-A9V4@/2!S
M<')I;G1F*`H@("`@("`@("`@)R5S97AP96-T960@5%)512P@86-T=6%L($9!
M3%-%)RP*"B`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@
M+B`G("<@.B`G)PH@("`@("`@("D["@H@("`@("`@(&EF("@A)&-O;F1I=&EO
M;BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA
M="!A(&-O;F1I=&EO;B!I<R!F86QS92X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&)O;VQE86X*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1&86QS92@D8V]N
M9&ET:6]N+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@)&UE<W-A9V4@/2!S
M<')I;G1F*`H@("`@("`@("`@)R5S97AP96-T960@1D%,4T4L(&%C='5A;"!4
M4E5%)RP*"B`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@
M+B`G("<@.B`G)PH@("`@("`@("D["@H@("`@("`@(&EF("@D8V]N9&ET:6]N
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G92D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T:&%T
M(&$@<W1R:6YG(&UA=&-H97,@82!G:79E;B!R96=U;&%R(&5X<')E<W-I;VXN
M"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!P87)A;2`@
M<W1R:6YG"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T4F5G17AP*"1P871T
M97)N+"`D<W1R:6YG+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@)&UE<W-A
M9V4@/2!S<')I;G1F*`H@("`@("`@("`@)R5S(B5S(B!D;V5S(&YO="!M871C
M:"!P871T97)N("(E<R(G+`H*("`@("`@("`@("%E;7!T>2@D;65S<V%G92D@
M/R`D;65S<V%G92`N("<@)R`Z("<G+`H@("`@("`@("`@)'-T<FEN9RP*("`@
M("`@("`@("1P871T97)N"B`@("`@("`@*3L*"B`@("`@("`@:68@*"%P<F5G
M7VUA=&-H*"1P871T97)N+"`D<W1R:6YG*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A('-T<FEN9R!D;V5S(&YO="!M
M871C:"!A(&=I=F5N(')E9W5L87(@97AP<F5S<VEO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@('-T<FEN9PH@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J
M($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-I;F-E("!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XQ+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T3F]T4F5G17AP*"1P871T97)N
M+"`D<W1R:6YG+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@)&UE<W-A9V4@
M/2!S<')I;G1F*`H@("`@("`@("`@)R5S(B5S(B!M871C:&5S('!A='1E<FX@
M(B5S(B<L"@H@("`@("`@("`@(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E
M("X@)R`G(#H@)R<L"B`@("`@("`@("`D<W1R:6YG+`H@("`@("`@("`@)'!A
M='1E<FX*("`@("`@("`I.PH*("`@("`@("!I9B`H<')E9U]M871C:"@D<&%T
M=&5R;BP@)'-T<FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF
M86EL*"1M97-S86=E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!<W-E<G1S('1H870@82!V87)I86)L92!I<R!O9B!A(&=I=F5N('1Y<&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@("`@("`@("`@)&5X<&5C
M=&5D"B`@("`@*B!`<&%R86T@(&UI>&5D("`@("`@("`@("`D86-T=6%L"B`@
M("`@*B!`<&%R86T@(&]P=&EO;F%L('-T<FEN9R`D;65S<V%G90H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T5'EP
M92@D97AP96-T960L("1A8W1U86PL("1M97-S86=E(#T@)R<I('L*("`@("`@
M("!R971U<FX@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("1E>'!E
M8W1E9"P*("`@("`@("`@(&=E='1Y<&4H)&%C='5A;"DL"B`@("`@("`@("`D
M;65S<V%G90H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV
M97)T<R!A('9A;'5E('1O(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2`@;6EX960@("`D=F%L=64*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=%1O4W1R:6YG*"1V86QU92D@>PH@
M("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:R`]/B`D=BD@>PH@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'8I*2!["B`@("`@("`@("`@("`@("`D=F%L
M=65;)&M=(#T@)'1H:7,M/E]C;VYV97)T5&]3=')I;F<H)'9A;'5E6R1K72D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!S971T>7!E
M*"1V86QU95LD:UTL("=S=')I;F<G*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("`O*BH*("`@
M("`J($!P87)A;2`@8F]O;&5A;B`D;&]O<V5L>51Y<&5D"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V]S96QY5'EP
M960H)&QO;W-E;'E4>7!E9"D@>PH@("`@("`@(&EF("AI<U]B;V]L*"1L;V]S
M96QY5'EP960I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&]O<V5L>51Y<&5D
M(#T@)&QO;W-E;'E4>7!E9#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&86EL<R!A('1E<W0@=VET:"!T:&4@9VEV96X@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<F]T
M96-T960*("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!F
M86EL*"1M97-S86=E(#T@)R<I('L@+RH@86)S=')A8W0@*B\@?0I]"@HO*@H@
M*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC
M+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*
M("H@16YD.@H@*B\*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1FEL
M92\`````````````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$V,C(S`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]&:6QE+T-35BYP:'``````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,#8P,``Q,#4Q-30S,3`U-P`P,3<S
M-C0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!&:6QE.CI#4U8*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M("!&:6QE"B`J($!P86-K86=E("`@("!&:6QE"B`J($!A=71H;W(@("`@("!4
M;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@
M("!(96QG:2#>;W)M87(@/&1U9G5Z0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M("`R,#`T+3(P,#4@5&AE($%U=&AO<G,*("H@0&QI8V5N<V4@("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z($-35BYP:'`L=B`Q+C(T(#(P
M,#4O,#@O,#D@,#@Z,38Z,#(@9'5F=7H@17AP("0*("H@0&QI;FL@("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]&:6QE"B`J+PH*<F5Q=6ER
M95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?;VYC92`G1FEL92YP:'`G.PH*
M+RHJ"BH@1FEL92!C;&%S<R!F;W(@:&%N9&QI;F<@0U-6(&9I;&5S("A#;VUM
M82!397!A<F%T960@5F%L=65S*2P@82!C;VUM;VX@9F]R;6%T"BH@9F]R(&5X
M8VAA;F=I;F<@9&%T82X**@HJ(%1/1$\Z"BH@("T@57-A9V4@97AA;7!L92!A
M;F0@1&]C"BH@("T@57-E(&=E=%!O:6YT97(H*2!I;B!D:7-C;W9E<D9O<FUA
M=`HJ("`M($%D9"!A(&QI;F4@8V]U;G1E<B!F;W(@8F5I;F<@86)L92!T;R!O
M=71P=70@8F5T=&5R(&5R<F]R(')E<&]R=',**B`@+2!3=&]R92!T:&4@;&%S
M="!E<G)O<B!I;B!'3$]"04Q3(&%N9"!A9&0@1FEL95]#4U8Z.F=E=$QA<W1%
M<G)O<B@I"BH**B!7:7-H.@HJ("`M($]T:&5R(&UE=&AO9',@;&EK92!R96%D
M06QL*"DL('=R:71E06QL*"DL(&YU;49I96QD<R@I+"!N=6U2;W=S*"D**B`@
M+2!4<GD@=&\@9&5T96-T(&EF(&$@0U-6(&AA<R!H96%D97(@;W(@;F]T(&EN
M(&1I<V-O=F5R1F]R;6%T*"D**@HJ($MN;W=N($)U9W,Z"BH@*'1H97D@:&%S
M(&)E96X@86YA;'EZ960@8G5T(&9O<B!T:&4@;6]M96YT('1H92!I;7!A8W0@
M:6X@=&AE('-P965D(&9O<@HJ("!P<F]P97)L>2!H86YD;&4@=&AI<R!U;F-O
M;6UO;B!C87-E<R!I<R!T;V\@:&EG:"!A;F0@=V]N)W0@8F4@<W5P<&]R=&5D
M*0HJ("`M($$@9FEE;&0@=VAI8V@@:7,@8V]M<&]S960@;VYL>2!B>2!A('-I
M;F=L92!Q=6]T960@<V5P87)A=&]R("AI92`M/B`[(CLB.RD**B`@("!I<R!N
M;W0@:&%N9&QE9"!P<F]P97)L>0HJ("`M(%=H96X@=&AE<F4@:7,@97AA8W1L
M>2!O;F4@9FEE;&0@;6EN=7,@=&AA;B!T:&4@97AP96-T960@;G5M8F5R(&%N
M9"!T:&5R90HJ("`@(&ES(&$@9FEE;&0@=VET:"!A('-E<&%R871O<B!I;G-I
M9&4L('1H92!P87)S97(@=VEL;"!T:')O=R!T:&4@(G=R;VYG(&-O=6YT(B!E
M<G)O<@HJ"BH@0&%U=&AO<B!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC
M;VT^"BH@0&%U=&AO<B`@("`@($AE;&=I(-YO<FUA<B`\9'5F=7I`<&AP+FYE
M=#X**B!`<&%C:V%G92!&:6QE"BHO"F-L87-S($9I;&5?0U-6"GL*("`@("\J
M*@H@("`@*B!4:&ES(')A:7-E17)R;W(@;65T:&]D('=O<FMS(&EN(&$@9&EF
M9F5R96YT('=A>2X@270@=VEL;"!A;'=A>7,@<F5T=7)N"B`@("`J(&9A;'-E
M("AA;B!E<G)O<B!O8V-U<G)E9"D@8G5T(&ET('=I;&P@8V%L;"!014%2.CIR
M86ES945R<F]R*"D@8F5F;W)E"B`@("`J(&ET+B!)9B!N;R!D969A=6QT(%!%
M05(@9VQO8F%L(&AA;F1L97(@:7,@<V5T+"!W:6QL('1R:6=G97(@86X@97)R
M;W(N"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R(%1H92!E<G)O
M<B!M97-S86=E"B`@("`J($!R971U<FX@8F]O;"!A;'=A>7,@9F%L<V4*("`@
M("HO"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"1E<G)O<BD*("`@('L*("`@
M("`@("`O+R!)9B!A(&1E9F%U;'0@4$5!4B!%<G)O<B!H86YD;&5R(&ES(&YO
M="!S970@=')I9V=E<B!T:&4@97)R;W(*("`@("`@("`O+R!86%@@061D(&$@
M4$5!4CHZ:7-3971(86YD;&5R*"D@;65T:&]D/PH@("`@("`@(&EF("@D1TQ/
M0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UT@/3T@4$5!4E]%4E)/
M4E]215154DXI('L*("`@("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@D97)R
M;W(L(&YU;&PL(%!%05)?15)23U)?5%))1T=%4BP@15]54T527U=!4DY)3D<I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R
M;W(H)&5R<F]R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@*B!#:&5C:W,@=&AE(&-O;F9I9W5R871I;VX@
M9VEV96X@8GD@=&AE('5S97(*("`@("H*("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`J($!P87)A;2!S=')I;F<@)B1E<G)O<B!4:&4@97)R;W(@=VEL;"!B
M92!W<FET=&5N(&AE<F4@:68@86YY"B`@("`J($!P87)A;2!A<G)A>2`@)B1C
M;VYF("!4:&4@8V]N9FEG=7)A=&EO;B!A<W-O8R!A<G)A>0H@("`@*B!`<F5T
M=7)N('-T<FEN9R!E<G)O<B`@("!2971U<FYS(&$@97)R;W(@;65S<V%G90H@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VYF*"8D97)R;W(L("8D8V]N9BD*("`@
M('L*("`@("`@("`O+R!C:&5C:R!C;VYF"B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D8V]N9BDI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<B`]("=);G9A
M;&ED(&-O;F9I9W5R871I;VXG.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<W-E="@D8V]N9ELG9FEE;&1S)UTI('Q\("%I<U]N=6UE<FEC*"1C;VYF6R=F
M:65L9',G72DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<B`]("=4:&4@
M;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,@*'1H92`B9FEE;&1S
M(B!K97DI)SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG
M<V5P)UTI*2!["B`@("`@("`@("`@(&EF("AS=')L96XH)&-O;F9;)W-E<"==
M*2`A/2`Q*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R(#T@)U-E
M<&%R871O<B!C86X@;VYL>2!B92!O;F4@8VAA<B<["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H)&-O;F9;)V9I96QD<R==(#X@,2D@>PH@("`@
M("`@("`@("!R971U<FX@)&5R<F]R(#T@)TUI<W-I;F<@<V5P87)A=&]R("AT
M:&4@(G-E<"(@:V5Y*2<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&-O;F9;)W%U;W1E)UTI*2!["B`@("`@("`@("`@(&EF("AS=')L96XH)&-O
M;F9;)W%U;W1E)UTI("$](#$I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M97)R;W(@/2`G5&AE('%U;W1E(&-H87(@;75S="!B92!O;F4@8VAA<B`H=&AE
M(")Q=6]T92(@:V5Y*2<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D8V]N9ELG<75O=&4G72`](&YU;&P["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES<V5T*"1C;VYF6R=C<FQF)UTI*2!["B`@("`@
M("`@("`@("1C;VYF6R=C<FQF)UT@/2`B7&XB.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<W-E="@D8V]N9ELG96]L,G5N:7@G72DI('L*("`@("`@("`@
M("`@)&-O;F9;)V5O;#)U;FEX)UT@/2!T<G5E.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("H@4F5T=7)N(&]R(&-R96%T92!T:&4@9FEL92!D97-C
M<FEP=&]R(&%S<V]C:6%T960@=VET:"!A(&9I;&4*("`@("H*("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL92!4:&4@;F%M92!O9B!T:&4@9FEL90H@("`@*B!`
M<&%R86T@87)R87D@("8D8V]N9B!4:&4@8V]N9FEG=7)A=&EO;@H@("`@*B!`
M<&%R86T@<W1R:6YG("1M;V1E(%1H92!O<&5N(&YO9&4@*&5X.B!&24Q%7TU/
M1$5?4D5!1"!O<B!&24Q%7TU/1$5?5U))5$4I"B`@("`J($!P87)A;2!B;V]L
M96%N("1R97-E="!I9B!P87-S960@87,@=')U92!A;F0@<F5S;W5R8V4@9F]R
M('1H92!F:6QE(&5X:7-T<PH@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M=&AA;B!T:&4@9FEL92!P;VEN=&5R('=I;&P@8F4@;6]V960@=&\@=&AE(&)E
M9VEN;FEN9PH@("`@*@H@("`@*B!`<F5T=7)N(&UI>&5D($$@9FEL92!R97-O
M=7)C92!O<B!F86QS90H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!O:6YT97(H
M)&9I;&4L("8D8V]N9BP@)&UO9&4@/2!&24Q%7TU/1$5?4D5!1"P@)')E<V5T
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1R97-O=7)C97,@(#T@
M87)R87DH*3L*("`@("`@("!S=&%T:6,@)&-O;F9I9SL*("`@("`@("!I9B`H
M:7-S970H)')E<V]U<F-E<ULD9FEL95TI*2!["B`@("`@("`@("`@("1C;VYF
M(#T@)&-O;F9I9SL*("`@("`@("`@("`@:68@*"1R97-E="D@>PH@("`@("`@
M("`@("`@("`@9G-E96LH)')E<V]U<F-E<ULD9FEL95TL(#`I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5S;W5R8V5S6R1F:6QE73L*
M("`@("`@("!]"B`@("`@("`@1FEL95]#4U8Z.E]C;VYF*"1E<G)O<BP@)&-O
M;F8I.PH@("`@("`@(&EF("@D97)R;W(I('L*("`@("`@("`@("`@<F5T=7)N
M($9I;&5?0U-6.CIR86ES945R<F]R*"1E<G)O<BD["B`@("`@("`@?0H@("`@
M("`@("1C;VYF:6<@/2`D8V]N9CL*("`@("`@("!014%2.CIP=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@("`@)&9P(#T@)D9I
M;&4Z.E]G971&:6QE4&]I;G1E<B@D9FEL92P@)&UO9&4I.PH@("`@("`@(%!%
M05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D9G`I*2!["B`@("`@("`@("`@(')E='5R;B!&:6QE7T-35CHZ<F%I
M<V5%<G)O<B@D9G`I.PH@("`@("`@('T*("`@("`@("`D<F5S;W5R8V5S6R1F
M:6QE72`]("1F<#L*"B`@("`@("`@:68@*"1M;V1E(#T]($9)3$5?34]$15]2
M14%$("8F("%E;7!T>2@D8V]N9ELG:&5A9&5R)UTI*2!["B`@("`@("`@("`@
M(&EF("@A1FEL95]#4U8Z.G)E860H)&9I;&4L("1C;VYF*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D9G`["B`@("!]"@H@("`@+RHJ"B`@("`J(%5N
M<75O=&4@9&%T80H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"!4
M:&4@9&%T82!T;R!U;G%U;W1E"B`@("`J($!P87)A;2!S=')I;F<@)'%U;W1E
M(%1H92!Q=6]T92!C:&%R"B`@("`J($!R971U<FX@<W1R:6YG('1H92!U;G%U
M;W1E9"!D871A"B`@("`J+PH@("`@9G5N8W1I;VX@=6YQ=6]T92@D9FEE;&0L
M("1Q=6]T92D*("`@('L*("`@("`@("`O+R!4<FEM(&9I<G-T('1H92!S=')I
M;F<N"B`@("`@("`@)&9I96QD(#T@=')I;2@D9FEE;&0I.PH@("`@("`@("1Q
M=6]T92`]('1R:6TH)'%U;W1E*3L*"B`@("`@("`@+R\@26YC87-E(&YU;&P@
M9FEE;&1S("AF;W)M.B`[.RD*("`@("`@("!I9B`H(7-T<FQE;B@D9FEE;&0I
M*2!["B`@("`@("`@("`@(')E='5R;B`D9FEE;&0["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'%U;W1E("8F("1F:65L9'LP?2`]/2`D<75O=&4@)B8@)&9I
M96QD>W-T<FQE;B@D9FEE;&0I+3%](#T]("1Q=6]T92D@>PH@("`@("`@("`@
M("!R971U<FX@<W5B<W1R*"1F:65L9"P@,2P@+3$I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&9I96QD.PH@("`@?0H*("`@("\J*@H@("`@*B!296%D
M<R!A(')O=R!O9B!D871A(&%S(&%N(&%R<F%Y(&9R;VT@82!#4U8@9FEL92X@
M270G<R!A8FQE('1O"B`@("`J(')E860@;65M;R!F:65L9',@=VET:"!M=6QT
M:6QI;F4@9&%T82X*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@
M(%1H92!F:6QE;F%M92!W:&5R92!T;R!W<FET92!T:&4@9&%T80H@("`@*B!`
M<&%R86T@87)R87D@("8D8V]N9B`@(%1H92!C;VYF:6=U<F%T:6]N(&]F('1H
M92!D97-T($-35@H@("`@*@H@("`@*B!`<F5T=7)N(&UI>&5D($%R<F%Y('=I
M=&@@=&AE(&1A=&$@<F5A9"!O<B!F86QS92!O;B!E<G)O<B]N;R!M;W)E(&1A
M=&$*("`@("HO"B`@("!F=6YC=&EO;B!R96%D475O=&5D*"1F:6QE+"`F)&-O
M;F8I"B`@("!["B`@("`@("`@:68@*"$D9G`@/2!&:6QE7T-35CHZ9V5T4&]I
M;G1E<B@D9FEL92P@)&-O;F8L($9)3$5?34]$15]214%$*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D8G5F9B`]
M("1C(#T@)R<["B`@("`@("`@)')E="`@/2!A<G)A>2@I.PH@("`@("`@("1I
M(#T@,3L*("`@("`@("`D:6Y?<75O=&4@/2!F86QS93L*("`@("`@("`D<75O
M=&4@/2`D8V]N9ELG<75O=&4G73L*("`@("`@("`D9B`]("1C;VYF6R=F:65L
M9',G73L*("`@("`@("`D96]L,G5N:7@@/2`D8V]N9ELG96]L,G5N:7@G73L*
M("`@("`@("!W:&EL92`H*"1C:"`](&9G971C*"1F<"DI("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`D<')E=B`]("1C.PH@("`@("`@("`@("`D8R`]("1C
M:#L*("`@("`@("`@("`@+R\@0V]M;6]N(&-A<V4*("`@("`@("`@("`@:68@
M*"1C("$]("1Q=6]T92`F)B`D8R`A/2`D8V]N9ELG<V5P)UT@)B8@)&,@(3T@
M(EQN(B`F)B`D8R`A/2`B7'(B*2!["B`@("`@("`@("`@("`@("`D8G5F9B`N
M/2`D8SL*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O+R!3=&%R="!Q=6]T92X*("`@("`@("`@("`@:68@
M*"1Q=6]T92`F)B`D8R`]/2`D<75O=&4@)B8*("`@("`@("`@("`@("`@("@D
M<')E=B`]/2`D8V]N9ELG<V5P)UT@?'P@)'!R978@/3T@(EQN(B!\?"`D<')E
M=B`]/3T@;G5L;"!\?`H@("`@("`@("`@("`@("`@("1P<F5V(#T](")<<B(@
M?'P@)'!R978@/3T@)R<I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@
M("`D:6Y?<75O=&4@/2!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H)&EN7W%U;W1E*2!["B`@("`@("`@("`@("`@("`O+R!7:&5N(&5N
M9',@<75O=&4*("`@("`@("`@("`@("`@(&EF("@D8R`]/2`D8V]N9ELG<V5P
M)UT@)B8@)'!R978@/3T@)&-O;F9;)W%U;W1E)UTI('L*("`@("`@("`@("`@
M("`@("`@("`D:6Y?<75O=&4@/2!F86QS93L*("`@("`@("`@("`@("`@('T@
M96QS96EF("@D8R`]/2`B7&XB('Q\("1C(#T](")<<B(I('L*("`@("`@("`@
M("`@("`@("`@("`D<W5B(#T@*"1P<F5V(#T](")<<B(I(#\@,B`Z(#$["B`@
M("`@("`@("`@("`@("`@("`@:68@*"AS=')L96XH)&)U9F8I(#X]("1S=6(I
M("8F"B`@("`@("`@("`@("`@("`@("`@("`@("@D8G5F9GMS=')L96XH)&)U
M9F8I("T@)'-U8GT@/3T@)'%U;W1E*2D*("`@("`@("`@("`@("`@("`@("![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I;E]Q=6]T92`](&9A;'-E.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"$D:6Y?<75O=&4@)B8@*"1C(#T]
M("1C;VYF6R=S97`G72!\?"`D8R`]/2`B7&XB('Q\("1C(#T](")<<B(I("8F
M("1P<F5V("$]("<G*2!["B`@("`@("`@("`@("`@("`O+R!-;W)E(&9I96QD
M<R!T:&%N(&5X<&5C=&5D"B`@("`@("`@("`@("`@("!I9B`H*"1C(#T]("1C
M;VYF6R=S97`G72D@)B8@*"AC;W5N="@D<F5T*2`K(#$I(#T]("1F*2D@>PH@
M("`@("`@("`@("`@("`@("`@("\O(%-E96L@=&AE('!O:6YT97(@:6YT;R!L
M:6YE8G)E86L@8VAA<F%C=&5R+@H@("`@("`@("`@("`@("`@("`@('=H:6QE
M("AT<G5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C(#T@9F=E=&,H
M)&9P*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@("@D8R`]/2`B7&XB
M('Q\("1C(#T](")<<B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O+R!);G-E<G0@;&%S
M="!F:65L9"!V86QU92X*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2!&
M:6QE7T-35CHZ=6YQ=6]T92@D8G5F9BP@)'%U;W1E*3L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O+R!,97-S(&9I96QD<R!T:&%N(&5X<&5C=&5D"B`@("`@
M("`@("`@("`@("!I9B`H*"1C(#T](")<;B(@?'P@)&,@/3T@(EQR(BD@)B8@
M*"1I("$]("1F*2D@>PH@("`@("`@("`@("`@("`@("`@("\O($EN<V5R="!L
M87-T(&9I96QD('9A;'5E+@H@("`@("`@("`@("`@("`@("`@("1R971;72`]
M($9I;&5?0U-6.CIU;G%U;W1E*"1B=69F+"`D<75O=&4I.PH*("`@("`@("`@
M("`@("`@("`@("`O+R!086ER('1H92!A<G)A>2!E;&5M96YT<R!T;R!F:65L
M9',@8V]U;G0N"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7VUE
M<F=E*"1R970L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y7V9I;&PH8V]U;G0H)')E="DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H)&8@+2`Q*2`M("AC
M;W5N="@D<F5T*2`M(#$I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R<I"B`@("`@("`@("`@("`@("`@("`@
M*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)'!R
M978@/3T@(EQR(BD@>PH@("`@("`@("`@("`@("`@("`@("1B=69F(#T@<W5B
M<W1R*"1B=69F+"`P+"`M,2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@+R\@0V]N=F5R="!%3TP@8VAA<F%C=&5R('1O(%5N:7@@14],
M("A,1BDN"B`@("`@("`@("`@("`@("!I9B`H)&5O;#)U;FEX*2!["B`@("`@
M("`@("`@("`@("`@("`@)&)U9F8@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<
M<BDD+R<L(")<;B(L("1B=69F*3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D<F5T6UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D8G5F9BP@
M)'%U;W1E*3L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5T*2`]/2`D
M9BD@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&)U9F8@/2`G)SL*("`@("`@
M("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D8G5F9B`N/2`D8SL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("%F96]F*"1F<"D@/R`D<F5T(#H@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`J(%)E861S(&$@(G)O=R(@9G)O;2!A($-35B!F
M:6QE(&%N9"!R971U<FX@:70@87,@86X@87)R87D*("`@("H*("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL92!4:&4@0U-6(&9I;&4*("`@("H@0'!A<F%M(&%R
M<F%Y("`F)&-O;F8@5&AE(&-O;F9I9W5R871I;VX@;V8@=&AE(&1E<W0@0U-6
M"B`@("`J"B`@("`J($!R971U<FX@;6EX960@07)R87D@;W(@9F%L<V4*("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D*"1F:6QE+"`F)&-O;F8I"B`@("!["B`@
M("`@("`@:68@*"$D9G`@/2!&:6QE7T-35CHZ9V5T4&]I;G1E<B@D9FEL92P@
M)&-O;F8L($9)3$5?34]$15]214%$*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@("\O(%1H92!S:7IE(&ES(&QI;6ET
M960@=&\@-$L*("`@("`@("!I9B`H(21L:6YE("`@/2!F9V5T<R@D9G`L(#0P
M.38I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1F:65L9',@/2`D8V]N9ELG9FEE;&1S)UT@/3T@,2`_(&%R<F%Y
M*"1L:6YE*2`Z(&5X<&QO9&4H)&-O;F9;)W-E<"==+"`D;&EN92D["@H@("`@
M("`@(&EF("@D8V]N9ELG<75O=&4G72D@>PH@("`@("`@("`@("`D;&%S="`]
M)B`D9FEE;&1S6V-O=6YT*"1F:65L9',I("T@,5T["B`@("`@("`@("`@("\O
M($9A;&QB86-K('1O(')E860@=&AE(&QI;F4@=VET:"!R96%D475O=&5D('=H
M96X@9W5E<W,*("`@("`@("`@("`@+R\@=&AA="!T:&4@<VEM<&QE(&5X<&QO
M9&4@=V]N)W0@=V]R:R!R:6=H=`H@("`@("`@("`@("!I9B`H*"1L87-T>W-T
M<FQE;B@D;&%S="D@+2`Q?2`]/2`B7&XB"B`@("`@("`@("`@("`@("`F)B`D
M;&%S='LP?2`]/2`D8V]N9ELG<75O=&4G70H@("`@("`@("`@("`@("`@)B8@
M)&QA<W1[<W1R;&5N*')T<FEM*"1L87-T*2D@+2`Q?2`A/2`D8V]N9ELG<75O
M=&4G72D*("`@("`@("`@("`@("`@('Q\"B`@("`@("`@("`@("`@("`H8V]U
M;G0H)&9I96QD<RD@(3T@)&-O;F9;)V9I96QD<R==*0H@("`@("`@("`@("`@
M("`@+R\@6%A8('!E<FAA<',@=&AE<F4@:7,@82!S97!A<F%T;W(@:6YS:61E
M(&$@<75O=&5D(&9I96QD"B`@("`@("`@("`@("`@("`O+W!R96=?;6%T8V@H
M(GQ[)&-O;F9;)W%U;W1E)UU]+BI[)&-O;F9;)W-E<"==?2XJ>R1C;VYF6R=Q
M=6]T92==?7Q5(BP@)&QI;F4I"B`@("`@("`@("`@("`@("`I"B`@("`@("`@
M("`@('L*("`@("`@("`@("`@("`@(&9S965K*"1F<"P@+3$@*B!S=')L96XH
M)&QI;F4I+"!3145+7T-54BD["B`@("`@("`@("`@("`@("!R971U<FX@1FEL
M95]#4U8Z.G)E8611=6]T960H)&9I;&4L("1C;VYF*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1L87-T(#T@<G1R:6TH)&QA<W0I
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A<R`D:R`]/B`D
M=BD@>PH@("`@("`@("`@("`@("`@("`@("1F:65L9'-;)&M=(#T@1FEL95]#
M4U8Z.G5N<75O=&4H)'8L("1C;VYF6R=Q=6]T92==*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&-O
M=6YT*"1F:65L9',I("$]("1C;VYF6R=F:65L9',G72D@>PH@("`@("`@("`@
M("!&:6QE7T-35CHZ<F%I<V5%<G)O<B@B4F5A9"!W<F]N9R!F:65L9',@;G5M
M8F5R(&-O=6YT.B`G(BX@8V]U;G0H)&9I96QD<RD@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(B<@97AP96-T960@(BXD8V]N9ELG9FEE
M;&1S)UTI.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1F:65L9',["B`@("!]"@H@("`@+RHJ"B`@("`J($EN
M=&5R;F%L('5S92!O;FQY+"!W:6QL(&)E(')E;6]V960@:6X@=&AE(&9U='5R
M90H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1S='(@5&AE('-T<FEN9R!T
M;R!D96)U9PH@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@("!F=6YC
M=&EO;B!?9&)G0G5F9B@D<W1R*0H@("`@>PH@("`@("`@(&EF("AS=')P;W,H
M)'-T<BP@(EQR(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1S='(@/2!S
M=')?<F5P;&%C92@B7'(B+"`B7W)?(BP@)'-T<BD["B`@("`@("`@?0H@("`@
M("`@(&EF("AS=')P;W,H)'-T<BP@(EQN(BD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1S='(@/2!S=')?<F5P;&%C92@B7&XB+"`B7VY?(BP@)'-T<BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H)'-T<BP@(EQT(BD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("1S='(@/2!S=')?<F5P;&%C92@B7'0B
M+"`B7W1?(BP@)'-T<BD["B`@("`@("`@?0H@("`@("`@(&5C:&\@(F)U9F8Z
M("@D<W1R*5QN(CL*("`@('T*"B`@("`O*BH*("`@("H@5W)I=&5S(&$@<W1R
M=6,@*&%R<F%Y*2!I;B!A(&9I;&4@87,@0U-6"B`@("`J"B`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&4@("!4:&4@9FEL96YA;64@=VAE<F4@=&\@=W)I=&4@
M=&AE(&1A=&$*("`@("H@0'!A<F%M(&%R<F%Y("`D9FEE;&1S($]R9&5R960@
M87)R87D@=VET:"!T:&4@9&%T80H@("`@*B!`<&%R86T@87)R87D@("8D8V]N
M9B`@(%1H92!C;VYF:6=U<F%T:6]N(&]F('1H92!D97-T($-35@H@("`@*@H@
M("`@*B!`<F5T=7)N(&)O;VP@5')U92!O;B!S=6-C97-S(&9A;'-E(&]T:&5R
M=VES90H@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1F:6QE+"`D9FEE;&1S
M+"`F)&-O;F8I"B`@("!["B`@("`@("`@:68@*"$D9G`@/2!&:6QE7T-35CHZ
M9V5T4&]I;G1E<B@D9FEL92P@)&-O;F8L($9)3$5?34]$15]74DE412DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I
M9B`H8V]U;G0H)&9I96QD<RD@(3T@)&-O;F9;)V9I96QD<R==*2!["B`@("`@
M("`@("`@($9I;&5?0U-6.CIR86ES945R<F]R*")7<F]N9R!F:65L9',@;G5M
M8F5R(&-O=6YT.B`G(BX@8V]U;G0H)&9I96QD<RD@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(B<@97AP96-T960@(BXD8V]N9ELG9FEE
M;&1S)UTI.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@
M("`@("`@)'=R:71E(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&9I96QD<RD[("1I*RLI('L*("`@("`@("`@("`@:68@*"%I<U]N
M=6UE<FEC*"1F:65L9'-;)&E=*2`F)B`D8V]N9ELG<75O=&4G72D@>PH@("`@
M("`@("`@("`@("`@)'=R:71E("X]("1C;VYF6R=Q=6]T92==("X@)&9I96QD
M<ULD:5T@+B`D8V]N9ELG<75O=&4G73L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1W<FET92`N/2`D9FEE;&1S6R1I73L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)&D@/"`H8V]U;G0H)&9I96QD<RD@
M+2`Q*2D@>PH@("`@("`@("`@("`@("`@)'=R:71E("X]("1C;VYF6R=S97`G
M73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1W<FET
M92`N/2`D8V]N9ELG8W)L9B==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&EF("@A9G=R:71E*"1F<"P@)'=R:71E*2D@>PH@("`@("`@("`@
M("!R971U<FX@1FEL95]#4U8Z.G)A:7-E17)R;W(H)T-A;B!N;W0@=W)I=&4@
M=&\@9FEL92<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("H@1&ES8V]V97(@=&AE(&9O<FUA="!O9B!A($-3
M5B!F:6QE("AT:&4@;G5M8F5R(&]F(&9I96QD<RP@=&AE('-E<&%R871O<@H@
M("`@*B!A;F0@:68@:70@<75O=&4@<W1R:6YG(&9I96QD<RD*("`@("H*("`@
M("H@0'!A<F%M('-T<FEN9R!T:&4@0U-6(&9I;&4@;F%M90H@("`@*B!`<&%R
M86T@87)R87D@97AT<F$@<V5P87)A=&]R<R!T:&%T('-H;W5L9"!B92!C:&5C
M:V5D(&9O<BX*("`@("H@0')E='5R;B!M:7AE9"!!<W-O8R!A<G)A>2!O<B!F
M86QS90H@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O=F5R1F]R;6%T*"1F:6QE
M+"`D97AT<F%397!S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(21F
M<"`]($!F;W!E;B@D9FEL92P@)W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M1FEL95]#4U8Z.G)A:7-E17)R;W(H(D-O=6QD(&YO="!O<&5N(&9I;&4Z("1F
M:6QE(BD["B`@("`@("`@?0H@("`@("`@("1S97!S(#T@87)R87DH(EQT(BP@
M)SLG+"`G.B<L("<L)RD["B`@("`@("`@)'-E<',@/2!A<G)A>5]M97)G92@D
M<V5P<RP@)&5X=')A4V5P<RD["B`@("`@("`@)&UA=&-H97,@/2!A<G)A>2@I
M.PH*("`@("`@("`O+R!3970@875T;R!D971E8W0@;&EN92!E;F1I;F<@9F]R
M($UA8R!%3TP@<W5P<&]R="!I9B`\(%!(4"`T+C,N,"X*("`@("`@("`D<&AP
M=F5R(#T@=F5R<VEO;E]C;VUP87)E*"<T+C,N,"<L('!H<'9E<G-I;VXH*2P@
M)SPG*3L*("`@("`@("!I9B`H)'!H<'9E<BD@>PH@("`@("`@("`@("`D;VQD
M:6YI(#T@:6YI7V=E="@G875T;U]D971E8W1?;&EN95]E;F1I;F=S)RD["B`@
M("`@("`@("`@(&EN:5]S970H)V%U=&]?9&5T96-T7VQI;F5?96YD:6YG<R<L
M("<Q)RD["B`@("`@("`@?0H*("`@("`@("`O+R!486ME('1H92!F:7)S="`Q
M,"!L:6YE<R!A;F0@<W1O<F4@=&AE(&YU;6)E<B!O9B!O8W5R<F5N8V5S"B`@
M("`@("`@+R\@9F]R(&5A8V@@<V5P87)A=&]R(&EN(&5A8V@@;&EN90H*("`@
M("`@("`D;&EN97,@/2!F:6QE*"1F:6QE*3L*("`@("`@("!I9B`H8V]U;G0H
M)&QI;F5S*2`^(#$P*2!["B`@("`@("`@("`@("1L:6YE<R`](&%R<F%Y7W-L
M:6-E*"1L:6YE<RP@,"P@,3`I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1P
M:'!V97(I('L*("`@("`@("`@("`@:6YI7W-E="@G875T;U]D971E8W1?;&EN
M95]E;F1I;F=S)RP@)&]L9&EN:2D["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@9F]R96%C:"`H
M)'-E<',@87,@)'-E<"D@>PH@("`@("`@("`@("`@("`@)&UA=&-H97-;)'-E
M<%U;72`]('-U8G-T<E]C;W5N="@D;&EN92P@)'-E<"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1F:6YA;"`](&%R<F%Y*"D["B`@("`@
M("`@+R\@1W)O=7`@=&AE(')E<W5L=',@8GD@86UO=6YT(&]F(&5Q=6%L(&]C
M=7)R96YC97,*("`@("`@("!F;W)E86-H("@D;6%T8VAE<R!A<R`D<V5P(#T^
M("1R97,I('L*("`@("`@("`@("`@)'1I;65S(#T@87)R87DH*3L*("`@("`@
M("`@("`@)'1I;65S6S!=(#T@,#L*("`@("`@("`@("`@9F]R96%C:"`H)')E
M<R!A<R`D:R`]/B`D;G5M*2!["B`@("`@("`@("`@("`@("!I9B`H)&YU;2`^
M(#`I('L*("`@("`@("`@("`@("`@("`@("`D=&EM97-;)&YU;5T@/2`H:7-S
M970H)'1I;65S6R1N=6U=*2D@/R`D=&EM97-;)&YU;5T@*R`Q(#H@,3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G-O
M<G0H)'1I;65S*3L*"B`@("`@("`@("`@("\O(%5S92!M87@@9FEE;&1S(&-O
M=6YT+@H@("`@("`@("`@("`D9FEE;&1S6R1S97!=(#T@;6%X*&%R<F%Y7V9L
M:7`H)'1I;65S*2D["B`@("`@("`@("`@("1A;6]U;G1;)'-E<%T@/2`D=&EM
M97-;:V5Y*"1T:6UE<RE=.PH@("`@("`@('T*"B`@("`@("`@87)S;W)T*"1A
M;6]U;G0I.PH@("`@("`@("1S97`@("`@/2!K97DH)&%M;W5N="D["@H@("`@
M("`@("1C;VYF6R=F:65L9',G72`]("1F:65L9'-;)'-E<%T@*R`Q.PH@("`@
M("`@("1C;VYF6R=S97`G72`@("`]("1S97`["@H@("`@("`@("\O(%1E<W0@
M:68@=&AE<F4@87)E(&9I96QD<R!W:71H('%U;W1E<R!A<G)O=6YD(&EN('1H
M92!F:7)S="`U(&QI;F5S"B`@("`@("`@)'%U;W1E<R`]("<B7"<G.PH@("`@
M("`@("1Q=6]T92`@/2!N=6QL.PH@("`@("`@(&EF("AC;W5N="@D;&EN97,I
M(#X@-2D@>PH@("`@("`@("`@("`D;&EN97,@/2!A<G)A>5]S;&EC92@D;&EN
M97,L(#`L(#4I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&QI;F5S
M(&%S("1L:6YE*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*")\)'-E
M<"A;)'%U;W1E<UTI+BHH6R1Q=6]T97-=*21S97!\52(L("1L:6YE+"`D;6%T
M8V@I*2!["B`@("`@("`@("`@("`@("!I9B`H)&UA=&-H6S%=(#T]("1M871C
M:%LR72D@>PH@("`@("`@("`@("`@("`@("`@("1Q=6]T92`]("1M871C:%LQ
M73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B
M?%XH6R1Q=6]T97-=*2XJ*%LD<75O=&5S72DD<V5P>S`L,7U\(BP@)&QI;F4L
M("1M871C:"D*("`@("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H(GPH6R1Q
M=6]T97-=*2XJ*%LD<75O=&5S72DD<V5P7',D?%5S(BP@)&QI;F4L("1M871C
M:"DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(&EF("@D;6%T8VA;
M,5T@/3T@)&UA=&-H6S)=*2!["B`@("`@("`@("`@("`@("`@("`@)'%U;W1E
M(#T@)&UA=&-H6S%=.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M("1C;VYF6R=Q=6]T92==(#T@)'%U;W1E.PH@("`@("`@(&9C;&]S92@D9G`I
M.PH@("`@("`@("\O(%A86"!7:&%T(&%B;W5T('1R>6EN9R!T;R!D:7-C;W9E
M<B!T:&4@(FAE861E<B(_"B`@("`@("`@<F5T=7)N("1C;VYF.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1G)O;G0@=&\@8V%L;"!G9710;VEN=&5R(&%N9"!M
M;W9I;F<@=&AE(')E<V]U<F-E('1O('1H90H@("`@("H@8F5G:6YN:6YG(&]F
M('1H92!F:6QE"B`@("`@*B!297-E="!I="!I9B!Y;W4@;&EK92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE(%1H92!N86UE(&]F('1H92!F
M:6QE"B`@("`@*B!`<&%R86T@87)R87D@("8D8V]N9B!4:&4@8V]N9FEG=7)A
M=&EO;@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D92!4:&4@;W!E;B!N;V1E
M("AE>#H@1DE,15]-3T1%7U)%040@;W(@1DE,15]-3T1%7U=2251%*0H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&]N('-U8V-E<W,@9F%L
M<V4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E=%!O:6YT
M97(H)&9I;&4L("8D8V]N9BP@)&UO9&4I"B`@("!["B`@("`@("`@:68@*"%&
M:6QE7T-35CHZ9V5T4&]I;G1E<B@D9FEL92P@)&-O;F8L("1M;V1E+"!T<G5E
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*?0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T9I;&4O571I;"YP:'``````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,Q-30S`#$P-3$U-#,Q,#4W`#`Q-S8U-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($9I;&4Z.E5T:6P*("H@"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("`@1FEL
M90H@*B!`<&%C:V%G92`@("`@1FEL90H@*B!`875T:&]R("`@("`@36EC:&%E
M;"!786QL;F5R(#QM:6ME0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`T
M+3(P,#4@36EC:&%E;"!786QL;F5R"B`J($!L:6-E;G-E("`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!5=&EL+G!H<"QV(#$N,C$@,C`P
M-2\P."\P.2`P-SHU,CHQ,R!M:6ME($5X<"`D"B`J($!L:6YK("`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1FEL90H@*B\*"B\J*B-`*PH@
M*B!3;W)T:6YG($-O;G-T86YT<PH@*B\*9&5F:6YE*"=&24Q%7U-/4E1?3D].
M12<L("`@(#`I.PID969I;F4H)T9)3$5?4T]25%]2159%4E-%)RP@,2D["F1E
M9FEN92@G1DE,15]33U)47TY!344G+"`@("`R*3L*9&5F:6YE*"=&24Q%7U-/
M4E1?4TE:12<L("`@(#0I.PID969I;F4H)T9)3$5?4T]25%]$051%)RP@("`@
M."D["F1E9FEN92@G1DE,15]33U)47U)!3D1/32<L("`Q-BD["B\J*B-`+2HO
M"@HO*BHC0"L*("H@3&ES=&EN9R!#;VYS=&%N=',*("HO"F1E9FEN92@G1DE,
M15],25-47T9)3$53)RP@("`Q*3L*9&5F:6YE*"=&24Q%7TQ)4U1?1$E24R<L
M("`@(#(I.PID969I;F4H)T9)3$5?3$E35%]$3U13)RP@("`@-"D["F1E9FEN
M92@G1DE,15],25-47T%,3"<L("`@("!&24Q%7TQ)4U1?1DE,15,@?"!&24Q%
M7TQ)4U1?1$E24R!\($9)3$5?3$E35%]$3U13*3L*+RHJ(T`M*B\*"B\J*@H@
M*B!`:6=N;W)E"B`J+PID969I;F4H)T9)3$5?5TE.,S(G+"!D969I;F5D*"=/
M4U]724Y$3U=3)RD@/R!/4U]724Y$3U=3(#H@(7-T<FYC87-E8VUP*%!(4%]/
M4RP@)W=I;B<L(#,I*3L*"B\J*B`*("H@1FEL95]5=&EL"B`J"B`J($9I;&4@
M86YD(&1I<F5C=&]R>2!U=&EL:71Y(&9U;F-T:6]N<RX*("H@"B`J($!A8V-E
M<W,@('!U8FQI8PH@*B!`<W1A=&EC"B`J+PIC;&%S<R!&:6QE7U5T:6P*>PH@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG('!A=&@@8G5I;'0@9G)O
M;2!T:&4@87)R87D@)'!A=&A087)T<RX@5VAE<F4@82!J;VEN(`H@("`@("H@
M;V-C=7)S(&UU;'1I<&QE('-E<&%R871O<G,@87)E(')E;6]V960N($IO:6YS
M('5S:6YG('1H92!O<'1I;VYA;"`*("`@("`J('-E<&%R871O<BP@9&5F875L
M=&EN9R!T;R!T:&4@4$A0($1)4D5#5$]265]315!!4D%43U(@8V]N<W1A;G0N
M"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U8FQI
M8R`*("`@("`J($!P87)A;2`@(&%R<F%Y("`@)'!A<G1S($%R<F%Y(&-O;G1A
M:6YI;F<@=&AE('!A<G1S('1O(&)E(&IO:6YE9`H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D<V5P87)A=&]R(%1H92!D:7)E8W1O<GD@<V5P97)A=&]R"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD4&%T:"@D<&%R=',L("1S97!A<F%T
M;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@("`@("1Q<R`]
M("<O7B<N('!R96=?<75O=&4H)'-E<&%R871O<BP@)R\G*2`N)RLD+R<["B`@
M("`@("`@9F]R("@D:2`](#`L("1C(#T@8V]U;G0H)'!A<G1S*3L@)&D@/"`D
M8SL@)&DK*RD@>PH@("`@("`@("`@("!I9B`H(7-T<FQE;B@D<&%R='-;)&E=
M*2!\?"!P<F5G7VUA=&-H*"1Q<RP@)'!A<G1S6R1I72DI('L*("`@("`@("`@
M("`@("`@('5N<V5T*"1P87)T<ULD:5TI.PH@("`@("`@("`@("!](&5L<V5I
M9B`H,"`]/2`D:2D@>PH@("`@("`@("`@("`@("`@)'!A<G1S6R1I72`](')T
M<FEM*"1P87)T<ULD:5TL("1S97!A<F%T;W(I.PH@("`@("`@("`@("!](&5L
M<V5I9B`H)&,@+2`Q(#T]("1I*2!["B`@("`@("`@("`@("`@("`D<&%R='-;
M)&E=(#T@;'1R:6TH)'!A<G1S6R1I72P@)'-E<&%R871O<BD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&%R='-;)&E=(#T@=')I
M;2@D<&%R='-;)&E=+"`D<V5P87)A=&]R*3L*("`@("`@("`@("`@?2`*("`@
M("`@("!](`H@("`@("`@(')E='5R;B!I;7!L;V1E*"1S97!A<F%T;W(L("1P
M87)T<RD["B`@("!](`H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('!A=&@@
M=VET:&]U="!L96%D:6YG("\@;W(@0SI<+B!)9B!T:&ES(&ES(&YO=`H@("`@
M("H@<')E<V5N="!T:&4@<&%T:"!I<R!R971U<FYE9"!A<R!I<RX*("`@("`J
M(`H@("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC(`H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`D<&%T:"!4:&4@<&%T:"!T;R!B92!P<F]C
M97-S960*("`@("`J($!R971U<FX@('-T<FEN9R`@5&AE('!R;V-E<W-E9"!P
M871H(&]R('1H92!P871H(&%S(&ES"B`@("`@*B\*("`@(&9U;F-T:6]N('-K
M:7!2;V]T*"1P871H*0H@("`@>PH@("`@("`@(&EF("A&:6QE7U5T:6PZ.FES
M06)S;VQU=&4H)'!A=&@I*2!["B`@("`@("`@("`@(&EF("A&24Q%7U=)3C,R
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@<W5B<W1R*"1P871H+"`D<&%T
M:'LS?2`]/2`G7%PG(#\@-"`Z(#,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B!L=')I;2@D<&%T:"P@)R\G*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1P871H.PH@("`@?2`*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('1E;7`@9&ER96-T;W)Y(&%C8V]R9&EN9R!T;R!E:71H97(@=&AE
M(%1-4"P@5$U01$E2+"!O<B`*("`@("`J(%1%35`@96YV('9A<FEA8FQE<RX@
M268@=&AE<V4@87)E(&YO="!S970@:70@=VEL;"!A;'-O(&-H96-K(&9O<B!T
M:&4@"B`@("`@*B!E>&ES=&5N8V4@;V8@+W1M<"P@)5=)3D1)4B5<=&5M<`H@
M("`@("H@"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P=6)L:6,@
M"B`@("`@*B!`<F5T=7)N("!S=')I;F<@(%1H92!S>7-T96T@=&UP(&1I<F5C
M=&]R>0H@("`@("HO"B`@("!F=6YC=&EO;B!T;7!$:7(H*0H@("`@>PH@("`@
M("`@(&EF("A&24Q%7U=)3C,R*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M7T5.5ELG5$5-4"==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1?14Y6
M6R=414U0)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1?14Y66R=435`G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D7T5.
M5ELG5$U0)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1?14Y66R=W:6YD:7(G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M7T5.5ELG=VEN9&ER)UT@+B`G7%QT96UP)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-S970H)%]%3E9;)U-Y<W1E;5)O;W0G72DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D7T5.5ELG4WES=&5M4F]O="==("X@)UQ<
M=&5M<"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1?
M4T525D526R=414U0)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)%]3
M15)615);)U1%35`G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M:7-S970H)%]315)615);)U1-4"==*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1?4T525D526R=435`G73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-S970H)%]315)615);)W=I;F1I<B==*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1?4T525D526R=W:6YD:7(G72`N("=<7'1E;7`G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG
M4WES=&5M4F]O="==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1?4T52
M5D526R=3>7-T96U2;V]T)UT@+B`G7%QT96UP)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@)UQT96UP)SL*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1?14Y66R=435!$25(G72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1?14Y66R=435!$25(G73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1?4T525D526R=435!$25(G72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1?4T525D526R=435!$25(G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("<O=&UP)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!T96UP
M;W)A<GD@9FEL96YA;64@=7-I;F<@=&5M<&YA;2@I(&%N9"!&:6QE.CIT;7!$
M:7(H*2X*("`@("`J(`H@("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S<R`@
M<'5B;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&ER;F%M92!/<'1I
M;VYA;"!D:7)E8W1O<GD@;F%M92!F;W(@=&AE('1M<"!F:6QE"B`@("`@*B!`
M<F5T=7)N("!S=')I;F<@($9I;&5N86UE(&%N9"!P871H(&]F('1H92!T;7`@
M9FEL90H@("`@("HO"B`@("!F=6YC=&EO;B!T;7!&:6QE*"1D:7)N86UE(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1D:7)N86UE*2D@>PH@
M("`@("`@("`@("`D9&ER;F%M92`]($9I;&5?571I;#HZ=&UP1&ER*"D["B`@
M("`@("`@?2`*("`@("`@("!R971U<FX@=&5M<&YA;2@D9&ER;F%M92P@)W1E
M;7`N)RD["B`@("!](`H*("`@("\J*@H@("`@("H@4F5T=7)N<R!B;V]L96%N
M(&)A<V5D(&]N('=H971H97(@9VEV96X@<&%T:"!I<R!A8G-O;'5T92!O<B!N
M;W0N"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U
M8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)'!A=&@@1VEV96X@<&%T
M:`H@("`@("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!P871H(&ES
M(&%B<V]L=71E+"!F86QS92!I9B!I="!I<R!N;W0*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-!8G-O;'5T92@D<&%T:"D*("`@('L*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+R@_.EPO?%Q<7"E<+EPN*#\]7"]\)"DO)RP@)'!A=&@I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](`H@("`@("`@
M(&EF("A&24Q%7U=)3C,R*2!["B`@("`@("`@("`@(')E='5R;B!P<F5G7VUA
M=&-H*"<O7EMA+7I!+5I=.BA<7%Q\7"\I+R<L("1P871H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("@D<&%T:'LP?2`]/2`G+R<I('Q\("@D<&%T:'LP
M?2`]/2`G?B<I.PH@("`@?2`*"B`@("`O*BH*("`@("`J($=E="!P871H(')E
M;&%T:79E('1O(&%N;W1H97(@<&%T:`H@("`@("H*("`@("`J($!S=&%T:6,*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@<W1R:6YG
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1P871H"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1R;V]T"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1S97!A
M<F%T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@<F5L871I=F50871H*"1P871H
M+"`D<F]O="P@)'-E<&%R871O<B`]($1)4D5#5$]265]315!!4D%43U(I"B`@
M("!["B`@("`@("`@)'!A=&@@/2!&:6QE7U5T:6PZ.G)E86QP871H*"1P871H
M+"`D<V5P87)A=&]R*3L*("`@("`@("`D<F]O="`]($9I;&5?571I;#HZ<F5A
M;'!A=&@H)')O;W0L("1S97!A<F%T;W(I.PH@("`@("`@("1D:7)S(#T@97AP
M;&]D92@D<V5P87)A=&]R+"`D<&%T:"D["B`@("`@("`@)&-O;7`@/2!E>'!L
M;V1E*"1S97!A<F%T;W(L("1R;V]T*3L*("`@("`@("`*("`@("`@("!I9B`H
M1DE,15]724XS,BD@>PH@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D9&ER
M<ULP72P@)&-O;7!;,%TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'!A
M=&@["B`@("`@("`@("`@('T*("`@("`@("`@("`@=6YS970H)&1I<G-;,%TL
M("1C;VUP6S!=*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@9F]R96%C
M:"`H)&-O;7`@87,@)&D@/3X@)'!A<G0I('L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1D:7)S6R1I72D@)B8@)'!A<G0@/3T@)&1I<G-;)&E=*2!["B`@("`@
M("`@("`@("`@("!U;G-E="@D9&ER<ULD:5TL("1C;VUP6R1I72D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`@"B`@("`@("`@<F5T=7)N('-T
M<E]R97!E870H)RXN)R`N("1S97!A<F%T;W(L(&-O=6YT*"1C;VUP*2D@+B!I
M;7!L;V1E*"1S97!A<F%T;W(L("1D:7)S*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!R96%L('!A=&@@*'=O<FMS('=I=&@@;F]N+65X:7-T86YT('!A
M=&AS*0H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("H@0')E='5R;B`@<W1R:6YG"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("1P871H"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1S97!A<F%T
M;W(*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A;%!A=&@H)'!A=&@L("1S97!A
M<F%T;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@("`@(&EF
M("@A<W1R;&5N*"1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<&%R
M871O<CL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)&1R:79E(#T@)R<[
M"B`@("`@("`@:68@*$9)3$5?5TE.,S(I('L*("`@("`@("`@("`@)'!A=&@@
M/2!P<F5G7W)E<&QA8V4H)R];7%Q<7%PO72\G+"`D<V5P87)A=&]R+"`D<&%T
M:"D["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%MA+7I!+5I=7#HI
M*"XJ*2\G+"`D<&%T:"P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D
M9')I=F4@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("1P871H("`]
M("1M871C:&5S6S)=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&-W9"`@(#T@9V5T8W=D*"D["B`@("`@("`@("`@("`@("`D9')I
M=F4@/2!S=6)S='(H)&-W9"P@,"P@,BD["B`@("`@("`@("`@("`@("!I9B`H
M)'!A=&A[,'T@(3T]("1S97!A<F%T;W)[,'TI('L*("`@("`@("`@("`@("`@
M("`@("`D<&%T:"`@/2!S=6)S='(H)&-W9"P@,RD@+B`D<V5P87)A=&]R("X@
M)'!A=&@["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V5I9B`H)'!A=&A[,'T@(3T]("1S97!A<F%T;W(I('L*("`@("`@
M("`@("`@)'!A=&@@/2!G971C=V0H*2`N("1S97!A<F%T;W(@+B`D<&%T:#L*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)&1I<E-T86-K(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("AE>'!L;V1E*"1S97!A<F%T;W(L("1P871H
M*2!A<R`D9&ER*2!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1I<BD@)B8@
M)&1I<B`A/3T@)RXG*2!["B`@("`@("`@("`@("`@("!I9B`H)&1I<B`]/2`G
M+BXG*2!["B`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P*"1D:7)3=&%C
M:RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1D:7)3=&%C:UM=(#T@)&1I<CL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`*("`@("`@("!R971U<FX@
M)&1R:79E("X@)'-E<&%R871O<B`N(&EM<&QO9&4H)'-E<&%R871O<BP@)&1I
M<E-T86-K*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K('=H971H97(@
M<&%T:"!I<R!I;B!R;V]T('!A=&@*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@(&)O;VP*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@)'!A=&@*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@)')O;W0*("`@("`J+PH@("`@9G5N8W1I;VX@<&%T:$EN4F]O="@D
M<&%T:"P@)')O;W0I"B`@("!["B`@("`@("`@<W1A=&EC("1R96%L4&%T:',@
M/2!A<G)A>2@I.PH@("`@("`@(`H@("`@("`@(&EF("@A:7-S970H)')E86Q0
M871H<ULD<F]O=%TI*2!["B`@("`@("`@("`@("1R96%L4&%T:'-;)')O;W1=
M(#T@1FEL95]5=&EL.CIR96%L4&%T:"@D<F]O="D["B`@("`@("`@?0H@("`@
M("`@(`H@("`@("`@(')E='5R;B!F86QS92`A/3T@<W1R<W1R*$9I;&5?571I
M;#HZ<F5A;%!A=&@H)'!A=&@I+"`D<F5A;%!A=&AS6R1R;V]T72D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,:7-T($1I<F5C=&]R>0H@("`@("H@"B`@("`@
M*B!4:&4@9FEN86P@87)G=6UE;G0L("1C8BP@:7,@82!C86QL8F%C:R!T:&%T
M(&5I=&AE<B!E=F%L=6%T97,@=&\@=')U92!O<@H@("`@("H@9F%L<V4@86YD
M('!E<F9O<FUS(&$@9FEL=&5R(&]P97)A=&EO;BP@;W(@:70@8V%N(&%L<V\@
M;6]D:69Y('1H92`*("`@("`J(&1I<F5C=&]R>2]F:6QE(&YA;65S(')E='5R
M;F5D+B`@5&\@86-H:65V92!T:&4@;&%T=&5R(&5F9F5C="!U<V4@87,@"B`@
M("`@*B!F;VQL;W=S.@H@("`@("H@"B`@("`@*B`\8V]D93X*("`@("`J(#P_
M<&AP"B`@("`@*B!F=6YC=&EO;B!U8R@F)&9I;&5N86UE*2!["B`@("`@*B`@
M("`@)&9I;&5N86UE(#T@<W1R=&]U<'!E<B@D9FEL96YA;64I.PH@("`@("H@
M("`@(')E='5R;B!T<G5E.PH@("`@("H@?0H@("`@("H@)&5N=')I97,@/2!&
M:6QE7U5T:6PZ.FQI<W1$:7(H)RXG+"!&24Q%7TQ)4U1?04Q,+"!&24Q%7U-/
M4E1?3D].12P@)W5C)RD["B`@("`@*B!F;W)E86-H("@D96YT<FEE<R!A<R`D
M92D@>PH@("`@("H@("`@(&5C:&\@)&4M/FYA;64L(")<;B(["B`@("`@*B!]
M"B`@("`@*B`_/@H@("`@("H@/"]C;V1E/@H@("`@("H@"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@(&%R
M<F%Y"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1P871H"B`@("`@*B!`<&%R
M86T@("!I;G0@("`@("1L:7-T"B`@("`@*B!`<&%R86T@("!I;G0@("`@("1S
M;W)T"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1C8@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L:7-T1&ER*"1P871H+"`D;&ES="`]($9)3$5?3$E35%]!3$PL
M("1S;W)T(#T@1DE,15]33U)47TY/3D4L("1C8B`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*"%S=')L96XH)'!A=&@I('Q\("%I<U]D:7(H)'!A=&@I*2![
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("`*
M("`@("`@("`D96YT<FEE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D9&ER
M(#T@9&ER*"1P871H*3L@9F%L<V4@(3T]("1E;G1R>2`]("1D:7(M/G)E860H
M*3L@*2!["B`@("`@("`@("`@(&EF("@D;&ES="`F($9)3$5?3$E35%]$3U13
M('Q\("1E;G1R>7LP?2`A/3T@)RXG*2!["B`@("`@("`@("`@("`@("`D:7-2
M968@/2`H)&5N=')Y(#T]/2`G+B<@?'P@)&5N=')Y(#T]/2`G+BXG*3L*("`@
M("`@("`@("`@("`@("1I<T1I<B`]("1I<U)E9B!\?"!I<U]D:7(H)'!A=&@@
M+B<O)RX@)&5N=')Y*3L*("`@("`@("`@("`@("`@(&EF("@@("`@*"@A)&ES
M1&ER("8F("1L:7-T("8@1DE,15],25-47T9)3$53*2`@('Q\"B`@("`@("`@
M("`@("`@("`@("`@("`@("`H)&ES1&ER("`F)B`D;&ES="`F($9)3$5?3$E3
M5%]$25)3*2D@("`F)@H@("`@("`@("`@("`@("`@("`@("`@("`H(6ES7V-A
M;&QA8FQE*"1C8BD@?'P@"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8U]A<G)A>2@D8V(L(&%R<F%Y*"8D96YT<GDI*2DI('L*
M("`@("`@("`@("`@("`@("`@("`D96YT<FEE<UM=(#T@*&]B:F5C="D@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&5N=')Y
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G<VEZ92<@(#T^("1I<T1I<B`_
M(&YU;&P@.B!F:6QE<VEZ92@D<&%T:"`N)R\G+B`D96YT<GDI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G9&%T92<@(#T^(&9I;&5M=&EM92@D<&%T:"`N
M)R\G+B`D96YT<GDI+`H@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&1I
M<BT^8VQO<V4H*3L*("`@("`@("`*("`@("`@("!I9B`H)'-O<G0I('L*("`@
M("`@("`@("`@)&5N=')I97,@/2!&:6QE7U5T:6PZ.G-O<G1&:6QE<R@D96YT
M<FEE<RP@)'-O<G0I.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!R971U
M<FX@)&5N=')I97,["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@4V]R="!&
M:6QE<PH@("`@("H@"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J($!R971U<FX@(&%R<F%Y"B`@("`@*B!`<&%R86T@("!A
M<G)A>2`@("1F:6QE<PH@("`@("H@0'!A<F%M("`@:6YT("`@("`D<V]R=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S;W)T1FEL97,H)&9I;&5S+"`D<V]R="D*
M("`@('L*("`@("`@("!I9B`H(21F:6QE<RD@>PH@("`@("`@("`@("!R971U
M<FX@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"$D
M<V]R="D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@("`@('T*
M("`@("`@("`*("`@("`@("!I9B`H)'-O<G0@/3T](#$I('L*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y7W)E=F5R<V4H)&9I;&5S*3L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@:68@*"1S;W)T("8@1DE,15]33U)47U)!3D1/32D@
M>PH@("`@("`@("`@("!S:'5F9FQE*"1F:6QE<RD["B`@("`@("`@("`@(')E
M='5R;B`D9FEL97,["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1N86UE
M<R`](&%R<F%Y*"D["B`@("`@("`@)'-I>F5S(#T@87)R87DH*3L*("`@("`@
M("`D9&%T97,@/2!A<G)A>2@I.PH@("`@"B`@("`@("`@:68@*"1S;W)T("8@
M1DE,15]33U)47TY!344I('L*("`@("`@("`@("`@)'(@/2`F)&YA;65S.PH@
M("`@("`@('T@96QS96EF("@D<V]R="`F($9)3$5?4T]25%]$051%*2!["B`@
M("`@("`@("`@("1R(#T@)B1D871E<SL*("`@("`@("!](&5L<V5I9B`H)'-O
M<G0@)B!&24Q%7U-/4E1?4TE:12D@>PH@("`@("`@("`@("`D<B`]("8D<VEZ
M97,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@87-O<G0H)&9I;&5S
M+"!33U)47U)%1U5,05(I.PH@("`@("`@("`@("!R971U<FX@)&9I;&5S.PH@
M("`@("`@('T*("`@("`@("`*("`@("`@("`D<V]R=$9L86=S(#T@87)R87DH
M"B`@("`@("`@("`@($9)3$5?4T]25%].04U%(#T^(%-/4E1?4U1224Y'+"`*
M("`@("`@("`@("`@1DE,15]33U)47T1!5$4@/3X@4T]25%].54U%4DE#+"`*
M("`@("`@("`@("`@1DE,15]33U)47U-)6D4@/3X@4T]25%].54U%4DE#+`H@
M("`@("`@("D["B`@("`@("`@"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S
M("1F:6QE*2!["B`@("`@("`@("`@("1N86UE<UM=(#T@)&9I;&4M/FYA;64[
M"B`@("`@("`@("`@("1S:7IE<UM=(#T@)&9I;&4M/G-I>F4["B`@("`@("`@
M("`@("1D871E<UM=(#T@)&9I;&4M/F1A=&4["B`@("`@("`@?0H@("`@("`@
M(`H@("`@("`@(&EF("@D<V]R="`F($9)3$5?4T]25%]2159%4E-%*2!["B`@
M("`@("`@("`@(&%R<V]R="@D<BP@)'-O<G1&;&%G<ULD<V]R="`F('XQ72D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@87-O<G0H)'(L("1S;W)T
M1FQA9W-;)'-O<G1=*3L*("`@("`@("!]"B`@("`*("`@("`@("`D<F5S=6QT
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<B!A<R`D:2`]/B`D9BD@
M>PH@("`@("`@("`@("`D<F5S=6QT6UT@/2`D9FEL97-;)&E=.PH@("`@("`@
M('T*("`@(`H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H@("`@"B`@
M("`O*BH*("`@("`J(%-W:71C:"!&:6QE($5X=&5N<VEO;@H@("`@("H@"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R
M971U<FX@('-T<FEN9WQA<G)A>0H@("`@("H@0'!A<F%M("`@<W1R:6YG?&%R
M<F%Y("`@("1F:6QE;F%M90H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("1T;R!N97<@9FEL92!E>'1E;G-I;VX*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`D9G)O;2!C:&%N9V4@;VYL>2!F:6QE<R!W:71H('1H
M:7,@97AT96YS:6]N"B`@("`@*B!`<&%R86T@("!B;V]L("`@("`@("`@("`@
M)')E=F5R<V4@8VAA;F=E(&]N;'D@9FEL97,@;F]T(&AA=FEN9R`D9G)O;2!E
M>'1E;G-I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@<W=I=&-H17AT*"1F:6QE
M;F%M92P@)'1O+"`D9G)O;2`](&YU;&PL("1R979E<G-E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1F:6QE;F%M92DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&9I;&5N86UE(&%S("1K97D@/3X@)&9I;&4I('L*
M("`@("`@("`@("`@("`@("1F:6QE;F%M95LD:V5Y72`]($9I;&5?571I;#HZ
M<W=I=&-H17AT*"1F:6QE+"`D=&\L("1F<F]M*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@)&9I;&5N86UE.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("!I9B`H)&QE;B`]('-T<FQE;B@D9G)O;2DI('L*("`@("`@
M("`@("`@)&5X="`]('-U8G-T<B@D9FEL96YA;64L("TD;&5N("T@,2D["B`@
M("`@("`@("`@("1C9FX@/2!&24Q%7U=)3C,R(#\@)W-T<F-A<V5C;7`G(#H@
M)W-T<F-M<"<["B`@("`@("`@("`@(&EF("@A)')E=F5R<V4@/3T@)&-F;B@D
M97AT+"`G+B<N("1F<F]M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1F
M:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@<W5B
M<W1R*"1F:6QE;F%M92P@,"P@+21L96X@+2`Q*2`N)RXG+B`D=&\["B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D<&]S(#T@<W1R<&]S*"1F:6QE
M;F%M92P@)RXG*2D@>PH@("`@("`@("`@("!R971U<FX@<W5B<W1R*"1F:6QE
M;F%M92P@,"P@)'!O<RD@+B<N)RX@)'1O.PH@("`@("`@('T*("`@("`@("`*
M("`@("`@("!R971U<FX@)&9I;&5N86UE("XG+B<N("1T;SL*("`@('T*("`@
M(`I]"@H_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O````````````````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`Q
M-C`W,P`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]$;W=N;&]A
M9&5R+P``````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-3<`,#(P,3<Q`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+T1O=VYL;V%D97(O4&%C:V%G92YP:'``````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#(Q-#$V-0`Q,#4Q-30S,3`U-P`P,C(R-#,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`-"B\J
M*@T*("H@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4-"B`J#0H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G
M($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4&%C:V%G92YP:'`L=B`Q+CDQ(#(P
M,#8O,#$O,C,@,3DZ,#4Z-3(@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E
M("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@
M*B\-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N('!A<F%M971E<B!I;FET:6%L
M:7IA=&EO;B!F86EL<R!B96-A=7-E(&YO(')E;&5A<V5S#0H@*B!E>&ES="!W
M:71H:6X@<')E9F5R<F5D7W-T871E+"!B=70@<F5L96%S97,@9&\@97AI<W0-
M"B`J+PT*9&5F:6YE*"=014%27T1/5TY,3T%$15)?4$%#2T%'15]35$%412<L
M("TQ,#`S*3L-"B\J*@T*("H@0V]O<F1I;F%T97,@9&]W;FQO860@<&%R86UE
M=&5R<R!A;F0@;6%N86=E<R!T:&5I<B!D97!E;F1E;F-I97,-"B`J('!R:6]R
M('1O(&1O=VYL;V%D:6YG('1H96TN#0H@*@T*("H@26YP=70@8V%N(&-O;64@
M9G)O;2!T:')E92!S;W5R8V5S.@T*("H-"B`J("T@;&]C86P@9FEL97,@*&%R
M8VAI=F5S(&]R('!A8VMA9V4N>&UL*0T*("H@+2!R96UO=&4@9FEL97,@*&1O
M=VYL;V%D86)L92!U<FQS*0T*("H@+2!A8G-T<F%C="!P86-K86=E(&YA;65S
M#0H@*@T*("H@5&AE(&9I<G-T('1W;R!E;&5M96YT<R!A<F4@:&%N9&QE9"!C
M;&5A;FQY(&)Y(%!%05)?4&%C:V%G949I;&4L(&)U="!T:&4@=&AI<F0@<F5Q
M=6ER97,-"B`J(&%C8V5S<VEN9R!P96%R=V5B)W,@>&UL+7)P8R!I;G1E<F9A
M8V4@=&\@9&5T97)M:6YE(&YE8V5S<V%R>2!D97!E;F1E;F-I97,L(&%N9"!T
M:&4-"B`J(&9O<FUA="!R971U<FYE9"!O9B!D97!E;F1E;F-I97,@:7,@<VQI
M9VAT;'D@9&EF9F5R96YT(&9R;VT@=&AA="!U<V5D(&EN('!A8VMA9V4N>&UL
M+@T*("H-"B`J(%1H:7,@8VQA<W,@:&ED97,@=&AE(&1I9F9E<F5N8V5S(&)E
M='=E96X@=&AE<V4@96QE;65N=',L(&%N9"!M86ME<R!A=71O;6%T:6,-"B`J
M(&1E<&5N9&5N8WD@<F5S;VQU=&EO;B!A('!I96-E(&]F(&-A:V4N("!)="!A
M;'-O(&UA;F%G97,@8V]N9FQI8W1S('=H96X-"B`J('1W;R!C;&%S<V5S(&1E
M<&5N9"!O;B!I;F-O;7!A=&EB;&4@9&5P96YD96YC:65S+"!O<B!D:69F97)I
M;F<@=F5R<VEO;G,@;V8@=&AE('-A;64-"B`J('!A8VMA9V4@9&5P96YD96YC
M>2X@($EN(&%D9&ET:6]N+"!D;W=N;&]A9"!W:6QL(&YO="!B92!A='1E;7!T
M960@:68@=&AE('!H<"!V97)S:6]N(&ES#0H@*B!N;W0@<W5P<&]R=&5D+"!0
M14%2(&EN<W1A;&QE<B!V97)S:6]N(&ES(&YO="!S=7!P;W)T960L(&]R(&YO
M;BU014-,(&5X=&5N<VEO;G,@87)E(&YO=`T*("H@:6YS=&%L;&5D+@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?1&]W;FQO861E<E]086-K86=E
M#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T1O=VYL;V%D97(-"B`@
M("`@*B\-"B`@("!V87(@)%]D;W=N;&]A9&5R.PT*("`@("\J*@T*("`@("`J
M($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!V87(@)%]C;VYF:6<[
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("HO
M#0H@("`@=F%R("1?<F5G:7-T<GD[#0H@("`@+RHJ#0H@("`@("H@57-E9"!T
M;R!I;7!L96UE;G0@<&%C:V%G:6YG<F]O="!P<F]P97)L>0T*("`@("`J($!V
M87(@4$5!4E]296=I<W1R>0T*("`@("`J+PT*("`@('9A<B`D7VEN<W1A;&Q2
M96=I<W1R>3L-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4&%C:V%G949I
M;&5?=C%\4$5!4E]086-K86=E1FEL97QV,@T*("`@("`J+PT*("`@('9A<B`D
M7W!A8VMA9V5F:6QE.PT*("`@("\J*@T*("`@("`J($!V87(@87)R87D-"B`@
M("`@*B\-"B`@("!V87(@)%]P87)S961N86UE.PT*("`@("\J*@T*("`@("`J
M($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@)%]D;W=N;&]A9%523#L-
M"B`@("`O*BH-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO#0H@("`@=F%R
M("1?9&]W;FQO861$97!S(#T@87)R87DH*3L-"B`@("`O*BH-"B`@("`@*B!`
M=F%R(&)O;VQE86X-"B`@("`@*B\-"B`@("!V87(@)%]V86QI9"`](&9A;'-E
M.PT*("`@("\J*@T*("`@("`J($!V87(@8F]O;&5A;@T*("`@("`J+PT*("`@
M('9A<B`D7V%N86QY>F5D(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@:68@
M=&AI<R!O<B!A('!A<F5N="!P86-K86=E('=A<R!I;G9O:V5D('=I=&@@4&%C
M:V%G92US=&%T92P@=&AI<R!I<R!S970@=&\@=&AE#0H@("`@("H@<W1A=&4@
M=F%R:6%B;&4N#0H@("`@("H-"B`@("`@*B!4:&ES(&%L;&]W<R!T96UP;W)A
M<GD@<F5A<W-I9VYM96YT(&]F('!R969E<G)E9%]S=&%T92!F;W(@82!P87)E
M;G0@<&%C:V%G92!A;F0@86QL(&]F#0H@("`@("H@:71S(&1E<&5N9&5N8VEE
M<RX-"B`@("`@*B!`=F%R('-T<FEN9WQF86QS90T*("`@("`J+PT*("`@('9A
M<B`D7V5X<&QI8VET4W1A=&4@/2!F86QS93L-"B`@("`O*BH-"B`@("`@*B!)
M9B!T:&ES('!A8VMA9V4@:7,@:6YV;VME9"!W:71H(%!A8VMA9V4C9W)O=7`L
M('1H:7,@=F%R:6%B;&4@=VEL;"!B92!T<G5E#0H@("`@("HO#0H@("`@=F%R
M("1?97AP;&EC:71'<F]U<"`](&9A;'-E.PT*("`@("\J*@T*("`@("`J(%!A
M8VMA9V4@='EP92!L;V-A;'QU<FQ\>&UL<G!C#0H@("`@("H@0'9A<B!S=')I
M;F<-"B`@("`@*B\-"B`@("!V87(@)%]T>7!E.PT*("`@("\J*@T*("`@("`J
M($-O;G1E;G1S(&]F('!A8VMA9V4N>&UL+"!I9B!D;W=N;&]A9&5D(&9R;VT@
M82!R96UO=&4@8VAA;FYE;`T*("`@("`J($!V87(@<W1R:6YG?&9A;'-E#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<F%W
M<&%C:V%G969I;&4[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!B;V]L96%N#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?=F%L
M:61A=&5D(#T@9F%L<V4[#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!
M4E]$;W=N;&]A9&5R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]$;W=N
M;&]A9&5R7U!A8VMA9V4H)B1D;W=N;&]A9&5R*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]D;W=N;&]A9&5R(#T@)B1D;W=N;&]A9&5R.PT*("`@("`@("`D
M=&AI<RT^7V-O;F9I9R`]("8D=&AI<RT^7V1O=VYL;V%D97(M/F-O;F9I9SL-
M"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^7V-O;F9I9RT^
M9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)&]P=&EO;G,@/2`D9&]W;FQO861E
M<BT^9V5T3W!T:6]N<R@I.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W!A8VMA9VEN9W)O;W0G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M9FEG+3YS971);G-T86QL4F]O="@D;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==
M*3L-"B`@("`@("`@("`@("1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y(#T@)B1T
M:&ES+3Y?8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYF:6<M/G-E=$EN<W1A;&Q2;V]T*&9A;'-E*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y
M(#T@)B1T:&ES+3Y?<F5G:7-T<GD[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]V86QI9"`]("1T:&ES+3Y?86YA;'EZ960@/2!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!087)S92!T:&4@:6YP=70@86YD(&1E=&5R
M;6EN92!W:&5T:&5R('1H:7,@:7,@82!L;V-A;"!F:6QE+"!A(')E;6]T92!U
M<FDL(&]R(&%N#0H@("`@("H@86)S=')A8W0@<&%C:V%G92!N86UE+@T*("`@
M("`J#0H@("`@("H@5&AI<R!I<R!T:&4@:&5A<G0@;V8@=&AE(%!%05)?1&]W
M;FQO861E<E]086-K86=E*"DL(&%N9"!I<R!U<V5D(&EN#0H@("`@("H@>T!L
M:6YK(%!%05)?1&]W;FQO861E<CHZ9&]W;FQO860H*7T-"B`@("`@*B!`<&%R
M86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!B;V]L?%!%05)?17)R;W(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!I;FET:6%L:7IE*"1P87)A;2D-"B`@("![
M#0H@("`@("`@("1O<FEG17)R(#T@)'1H:7,M/E]F<F]M1FEL92@D<&%R86TI
M.PT*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:60I('L-"B`@("`@("`@("`@
M("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V]F9FQI;F4G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;W)I9T5R
M<BDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N
M<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)&]R:6=%<G(M/F=E=$UE<W-A9V4H*2D[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-A;FYO
M="!D;W=N;&]A9"!N;VXM;&]C86P@<&%C:V%G92`B)R`N("1P87)A;2`N("<B
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D97)R(#T@)'1H:7,M
M/E]F<F]M57)L*"1P87)A;2D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R*2!\?"`A)'1H:7,M/E]V86QI9"D@>PT*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)W5R;"<I('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL
M;V%D97(M/FQO9R@P+"`D97)R+3YG971-97-S86=E*"DI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"));G9A
M;&ED(&]R(&UI<W-I;F<@<F5M;W1E('!A8VMA9V4@9FEL92(I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D97)R(#T@)'1H:7,M/E]F
M<F]M4W1R:6YG*"1P87)A;2D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<BD@?'P@(21T:&ES+3Y?=F%L:60I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BD@)B8-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<BT^9V5T0V]D92@I(#T](%!%05)?
M1$]73DQ/041%4E]004-+04=%7U-4051%*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4[("\O(&EN<W1R=6-T('1H92!D;W=N;&]A
M9&5R('1O('-I;&5N=&QY('-K:7`-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T>7!E*2`F
M)B`D=&AI<RT^7W1Y<&4@/3T@)VQO8V%L)R`F)@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%2.CII<T5R<F]R*"1O<FEG17)R*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1O<FEG17)R+3YG9715
M<V5R26YF;R@I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1O<FEG17)R+3YG9715<V5R26YF;R@I(&%S("1E<G(I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E
M<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M97)R(#T@)&5R<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^
M;&]G*#`L("1E<G(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1O<FEG
M17)R+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)A
M;2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P
M87)A;2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B0V%N;F]T(&EN:71I86QI>F4@)R1P87)A;2<L
M(&EN=F%L:60@;W(@;6ES<VEN9R!P86-K86=E(&9I;&4B*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1E<G(M
M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;2`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H)'!A<F%M+"!T<G5E*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@-"B`@("`@("`@("`@("`@("`@("`@("`@(")#86YN;W0@:6YI=&EA;&EZ
M92`G)'!A<F%M)RP@:6YV86QI9"!O<B!M:7-S:6YG('!A8VMA9V4@9FEL92(I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!2971R:65V92!A;GD@;F]N+6QO8V%L('!A8VMA9V5S#0H@("`@("H@
M0')E='5R;B!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?
M=C)\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9D;W=N;&]A
M9"@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F
M:6QE.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1O
M=VYL;V%D55),6R=U<FPG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?:7-V
M86QI9"`](&9A;'-E.PT*("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^9V5T
M4&%R<V5D4&%C:V%G92@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F\@
M87,@)&D@/3X@)'`I('L-"B`@("`@("`@("`@("`@("`D:6YF;ULD:5T@/2!S
M=')T;VQO=V5R*"1P*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1E
M<G(@/2`D=&AI<RT^7V9R;VU5<FPH)'1H:7,M/E]D;W=N;&]A9%523%LG=7)L
M)UTL#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D
M4&%C:V%G94YA;654;U-T<FEN9R@D=&AI<RT^7W!A<G-E9&YA;64L('1R=64I
M*3L-"B`@("`@("`@("`@("1N97=I;F9O(#T@)'1H:7,M/F=E=%!A<G-E9%!A
M8VMA9V4H*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1N97=I;F9O(&%S("1I
M(#T^("1P*2![#0H@("`@("`@("`@("`@("`@)&YE=VEN9F];)&E=(#T@<W1R
M=&]L;W=E<B@D<"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M)&EN9F\@(3T@)&YE=VEN9F\I('L-"B`@("`@("`@("`@("`@("!D;R![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@D:6YF;ULG<&%C:V%G92==(#T]("=P
M96-L+G!H<"YN970G("8F("1N97=I;F9O6R=P86-K86=E)UT@/3T@)W!E87(N
M<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=P
M86-K86=E)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D:6YF;R`]/2`D;F5W:6YF;RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O('-K:7`@=&AE(&-H86YN96P@8VAE8VL@:68@
M82!P96-L('!A8VMA9V4@<V%Y<R!I="=S(&$@4$5!4B!P86-K86=E#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-2251)0T%,
M($524D]2.B!792!A<F4@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1I
M;F9O*2`N("<L(&)U="!T:&4@9FEL92`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=D;W=N;&]A9&5D(&-L86EM<R!T;R!B92`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA
M9V5.86UE5&]3=')I;F<H)'1H:7,M/F=E=%!A<G-E9%!A8VMA9V4H*2DI.PT*
M("`@("`@("`@("`@("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I('Q\("$D
M=&AI<RT^7W9A;&ED*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]T
M>7!E(#T@)VQO8V%L)SL-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M969I;&4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5&:6QE
M*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N("9G971$;W=N;&]A9&5R*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D97([#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T5'EP92@I(`T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?='EP93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!,:6ME('M`;&EN:R!I;FET:6%L:7IE*"E]+"!B=70@;W!E<F%T97,@;VX@
M82!D97!E;F1E;F-Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9G)O;41E<%52
M3"@D9&5P*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]D;W=N;&]A9%523"`]
M("1D97`[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@
M("`@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/
M<'1I;VYS*"D[#0H@("`@("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H
M(GIL:6(B*2!\?"!I<W-E="@D;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*
M("`@("`@("`@("`@("`@("1E>'0@/2`G+G1A<B<[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D97)R(#T@)'1H
M:7,M/E]F<F]M57)L*"1D97!;)W5R:2==("X@)&5X="D[#0H@("`@("`@("`@
M("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)&5R<BT^9V5T365S<V%G
M92@I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@=7)I(&1E<&5N9&5N8WD@
M(B<@+B`D9&5P6R=U<FDG72`N("1E>'0@+B`G(BP@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("=C86YN;W0@9&]W;FQO860G*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5D
M;F%M92`]#0H@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E)R`]/B`D9&5P6R=I;F9O)UTM/F=E=%!A8VMA9V4H
M*2P-"B`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1D97!;)VEN
M9F\G72T^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@("`@("`@("`G=F5R
M<VEO;B<@/3X@)&1E<%LG=F5R<VEO;B==#0H@("`@("`@("`@("`@("`@*3L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG;F]D969A=6QT)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S961N86UE6R=G<F]U<"==
M(#T@)V1E9F%U;'0G.R`O+R!D;W=N;&]A9"!T:&4@9&5F875L="!D97!E;F1E
M;F-Y(&=R;W5P#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'!L:6-I=$=R
M;W5P(#T@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI
M<RT^7W)A=W!A8VMA9V5F:6QE(#T@)&1E<%LG<F%W)UT[#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!D971E8W1$97!E;F1E;F-I97,H)'!A
M<F%M<RD-"B`@("![#0H@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N
M;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULG9&]W;FQO861O;FQY)UTI*2![#0H@("`@("`@("`@("!R971U<FX[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=O9F9L
M:6YE)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO
M9R@S+"`G4VMI<'!I;F<@9&5P96YD96YC>2!D;W=N;&]A9"!C:&5C:RP@+2UO
M9F9L:6YE('-P96-I9FEE9"<I.PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@
M("`@("!]#0H@("`@("`@("1P;F%M92`]("1T:&ES+3YG971087)S961086-K
M86=E*"D[#0H@("`@("`@(&EF("@A)'!N86UE*2![#0H@("`@("`@("`@("!R
M971U<FX[#0H@("`@("`@('T-"B`@("`@("`@)&1E<',@/2`D=&AI<RT^9V5T
M1&5P<R@I.PT*("`@("`@("!I9B`H(21D97!S*2![#0H@("`@("`@("`@("!R
M971U<FX[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R
M97%U:7)E9"==*2D@>R`O+R!P86-K86=E+GAM;"`R+C`-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1E=&5C=#(H)&1E<',L("1P;F%M92P@)&]P=&EO
M;G,L("1P87)A;7,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&5T96-T,2@D9&5P<RP@)'!N86UE+"`D;W!T:6]N
M<RP@)'!A<F%M<RD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!S971686QI9&%T960H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]V86QI
M9&%T960@/2!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&%L<F5A9'E6
M86QI9&%T960H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L
M:61A=&5D.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E;6]V92!P86-K
M86=E<R!T;R!B92!D;W=N;&]A9&5D('1H870@87)E(&%L<F5A9'D@:6YS=&%L
M;&5D#0H@("`@("H@0'!A<F%M(&%R<F%Y(&]F(%!%05)?1&]W;FQO861E<E]0
M86-K86=E(&]B:F5C=',-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<F5M;W9E26YS=&%L;&5D*"8D<&%R86US*0T*("`@('L-"B`@
M("`@("`@:68@*"%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@("1O<'1I;VYS(#T@)'!A<F%M
M<ULP72T^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@:68@
M*"%I<W-E="@D;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI*2![#0H@("`@("`@
M("`@("!F;W)E86-H("@D<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@
M("`@("`@("`@("`@("\O(')E;6]V92!S96QF(&EF(&%L<F5A9'D@:6YS=&%L
M;&5D('=I=&@@=&AI<R!V97)S:6]N#0H@("`@("`@("`@("`@("`@+R\@=&AI
M<R!D;V5S(&YO="!N965D(&%N>2!P96-L(&UA9VEC("T@=V4@;VYL>2!R96UO
M=F4@97AA8W0@;6%T8VAE<PT*("`@("`@("`@("`@("`@(&EF("@D<&%R86TM
M/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!A<F%M+3YG9710
M86-K86=E*"DL("1P87)A;2T^9V5T0VAA;FYE;"@I*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1P87)A;2T^7VEN<W1A
M;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H)'!A<F%M+3YG971086-K86=E*"DL
M("=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M+3YG971#:&%N;F5L*"DI+"`D<&%R86TM/F=E=%9E<G-I;VXH*2P@)ST])RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO
M;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN9F\@/2`D<&%R86TM/F=E=%!A<G-E9%!A8VMA9V4H*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D:6YF;ULG=F5R<VEO;B==*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D:6YF;ULG<W1A
M=&4G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86TM/E]D;W=N;&]A9&5R+3YL;V<H,2P@)U-K:7!P
M:6YG('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M+3YG9713:&]R=$YA;64H*2`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(BP@86QR96%D>2!I;G-T86QL
M960@87,@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)A;2T^7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN
M9F\H)'!A<F%M+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG+"`D<&%R86TM/F=E=$-H
M86YN96PH*2DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H(6ES<V5T*"1O<'1I;VYS6R=F;W)C92==*2`F)B`A
M:7-S970H)&]P=&EO;G-;)W5P9W)A9&4G72D@)B8-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("1P87)A;2T^9V5T4&%R<V5D
M4&%C:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3Y?
M9&]W;FQO861E<BT^;&]G*#$L("=3:VEP<&EN9R!P86-K86=E("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%-H;W)T3F%M
M92@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(BP@86QR96%D
M>2!I;G-T86QL960@87,@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86TM/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5)
M;F9O*"1P87)A;2T^9V5T4&%C:V%G92@I+"`G=F5R<VEO;B<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2T^9V5T0VAA;FYE;"@I
M*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(%!%05)?1&]W
M;FQO861E<E]086-K86=E.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]D971E8W0R*"1D97!S+"`D<&YA;64L
M("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]D
M;W=N;&]A9$1E<',@/2!A<G)A>2@I.PT*("`@("`@("`D9W)O=7!N;W1F;W5N
M9"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("AA<G)A>2@G<&%C:V%G92<L
M("=S=6)P86-K86=E)RD@87,@)'!A8VMA9V5T>7!E*2![#0H@("`@("`@("`@
M("`O+R!G970@<F5Q=6ER960@9&5P96YD96YC>2!G<F]U<`T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R1P86-K86=E='EP95TI
M*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E
M9"==6R1P86-K86=E='EP95U;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97!S6R=R97%U:7)E9"==6R1P86-K86=E='EP95T@87,@
M)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O('-K:7`@86YY('!A8VMA9V4@=&AA="!T:&ES('!A8VMA9V4@8V]N
M9FQI8W1S('=I=&@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R970@/2`D=&AI<RT^7V1E=&5C=#)$97`H)&1E<"P@
M)'!N86UE+"`G<F5Q=6ER960G+"`D<&%R86US*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861$97!S6UT@/2`D<F5T
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)&1E<"`]("1D97!S6R=R97%U:7)E9"==6R1P86-K86=E='EP
M95T[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG8V]N
M9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!S:VEP
M(&%N>2!P86-K86=E('1H870@=&AI<R!P86-K86=E(&-O;F9L:6-T<R!W:71H
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/E]D971E
M8W0R1&5P*"1D97`L("1P;F%M92P@)W)E<75I<F5D)RP@)'!A<F%M<RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D
M1&5P<UM=(#T@)')E=#L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("\O(&=E="!O<'1I;VYA;"!D97!E;F1E
M;F-Y(&=R;W5P+"!I9B!A;GD-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M<ULG;W!T:6]N86PG75LD<&%C:V%G971Y<&5=*2D@>PT*("`@("`@("`@("`@
M("`@("1S:VEP;F%M97,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&1E<'-;)V]P=&EO;F%L)UU;)'!A8VMA9V5T>7!E75LP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<'-;)V]P=&EO;F%L)UU;)'!A
M8VMA9V5T>7!E72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA;"==6R1P86-K86=E
M='EP95TI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9&5P<ULG;W!T:6]N86PG75LD<&%C:V%G971Y<&5=(&%S("1D
M97`I('L-"B`@("`@("`@("`@("`@("`@("`@)'-K:7`@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG86QL9&5P
M<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG<&%C:V%G
M92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#,L("=.
M;W1I8V4Z('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T
M<FEN9R@D=&AI<RT^9V5T4&%R<V5D4&%C:V%G92@I+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=')U92D@+B`G(B!O<'1I;VYA;"!D
M97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN
M9RAA<G)A>2@G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!;)VYA;64G72P@)V-H86YN96PG(#T^("=P96%R
M+G!H<"YN970G*2P@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(B!W:6QL(&YO="!B92!A=71O;6%T:6-A;&QY(&1O=VYL;V%D
M960G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1S:VEP;F%M97-;72`]("1T:&ES+3Y?<F5G:7-T<GDM
M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<VMI<"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D9&5P6R=P86-K86=E)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A*"1R
M970@/2`D=&AI<RT^7V1E=&5C=#)$97`H)&1E<"P@)'!N86UE+"`G;W!T:6]N
M86PG+"`D<&%R86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("A`)'-K:7!N86UE<UMC;W5N="@D<VMI<&YA;65S*2`M
M(#%=(#T]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R
M=64I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P
M*"1S:VEP;F%M97,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M)'-K:7`@)B8@:7-?87)R87DH)')E="DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861$97!S6UT@/2`D<F5T.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("AC;W5N="@D<VMI<&YA;65S*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@Q
M+"`G1&ED(&YO="!D;W=N;&]A9"!O<'1I;VYA;"!D97!E;F1E;F-I97,Z("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@
M)'-K:7!N86UE<RD@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<L
M('5S92`M+6%L;&1E<',@=&\@9&]W;FQO860@875T;VUA=&EC86QL>2<I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@+R\@9V5T(')E<75E<W1E9"!D97!E
M;F1E;F-Y(&=R;W5P+"!I9B!A;GD-"B`@("`@("`@("`@("1G<F]U<&YA;64@
M/2`D=&AI<RT^9V5T1W)O=7`H*3L-"B`@("`@("`@("`@("1E>'!L:6-I="`]
M("1T:&ES+3Y?97AP;&EC:71'<F]U<#L-"B`@("`@("`@("`@(&EF("@A)&=R
M;W5P;F%M92D@>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^8V%N1&5F
M875L="@I*2![#0H@("`@("`@("`@("`@("`@("`@("1G<F]U<&YA;64@/2`G
M9&5F875L="<[("\O('1R>2!T:&4@9&5F875L="!D97!E;F1E;F-Y(&=R;W5P
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"1G<F]U<&YO=&9O=6YD*2![#0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<'-;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=G<F]U<"==6R=A='1R:6)S)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!S6R=G<F]U
M<"==6R=A='1R:6)S)UU;)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D9W)O=7!N
M86UE*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P(#T@)&1E
M<'-;)V=R;W5P)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D
M97AP;&EC:70I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`G5V%R;FEN9SH@
M<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M)'!N86UE+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<B(&AA<R!N;R!D97!E;F1E;F-Y("<@+B`G9W)O=7`@;F%M960@(B<@
M+B`D9W)O=7!N86UE("X@)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<&YO=&9O=6YD(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=G<F]U<"==(&%S("1G<F]U
M<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)&=R;W5P6R=A='1R:6)S)UU;)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D9W)O
M=7!N86UE*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N
M9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"$D9F]U;F0I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D97AP;&EC:70I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S
M;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("=787)N:6YG.B!P86-K86=E("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'!N86UE
M+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G(B!H87,@;F\@9&5P96YD96YC>2`G("X@)V=R;W5P(&YA;65D("(G("X@
M)&=R;W5P;F%M92`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&=R;W5P;F]T9F]U;F0@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&=R;W5P*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9W)O=7!;)'!A8VMA9V5T>7!E72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LD<&%C:V%G971Y<&5=6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P6R1P
M86-K86=E='EP95T@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R970@/2`D=&AI<RT^7V1E=&5C=#)$97`H)&1E<"P@)'!N86UE
M+"`G9&5P96YD96YC>2!G<F]U<"`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1G<F]U<%LG871T<FEB<R==6R=N86UE)UT@+B`G(B<L
M("1P87)A;7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1O=VYL;V%D1&5P<UM=(#T@)')E=#L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/E]D971E8W0R1&5P*"1G<F]U
M<%LD<&%C:V%G971Y<&5=+"`D<&YA;64L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1E<&5N9&5N8WD@9W)O=7`@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1G<F]U<%LG871T<FEB<R==6R=N86UE)UT@+B`G
M(B<L("1P87)A;7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D;W=N;&]A9$1E<'-;72`]("1R970[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?9&5T96-T,D1E<"@D9&5P+"`D<&YA;64L("1G<F]U
M<"P@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("!]#0H@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R
M+3YG971/<'1I;VYS*"D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=U<FDG
M72DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G=7)I)R`]/B`D9&5P
M6R=U<FDG72P@)V1E<"<@/3X@)&1E<"D[.PT*("`@("`@("!]#0H@("`@("`@
M("1T97-T9&5P(#T@)&1E<#L-"B`@("`@("`@)'1E<W1D97!;)W!A8VMA9V4G
M72`]("1D97!;)VYA;64G73L-"B`@("`@("`@:68@*%!%05)?1&]W;FQO861E
M<E]086-K86=E.CIW:6QL1&]W;FQO860H)'1E<W1D97`L("1P87)A;7,I*2![
M#0H@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,BP@
M)'1H:7,M/F=E=%-H;W)T3F%M92@I("X@)SH@4VMI<'!I;F<@)R`N("1G<F]U
M<"`N#0H@("`@("`@("`@("`@("`@("`@("<@9&5P96YD96YC>2`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A
M8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D@+@T*("`@("`@("`@("`@
M("`@("`@("`G(BP@=VEL;"!B92!I;G-T86QL960G*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T3W!T:6]N
M<R@I.PT*("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD[#0H@("`@("`@(&EF("@D=&AI<RT^7V5X<&QI8VET4W1A
M=&4I('L-"B`@("`@("`@("`@("1P;F%M95LG<W1A=&4G72`]("1T:&ES+3Y?
M97AP;&EC:713=&%T93L-"B`@("`@("`@?0T*("`@("`@("`D=7)L(#T-"B`@
M("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=$1E<%!A8VMA9V5$
M;W=N;&]A9%5R;"@D9&5P+"`D<&YA;64I.PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D=7)L*2D@>PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@
M('T-"B`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*
M("`@("`@("`D<F5T(#T@)'1H:7,M/E]A;F%L>7IE1&]W;FQO86154DPH)'5R
M;"P@)V1E<&5N9&5N8WDG+"`D9&5P+"`D<&%R86US+"`D9W)O=7`@/3T@)V]P
M=&EO;F%L)R`F)@T*("`@("`@("`@("`@(6ES<V5T*"1O<'1I;VYS6R=A;&QD
M97!S)UTI*3L-"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1R970M/F=E=$UE
M<W-A9V4H*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`O+R!C:&5C
M:R!T;R!S964@:68@82!D97`@:7,@86QR96%D>2!I;G-T86QL960@86YD(&ES
M('1H92!S86UE(&]R(&YE=V5R#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M97!;)VUI;B==*2`F)B`A:7-S970H)&1E<%LG;6%X)UTI("8F("%I<W-E="@D
M9&5P6R=R96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@("`@("1O<&5R
M(#T@)VAA<R<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1O<&5R(#T@)V=T)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("\O(&1O(&YO="!T<GD@=&\@;6]V92!T:&ES(&)E9F]R92!G971$97!086-K
M86=E1&]W;FQO86154DP-"B`@("`@("`@("`@("\O('=E(&-A;B=T(&1E=&5R
M;6EN92!W:&5T:&5R('5P9W)A9&4@:7,@;F5C97-S87)Y('5N=&EL('=E(&MN
M;W<@=VAA=`T*("`@("`@("`@("`@+R\@=F5R<VEO;B!W;W5L9"!B92!D;W=N
M;&]A9&5D#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=F;W)C
M92==*2`F)B`D=&AI<RT^:7-);G-T86QL960H)')E="P@)&]P97(I*2![#0H@
M("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7VEN<W1A;&Q296=I
M<W1R>2T^<&%C:V%G94EN9F\H)&1E<%LG;F%M92==+"`G=F5R<VEO;B<L#0H@
M("`@("`@("`@("`@("`@("`@("1D97!;)V-H86YN96PG72D[#0H@("`@("`@
M("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H
M,RP@)'1H:7,M/F=E=%-H;W)T3F%M92@I("X@)SH@4VMI<'!I;F<@)R`N("1G
M<F]U<"`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(&1E<&5N9&5N8WD@
M(B<@+@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP
M87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("<B('9E<G-I;VX@)R`N("1U<FQ;)W9E<G-I
M;VXG72`N("<L(&%L<F5A9'D@:6YS=&%L;&5D(&%S('9E<G-I;VX@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;BD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG
M;F]D969A=6QT)UTI*2![#0H@("`@("`@("`@("`D<F5T6R=N;V1E9F%U;'0G
M72`]('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7V1E=&5C=#$H)&1E<',L("1P;F%M92P@
M)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1O
M=VYL;V%D1&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("1S:VEP;F%M97,@/2!A
M<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9&5P*2![#0H@
M("`@("`@("`@("`D;F]D;W=N;&]A9"`](&9A;'-E.PT*("`@("`@("`@("`@
M:68@*"1D97!;)W1Y<&4G72`]/2`G<&MG)RD@>PT*("`@("`@("`@("`@("`@
M("1D97!;)V-H86YN96PG72`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@
M("`@("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@
M("`@("`@("`@("!S=VET8V@@*"1D97!;)W)E;"==*2![#0H@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)VYO="<@.@T*("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G9V4G
M(#H-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G97$G(#H-"B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G9W0G(#H-"B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G:&%S)R`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7`@
M/2`H(6ES<V5T*"1D97!;)V]P=&EO;F%L)UTI('Q\("1D97!;)V]P=&EO;F%L
M)UT@/3T@)VYO)RD@/PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M97%U:7)E9"<@.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<'1I
M;VYA;"<[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4E]$;W=N
M;&]A9&5R7U!A8VMA9V4Z.G=I;&Q$;W=N;&]A9"@D9&5P+"`D<&%R86US*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO
M861E<BT^;&]G*#(L("1T:&ES+3YG9713:&]R=$YA;64H*2`N("<Z(%-K:7!P
M:6YG("<@+B`D9W)O=7`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G(&1E<&5N9&5N8WD@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M
M951O4W1R:6YG*"1D97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R(L('=I;&P@8F4@:6YS=&%L;&5D)RD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1F86ME
M9'`@/2!N97<@4$5!4E]086-K86=E1FEL95]V,3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1F86ME9'`M/G-E=%!A8VMA9V4H)&1E<%LG;F%M92==*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O('-K:7`@:6YT97)N970@8VAE
M8VL@:68@=V4@87)E(&YO="!U<&=R861I;F<@*&)U9R`C-3@Q,"D-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W5P9W)A
M9&4G72D@)B8@)'1H:7,M/FES26YS=&%L;&5D*`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9A:V5D<"P@)&1E<%LG<F5L)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL
M;V<H,BP@)'1H:7,M/F=E=%-H;W)T3F%M92@I("X@)SH@4VMI<'!I;F<@)R`N
M("1G<F]U<`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@
M9&5P96YD96YC>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I
M;F<H)&1E<"P@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G(BP@:7,@86QR96%D>2!I;G-T86QL960G*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?97AP;&EC:713=&%T92D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&YA;65;)W-T871E)UT@/2`D=&AI
M<RT^7V5X<&QI8VET4W1A=&4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1U<FP@/0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1O=VYL;V%D97(M/E]G971$97!086-K86=E1&]W;FQO8615<FPH)&1E<"P@
M)'!N86UE*3L-"B`@("`@("`@("`@("`@("`D8VAA;B`]("=P96%R+G!H<"YN
M970G.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1U<FPI
M*2![#0H@("`@("`@("`@("`@("`@("`@("\O(&-H96-K('1O('-E92!I9B!T
M:&ES(&ES(&$@<&5C;"!P86-K86=E('1H870@:&%S(&IU;7!E9`T*("`@("`@
M("`@("`@("`@("`@("`O+R!F<F]M('!E87(N<&AP+FYE="!T;R!P96-L+G!H
M<"YN970@8VAA;FYE;`T*("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP
M)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D;F5W9&5P(#T@4$5!4E]$97!E;F1E;F-Y,CHZ;F]R;6%L:7IE1&5P*"1D
M97`I.PT*("`@("`@("`@("`@("`@("`@("`D;F5W9&5P(#T@)&YE=V1E<%LP
M73L-"B`@("`@("`@("`@("`@("`@("`@)&YE=V1E<%LG8VAA;FYE;"==(#T@
M)W!E8VPN<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@("`@("1C:&%N(#T@
M)W!E8VPN<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@("`@("1U<FP@/0T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?
M9V5T1&5P4&%C:V%G941O=VYL;V%D57)L*"1N97=D97`L("1P;F%M92D[#0H@
M("`@("`@("`@("`@("`@("`@("1O8FH@/2`F)'1H:7,M/E]I;G-T86QL4F5G
M:7-T<GDM/F=E=%!A8VMA9V4H)&1E<%LG;F%M92==*3L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'5R;"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D;V)J("$]/2!N=6QL("8F("1T
M:&ES+3YI<TEN<W1A;&QE9"@D;V)J+"`D9&5P6R=R96PG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7`@/2`H(6ES<V5T*"1D97!;
M)V]P=&EO;F%L)UTI('Q\("1D97!;)V]P=&EO;F%L)UT@/3T@)VYO)RD@/PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#H-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]P=&EO;F%L)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@
M/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@S
M+"`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)SH@4VMI<'!I;F<@)R`N("1G<F]U<"`N("<@
M9&5P96YD96YC>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O
M4W1R:6YG*"1D97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<B+"!A;')E861Y(&EN<W1A;&QE9"!A<R!V97)S:6]N
M("<@+B`D;V)J+3YG971697)S:6]N*"DI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M0"1S:VEP;F%M97-;8V]U;G0H)'-K:7!N86UE<RD@+2`Q72`]/0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM
M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P*"1S:VEP
M;F%M97,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P
M=&EO;F%L)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,BP@)'1H:7,M/F=E
M=%-H;W)T3F%M92@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<Z(%-K:7!P:6YG("<@+B`D9W)O=7`-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R!D97!E;F1E;F-Y("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G
M:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(L(&YO
M(')E;&5A<V5S(&5X:7-T)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=7)L.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2.CIP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG86QL9&5P<R==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG;W!T:6]N86PG72D@)B8@)&1E<%LG;W!T:6]N
M86PG72`]/2`G>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#,L("=.;W1I
M8V4Z('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(B!O<'1I;VYA;"!D97!E;F1E;F-Y("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I
M<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D
M8VAA;BP@)W!A8VMA9V4G(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=N86UE)UTI+"!T<G5E*2`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<B('=I;&P@;F]T(&)E(&%U=&]M871I
M8V%L;'D@9&]W;FQO861E9"<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'-K:7!N86UE<UM=(#T@)'1H
M:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG
M(#T^("1C:&%N+"`G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<%LG;F%M92==*2P@=')U92D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D;F]D;W=N;&]A9"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D;W!T:6]N<ULG86QL9&5P<R==*2`F)B`A:7-S970H
M)&]P=&EO;G-;)V]N;'ER97%D97!S)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&1E<%LG;W!T:6]N86PG72D@?'P@)&1E<%LG;W!T
M:6]N86PG72`]/2`G;F\G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,RP@)TYO
M=&EC93H@<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YG9713:&]R=$YA;64H*2`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B(')E<75I<F5D(&1E<&5N9&5N8WD@(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^
M("1C:&%N+"`G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!;)VYA;64G72DL('1R=64I("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R(@=VEL;"!N;W0@8F4@875T;VUA
M=&EC86QL>2!D;W=N;&]A9&5D)RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<VMI<&YA;65S6UT@/2`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE
M;"<@/3X@)&-H86XL("=P86-K86=E)R`]/@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5P6R=N86UE)UTI+"!T<G5E*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1N;V1O=VYL;V%D(#T@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`O+R!C:&5C:R!T;R!S964@:68@82!D97`@:7,@86QR96%D>2!I;G-T
M86QL960-"B`@("`@("`@("`@("`@("`O+R!D;R!N;W0@=')Y('1O(&UO=F4@
M=&AI<R!B969O<F4@9V5T1&5P4&%C:V%G941O=VYL;V%D55),#0H@("`@("`@
M("`@("`@("`@+R\@=V4@8V%N)W0@9&5T97)M:6YE('=H971H97(@=7!G<F%D
M92!I<R!N96-E<W-A<GD@=6YT:6P@=V4@:VYO=R!W:&%T#0H@("`@("`@("`@
M("`@("`@+R\@=F5R<VEO;B!W;W5L9"!B92!D;W=N;&]A9&5D#0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG9F]R8V4G72D@)B8@)'1H
M:7,M/FES26YS=&%L;&5D*`T*("`@("`@("`@("`@("`@("`@("`@("`@)'5R
M;"P@)&1E<%LG<F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1G<F]U
M<"`]("@A:7-S970H)&1E<%LG;W!T:6]N86PG72D@?'P@)&1E<%LG;W!T:6]N
M86PG72`]/2`G;F\G*2`_#0H@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q
M=6ER960G(#H-"B`@("`@("`@("`@("`@("`@("`@("`@("=O<'1I;VYA;"<[
M#0H@("`@("`@("`@("`@("`@("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N97=D
M97`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("1T
M:&ES+3Y?:6YS=&%L;%)E9VES=')Y+3YP86-K86=E26YF;R@D;F5W9&5P6R=N
M86UE)UTL("=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;F5W9&5P6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D
M=&AI<RT^7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H)&1E<%LG;F%M
M92==+"`G=F5R<VEO;B<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("1D97!;)W9E<G-I;VXG72`]("1U<FQ;)W9E<G-I
M;VXG73L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N
M<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D;W=N;&]A9&5R+3YL;V<H,RP@)'1H:7,M/F=E=%-H;W)T3F%M92@I("X@
M)SH@4VMI<'!I;F<@)R`N("1G<F]U<"`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R!D97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M
M951O4W1R:6YG*"1D97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(BP@86QR96%D>2!I;G-T86QL960@87,@=F5R<VEO;B`G("X@
M)'9E<G-I;VXI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("A`)'-K:7!N86UE<UMC;W5N="@D<VMI<&YA;65S*2`M
M(#%=(#T]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G
M:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<VMI<&YA
M;65S*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1N;V1O=VYL;V%D*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N97=D97`I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1D97`@/2`D;F5W9&5P.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P
M6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3Y?86YA
M;'EZ941O=VYL;V%D55),*"1U<FPL("=D97!E;F1E;F-Y)RP@)&1E<"P@)'!A
M<F%M<RP-"B`@("`@("`@("`@("`@("`@("`@:7-S970H)&1E<%LG;W!T:6]N
M86PG72D@)B8@)&1E<%LG;W!T:6]N86PG72`]/2`G>65S)R`F)@T*("`@("`@
M("`@("`@("`@("`@("`A:7-S970H)&]P=&EO;G-;)V%L;&1E<',G72DI.PT*
M("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D
M97(M/FQO9R@P+"`D<F5T+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL
M;V%D1&5P<UM=(#T@)')E=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H8V]U;G0H)'-K:7!N86UE<RDI('L-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@Q+"`G1&ED(&YO="!D;W=N
M;&]A9"!D97!E;F1E;F-I97,Z("<@+@T*("`@("`@("`@("`@("`@("`@("!I
M;7!L;V1E*"<L("<L("1S:VEP;F%M97,I("X-"B`@("`@("`@("`@("`@("`@
M("`@)RP@=7-E("TM86QL9&5P<R!O<B`M+6]N;'ER97%D97!S('1O(&1O=VYL
M;V%D(&%U=&]M871I8V%L;'DG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$1O=VYL;V%D55),*"1P:V<I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1O=VYL;V%D55),(#T@)'!K9SL-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3970@=&AE('!A8VMA9V4N>&UL
M(&]B:F5C="!F;W(@=&AI<R!D;W=N;&]A9&5D('!A8VMA9V4-"B`@("`@*@T*
M("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G
M949I;&5?=C(@)'!K9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%!A8VMA
M9V5&:6QE*"8D<&MG*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M9FEL92`]("8D<&MG.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%-H;W)T
M3F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]R96=I<W1R
M>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9RAA<G)A>2@G8VAA;FYE;"<@
M/3X@)'1H:7,M/F=E=$-H86YN96PH*2P-"B`@("`@("`@("`@("=P86-K86=E
M)R`]/B`D=&AI<RT^9V5T4&%C:V%G92@I*2P@=')U92D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T4&%R<V5D4&%C:V%G92@I#0H@("`@>R`@(`T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E9FEL92D@?'P@:7-S970H
M)'1H:7,M/E]P87)S961N86UE*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=C:&%N;F5L)R`]/B`D=&AI<RT^9V5T0VAA;FYE;"@I+`T*("`@("`@
M("`@("`@("`@("=P86-K86=E)R`]/B`D=&AI<RT^9V5T4&%C:V%G92@I+`T*
M("`@("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D=&AI<RT^9V5T5F5R<VEO
M;B@I*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T1&]W;FQO86154DPH*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DP[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@8V%N1&5F875L="@I#0H@("`@>PT*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]D;W=N;&]A9%523"DI('L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=N;V1E9F%U;'0G72DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T4&%C:V%G92@I#0H@("`@>PT*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E9FEL92DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E*"D[#0H@("`@
M("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9%52
M3%LG:6YF;R==+3YG971086-K86=E*"D[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q0
M14%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-3
M=6)P86-K86=E*"8D<&8I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!A8VMA9V5F:6QE+3YI<U-U8G!A8VMA9V4H)'!F*3L-"B`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I
M;F9O)UTM/FES4W5B<&%C:V%G92@D<&8I.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T4&%C:V%G951Y<&4H*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G951Y
M<&4H*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?9&]W;FQO
M86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%!A8VMA9V54>7!E*"D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<T)U;F1L92@I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E9FEL92DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG9710
M86-K86=E5'EP92@I(#T]("=B=6YD;&4G.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T4&%C:V%G95AM;%9E<G-I;VXH*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C
M:V%G97AM;%9E<G-I;VXH*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T
M:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%!A8VMA9V5X
M;6Q697)S:6]N*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R
M971U<FX@)S$N,"<[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!G971#:&%N;F5L*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G969I;&4M/F=E=$-H86YN96PH*3L-"B`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM
M/F=E=$-H86YN96PH*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=%5222@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!A8VMA9V5F:6QE+3YG97154DDH*3L-"B`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%52
M22@I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5F5R
M<VEO;B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA
M9V5F:6QE+3YG971697)S:6]N*"D[#0H@("`@("`@('T@96QS96EF("AI<W-E
M="@D=&AI<RT^7V1O=VYL;V%D55),6R=V97)S:6]N)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG=F5R<VEO;B==.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-#;VUP871I8FQE
M*"1P9BD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5F:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M969I;&4M/FES0V]M<&%T:6)L92@D<&8I.PT*("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^:7-#
M;VUP871I8FQE*"1P9BD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T
M:6]N('-E=$=R;W5P*"1G<F]U<"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M<&%R<V5D;F%M95LG9W)O=7`G72`]("1G<F]U<#L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971'<F]U<"@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P87)S961N86UE6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&%R<V5D;F%M95LG9W)O=7`G73L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B`G)SL-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&ES17AT96YS:6]N*"1N86UE*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^:7-%
M>'1E;G-I;VXH)&YA;64I.PT*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H
M:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^9V5T4')O=FED97-%
M>'1E;G-I;VXH*2`]/2`D;F%M93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=$1E<',H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G
M,BXP)RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA
M9V5F:6QE+3YG971$97!S*'1R=64I.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^
M9V5T1&5P<R@I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^9V5T4&%C
M:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=$1E<',H
M=')U92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=$1E<',H
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y(%!A<G-E9"!A<G)A>2!F<F]M('M`
M;&EN:R!014%27U)E9VES=')Y.CIP87)S95!A8VMA9V5.86UE*"E](&]R(&$@
M9&5P96YD96YC>0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M960@9G)O;2!G971$97!$;W=N;&]A9%523"@I#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@:7-%<75A;"@D<&%R86TI#0H@("`@>PT*("`@("`@("!I9B`H:7-?
M;V)J96-T*"1P87)A;2DI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'!A
M<F%M+3YG971#:&%N;F5L*"D[#0H@("`@("`@("`@("`D<&%C:V%G92`]("1P
M87)A;2T^9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@:68@*"1P87)A;2T^
M9V5T55))*"DI('L-"B`@("`@("`@("`@("`@("`D<&%R86T@/2!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1P87)A;2T^9V5T
M0VAA;FYE;"@I+`T*("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@
M)'!A<F%M+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@("=V
M97)S:6]N)R`]/B`D<&%R86TM/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@
M("`@("`@("`@)W5R:2<@/3X@)'!A<F%M+3YG97154DDH*2P-"B`@("`@("`@
M("`@("`@("`I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D<&%R86T@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V-H
M86YN96PG(#T^("1P87)A;2T^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@
M("`@("`@("`G<&%C:V%G92<@/3X@)'!A<F%M+3YG971086-K86=E*"DL#0H@
M("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D<&%R86TM/F=E=%9E
M<G-I;VXH*2P-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A
M;5LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=C:&%N;F5L
M)UT@/2`G7U]U<FDG.PT*("`@("`@("`@("`@("`@("1P87)A;5LG<&%C:V%G
M92==(#T@)'!A<F%M6R=D97`G75LG;F%M92==.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'!A8VMA9V4@/2!I<W-E="@D<&%R86U;)W!A8VMA9V4G
M72D@/R`D<&%R86U;)W!A8VMA9V4G72`Z#0H@("`@("`@("`@("`@("`@)'!A
M<F%M6R=I;F9O)UTM/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("1C:&%N
M;F5L(#T@:7-S970H)'!A<F%M6R=C:&%N;F5L)UTI(#\@)'!A<F%M6R=C:&%N
M;F5L)UT@.@T*("`@("`@("`@("`@("`@("1P87)A;5LG:6YF;R==+3YG971#
M:&%N;F5L*"D[#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M6R=R96PG
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y,BYP:'`G.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D;F5W9&5P(#T@4$5!4E]$97!E;F1E
M;F-Y,CHZ;F]R;6%L:7IE1&5P*"1P87)A;2D[#0H@("`@("`@("`@("`@("`@
M)&YE=V1E<"`]("1N97=D97!;,%T[#0H@("`@("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'!A<F%M6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`D;F5W
M9&5P(#T@)'!A<F%M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D;F5W9&5P*2D@>PT*("`@("`@("`@("`@:68@*"%I
M<W-E="@D;F5W9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`D;F5W
M9&5P6R=M:6XG72`]("<P)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)&YE=V1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@
M("`@)&YE=V1E<%LG;6%X)UT@/2`G,3`P,#`P,#`P,#`P,#`P,#`P,#`P)SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O('5S92!M86=I8R!T;R!S
M=7!P;W)T('!E8VP@<&%C:V%G97,@<W5D9&5N;'D@:G5M<&EN9R!T;R!T:&4@
M<&5C;"!C:&%N;F5L#0H@("`@("`@("`@("`O+R!W92!N965D('1O('-U<'!O
M<G0@8F]T:"!D97!E;F1E;F-Y('!O<W-I8FEL:71I97,-"B`@("`@("`@("`@
M(&EF("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)R`F)B`D=&AI<RT^9V5T
M0VAA;FYE;"@I(#T]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@
M("`@:68@*"1P86-K86=E(#T]("1T:&ES+3YG971086-K86=E*"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&-H86YN96P@/2`G<&5C;"YP:'`N;F5T)SL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H)&-H86YN96P@/3T@)W!E8VPN<&AP+FYE="<@)B8@)'1H:7,M/F=E
M=$-H86YN96PH*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M("`@(&EF("@D<&%C:V%G92`]/2`D=&AI<RT^9V5T4&%C:V%G92@I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@<F5T=7)N("AS=')T;VQO=V5R*"1P86-K86=E*2`]/2!S=')T;VQO=V5R
M*"1T:&ES+3YG971086-K86=E*"DI("8F#0H@("`@("`@("`@("`@("`@)&-H
M86YN96P@/3T@)'1H:7,M/F=E=$-H86YN96PH*2`F)@T*("`@("`@("`@("`@
M("`@('9E<G-I;VY?8V]M<&%R92@D;F5W9&5P6R=M:6XG72P@)'1H:7,M/F=E
M=%9E<G-I;VXH*2P@)SP])RD@)B8-"B`@("`@("`@("`@("`@("!V97)S:6]N
M7V-O;7!A<F4H)&YE=V1E<%LG;6%X)UTL("1T:&ES+3YG971697)S:6]N*"DL
M("<^/2<I*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!U<V4@;6%G:6,@=&\@
M<W5P<&]R="!P96-L('!A8VMA9V5S('-U9&1E;FQY(&IU;7!I;F<@=&\@=&AE
M('!E8VP@8VAA;FYE;`T*("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN
M<&AP+FYE="<@)B8@)'1H:7,M/F=E=$-H86YN96PH*2`]/2`G<&5A<BYP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)'!A8VMA9V4I
M(#T]('-T<G1O;&]W97(H)'1H:7,M/F=E=%!A8VMA9V4H*2DI('L-"B`@("`@
M("`@("`@("`@("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%R86U;
M)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@(')E='5R;B`H<W1R=&]L;W=E
M<B@D<&%C:V%G92D@/3T@<W1R=&]L;W=E<B@D=&AI<RT^9V5T4&%C:V%G92@I
M*2`F)@T*("`@("`@("`@("`@("`@("1C:&%N;F5L(#T]("1T:&ES+3YG971#
M:&%N;F5L*"D@)B8-"B`@("`@("`@("`@("`@("`D<&%R86U;)W9E<G-I;VXG
M72`]/2`D=&AI<RT^9V5T5F5R<VEO;B@I*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(')E='5R;B!S=')T;VQO=V5R*"1P86-K86=E*2`]/2!S
M=')T;VQO=V5R*"1T:&ES+3YG971086-K86=E*"DI("8F#0H@("`@("`@("`@
M("`@("`@)&-H86YN96P@/3T@)'1H:7,M/F=E=$-H86YN96PH*3L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES26YS=&%L;&5D*"1D97`L
M("1O<&5R(#T@)ST])RD-"B`@("![#0H@("`@("`@(&EF("@A)&1E<"D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D;W!E<B`A/2`G9V4G("8F("1O<&5R("$]("=G="<@)B8@)&]P97(@
M(3T@)VAA<R<@)B8@)&]P97(@(3T@)ST])RD@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<U]O8FIE8W0H
M)&1E<"DI('L-"B`@("`@("`@("`@("1P86-K86=E(#T@)&1E<"T^9V5T4&%C
M:V%G92@I.PT*("`@("`@("`@("`@)&-H86YN96P@/2`D9&5P+3YG971#:&%N
M;F5L*"D[#0H@("`@("`@("`@("!I9B`H)&1E<"T^9V5T55))*"DI('L-"B`@
M("`@("`@("`@("`@("`D9&5P(#T@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("=U<FDG(#T^("1D97`M/F=E=%5222@I+`T*("`@("`@("`@("`@("`@
M("`@("`G=F5R<VEO;B<@/3X@)&1E<"T^9V5T5F5R<VEO;B@I+`T*("`@("`@
M("`@("`@("`@("D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1D97`@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W9E
M<G-I;VXG(#T^("1D97`M/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@("`@
M("`I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@("`@("`@
M("`@("1C:&%N;F5L(#T@)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`D<&%C
M:V%G92`]("1D97!;)V1E<"==6R=N86UE)UT[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)&1E<%LG:6YF;R==
M+3YG971#:&%N;F5L*"D[#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`D
M9&5P6R=I;F9O)UTM/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E
M<BT^9V5T3W!T:6]N<R@I.PT*("`@("`@("`D=&5S="`]("1T:&ES+3Y?:6YS
M=&%L;%)E9VES=')Y+3YP86-K86=E17AI<W1S*"1P86-K86=E+"`D8VAA;FYE
M;"D[#0H@("`@("`@(&EF("@A)'1E<W0@)B8@)&-H86YN96P@/3T@)W!E8VPN
M<&AP+FYE="<I('L-"B`@("`@("`@("`@("\O(&1O(&UA9VEC('1O(&%L;&]W
M('5P9W)A9&EN9R!F<F]M(&]L9"!P96-L('!A8VMA9V5S('1O(&YE=R!O;F5S
M#0H@("`@("`@("`@("`D=&5S="`]("1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y
M+3YP86-K86=E17AI<W1S*"1P86-K86=E+"`G<&5A<BYP:'`N;F5T)RD[#0H@
M("`@("`@("`@("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D=&5S="D@>PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=U
M<FDG+"`G7U]U<FDG*2`]/2`D9&5P6R=U<FDG72D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W5P
M9W)A9&4G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&]P97(@/3T@)VAA
M<R<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R
M92@D=&AI<RT^7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E+"`G=F5R<VEO;B<L("1C
M:&%N;F5L*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG=F5R
M<VEO;B==+"`G/CTG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1T:&ES+3Y?:6YS
M=&%L;%)E9VES=')Y+3YP86-K86=E26YF;R@-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H86YN96PI+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=V97)S:6]N)UTL("<^/2<I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A
M;2!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!R96UO=F5$=7!L:6-A=&5S*"8D<&%R86US*0T*("`@('L-"B`@("`@("`@
M)'!N86UE<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@
M87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("!I9B`H(21P87)A;2D@
M>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1P87)A;2T^9V5T4&%C:V%G92@I*2![#0H@("`@
M("`@("`@("`@("`@)'!N86UE<ULD:5T@/2`D<&%R86TM/F=E=$-H86YN96PH
M*2`N("<O)R`N#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2T^9V5T4&%C
M:V%G92@I("X@)RTG("X@)'!A<F%M+3YG971697)S:6]N*"D@+B`G(R<@+B`D
M<&%R86TM/F=E=$=R;W5P*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@)'!N86UE<R`](&%R<F%Y7W5N:7%U92@D<&YA;65S*3L-"B`@
M("`@("`@)'5N<V5T(#T@87)R87E?9&EF9BAA<G)A>5]K97ES*"1P87)A;7,I
M+"!A<G)A>5]K97ES*"1P;F%M97,I*3L-"B`@("`@("`@)'1E<W1P(#T@87)R
M87E?9FQI<"@D<&YA;65S*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D:2`]/B`D<&%R86TI('L-"B`@("`@("`@("`@(&EF("@A)'!A<F%M*2![
M#0H@("`@("`@("`@("`@("`@)'5N<V5T6UT@/2`D:3L-"B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@A:7-?82@D<&%R86TL("=014%27T1O=VYL;V%D97)?4&%C:V%G92<I*2![
M#0H@("`@("`@("`@("`@("`@)'5N<V5T6UT@/2`D:3L-"B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)'1E<W1P6R1P87)A;2T^9V5T0VAA;FYE;"@I("X@)R\G("X@
M)'!A<F%M+3YG971086-K86=E*"D@+B`G+2<@+@T*("`@("`@("`@("`@("`@
M("`@)'!A<F%M+3YG971697)S:6]N*"D@+B`G(R<@+B`D<&%R86TM/F=E=$=R
M;W5P*"E=*2D@>PT*("`@("`@("`@("`@("`@("1U;G-E=%M=(#T@)&D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'5N
M<V5T(&%S("1I*2![#0H@("`@("`@("`@("!U;G-E="@D<&%R86US6R1I72D[
M#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@
M(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@
M("`@("`D<F5T6UT@/2`F)'!A<F%M<ULD:5T[#0H@("`@("`@('T-"B`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1R970@
M87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("`D<&%R86US6UT@/2`F
M)')E=%LD:5T[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!E
M>'!L:6-I=%-T871E*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^
M7V5X<&QI8VET4W1A=&4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T17AP
M;&EC:713=&%T92@D<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?97AP;&EC
M:713=&%T92`]("1S.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!S=&%T
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!M97)G941E<&5N9&5N8VEE<R@F
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1N97=P87)A;7,@/2!A<G)A>2@I
M.PT*("`@("`@("`D8G5N9&QE<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A
M8V@@*"1P87)A;7,@87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("!I
M9B`H(21P87)A;2T^:7-"=6YD;&4H*2D@>PT*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&)U;F1L97-;
M72`]("1I.PT*("`@("`@("`@("`@)'!F(#T@)B1P87)A;2T^9V5T4&%C:V%G
M949I;&4H*3L-"B`@("`@("`@("`@("1N97=D97!S(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("1C;VYT96YT<R`]("1P9BT^9V5T0G5N9&QE9%!A8VMA9V5S
M*"D[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C;VYT96YT<RDI('L-
M"B`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!A<G)A>2@D8V]N=&5N=',I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&-O;G1E
M;G1S(&%S("1F:6QE*2![#0H@("`@("`@("`@("`@("`@)&9I;&5C;VYT96YT
M<R`]("1P9BT^9V5T1FEL94-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@("`@
M("`@("`D9&P@/2`F)'!A<F%M+3YG971$;W=N;&]A9&5R*"D[#0H@("`@("`@
M("`@("`@("`@)&]P=&EO;G,@/2`D9&PM/F=E=$]P=&EO;G,H*3L-"B`@("`@
M("`@("`@("`@("`D9G`@/2!`9F]P96XH)&1L+3YG971$;W=N;&]A9$1I<B@I
M("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE+"`G=V(G*3L-"B`@("`@
M("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M9G=R:71E*"1F<"P@)&9I;&5C;VYT96YT<RP@<W1R;&5N*"1F:6QE8V]N=&5N
M=',I*3L-"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M("`@("`@("!I9B`H)',@/2`D<&%R86US6R1I72T^97AP;&EC:713=&%T92@I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1O8FHM/G-E=$5X<&QI8VET4W1A
M=&4H)',I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M;V)J(#T@)FYE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D<&%R86US6R1I
M72T^9V5T1&]W;FQO861E<B@I*3L-"B`@("`@("`@("`@("`@("!014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("`@("`@("`@)&4@/2`D;V)J+3Y?9G)O;49I;&4H)&$@/2`D9&PM/F=E=$1O
M=VYL;V%D1&ER*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4I.PT*
M("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1L+3YL;V<H,"P@)&4M/F=E
M=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1J(#T@)B1O8FH[#0H@("`@("`@("`@("`@("`@:68@
M*"%014%27T1O=VYL;V%D97)?4&%C:V%G93HZ=VEL;$1O=VYL;V%D*"1J+`T*
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1P87)A;7,L("1N
M97=P87)A;7,I*2`F)B`A)'!A<F%M+3YI<TEN<W1A;&QE9"@D:BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&YE=W!A<F%M<UM=(#T@)B1J.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H("@D8G5N9&QE<R!A<R`D:2D@>PT*("`@("`@("`@("`@=6YS
M970H)'!A<F%M<ULD:5TI.R`O+R!R96UO=F4@8G5N9&QE<R`M(&]N;'D@=&AE
M:7(@8V]N=&5N=',@;6%T=&5R(&9O<B!I;G-T86QL871I;VX-"B`@("`@("`@
M?0T*("`@("`@("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M;W9E1'5P
M;&EC871E<R@D<&%R86US*3L@+R\@<W1R:7`@86YY('5N<V5T(&EN9&EC97,-
M"B`@("`@("`@:68@*&-O=6YT*"1N97=P87)A;7,I*2![("\O(&%D9"!I;B!B
M=6YD;&5D('!A8VMA9V5S(&9O<B!I;G-T86QL#0H@("`@("`@("`@("!F;W)E
M86-H("@D;F5W<&%R86US(&%S("1I(#T^("1U;G5S960I('L-"B`@("`@("`@
M("`@("`@("`D<&%R86US6UT@/2`F)&YE=W!A<F%M<ULD:5T[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D;F5W<&%R86US(#T@87)R87DH*3L-"B`@
M("`@("`@?0T*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1I(#T^("1P
M87)A;2D@>PT*("`@("`@("`@("`@)&YE=V1E<',@/2!A<G)A>2@I.PT*("`@
M("`@("`@("`@9F]R96%C:"`H)'!A<F%M+3Y?9&]W;FQO861$97!S(&%S("1D
M97`I('L-"B`@("`@("`@("`@("`@("!I9B`H(5!%05)?1&]W;FQO861E<E]0
M86-K86=E.CIW:6QL1&]W;FQO860H)&1E<"P-"B`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]M97)G92@D<&%R86US+"`D;F5W<&%R86US*2D@)B8@(21P
M87)A;2T^:7-);G-T86QL960H)&1E<"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)&YE=V1E<'-;72`]("1D97`[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@+R\@9&5T96-T('9E<G-I;VYI;F<@
M8V]N9FQI8W1S(&AE<F4-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`O+R!C;VYV97)T('1H92!D97!E;F1E;F-I97,@
M:6YT;R!014%27T1O=VYL;V%D97)?4&%C:V%G92!O8FIE8W1S(&9O<B!T:&4@
M;F5X="!T:6UE#0H@("`@("`@("`@("`O+R!A<F]U;F0-"B`@("`@("`@("`@
M("1P87)A;7-;)&E=+3Y?9&]W;FQO861$97!S(#T@87)R87DH*3L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1N97=D97!S(&%S("1D97`I('L-"B`@("`@("`@
M("`@("`@("`D;V)J(#T@)FYE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D
M<&%R86US6R1I72T^9V5T1&]W;FQO861E<B@I*3L-"B`@("`@("`@("`@("`@
M("!I9B`H)',@/2`D<&%R86US6R1I72T^97AP;&EC:713=&%T92@I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1O8FHM/G-E=$5X<&QI8VET4W1A=&4H)',I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("`@("`@("`@)&4@/2`D;V)J+3YF<F]M1&5P55),*"1D97`I.PT*("`@("`@
M("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]B:BT^7V1O=VYL;V%D97(M/FQO9R@P
M+"`D92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)&4@/2`D;V)J+3YD971E8W1$97!E;F1E
M;F-I97,H)'!A<F%M<RD[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1O8FHM/E]D;W=N;&]A9&5R+3YL;V<H,"P@)&4M/F=E=$UE<W-A9V4H*2D[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&H@/2`F)&]B:CL-"B`@("`@("`@("`@("`@("`D
M;F5W<&%R86US6UT@/2`F)&H[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&-O=6YT*"1N97=P87)A;7,I*2![#0H@("`@("`@("`@
M("!F;W)E86-H("@D;F5W<&%R86US(&%S("1I(#T^("1U;G5S960I('L-"B`@
M("`@("`@("`@("`@("`D<&%R86US6UT@/2`F)&YE=W!A<F%M<ULD:5T[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@('T-"@T*#0H@("`@+RHJ#0H@("`@("H@0'-T871I8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N('=I;&Q$;W=N;&]A9"@D<&%R86TL("1P87)A
M;7,I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D;V)J*2![#0H@("`@("`@("`@("!I
M9B`H)&]B:BT^:7-%<75A;"@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($9O
M<B!S:6UP;&5R('5N:70M=&5S=&EN9PT*("`@("`J($!P87)A;2!014%27T-O
M;F9I9PT*("`@("`J($!P87)A;2!I;G0-"B`@("`@*B!`<&%R86T@<W1R:6YG
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5F:6QE3V)J96-T
M*"8D8RP@)&0L("1T(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D82`]("9N
M97<@4$5!4E]086-K86=E1FEL92@D8RP@)&0L("1T*3L-"B`@("`@("`@<F5T
M=7)N("1A.PT*("`@('T-"@T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!W:6QL
M(')E=')I979E(&9R;VT@82!L;V-A;"!F:6QE(&EF('!O<W-I8FQE+"!A;F0@
M<&%R<V4@;W5T#0H@("`@("H@82!G<F]U<"!N86UE(&%S('=E;&PN("!4:&4@
M;W)I9VEN86P@<&%R86UE=&5R('=I;&P@8F4@;6]D:69I960@=&\@<F5F;&5C
M="!T:&ES+@T*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@8V%N(&)E(&$@
M<&%R<V5D('!A8VMA9V4@;F%M92!A<R!W96QL#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V9R;VU&:6QE*"8D<&%R
M86TI#0H@("`@>PT*("`@("`@("!I9B`H:7-?<W1R:6YG*"1P87)A;2D@)B8@
M(4!I<U]F:6QE*"1P87)A;2DI('L-"B`@("`@("`@("`@("1T97-T(#T@97AP
M;&]D92@G(R<L("1P87)A;2D[#0H@("`@("`@("`@("`D9W)O=7`@/2!A<G)A
M>5]P;W`H)'1E<W0I.PT*("`@("`@("`@("`@:68@*$!I<U]F:6QE*&EM<&QO
M9&4H)R,G+"`D=&5S="DI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$=R;W5P*"1G<F]U<"D[#0H@("`@("`@("`@("`@("`@)'!A<F%M(#T@:6UP
M;&]D92@G(R<L("1T97-T*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5X
M<&QI8VET1W)O=7`@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("A`:7-?9FEL92@D<&%R86TI*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7W1Y<&4@/2`G;&]C86PG.PT*("`@("`@("`@("`@)&]P=&EO
M;G,@/2`D=&AI<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G969I
M;&5/8FIE8W0H)'1H:7,M/E]C;VYF:6<L#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&]W;FQO861E<BT^7V1E8G5G*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C
M:V%G969I;&5/8FIE8W0H)'1H:7,M/E]C;VYF:6<L#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^7V1E8G5G+"`D=&AI<RT^7V1O
M=VYL;V%D97(M/F=E=$1O=VYL;V%D1&ER*"DI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PT*("`@("`@("`@("`@)'!F(#T@)B1P:V<M/F9R;VU!;GE&
M:6QE*"1P87)A;2P@4$5!4E]604Q)1$%415])3E-404Q,24Y'*3L-"B`@("`@
M("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1P9CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G969I;&4@/2`F)'!F.PT*("`@("`@("`@("`@:68@*"$D=&AI<RT^9V5T
M1W)O=7`H*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YS971'<F]U<"@G
M9&5F875L="<I.R`O+R!I;G-T86QL('1H92!D969A=6QT(&1E<&5N9&5N8WD@
M9W)O=7`-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W9A;&ED(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]V86QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(%]F<F]M57)L*"1P87)A;2P@)'-A=F5P87)A;2`]("<G*0T*("`@('L-"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86TI("8F#0H@("`@("`@("`@("`@
M("AP<F5G7VUA=&-H*"<C7BAH='1P?&9T<"DZ+R\C)RP@)'!A<F%M*2DI('L-
M"B`@("`@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG
M971/<'1I;VYS*"D[#0H@("`@("`@("`@("`D=&AI<RT^7W1Y<&4@/2`G=7)L
M)SL-"B`@("`@("`@("`@("1C86QL8F%C:R`]("1T:&ES+3Y?9&]W;FQO861E
M<BT^=6D@/PT*("`@("`@("`@("`@("`@(&%R<F%Y*"8D=&AI<RT^7V1O=VYL
M;V%D97(L("=?9&]W;FQO861#86QL8F%C:R<I(#H@;G5L;#L-"B`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^
M7V1O=VYL;V%D97(M/F1O=VYL;V%D2'1T<"@D<&%R86TL("1T:&ES+3Y?9&]W
M;FQO861E<BT^=6DL#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9&5R+3YG971$;W=N;&]A9$1I<B@I+"`D8V%L;&)A8VLI.PT*("`@("`@("`@
M("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL92DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1S879E<&%R86TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1S879E<&%R86T@/2`B+"!C86YN;W0@9&]W;FQO860@
M7"(D<V%V97!A<F%M7"(B.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&1O
M=VYL;V%D(&9R;VT@(B<@+B`D<&%R86T@+@T*("`@("`@("`@("`@("`@("`@
M("`G(B<@+B`D<V%V97!A<F%M*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1E<G([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]R87=P86-K86=E9FEL92D@>PT*("`@("`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G07)C:&EV92]487(N<&AP)SL-"B`@("`@("`@("`@("`@("`D
M=&%R(#T@)FYE=R!!<F-H:79E7U1A<B@D9FEL92D[#0H@("`@("`@("`@("`@
M("`@)'!A8VMA9V5X;6P@/2`D=&%R+3YE>'1R86-T26Y3=')I;F<H)W!A8VMA
M9V4R+GAM;"<I.PT*("`@("`@("`@("`@("`@(&EF("@A)'!A8VMA9V5X;6PI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5X;6P@/2`D=&%R+3YE
M>'1R86-T26Y3=')I;F<H)W!A8VMA9V4N>&UL)RD[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AS=')?<F5P;&%C92AA<G)A>2@B
M7&XB+"`B7'(B*2P@87)R87DH)R<L)R<I+"`D<&%C:V%G97AM;"D@(3T-"B`@
M("`@("`@("`@("`@("`@("`@("!S=')?<F5P;&%C92AA<G)A>2@B7&XB+"`B
M7'(B*2P@87)R87DH)R<L)R<I+"`D=&AI<RT^7W)A=W!A8VMA9V5F:6QE*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=$-H86YN96PH
M*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@8F4@;6]R92!L87@@9F]R('1H92!E>&ES=&EN9R!014%2('!A8VMA
M9V5S('1H870@:&%V92!N;W0M;VL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&-H87)A8W1E<G,@:6X@=&AE:7(@<&%C:V%G92YX;6P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("=#
M4DE424-!3"!705).24Y'.B!4:&4@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YG971086-K86=E*"D@+B`G(B!P86-K86=E(&AA
M<R!I;G9A;&ED(&-H87)A8W1E<G,@:6X@:71S("<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P86-K86=E+GAM;"X@(%1H92!N97AT('9E<G-I
M;VX@;V8@4$5!4B!M87D@;F]T(&)E(&%B;&4@=&\@:6YS=&%L;"`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=&AI<R!P86-K86=E(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@4&QE87-E(&]P96X@82!B=6<@<F5P;W)T(&%T
M("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O)R`N("1T:&ES+3YG971086-K86=E*"D@+B`G
M+V)U9W,G*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#
M4DE424-!3"!%4E)/4CH@<&%C:V%G92YX;6P@9&]W;FQO861E9"!D;V5S("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N;W0@;6%T8V@@=F%L
M=64@<F5T=7)N960@9G)O;2!X;6PM<G!C)RD[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`O+R!W:&5W+"!D;W=N;&]A9"!W;W)K960A#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@
M("`@("`@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5F:6QE3V)J
M96-T*"1T:&ES+3Y?8V]N9FEG+"`D=&AI<RT^7V1O=VYL;V%D97(M/F1E8G5G
M*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'!K
M9R`]("8D=&AI<RT^9V5T4&%C:V%G969I;&5/8FIE8W0H)'1H:7,M/E]C;VYF
M:6<L("1T:&ES+3Y?9&]W;FQO861E<BT^9&5B=6<L#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T1&]W;FQO861$:7(H*2D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D<&8@
M/2`F)'!K9RT^9G)O;4%N>49I;&4H)&9I;&4L(%!%05)?5D%,241!5$5?24Y3
M5$%,3$E.1RD[#0H@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG
M*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@
M("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P9BT^9V5T57-E<DEN9F\H
M*2DI('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG9715
M<V5R26YF;R@I(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E<G(@/2`D97)R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,"P@(E9A;&ED871I
M;VX@17)R;W(Z("1E<G(B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G
M*#`L("1P9BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H)T1O=VYL
M;V%D(&]F("(G("X@*"1S879E<&%R86T@/R`D<V%V97!A<F%M(#H-"B`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M*2`N("<B('-U8V-E961E9"P@8G5T(&ET
M(&ES(&YO="!A('9A;&ED('!A8VMA9V4@87)C:&EV92<I.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:60@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G969I;&4@/2`F)'!F.PT*("`@("`@("`@("`@)'1H:7,M
M/G-E=$=R;W5P*"=D969A=6QT)RD[("\O(&EN<W1A;&P@=&AE(&1E9F%U;'0@
M9&5P96YD96YC>2!G<F]U<`T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=F%L:60@/2!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI
M<RT^7W9A;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y('!A<W,@:6X@86X@87)R87D@
M;V8@9F]R;6%T#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)W!N
M86UE)RP-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(%LG8VAA;FYE;"<@
M/3X@)V-H86YN86UE)RQ=#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!;
M)W9E<G-I;VXG(#T^("=V97)S:6]N)RQ=#0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("!;)W-T871E)R`]/B`G<W1A=&4G+%TI#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!O<B!A('-T<FEN9R!O9B!F;W)M870@6V-H86YN86UE
M+UUP;F%M95LM=F5R<VEO;GPM<W1A=&5=#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7V9R;VU3=')I;F<H)'!A<F%M*0T*("`@('L-"B`@("`@("`@)&]P=&EO
M;G,@/2`D=&AI<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@
M("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`D<&YA;64@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S95!A
M8VMA9V5.86UE*"1P87)A;2P-"B`@("`@("`@("`@("1T:&ES+3Y?8V]N9FEG
M+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I*3L-"B`@("`@("`@4$5!4CHZ<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<&YA;64I*2![#0H@("`@("`@("`@("!I9B`H)'!N86UE+3YG971#;V1E*"D@
M/3T@)VEN=F%L:60G*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<&YA;64M/F=E=$-O9&4H
M*2`]/2`G8VAA;FYE;"<I('L-"B`@("`@("`@("`@("`@("`D<&%R<V5D(#T@
M)'!N86UE+3YG9715<V5R26YF;R@I.PT*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V1O=VYL;V%D97(M/F1I<V-O=F5R*"1P87)S961;)V-H86YN96PG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]N9FEG
M+3YG970H)V%U=&]?9&ES8V]V97(G*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!N86UE(#T@)'1H:7,M
M/E]R96=I<W1R>2T^<&%R<V5086-K86=E3F%M92@D<&%R86TL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYF:6<M/F=E="@G9&5F
M875L=%]C:&%N;F5L)RDI.PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("=#:&%N;F5L("(G("X@
M)'!A<G-E9%LG8VAA;FYE;"==("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R(@:7,@;F]T(&EN:71I86QI>F5D+"!U<V4@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B<&5A<B!C:&%N;F5L+61I
M<V-O=F5R("<@+B`D<&%R<V5D6R=C:&%N;F5L)UT@+B`G(B!T;R!I;FET:6%L
M:7IE)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<B!P
M96%R(&-O;F9I9RUS970@875T;U]D:7-C;W9E<B`Q)RD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'!N86UE*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`D<&YA;64M/F=E=$UE<W-A
M9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)A;2`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A
M8VMA9V5.86UE5&]3=')I;F<H)'!A<F%M*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G:6YV86QI9"!P86-K86=E(&YA;64O<&%C:V%G92!F:6QE("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2`N("<B)RD[#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:60@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1P;F%M92T^9V5T365S
M<V%G92@I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H)VEN=F%L:60@<&%C:V%G92!N86UE
M+W!A8VMA9V4@9FEL92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1P87)A
M;2`N("<B)RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9"`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]T
M>7!E*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]T>7!E(#T@)WAM;')P8R<[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P87)S961N86UE(#T@)'!N
M86UE.PT*("`@("`@("!I9B`H:7-S970H)'!N86UE6R=S=&%T92==*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]E>'!L:6-I=%-T871E(#T@)'!N86UE6R=S
M=&%T92==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]E>'!L:6-I=%-T871E(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1P;F%M95LG9W)O=7`G72DI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?97AP;&EC:71'<F]U<"`]('1R=64[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D=&AI<RT^7V5X<&QI8VET1W)O=7`@/2!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D:6YF;R`]("1T:&ES+3Y?9&]W;FQO861E
M<BT^7V=E=%!A8VMA9V5$;W=N;&]A9%5R;"@D<&YA;64I.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(&EF("@D
M<&YA;65;)V-H86YN96PG72`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@
M("`@("`@("`@("\O('1R>2!P96-L#0H@("`@("`@("`@("`@("`@)'!N86UE
M6R=C:&%N;F5L)UT@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@("`@("`@
M("!I9B`H)'1E<W0@/2`D=&AI<RT^7V1O=VYL;V%D97(M/E]G971086-K86=E
M1&]W;FQO8615<FPH)'!N86UE*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(5!%05(Z.FES17)R;W(H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;R`](%!%05(Z.G)A:7-E17)R;W(H)&EN9F\M/F=E=$UE
M<W-A9V4H*2`N("<@+2!P86-K86=E("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H)'!N86UE+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R!C86X@8F4@:6YS=&%L;&5D('=I=&@@(G!E8VP@:6YS=&%L
M;"`G("X@)'!N86UE6R=P86-K86=E)UT@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<B)RD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&YA;65;)V-H86YN96PG72`]
M("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'!N
M86UE6R=C:&%N;F5L)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&EN
M9F\[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]R87=P86-K86=E9FEL
M92`]("1I;F9O6R=R87<G73L-"B`@("`@("`@)')E="`]("1T:&ES+3Y?86YA
M;'EZ941O=VYL;V%D55),*"1I;F9O+"`D<&%R86TL("1P;F%M92D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("!R
M971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')E="D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9%523"`]("1R970[#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]V86QI9"`]("AB;V]L*2`D<F5T.PT*
M("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&]U='!U="!O9B!P86-K86=E+F=E=$1O=VYL;V%D55),#0H@("`@("H@
M0'!A<F%M('-T<FEN9WQA<G)A>7QO8FIE8W0@:6YF;W)M871I;VX@9F]R(&1E
M=&5C=&EN9R!P86-K86=E<R!T;R!B92!D;W=N;&]A9&5D+"!A;F0-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@97)R;W)S#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&YA;64@:6YF;W)M871I;VX@;V8@=&AE('!A8VMA
M9V4-"B`@("`@*B!`<&%R86T@87)R87E\;G5L;"!P86-K86=E<R!T;R!B92!D
M;W=N;&]A9&5D#0H@("`@("H@0'!A<F%M(&)O;VP@:7,@=&AI<R!A;B!O<'1I
M;VYA;"!D97!E;F1E;F-Y/PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]A;F%L>7IE1&]W;FQO86154DPH)&EN9F\L
M("1P87)A;2P@)'!N86UE+"`D<&%R86US(#T@;G5L;"P@)&]P=&EO;F%L(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7W-T<FEN9R@D<&%R86TI
M("8F(%!%05)?1&]W;FQO861E<E]086-K86=E.CIW:6QL1&]W;FQO860H)'!A
M<F%M+"`D<&%R86US*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)&EN9F\I('L-"B`@("`@("`@("`@
M(&EF("@A:7-?<W1R:6YG*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@("`D
M<V%V97!A<F%M(#T@(BP@8V%N;F]T(&1O=VYL;V%D(%PB)'!A<F%M7"(B.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<V%V97!A
M<F%M(#T@)R<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!N;R!R
M96QE87-E<R!E>&ES=`T*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)TYO(')E;&5A<V5S(&9O<B!P86-K86=E("(G("X-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O
M4W1R:6YG*"1P;F%M92P@=')U92D@+B`G(B!E>&ES="<@+B`D<V%V97!A<F%M
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF;ULG
M:6YF;R==+3YG971#:&%N;F5L*"DI("$]('-T<G1O;&]W97(H)'!N86UE6R=C
M:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`D97)R(#T@9F%L<V4[#0H@("`@
M("`@("`@("!I9B`H)'!N86UE6R=C:&%N;F5L)UT@/3T@)W!E8VPN<&AP+FYE
M="<I('L-"B`@("`@("`@("`@("`@("!I9B`H)&EN9F];)VEN9F\G72T^9V5T
M0VAA;FYE;"@I("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`@
M("`@("`@("1E<G(@/2!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T@96QS96EF("@D:6YF;ULG:6YF;R==+3YG971#:&%N;F5L*"D@
M/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("!I9B`H)'!N
M86UE6R=C:&%N;F5L)UT@(3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&5R<B`]('1R=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D97)R(#T@
M=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D97)R*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U-%
M0U522519($524D]2.B!P86-K86=E(&EN(&-H86YN96P@(B<@+B`D<&YA;65;
M)V-H86YN96PG72`N#0H@("`@("`@("`@("`@("`@("`@("<B(')E=')I979E
M9"!A;F]T:&5R(&-H86YN96Q<)W,@;F%M92!F;W(@9&]W;FQO860A("@B)R`N
M#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=I;F9O)UTM/F=E=$-H86YN
M96PH*2`N("<B*2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("@A:7-S970H)&EN9F];)W5R;"==*2D@>PT*("`@("`@("`@("`@
M)&EN<W1E860@/2`@)RP@=VEL;"!I;G-T96%D(&1O=VYL;V%D('9E<G-I;VX@
M)R`N("1I;F9O6R=V97)S:6]N)UT@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)RP@<W1A8FEL:71Y("(G("X@)&EN9F];)VEN9F\G72T^9V5T4W1A=&4H
M*2`N("<B)SL-"B`@("`@("`@("`@("\O(')E;&5A<V5S(&5X:7-T+"!B=70@
M=V4@9F%I;&5D('1O(&=E="!A;GD-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V1O=VYL;V%D97(M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<&YA;65;)W9E<G-I;VXG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'9S(#T@)RP@=F5R<VEO;B`B)R`N("1P
M;F%M95LG=F5R<VEO;B==("X@)R(G.PT*("`@("`@("`@("`@("`@('T@96QS
M96EF("AI<W-E="@D<&YA;65;)W-T871E)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1V<R`]("<L('-T86)I;&ET>2`B)R`N("1P;F%M95LG<W1A=&4G
M72`N("<B)SL-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M(#T]
M("=D97!E;F1E;F-Y)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@G4$5!4E]#;VUM;VXG*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:6Y?87)R87DH)&EN9F];)VEN9F\G72T^9V5T4W1A=&4H*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@4$5!4E]#;VUM;VXZ.F)E='1E<E-T871E<R@D
M=&AI<RT^7V-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2P@=')U92DI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;F%L*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@9&]N)W0@<W!I="!O
M=70@8V]N9G5S:6YG(&5R<F]R(&UE<W-A9V4-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C
M:V%G941O=VYL;V%D57)L*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<&%C:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L
M)R`]/B`D<&YA;65;)V-H86YN96PG72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N
M)UTI*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1V<R`]("<@=VET:&EN('!R969E<G)E9"!S=&%T92`B
M)R`N("1T:&ES+3Y?8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B<[#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1E
M<&5N9&5N8WDR+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;F%L*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@9&]N)W0@<W!I="!O=70@8V]N
M9G5S:6YG(&5R<F]R(&UE<W-A9V4-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C:V%G941O
M=VYL;V%D57)L*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<&%C:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D
M<&YA;65;)V-H86YN96PG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N)UTI*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1V<R`](%!%05)?1&5P96YD96YC>3(Z.E]G971%>'1R85-T<FEN
M9R@D<&YA;64I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN<W1E860@
M/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1V<R`]("<@=VET:&EN
M('!R969E<G)E9"!S=&%T92`B)R`N("1T:&ES+3Y?8V]N9FEG+3YG970H#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G<')E9F5R<F5D7W-T871E)RD@+B`G
M(B<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,2P@)U=!4DY)3D<Z(&9A:6QE
M9"!T;R!D;W=N;&]A9"`G("X@)'!N86UE6R=C:&%N;F5L)UT@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)R\G("X@)'!N86UE6R=P86-K86=E)UT@+B`D
M=G,@+B`D:6YS=&5A9"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("\O(&1O=VYL;V%D('1H92!L871E<W0@<F5L96%S90T*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D97(M/E]G971086-K
M86=E1&]W;FQO8615<FPH#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P
M86-K86=E)R`]/B`D<&YA;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&EN9F];
M)W9E<G-I;VXG72DI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`O+R!C;VYS=')U8W0@:&5L<&9U;"!E<G)O<B!M97-S86=E#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P;F%M95LG=F5R<VEO;B==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=G,@/2`G+"!V97)S:6]N("(G("X@
M)'!N86UE6R=V97)S:6]N)UT@+B`G(B<[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1P;F%M95LG<W1A=&4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'9S(#T@)RP@<W1A8FEL:71Y("(G("X@)'!N86UE6R=S=&%T
M92==("X@)R(G.PT*("`@("`@("`@("`@("`@('T@96QS96EF("@D<&%R86T@
M/3T@)V1E<&5N9&5N8WDG*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I;E]A<G)A>2@D:6YF;ULG:6YF;R==+3YG9713=&%T92@I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("!014%27T-O;6UO;CHZ8F5T=&5R4W1A=&5S
M*"1T:&ES+3Y?8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I+"!T<G5E
M*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;W!T:6]N86PI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!D;VXG="!S<&ET
M(&]U="!C;VYF=7-I;F<@97)R;W(@;65S<V%G92P@86YD(&1O;B=T(&1I92!O
M;@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&]P=&EO;F%L(&1E
M<"!F86EL=7)E(0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1O=VYL;V%D97(M/E]G971086-K86=E1&]W;FQO8615<FPH
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K
M86=E)R`]/B`D<&YA;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1P;F%M95LG8VAA
M;FYE;"==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=F5R<VEO;B<@/3X@)&EN9F];)W9E<G-I;VXG72DI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'9S
M(#T@)R!W:71H:6X@<')E9F5R<F5D('-T871E("(G("X@)'1H:7,M/E]C;VYF
M:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<B)SL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"=014%27T1E<&5N9&5N8WDR)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D;W!T:6]N86PI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!D;VXG="!S<&ET(&]U="!C;VYF=7-I;F<@97)R;W(@;65S
M<V%G92P@86YD(&1O;B=T(&1I92!O;@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O(&]P=&EO;F%L(&1E<"!F86EL=7)E(0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D97(M/E]G
M971086-K86=E1&]W;FQO8615<FPH#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B`D<&YA;65;)W!A8VMA9V4G
M72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-H
M86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&EN9F];)W9E
M<G-I;VXG72DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'9S(#T@4$5!4E]$97!E;F1E;F-Y,CHZ7V=E
M=$5X=')A4W1R:6YG*"1P;F%M92D[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D=G,@/2`G('=I=&AI;B!P<F5F97)R960@<W1A=&4@(B<@+B`D=&AI<RT^
M7V1O=VYL;V%D97(M/F-O;F9I9RT^9V5T*`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)W!R969E<G)E9%]S=&%T92<I("X@)R(G.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W
M;FQO861E<BT^9V5T3W!T:6]N<R@I.PT*("`@("`@("`@("`@("`@("\O('1H
M:7,@:7,@;VYL>2!S970@8GD@=&AE(")D;W=N;&]A9"UA;&PB(&-O;6UA;F0-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VEG;F]R97!R
M969E<G)E9%]S=&%T92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D97)R
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=&86EL960@=&\@9&]W;FQO860@)R`N("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==
M+"`G<&%C:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTI+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T<G5E*0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)'9S("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<L
M(&QA=&5S="!R96QE87-E(&ES('9E<G-I;VX@)R`N("1I;F9O6R=V97)S:6]N
M)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)RP@<W1A8FEL:71Y("(G
M("X@)&EN9F];)VEN9F\G72T^9V5T4W1A=&4H*2`N("<B+"!U<V4@(B<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R
M<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@)'!N86UE6R=C:&%N;F5L)UTL
M("=P86-K86=E)R`]/B`D<&YA;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&EN9F];)W9E<G-I;VXG
M72DI("X@)R(@=&\@:6YS=&%L;"<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E]$3U=.3$]!1$527U!!0TM!1T5?4U1!5$4I.PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H#0H@
M("`@("`@("`@("`@("`@("`@("=&86EL960@=&\@9&]W;FQO860@)R`N("1T
M:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@)'!N
M86UE6R=C:&%N;F5L)UTL("=P86-K86=E)R`]/B`D<&YA;65;)W!A8VMA9V4G
M72DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92D-"B`@("`@
M("`@("`@("`@("`@("`@("X@)'9S("X-"B`@("`@("`@("`@("`@("`@("`@
M)RP@;&%T97-T(')E;&5A<V4@:7,@=F5R<VEO;B`G("X@)&EN9F];)W9E<G-I
M;VXG72`N#0H@("`@("`@("`@("`@("`@("`@("<L('-T86)I;&ET>2`B)R`N
M("1I;F9O6R=I;F9O)UTM/F=E=%-T871E*"D@+B`G(BP@=7-E("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C
M:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=C:&%N;F5L)R`]/B`D<&YA;65;)V-H86YN96PG72P@)W!A8VMA9V4G
M(#T^("1P;F%M95LG<&%C:V%G92==+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N)UTI*2`N("<B('1O(&EN
M<W1A;&PG*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&EN9F\[#0H@
M("`@?0T*?0T*/SX-"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R\`
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#4W`#`Q-C<W-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]487-K+U5N:7AE;VPO````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(P-#(P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO56YI>&5O;"]R=RYP
M:'``````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,V-P`Q,#4Q-30S
M,3`U-P`P,C$U-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@/'1A<VMS.G5N:7AE;VP^("T@<F5A
M9"]W<FET92!V97)S:6]N#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(')W+G!H<"QV(#$N-"`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*+RHJ#0H@*B!"87-E(&-L
M87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+U5N:7AE;VPN<&AP
M)SL-"B\J*@T*("H@06)S=')A8W1S('1H92!U;FEX96]L('1A<VL@>&UL+@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q,`T*("HO#0IC;&%S<R!014%27U1A<VM?56YI>&5O;%]R
M=R!E>'1E;F1S(%!%05)?5&%S:U]5;FEX96]L#0I[#0H@("`@9G5N8W1I;VX@
M4$5!4E]487-K7U5N:7AE;VQ?<G<H)B1P:V<L("8D8V]N9FEG+"`F)&QO9V=E
M<BP@)&9I;&58;6PI#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?5&%S
M:U]#;VUM;VXH)&-O;F9I9RP@)&QO9V=E<BP@4$5!4E]405-+7U!!0TM!1T4I
M.PT*("`@("`@("`D=&AI<RT^7V-O;G1E;G1S(#T@)&9I;&58;6P[#0H@("`@
M("`@("1T:&ES+3Y?<&MG(#T@)B1P:V<[#0H@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@87)R87DH*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T
M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G971.86UE*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G
M=6YI>&5O;"<[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T6&UL*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B`G)SL-"B`@("!]#0I]#0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U=I;F1O=W-E;VPO````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`
M,#(Q,3(W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO
M5VEN9&]W<V5O;"]R=RYP:'``````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S0Q-``Q,#4Q-30S,3`U-P`P,C(R-C<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\J*@T*("H@/'1A<VMS.G=I
M;F1O=W-E;VP^("T@<F5A9"]W<FET92!V97)S:6]N#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E
M9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(')W+G!H<"QV(#$N-"`R,#`V+S`Q
M+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*
M+RHJ#0H@*B!"87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]4
M87-K+U=I;F1O=W-E;VPN<&AP)SL-"B\J*@T*("H@06)S=')A8W1S('1H92!W
M:6YD;W=S96]L('1A<VL@>&UL+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q,`T*("HO#0IC;&%S
M<R!014%27U1A<VM?5VEN9&]W<V5O;%]R=R!E>'1E;F1S(%!%05)?5&%S:U]7
M:6YD;W=S96]L#0I[#0H@("`@9G5N8W1I;VX@4$5!4E]487-K7U=I;F1O=W-E
M;VQ?<G<H)B1P:V<L("8D8V]N9FEG+"`F)&QO9V=E<BP@)&9I;&58;6PI#0H@
M("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?5&%S:U]#;VUM;VXH)&-O;F9I
M9RP@)&QO9V=E<BP@4$5!4E]405-+7U!!0TM!1T4I.PT*("`@("`@("`D=&AI
M<RT^7V-O;G1E;G1S(#T@)&9I;&58;6P[#0H@("`@("`@("1T:&ES+3Y?<&MG
M(#T@)B1P:V<[#0H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87DH*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T92@I#0H@("`@>PT*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971.
M86UE*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G=VEN9&]W<V5O;"<[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T6&UL*"D-"B`@("![#0H@("`@("`@
M(')E='5R;B`G)SL-"B`@("!]#0I]#0H_/@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U)E<&QA
M8V4O````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-3<`,#(P,S4P`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+U1A<VLO4F5P;&%C92]R=RYP:'``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,S<U-``Q,#4Q-30S,3`U-P`P,C$U,3<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\J*@T*
M("H@/'1A<VMS.G)E<&QA8V4^("T@<F5A9"]W<FET92!V97)S:6]N#0H@*@T*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(')W+G!H<"QV(#$N
M,R`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A
M,3`-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC
M92`G4$5!4B]487-K+U)E<&QA8V4N<&AP)SL-"B\J*@T*("H@06)S=')A8W1S
M('1H92!R97!L86-E('1A<VL@>&UL+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#
M;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q,`T*("HO#0IC
M;&%S<R!014%27U1A<VM?4F5P;&%C95]R=R!E>'1E;F1S(%!%05)?5&%S:U]2
M97!L86-E#0I[#0H@("`@9G5N8W1I;VX@4$5!4E]487-K7U)E<&QA8V5?<G<H
M)B1P:V<L("8D8V]N9FEG+"`F)&QO9V=E<BP@)&9I;&58;6PI#0H@("`@>PT*
M("`@("`@("!P87)E;G0Z.E!%05)?5&%S:U]#;VUM;VXH)&-O;F9I9RP@)&QO
M9V=E<BP@4$5!4E]405-+7U!!0TM!1T4I.PT*("`@("`@("`D=&AI<RT^7V-O
M;G1E;G1S(#T@)&9I;&58;6P[#0H@("`@("`@("1T:&ES+3Y?<&MG(#T@)B1P
M:V<[#0H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87DH*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T92@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)'1H:7,M/G9A;&ED871E6&UL*"1T:&ES+3Y?<&MG+"`D=&AI<RT^
M7W!A<F%M<RP@)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]C;VYT96YT<RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T26YF;R@D9G)O;2P@)'1O+"`D='EP
M92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87DH)V%T
M=')I8G,G(#T^(&%R<F%Y*"=F<F]M)R`]/B`D9G)O;2P@)W1O)R`]/B`D=&\L
M("=T>7!E)R`]/B`D='EP92DI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=$YA;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("=R97!L86-E)SL-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!G9718;6PH*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&%R86US.PT*("`@('T-"GT-"C\^````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!
M4B]487-K+U!O<W1I;G-T86QL<V-R:7!T+P``````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(R-3,V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4&]S=&EN<W1A;&QS8W)I<'0O<G<N
M<&AP```````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#,U-0`Q,#4Q-30S,3`U-P`P,C,W
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J*@T*("H@/'1A<VMS.G!O<W1I;G-T86QL<V-R:7!T/B`M(')E
M860O=W)I=&4@=F5R<VEO;@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-
M"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K
M86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M($-64SH@)$ED.B!R=RYP:'`L=B`Q+C$Q(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@
M8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q,`T*("HO#0HO*BH-"B`J($)A<V4@
M8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U1A<VLO4&]S=&EN<W1A
M;&QS8W)I<'0N<&AP)SL-"B\J*@T*("H@06)S=')A8W1S('1H92!P;W-T:6YS
M=&%L;'-C<FEP="!F:6QE('1A<VL@>&UL+@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q,`T*("HO
M#0IC;&%S<R!014%27U1A<VM?4&]S=&EN<W1A;&QS8W)I<'1?<G<@97AT96YD
M<R!014%27U1A<VM?4&]S=&EN<W1A;&QS8W)I<'0-"GL-"B`@("`O*BH-"B`@
M("`@*B!P87)E;G0@<&%C:V%G92!F:6QE(&]B:F5C=`T*("`@("`J#0H@("`@
M("H@0'9A<B!014%27U!A8VMA9V5&:6QE7W8R7W)W#0H@("`@("HO#0H@("`@
M=F%R("1?<&MG.PT*("`@("\J*@T*("`@("`J($5N=&5R(&1E<V-R:7!T:6]N
M(&AE<F4N+BX-"B`@("`@*@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&
M:6QE7W8R7W)W("1P:V<-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<@)&-O
M;F9I9PT*("`@("`J($!P87)A;2!014%27T9R;VYT96YD("1L;V=G97(-"B`@
M("`@*B!`<&%R86T@87)R87D@)&9I;&58;6P-"B`@("`@*B!`<F5T=7)N(%!%
M05)?5&%S:U]0;W-T:6YS=&%L;'-C<FEP=%]R=PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%!%05)?5&%S:U]0;W-T:6YS=&%L;'-C<FEP=%]R=R@F)'!K9RP@
M)B1C;VYF:6<L("8D;&]G9V5R+"`D9FEL95AM;"D-"B`@("![#0H@("`@("`@
M('!A<F5N=#HZ4$5!4E]487-K7T-O;6UO;B@D8V]N9FEG+"`D;&]G9V5R+"!0
M14%27U1!4TM?4$%#2T%'12D[#0H@("`@("`@("1T:&ES+3Y?8V]N=&5N=',@
M/2`D9FEL95AM;#L-"B`@("`@("`@)'1H:7,M/E]P:V<@/2`F)'!K9SL-"B`@
M("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>2@I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N('9A;&ED871E*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D
M=&AI<RT^=F%L:61A=&58;6PH)'1H:7,M/E]P:V<L("1T:&ES+3Y?<&%R86US
M+"`D=&AI<RT^8V]N9FEG+"`D=&AI<RT^7V-O;G1E;G1S*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!G971.86UE*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`G<&]S=&EN<W1A;&QS8W)I<'0G.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(&%D9"!A('-I;7!L92`\<&%R86UG<F]U<#X@=&\@=&AE('!O<W0M:6YS
M=&%L;"!S8W)I<'0-"B`@("`@*@T*("`@("`J($]R9&5R(&ES('-I9VYI9FEC
M86YT+"!S;R!C86QL('1H:7,@;65T:&]D(&EN('1H92!S86UE#0H@("`@("H@
M<V5Q=65N8V4@=&AE('5S97)S('-H;W5L9"!S964@=&AE('!A<F%M9W)O=7!S
M+B`@5&AE("1P87)A;7,-"B`@("`@*B!P87)A;65T97(@<VAO=6QD(&5I=&AE
M<B!B92!T:&4@<F5S=6QT(&]F(&$@8V%L;"!T;R![0&QI;FL@9V5T4&%R86TH
M*7T-"B`@("`@*B!O<B!A;B!A<G)A>2!O9B!C86QL<R!T;R!G971087)A;2@I
M+@T*("`@("`J(`T*("`@("`J(%5S92![0&QI;FL@861D0V]N9&ET:6]N5'EP
M94=R;W5P*"E]('1O(&%D9"!A(#QP87)A;6=R;W5P/B!C;VYT86EN:6YG#0H@
M("`@("H@82`\8V]N9&ET:6]N='EP93X@=&%G#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:60@/'!A<F%M9W)O=7`^(&ED(&%S('-E96X@8GD@=&AE('-C<FEP
M=`T*("`@("`J($!P87)A;2!A<G)A>7QF86QS92`D<&%R86US(&%R<F%Y(&]F
M(&=E=%!A<F%M*"D@8V%L;',L(&]R(&9A;'-E(&9O<B!N;R!P87)A;7,-"B`@
M("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E("1I;G-T<G5C=&EO;G,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&1087)A;4=R;W5P*"1I9"P@)'!A<F%M<R`]
M(&9A;'-E+"`D:6YS=')U8W1I;VYS(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!I9B`H)'!A<F%M<R`F)B!I<W-E="@D<&%R86US6S!=*2`F)B`A:7-S970H
M)'!A<F%M<ULQ72DI('L-"B`@("`@("`@("`@("1P87)A;7,@/2`D<&%R86US
M6S!=.PT*("`@("`@("!]#0H@("`@("`@("1S='5F9B`]#0H@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!K9RT^9V5T5&%S
M:W-.<R@I("X@)SII9"<@/3X@)&ED+`T*("`@("`@("`@("`@*3L-"B`@("`@
M("`@:68@*"1I;G-T<G5C=&EO;G,I('L-"B`@("`@("`@("`@("1S='5F9ELD
M=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SII;G-T<G5C=&EO;G,G72`]
M("1I;G-T<G5C=&EO;G,[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P87)A
M;7,I('L-"B`@("`@("`@("`@("1S='5F9ELD=&AI<RT^7W!K9RT^9V5T5&%S
M:W-.<R@I("X@)SIP87)A;2==(#T@)'!A<F%M<SL-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULD=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I
M("X@)SIP87)A;6=R;W5P)UU;72`]("1S='5F9CL-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!A9&0@82!C;VUP;&5X(#QP87)A;6=R;W5P/B!T;R!T:&4@
M<&]S="UI;G-T86QL('-C<FEP="!W:71H(&-O;F1I=&EO;G,-"B`@("`@*@T*
M("`@("`J(%1H:7,@:6YS97)T<R!A(#QP87)A;6=R;W5P/B!W:71H#0H@("`@
M("H-"B`@("`@*B!/<F1E<B!I<R!S:6=N:69I8V%N="P@<V\@8V%L;"!T:&ES
M(&UE=&AO9"!I;B!T:&4@<V%M90T*("`@("`J('-E<75E;F-E('1H92!U<V5R
M<R!S:&]U;&0@<V5E('1H92!P87)A;6=R;W5P<RX@(%1H92`D<&%R86US#0H@
M("`@("H@<&%R86UE=&5R('-H;W5L9"!E:71H97(@8F4@=&AE(')E<W5L="!O
M9B!A(&-A;&P@=&\@>T!L:6YK(&=E=%!A<F%M*"E]#0H@("`@("H@;W(@86X@
M87)R87D@;V8@8V%L;',@=&\@9V5T4&%R86TH*2X-"B`@("`@*B`-"B`@("`@
M*B!5<V4@>T!L:6YK(&%D9%!A<F%M1W)O=7`H*7T@=&\@861D(&$@<VEM<&QE
M(#QP87)A;6=R;W5P/@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:60@/'!A<F%M9W)O=7`^(&ED(&%S('-E96X@8GD@=&AE('-C<FEP=`T*("`@
M("`J($!P87)A;2!S=')I;F<@)&]L9&=R;W5P(#QP87)A;6=R;W5P/B!I9"!O
M9B!T:&4@<V5C=&EO;B!R969E<F5N8V5D(&)Y#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@/&-O;F1I=&EO;G1Y<&4^#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%R86T@;F%M92!O9B!T:&4@/'!A<F%M/B!F<F]M('1H92!O
M;&1E<B!S96-T:6]N(')E9F5R96YC960-"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!B>2`\8V]N=&ET:6]N='EP93X-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1V86QU92!V86QU92!T;R!M871C:"!O9B!T:&4@<&%R86UE=&5R#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8V]N9&ET:6]N='EP92!O;F4@;V8@)STG
M+"`G(3TG+"`G<')E9U]M871C:"<-"B`@("`@*B!`<&%R86T@87)R87E\9F%L
M<V4@)'!A<F%M<R!A<G)A>2!O9B!G971087)A;2@I(&-A;&QS+"!O<B!F86QS
M92!F;W(@;F\@<&%R86US#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92`D
M:6YS=')U8W1I;VYS#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D0V]N9&ET
M:6]N5'EP94=R;W5P*"1I9"P@)&]L9&=R;W5P+"`D<&%R86TL("1V86QU92P@
M)&-O;F1I=&EO;G1Y<&4@/2`G/2<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7,@/2!F86QS92P@)&EN<W1R=6-T:6]N<R`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1P87)A;7,@)B8@:7-S970H
M)'!A<F%M<ULP72D@)B8@(6ES<V5T*"1P87)A;7-;,5TI*2![#0H@("`@("`@
M("`@("`D<&%R86US(#T@)'!A<F%M<ULP73L-"B`@("`@("`@?0T*("`@("`@
M("`D<W1U9F8@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z:60G(#T^("1I9"P-
M"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("@D:6YS=')U8W1I;VYS*2![
M#0H@("`@("`@("`@("`D<W1U9F9;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H
M*2`N("<Z:6YS=')U8W1I;VYS)UT@/2`D:6YS=')U8W1I;VYS.PT*("`@("`@
M("!]#0H@("`@("`@("1S='5F9ELD=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I
M("X@)SIN86UE)UT@/2`D;VQD9W)O=7`@+B`G.CHG("X@)'!A<F%M.PT*("`@
M("`@("`D<W1U9F9;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z8V]N
M9&ET:6]N='EP92==(#T@)&-O;F1I=&EO;G1Y<&4[#0H@("`@("`@("1S='5F
M9ELD=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SIV86QU92==(#T@)'9A
M;'5E.PT*("`@("`@("!I9B`H)'!A<F%M<RD@>PT*("`@("`@("`@("`@)'-T
M=69F6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G!A<F%M)UT@/2`D
M<&%R86US.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%R86US6R1T
M:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G!A<F%M9W)O=7`G75M=(#T@
M)'-T=69F.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%AM;"@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7,[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@57-E('1O('-E="!U<"!A('!A<F%M('1A9R!F;W(@
M=7-E(&EN(&-R96%T:6YG(&$@<&%R86UG<F]U<`T*("`@("`J($!S=&%T:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971087)A;2@D;F%M92P@)'!R;VUP
M="P@)'1Y<&4@/2`G<W1R:6YG)RP@)&1E9F%U;'0@/2!N=6QL*0T*("`@('L-
M"B`@("`@("`@:68@*"1D969A=6QT("$]/2!N=6QL*2![#0H@("`@("`@("`@
M("!R971U<FX@#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SIN86UE)R`]/B`D;F%M
M92P-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I
M("X@)SIP<F]M<'0G(#T^("1P<F]M<'0L#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z='EP92<@/3X@)'1Y<&4L#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z
M9&5F875L="<@/3X@)&1E9F%U;'0-"B`@("`@("`@("`@("D[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SIN86UE
M)R`]/B`D;F%M92P-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!K9RT^9V5T
M5&%S:W-.<R@I("X@)SIP<F]M<'0G(#T^("1P<F]M<'0L#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z='EP92<@/3X@
M)'1Y<&4L#0H@("`@("`@("`@("`I.PT*("`@('T-"GT-"C\^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+T-O;6UO;BYP
M:'``````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34P,3$`,3`U
M,34T,S$P-3<`,#(P-S,Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?5&%S:U]#;VUM;VXL
M(&)A<V4@8VQA<W,@9F]R(&EN<W1A;&QE<B!T87-K<PT*("H-"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#;VUM;VXN<&AP+'8@,2XQ-2`R
M,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC
M92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*
M("HO#0HO*BHC0"L-"B`J($5R<F]R(&-O9&5S(&9O<B!T87-K('9A;&ED871I
M;VX@<F]U=&EN97,-"B`J+PT*9&5F:6YE*"=014%27U1!4TM?15)23U)?3D]!
M5%1224)3)RP@,2D[#0ID969I;F4H)U!%05)?5$%32U]%4E)/4E]-25-324Y'
M7T%45%))0B<L(#(I.PT*9&5F:6YE*"=014%27U1!4TM?15)23U)?5U)/3D=?
M05144DE"7U9!3%5%)RP@,RD[#0ID969I;F4H)U!%05)?5$%32U]%4E)/4E])
M3E9!3$E$)RP@-"D[#0HO*BHC0"TJ+PT*9&5F:6YE*"=014%27U1!4TM?4$%#
M2T%'12<L(#$I.PT*9&5F:6YE*"=014%27U1!4TM?24Y35$%,3"<L(#(I.PT*
M9&5F:6YE*"=014%27U1!4TM?4$%#2T%'14%.1$E.4U1!3$PG+"`S*3L-"B\J
M*@T*("H@02!T87-K(&ES(&%N(&]P97)A=&EO;B!T:&%T(&UA;FEP=6QA=&5S
M('1H92!C;VYT96YT<R!O9B!A(&9I;&4N#0H@*@T*("H@4VEM<&QE('1A<VMS
M(&]P97)A=&4@;VX@,2!F:6QE+B`@375L=&EP;&4@=&%S:W,@87)E(&5X96-U
M=&5D(&%F=&5R(&%L;"!F:6QE<R!H879E(&)E96X-"B`J('!R;V-E<W-E9"!A
M;F0@:6YS=&%L;&5D+"!A;F0@87)E(&1E<VEG;F5D('1O(&]P97)A=&4@;VX@
M86QL(&9I;&5S(&-O;G1A:6YI;F<@=&AE('1A<VLN#0H@*B!4:&4@4&]S="UI
M;G-T86QL('-C<FEP="!T87-K('-I;7!L>2!T86ME<R!A9'9A;G1A9V4@;V8@
M=&AE(&9A8W0@=&AA="!I="!W:6QL(&)E(')U;@T*("H@869T97(@:6YS=&%L
M;&%T:6]N+"!R97!L86-E(&ES(&$@<VEM<&QE('1A<VLN#0H@*@T*("H@0V]M
M8FEN:6YG('1A<VMS(&ES('!O<W-I8FQE+"!B=70@;W)D97)I;F<@:7,@<VEG
M;FEF:6-A;G0N#0H@*@T*("H@/&9I;&4@;F%M93TB=&5S="YP:'`B(')O;&4]
M(G!H<"(^#0H@*B`@/'1A<VMS.G)E<&QA8V4@9G)O;3TB0&1A=&$M9&ER0"(@
M=&\](F1A=&%?9&ER(B!T>7!E/2)P96%R+6-O;F9I9R(O/@T*("H@(#QT87-K
M<SIP;W-T:6YS=&%L;'-C<FEP="\^#0H@*B`\+V9I;&4^#0H@*@T*("H@5&AI
M<R!W:6QL(&9I<G-T(')E<&QA8V4@86YY(&EN<W1A;F-E(&]F($!D871A+61I
M<D`@:6X@=&AE('1E<W0N<&AP(&9I;&4-"B`J('=I=&@@=&AE('!A=&@@=&\@
M=&AE(&-U<G)E;G0@9&%T82!D:7)E8W1O<GDN("!4:&5N+"!I="!W:6QL(&EN
M8VQU9&4@=&AE#0H@*B!T97-T+G!H<"!F:6QE(&%N9"!R=6X@=&AE('-C<FEP
M="!I="!C;VYT86EN<R!T;R!C;VYF:6=U<F4@=&AE('!A8VMA9V4@<&]S="UI
M;G-T86QL871I;VXN#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J($!A8G-T<F%C=`T*("HO
M#0IC;&%S<R!014%27U1A<VM?0V]M;6]N#0I[#0H@("`@+RHJ#0H@("`@("H@
M5F%L:60@='EP97,@9F]R('1H:7,@=F5R<VEO;B!A<F4@)W-I;7!L92<@86YD
M("=M=6QT:7!L92<-"B`@("`@*@T*("`@("`J("T@<VEM<&QE('1A<VMS(&]P
M97)A=&4@;VX@=&AE(&-O;G1E;G1S(&]F(&$@9FEL92!A;F0@=W)I=&4@;W5T
M(&-H86YG97,@=&\@9&ES:PT*("`@("`J("T@;75L=&EP;&4@=&%S:W,@;W!E
M<F%T92!O;B!T:&4@8V]N=&5N=',@;V8@;6%N>2!F:6QE<R!A;F0@=W)I=&4@
M;W5T('1H90T*("`@("`J("`@8VAA;F=E<R!D:7)E8W1L>2!T;R!D:7-K#0H@
M("`@("H-"B`@("`@*B!#:&EL9"!T87-K(&-L87-S97,@;75S="!O=F5R<FED
M92!T:&ES('!R;W!E<G1Y+@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@
M("`@("HO#0H@("`@=F%R("1T>7!E(#T@)W-I;7!L92<[#0H@("`@+RHJ#0H@
M("`@("H@1&5T97)M:6YE<R!W:&EC:"!I;G-T86QL('!H87-E('1H:7,@=&%S
M:R!I<R!E>&5C=71E9"!U;F1E<@T*("`@("`J+PT*("`@('9A<B`D<&AA<V4@
M/2!014%27U1!4TM?24Y35$%,3#L-"B`@("`O*BH-"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D8V]N9FEG.PT*("`@("\J
M*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R
M("1R96=I<W1R>3L-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E
M9`T*("`@("`J+PT*("`@('9A<B`D;&]G9V5R.PT*("`@("\J*@T*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1I;G-T86QL
M<&AA<V4[#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@
M("`@("H@0'!A<F%M(%!%05)?0V]M;6]N#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@4$5!4E]487-K7T-O;6UO;B@F)&-O;F9I9RP@)B1L;V=G97(L("1P:&%S
M92D-"B`@("![#0H@("`@("`@("1T:&ES+3YC;VYF:6<@/2`F)&-O;F9I9SL-
M"B`@("`@("`@)'1H:7,M/G)E9VES=')Y(#T@)B1C;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@("`@("1T:&ES+3YL;V=G97(@/2`F)&QO9V=E<CL-"B`@
M("`@("`@)'1H:7,M/FEN<W1A;&QP:&%S92`]("1P:&%S93L-"B`@("`@("`@
M:68@*"1T:&ES+3YT>7!E(#T]("=M=6QT:7!L92<I('L-"B`@("`@("`@("`@
M("1'3$]"04Q36R=?4$5!4E]405-+7U!/4U1)3E-404Y#15,G75MG971?8VQA
M<W,H)'1H:7,I75M=(#T@)B1T:&ES.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@5F%L:61A=&4@=&AE(&)A<VEC(&-O;G1E;G1S(&]F
M(&$@=&%S:R!T86<N#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?
M=C(-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<&%R86T@4$5!4E]#
M;VYF:6<-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&5N=&ER92!P87)S960@
M/&9I;&4^('1A9PT*("`@("`J($!R971U<FX@=')U97QA<G)A>2!/;B!E<G)O
M<BP@<F5T=7)N(&%N(&%R<F%Y(&EN(&9O<FUA=#H-"B`@("`@*B`@("!A<G)A
M>2A014%27U1!4TM?15)23U)?/S\_6RP@<&%R86TQ75LL('!A<F%M,EU;+"`N
M+BY=*0T*("`@("`J#0H@("`@("H@("`@1F]R(%!%05)?5$%32U]%4E)/4E]-
M25-324Y'7T%45%))0BP@<&%S<R!T:&4@871T<FEB=71E(&YA;64@:6X-"B`@
M("`@*B`@("!&;W(@4$5!4E]405-+7T524D]27U=23TY'7T%45%))0E]604Q5
M12P@<&%S<R!T:&4@871T<FEB=71E(&YA;64@86YD(&%N(&%R<F%Y#0H@("`@
M("H@("`@;V8@;&5G86P@=F%L=65S(&EN#0H@("`@("H@0'-T871I8PT*("`@
M("`J($!A8G-T<F%C=`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED6&UL
M*"1P:V<L("1X;6PL("8D8V]N9FEG+"`D9FEL95AM;"D-"B`@("![#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@26YI=&EA;&EZ92!A('1A<VL@:6YS=&%N
M8V4@=VET:"!T:&4@<&%R86UE=&5R<PT*("`@("`J($!P87)A;2!A<G)A>2!R
M87<L('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R86T@87)R87D@871T<FEB=71E
M<R!F<F]M('1H92`\9FEL93X@=&%G(&-O;G1A:6YI;F<@=&AI<R!T87-K#0H@
M("`@("H@0'!A<F%M('-T<FEN9WQN=6QL(&QA<W0@:6YS=&%L;&5D('9E<G-I
M;VX@;V8@=&AI<R!P86-K86=E#0H@("`@("H@0&%B<W1R86-T#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@:6YI="@D>&UL+"`D9FEL94%T=')I8G5T97,L("1L
M87-T5F5R<VEO;BD-"B`@("![#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0F5G:6X@82!T87-K('!R;V-E<W-I;F<@<V5S<VEO;BX@($%L;"!M=6QT:7!L
M92!T87-K<R!W:6QL(&)E('!R;V-E<W-E9"!A9G1E<B!E86-H(&9I;&4-"B`@
M("`@*B!H87,@8F5E;B!S=6-C97-S9G5L;'D@:6YS=&%L;&5D+"!A;&P@<VEM
M<&QE('1A<VMS('-H;W5L9"!P97)F;W)M('1H96ER('1A<VL@:&5R92!A;F0-
M"B`@("`@*B!R971U<FX@86YY(&5R<F]R<R!U<VEN9R!T:&4@8W5S=&]M('1H
M<F]W17)R;W(H*2!M971H;V0@=&\@86QL;W<@9F]R=V%R9"!C;VUP871I8FEL
M:71Y#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO9"!-55-4($Y/5"!W<FET
M92!O=70@86YY(&-H86YG97,@=&\@9&ES:PT*("`@("`J($!P87)A;2!014%2
M7U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&-O
M;G1E;G1S#0H@("`@("H@0'!A<F%M('-T<FEN9R!T:&4@979E;G1U86P@9FEN
M86P@9FEL92!L;V-A=&EO;B`H:6YF;W)M871I;VYA;"!O;FQY*0T*("`@("`J
M($!R971U<FX@<W1R:6YG?&9A;'-E?%!%05)?17)R;W(@9F%L<V4@=&\@<VMI
M<"!T:&ES(&9I;&4L(%!%05)?17)R;W(@=&\@9F%I;`T*("`@("`J("`@("`@
M("`@*'5S92`D=&AI<RT^=&AR;W=%<G)O<BDL(&]T:&5R=VES92!R971U<FX@
M=&AE(&YE=R!C;VYT96YT<PT*("`@("`J($!A8G-T<F%C=`T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-T87)T4V5S<VEO;B@D<&MG+"`D8V]N=&5N=',L("1D
M97-T*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UE
M=&AO9"!I<R!U<V5D('1O('!R;V-E<W,@96%C:"!O9B!T:&4@=&%S:W,@9F]R
M(&$@<&%R=&EC=6QA<B!M=6QT:7!L92!C;&%S<PT*("`@("`J('1Y<&4N("!3
M:6UP;&4@=&%S:W,@;F5E9"!N;W0@:6UP;&5M96YT('1H:7,@;65T:&]D+@T*
M("`@("`J($!P87)A;2!A<G)A>2!A;B!A<G)A>2!O9B!T87-K<PT*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("H@0'-T871I8PT*("`@("`J($!A
M8G-T<F%C=`T*("`@("`J+PT*("`@(&9U;F-T:6]N(')U;B@D=&%S:W,I#0H@
M("`@>PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B!`9FEN86P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!H87-0;W-T:6YS=&%L
M;%1A<VMS*"D-"B`@("![#0H@("`@("`@(')E='5R;B!I<W-E="@D1TQ/0D%,
M4ULG7U!%05)?5$%32U]03U-424Y35$%.0T53)UTI.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`9FEN86P-"B`@("`@*B\-
M"B`@("`@9G5N8W1I;VX@<G5N4&]S=&EN<W1A;&Q487-K<R@I#0H@("`@('L-
M"B`@("`@("`@(&9O<F5A8V@@*"1'3$]"04Q36R=?4$5!4E]405-+7U!/4U1)
M3E-404Y#15,G72!A<R`D8VQA<W,@/3X@)'1A<VMS*2![#0H@("`@("`@("`@
M("`@)&5R<B`](&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1C;&%S<RP@)W)U;B<I
M+`T*("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27U1!4TM?4$]3
M5$E.4U1!3D-%4R==6R1C;&%S<UTI.PT*("`@("`@("`@("`@(&EF("@D97)R
M*2![#0H@("`@("`@("`@("`@("`@(')E='5R;B!014%27U1A<VM?0V]M;6]N
M.CIT:')O=T5R<F]R*"1E<G(I.PT*("`@("`@("`@("`@('T-"B`@("`@("`@
M('T-"B`@("`@("`@('5N<V5T*"1'3$]"04Q36R=?4$5!4E]405-+7U!/4U1)
M3E-404Y#15,G72D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M
M:6YE<R!W:&5T:&5R(&$@<F]L92!I<R!A('-C<FEP=`T*("`@("`J($!R971U
M<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES4V-R:7!T*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^='EP92`]/2`G<V-R:7!T)SL-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!T:')O=T5R<F]R*"1M<V<L("1C;V1E
M(#T@+3$I#0H@("`@>PT*("`@("`@("!I;F-L=61E7V]N8V4@)U!%05(N<&AP
M)SL-"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&US9RP@)&-O
M9&4I.PT*("`@('T-"GT-"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]487-K+U!O<W1I;G-T86QL<V-R:7!T+G!H<```
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S4S-S(`,3`U,34T,S$P-3<`,#(S,C4V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*BH-"B`J(#QT87-K<SIP;W-T:6YS=&%L;'-C<FEP=#X-"B`J#0H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE
M87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4&]S=&EN<W1A;&QS
M8W)I<'0N<&AP+'8@,2XQ."`R,#`V+S`R+S`X(#`Q.C(Q.C0W(&-E;&QO9R!%
M>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J($)A<V4@8VQA<W,-"B`J
M+PT*<F5Q=6ER95]O;F-E("=014%2+U1A<VLO0V]M;6]N+G!H<"<[#0HO*BH-
M"B`J($EM<&QE;65N=',@=&AE('!O<W1I;G-T86QL<V-R:7!T(&9I;&4@=&%S
M:RX-"B`J#0H@*B!.;W1E('1H870@<&]S="UI;G-T86QL('-C<FEP=',@87)E
M(&AA;F1L960@<V5P87)A=&5L>2!F<F]M(&EN<W1A;&QA=&EO;BP@8GD@=&AE
M#0H@*B`B<&5A<B!R=6XM<V-R:7!T<R(@8V]M;6%N9`T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"F-L87-S(%!%05)?5&%S:U]0;W-T:6YS=&%L;'-C<FEP="!E>'1E
M;F1S(%!%05)?5&%S:U]#;VUM;VX-"GL-"B`@("!V87(@)'1Y<&4@/2`G<V-R
M:7!T)SL-"B`@("!V87(@)%]C;&%S<SL-"B`@("!V87(@)%]P87)A;7,[#0H@
M("`@=F%R("1?;V)J.PT*("`@("\J*@T*("`@("`J#0H@("`@("H@0'9A<B!0
M14%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@("`@=F%R("1?<&MG.PT*
M("`@('9A<B`D7V-O;G1E;G1S.PT*("`@('9A<B`D<&AA<V4@/2!014%27U1!
M4TM?24Y35$%,3#L-"@T*("`@("\J*@T*("`@("`J(%9A;&ED871E('1H92!R
M87<@>&UL(&%T('!A<G-I;F<M=&EM92X-"B`@("`@*@T*("`@("`J(%1H:7,@
M86QS;R!A='1E;7!T<R!T;R!V86QI9&%T92!T:&4@<V-R:7!T('1O(&UA:V4@
M<W5R92!I="!M965T<R!T:&4@8W)I=&5R:6$-"B`@("`@*B!F;W(@82!P;W-T
M+6EN<W1A;&P@<V-R:7!T#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I
M;&5?=C(-"B`@("`@*B!`<&%R86T@87)R87D@5&AE(%A-3"!C;VYT96YT<R!O
M9B!T:&4@/'!O<W1I;G-T86QL<V-R:7!T/B!T86<-"B`@("`@*B!`<&%R86T@
M4$5!4E]#;VYF:6<-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&5N=&ER92!P
M87)S960@/&9I;&4^('1A9PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!V86QI9&%T95AM;"@D<&MG+"`D>&UL+"`F)&-O;F9I9RP@
M)&9I;&58;6PI#0H@("`@>PT*("`@("`@("!I9B`H)&9I;&58;6Q;)W)O;&4G
M72`A/2`G<&AP)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?
M5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N
M#0H@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@;75S="!B92!R
M;VQE/2)P:'`B)RD[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D9FEL
M92`]("1P:V<M/F=E=$9I;&5#;VYT96YT<R@D9FEL95AM;%LG;F%M92==*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I;&4I*2![#0H@("`@("`@
M("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN
M<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@("`@("`D9FEL95AM;%LG
M;F%M92==("X@)R(@:7,@;F]T('9A;&ED.B`G("X-"B`@("`@("`@("`@("`@
M("`D9FEL92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@?2!E;'-E:68@*"1F
M:6QE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@87)R87DH4$5!
M4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G
M("X-"B`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@8V]U
M;&0@;F]T(&)E(')E=')I979E9"!F;W(@<')O8V5S<VEN9R$G*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A;F%L>7-I<R`]("1P:V<M/F%N
M86QY>F53;W5R8V5#;V1E*"1F:6QE+"!T<G5E*3L-"B`@("`@("`@("`@(&EF
M("@A)&%N86QY<VES*2![#0H@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("1W87)N:6YG<R`]("<G
M.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P:V<M/F=E=%9A;&ED871I
M;VY787)N:6YG<R@I(&%S("1W87)N*2![#0H@("`@("`@("`@("`@("`@("`@
M("1W87)N:6YG<R`N/2`D=V%R;ELG;65S<V%G92==("X@(EQN(CL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%
M05)?5$%32U]%4E)/4E])3E9!3$E$+"`G06YA;'ES:7,@;V8@<&]S="UI;G-T
M86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1F:6QE6&UL
M6R=N86UE)UT@+B`G(B!F86EL960Z("<@+B`D=V%R;FEN9W,I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT*"1A;F%L>7-I<ULG9&5C
M;&%R961?8VQA<W-E<R==*2`A/2`Q*2![#0H@("`@("`@("`@("`@("`@4$5!
M4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(')E='5R
M;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L
M;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG
M;F%M92==("X@)R(@;75S="!D96-L87)E(&5X86-T;'D@,2!C;&%S<R<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-L87-S(#T@)&%N86QY<VES
M6R=D96-L87)E9%]C;&%S<V5S)UU;,%T[#0H@("`@("`@("`@("!I9B`H)&-L
M87-S("$]('-T<E]R97!L86-E*&%R<F%Y*"<O)RP@)RYP:'`G*2P@87)R87DH
M)U\G+"`G)RDL#0H@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==
M*2`N("=?<&]S=&EN<W1A;&PG*2![#0H@("`@("`@("`@("`@("`@4$5!4CHZ
M<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(')E='5R;B!A
M<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S
M8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M
M92==("X@)R(@8VQA<W,@(B<@+B`D8VQA<W,@+B`G(B!M=7-T(&)E(&YA;65D
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H87)R87DH
M)R\G+"`G+G!H<"<I+"!A<G)A>2@G7R<L("<G*2P-"B`@("`@("`@("`@("`@
M("`@("`@)&9I;&58;6Q;)VYA;64G72D@+B`G7W!O<W1I;G-T86QL(B<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D86YA;'ES
M:7-;)V1E8VQA<F5D7VUE=&AO9',G75LD8VQA<W-=*2D@>PT*("`@("`@("`@
M("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@
M("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0
M;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@("`@("`@("`@
M)&9I;&58;6Q;)VYA;64G72`N("<B(&UU<W0@9&5C;&%R92!M971H;V1S(&EN
M:70H*2!A;F0@<G5N*"DG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1M971H;V1S(#T@87)R87DH)VEN:70G(#T^(#`L("=R=6XG(#T^(#$I.PT*
M("`@("`@("`@("`@9F]R96%C:"`H)&%N86QY<VES6R=D96-L87)E9%]M971H
M;V1S)UU;)&-L87-S72!A<R`D;65T:&]D*2![#0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1M971H;V1S6R1M971H;V1=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D;65T:&]D<ULD;65T:&]D72D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT
M*"1M971H;V1S*2D@>PT*("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!
M4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B
M(&UU<W0@9&5C;&%R92!M971H;V1S(&EN:70H*2!A;F0@<G5N*"DG*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!014%2.CIP;W!%<G)O
M<DAA;F1L:6YG*"D[#0H@("`@("`@("1D969I;F5D<&%R86US(#T@87)R87DH
M*3L-"B`@("`@("`@)'1A<VMS3F%M97-P86-E(#T@)'!K9RT^9V5T5&%S:W-.
M<R@I("X@)SHG.PT*("`@("`@("!I9B`H(6ES<V5T*"1X;6Q;)'1A<VMS3F%M
M97-P86-E("X@)W!A<F%M9W)O=7`G72D@)B8@:7-S970H)'AM;%LG<&%R86UG
M<F]U<"==*2D@>PT*("`@("`@("`@("`@+R\@:6X@;W)D97(@=&\@<W5P<&]R
M="!T:&4@;VQD97(@8F5T87,L('=H:6-H(&1I9"!N;W0@97AP96-T(&EN=&5R
M;F%L('1A9W,-"B`@("`@("`@("`@("\O('1O(&%L<V\@=7-E('1H92!N86UE
M<W!A8V4-"B`@("`@("`@("`@("1T87-K<TYA;65S<&%C92`]("<G.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D>&UL6R1T87-K<TYA;65S<&%C
M92`N("=P87)A;6=R;W5P)UTI*2![#0H@("`@("`@("`@("`D<&%R86US(#T@
M)'AM;%LD=&%S:W-.86UE<W!A8V4@+B`G<&%R86UG<F]U<"==.PT*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2!\?"`A:7-S970H)'!A<F%M
M<ULP72DI('L-"B`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH)'!A
M<F%M<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1P87)A;2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=I9"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.
M5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B`\<&%R86UG<F]U
M<#X@;75S="!H879E("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)V%N
M("<@+B`D=&%S:W-.86UE<W!A8V4@+B`G:60^('1A9R<I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M6R1T
M87-K<TYA;65S<&%C92`N("=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:6Y?87)R87DH)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N
M86UE)UTL("1D969I;F5D<&%R86US*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G
M4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B("<@+B`D=&%S:W-.86UE
M<W!A8V4@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;6=R
M;W5P/B!I9"`B)R`N("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G72`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@<&%R86UE=&5R("(G
M("X@)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE)UT@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<B(&AA<R!N;W0@8F5E;B!P<F5V:6]U
M<VQY(&1E9FEN960G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)A;5LD=&%S:W-.86UE<W!A
M8V4@+B`G8V]N9&ET:6]N='EP92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G
M4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B("<@+B`D=&%S:W-.86UE
M<W!A8V4@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;6=R
M;W5P/B!I9"`B)R`N("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G72`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@;75S="!H879E(&$@
M)R`N("1T87-K<TYA;65S<&%C92`N(`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C;VYD:71I;VYT>7!E/B!T86<@8V]N=&%I;FEN9R!E:71H97(@
M(CTB+"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B$](BP@
M;W(@(G!R96=?;6%T8V@B)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D<&%R86U;)'1A<VMS
M3F%M97-P86-E("X@)V-O;F1I=&EO;G1Y<&4G72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)STG+"`G(3TG+"`G<')E9U]M871C:"<I*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?
M5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G
M72`N("<B("<@+B`D=&%S:W-.86UE<W!A8V4@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P87)A;6=R;W5P/B!I9"`B)R`N("1P87)A;5LD=&%S
M:W-.86UE<W!A8V4@+B`G:60G72`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R(@;75S="!H879E(&$@)R`N("1T87-K<TYA;65S<&%C92`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;F1I=&EO;G1Y<&4^('1A
M9R!C;VYT86EN:6YG(&5I=&AE<B`B/2(L("<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<B(3TB+"!O<B`B<')E9U]M871C:"(G*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G=F%L=64G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?
M15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G
M(B`G("X@)'1A<VMS3F%M97-P86-E("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<&%R86UG<F]U<#X@:60@(B<@+B`D<&%R86U;)'1A<VMS3F%M
M97-P86-E("X@)VED)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<B(&UU<W0@:&%V92!A("<@+B`D=&%S:W-.86UE<W!A8V4@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=V86QU93X@=&%G(&-O;G1A:6YI;F<@
M97AP96-T960@<&%R86UE=&5R('9A;'5E)RD[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:6YS=')U8W1I;VYS
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?<W1R:6YG*"1P
M87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:6YS=')U8W1I;VYS)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+
M7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==("X@
M)R(@)R`N("1T87-K<TYA;65S<&%C92`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!A<F%M9W)O=7`^(&ED("(G("X@)'!A<F%M6R1T87-K<TYA
M;65S<&%C92`N("=I9"==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G(B`G("X@)'1A<VMS3F%M97-P86-E("X@)VEN<W1R=6-T:6]N<SX@;75S
M="!B92!S:6UP;&4@=&5X="<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=P87)A;2==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L@+R\@/'!A<F%M/B!I<R!N;R!L;VYG
M97(@<F5Q=6ER960-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)'-U8G!A<F%M<R`]("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G<&%R
M86TG73L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S=6)P87)A
M;7,I('Q\("%I<W-E="@D<W5B<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<W5B<&%R86US(#T@87)R87DH)'-U8G!A<F%M<RD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S=6)P
M87)A;7,@87,@)'-U8G!A<F%M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!
M4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M
M92==("X@)R(@<&%R86UE=&5R(&9O<B`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&%S:W-.86UE<W!A8V4@+B`G<&%R86UG<F]U<#X@:60@
M(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;5LD=&%S
M:W-.86UE<W!A8V4@+B`G:60G72`N("<B(&UU<W0@:&%V92`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G82`G("X@)'1A<VMS3F%M97-P86-E
M("X@)VYA;64^('1A9R<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UMA+7I!+5HP+3E=
M*R\G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`D<W5B<&%R86U;)'1A
M<VMS3F%M97-P86-E("X@)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@
M)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!P87)A;65T97(@(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=6)P87)A;5LD=&%S
M:W-.86UE<W!A8V4@+B`G;F%M92==("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(B!F;W(@)R`N("1T87-K<TYA;65S<&%C92`N("=P87)A;6=R
M;W5P/B!I9"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M6R1T87-K<TYA;65S<&%C92`N("=I9"==("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B!I<R!N;W0@82!V86QI9"!N86UE+B`@375S="!C
M;VYT86EN(&]N;'D@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,G*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1S=6)P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G<')O;7!T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]4
M05-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==
M("X@)R(@<&%R86UE=&5R("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<W5B<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VYA;64G72`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@9F]R("<@+B`D=&%S:W-.
M86UE<W!A8V4@+B`G<&%R86UG<F]U<#X@:60@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G
M72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@;75S="!H879E
M(&$@)R`N("1T87-K<TYA;65S<&%C92`N("=P<F]M<'0^('1A9R<I.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=T>7!E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]4
M05-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==
M("X@)R(@<&%R86UE=&5R("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<W5B<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VYA;64G72`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@9F]R("<@+B`D=&%S:W-.
M86UE<W!A8V4@+B`G<&%R86UG<F]U<#X@:60@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G
M72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@;75S="!H879E
M(&$@)R`N("1T87-K<TYA;65S<&%C92`N("=T>7!E/B!T86<G*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D9&5F:6YE
M9'!A<F%M<UM=(#T@)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=I9"==("X@
M)SHZ)R`N#0H@("`@("`@("`@("`@("`@("`@("1S=6)P87)A;5LD=&%S:W-.
M86UE<W!A8V4@+B`G;F%M92==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!);FET:6%L:7IE(&$@=&%S:R!I;G-T
M86YC92!W:71H('1H92!P87)A;65T97)S#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P87)A;2!A<G)A>2!A='1R:6)U
M=&5S(&9R;VT@=&AE(#QF:6QE/B!T86<@8V]N=&%I;FEN9R!T:&ES('1A<VL-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@;&%S="!I;G-T86QL960@=F5R
M<VEO;B!O9B!T:&ES('!A8VMA9V4L(&EF(&%N>2`H=7-E9G5L(&9O<B!U<&=R
M861E<RD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;FET*"1X;6PL("1F:6QE
M871T<FEB<RP@)&QA<W1V97)S:6]N*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]C;&%S<R`]('-T<E]R97!L86-E*"<O)RP@)U\G+"`D9FEL96%T=')I8G-;
M)VYA;64G72D[#0H@("`@("`@("1T:&ES+3Y?9FEL96YA;64@/2`D9FEL96%T
M=')I8G-;)VYA;64G73L-"B`@("`@("`@)'1H:7,M/E]C;&%S<R`]('-T<E]R
M97!L86-E("@G+G!H<"<L("<G+"`D=&AI<RT^7V-L87-S*2`N("=?<&]S=&EN
M<W1A;&PG.PT*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1X;6P[#0H@("`@
M("`@("1T:&ES+3Y?;&%S='9E<G-I;VX@/2`D;&%S='9E<G-I;VX[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4W1R:7`@=&AE('1A<VMS.B!N86UE<W!A
M8V4@9G)O;2!I;G1E<FYA;"!P87)A;7,-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]S=')I<$YA;65S
M<&%C92@D<&%R86US(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D<&%R
M86US(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D<&%R86US(#T@87)R87DH
M*3L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A;7,I
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7,@87,@)&D@/3X@
M)'!A<F%M*2![#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)A
M;2DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@)'1H:7,M/E]S
M=')I<$YA;65S<&%C92@D<&%R86TI.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D<&%R86US6W-T<E]R97!L86-E*"1T:&ES+3Y?<&MG
M+3YG971487-K<TYS*"D@+B`G.B<L("<G+"`D:2E=(#T@)'!A<F%M.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&YE=W!A<F%M
M<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("!F;W)E86-H("@D<&%R86US(&%S
M("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2`]("1T
M:&ES+3Y?<W1R:7!.86UE<W!A8V4H)'!A<F%M*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)&YE=W!A<F%M<UMS=')?<F5P;&%C92@D
M=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SHG+"`G)RP@)&DI72`]("1P
M87)A;3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D;F5W
M<&%R86US.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M56YL:6ME(&]T:&5R('1A<VMS+"!T:&4@:6YS=&%L;&5D(&9I;&4@;F%M92!I
M<R!P87-S960@:6X@:6YS=&5A9"!O9B!T:&4@9FEL92!C;VYT96YT<RP-"B`@
M("`@*B!B96-A=7-E('1H:7,@=&%S:R!I<R!H86YD;&5D('!O<W0M:6YS=&%L
M;&%T:6]N#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!
M4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!N
M86UE#0H@("`@("H@0')E='5R;B!B;V]L?%!%05)?17)R;W(@9F%L<V4@=&\@
M<VMI<"!T:&ES(&9I;&4L(%!%05)?17)R;W(@=&\@9F%I;`T*("`@("`J("`@
M("`@("`@*'5S92`D=&AI<RT^=&AR;W=%<G)O<BD-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S=&%R=%-E<W-I;VXH)'!K9RP@)&-O;G1E;G1S*0T*("`@('L-
M"B`@("`@("`@:68@*"1T:&ES+3YI;G-T86QL<&AA<V4@(3T@4$5!4E]405-+
M7TE.4U1!3$PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("`O+R!R96UO=F4@=&AE('1A<VMS.B!N86UE<W!A8V4@
M:68@<')E<V5N=`T*("`@("`@("`D=&AI<RT^7W!K9R`]("1P:V<[#0H@("`@
M("`@("1T:&ES+3Y?<W1R:7!.86UE<W!A8V4H*3L-"B`@("`@("`@)'1H:7,M
M/FQO9V=E<BT^;&]G*#`L("=);F-L=61I;F<@97AT97)N86P@<&]S="UI;G-T
M86QL871I;VX@<V-R:7!T("(G("X-"B`@("`@("`@("`@("1C;VYT96YT<R`N
M("<B("T@86YY(&5R<F]R<R!A<F4@:6X@=&AI<R!S8W)I<'0G*3L-"B`@("`@
M("`@:6YC;'5D95]O;F-E("1C;VYT96YT<SL-"B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D=&AI<RT^7V-L87-S*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/FQO9V=E<BT^;&]G*#`L("=);F-L=7-I;VX@<W5C8V5E9&5D)RD[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G1H<F]W
M17)R;W(H)VEN:70@;V8@<&]S="UI;G-T86QL('-C<FEP="!C;&%S<R`B)R`N
M("1T:&ES+3Y?8VQA<W,-"B`@("`@("`@("`@("`@("`N("<B(&9A:6QE9"<I
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?;V)J(#T@;F5W("1T:&ES
M+3Y?8VQA<W,[#0H@("`@("`@("1T:&ES+3YL;V=G97(M/FQO9R@Q+"`G<G5N
M;FEN9R!P;W-T+6EN<W1A;&P@<V-R:7!T("(G("X@)'1H:7,M/E]C;&%S<R`N
M("<M/FEN:70H*2(G*3L-"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D<F5S(#T@)'1H:7,M
M/E]O8FHM/FEN:70H)'1H:7,M/F-O;F9I9RP@)'!K9RP@)'1H:7,M/E]L87-T
M=F5R<VEO;BD[#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@:68@*"1R97,I('L-"B`@("`@("`@("`@("1T:&ES+3YL;V=G
M97(M/FQO9R@P+"`G:6YI="!S=6-C965D960G*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=&AR;W=%<G)O<B@G:6YI
M="!O9B!P;W-T+6EN<W1A;&P@<V-R:7!T("(G("X@)'1H:7,M/E]C;&%S<R`N
M#0H@("`@("`@("`@("`@("`@)RT^:6YI="@I(B!F86EL960G*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7V-O;G1E;G1S(#T@)&-O;G1E;G1S.PT*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!.;R!L;VYG97(@=7-E9`T*("`@("`J($!S964@4$5!4E]086-K86=E1FEL
M95]V,CHZ<G5N4&]S=&EN<W1A;&Q38W)I<'1S*"D-"B`@("`@*B!`<&%R86T@
M87)R87D@86X@87)R87D@;V8@=&%S:W,-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&EN<W1A;&P@;W(@=7!G<F%D90T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D
M#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(')U;B@I
M#0H@("`@>PT*("`@('T-"GT-"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U1A<VLO4F5P;&%C92YP:'``````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q-C(U-@`Q,#4Q-30S,3`U-P`P,C$P-S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\J*@T*("H@
M/'1A<VMS.G)E<&QA8V4^#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(%)E<&QA8V4N<&AP+'8@,2XQ-2`R,#`V+S`S+S`R(#$X.C$T
M.C$S(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J($)A
M<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U1A<VLO0V]M;6]N
M+G!H<"<[#0HO*BH-"B`J($EM<&QE;65N=',@=&AE(')E<&QA8V4@9FEL92!T
M87-K+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?5&%S:U]297!L
M86-E(&5X=&5N9',@4$5!4E]487-K7T-O;6UO;@T*>PT*("`@('9A<B`D='EP
M92`]("=S:6UP;&4G.PT*("`@('9A<B`D<&AA<V4@/2!014%27U1!4TM?4$%#
M2T%'14%.1$E.4U1!3$P[#0H@("`@=F%R("1?<F5P;&%C96UE;G1S.PT*#0H@
M("`@+RHJ#0H@("`@("H@5F%L:61A=&4@=&AE(')A=R!X;6P@870@<&%R<VEN
M9RUT:6UE+@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8R#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P
M87)A;2!014%27T-O;F9I9PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!V86QI9&%T95AM;"@D<&MG+"`D>&UL+"`F)&-O;F9I9RP@
M)&9I;&58;6PI#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1X;6Q;)V%T
M=')I8G,G72DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!
M4TM?15)23U)?3D]!5%1224)3*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(6ES<V5T*"1X;6Q;)V%T=')I8G,G75LG='EP92==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E]-25-324Y'7T%45%))
M0BP@)W1Y<&4G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1X
M;6Q;)V%T=')I8G,G75LG=&\G72DI('L-"B`@("`@("`@("`@(')E='5R;B!A
M<G)A>2A014%27U1!4TM?15)23U)?34E34TE.1U]!5%1224(L("=T;R<I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'AM;%LG871T<FEB<R==
M6R=F<F]M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]4
M05-+7T524D]27TU)4U-)3D=?05144DE"+"`G9G)O;2<I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D>&UL6R=A='1R:6)S)UU;)W1Y<&4G72`]/2`G<&5A
M<BUC;VYF:6<G*2![#0H@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1X;6Q;
M)V%T=')I8G,G75LG=&\G72P@)&-O;F9I9RT^9V5T2V5Y<R@I*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?5U)/
M3D=?05144DE"7U9!3%5%+"`G=&\G+"`D>&UL6R=A='1R:6)S)UU;)W1O)UTL
M#0H@("`@("`@("`@("`@("`@("`@("1C;VYF:6<M/F=E=$ME>7,H*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS96EF("@D>&UL6R=A='1R:6)S
M)UU;)W1Y<&4G72`]/2`G<&AP+6-O;G-T)RD@>PT*("`@("`@("`@("`@:68@
M*&1E9FEN960H)'AM;%LG871T<FEB<R==6R=T;R==*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27U=2
M3TY'7T%45%))0E]604Q512P@)W1O)RP@)'AM;%LG871T<FEB<R==6R=T;R==
M+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=F%L:60@4$A0(&-O;G-T
M86YT)RDI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H)'AM
M;%LG871T<FEB<R==6R=T>7!E)UT@/3T@)W!A8VMA9V4M:6YF;R<I('L-"B`@
M("`@("`@("`@(&EF("AI;E]A<G)A>2@D>&UL6R=A='1R:6)S)UU;)W1O)UTL
M#0H@("`@("`@("`@("`@("`@87)R87DH)VYA;64G+"`G<W5M;6%R>2<L("=C
M:&%N;F5L)RP@)VYO=&5S)RP@)V5X=&5N9',G+"`G9&5S8W)I<'1I;VXG+`T*
M("`@("`@("`@("`@("`@("`@("`G<F5L96%S95]N;W1E<R<L("=L:6-E;G-E
M)RP@)W)E;&5A<V4M;&EC96YS92<L("=L:6-E;G-E+75R:2<L#0H@("`@("`@
M("`@("`@("`@("`@("=V97)S:6]N)RP@)V%P:2UV97)S:6]N)RP@)W-T871E
M)RP@)V%P:2US=&%T92<L("=R96QE87-E7V1A=&4G+`T*("`@("`@("`@("`@
M("`@("`@("`G9&%T92<L("=T:6UE)RDI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?5U)/3D=?0514
M4DE"7U9!3%5%+"`G=&\G+"`D>&UL6R=A='1R:6)S)UU;)W1O)UTL#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=N86UE)RP@)W-U;6UA<GDG+"`G8VAA
M;FYE;"<L("=N;W1E<R<L("=E>'1E;F1S)RP@)V1E<V-R:7!T:6]N)RP-"B`@
M("`@("`@("`@("`@("`@("`@)W)E;&5A<V5?;F]T97,G+"`G;&EC96YS92<L
M("=R96QE87-E+6QI8V5N<V4G+"`G;&EC96YS92UU<FDG+`T*("`@("`@("`@
M("`@("`@("`@("`G=F5R<VEO;B<L("=A<&DM=F5R<VEO;B<L("=S=&%T92<L
M("=A<&DM<W1A=&4G+"`G<F5L96%S95]D871E)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V1A=&4G+"`G=&EM92<I*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!
M4TM?15)23U)?5U)/3D=?05144DE"7U9!3%5%+"`G='EP92<L("1X;6Q;)V%T
M=')I8G,G75LG='EP92==+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=P96%R
M+6-O;F9I9R<L("=P86-K86=E+6EN9F\G+"`G<&AP+6-O;G-T)RDI.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($EN:71I86QI>F4@82!T87-K(&EN<W1A;F-E('=I=&@@=&AE
M('!A<F%M971E<G,-"B`@("`@*B!`<&%R86T@87)R87D@<F%W+"!P87)S960@
M>&UL#0H@("`@("H@0'!A<F%M('5N=7-E9`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&EN:70H)'AM;"P@)&%T=')I8G,I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W)E<&QA8V5M96YT<R`](&ES<V5T*"1X;6Q;)V%T=')I8G,G72D@/R!A
M<G)A>2@D>&UL*2`Z("1X;6P[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1&\@82!P86-K86=E+GAM;"`Q+C`@<F5P;&%C96UE;G0L('=I=&@@861D:71I
M;VYA;"!P86-K86=E+6EN9F\@9FEE;&1S(&%V86EL86)L90T*("`@("`J#0H@
M("`@("H@4V5E('9A;&ED871E6&UL*"D@<V]U<F-E(&9O<B!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!A;&QO=V5D(&9I96QD<PT*("`@("`J($!P87)A;2!014%2
M7U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&9I;&4@8V]N=&5N=',-"B`@("`@*B!`<&%R86T@<W1R
M:6YG('1H92!E=F5N='5A;"!F:6YA;"!F:6QE(&QO8V%T:6]N("AI;F9O<FUA
M=&EO;F%L(&]N;'DI#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V5\4$5!
M4E]%<G)O<B!F86QS92!T;R!S:VEP('1H:7,@9FEL92P@4$5!4E]%<G)O<B!T
M;R!F86EL#0H@("`@("H@("`@("`@("`H=7-E("1T:&ES+3YT:')O=T5R<F]R
M*2P@;W1H97)W:7-E(')E='5R;B!T:&4@;F5W(&-O;G1E;G1S#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<W1A<G1397-S:6]N*"1P:V<L("1C;VYT96YT<RP@
M)&1E<W0I#0H@("`@>PT*("`@("`@("`D<W5B<W1?9G)O;2`]("1S=6)S=%]T
M;R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F5P;&%C
M96UE;G1S(&%S("1A*2![#0H@("`@("`@("`@("`D82`]("1A6R=A='1R:6)S
M)UT[#0H@("`@("`@("`@("`D=&\@/2`G)SL-"B`@("`@("`@("`@(&EF("@D
M85LG='EP92==(#T]("=P96%R+6-O;F9I9R<I('L-"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/FEN<W1A;&QP:&%S92`]/2!014%27U1!4TM?4$%#2T%'
M12D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D85LG=&\G72`]
M/2`G;6%S=&5R7W-E<G9E<B<I('L-"B`@("`@("`@("`@("`@("`@("`@)&-H
M86X@/2`D=&AI<RT^<F5G:7-T<GDM/F=E=$-H86YN96PH)'!K9RT^9V5T0VAA
M;FYE;"@I*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%014%2.CII<T5R
M<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1O(#T@
M)&-H86XM/F=E=%-E<G9E<B@I.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9V=E<BT^
M;&]G*#`L("(D9&5S=#H@:6YV86QI9"!P96%R+6-O;F9I9R!R97!L86-E;65N
M=#H@)&%;=&]=(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F-O
M;F9I9RT^:7-$969I;F5D3&%Y97(H)V9T<"<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!T<GD@=&AE(')E;6]T92!C;VYF:6<@9FEL92!F:7)S
M=`T*("`@("`@("`@("`@("`@("`@("`@("`@)'1O(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"1A6R=T;R==+"`G9G1P)RP@)'!K9RT^9V5T0VAA;FYE;"@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1T;RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!T:&5N(&1E9F%U;'0@
M=&\@;&]C86P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&\@/2`D
M=&AI<RT^8V]N9FEG+3YG970H)&%;)W1O)UTL(&YU;&PL("1P:V<M/F=E=$-H
M86YN96PH*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&\@/2`D=&AI<RT^8V]N9FEG+3YG970H)&%;)W1O)UTL(&YU;&PL("1P
M:V<M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)'1O*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G9V5R+3YL
M;V<H,"P@(B1D97-T.B!I;G9A;&ED('!E87(M8V]N9FEG(')E<&QA8V5M96YT
M.B`D85MT;UTB*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS96EF("@D
M85LG='EP92==(#T]("=P:'`M8V]N<W0G*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YI;G-T86QL<&AA<V4@/3T@4$5!4E]405-+7U!!0TM!1T4I
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H9&5F:6YE9"@D85LG
M=&\G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1O(#T@8V]N<W1A;G0H
M)&%;)W1O)UTI.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V=G97(M/FQO9R@P+"`B)&1E<W0Z(&EN
M=F%L:60@<&AP+6-O;G-T(')E<&QA8V5M96YT.B`D85MT;UTB*3L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@
M*"1T(#T@)'!K9RT^<&%C:V%G94EN9F\H)&%;)W1O)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T;R`]("1T.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V=G97(M/FQO9R@P
M+"`B)&1E<W0Z(&EN=F%L:60@<&%C:V%G92UI;F9O(')E<&QA8V5M96YT.B`D
M85MT;UTB*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D=&\I*2![#0H@("`@("`@("`@("`@("`@)'-U8G-T
M7V9R;VU;72`]("1A6R=F<F]M)UT[#0H@("`@("`@("`@("`@("`@)'-U8G-T
M7W1O6UT@/2`D=&\[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/FQO9V=E<BT^;&]G*#,L(")D;VEN9R`B("X@<VEZ96]F*"1S
M=6)S=%]F<F]M*2`N#0H@("`@("`@("`@("`B('-U8G-T:71U=&EO;BAS*2!F
M;W(@)&1E<W0B*3L-"B`@("`@("`@:68@*'-I>F5O9B@D<W5B<W1?9G)O;2DI
M('L-"B`@("`@("`@("`@("1C;VYT96YT<R`]('-T<E]R97!L86-E*"1S=6)S
M=%]F<F]M+"`D<W5B<W1?=&\L("1C;VYT96YT<RD[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1C;VYT96YT<SL-"B`@("!]#0I]#0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O5&%S:R]5;FEX96]L+G!H<```````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`U,C(Q`#$P-3$U-#,Q,#4W`#`R,3$R-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B`\=&%S:W,Z=6YI>&5O;#X-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T
M;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@56YI>&5O;"YP:'`L=B`Q+C@@,C`P-B\P,2\P-B`P-#HT
M-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!"
M87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+T-O;6UO
M;BYP:'`G.PT*+RHJ#0H@*B!);7!L96UE;G1S('1H92!U;FEX(&QI;F4@96YD
M:6YG<R!F:6QE('1A<VLN#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!
M4E]487-K7U5N:7AE;VP@97AT96YD<R!014%27U1A<VM?0V]M;6]N#0I[#0H@
M("`@=F%R("1T>7!E(#T@)W-I;7!L92<[#0H@("`@=F%R("1P:&%S92`](%!%
M05)?5$%32U]004-+04=%.PT*("`@('9A<B`D7W)E<&QA8V5M96YT<SL-"@T*
M("`@("\J*@T*("`@("`J(%9A;&ED871E('1H92!R87<@>&UL(&%T('!A<G-I
M;F<M=&EM92X-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*
M("`@("`J($!P87)A;2!A<G)A>2!R87<L('!A<G-E9"!X;6P-"B`@("`@*B!`
M<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@=F%L:61A=&58;6PH)'!K9RP@)'AM;"P@)B1C;VYF:6<L
M("1F:6QE6&UL*0T*("`@('L-"B`@("`@("`@:68@*"1X;6P@(3T@)R<I('L-
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y6
M04Q)1"P@)VYO(&%T=')I8G5T97,@86QL;W=E9"<I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($EN:71I86QI>F4@82!T87-K(&EN<W1A;F-E('=I=&@@=&AE('!A<F%M971E
M<G,-"B`@("`@*B!`<&%R86T@87)R87D@<F%W+"!P87)S960@>&UL#0H@("`@
M("H@0'!A<F%M('5N=7-E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN:70H
M)'AM;"P@)&%T=')I8G,I#0H@("`@>PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%)E<&QA8V4@86QL(&QI;F4@96YD:6YG<R!W:71H(&QI;F4@96YD:6YG
M<R!C=7-T;VUI>F5D(&9O<B!T:&4@8W5R<F5N="!/4PT*("`@("`J#0H@("`@
M("H@4V5E('9A;&ED871E6&UL*"D@<V]U<F-E(&9O<B!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!A;&QO=V5D(&9I96QD<PT*("`@("`J($!P87)A;2!014%27U!A
M8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&9I;&4@8V]N=&5N=',-"B`@("`@*B!`<&%R86T@<W1R:6YG
M('1H92!E=F5N='5A;"!F:6YA;"!F:6QE(&QO8V%T:6]N("AI;F9O<FUA=&EO
M;F%L(&]N;'DI#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V5\4$5!4E]%
M<G)O<B!F86QS92!T;R!S:VEP('1H:7,@9FEL92P@4$5!4E]%<G)O<B!T;R!F
M86EL#0H@("`@("H@("`@("`@("`H=7-E("1T:&ES+3YT:')O=T5R<F]R*2P@
M;W1H97)W:7-E(')E='5R;B!T:&4@;F5W(&-O;G1E;G1S#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@<W1A<G1397-S:6]N*"1P:V<L("1C;VYT96YT<RP@)&1E
M<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H,RP@(G)E
M<&QA8VEN9R!A;&P@;&EN92!E;F1I;F=S('=I=&@@7%QN(&EN("1D97-T(BD[
M#0H@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H(B]<<EQN?%QN7')\7')\
M7&XO(BP@(EQN(BP@)&-O;G1E;G1S*3L-"B`@("!]#0I]#0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U=I;F1O
M=W-E;VPN<&AP````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R,34`
M,3`U,34T,S$P-3<`,#(Q-C0P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(#QT87-K<SIW:6YD;W=S
M96]L/@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*
M("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!7
M:6YD;W=S96]L+G!H<"QV(#$N-R`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO
M9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J($)A<V4@8VQA<W,-
M"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U1A<VLO0V]M;6]N+G!H<"<[#0HO
M*BH-"B`J($EM<&QE;65N=',@=&AE('=I;F1O=W,@;&EN92!E;F1S:6YG<R!F
M:6QE('1A<VLN#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H
M<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U
M<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]487-K
M7U=I;F1O=W-E;VP@97AT96YD<R!014%27U1A<VM?0V]M;6]N#0I[#0H@("`@
M=F%R("1T>7!E(#T@)W-I;7!L92<[#0H@("`@=F%R("1P:&%S92`](%!%05)?
M5$%32U]004-+04=%.PT*("`@('9A<B`D7W)E<&QA8V5M96YT<SL-"@T*("`@
M("\J*@T*("`@("`J(%9A;&ED871E('1H92!R87<@>&UL(&%T('!A<G-I;F<M
M=&EM92X-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@
M("`J($!P87)A;2!A<G)A>2!R87<L('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R
M86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@=F%L:61A=&58;6PH)'!K9RP@)'AM;"P@)B1C;VYF:6<L("1F
M:6QE6&UL*0T*("`@('L-"B`@("`@("`@:68@*"1X;6P@(3T@)R<I('L-"B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)
M1"P@)VYO(&%T=')I8G5T97,@86QL;W=E9"<I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($EN
M:71I86QI>F4@82!T87-K(&EN<W1A;F-E('=I=&@@=&AE('!A<F%M971E<G,-
M"B`@("`@*B!`<&%R86T@87)R87D@<F%W+"!P87)S960@>&UL#0H@("`@("H@
M0'!A<F%M('5N=7-E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN:70H)'AM
M;"P@)&%T=')I8G,I#0H@("`@>PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%)E<&QA8V4@86QL(&QI;F4@96YD:6YG<R!W:71H('=I;F1O=W,@;&EN92!E
M;F1I;F=S#0H@("`@("H-"B`@("`@*B!3964@=F%L:61A=&58;6PH*2!S;W5R
M8V4@9F]R('1H92!C;VUP;&5T92!L:7-T(&]F(&%L;&]W960@9FEE;&1S#0H@
M("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E
M1FEL95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!C;VYT96YT<PT*
M("`@("`J($!P87)A;2!S=')I;F<@=&AE(&5V96YT=6%L(&9I;F%L(&9I;&4@
M;&]C871I;VX@*&EN9F]R;6%T:6]N86P@;VYL>2D-"B`@("`@*B!`<F5T=7)N
M('-T<FEN9WQF86QS97Q014%27T5R<F]R(&9A;'-E('1O('-K:7`@=&AI<R!F
M:6QE+"!014%27T5R<F]R('1O(&9A:6P-"B`@("`@*B`@("`@("`@("AU<V4@
M)'1H:7,M/G1H<F]W17)R;W(I+"!O=&AE<G=I<V4@<F5T=7)N('1H92!N97<@
M8V]N=&5N=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&%R=%-E<W-I;VXH
M)'!K9RP@)&-O;G1E;G1S+"`D9&5S="D-"B`@("![#0H@("`@("`@("1T:&ES
M+3YL;V=G97(M/FQO9R@S+"`B<F5P;&%C:6YG(&%L;"!L:6YE(&5N9&EN9W,@
M=VET:"!<7')<7&X@:6X@)&1E<W0B*3L-"B`@("`@("`@<F5T=7)N('!R96=?
M<F5P;&%C92@B+UQR7&Y\7&Y<<GQ<<GQ<;B\B+"`B7')<;B(L("1C;VYT96YT
M<RD[#0H@("`@?0T*?0T*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]014%2+U9A;&ED871O<B\`````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C`P
M,C``(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5F%L:61A=&]R
M+U!%0TPN<&AP````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,30S
M`#$P-3$U-#,Q,#4W`#`R,3(U,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`T*+RHJ#0H@*B!#:&%N;F5L(%9A;&ED
M871O<B!F;W(@=&AE('!E8VPN<&AP+FYE="!C:&%N;F5L#0H@*@T*("H@4$A0
M(#0@86YD(%!(4"`U#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z(%!%0TPN<&AP+'8@,2XW(#(P,#8O,#(O,#,@,#(Z,#(Z
M,C(@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$U#0H@*B\-"B\J*@T*("H@5&AI
M<R!I<R!T:&4@<&%R96YT(&-L87-S(&9O<B!A;&P@=F%L:61A=&]R<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O5F%L:61A=&4N<&AP)SL-"B\J*@T*("H@
M0VAA;FYE;"!686QI9&%T;W(@9F]R('1H92!P96-L+G!H<"YN970@8VAA;FYE
M;`T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,&$U#0H@*B\-"F-L87-S(%!%05)?5F%L:61A=&]R7U!%
M0TP@97AT96YD<R!014%27U9A;&ED871E#0I[#0H@("`@9G5N8W1I;VX@=F%L
M:61A=&5697)S:6]N*"D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7W-T
M871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'*2![#0H@("`@("`@("`@
M("`D=F5R<VEO;B`]("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5F5R<VEO;B@I
M.PT*("`@("`@("`@("`@)'9E<G-I;VYC;VUP;VYE;G1S(#T@97AP;&]D92@G
M+B<L("1V97)S:6]N*3L-"B`@("`@("`@("`@("1L87-T(#T@87)R87E?<&]P
M*"1V97)S:6]N8V]M<&]N96YT<RD[#0H@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1L87-T+"`Q+"`R*2`]/2`G<F,G*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A9&1&86EL=7)E*"=V97)S:6]N)RP@)U)E;&5A<V4@0V%N9&ED871E
M('9E<G-I;VYS(&UU<W0@:&%V92`G("X-"B`@("`@("`@("`@("`@("`G=7!P
M97(M8V%S92!20RP@;F]T(&QO=V5R+6-A<V4@<F,G*3L-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M=F%L:61A=&5086-K86=E3F%M92@I#0H@("`@>PT*("`@("`@("`D<F5T(#T@
M<&%R96YT.CIV86QI9&%T95!A8VMA9V5.86UE*"D[#0H@("`@("`@(&EF("@D
M=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R
M8R<I('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1T:&ES+3Y?<&%C
M:V%G97AM;"T^9V5T4&%C:V%G92@I*2`A/0T*("`@("`@("`@("`@("`@("`@
M<W1R=&]L;W=E<B@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!R;W9I9&5S17AT
M96YS:6]N*"DI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N
M:6YG*"=P<F]V:61E<V5X=&5N<VEO;B<L("=P86-K86=E(&YA;64@(B<@+@T*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!A
M8VMA9V4H*2`N("<B(&ES(&1I9F9E<F5N="!F<F]M(&5X=&5N<VEO;B!N86UE
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL
M+3YG9710<F]V:61E<T5X=&5N<VEO;B@I("X@)R(G*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0I]
M#0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"\`````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`Q-S0U,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U!A8VMA9V4N<&AP+F]R:6<`
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S<P-3$`,3`U,34T,S$P-3<`,#(R
M-#8P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]086-K86=E("AP86-K86=E
M+"!P86-K86=E+79A;&ED871E+"!C=G-D:69F+"!C=G-T86<L('!A8VMA9V4M
M9&5P96YD96YC:65S+`T*("H@<VEG;BP@;6%K97)P;2P@8V]N=F5R="!C;VUM
M86YD<RD-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@
M*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!A8VMA
M9V4N<&AP+'8@,2XQ,3D@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP
M("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR
M97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ
M#0H@*B!014%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R
M("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-
M"B`J+PT*#0IC;&%S<R!014%27T-O;6UA;F1?4&%C:V%G92!E>'1E;F1S(%!%
M05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*
M#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<&%C:V%G
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T)U:6QD
M(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K
M86=E)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W`G+`T*("`@("`@
M("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N
M;V-O;7!R97-S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=$;R!N;W0@9WII<"!T:&4@<&%C:V%G92!F:6QE)PT*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=S:&]W;F%M92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4')I;G0@=&AE(&YA;64@
M;V8@=&AE('!A8VMA9V5D(&9I;&4N)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)UMD97-C9FEL95T@6V1E<V-F:6QE,ET-"D-R96%T97,@82!014%2('!A8VMA
M9V4@9G)O;2!I=',@9&5S8W)I<'1I;VX@9FEL92`H=7-U86QL>2!C86QL960-
M"G!A8VMA9V4N>&UL*2X@($EF(&$@<V5C;VYD('!A8VMA9V5F:6QE(&ES('!A
M<W-E9"!I;BP@=&AE;@T*=&AE('!A8VMA9V5R('=I;&P@8VAE8VL@=&\@;6%K
M92!S=7)E('1H870@;VYE(&ES(&$@<&%C:V%G92YX;6P-"G9E<G-I;VX@,2XP
M+"!A;F0@=&AE(&]T:&5R(&ES(&$@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`N
M("!4:&4-"G!A8VMA9V4N>&UL('9E<G-I;VX@,2XP('=I;&P@8F4@<V%V960@
M87,@(G!A8VMA9V4N>&UL(B!I;B!T:&4@87)C:&EV92P-"F%N9"!T:&4@;W1H
M97(@87,@(G!A8VMA9V4R+GAM;"(@:6X@=&AE(&%R8VAI=F4B#0HG#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`G<&%C:V%G92UV86QI9&%T92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U9A;&ED871E(%!A8VMA
M9V4@0V]N<VES=&5N8WDG+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G
M9&]086-K86=E5F%L:61A=&4G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]
M/B`G<'8G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@
M("`@("`@("`@("`G9&]C)R`]/B`G#0HG+`T*("`@("`@("`@("`@*2P-"B`@
M("`@("`@)V-V<V1I9F8G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA
M<GDG(#T^("=2=6X@82`B8W9S(&1I9F8B(&9O<B!A;&P@9FEL97,@:6X@82!P
M86-K86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0W9S1&EF
M9B<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C9"<L#0H@("`@("`@
M("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)W%U
M:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G<2<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("="92!Q
M=6EE="<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)W)E86QL>7%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G42<L#0H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("="92!R96%L;'D@<75I970G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=D871E)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G1"<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=$:69F(&%G86EN<W0@<F5V:7-I;VX@;V8@
M1$%412<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$051%)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5L
M96%S92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)U(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF
M9B!A9V%I;G-T('1A9R!F;W(@<&%C:V%G92!R96QE87-E(%)%3"<L#0H@("`@
M("`@("`@("`@("`@("`@("=A<F<G(#T^("=214PG+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=R979I<VEO;B<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E
M=FES:6]N(%)%5B<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=2
M158G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=C;VYT97AT)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("='96YE<F%T92!C;VYT97AT(&1I9F8G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=U;FEF:65D)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G=2<L#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("='96YE<F%T92!U;FEF:65D(&1I9F8G
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I
M9VYO<F4M8V%S92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)VDG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G26=N;W)E(&-A<V4L(&-O;G-I9&5R('5P<&5R+2!A;F0@;&]W97(M8V%S
M92!L971T97)S(&5Q=6EV86QE;G0G+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M=VAI=&5S<&%C92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V(G+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E(&-H86YG97,@
M:6X@86UO=6YT(&]F('=H:71E('-P86-E)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E+6)L86YK+6QI;F5S)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M0B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=)9VYO<F4@8VAA
M;F=E<R!T:&%T(&EN<V5R="!O<B!D96QE=&4@8FQA;FL@;&EN97,G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=B<FEE9B<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=297!O
M<G0@;VYL>2!W:&5T:&5R('1H92!F:6QE<R!D:69F97(L(&YO(&1E=&%I;',G
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=D
M<GDM<G5N)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$
M;VY<)W0@9&\@86YY=&AI;F<L(&IU<W0@<')E=&5N9"<L#0H@("`@("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("=D;V,G(#T^("<\<&%C:V%G92YX;6P^#0I#;VUP87)E<R!A;&P@=&AE(&9I
M;&5S(&EN(&$@<&%C:V%G92X@(%=I=&AO=70@86YY(&]P=&EO;G,L('1H:7,-
M"F-O;6UA;F0@=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O9&4@=VET:"!T
M:&4@;&%S="!C:&5C:V5D+6EN(&-O9&4N#0I5<VEN9R!T:&4@+7(@;W(@+5(@
M;W!T:6]N('EO=2!M87D@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@
M=&AA=`T*;V8@82!S<&5C:69I8R!R96QE87-E+@T*)RP-"B`@("`@("`@("`@
M("DL#0H@("`@("`@("=C=G-T86<G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=3970@0U93(%)E;&5A<V4@5&%G)RP-"B`@("`@("`@
M("`@("=F=6YC=&EO;B<@/3X@)V1O0W9S5&%G)RP-"B`@("`@("`@("`@("=S
M:&]R=&-U="<@/3X@)V-T)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G<75I970G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=Q)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)T)E('%U:65T)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5A;&QY<75I970G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=1
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T)E(')E86QL>2!Q
M=6EE="<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)W-L:61E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G1B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=-;W9E("AS;&ED92D@=&%G(&EF(&ET(&5X:7-T<R<L#0H@("`@("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V1E;&5T92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V0G+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4F5M;W9E('1A9R<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V1R>2UR
M=6XG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=N)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1O;EPG
M="!D;R!A;GET:&EN9RP@:G5S="!P<F5T96YD)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O
M8R<@/3X@)SQP86-K86=E+GAM;#X@6V9I;&5S+BXN70T*4V5T<R!A($-64R!T
M86<@;VX@86QL(&9I;&5S(&EN(&$@<&%C:V%G92X@(%5S92!T:&ES(&-O;6UA
M;F0@869T97(@>6]U(&AA=F4-"G!A8VMA9V5D(&$@9&ES=')I8G5T:6]N('1A
M<F)A;&P@=VET:"!T:&4@(G!A8VMA9V4B(&-O;6UA;F0@=&\@=&%G('=H870-
M"G)E=FES:6]N<R!O9B!W:&%T(&9I;&5S('=E<F4@:6X@=&AA="!R96QE87-E
M+B`@268@;F5E9"!T;R!F:7@@<V]M971H:6YG#0IA9G1E<B!R=6YN:6YG(&-V
M<W1A9R!O;F-E+"!B=70@8F5F;W)E('1H92!T87)B86QL(&ES(')E;&5A<V5D
M('1O('1H92!P=6)L:6,L#0IU<V4@=&AE(")S;&ED92(@;W!T:6]N('1O(&UO
M=F4@=&AE(')E;&5A<V4@=&%G+@T*#0IT;R!I;F-L=61E(&9I;&5S("AS=6-H
M(&%S(&$@<V5C;VYD('!A8VMA9V4N>&UL+"!O<B!T97-T<R!N;W0@:6YC;'5D
M960@:6X@=&AE#0IR96QE87-E*2P@<&%S<R!T:&5M(&%S(&%D9&ET:6]N86P@
M<&%R86UE=&5R<RX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<&%C
M:V%G92UD97!E;F1E;F-I97,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U
M;6UA<GDG(#T^("=3:&]W('!A8VMA9V4@9&5P96YD96YC:65S)RP-"B`@("`@
M("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G941E<&5N9&5N8VEE<R<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=P9"<L#0H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("<-"DQI<W0@86QL(&1E<&5N8VEE<R!T:&4@<&%C:V%G92!H87,N)PT*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)W-I9VXG(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W-U;6UA<GDG(#T^("=3:6=N(&$@<&%C:V%G92!D:7-T<FEB=71I
M;VX@9FEL92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U-I9VXG
M+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<VDG+`T*("`@("`@("`@
M("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]
M/B`G/'!A8VMA9V4M9FEL93X-"E-I9VYS(&$@<&%C:V%G92!D:7-T<FEB=71I
M;VX@*"YT87(@;W(@+G1G>BD@9FEL92!W:71H($=N=5!'+B<L#0H@("`@("`@
M("`@("`I+`T*("`@("`@("`G;6%K97)P;2<@/3X@87)R87DH#0H@("`@("`@
M("`@("`G<W5M;6%R>2<@/3X@)T)U:6QD<R!A;B!24$T@<W!E8R!F:6QE(&9R
M;VT@82!014%2('!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]-86ME4E!-)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)P
M;2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@)W-P96,M=&5M<&QA=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=T)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V%R9R<@/3X@)T9)3$4G+`T*("`@("`@("`@("`@("`@("`@("`G
M9&]C)R`]/B`G57-E($9)3$4@87,@4E!-('-P96,@9FEL92!T96UP;&%T92<-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<G!M
M+7!K9VYA;64G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO
M<G1O<'0G(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@
M)T9/4DU!5"<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=5<V4@
M1D]234%4(&%S(&9O<FUA="!S=')I;F<@9F]R(%)032!P86-K86=E(&YA;64L
M("5S(&ES(')E<&QA8V5D#0IB>2!T:&4@4$5!4B!P86-K86=E(&YA;64L(&1E
M9F%U;'1S('1O(")014%2.CHE<R(N)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)SQP86-K86=E+69I;&4^#0H-"D-R96%T97,@86X@4E!-("YS<&5C(&9I;&4@
M9F]R('=R87!P:6YG(&$@4$5!4B!P86-K86=E(&EN<VED92!A;B!24$T-"G!A
M8VMA9V4N("!);G1E;F1E9"!T;R!B92!U<V5D(&9R;VT@=&AE(%-014-3(&1I
M<F5C=&]R>2P@=VET:"!T:&4@4$5!4@T*<&%C:V%G92!T87)B86QL(&EN('1H
M92!33U520T53(&1I<F5C=&]R>3H-"@T*)"!P96%R(&UA:V5R<&T@+BXO4T]5
M4D-%4R].971?4V]C:V5T+3$N,"YT9WH-"E=R;W1E(%)032!S<&5C(&9I;&4@
M4$5!4CHZ3F5T7T=E;RTQ+C`N<W!E8PT*)"!R<&T@+6)B(%!%05(Z.DYE=%]3
M;V-K970M,2XP+G-P96,-"BXN+@T*5W)O=&4Z("]U<W(O<W)C+W)E9&AA="]2
M4$U3+VDS.#8O4$5!4CHZ3F5T7U-O8VME="TQ+C`M,2YI,S@V+G)P;0T*)RP-
M"B`@("`@("`@("`@("DL#0H@("`@("`@("=C;VYV97)T)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0V]N=F5R="!A('!A8VMA9V4N
M>&UL(#$N,"!T;R!P86-K86=E+GAM;"`R+C`@9F]R;6%T)RP-"B`@("`@("`@
M("`@("=F=6YC=&EO;B<@/3X@)V1O0V]N=F5R="<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=C,B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@)V9L870G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=F)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!B96%U=&EF>2!T:&4@9FEL
M96QI<W0N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C9FEL95T@6V1E
M<V-F:6QE,ET-"D-O;G9E<G1S(&$@<&%C:V%G92YX;6P@:6X@,2XP(&9O<FUA
M="!I;G1O(&$@<&%C:V%G92YX;6P-"FEN(#(N,"!F;W)M870N("!4:&4@;F5W
M(&9I;&4@=VEL;"!B92!N86UE9"!P86-K86=E,BYX;6P@8GD@9&5F875L="P-
M"F%N9"!P86-K86=E+GAM;"!W:6QL(&)E('5S960@87,@=&AE(&]L9"!F:6QE
M(&)Y(&1E9F%U;'0N#0I4:&ES(&ES(&YO="!T:&4@;6]S="!I;G1E;&QI9V5N
M="!C;VYV97)S:6]N+"!A;F0@<VAO=6QD(&]N;'D@8F4-"G5S960@9F]R(&%U
M=&]M871E9"!C;VYV97)S:6]N(&]R(&QE87)N:6YG('1H92!F;W)M870N#0HG
M#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@=F%R("1O=71P
M=70[#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*
M("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]086-K86=E(&-O;G-T<G5C
M=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?4&%C:V%G92@F)'5I+"`F)&-O
M;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O
M;6UO;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(%]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H*0T*#0H@("`@
M9G5N8W1I;VX@7V1I<W!L87E686QI9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R
M;BP@)'-T<FEC="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@9F]R96%C:"`H
M)&5R<B!A<R`D92D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B
M17)R;W(Z("1E7&XB.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1W
M87)N(&%S("1W*2![#0H@("`@("`@("`@("`D=&AI<RT^;W5T<'5T("X](")7
M87)N:6YG.B`D=UQN(CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;W5T
M<'5T("X]('-P<FEN=&8H)U9A;&ED871I;VXZ("5D(&5R<F]R*',I+"`E9"!W
M87)N:6YG*',I)RXB7&XB+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<VEZ96]F*"1E<G(I+"!S:7IE;V8H)'=A<FXI*3L-"B`@
M("`@("`@:68@*"1S=')I8W0@)B8@<VEZ96]F*"1E<G(I(#X@,"D@>PT*("`@
M("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B1FEX('1H97-E(&5R<F]R<R!A
M;F0@=')Y(&%G86EN+B([#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5R*"D-"B`@("![#0H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5R)RDI('L-
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E<BYP:'`G
M.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5R
M.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M)F=E=%!A8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U9R`](&9A;'-E+"`D=&UP
M9&ER(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"=014%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O0V]M;6]N+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)U!%05(O4&%C:V%G949I;&4N<&AP)RDI('L-"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE
M*"1C;VYF:6<L("1D96)U9RP@)'1M<&1I<BD[#0H@("`@("`@("1C;VUM;VX@
M/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1C;VUM;VXM/G5I(#T@)'1H
M:7,M/G5I.PT*("`@("`@("`D82T^<V5T3&]G9V5R*"1C;VUM;VXI.PT*("`@
M("`@("!R971U<FX@)&$[#0H@("`@?0T*("`@("\O('M[>R!D;U!A8VMA9V4H
M*0T*#0H@("`@9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G
M)SL-"B`@("`@("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A<F%M<ULP72D@
M/R`D<&%R86US6S!=(#H@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@)'!K9S(@
M/2!I<W-E="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!N=6QL.PT*("`@
M("`@("!I9B`H(21P:V<R("8F("%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@
M("`@("`@("`@:68@*&9I;&5?97AI<W1S*"=P86-K86=E,BYX;6PG*2D@>PT*
M("`@("`@("`@("`@("`@("1P:V<R(#T@)W!A8VMA9V4R+GAM;"<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5R(#T@)B1T
M:&ES+3YG971086-K86=E<B@I.PT*("`@("`@("`D8V]M<')E<W,@/2!E;7!T
M>2@D;W!T:6]N<ULG;F]C;VUP<F5S<R==*2`_('1R=64@.B!F86QS93L-"B`@
M("`@("`@)')E<W5L="`]("1P86-K86=E<BT^<&%C:V%G92@D<&MG:6YF;V9I
M;&4L("1C;VUP<F5S<RP@)'!K9S(I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1R97-U;'0I.PT*("`@("`@("!]#0H@("`@("`@("\O($1O
M;B=T('=A;G0@;W5T<'5T+"!O;FQY('1H92!P86-K86=E(&9I;&4@;F%M92!J
M=7-T(&-R96%T960-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S:&]W
M;F%M92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`]("1R97-U
M;'0[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YO=71P=70I('L-
M"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T
M<'5T+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4&%C:V%G
M959A;&ED871E*"D-"@T*("`@(&9U;F-T:6]N(&1O4&%C:V%G959A;&ED871E
M*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@
M("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R
M86US*2`\(#$I('L-"B`@("`@("`@("`@("1P87)A;7-;,%T@/2`B<&%C:V%G
M92YX;6PB.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F)'1H:7,M/F=E
M=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*
M("`@("`@("`D;V)J+3YR87=2971U<FXH*3L-"B`@("`@("`@4$5!4CHZ<W1A
M=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`D:6YF;R`]("1O8FHM/F9R;VU49WI&:6QE*"1P87)A;7-;,%TL(%!%
M05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&EN9F\I*2![#0H@("`@("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU0
M86-K86=E1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/4DU!3"D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D87)C:&EV92`]("1I
M;F9O+3YG971!<F-H:79E1FEL92@I.PT*("`@("`@("`@("`@)'1A<B`]("9N
M97<@07)C:&EV95]487(H)&%R8VAI=F4I.PT*("`@("`@("`@("`@)'1A<BT^
M97AT<F%C="AD:7)N86UE*"1I;F9O+3YG971086-K86=E1FEL92@I*2D[#0H@
M("`@("`@("`@("`D:6YF;RT^<V5T4&%C:V%G949I;&4H9&ER;F%M92@D:6YF
M;RT^9V5T4&%C:V%G949I;&4H*2D@+B!$25)%0U1/4EE?4T5005)!5$]2("X-
M"B`@("`@("`@("`@("`@("`D:6YF;RT^9V5T4&%C:V%G92@I("X@)RTG("X@
M)&EN9F\M/F=E=%9E<G-I;VXH*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*
M("`@("`@("`@("`@("`@(&)A<V5N86UE*"1I;F9O+3YG971086-K86=E1FEL
M92@I*2D[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF
M;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@)'9A;&ED(#T@9F%L<V4[#0H@
M("`@("`@(&EF("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G
M,BXP)RD@>PT*("`@("`@("`@("`@:68@*"1V86QI9"`]("1I;F9O+3YV86QI
M9&%T92A014%27U9!3$E$051%7TY/4DU!3"DI('L-"B`@("`@("`@("`@("`@
M("`D:6YF;RT^9FQA='1E;D9I;&5,:7-T*"D[#0H@("`@("`@("`@("`@("`@
M)'9A;&ED(#T@)&EN9F\M/G9A;&ED871E*%!%05)?5D%,241!5$5?4$%#2T%'
M24Y'*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1V86QI9"`]("1I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%
M7U!!0TM!1TE.1RD[#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`](&%R<F%Y
M*"D[#0H@("`@("`@("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@:68@*"$D
M=F%L:60I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG971686QI
M9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@
M("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=W87)N:6YG)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?
M9&ES<&QA>59A;&ED871I;VY297-U;'1S*"1E<G(L("1W87)N*3L-"B`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1T:&ES+3YO=71P=70L("1C;VUM
M86YD*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&1O0W9S5&%G*"D-"@T*("`@(&9U;F-T:6]N(&1O
M0W9S5&%G*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@
M("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@)%]C;60@/2`D
M8V]M;6%N9#L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-
M"B`@("`@("`@("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I
M.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M
M;6%N9#H@;6ES<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@
M('T-"B`@("`@("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H
M:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@
M)&]B:BT^9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].
M3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[
M#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-
M"B`@("`@("`@:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@
M("`@9F]R96%C:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S
M("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L
M)UT@/3T@)W=A<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N
M6UT@/2`D97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE
M<W-A9V4G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T
M:6]N4F5S=6QT<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N
M9"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-6
M4R!T86<@9F%I;&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@)'9E<G-I;VX@
M/2`D:6YF;RT^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D8W9S=F5R<VEO;B`]
M('!R96=?<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D=F5R<VEO;BD[
M#0H@("`@("`@("1C=G-T86<@/2`B4D5,14%315\D8W9S=F5R<VEO;B([#0H@
M("`@("`@("1F:6QE<R`](&%R<F%Y7VME>7,H)&EN9F\M/F=E=$9I;&5L:7-T
M*"DI.PT*("`@("`@("`D8V]M;6%N9"`](")C=G,B.PT*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)W%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M
M;6%N9"`N/2`G("UQ)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M
M;6%N9"`N/2`G("U1)SL-"B`@("`@("`@?0T*("`@("`@("`D8V]M;6%N9"`N
M/2`G('1A9R<[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VQI9&4G
M72DI('L-"B`@("`@("`@("`@("1C;VUM86YD("X]("<@+48G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&5L971E)UTI*2![
M#0H@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("UD)SL-"B`@("`@("`@?0T*
M("`@("`@("`D8V]M;6%N9"`N/2`G("<@+B`D8W9S=&%G("X@)R`G("X@97-C
M87!E<VAE;&QA<F<H)'!A<F%M<ULP72D[#0H@("`@("`@(&%R<F%Y7W-H:69T
M*"1P87)A;7,I.PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<RDI('L-"B`@
M("`@("`@("`@("\O(&%D9"!I;B!A9&1I=&EO;F%L(&9I;&5S('1O(&)E('1A
M9V=E9`T*("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S
M+"`D<&%R86US*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9FEL
M97,@87,@)&9I;&4I('L-"B`@("`@("`@("`@("1C;VUM86YD("X]("<@)R`N
M(&5S8V%P97-H96QL87)G*"1F:6QE*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q*2![#0H@("`@
M("`@("`@("`D=&AI<RT^;W5T<'5T("X]("(K("1C;VUM86YD7&XB.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-O;6UA;F1<
M;B([#0H@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9')Y+7)U;B==*2D@
M>PT*("`@("`@("`@("`@)&9P(#T@<&]P96XH)&-O;6UA;F0L(")R(BD[#0H@
M("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2!R=')I;2@D;&EN
M92DN(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('!C;&]S92@D
M9G`I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@D=&AI<RT^;W5T<'5T+"`D7V-M9"D[#0H@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-V<T1I9F8H
M*0T*#0H@("`@9G5N8W1I;VX@9&]#=G-$:69F*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G
M)SL-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@
M("`@("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I.PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@
M;6ES<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@('T-"B`@
M("`@("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O
M;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^
M9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI
M.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@
M("`@('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-"B`@("`@
M("`@:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1E<G)O
M<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@/3T@
M)W=A<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N6UT@/2`D
M97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE<W-A9V4G
M73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N4F5S
M=6QT<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-64R!D:69F
M(&9A:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O,2`]("1I;F9O
M+3YG971&:6QE;&ES="@I.PT*("`@("`@("`D9FEL97,@/2`D:6YF;S$[#0H@
M("`@("`@("1C;60@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=Q=6EE="==*2D@>PT*("`@("`@("`@("`@)&-M9"`N/2`G("UQ)SL-
M"B`@("`@("`@("`@('5N<V5T*"1O<'1I;VYS6R=Q=6EE="==*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QL>7%U:65T
M)UTI*2![#0H@("`@("`@("`@("`D8VUD("X]("<@+5$G.PT*("`@("`@("`@
M("`@=6YS970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<F5L96%S92==*2D@>PT*
M("`@("`@("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E<&QA8V4H)R];7F$M
M>C`M.5TO:2<L("=?)RP@)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@
M("`@("`D8W9S=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@
M("`@("`@)&]P=&EO;G-;)W)E=FES:6]N)UT@/2`D8W9S=&%G.PT*("`@("`@
M("`@("`@=6YS970H)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@('T-
M"B`@("`@("`@)&5X96-U=&4@/2!T<G5E.PT*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)V1R>2UR=6XG72DI('L-"B`@("`@("`@("`@("1E>&5C=71E
M(#T@9F%L<V4[#0H@("`@("`@("`@("!U;G-E="@D;W!T:6]N<ULG9')Y+7)U
M;B==*3L-"B`@("`@("`@?0T*("`@("`@("`D8VUD("X]("<@9&EF9B<[#0H@
M("`@("`@("\O('1H92!R97-T(&]F('1H92!O<'1I;VYS(&%R92!P87-S960@
M<FEG:'0@;VX@=&\@(F-V<R!D:69F(@T*("`@("`@("!F;W)E86-H("@D;W!T
M:6]N<R!A<R`D;W!T:6]N(#T^("1O<'1A<F<I('L-"B`@("`@("`@("`@("1A
M<F<@/2!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T:6]N<R==6R1O
M<'1I;VY=6R=A<F<G73L-"B`@("`@("`@("`@("1S:&]R="`]($`D=&AI<RT^
M8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UU;)&]P=&EO;EU;)W-H;W)T
M;W!T)UT[#0H@("`@("`@("`@("`D8VUD("X]("1S:&]R="`_("(@+21S:&]R
M="(@.B`B("TM)&]P=&EO;B([#0H@("`@("`@("`@("!I9B`H)&%R9R`F)B`D
M;W!T87)G*2![#0H@("`@("`@("`@("`@("`@)&-M9"`N/2`H)'-H;W)T(#\@
M)R<@.B`G/2<I("X@97-C87!E<VAE;&QA<F<H)&]P=&%R9RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S
M("1F:6QE*2![#0H@("`@("`@("`@("`D8VUD("X]("<@)R`N(&5S8V%P97-H
M96QL87)G*"1F:6QE6R=N86UE)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#$I('L-"B`@("`@
M("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-M9%QN(CL-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&5X96-U=&4I('L-"B`@("`@("`@("`@("1F<"`]
M('!O<&5N*"1C;60L(")R(BD[#0H@("`@("`@("`@("!W:&EL92`H)&QI;F4@
M/2!F9V5T<R@D9G`L(#$P,C0I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/F]U='!U="`N/2!R=')I;2@D;&EN92DN(EQN(CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('!C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N
M9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!D;U!A8VMA9V5$97!E;F1E;F-I97,H*0T*#0H@("`@
M9G5N8W1I;VX@9&]086-K86=E1&5P96YD96YC:65S*"1C;VUM86YD+"`D;W!T
M:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("\O("1P87)A;7-;,%T@
M+3X@=&AE(%!%05(@<&%C:V%G92!T;R!L:7-T(&ET<R!I;F9O<FUA=&EO;@T*
M("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8F%D('!A<F%M971E<BAS
M*2P@=')Y(%PB:&5L<"`D8V]M;6%N9%PB(BD[#0H@("`@("`@('T-"B`@("`@
M("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I
M9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O
M;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@
M('T-"B`@("`@("`@)&1E<',@/2`D:6YF;RT^9V5T1&5P<R@I.PT*("`@("`@
M("!I9B`H:7-?87)R87DH)&1E<',I*2![#0H@("`@("`@("`@("!I9B`H)&EN
M9F\M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@
M("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G8V%P=&EO;B<@/3X@)T1E<&5N9&5N8VEE<R!F;W(@<&5A<B\G("X@)&EN
M9F\M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@)V)O<F1E
M<B<@/3X@=')U92P-"B`@("`@("`@("`@("`@("`@("`@)VAE861L:6YE)R`]
M/B!A<G)A>2@B4F5Q=6ER960_(BP@(E1Y<&4B+"`B3F%M92(L(")296QA=&EO
M;B(L(")697)S:6]N(BDL#0H@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9"D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)V]P=&EO;F%L)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1;)V]P=&EO;F%L)UT@/3T@
M)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@
M)TYO)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V1E<'-?<F5L7W1R86YS6R1D6R=R96PG75TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5L(#T@)'1H:7,M/E]D97!S
M7W)E;%]T<F%N<ULD9%LG<F5L)UU=.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E;"`]("1D6R=R
M96PG73L-"B`@("`@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG
M='EP92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@
M=6-F:7)S="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP92==72D[
M#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D='EP92`]("1D6R=T>7!E)UT[#0H@("`@("`@("`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;
M)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M)&1;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@("`@("`@
M("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&1;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V
M97)S:6]N(#T@)&1;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@
M)R<[#0H@("`@("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@
M("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D<F5Q+"`D='EP92P@)&YA
M;64L("1R96PL("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>R`O+R!P86-K86=E+GAM;"`R+C`@9&5P96YD96YC
M:65S(&1I<W!L87D-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@("`@("`@("`D9&5P<R`]
M("1I;F9O+3YG971$97!E;F1E;F-I97,H*3L-"B`@("`@("`@("`@("`@("`D
M<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1D97!S*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D9"`](&YE=R!014%27T1E<&5N9&5N8WDR*"1T:&ES+3YC;VYF
M:6<L(&%R<F%Y*"DL("<G*3L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&$@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]
M/B`G1&5P96YD96YC:65S(&9O<B`G("X@)&EN9F\M/F=E=%!A8VMA9V4H*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*")2
M97%U:7)E9#\B+"`B5'EP92(L(").86UE(BP@)U9E<G-I;VYI;F<G+"`G1W)O
M=7`G*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1T>7!E(#T^("1S=6)D*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@*"1T>7!E(#T]("=R
M97%U:7)E9"<I(#\@)UEE<R<@.B`G3F\G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1T>7!E(#T]("=G<F]U<"<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9W)O=7`@/2`D<W5B9%LG871T<FEB<R==6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1G<F]U<"`]("<G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<W5B9%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<W5B9"`](&%R<F%Y*"1S=6)D*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S
M=6)D(&%S("1G<F]U<&$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9W)O=7!A(&%S("1D97!T>7!E(#T^("1D97!I;F9O*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P='EP
M92`]/2`G871T<FEB<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D9&5P='EP92`]/2`G<&5A<FEN<W1A;&QE<B<I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D97!T>7!E(#T@)W!E87(@26YS
M=&%L;&5R)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M97!I;F9O6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<&EN9F\@/2!A<G)A>2@D9&5P:6YF;RD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&1E<&EN9F\@87,@)&EN9BD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D:6YF6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)')E9RT^8VAA;FYE;$%L:6%S
M*"1I;F9;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"$D86QI87,I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)RAC:&%N
M;F5L/RD@)R`N)&EN9ELG8VAA;FYE;"==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1A;&EA<R`N("<O)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=N
M86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64@+CT@)&EN9ELG;F%M92==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1I;F9;)W!A
M='1E<FXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F%M92`N/2`D:6YF6R=P871T97)N)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE("X]("<G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9;
M)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N86UE("X]("<@6R<@+B`D:6YF6R=U<FDG72`N("`G72<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG
M8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9E<B`]("=C;VYF;&EC=',G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F5R(#T@)&0M/E]G971%
M>'1R85-T<FEN9R@D:6YF*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1R97$L('5C9FER<W0H)&1E
M<'1Y<&4I+"`D;F%M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=F5R+"`D9W)O=7`I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@
M("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM
M86YD*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H-
M"B`@("`@("`@+R\@1F%L;&)A8VL-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*")4:&ES('!A8VMA9V4@9&]E<R!N;W0@:&%V92!A;GD@9&5P96YD
M96YC:65S+B(L("1C;VUM86YD*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@9&]3:6=N*"D-"@T*("`@(&9U;F-T:6]N(&1O4VEG;B@D8V]M
M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!R97%U
M:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("!R97%U:7)E7V]N8V4@
M)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@("\O('-H;W5L9"!M;W9E(&UO
M<W0@;V8@=&AI<R!C;V1E(&EN=&\@4$5!4E]086-K86=E<@T*("`@("`@("`O
M+R!S;R!I="=L;"!B92!E87-Y('1O(&EM<&QE;65N="`B<&5A<B!P86-K86=E
M("TM<VEG;B(-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A9"!P
M87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M<ULP72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92!D
M;V5S(&YO="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@("!]#0H@("`@
M("`@("1O8FH@/2`D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I
M9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O
M;51G>D9I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@
M('T-"B`@("`@("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D<&%R86US6S!=
M*3L-"B`@("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*"<M9"!P96%R
M<VEG;B<I.PT*("`@("`@("!I9B`H(21T87(M/F5X=')A8W1,:7-T*"=P86-K
M86=E,BYX;6P@<&%C:V%G92YS:6<G+"`D=&UP9&ER*2D@>PT*("`@("`@("`@
M("`@:68@*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G92YX;6P@<&%C:V%G
M92YS:6<G+"`D=&UP9&ER*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&5X=')A8W0@=&%R(&9I;&4B
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL
M95]E>&ES=',H(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")P86-K86=E(&%L<F5A9'D@
M<VEG;F5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5X;6P@/2`G
M<&%C:V%G92YX;6PG.PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H(B1T;7!D
M:7(O<&%C:V%G93(N>&UL(BDI('L-"B`@("`@("`@("`@("1P86-K86=E>&UL
M(#T@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@0'5N;&EN
M:R@B)'1M<&1I<B]P86-K86=E+G-I9R(I.PT*("`@("`@("`D:6YP=70@/2`D
M=&AI<RT^=6DM/G5S97)$:6%L;V<H)&-O;6UA;F0L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G1VYU4$<@4&%S<W!H
M<F%S92<I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W!A<W-W;W)D)RDI.PT*("`@("`@("`D9W!G(#T@<&]P96XH
M(F=P9R`M+6)A=&-H("TM<&%S<W!H<F%S92UF9"`P("TM87)M;W(@+2UD971A
M8V@M<VEG;B`M+6]U='!U="`D=&UP9&ER+W!A8VMA9V4N<VEG("1T;7!D:7(O
M)'!A8VMA9V5X;6P@,CXO9&5V+VYU;&PB+"`B=R(I.PT*("`@("`@("!I9B`H
M(21G<&<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B9W!G(&-O;6UA;F0@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@
M9G=R:71E*"1G<&<L("(D:6YP=71;,%U<;B(I.PT*("`@("`@("!I9B`H<&-L
M;W-E*"1G<&<I('Q\("%F:6QE7V5X:7-T<R@B)'1M<&1I<B]P86-K86=E+G-I
M9R(I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(F=P9R!S:6=N(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@("1T87(M
M/F%D9$UO9&EF>2@B)'1M<&1I<B]P86-K86=E+G-I9R(L("<G+"`D=&UP9&ER
M*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$EN<W1A;&QE<B@F)'5I*0T*
M("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?26YS=&%L
M;&5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]);G-T
M86QL97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@4$5!
M4E]);G-T86QL97(H)'5I*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-
M"B`@("`-"B`@("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O
M<V5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$-O;6UA;F1086-K86=I
M;F<H)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R<I*2![#0H@("`@("`@
M("`@("!`:6YC;'5D95]O;F-E("=014%2+T-O;6UA;F0O4&%C:V%G:6YG+G!H
M<"<[#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)U!%05)?0V]M;6%N9%]086-K86=I;F<G*2D@>PT*("`@("`@("`@
M("`@)&$@/2`F;F5W(%!%05)?0V]M;6%N9%]086-K86=I;F<H)'5I+"`D8V]N
M9FEG*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@;G5L
M;#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@
M("`@+R\@>WM[(&1O36%K95)032@I#0H-"B`@("!F=6YC=&EO;B!D;TUA:V52
M4$TH)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*#0H@("`@("`@("\O($-H96-K
M('1O('-E92!I9B!014%27T-O;6UA;F1?4&%C:V%G:6YG(&ES(&EN<W1A;&QE
M9"P@86YD#0H@("`@("`@("\O('1R86YS<&%R96YT;'D@<W=I=&-H('1O('5S
M92!T:&4@(FUA:V4M<G!M+7-P96,B(&-O;6UA;F0@9G)O;2!I=`T*("`@("`@
M("`O+R!I;G-T96%D+"!I9B!I="!D;V5S+B!/=&AE<G=I<V4L(&-O;G1I;G5E
M('1O('5S92!T:&4@;VQD('9E<G-I;VX-"B`@("`@("`@+R\@;V8@(FUA:V5R
M<&TB('-U<'!L:65D('=I=&@@=&AI<R!P86-K86=E("A014%2*2X-"B`@("`@
M("`@)'!A8VMA9VEN9U]C;60@/2`D=&AI<RT^9V5T0V]M;6%N9%!A8VMA9VEN
M9R@D=&AI<RT^=6DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!I9B`H)'!A
M8VMA9VEN9U]C;60@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R!I<R!I;G-T
M86QL960[('5S:6YG("<N#0H@("`@("`@("`@("`@("`@)VYE=V5R(")M86ME
M+7)P;2US<&5C(B!C;VUM86YD(&EN<W1E860G*3L-"B`@("`@("`@("`@(')E
M='5R;B`D<&%C:V%G:6YG7V-M9"T^<G5N*"=M86ME+7)P;2US<&5C)RP@)&]P
M=&EO;G,L("1P87)A;7,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=705).24Y'.B`B<&5A<B!M86ME
M<G!M(B!I<R!N;W<@9&5P<F5C871E9#L@86X@)RX-"B`@("`@("`@("`@("`@
M)VEM<')O=F5D('9E<G-I;VX@:7,@879A:6QA8FQE('9I82`B<&5A<B!M86ME
M+7)P;2US<&5C(BP@=VAI8V@@)RX-"B`@("`@("`@("`@("`@)VES(&%V86EL
M86)L92!B>2!I;G-T86QL:6YG(%!%05)?0V]M;6%N9%]086-K86=I;F<G*3L-
M"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R
M86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F)A9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<
M(B(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A
M<F%M<ULP72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B9FEL92!D;V5S(&YO="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@
M("`@("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G949I
M;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1P
M9B`]("8D<&MG+3YF<F]M06YY1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$
M051%7TY/4DU!3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P9BDI
M('L-"B`@("`@("`@("`@("1U(#T@)'!F+3YG9715<V5R:6YF;R@I.PT*("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1U*2D@>PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1U(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R(#T@)&5R<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@D97)R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1P87)A;7-;
M,%T@:7,@;F]T(&$@=F%L:60@<&%C:V%G92(I.PT*("`@("`@("!]#0H@("`@
M("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G+"`G<&5A
M<C)R<&TG*2D[#0H@("`@("`@("1I;G-T<F]O="`](%-Y<W1E;3HZ;6MT96UP
M*&%R<F%Y*"<M9"<L("=P96%R,G)P;2<I*3L-"B`@("`@("`@)'1M<"`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@("`D=&AI<RT^
M8V]N9FEG+3YS970H)W9E<F)O<V4G+"`P*3L-"B`@("`@("`@)&EN<W1A;&QE
M<B`]("1T:&ES+3YG971);G-T86QL97(H)'1H:7,M/G5I*3L-"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(O4&%C:V%G92YP:'`G.PT*
M("`@("`@("`D<&%C:R`](&YE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D
M:6YS=&%L;&5R*3L-"B`@("`@("`@)'!A8VLM/G-E=%!A8VMA9V5&:6QE*"1P
M9BD[#0H@("`@("`@("1P87)A;7-;,%T@/2`F)'!A8VL[#0H@("`@("`@("1I
M;G-T86QL97(M/G-E=$]P=&EO;G,H87)R87DH)VEN<W1A;&QR;V]T)R`]/B`D
M:6YS=')O;W0L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;F]D97!S)R`]/B!T<G5E+"`G<V]F="<@/3X@=')U92DI.PT*
M("`@("`@("`D:6YS=&%L;&5R+3YS971$;W=N;&]A9&5D4&%C:V%G97,H)'!A
M<F%M<RD[#0H@("`@("`@("1I;F9O(#T@)&EN<W1A;&QE<BT^:6YS=&%L;"@D
M<&%R86US6S!=+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)VEN<W1A;&QR;V]T)R`]/B`D:6YS=')O;W0L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]D97!S)R`]
M/B!T<G5E+"`G<V]F="<@/3X@=')U92DI.PT*("`@("`@("`D<&MG9&ER(#T@
M)'!F+3YG971086-K86=E*"D@+B`G+2<@+B`D<&8M/F=E=%9E<G-I;VXH*3L-
M"B`@("`@("`@)&EN9F];)W)P;5]X;6Q?9&ER)UT@/2`G+W9A<B]L:6(O<&5A
M<B<[#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G=F5R8F]S92<L("1T
M;7`I.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-P96,M=&5M<&QA
M=&4G72DI('L-"B`@("`@("`@("`@("1S<&5C7W1E;7!L871E(#T@)&]P=&EO
M;G-;)W-P96,M=&5M<&QA=&4G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1S<&5C7W1E;7!L871E(#T@)R]H;VUE+VQU8V5R+W=O<FLO<&5A
M<B]S:&%R92]P:'`O9&%T82]014%2+W1E;7!L871E+G-P96,G.PT*("`@("`@
M("!]#0H@("`@("`@("1I;F9O6R=P;W-S:6)L95]C:&%N;F5L)UT@/2`G)SL-
M"B`@("`@("`@)&EN9F];)V5X=')A7V-O;F9I9R==(#T@)R<[#0H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULG<G!M+7!K9VYA;64G72DI('L-"B`@("`@
M("`@("`@("1R<&U?<&MG;F%M95]F;W)M870@/2`D;W!T:6]N<ULG<G!M+7!K
M9VYA;64G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@D
M<&8M/F=E=$-H86YN96PH*2`]/2`G<&5A<BYP:'`N;F5T)R!\?"`D<&8M/F=E
M=$-H86YN96PH*2`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M("`@("1A;&EA<R`]("=014%2)SL-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D<&8M
M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1A;&EA<R`]("1C:&%N+3YG971!;&EA<R@I.PT*
M("`@("`@("`@("`@("`@("1A;&EA<R`]('-T<G1O=7!P97(H)&%L:6%S*3L-
M"B`@("`@("`@("`@("`@("`D:6YF;ULG<&]S<VEB;&5?8VAA;FYE;"==(#T@
M)'!F+3YG971#:&%N;F5L*"D@+B`G+R<[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<G!M7W!K9VYA;65?9F]R;6%T(#T@)&%L:6%S("X@)SHZ)7,G
M.PT*("`@("`@("!]#0H-"B`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G
M72`]("<G.PT*("`@("`@("`D:6YF;ULG9&]C7V9I;&5S)UT@/2`G)SL-"B`@
M("`@("`@)&EN9F];)V9I;&5S)UT@/2`G)SL-"B`@("`@("`@)&EN9F];)W!A
M8VMA9V4R>&UL)UT@/2`G)SL-"B`@("`@("`@)&EN9F];)W)P;5]P86-K86=E
M)UT@/2!S<')I;G1F*"1R<&U?<&MG;F%M95]F;W)M870L("1P9BT^9V5T4&%C
M:V%G92@I*3L-"B`@("`@("`@)'-R8V9I;&5S(#T@,#L-"B`@("`@("`@9F]R
M96%C:"`H)&EN9F];)V9I;&5L:7-T)UT@87,@)&YA;64@/3X@)&%T='(I('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)&%T=');)W)O;&4G72DI('L-"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1N86UE(#T@<')E9U]R97!L86-E*"<A6R\Z7%Q<7%TA)RP@)R\G
M+"`D;F%M92D[#0H@("`@("`@("`@("!I9B`H)&%T=');)W)O;&4G72`]/2`G
M9&]C)RD@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=D;V-?9FEL97,G72`N
M/2`B("1N86UE(CL-"B`@("`@("`@("`@("\O($UA<"!R;VQE('1O('1H92!R
M<&T@=F%R<PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D8U]P<F5F:7@@/2`G)7M?;&EB9&ER?2]P:'`O<&5A<B<[#0H@("`@("`@
M("`@("`@("`@<W=I=&-H("@D871T<ELG<F]L92==*2![#0H@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)W!H<"<Z#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<')E9FEX(#T@)&-?<')E9FEX.PT*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G97AT)SH-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`G)7M?;&EB9&ER?2]P:'`G
M.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL@+R\@6%A8(&=O;V0@<&QA
M8V4_#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W-R8R<Z#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<W)C9FEL97,K*SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P<F5F:7@@/2`G)7M?:6YC;'5D961I<GTO<&AP)SL-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[("\O(%A86"!G;V]D('!L86-E/PT*
M("`@("`@("`@("`@("`@("`@("!C87-E("=T97-T)SH-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+W1E<W1S+R(@+B`D
M<&8M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V1A=&$G.@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R969I>"`]("(D8U]P<F5F:7@O9&%T82\B("X@
M)'!F+3YG971086-K86=E*"D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@("`@("!C87-E("=S8W)I<'0G.@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!R969I>"`]("<E>U]B:6YD:7)])SL-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z("\O(&YO;BUS=&%N9&%R9"!R;VQE<PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R969I>"`]("(D8U]P<F5F:7@O)&%T=');<F]L95TO
M(B`N("1P9BT^9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)V5X=')A7V-O;F9I9R==("X]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`B7&X@("`@("`@("UD('LD871T<EMR;VQE77U?9&ER/21C7W!R
M969I>"][)&%T=');<F]L95U](%Q<(CL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@<F]L92`B)R`N
M("1A='1R6R=R;VQE)UT@+B`G(B!U<V5D+"`G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G86YD('=I;&P@8F4@:6YS=&%L;&5D(&EN("(G("X@
M)&-?<')E9FEX("X@)R\G("X@)&%T=');)W)O;&4G72`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R\G("X@)'!F+3YG971086-K86=E*"D@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@+2!H86YD+65D:70@=&AE
M(&9I;F%L("YS<&5C(&EF('1H:7,@:7,@=W)O;F<G+"`D8V]M;6%N9"D[#0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D;F%M92`]('-T<E]R97!L86-E*"=<7"<L("<O
M)RP@)&YA;64I.PT*("`@("`@("`@("`@("`@("1I;F9O6R=F:6QE<R==("X]
M("(D<')E9FEX+R1N86UE7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@D<W)C9FEL97,@/B`P*2![#0H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)T]3+T=U97-S+G!H<"<[#0H@("`@("`@("`@("`D;W,@
M/2!N97<@3U-?1W5E<W,[#0H@("`@("`@("`@("`D87)C:"`]("1O<RT^9V5T
M0W!U*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D87)C:"`]
M("=N;V%R8V@G.PT*("`@("`@("!]#0H@("`@("`@("1C9F<@/2!A<G)A>2@G
M;6%S=&5R7W-E<G9E<B<L("=P:'!?9&ER)RP@)V5X=%]D:7(G+"`G9&]C7V1I
M<B<L#0H@("`@("`@("`@("`@("`@("`@("`G8FEN7V1I<B<L("=D871A7V1I
M<B<L("=T97-T7V1I<B<I.PT*("`@("`@("!F;W)E86-H("@D8V9G(&%S("1K
M*2![#0H@("`@("`@("`@("!I9B`H)&L@/3T@)VUA<W1E<E]S97)V97(G*2![
M#0H@("`@("`@("`@("`@("`@)&-H86X@/2`D<F5G+3YG971#:&%N;F5L*"1P
M9BT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&EN9F];)&M=(#T@)&-H86XM/F=E=%-E<G9E
M<B@I.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&EN9F];)&M=(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"1K*3L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;ULG87)C:"==(#T@)&%R
M8V@[#0H@("`@("`@("1F<"`]($!F;W!E;B@D<W!E8U]T96UP;&%T92P@(G(B
M*3L-"B`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&]P96X@4E!-('-P96,@9FEL
M92!T96UP;&%T92`D<W!E8U]T96UP;&%T93H@)'!H<%]E<G)O<FUS9R(I.PT*
M("`@("`@("!]#0H@("`@("`@("1I;F9O6R=P86-K86=E)UT@/2`D<&8M/F=E
M=%!A8VMA9V4H*3L-"B`@("`@("`@)&EN9F];)W9E<G-I;VXG72`]("1P9BT^
M9V5T5F5R<VEO;B@I.PT*("`@("`@("`D:6YF;ULG<F5L96%S95]L:6-E;G-E
M)UT@/2`D<&8M/F=E=$QI8V5N<V4H*3L-"B`@("`@("`@:68@*"1P9BT^9V5T
M1&5P<R@I*2![#0H@("`@("`@("`@("!I9B`H)'!F+3YG971086-K86=E>&UL
M5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`@("`@)')E<75I
M<F5S(#T@)&-O;F9L:6-T<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'!F+3YG971$97!S*"D@87,@)&1E<"D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;W!T:6]N86PG72D@)B8@)&1E
M<%LG;W!T:6]N86PG72`]/2`G>65S)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1D97!;)W1Y<&4G72`A/2`G<&MG)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V-H86YN96PG72D@)B8@)&1E<%LG8VAA;FYE;"==("$]("=P96%R+G!H
M<"YN970G("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)V-H
M86YN96PG72`A/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D9&5P6R=C:&%N
M;F5L)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1P86-K
M86=E(#T@<W1R=&]U<'!E<B@D8VAA;BT^9V5T06QI87,H*2D@+B`G.CHG("X@
M)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`G4$5!4CHZ)R`N
M("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`D=')A;G,@/2!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("<^)R`]/B`G/B<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G/"<@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SX])R`]
M/B`G/CTG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SP])R`]/B`G/#TG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@)STG(#T^("<])RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=G="<@/3X@)SXG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@)VQT)R`]/B`G/"<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G9V4G(#T^("<^/2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M;&4G(#T^("<\/2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G97$G(#T^
M("<])RP-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1D97!;)W)E;"==(#T]("=H87,G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5Q=6ER97-;72`]("1P86-K86=E.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&1E<%LG<F5L)UT@/3T@)VYO="<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;72`]("1P
M86-K86=E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&1E<%LG
M<F5L)UT@/3T@)VYE)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;F9L:6-T<UM=(#T@)'!A8VMA9V4@+B`G(#T@)R`N("1D97!;)W9E<G-I;VXG
M73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T<F%N
M<ULD9&5P6R=R96PG75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5Q=6ER97-;72`]("1P86-K86=E("X@)R`G("X@)'1R86YS6R1D97!;)W)E
M;"==72`N("<@)R`N("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H8V]U;G0H)')E<75I<F5S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M:6YF;ULG97AT<F%?:&5A9&5R<R==("X]("=297%U:7)E<SH@)R`N(&EM<&QO
M9&4H)RP@)RP@)')E<75I<F5S*2`N(")<;B([#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D8V]N9FQI8W1S*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R<R==("X]
M("=#;VYF;&EC=',Z("<@+B!I;7!L;V1E*"<L("<L("1C;VYF;&EC=',I("X@
M(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1I;F9O6R=P86-K86=E,GAM;"==(#T@)S(G
M.R`O+R!T96QL('1H92!S<&5C('1O('5S92!P86-K86=E,BYX;6P-"B`@("`@
M("`@("`@("`@("`D<F5Q=6ER97,@/2`D8V]N9FQI8W1S(#T@87)R87DH*3L-
M"B`@("`@("`@("`@("`@("`D9&5P<R`]("1P9BT^9V5T1&5P<RAT<G5E*3L-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;
M)W!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G
M72`](&%R<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@87,@)&1E<"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D97!;)V-H86YN96PG72`A
M/2`G<&5A<BYP:'`N;F5T)R`F)B`@)&1E<%LG8VAA;FYE;"==("$]("=P96-L
M+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H
M86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D9&5P6R=C:&%N;F5L)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C
M:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%C:V%G92`]('-T<G1O=7!P97(H)&-H86XM/F=E=$%L:6%S*"DI("X@)SHZ
M)R`N("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@
M/2`G4$5!4CHZ)R`N("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=C;VYF;&EC=',G72D@)B8@*&ES<V5T*"1D97!;)VUI;B==*2!\?`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)&1E<%LG;6%X
M)UTI*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!R86YG
M92`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P<F%N9V5;72`](&%R<F%Y*"1D97!;)VUI;B==+"<^
M/2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!R86YG95M=
M(#T@87)R87DH)&1E<%LG;6%X)UTL("<\/2<I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G
M72D@?'P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(6ES<V5T*"1D97!;)V5X8VQU9&4G75LP72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y
M*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&-O=6YT*"1D97!R86YG92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E>&-L(#T@)&1E<%LG97AC;'5D92==.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@8VAA;F=E(#X]('1O
M(#X@:68@97AC;'5D:6YG('1H92!M:6X@=F5R<VEO;@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@8VAA;F=E(#P]('1O(#P@:68@
M97AC;'5D:6YG('1H92!M87@@=F5R<VEO;@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R*"1I(#T@,#L@)&D@/"!C;W5N="@D97AC
M;"D[("1I*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<')A;F=E6S!=*2`F)@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L6R1I
M72`]/2`D9&5P<F%N9V5;,%U;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<')A;F=E6S!=6S%=(#T@)SPG
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!U;G-E="@D9&5P6R=E>&-L=61E)UU;)&E=*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!R86YG95LQ
M72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97AC;%LD:5T@/3T@)&1E<')A;F=E6S%=6S!=*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!R
M86YG95LQ75LQ72`]("<^)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=6YS970H)&1E<%LG97AC;'5D92==6R1I72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9&5P6R=E>&-L=61E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=E
M>&-L=61E)UT@/2!A<G)A>5]V86QU97,H)&1E<%LG97AC;'5D92==*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=D97!R86YG
M92`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!R96UO=F4@97AC;'5D97,@=&AA="!A<F4@;W5T<VED92!T:&4@
M97AI<W1I;F<@<F%N9V4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D97!;)V5X8VQU9&4G
M72D[("1I*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&1E<%LG97AC;'5D92==6R1I72`\("1D97!;)VUI;B==
M('Q\#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<%LG97AC;'5D92==6R1I72`^("1D97!;)VUA>"==*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1D97!;)V5X8VQU9&4G75LD:5TI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y7W9A;'5E<R@D9&5P
M6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7-O<G0H)&1E<%LG97AC;'5D92==+"`G=F5R<VEO;E]C;VUP87)E
M)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!T
M86ME('1H92!R96UA:6YI;F<@97AC;'5D97,@86YD#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!S<&QI="!T:&4@9&5P96YD96YC
M>2!I;G1O('-U8BUR86YG97,-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1L87-T;6EN(#T@)&1E<')A;F=E6S!=.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&1E<%LG97AC;'5D92==*2`M(#$[("1I*RLI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W9&5P<F%N9V5;
M72`]("<H)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P86-K86=E("X@(B![)&QA<W1M:6Y;,5U]('LD;&%S=&UI
M;ELP77T@86YD("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G92`N("<@/"`G("X@)&1E<%LG97AC;'5D
M92==6R1I72`N("<I)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;&%S=&UI;B`](&%R<F%Y*"1D97!;)V5X8VQU9&4G75LD
M:5TL("<^)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE=V1E<')A;F=E6UT@/2`G*"<@+B`D<&%C
M:V%G92`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("(@>R1L87-T;6EN6S%=?2![)&QA<W1M:6Y;,%U](&%N9"`B("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMA9V4@+B`G(#P@)R`N("1D97!;)VUA>"==("X@)RDG.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9L:6-T<UM=(#T@:6UP;&]D
M92@G(&]R("<L("1D97!R86YG92D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G92`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B![)&1E<')A;F=E
M6S!=6S%=?2![)&1E<')A;F=E6S!=6S!=?2(@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E="@D9&5P<F%N9V5;,5TI
M(#\@#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(B!A;F0@)'!A8VMA9V4@>R1D97!R86YG95LQ75LQ77T@>R1D97!R86YG95LQ
M75LP77TB#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`G)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M97!;)VUI;B==*2`F)B`A:7-S970H)&1E<%LG;6%X)UTI("8F#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)&1E<%LG97AC;'5D92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G92`N("<@/CT@)R`N
M("1D97!;)VUI;B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG
M;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M97%U:7)E<UM=(#T@)'!A8VMA9V4@+B`G(#P]("<@+B`D9&5P6R=M87@G73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X(#T@)&1E<%LG
M97AC;'5D92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1E>"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E>"`](&%R<F%Y*"1E>"D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&5X(&%S("1V97(I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;72`]("1P86-K
M86=E("X@)R`]("<@+B`D=F5R.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G07)C:&EV92]4
M87(N<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@)'1A<B`](&YE=R!!<F-H
M:79E7U1A<B@D<&8M/F=E=$%R8VAI=F5&:6QE*"DI.PT*("`@("`@("`@("`@
M("`@("`@("`D=&%R+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[#0H@("`@("`@("`@("`@("`@("`@("1A(#T@)'1A<BT^97AT<F%C
M=$EN4W1R:6YG*"=P86-K86=E,BYX;6PG*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1A<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&$@/3T](&YU;&P@?'P@4$5!4CHZ:7-%<G)O<B@D82DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=P86-K86=E,GAM;"==
M(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!T:&ES(&1O97-N
M)W0@:&%V92!A('!A8VMA9V4N>&UL('9E<G-I;VX@,2XP#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5Q=6ER97-;72`]("=014%2.CI014%2(#X]("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E
M9"==6R=P96%R:6YS=&%L;&5R)UU;)VUI;B==.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5Q=6ER
M97,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?
M:&5A9&5R<R==("X]("=297%U:7)E<SH@)R`N(&EM<&QO9&4H)RP@)RP@)')E
M<75I<F5S*2`N(")<;B([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&-O=6YT*"1C;VYF;&EC=',I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R<R==("X]
M("=#;VYF;&EC=',Z("<@+B!I;7!L;V1E*"<L("<L("1C;VYF;&EC=',I("X@
M(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O(')E
M;6]V92!T:&4@=')A:6QI;F<@;F5W;&EN90T*("`@("`@("`D:6YF;ULG97AT
M<F%?:&5A9&5R<R==(#T@=')I;2@D:6YF;ULG97AT<F%?:&5A9&5R<R==*3L-
M"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N
M=',G*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@
M("`D<W!E8U]C;VYT96YT<R`]('!R96=?<F5P;&%C92@G+T`H6V$M>C`M.5\M
M72LI0"]E)RP@)R1I;F9O6R)<,2)=)RP-"B`@("`@("`@("`@("`@("!F:6QE
M7V=E=%]C;VYT96YT<R@D<W!E8U]T96UP;&%T92DI.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)'-P96-?8V]N=&5N=',@/2!P<F5G7W)E<&QA
M8V4H)R]`*%MA+7HP+3E?+5TK*4`O92<L("<D:6YF;ULB7#$B72<L#0H@("`@
M("`@("`@("`@("`@9G)E860H)&9P+"!F:6QE<VEZ92@D<W!E8U]T96UP;&%T
M92DI*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@
M("`@("`@("1S<&5C7V9I;&4@/2`B)&EN9F];<G!M7W!A8VMA9V5=+21I;F9O
M6W9E<G-I;VY=+G-P96,B.PT*("`@("`@("`D=W`@/2!F;W!E;B@D<W!E8U]F
M:6QE+"`B=V(B*3L-"B`@("`@("`@:68@*"$D=W`I('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T('=R:71E(%)0
M32!S<&5C(&9I;&4@)'-P96-?9FEL93H@)'!H<%]E<G)O<FUS9R(I.PT*("`@
M("`@("!]#0H@("`@("`@(&9W<FET92@D=W`L("1S<&5C7V-O;G1E;G1S*3L-
M"B`@("`@("`@9F-L;W-E*"1W<"D[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@B5W)O=&4@4E!-('-P96,@9FEL92`D<W!E8U]F:6QE(BP@)&-O
M;6UA;F0I.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&1O0V]N=F5R="@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A
M;7,I#0H@("`@>PT*("`@("`@("`D<&%C:V%G97AM;"`](&ES<V5T*"1P87)A
M;7-;,%TI(#\@)'!A<F%M<ULP72`Z("=P86-K86=E+GAM;"<[#0H@("`@("`@
M("1N97=P86-K86=E>&UL(#T@:7-S970H)'!A<F%M<ULQ72D@/R`D<&%R86US
M6S%=(#H@9&ER;F%M92@D<&%C:V%G97AM;"D@+@T*("`@("`@("`@("`@1$E2
M14-43U)97U-%4$%2051/4B`N("=P86-K86=E,BYX;6PG.PT*("`@("`@("`D
M<&MG(#T@)B1T:&ES+3YG971086-K86=E1FEL92@D=&AI<RT^8V]N9FEG+"`D
M=&AI<RT^7V1E8G5G*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D<&8@/2`D
M<&MG+3YF<F]M4&%C:V%G949I;&4H)'!A8VMA9V5X;6PL(%!%05)?5D%,241!
M5$5?3D]234%,*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)'!F*2D@>PT*
M("`@("`@("`@("`@:68@*&ES7V$H)'!F+"`G4$5!4E]086-K86=E1FEL95]V
M,B<I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A
M*"1P86-K86=E>&UL("X@)R!I<R!A;')E861Y(&$@<&%C:V%G92YX;6P@=F5R
M<VEO;B`R+C`G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1G96X@/2`F)'!F+3YG971$969A
M=6QT1V5N97)A=&]R*"D[#0H@("`@("`@("`@("`D;F5W<&8@/2`F)&=E;BT^
M=&]6,B@I.PT*("`@("`@("`@("`@)&YE=W!F+3YS971086-K86=E9FEL92@D
M;F5W<&%C:V%G97AM;"D[#0H@("`@("`@("`@("`D9V5N(#T@)B1N97=P9BT^
M9V5T1&5F875L=$=E;F5R871O<B@I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A
M=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@)'-T871E(#T@*&ES<V5T*"1O<'1I;VYS6R=F;&%T)UTI(#\@
M4$5!4E]604Q)1$%415]004-+04=)3D<@.B!014%27U9!3$E$051%7TY/4DU!
M3"D[#0H@("`@("`@("`@("`D<V%V960@/2`D9V5N+3YT;U!A8VMA9V5&:6QE
M*&1I<FYA;64H)&YE=W!A8VMA9V5X;6PI+"`D<W1A=&4L#0H@("`@("`@("`@
M("`@("`@8F%S96YA;64H)&YE=W!A8VMA9V5X;6PI*3L-"B`@("`@("`@("`@
M(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1S879E9"DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'-A=F5D+3YG9715<V5R26YF;R@I*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D<V%V960M/F=E=%5S97));F9O
M*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'-A=F5D+3YG971-
M97-S86=E*"DI.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A
M*"=7<F]T92!N97<@=F5R<VEO;B`R+C`@<&%C:V%G92YX;6P@=&\@(B<@+B`D
M<V%V960@+B`G(B<I.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!F+3YG
M9715<V5R26YF;R@I*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P
M9BT^9V5T57-E<DEN9F\H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'=A<FYI;F=;)VUE<W-A
M9V4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P9BD[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+T-O;6UA;F0O0G5I;&0N>&UL````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#0Q-0`Q,#4Q-30S,3`U-P`P,C$R,C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&-O;6UA;F1S('9E<G-I
M;VX](C$N,"(^#0H@/&)U:6QD/@T*("`\<W5M;6%R>3Y"=6EL9"!A;B!%>'1E
M;G-I;VX@1G)O;2!#(%-O=7)C93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O
M0G5I;&0\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8CPO<VAO<G1C=70^#0H@
M(#QO<'1I;VYS("\^#0H@(#QD;V,^6W!A8VMA9V4N>&UL70T*0G5I;&1S(&]N
M92!O<B!M;W)E(&5X=&5N<VEO;G,@8V]N=&%I;F5D(&EN(&$@<&%C:V%G92X\
M+V1O8SX-"B`\+V)U:6QD/@T*/"]C;VUM86YD<SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD
M+T)U:6QD+G!H<```````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4V
M,#``,3`U,34T,S$P-3<`,#(Q,C$W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N
M9%]!=71H("AB=6EL9"!C;VUM86YD*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@
M/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!"=6EL9"YP:'`L=B`Q+C$S(#(P,#8O,#$O,#8@
M,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J
M(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0O
M0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@8G5I
M;&1I;F<@97AT96YS:6]N<RX-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N0V]X
M(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!0
M14%27T-O;6UA;F1?0G5I;&0@97AT96YD<R!014%27T-O;6UA;F1?0V]M;6]N
M#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A<B`D8V]M;6%N
M9',@/2!A<G)A>2@-"B`@("`@("`@)V)U:6QD)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G0G5I;&0@86X@17AT96YS:6]N($9R;VT@
M0R!3;W5R8V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]"=6EL
M9"<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=B)RP-"B`@("`@("`@
M("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)UMP86-K86=E+GAM;%T-"D)U:6QD<R!O;F4@;W(@;6]R92!E>'1E;G-I
M;VYS(&-O;G1A:6YE9"!I;B!A('!A8VMA9V4N)PT*("`@("`@("`@("`@*2P-
M"B`@("`@("`@*3L-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T
M<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27T-O;6UA;F1?0G5I;&0@
M8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]"=6EL9"@F)'5I
M+"`F)&-O;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM
M86YD7T-O;6UO;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(&1O0G5I;&0H*0T*#0H@("`@9G5N8W1I;VX@9&]"
M=6EL9"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O0G5I;&1E<BYP:'`G.PT*("`@("`@
M("!I9B`H<VEZ96]F*"1P87)A;7,I(#P@,2D@>PT*("`@("`@("`@("`@)'!A
M<F%M<ULP72`]("=P86-K86=E+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@
M)&)U:6QD97(@/2`F;F5W(%!%05)?0G5I;&1E<B@D=&AI<RT^=6DI.PT*("`@
M("`@("`D=&AI<RT^9&5B=6<@/2`D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O
M<V4G*3L-"B`@("`@("`@)&5R<B`]("1B=6EL9&5R+3YB=6EL9"@D<&%R86US
M6S!=+"!A<G)A>2@F)'1H:7,L("=B=6EL9$-A;&QB86-K)RDI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1E<G([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&)U:6QD0V%L;&)A8VLH
M*0T*#0H@("`@9G5N8W1I;VX@8G5I;&1#86QL8F%C:R@D=VAA="P@)&1A=&$I
M#0H@("`@>PT*("`@("`@("!I9B`H*"1W:&%T(#T]("=C;61O=71P=70G("8F
M("1T:&ES+3YD96)U9R`^(#$I('Q\#0H@("`@("`@("`@("`H)'=H870@/3T@
M)V]U='!U="<@)B8@)'1H:7,M/F1E8G5G(#X@,"DI('L-"B`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82AR=')I;2@D9&%T82DL("=B=6EL9"<I
M.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0VAA;FYE;',N>&UL````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3(W,0`Q,#4Q-30S,3`U-P`P
M,C$W,S``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&QI<W0M8VAA;FYE;',^
M#0H@(#QS=6UM87)Y/DQI<W0@079A:6QA8FQE($-H86YN96QS/"]S=6UM87)Y
M/@T*("`\9G5N8W1I;VX^9&],:7-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T
M/FQC/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SX-"DQI<W0@
M86QL(&%V86EL86)L92!C:&%N;F5L<R!F;W(@:6YS=&%L;&%T:6]N+@T*/"]D
M;V,^#0H@/"]L:7-T+6-H86YN96QS/@T*(#QU<&1A=&4M8VAA;FYE;',^#0H@
M(#QS=6UM87)Y/E5P9&%T92!T:&4@0VAA;FYE;"!,:7-T/"]S=6UM87)Y/@T*
M("`\9G5N8W1I;VX^9&]5<&1A=&5!;&P\+V9U;F-T:6]N/@T*("`\<VAO<G1C
M=70^=6,\+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/@T*3&ES
M="!A;&P@:6YS=&%L;&5D('!A8VMA9V5S(&EN(&%L;"!C:&%N;F5L<RX-"CPO
M9&]C/@T*(#PO=7!D871E+6-H86YN96QS/@T*(#QC:&%N;F5L+61E;&5T93X-
M"B`@/'-U;6UA<GD^4F5M;W9E(&$@0VAA;FYE;"!&<F]M('1H92!,:7-T/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]$96QE=&4\+V9U;F-T:6]N/@T*("`\
M<VAO<G1C=70^8V1E/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O
M8SXF;'0[8VAA;FYE;"!N86UE)F=T.PT*1&5L971E(&$@8VAA;FYE;"!F<F]M
M('1H92!R96=I<W1R>2X@(%EO=2!M87D@;F]T#0IR96UO=F4@86YY(&-H86YN
M96P@=&AA="!H87,@:6YS=&%L;&5D('!A8VMA9V5S+@T*/"]D;V,^#0H@/"]C
M:&%N;F5L+61E;&5T93X-"B`\8VAA;FYE;"UA9&0^#0H@(#QS=6UM87)Y/D%D
M9"!A($-H86YN96P\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T%D9#PO9G5N
M8W1I;VX^#0H@(#QS:&]R=&-U=#YC83PO<VAO<G1C=70^#0H@(#QO<'1I;VYS
M("\^#0H@(#QD;V,^)FQT.V-H86YN96PN>&UL)F=T.PT*061D(&$@<')I=F%T
M92!C:&%N;F5L('1O('1H92!C:&%N;F5L(&QI<W0N("!.;W1E('1H870@86QL
M#0IP=6)L:6,@8VAA;FYE;',@<VAO=6QD(&)E('-Y;F-E9"!U<VEN9R`F<75O
M=#MU<&1A=&4M8VAA;FYE;',F<75O=#LN#0I087)A;65T97(@;6%Y(&)E(&5I
M=&AE<B!A(&QO8V%L(&9I;&4@;W(@<F5M;W1E(%523"!T;R!A#0IC:&%N;F5L
M+GAM;"X-"CPO9&]C/@T*(#PO8VAA;FYE;"UA9&0^#0H@/&-H86YN96PM=7!D
M871E/@T*("`\<W5M;6%R>3Y5<&1A=&4@86X@17AI<W1I;F<@0VAA;FYE;#PO
M<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O57!D871E/"]F=6YC=&EO;CX-"B`@
M/'-H;W)T8W5T/F-U/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\9F]R
M8V4^#0H@("`@/'-H;W)T;W!T/F8\+W-H;W)T;W!T/@T*("`@(#QD;V,^=VEL
M;"!F;W)C92!D;W=N;&]A9"!O9B!N97<@8VAA;FYE;"YX;6P@:68@86X@97AI
M<W1I;F<@8VAA;FYE;"!N86UE(&ES('5S960\+V1O8SX-"B`@(#PO9F]R8V4^
M#0H@("`\8VAA;FYE;#X-"B`@("`\<VAO<G1O<'0^8SPO<VAO<G1O<'0^#0H@
M("`@/&%R9SY#2$%.3D5,/"]A<F<^#0H@("`@/&1O8SYW:6QL(&9O<F-E(&1O
M=VYL;V%D(&]F(&YE=R!C:&%N;F5L+GAM;"!I9B!A;B!E>&ES=&EN9R!C:&%N
M;F5L(&YA;64@:7,@=7-E9#PO9&]C/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P
M=&EO;G,^#0H@(#QD;V,^6R9L=#MC:&%N;F5L+GAM;"9G=#M\)FQT.V-H86YN
M96P@;F%M929G=#M=#0I5<&1A=&4@82!C:&%N;F5L(&EN('1H92!C:&%N;F5L
M(&QI<W0@9&ER96-T;'DN("!.;W1E('1H870@86QL#0IP=6)L:6,@8VAA;FYE
M;',@8V%N(&)E('-Y;F-E9"!U<VEN9R`F<75O=#MU<&1A=&4M8VAA;FYE;',F
M<75O=#LN#0I087)A;65T97(@;6%Y(&)E(&$@;&]C86P@;W(@<F5M;W1E(&-H
M86YN96PN>&UL+"!O<B!T:&4@;F%M92!O9@T*86X@97AI<W1I;F<@8VAA;FYE
M;"X-"CPO9&]C/@T*(#PO8VAA;FYE;"UU<&1A=&4^#0H@/&-H86YN96PM:6YF
M;SX-"B`@/'-U;6UA<GD^4F5T<FEE=F4@26YF;W)M871I;VX@;VX@82!#:&%N
M;F5L/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]);F9O/"]F=6YC=&EO;CX-
M"B`@/'-H;W)T8W5T/F-I/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@
M/&1O8SXF;'0[<&%C:V%G929G=#L-"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN
M<W1A;&QE9"!P86-K86=E+@T*/"]D;V,^#0H@/"]C:&%N;F5L+6EN9F\^#0H@
M/&-H86YN96PM86QI87,^#0H@(#QS=6UM87)Y/E-P96-I9GD@86X@86QI87,@
M=&\@82!C:&%N;F5L(&YA;64\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T%L
M:6%S/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-H83PO<VAO<G1C=70^#0H@
M(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.V-H86YN96PF9W0[("9L=#MA;&EA
M<R9G=#L-"E-P96-I9GD@82!S<&5C:69I8R!A;&EA<R!T;R!U<V4@9F]R(&$@
M8VAA;FYE;"!N86UE+@T*5&AE(&%L:6%S(&UA>2!N;W0@8F4@86X@97AI<W1I
M;F<@8VAA;FYE;"!N86UE(&]R#0IA;&EA<RX-"CPO9&]C/@T*(#PO8VAA;FYE
M;"UA;&EA<SX-"B`\8VAA;FYE;"UD:7-C;W9E<CX-"B`@/'-U;6UA<GD^26YI
M=&EA;&EZ92!A($-H86YN96P@9G)O;2!I=',@<V5R=F5R/"]S=6UM87)Y/@T*
M("`\9G5N8W1I;VX^9&]$:7-C;W9E<CPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U
M=#YD:3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.W!A
M8VMA9V4F9W0[#0I,:7-T('1H92!F:6QE<R!I;B!A;B!I;G-T86QL960@<&%C
M:V%G92X-"CPO9&]C/@T*(#PO8VAA;FYE;"UD:7-C;W9E<CX-"CPO8V]M;6%N
M9',^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O0V]M;6%N9"]#:&%N;F5L<RYP:'``````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,3`Q-#(R`#$P-3$U-#,Q,#4W`#`R,3<Q,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+R\@+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO
M#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]#:&%N;F5L<R`H;&ES="UC:&%N;F5L
M<RP@=7!D871E+6-H86YN96QS+"!C:&%N;F5L+61E;&5T92P@8VAA;FYE;"UA
M9&0L#0H@*B!C:&%N;F5L+75P9&%T92P@8VAA;FYE;"UI;F9O+"!C:&%N;F5L
M+6%L:6%S+"!C:&%N;F5L+61I<V-O=F5R(&-O;6UA;F1S*0T*("H-"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@
M(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#:&%N;F5L<RYP:'`L=B`Q+C0T
M(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC
M92`G4$5!4B]#;VUM86YD+T-O;6UO;BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@
M8V]M;6%N9',@9F]R(&UA;F%G:6YG(&-H86YN96QS+@T*("H-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C!A,0T*("HO#0IC;&%S<R!014%27T-O;6UA;F1?0VAA;FYE;',@97AT96YD
M<R!014%27T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I
M97,-"@T*("`@('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)VQI
M<W0M8VAA;FYE;',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=,:7-T($%V86EL86)L92!#:&%N;F5L<R<L#0H@("`@("`@("`@("`G
M9G5N8W1I;VXG(#T^("=D;TQI<W0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T
M)R`]/B`G;&,G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL
M#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0I,:7-T(&%L;"!A=F%I;&%B;&4@
M8VAA;FYE;',@9F]R(&EN<W1A;&QA=&EO;BX-"B<L#0H@("`@("`@("`@("`I
M+`T*("`@("`@("`G=7!D871E+6-H86YN96QS)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G57!D871E('1H92!#:&%N;F5L($QI<W0G
M+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]5<&1A=&5!;&PG+`T*
M("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G=6,G+`T*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G
M#0I,:7-T(&%L;"!I;G-T86QL960@<&%C:V%G97,@:6X@86QL(&-H86YN96QS
M+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-H86YN96PM9&5L971E
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4F5M;W9E
M(&$@0VAA;FYE;"!&<F]M('1H92!,:7-T)RP-"B`@("`@("`@("`@("=F=6YC
M=&EO;B<@/3X@)V1O1&5L971E)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@
M/3X@)V-D92<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-
M"B`@("`@("`@("`@("=D;V,G(#T^("<\8VAA;FYE;"!N86UE/@T*1&5L971E
M(&$@8VAA;FYE;"!F<F]M('1H92!R96=I<W1R>2X@(%EO=2!M87D@;F]T#0IR
M96UO=F4@86YY(&-H86YN96P@=&AA="!H87,@:6YS=&%L;&5D('!A8VMA9V5S
M+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-H86YN96PM861D)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G061D(&$@0VAA
M;FYE;"<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T%D9"<L#0H@
M("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C82<L#0H@("`@("`@("`@("`G
M;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\
M8VAA;FYE;"YX;6P^#0I!9&0@82!P<FEV871E(&-H86YN96P@=&\@=&AE(&-H
M86YN96P@;&ES="X@($YO=&4@=&AA="!A;&P-"G!U8FQI8R!C:&%N;F5L<R!S
M:&]U;&0@8F4@<WEN8V5D('5S:6YG(")U<&1A=&4M8VAA;FYE;',B+@T*4&%R
M86UE=&5R(&UA>2!B92!E:71H97(@82!L;V-A;"!F:6QE(&]R(')E;6]T92!5
M4DP@=&\@80T*8VAA;FYE;"YX;6PN#0HG#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G8VAA;FYE;"UU<&1A=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=5<&1A=&4@86X@17AI<W1I;F<@0VAA;FYE;"<L#0H@
M("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U5P9&%T92<L#0H@("`@("`@
M("`@("`G<VAO<G1C=70G(#T^("=C=2<L#0H@("`@("`@("`@("`G;W!T:6]N
M<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V9O<F-E)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G9B<L#0H@
M("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=W:6QL(&9O<F-E(&1O=VYL
M;V%D(&]F(&YE=R!C:&%N;F5L+GAM;"!I9B!A;B!E>&ES=&EN9R!C:&%N;F5L
M(&YA;64@:7,@=7-E9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)V-H86YN96PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=C)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V%R9R<@/3X@)T-(04Y.14PG+`T*("`@("`@("`@("`@("`@("`@("`G
M9&]C)R`]/B`G=VEL;"!F;W)C92!D;W=N;&]A9"!O9B!N97<@8VAA;FYE;"YX
M;6P@:68@86X@97AI<W1I;F<@8VAA;FYE;"!N86UE(&ES('5S960G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T**2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("=;/&-H86YN96PN>&UL/GP\8VAA;FYE;"!N86UE/ET-"E5P9&%T92!A(&-H
M86YN96P@:6X@=&AE(&-H86YN96P@;&ES="!D:7)E8W1L>2X@($YO=&4@=&AA
M="!A;&P-"G!U8FQI8R!C:&%N;F5L<R!C86X@8F4@<WEN8V5D('5S:6YG(")U
M<&1A=&4M8VAA;FYE;',B+@T*4&%R86UE=&5R(&UA>2!B92!A(&QO8V%L(&]R
M(')E;6]T92!C:&%N;F5L+GAM;"P@;W(@=&AE(&YA;64@;V8-"F%N(&5X:7-T
M:6YG(&-H86YN96PN#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8VAA
M;FYE;"UI;F9O)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]
M/B`G4F5T<FEE=F4@26YF;W)M871I;VX@;VX@82!#:&%N;F5L)RP-"B`@("`@
M("`@("`@("=F=6YC=&EO;B<@/3X@)V1O26YF;R<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=C:2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@
M87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G93X-"DQI
M<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A;&QE9"!P86-K86=E+@T*)PT*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)V-H86YN96PM86QI87,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=3<&5C:69Y(&%N(&%L:6%S
M('1O(&$@8VAA;FYE;"!N86UE)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@
M/3X@)V1O06QI87,G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8VAA
M)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)SQC:&%N;F5L/B`\86QI87,^#0I3<&5C:69Y(&$@
M<W!E8VEF:6,@86QI87,@=&\@=7-E(&9O<B!A(&-H86YN96P@;F%M92X-"E1H
M92!A;&EA<R!M87D@;F]T(&)E(&%N(&5X:7-T:6YG(&-H86YN96P@;F%M92!O
M<@T*86QI87,N#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8VAA;FYE
M;"UD:7-C;W9E<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@
M/3X@)TEN:71I86QI>F4@82!#:&%N;F5L(&9R;VT@:71S('-E<G9E<B<L#0H@
M("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T1I<V-O=F5R)RP-"B`@("`@
M("`@("`@("=S:&]R=&-U="<@/3X@)V1I)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K
M86=E/@T*3&ES="!T:&4@9FEL97,@:6X@86X@:6YS=&%L;&5D('!A8VMA9V4N
M#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!0
M14%27T-O;6UA;F1?4F5G:7-T<GD@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%
M05)?0V]M;6%N9%]#:&%N;F5L<R@F)'5I+"`F)&-O;F9I9RD-"B`@("![#0H@
M("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL("1C;VYF
M:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&1O3&ES
M="@I#0H@("`@#0H@("`@9G5N8W1I;VX@7W-O<G1#:&%N;F5L<R@D82P@)&(I
M#0H@("`@>PT*("`@("`@("!R971U<FX@<W1R;F%T8V%S96-M<"@D82T^9V5T
M3F%M92@I+"`D8BT^9V5T3F%M92@I*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!D;TQI<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-
M"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I
M.PT*("`@("`@("`D<F5G:7-T97)E9"`]("1R96<M/F=E=$-H86YN96QS*"D[
M#0H@("`@("`@('5S;W)T*"1R96=I<W1E<F5D+"!A<G)A>2@F)'1H:7,L("=?
M<V]R=&-H86YN96QS)RDI.PT*("`@("`@("`D:2`]("1J(#T@,#L-"B`@("`@
M("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`G
M4F5G:7-T97)E9"!#:&%N;F5L<SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@
M/3X@=')U92P-"B`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)T-H
M86YN96PG+"`G4W5M;6%R>2<I#0H@("`@("`@("`@("`I.PT*("`@("`@("!F
M;W)E86-H("@D<F5G:7-T97)E9"!A<R`D8VAA;FYE;"D@>PT*("`@("`@("`@
M("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&-H86YN96PM/F=E=$YA;64H
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H
M86YN96PM/F=E=%-U;6UA<GDH*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&-O=6YT*"1R96=I<W1E<F5D*3T],"D@>PT*("`@("`@("`@("`@)&1A=&$@
M/2`G*&YO(')E9VES=&5R960@8VAA;FYE;',I)SL-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@(`T*("`@(&9U;F-T
M:6]N(&1O57!D871E06QL*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-
M"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("!I9B`H(21R
M96<M/F-H86YN96Q%>&ES=',H)&]P=&EO;G-;)V-H86YN96PG72DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U5N:VYO
M=VX@8VAA;FYE;"`B)R`N("1O<'1I;VYS6R=C:&%N;F5L)UT@+B`G(B<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T
M*"=D969A=6QT7V-H86YN96PG+"`D;W!T:6]N<ULG8VAA;FYE;"==*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E
M="@G9&5F875L=%]C:&%N;F5L)RP@)W!E87(N<&AP+FYE="<I.PT*("`@("`@
M("!]#0H@("`@("`@("1R96UO=&4@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M
M;W1E*"D[#0H@("`@("`@("1C:&%N;F5L<R`]("1R96UO=&4M/F-A;&PH)V-H
M86YN96PN;&ES=$%L;"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M8VAA;FYE;',I*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H
M)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@
M("!R971U<FX@)&-H86YN96QS.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-?87)R87DH)&-H86YN96QS*2!\?"!I<W-E="@D8VAA;FYE;'-;)V9A=6QT
M0V]D92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D
M969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"));F-O<G)E8W0@8VAA;FYE;"!L
M:7-T:6YG(')E='5R;F5D(&9R;VT@8VAA;FYE;"`G)&-H86XG(BD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%C;W5N="@D8VAA;FYE;',I*2![#0H@("`@
M("`@("`@("`D9&%T82`]("=N;R!U<&1A=&5S(&%V86EL86)L92<[#0H@("`@
M("`@('T-"B`@("`@("`@)&1L(#T@)B1T:&ES+3YG971$;W=N;&]A9&5R*"D[
M#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG*2D@>PT*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@
M?0T*("`@("`@("`D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD
M)RDI.PT*("`@("`@("!F;W)E86-H("@D8VAA;FYE;',@87,@)&-H86YN96PI
M('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)&-H86YN96Q;,%T[#0H@("`@
M("`@("`@("`D<V%V92`]("1C:&%N;F5L.PT*("`@("`@("`@("`@:68@*"1R
M96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PL('1R=64I*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")5<&1A=&EN9R!C:&%N
M;F5L(%PB)&-H86YN96Q<(B(L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@
M("`D=&5S="`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PL('1R=64I.PT*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T97-T*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(D-H
M86YN96P@)R1C:&%N;F5L)R!I<R!C;W)R=7!T(&EN(')E9VES=')Y(2(L("1C
M;VUM86YD*3L-"B`@("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9"`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1L87-T;6]D:69I960@/2`D=&5S="T^;&%S=$UO9&EF:65D
M*"D[#0H@("`@("`@("`@("`@("`@("`@(`T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@)&1L+3YD;W=N;&]A9$AT='`H)VAT='`Z+R\G("X@)'1E<W0M/F=E
M=$YA;64H*2`N("<O8VAA;FYE;"YX;6PG+`T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^=6DL("1T;7!D:7(L(&YU;&PL("1L87-T;6]D:69I960I.PT*
M("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N=&5N
M=',I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@G15)23U(Z($-A;FYO="!R971R:65V92!C:&%N;F5L+GAM;"!F;W(@
M8VAA;FYE;"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&5S="T^
M9V5T3F%M92@I("X@)R(G+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H(21C;VYT96YT<RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H(D-H86YN96P@7"(D8VAA;FYE;%PB(&ES
M('5P+71O+61A=&4B+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!L:7-T*"1C;VYT96YT<RP@)&QA<W1M;V1I9FEE9"D@/2`D8V]N=&5N=',[
M#0H@("`@("`@("`@("`@("`@)&EN9F\@/2!I;7!L;V1E*"<G+"!F:6QE*"1C
M;VYT96YT<RDI.PT*("`@("`@("`@("`@("`@(&EF("@A)&EN9F\I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")#:&%N
M;F5L(%PB)&-H86YN96Q<(B!I<R!U<"UT;RUD871E(BP@)&-O;6UA;F0I.PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?
M0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)&-H86YN96QI;F9O(#T@;F5W(%!%05)?
M0VAA;FYE;$9I;&4[#0H@("`@("`@("`@("`@("`@)&-H86YN96QI;F9O+3YF
M<F]M6&UL4W1R:6YG*"1I;F9O*3L-"B`@("`@("`@("`@("`@("!I9B`H)&-H
M86YN96QI;F9O+3YG971%<G)O<G,H*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(D1O=VYL;V%D960@8VAA;FYE;"!D
M871A(&9R;VT@8VAA;FYE;"!<(B1C:&%N;F5L7"(@(B`N(`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)VES(&-O<G)U<'0L('-K:7!P:6YG)RP@)&-O;6UA
M;F0I.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-H86YN96P@/2`D8VAA;FYE
M;&EN9F\[#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N;F5L+3YG971.86UE
M*"D@(3T@)'-A=F4I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*"=%4E)/4CH@4V5C=7)I='D@<FES:R`M(&1O=VYL;V%D
M960@8VAA;FYE;"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=D969I
M;FET:6]N(&9I;&4@9F]R(&-H86YN96P@(B<-"B`@("`@("`@("`@("`@("`@
M("`@("`@("X@)&-H86YN96PM/F=E=$YA;64H*2`N("<@9G)O;2!C:&%N;F5L
M("(G("X@)'-A=F4@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(N("!4
M;R!U<V4@86YY=V%Y+"!U<V4@8VAA;FYE;"UU<&1A=&4G+"`D8V]M;6%N9"D[
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D<F5G+3YU<&1A=&5#:&%N;F5L*"1C
M:&%N;F5L+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@:68@*"1R96<M/FES06QI87,H)&-H86YN96PI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T96UP(#T@)B1R96<M/F=E=$-H
M86YN96PH)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D=&5M<"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D=&5M<"D[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'1E;7`M/G-E=$%L
M:6%S*"1T96UP+3YG971.86UE*"DL('1R=64I.R`O+R!S970@=&AE(&%L:6%S
M('1O('1H92!C:&%N;F5L(&YA;64-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1R96<M/F-H86YN96Q%>&ES=',H)'1E;7`M/F=E=$YA;64H*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G
M15)23U(Z(&5X:7-T:6YG(&-H86YN96P@(B<@+B`D=&5M<"T^9V5T3F%M92@I
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!I<R!A;&EA<V5D
M('1O("(G("X@)&-H86YN96P@+B`G(B!A;')E861Y(&%N9"!C86YN;W0@8F4@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E+6%L:6%S960@
M=&\@(B<@+B`D=&5M<"T^9V5T3F%M92@I("X@)R(@8F5C875S92!A(&-H86YN
M96P@=VET:"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&AA
M="!N86UE(&]R(&%L:6%S(&%L<F5A9'D@97AI<W1S(2`@4&QE87-E(')E+6%L
M:6%S(&%N9"!T<GD@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%G86EN+B<L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@B061D:6YG(&YE=R!C:&%N;F5L(%PB)&-H86YN96Q<(B(L("1C;VUM86YD
M*3L-"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@)&-O
M;G1E;G1S(#T@)&1L+3YD;W=N;&]A9$AT='`H)VAT='`Z+R\G("X@)&-H86YN
M96P@+B`G+V-H86YN96PN>&UL)RP-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"!F86QS92D[#0H@("`@("`@("`@("`@
M("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C;VYT96YT<RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=%4E)/4CH@
M0V%N;F]T(')E=')I979E(&-H86YN96PN>&UL(&9O<B!C:&%N;F5L("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C:&%N;F5L("X@)R(G+"`D8V]M
M;6%N9"D[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!L:7-T*"1C;VYT96YT<RP@
M)&QA<W1M;V1I9FEE9"D@/2`D8V]N=&5N=',[#0H@("`@("`@("`@("`@("`@
M)&EN9F\@/2!I;7!L;V1E*"<G+"!F:6QE*"1C;VYT96YT<RDI.PT*("`@("`@
M("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE
M)RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1C:&%N;F5L:6YF;R`](&YE=R!014%27T-H86YN96QF:6QE
M.PT*("`@("`@("`@("`@("`@("1C:&%N;F5L:6YF;RT^9G)O;5AM;%-T<FEN
M9R@D:6YF;RD[#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N;F5L:6YF;RT^
M9V5T17)R;W)S*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*")$;W=N;&]A9&5D(&-H86YN96P@9&%T82!F<F]M(&-H
M86YN96P@7"(D8VAA;FYE;%PB(B`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G(&ES(&-O<G)U<'0L('-K:7!P:6YG)RP@)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&-H86YN96P@/2`D8VAA;FYE;&EN9F\[#0H@("`@
M("`@("`@("`@("`@:68@*"1C:&%N;F5L+3YG971.86UE*"D@(3T@)'-A=F4I
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A
M*"=%4E)/4CH@4V5C=7)I='D@<FES:R`M(&1O=VYL;V%D960@8VAA;FYE;"`G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=D969I;FET:6]N(&9I;&4@
M9F]R(&-H86YN96P@(B<-"B`@("`@("`@("`@("`@("`@("`@("`@("X@)&-H
M86YN96PM/F=E=$YA;64H*2`N("<B(&9R;VT@8VAA;FYE;"`B)R`N("1S879E
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B+B`@5&\@=7-E(&%N>7=A
M>2P@=7-E(&-H86YN96PM=7!D871E)RP@)&-O;6UA;F0I.PT*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)')E9RT^861D0VAA;FYE;"@D8VAA;FYE;"P@)&QA<W1M
M;V1I9FEE9"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H
M86YN96PI.PT*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)W5P9&%T
M92UC:&%N;F5L<R!C;VUP;&5T92<L("1C;VUM86YD*3L-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*("`@(`T*("`@(&9U;F-T:6]N(&1O26YF;R@D
M8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I
M9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B3F\@8VAA;FYE;"!S<&5C:69I960B*3L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E
M=%)E9VES=')Y*"D[#0H@("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D
M<&%R86US6S!=*3L-"B`@("`@("`@:68@*"1R96<M/F-H86YN96Q%>&ES=',H
M)&-H86YN96PI*2![#0H@("`@("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H
M86YN96PH)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(&EF("AS=')P;W,H)&-H86YN96PL("<Z+R\G
M*2D@>PT*("`@("`@("`@("`@("`@("1D;W=N;&]A9&5R(#T@)B1T:&ES+3YG
M971$;W=N;&]A9&5R*"D[#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U-Y<W1E;2<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G
M+60G*2D[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@
M("1L;V,@/2`D9&]W;FQO861E<BT^9&]W;FQO861(='1P*"1C:&%N;F5L+"`D
M=&AI<RT^=6DL("1T;7!D:7(I.PT*("`@("`@("`@("`@("`@(%!%05(Z.G-T
M871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D;&]C*2D@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!O<&5N("(G("X@)&-H
M86YN96P@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1C;VYT96YT<R`](&EM<&QO9&4H)R<L(&9I;&4H
M)&QO8RDI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1P87)A;7-;,%TL
M("=R)RD[#0H@("`@("`@("`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D<&%R86US6S!=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=#86YN;W0@;W!E;B`B)R`N("1P87)A;7-;,%T@+B`G(B<I.PT*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;FMN;W=N(&-H86YN
M96P@(B<@+B`D8VAA;FYE;"`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@)R<[#0H@("`@("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1F<"DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S("X](&9R96%D*"1F
M<"P@,3`R-"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-H86X@/2!N97<@4$5!
M4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@("1C:&%N+3YF<F]M6&UL4W1R
M:6YG*"1C;VYT96YT<RD[#0H@("`@("`@("`@("`D8VAA;BT^=F%L:61A=&4H
M*3L-"B`@("`@("`@("`@(&EF("@D97)R<R`]("1C:&%N+3YG971%<G)O<G,H
M=')U92DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D
M97)R*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@D97)R6R=L979E;"==("X@)SH@)R`N("1E<G);)VUE<W-A9V4G72D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE;"!F:6QE("(G("X@)'!A<F%M<ULP
M72`N("<B(&ES(&YO="!V86QI9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("@D8VAA;BD@>PT*("`@("`@("`@("`@)&-H86YN
M96P@/2`D8VAA;BT^9V5T3F%M92@I.PT*("`@("`@("`@("`@)&-A<'1I;VX@
M/2`G0VAA;FYE;"`G("X@)&-H86YN96P@+B`G($EN9F]R;6%T:6]N.B<[#0H@
M("`@("`@("`@("`D9&%T83$@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G
M8V%P=&EO;B<@/3X@)&-A<'1I;VXL#0H@("`@("`@("`@("`@("`@)V)O<F1E
M<B<@/3X@=')U92D[#0H@("`@("`@("`@("`D9&%T83%;)V1A=&$G75LG<V5R
M=F5R)UT@/2!A<G)A>2@G3F%M92!A;F0@4V5R=F5R)RP@)&-H86XM/F=E=$YA
M;64H*2D[#0H@("`@("`@("`@("!I9B`H)&-H86XM/F=E=$%L:6%S*"D@(3T@
M)&-H86XM/F=E=$YA;64H*2D@>PT*("`@("`@("`@("`@("`@("1D871A,5LG
M9&%T82==6R=A;&EA<R==(#T@87)R87DH)T%L:6%S)RP@)&-H86XM/F=E=$%L
M:6%S*"DI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1A=&$Q6R=D
M871A)UU;)W-U;6UA<GDG72`](&%R<F%Y*"=3=6UM87)Y)RP@)&-H86XM/F=E
M=%-U;6UA<GDH*2D[#0H@("`@("`@("`@("`D=F%L:61A=&4@/2`D8VAA;BT^
M9V5T5F%L:61A=&EO;E!A8VMA9V4H*3L-"B`@("`@("`@("`@("1D871A,5LG
M9&%T82==6R=V<&%C:V%G92==(#T@87)R87DH)U9A;&ED871I;VX@4&%C:V%G
M92!.86UE)RP@)'9A;&ED871E6R=?8V]N=&5N="==*3L-"B`@("`@("`@("`@
M("1D871A,5LG9&%T82==6R=V<&%C:V%G979E<G-I;VXG72`]#0H@("`@("`@
M("`@("`@("`@87)R87DH)U9A;&ED871I;VX@4&%C:V%G92!697)S:6]N)RP@
M)'9A;&ED871E6R=A='1R:6)S)UU;)W9E<G-I;VXG72D[#0H@("`@("`@("`@
M("`D9"`](&%R<F%Y*"D[#0H@("`@("`@("`@("`D9%LG;6%I;B==(#T@)&1A
M=&$Q.PT*#0H@("`@("`@("`@("`D9&%T85LG9&%T82==(#T@87)R87DH*3L-
M"B`@("`@("`@("`@("1D871A6R=C87!T:6]N)UT@/2`G4V5R=F5R($-A<&%B
M:6QI=&EE<R<[#0H@("`@("`@("`@("`D9&%T85LG:&5A9&QI;F4G72`](&%R
M<F%Y*"=4>7!E)RP@)U9E<G-I;VXO4D535"!T>7!E)RP@)T9U;F-T:6]N($YA
M;64O4D535"!B87-E)RD[#0H@("`@("`@("`@("`D8V%P86)I;&ET:65S(#T@
M)&-H86XM/F=E=$9U;F-T:6]N<R@G>&UL<G!C)RD[#0H@("`@("`@("`@("`D
M<V]A<',@/2`D8VAA;BT^9V5T1G5N8W1I;VYS*"=S;V%P)RD[#0H@("`@("`@
M("`@("!I9B`H)&-A<&%B:6QI=&EE<R!\?"`D<V]A<',@?'P@)&-H86XM/G-U
M<'!O<G1S4D535"@I*2![#0H@("`@("`@("`@("`@("`@:68@*"1C87!A8FEL
M:71I97,I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D8V%P
M86)I;&ET:65S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-A
M<&%B:6QI=&EE<R`](&%R<F%Y*"1C87!A8FEL:71I97,I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C
M87!A8FEL:71I97,@87,@)'!R;W1O8V]L*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@G>&UL<G!C)RP@)'!R
M;W1O8V]L6R=A='1R:6)S)UU;)W9E<G-I;VXG72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')O=&]C;VQ;)U]C;VYT96YT)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@D<V]A<',I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<V]A<'-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<V]A<',@/2!A<G)A>2@D<V]A<',I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S;V%P<R!A<R`D
M<')O=&]C;VPI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A6R=D
M871A)UU;72`](&%R<F%Y*"=S;V%P)RP@)'!R;W1O8V]L6R=A='1R:6)S)UU;
M)W9E<G-I;VXG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O
M=&]C;VQ;)U]C;VYT96YT)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D8VAA;BT^
M<W5P<&]R='-215-4*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&9U;F-S
M(#T@)&-H86XM/F=E=$9U;F-T:6]N<R@G<F5S="<I.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1F=6YC<ULP72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1F=6YC<R`](&%R<F%Y*"1F=6YC<RD[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&9U;F-S(&%S("1P<F]T;V-O;"D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)W)E<W0G+"`D<')O=&]C;VQ;
M)V%T=')I8G,G75LG='EP92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P<F]T;V-O;%LG7V-O;G1E;G0G72D[(`T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@G
M3F\@<W5P<&]R=&5D('!R;W1O8V]L<R<I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&1;)W!R;W1O8V]L<R==(#T@)&1A=&$[#0H@("`@("`@("`@
M("`D9&%T85LG9&%T82==(#T@87)R87DH*3L-"B`@("`@("`@("`@("1M:7)R
M;W)S(#T@)&-H86XM/F=E=$UI<G)O<G,H*3L-"B`@("`@("`@("`@(&EF("@D
M;6ER<F]R<RD@>PT*("`@("`@("`@("`@("`@("1D871A6R=C87!T:6]N)UT@
M/2`G0VAA;FYE;"`G("X@)&-H86YN96P@+B`G($UI<G)O<G,Z)SL-"B`@("`@
M("`@("`@("`@("!U;G-E="@D9&%T85LG:&5A9&QI;F4G72D[#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&UI<G)O<G,@87,@)&UI<G)O<BD@>PT*("`@
M("`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D;6ER
M<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@("`@
M("1D6R=M:7)R;W)S)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&UI<G)O<G,@87,@)&UI<G)O<BD@
M>PT*("`@("`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V-A<'1I;VXG72`]("=-
M:7)R;W(@)R`N("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==("X@)R!#87!A
M8FEL:71I97,G.PT*("`@("`@("`@("`@("`@("`@("`D9&%T85LG:&5A9&QI
M;F4G72`](&%R<F%Y*"=4>7!E)RP@)U9E<G-I;VXO4D535"!T>7!E)RP@)T9U
M;F-T:6]N($YA;64O4D535"!B87-E)RD[#0H@("`@("`@("`@("`@("`@("`@
M("1C87!A8FEL:71I97,@/2`D8VAA;BT^9V5T1G5N8W1I;VYS*"=X;6QR<&,G
M+"`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@
M("`@("`@("1S;V%P<R`]("1C:&%N+3YG971&=6YC=&EO;G,H)W-O87`G+"`D
M;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D8V%P86)I;&ET:65S('Q\("1S;V%P<R!\?"`D8VAA;BT^<W5P
M<&]R='-215-4*"1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1C87!A8FEL:71I97,I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1C87!A8FEL
M:71I97-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C87!A8FEL:71I97,@/2!A<G)A>2@D8V%P86)I;&ET:65S*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&-A<&%B:6QI=&EE<R!A<R`D<')O=&]C;VPI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A
M=&$G75M=(#T@87)R87DH)WAM;')P8R<L("1P<F]T;V-O;%LG871T<FEB<R==
M6R=V97)S:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<')O=&]C;VQ;)U]C;VYT96YT)UTI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<V]A<',I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S;V%P<ULP72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O87!S(#T@87)R
M87DH)'-O87!S*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'-O87!S(&%S
M("1P<F]T;V-O;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@G<V]A<"<L("1P<F]T;V-O;%LG
M871T<FEB<R==6R=V97)S:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')O=&]C;VQ;)U]C;VYT96YT)UTI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D8VAA;BT^<W5P
M<&]R='-215-4*"1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F=6YC<R`]("1C:&%N+3YG971&
M=6YC=&EO;G,H)W)E<W0G+"`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9G5N
M8W-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M=6YC<R`](&%R<F%Y*"1F=6YC<RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1F=6YC<R!A<R`D<')O=&]C;VPI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)W)E<W0G+"`D
M<')O=&]C;VQ;)V%T=')I8G,G75LG='EP92==+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==*3L@
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R
M87DH)TYO('-U<'!O<G1E9"!P<F]T;V-O;',G*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D9%LG;6ER<F]R<')O=&]C
M;VQS)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&0L("=C
M:&%N;F5L+6EN9F\G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G4V5R:6]U<R!E<G)O<CH@0VAA
M;FYE;"`B)R`N("1P87)A;7-;,%T@+@T*("`@("`@("`@("`@("`@("<B(&AA
M<R!A(&-O<G)U<'1E9"!R96=I<W1R>2!E;G1R>2<I.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@#0H@("`@9G5N8W1I;VX@9&]$96QE
M=&4H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@
M("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN96PM9&5L971E.B!N;R!C
M:&%N;F5L('-P96-I9FEE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1R96<@
M/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@
M*"$D<F5G+3YC:&%N;F5L17AI<W1S*"1P87)A;7-;,%TI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN96PM9&5L971E
M.B!C:&%N;F5L("(G("X@)'!A<F%M<ULP72`N("<B(&1O97,@;F]T(&5X:7-T
M)RD[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN96P@/2`D<F5G+3YC:&%N
M;F5L3F%M92@D<&%R86US6S!=*3L-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]
M("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-A;FYO="!D96QE=&4@=&AE('!E87(N<&AP+FYE="!C
M:&%N;F5L)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]
M("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-A;FYO="!D96QE=&4@=&AE('!E8VPN<&AP+FYE="!C
M:&%N;F5L)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]
M("=?7W5R:2<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G0V%N;F]T(&1E;&5T92!T:&4@7U]U<FD@<'-E=61O+6-H86YN96PG
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M(#T@)')E9RT^;&ES=%!A8VMA9V5S*"1C:&%N;F5L*2DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N
M="@D97)R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=#:&%N;F5L("(G("X@)&-H86YN96P@+@T*("`@("`@("`@("`@("`@
M("<B(&AA<R!I;G-T86QL960@<&%C:V%G97,L(&-A;FYO="!D96QE=&4G*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R96<M/F1E;&5T94-H86YN96PH
M)&-H86YN96PI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)T-H86YN96P@(B<@+B`D8VAA;FYE;"`N("<B(&1E;&5T:6]N(&9A
M:6QE9"<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/F-O;F9I9RT^9&5L971E0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)T-H86YN96P@(B<@+B`D8VAA;FYE
M;"`N("<B(&1E;&5T960G+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!D;T%D9"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P
M87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I("$]
M(#$I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M8VAA;FYE;"UA9&0Z(&YO(&-H86YN96P@9FEL92!S<&5C:69I960G*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H<W1R<&]S*"1P87)A;7-;,%TL("<Z+R\G
M*2D@>PT*("`@("`@("`@("`@)&1O=VYL;V%D97(@/2`F)'1H:7,M/F=E=$1O
M=VYL;V%D97(H*3L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3
M>7-T96TG*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES
M=&5M+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&UP9&ER
M(#T@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI.PT*("`@("`@("`@("`@
M4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("`@("`@)&QO8R`]("1D;W=N;&]A9&5R+3YD;W=N;&]A
M9$AT='`H)'!A<F%M<ULP72P@)'1H:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"!F
M86QS92D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&]C*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M8VAA;FYE;"UA9&0Z($-A;FYO="!O<&5N("(G("X@)'!A<F%M<ULP72`N("<B
M)RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&QI
M<W0H)&QO8RP@)&QA<W1M;V1I9FEE9"D@/2`D;&]C.PT*("`@("`@("`@("`@
M("`@("1C;VYT96YT<R`](&EM<&QO9&4H)R<L(&9I;&4H)&QO8RDI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&QA
M<W1M;V1I9FEE9"`](&9A;'-E.PT*("`@("`@("`@("`@)&9P(#T@0&9O<&5N
M*"1P87)A;7-;,%TL("=R)RD[#0H@("`@("`@("`@("!I9B`H(21F<"D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA
M;FYE;"UA9&0Z(&-A;FYO="!O<&5N("(G("X@)'!A<F%M<ULP72`N("<B)RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8V]N=&5N=',@/2`G)SL-
M"B`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2![#0H@("`@("`@("`@
M("`@("`@)&-O;G1E;G1S("X](&9R96%D*"1F<"P@,3`R-"D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#:&%N;F5L1FEL92<I
M*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I
M;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D8VAA;FYE;"`](&YE=R!0
M14%27T-H86YN96Q&:6QE.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1R97-U
M;'0@/2`D8VAA;FYE;"T^9G)O;5AM;%-T<FEN9R@D8V]N=&5N=',I.PT*("`@
M("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M(&EF("@A)')E<W5L="D@>PT*("`@("`@("`@("`@)&5X:70@/2!F86QS93L-
M"B`@("`@("`@("`@(&EF("AC;W5N="@D97)R;W)S(#T@)&-H86YN96PM/F=E
M=$5R<F]R<RAT<G5E*2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M97)R;W)S(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H=6-F:7)S="@D97)R;W);)VQE=F5L)UT@+B`G
M.B`G("X@)&5R<F]R6R=M97-S86=E)UTI*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"$D97AI="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M:70@/2`D97)R;W);)VQE=F5L)UT@/3T@)V5R<F]R)R`_('1R=64@.B!F86QS
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H)&5X:70I('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=C:&%N;F5L+6%D9#H@
M:6YV86QI9"!C:&%N;F5L+GAM;"!F:6QE)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1R96<@/2`F
M)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*"1R
M96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PM/F=E=$YA;64H*2DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE;"UA
M9&0Z($-H86YN96P@(B<@+B`D8VAA;FYE;"T^9V5T3F%M92@I("X-"B`@("`@
M("`@("`@("`@("`G(B!E>&ES=',L('5S92!C:&%N;F5L+75P9&%T92!T;R!U
M<&1A=&4@96YT<GDG*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)')E
M9RT^861D0VAA;FYE;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE9"D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("!R
M971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R970I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE
M;"UA9&0Z(&%D9&EN9R!#:&%N;F5L("(G("X@)&-H86YN96PM/F=E=$YA;64H
M*2`N#0H@("`@("`@("`@("`@("`@)R(@=&\@<F5G:7-T<GD@9F%I;&5D)RD[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T0VAA;FYE
M;',H)')E9RT^;&ES=$-H86YN96QS*"DI.PT*("`@("`@("`D=&AI<RT^8V]N
M9FEG+3YW<FET94-O;F9I9T9I;&4H*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"=!9&1I;F<@0VAA;FYE;"`B)R`N("1C:&%N;F5L+3YG971.
M86UE*"D@+B`G(B!S=6-C965D960G+"`D8V]M;6%N9"D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9&]5<&1A=&4H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U-Y<W1E
M;2<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G
M.PT*("`@("`@("!]#0H@("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M
M<"AA<G)A>2@G+60G*2D[#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I
M9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US
M*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(DYO(&-H86YN96P@9FEL92!S<&5C:69I960B*3L-"B`@("`@("`@?0T*
M("`@("`@("`D;&%S=&UO9&EF:65D(#T@9F%L<V4[#0H@("`@("`@(&EF("@H
M(69I;&5?97AI<W1S*"1P87)A;7-;,%TI('Q\(&ES7V1I<B@D<&%R86US6S!=
M*2D-"B`@("`@("`@("`@("`@)B8@)')E9RT^8VAA;FYE;$5X:7-T<RAS=')T
M;VQO=V5R*"1P87)A;7-;,%TI*2D@>PT*("`@("`@("`@("`@)&,@/2`D<F5G
M+3YG971#:&%N;F5L*'-T<G1O;&]W97(H)'!A<F%M<ULP72DI.PT*("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&,I*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G4F5T<FEE
M=FEN9R!C:&%N;F5L+GAM;"!F<F]M(')E;6]T92!S97)V97(G*3L-"B`@("`@
M("`@("`@("1D;"`]("8D=&AI<RT^9V5T1&]W;FQO861E<BAA<G)A>2@I*3L-
M"B`@("`@("`@("`@("\O(&EF(&9O<F-E(&ES('-P96-I9FEE9"P@=7-E(&$@
M=&EM97-T86UP(&]F("(Q(B!T;R!F;W)C92!R971R:65V86P-"B`@("`@("`@
M("`@("1L87-T;6]D:69I960@/2!I<W-E="@D;W!T:6]N<ULG9F]R8V4G72D@
M/R!F86QS92`Z("1C+3YL87-T36]D:69I960H*3L-"B`@("`@("`@("`@(%!%
M05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@("`@("1C;VYT96YT<R`]("1D;"T^9&]W;FQO861(='1P
M*"=H='1P.B\O)R`N("1C+3YG971.86UE*"D@+B`G+V-H86YN96PN>&UL)RP-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DL("1T;7!D:7(L(&YU;&PL("1L
M87-T;6]D:69I960I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&-O;G1E;G1S*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0V%N;F]T(')E=')I979E(&-H86YN96PN>&UL(&9O<B!C
M:&%N;F5L("(G("X-"B`@("`@("`@("`@("`@("`@("`@)&,M/F=E=$YA;64H
M*2`N("<B)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!L:7-T*"1C
M;VYT96YT<RP@)&QA<W1M;V1I9FEE9"D@/2`D8V]N=&5N=',[#0H@("`@("`@
M("`@("!I9B`H(21C;VYT96YT<RD@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@B0VAA;FYE;"`D<&%R86US6S!=(&-H86YN96PN
M>&UL(&ES('5P('1O(&1A=&4B*3L-"B`@("`@("`@("`@("`@("!R971U<FX[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8V]N=&5N=',@/2!I;7!L
M;V1E*"<G+"!F:6QE*"1C;VYT96YT<RDI.PT*("`@("`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-H86YN96P@/2!N97<@4$5!
M4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@("1C:&%N;F5L+3YF<F]M6&UL
M4W1R:6YG*"1C;VYT96YT<RD[#0H@("`@("`@("`@("!I9B`H(21C:&%N;F5L
M+3YG971%<G)O<G,H*2D@>PT*("`@("`@("`@("`@("`@("\O('-E8W5R:71Y
M(&-H96-K.B!I<R!T:&4@9&]W;FQO861E9"!F:6QE(&9O<B!T:&4@8VAA;FYE
M;"!W92!G;W0@:70@9G)O;3\-"B`@("`@("`@("`@("`@("!I9B`H<W1R=&]L
M;W=E<B@D8VAA;FYE;"T^9V5T3F%M92@I*2`A/2!S=')T;VQO=V5R*"1C+3YG
M971.86UE*"DI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU:2T^;&]G*#`L("=705).24Y'.B!D;W=N;&]A9&5D(&-H86YN
M96P@9&5F:6YI=&EO;B!F:6QE)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R!F;W(@8VAA;FYE;"`B)R`N("1C:&%N;F5L+3YG971.86UE*"D@
M+B`G(B!F<F]M(&-H86YN96P@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<G1O;&]W97(H)&,M/F=E=$YA;64H*2D@+B`G(B<I.PT*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=%4E)/4CH@9&]W;FQO
M861E9"!C:&%N;F5L(&1E9FEN:71I;VX@9FEL92<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<@9F]R(&-H86YN96P@(B<@+B`D8VAA;FYE;"T^
M9V5T3F%M92@I("X@)R(@9G)O;2!C:&%N;F5L("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1C+3YG971.86UE*"DI("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("AS=')P;W,H)'!A<F%M<ULP72P@)SHO+R<I*2![#0H@("`@("`@
M("`@("`@("`@)&1L(#T@)B1T:&ES+3YG971$;W=N;&]A9&5R*"D[#0H@("`@
M("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@("1L;V,@/2`D9&PM
M/F1O=VYL;V%D2'1T<"@D<&%R86US6S!=+`T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^=6DL("1T;7!D:7(L(&YU;&PL("1L87-T;6]D:69I960I.PT*
M("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&]C*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D-A;FYO="!O<&5N("(@+B`D<&%R86US6S!=*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!L:7-T*"1L;V,L
M("1L87-T;6]D:69I960I(#T@)&QO8SL-"B`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G1S(#T@:6UP;&]D92@G)RP@9FEL92@D;&]C*2D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D9G`@/2!`9F]P96XH)'!A<F%M<ULP72P@)W(G*3L-"B`@("`@("`@
M("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-A;FYO="!O<&5N("(@+B`D<&%R86US
M6S!=*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-O
M;G1E;G1S(#T@)R<[#0H@("`@("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1F
M<"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S("X](&9R96%D
M*"1F<"P@,3`R-"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP
M:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-H86YN96P@/2!N
M97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@("1C:&%N;F5L+3YF
M<F]M6&UL4W1R:6YG*"1C;VYT96YT<RD[#0H@("`@("`@('T-"B`@("`@("`@
M)&5X:70@/2!F86QS93L-"B`@("`@("`@:68@*&-O=6YT*"1E<G)O<G,@/2`D
M8VAA;FYE;"T^9V5T17)R;W)S*'1R=64I*2D@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&5R<F]R<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H=6-F:7)S="@D97)R;W);)VQE=F5L)UT@
M+B`G.B`G("X@)&5R<F]R6R=M97-S86=E)UTI*3L-"B`@("`@("`@("`@("`@
M("!I9B`H(21E>&ET*2![#0H@("`@("`@("`@("`@("`@("`@("1E>&ET(#T@
M)&5R<F]R6R=L979E;"==(#T]("=E<G)O<B<@/R!T<G5E(#H@9F%L<V4[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1E>&ET*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=);G9A;&ED(&-H86YN96PN>&UL(&9I;&4G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R96<M/F-H86YN
M96Q%>&ES=',H)&-H86YN96PM/F=E=$YA;64H*2DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G17)R;W(Z($-H86YN96P@(B<@
M+B`D8VAA;FYE;"T^9V5T3F%M92@I("X-"B`@("`@("`@("`@("`@("`G(B!D
M;V5S(&YO="!E>&ES="P@=7-E(&-H86YN96PM861D('1O(&%D9"!A;B!E;G1R
M>2<I.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D<F5G+3YU<&1A=&5#
M:&%N;F5L*"1C:&%N;F5L+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)')E="D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5<&1A=&EN9R!#:&%N
M;F5L("(G("X@)&-H86YN96PM/F=E=$YA;64H*2`N#0H@("`@("`@("`@("`@
M("`@)R(@:6X@<F5G:7-T<GD@9F%I;&5D)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^<V5T0VAA;FYE;',H)')E9RT^;&ES=$-H86YN
M96QS*"DI.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YW<FET94-O;F9I9T9I
M;&4H*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=5<&1A=&4@
M;V8@0VAA;FYE;"`B)R`N("1C:&%N;F5L+3YG971.86UE*"D@+B`G(B!S=6-C
M965D960G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B`F9V5T1&]W;FQO861E
M<B@I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]$
M;W=N;&]A9&5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]$;W=N;&]A9&5R+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2!N
M97<@4$5!4E]$;W=N;&]A9&5R*"1T:&ES+3YU:2P@87)R87DH*2P@)'1H:7,M
M/F-O;F9I9RD[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!D;T%L:6%S*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-
M"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`]/2`Q*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)TYO(&-H
M86YN96P@86QI87,@<W!E8VEF:65D)RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*'-I>F5O9B@D<&%R86US*2`A/2`R*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@)TEN=F%L
M:60@9F]R;6%T+"!C;W)R96-T(&ES.B!C:&%N;F5L+6%L:6%S(&-H86YN96P@
M86QI87,G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R96<M/F-H86YN
M96Q%>&ES=',H)'!A<F%M<ULP72P@=')U92DI('L-"B`@("`@("`@("`@(&EF
M("@D<F5G+3YI<T%L:6%S*"1P87)A;7-;,%TI*2![#0H@("`@("`@("`@("`@
M("`@)&5X=')A(#T@)R`H=7-E(")C:&%N;F5L+6%L:6%S("<@+B`D<F5G+3YC
M:&%N;F5L3F%M92@D<&%R86US6S!=*2`N("<@)R`N#0H@("`@("`@("`@("`@
M("`@("`@('-T<G1O;&]W97(H)'!A<F%M<ULQ72D@+B`G(BDG.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D97AT<F$@/2`G)SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G(B<@+B`D<&%R86US6S!=("X@)R(@:7,@;F]T(&$@=F%L:60@
M8VAA;FYE;"<@+B`D97AT<F$I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<F5G+3YI<T%L:6%S*"1P87)A;7-;,5TI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-H86YN96P@(B<@+B`D<F5G+3YC:&%N
M;F5L3F%M92@D<&%R86US6S%=*2`N("<B(&ES("<@+@T*("`@("`@("`@("`@
M("`@("=A;')E861Y(&%L:6%S960@=&\@(B<@+B!S=')T;VQO=V5R*"1P87)A
M;7-;,5TI("X@)R(L(&-A;FYO="!R92UA;&EA<R<I.PT*("`@("`@("!]#0H@
M("`@("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)'!A<F%M<ULP72D[
M#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#;W)R=7!T(')E9VES
M=')Y/R`@17)R;W(@<F5T<FEE=FEN9R!C:&%N;F5L("(G("X@)'!A<F%M<ULP
M72`N#0H@("`@("`@("`@("`@("`@)R(@:6YF;W)M871I;VX@*"<@+B`D8VAA
M;BT^9V5T365S<V%G92@I("X@)RDG*3L-"B`@("`@("`@?0T*("`@("`@("`O
M+R!M86ME(&ET(&$@;&]C86P@86QI87,-"B`@("`@("`@:68@*"$D8VAA;BT^
M<V5T06QI87,H<W1R=&]L;W=E<B@D<&%R86US6S%=*2P@=')U92DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G06QI87,@(B<@
M+B!S=')T;VQO=V5R*"1P87)A;7-;,5TI("X-"B`@("`@("`@("`@("`@("`G
M(B!I<R!N;W0@82!V86QI9"!C:&%N;F5L(&%L:6%S)RD[#0H@("`@("`@('T-
M"B`@("`@("`@)')E9RT^=7!D871E0VAA;FYE;"@D8VAA;BD[#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G0VAA;FYE;"`B)R`N("1C:&%N+3YG
M971.86UE*"D@+B`G(B!A;&EA<V5D('-U8V-E<W-F=6QL>2!T;R`B)R`N#0H@
M("`@("`@("`@("!S=')T;VQO=V5R*"1P87)A;7-;,5TI("X@)R(G*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!D;T1I<V-O=F5R*"1C;VUM86YD+"`D;W!T
M:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*'-I>F5O9B@D
M<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(DYO(&-H86YN96P@<V5R=F5R('-P96-I9FEE9"(I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D<F5G+3YC:&%N;F5L17AI<W1S*"1P87)A
M;7-;,%TI*2![#0H@("`@("`@("`@("!I9B`H)')E9RT^:7-!;&EA<R@D<&%R
M86US6S!=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B02!C:&%N;F5L(&%L:6%S(&YA;65D(%PB)'!A<F%M<ULP75PB
M("(@+@T*("`@("`@("`@("`@("`@("`@("`G86QR96%D>2!E>&ES=',L(&%L
M:6%S:6YG(&-H86YN96P@(B<@+B`D<F5G+3YC:&%N;F5L3F%M92@D<&%R86US
M6S!=*0T*("`@("`@("`@("`@("`@("`@("`N("<B)RD[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B0VAA;FYE;"!<(B1P87)A;7-;,%U<(B!I<R!A;')E861Y(&EN
M:71I86QI>F5D(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@)&5R<B`]("1T:&ES+3YD;T%D9"@D8V]M;6%N9"P@)&]P
M=&EO;G,L(&%R<F%Y*"=H='1P.B\O)R`N("1P87)A;7-;,%T@+B`G+V-H86YN
M96PN>&UL)RDI.PT*("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$:7-C;W9E<GD@;V8@
M8VAA;FYE;"!<(B1P87)A;7-;,%U<(B!F86EL960@*"(@+@T*("`@("`@("`@
M("`@("`@("1E<G(M/F=E=$UE<W-A9V4H*2`N("<I)RD[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")$:7-C;W9E<GD@;V8@
M8VAA;FYE;"!<(B1P87)A;7-;,%U<(B!S=6-C965D960B+"`D8V]M;6%N9"D[
M#0H@("`@?0T*?0T*/SX-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T-O;6UO;BYP:'``````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$P-S,`,3`U,34T,S$P-3<`,#(Q
M-#$R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]#;VUM;VX@8F%S92!C;&%S
M<PT*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#;VUM;VXN
M<&AP+'8@,2XS,B`R,#`V+S`S+S`R(#$V.C,Y.C$T('!A:F]Y92!%>'`@)`T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I
M<F5?;VYC92`G4$5!4BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@
M8F%S92!C;&%S<PT*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K
M86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`
M<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?0V]M;6%N
M9%]#;VUM;VX@97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I
M97,-"@T*("`@("\J*@T*("`@("`J(%!%05)?0V]N9FEG(&]B:F5C="!U<V5D
M('1O('!A<W,@=7-E<B!S>7-T96T@86YD(&-O;F9I9W5R871I;VX-"B`@("`@
M*B!O;B!W:&5N(&5X96-U=&EN9R!C;VUM86YD<PT*("`@("`J#0H@("`@("H@
M0'9A<B!014%27T-O;F9I9PT*("`@("`J+PT*("`@('9A<B`D8V]N9FEG.PT*
M("`@("\J*@T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?<F5G:7-T<GD[
M#0H-"B`@("`O*BH-"B`@("`@*B!5<V5R($EN=&5R9F%C92!O8FIE8W0L(&9O
M<B!A;&P@:6YT97)A8W1I;VX@=VET:"!T:&4@=7-E<BX-"B`@("`@*B!`=F%R
M(&]B:F5C=`T*("`@("`J+PT*("`@('9A<B`D=6D[#0H-"B`@("!V87(@)%]D
M97!S7W)E;%]T<F%N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VQT)R`]/B`G/"<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&4G(#T^("<\/2<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G97$G(#T^("<])RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=N92<@/3X@)R$])RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=G="<@/3X@)SXG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V=E)R`]/B`G/CTG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAA<R<@/3X@)ST])PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@('9A<B`D
M7V1E<'-?='EP95]T<F%N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P:V<G(#T^("=P86-K86=E)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G97AT96YS:6]N)R`]/B`G97AT
M96YS:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&AP)R`]/B`G4$A0)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<')O9R<@/3X@)V5X=&5R;F%L('!R;V=R86TG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=L9&QI8B<@/3X@)V5X=&5R;F%L
M(&QI8G)A<GD@9F]R(&QI;FMI;F<G+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R=&QI8B<@/3X@)V5X=&5R;F%L(')U;G1I;64@;&EB
M<F%R>2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]S
M)R`]/B`G;W!E<F%T:6YG('-Y<W1E;2<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W=E8G-R=B<@/3X@)W=E8B!S97)V97(G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S87!I)R`]/B`G4T%0
M22!B86-K96YD)PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D[#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*
M("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]#;VUM;VX@8V]N<W1R=6-T
M;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]#;VUM;VXH)B1U:2P@)B1C;VYF
M:6<I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05(H*3L-"B`@("`@("`@
M)'1H:7,M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("`D=&AI<RT^=6D@
M/2`F)'5I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&=E
M=$-O;6UA;F1S*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A(&QI<W0@
M;V8@86QL('1H92!C;VUM86YD<R!D969I;F5D(&)Y('1H:7,@8VQA<W,N#0H@
M("`@("H@0')E='5R;B!A<G)A>2!L:7-T(&]F(&-O;6UA;F1S#0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971#;VUM
M86YD<R@I#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@
M("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^8V]M;6%N9',I(&%S("1C
M;VUM86YD*2![#0H@("`@("`@("`@("`D<F5T6R1C;VUM86YD72`]("1T:&ES
M+3YC;VUM86YD<ULD8V]M;6%N9%U;)W-U;6UA<GDG73L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@9V5T4VAO<G1C=71S*"D-"@T*("`@("\J*@T*("`@("`J(%)E
M='5R;B!A(&QI<W0@;V8@86QL('1H92!C;VUM86YD('-H;W)T8W5T<R!D969I
M;F5D(&)Y('1H:7,@8VQA<W,N#0H@("`@("H@0')E='5R;B!A<G)A>2!S:&]R
M=&-U="`]/B!C;VUM86YD#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G9713:&]R=&-U=',H*0T*("`@('L-"B`@("`@
M("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME
M>7,H)'1H:7,M/F-O;6UA;F1S*2!A<R`D8V]M;6%N9"D@>PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)W-H;W)T
M8W5T)UTI*2![#0H@("`@("`@("`@("`@("`@)')E=%LD=&AI<RT^8V]M;6%N
M9'-;)&-O;6UA;F1=6R=S:&]R=&-U="==72`]("1C;VUM86YD.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971/<'1I;VYS*"D-"@T*
M("`@(&9U;F-T:6]N(&=E=$]P=&EO;G,H)&-O;6UA;F0I#0H@("`@>PT*("`@
M("`@("`D<VAO<G1C=71S(#T@)'1H:7,M/F=E=%-H;W)T8W5T<R@I.PT*("`@
M("`@("!I9B`H:7-S970H)'-H;W)T8W5T<ULD8V]M;6%N9%TI*2![#0H@("`@
M("`@("`@("`D8V]M;6%N9"`]("1S:&]R=&-U='-;)&-O;6UA;F1=.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM
M86YD75LG;W!T:6]N<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971'971O<'1!<F=S*"D-"@T*("`@(&9U;F-T:6]N(&=E=$=E=&]P
M=$%R9W,H)&-O;6UA;F0L("8D<VAO<G1?87)G<RP@)B1L;VYG7V%R9W,I#0H@
M("`@>PT*("`@("`@("`D<VAO<G1?87)G<R`]("(B.PT*("`@("`@("`D;&]N
M9U]A<F=S(#T@87)R87DH*3L-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YC
M;VUM86YD<ULD8V]M;6%N9%TI('Q\(&5M<'1Y*"1T:&ES+3YC;VUM86YD<ULD
M8V]M;6%N9%U;)V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@(')E='5R;CL-
M"B`@("`@("`@?0T*("`@("`@("!R97-E="@D=&AI<RT^8V]M;6%N9'-;)&-O
M;6UA;F1=6R=O<'1I;VYS)UTI.PT*("`@("`@("!W:&EL92`H;&ES="@D;W!T
M:6]N+"`D:6YF;RD@/2!E86-H*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;
M)V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@("1L87)G(#T@)'-A<F<@/2`G
M)SL-"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG87)G)UTI*2![#0H@
M("`@("`@("`@("`@("`@:68@*"1I;F9O6R=A<F<G77LP?2`]/2`G*"<I('L-
M"B`@("`@("`@("`@("`@("`@("`@)&QA<F<@/2`G/3TG.PT*("`@("`@("`@
M("`@("`@("`@("`D<V%R9R`]("<Z.B<[#0H@("`@("`@("`@("`@("`@("`@
M("1A<F<@/2!S=6)S='(H)&EN9F];)V%R9R==+"`Q+"`M,2D[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&QA<F<@
M/2`G/2<[#0H@("`@("`@("`@("`@("`@("`@("1S87)G(#T@)SHG.PT*("`@
M("`@("`@("`@("`@("`@("`D87)G(#T@)&EN9F];)V%R9R==.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D:6YF;ULG<VAO<G1O<'0G72DI('L-"B`@("`@("`@("`@("`@("`D
M<VAO<G1?87)G<R`N/2`D:6YF;ULG<VAO<G1O<'0G72`N("1S87)G.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&QO;F=?87)G<UM=(#T@)&]P=&EO
M;B`N("1L87)G.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=$AE;'`H*0T*("`@("\J*@T*("`@("H@4F5T=7)N<R!T
M:&4@:&5L<"!M97-S86=E(&9O<B!T:&4@9VEV96X@8V]M;6%N9`T*("`@("H-
M"B`@("`J($!P87)A;2!S=')I;F<@)&-O;6UA;F0@5&AE(&-O;6UA;F0-"B`@
M("`J($!R971U<FX@;6EX960@02!F86EL('-T<FEN9R!I9B!T:&4@8V]M;6%N
M9"!D;V5S(&YO="!H879E(&AE;'`@;W(-"B`@("`J("`@("`@("`@("`@("`@
M82!T=V\@96QE;65N=',@87)R87D@8V]N=&%I;FEN9R!;,%T]/FAE;'`@<W1R
M:6YG+`T*("`@("H@("`@("`@("`@("`@("!;,5T]/B!H96QP('-T<FEN9R!F
M;W(@=&AE(&%C8V5P=&5D(&-M9"!A<F=S#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!G971(96QP*"1C;VUM86YD*0T*("`@('L-"B`@("`@("`@)&-O;F9I9R`]
M("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("1H96QP(#T@
M0"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)V1O8R==.PT*("`@("`@("!I
M9B`H96UP='DH)&AE;'`I*2![#0H@("`@("`@("`@("`O+R!86%@@*&-O>"D@
M1F%L;&)A8VL@=&\@<W5M;6%R>2!I9B!T:&5R92!I<R!N;R!D;V,@*'-H;W<@
M8F]T:#\I#0H@("`@("`@("`@("!I9B`H(21H96QP(#T@0"1T:&ES+3YC;VUM
M86YD<ULD8V]M;6%N9%U;)W-U;6UA<GDG72D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`B3F\@:&5L<"!F;W(@8V]M;6%N9"!<(B1C;VUM86YD7"(B.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AP<F5G7VUA
M=&-H7V%L;"@G+WMC;VYF:6=<<RLH6UY<?5TK*7TO92<L("1H96QP+"`D;6%T
M8VAE<RDI('L-"B`@("`@("`@("`@(&9O<F5A8V@H)&UA=&-H97-;,%T@87,@
M)&L@/3X@)'8I('L-"B`@("`@("`@("`@("`@("`D:&5L<"`]('!R96=?<F5P
M;&%C92@B+R1V+R(L("1C;VYF:6<M/F=E="@D;6%T8VAE<ULQ75LD:UTI+"`D
M:&5L<"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1H96QP+"`D=&AI<RT^9V5T2&5L<$%R9W,H)&-O;6UA;F0I
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T2&5L<$%R
M9W,H*0T*("`@("\J*@T*("`@("H@4F5T=7)N<R!T:&4@:&5L<"!F;W(@=&AE
M(&%C8V5P=&5D(&%R9W5M96YT<R!O9B!A(&-O;6UA;F0-"B`@("`J#0H@("`@
M*B!`<&%R86T@('-T<FEN9R`D8V]M;6%N9`T*("`@("H@0')E='5R;B!S=')I
M;F<@5&AE(&AE;'`@<W1R:6YG#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971(
M96QP07)G<R@D8V]M;6%N9"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UTI("8F#0H@("`@
M("`@("`@("!C;W5N="@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I
M;VYS)UTI*0T*("`@("`@("![#0H@("`@("`@("`@("`D:&5L<"`](")/<'1I
M;VYS.EQN(CL-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VUM86YD
M<ULD8V]M;6%N9%U;)V]P=&EO;G,G72!A<R`D:R`]/B`D=BD@>PT*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D=ELG87)G)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D=ELG87)G)UU[,'T@/3T@)R@G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D87)G(#T@<W5B<W1R*"1V6R=A<F<G72P@,2P@
M+3$I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-A<'`@/2`B(%LD87)G
M72([#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%P<"`](");/21A<F==
M(CL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1S87!P(#T@(B`D=EMA<F==(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1L87!P(#T@(CTD=EMA<F==(CL-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1S87!P(#T@)&QA<'`@/2`B(CL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V6R=S:&]R=&]P
M="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<R`]("1V6R=S:&]R=&]P
M="==.PT*("`@("`@("`@("`@("`@("`@("!`)&AE;'`@+CT@(B`@+21S)'-A
M<'`L("TM)&LD;&%P<%QN(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("!`)&AE;'`@+CT@(B`@+2TD:R1L87!P7&XB
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<"`]("(@
M("`@("`@("([#0H@("`@("`@("`@("`@("`@)&1O8R`](')T<FEM*'-T<E]R
M97!L86-E*")<;B(L(")<;B1P(BP@)'9;)V1O8R==*2D[#0H@("`@("`@("`@
M("`@("`@)&AE;'`@+CT@(B`@("`@("`@)&1O8UQN(CL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B`D:&5L<#L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@;G5L;#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@<G5N*"D-"@T*("`@(&9U;F-T:6]N(')U;B@D8V]M;6%N9"P@)&]P
M=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG9G5N8W1I;VXG72DI('L-"B`@("`@
M("`@("`@("\O(&QO;VL@9F]R('-H;W)T8W5T<PT*("`@("`@("`@("`@9F]R
M96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^8V]M;6%N9',I(&%S("1C;60I('L-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;6UA;F1S6R1C
M;61=6R=S:&]R=&-U="==*2`F)B`D=&AI<RT^8V]M;6%N9'-;)&-M9%U;)W-H
M;W)T8W5T)UT@/3T@)&-O;6UA;F0I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3YC;VUM86YD<ULD8VUD75LG9G5N8W1I;VXG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1F=6YC(#T@)'1H:7,M/F-O;6UA;F1S6R1C;61=6R=F=6YC=&EO;B==
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1C;VUM86YD(#T@)&-M9#L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&9U;F,@/2`D=&AI<RT^8V]M;6%N9'-;
M)&-O;6UA;F1=6R=F=6YC=&EO;B==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^)&9U;F,H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0V]N9FEG+GAM
M;```````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C8R,0`Q,#4Q-30S
M,3`U-P`P,C$T,#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&-O;F9I9RUS
M:&]W/@T*("`\<W5M;6%R>3Y3:&]W($%L;"!3971T:6YG<SPO<W5M;6%R>3X-
M"B`@/&9U;F-T:6]N/F1O0V]N9FEG4VAO=SPO9G5N8W1I;VX^#0H@(#QS:&]R
M=&-U=#YC<V@\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L
M/@T*("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-H;W<@
M8V]N9FEG=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@8VAA;FYE;#PO
M9&]C/@T*("`@(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\
M+V]P=&EO;G,^#0H@(#QD;V,^6VQA>65R70T*1&ES<&QA>7,@86QL(&-O;F9I
M9W5R871I;VX@=F%L=65S+B`@06X@;W!T:6]N86P@87)G=6UE;G0-"FUA>2!B
M92!U<V5D('1O('1E;&P@=VAI8V@@8V]N9FEG=7)A=&EO;B!L87EE<B!T;R!D
M:7-P;&%Y+B`@5F%L:60-"F-O;F9I9W5R871I;VX@;&%Y97)S(&%R92`F<75O
M=#MU<V5R)G%U;W0[+"`F<75O=#MS>7-T96TF<75O=#L@86YD("9Q=6]T.V1E
M9F%U;'0F<75O=#LN(%1O(&1I<W!L87D-"F-O;F9I9W5R871I;VYS(&9O<B!D
M:69F97)E;G0@8VAA;FYE;',L('-E="!T:&4@9&5F875L=%]C:&%N;F5L#0IC
M;VYF:6=U<F%T:6]N('9A<FEA8FQE(&%N9"!R=6X@8V]N9FEG+7-H;W<@86=A
M:6XN#0H\+V1O8SX-"B`\+V-O;F9I9RUS:&]W/@T*(#QC;VYF:6<M9V5T/@T*
M("`\<W5M;6%R>3Y3:&]W($]N92!3971T:6YG/"]S=6UM87)Y/@T*("`\9G5N
M8W1I;VX^9&]#;VYF:6='970\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8V<\
M+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*("`@(#QS
M:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-H;W<@8V]N9FEG=7)A
M=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@8VAA;FYE;#PO9&]C/@T*("`@
M(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P=&EO;G,^
M#0H@(#QD;V,^)FQT.W!A<F%M971E<B9G=#L@6VQA>65R70T*1&ES<&QA>7,@
M=&AE('9A;'5E(&]F(&]N92!C;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%1H
M90T*9FER<W0@87)G=6UE;G0@:7,@=&AE(&YA;64@;V8@=&AE('!A<F%M971E
M<BP@86X@;W!T:6]N86P@<V5C;VYD(&%R9W5M96YT#0IM87D@8F4@=7-E9"!T
M;R!T96QL('=H:6-H(&-O;F9I9W5R871I;VX@;&%Y97(@=&\@;&]O:R!I;BX@
M(%9A;&ED(&-O;F9I9W5R871I;VX-"FQA>65R<R!A<F4@)G%U;W0[=7-E<B9Q
M=6]T.RP@)G%U;W0[<WES=&5M)G%U;W0[(&%N9"`F<75O=#MD969A=6QT)G%U
M;W0[+B`@268@;F\@;&%Y97(@:7,@<W!E8VEF:65D+"!A('9A;'5E#0IW:6QL
M(&)E('!I8VME9"!F<F]M('1H92!F:7)S="!L87EE<B!T:&%T(&1E9FEN97,@
M=&AE('!A<F%M971E<BP@:6X@=&AE(&]R9&5R#0IJ=7-T('-P96-I9FEE9"X@
M(%1H92!C;VYF:6=U<F%T:6]N('9A;'5E('=I;&P@8F4@<F5T<FEE=F5D(&9O
M<B!T:&4@8VAA;FYE;`T*<W!E8VEF:65D(&)Y('1H92!D969A=6QT7V-H86YN
M96P@8V]N9FEG=7)A=&EO;B!V87)I86)L92X-"CPO9&]C/@T*(#PO8V]N9FEG
M+6=E=#X-"B`\8V]N9FEG+7-E=#X-"B`@/'-U;6UA<GD^0VAA;F=E(%-E='1I
M;F<\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T-O;F9I9U-E=#PO9G5N8W1I
M;VX^#0H@(#QS:&]R=&-U=#YC<SPO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*
M("`@/&-H86YN96P^#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^<VAO=R!C;VYF:6=U<F%T:6]N('9A<FEA8FQE<R!F;W(@86YO=&AE
M<B!C:&%N;F5L/"]D;V,^#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H
M86YN96P^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%R86UE=&5R)F=T
M.R`F;'0[=F%L=64F9W0[(%ML87EE<ET-"E-E=',@=&AE('9A;'5E(&]F(&]N
M92!C;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%1H92!F:7)S="!A<F=U;65N
M="!I<PT*=&AE(&YA;64@;V8@=&AE('!A<F%M971E<BP@=&AE('-E8V]N9"!A
M<F=U;65N="!I<R!T:&4@;F5W('9A;'5E+B`@4V]M90T*<&%R86UE=&5R<R!A
M<F4@<W5B:F5C="!T;R!V86QI9&%T:6]N+"!A;F0@=&AE(&-O;6UA;F0@=VEL
M;"!F86EL('=I=&@-"F%N(&5R<F]R(&UE<W-A9V4@:68@=&AE(&YE=R!V86QU
M92!D;V5S(&YO="!M86ME('-E;G-E+B`@06X@;W!T:6]N86P-"G1H:7)D(&%R
M9W5M96YT(&UA>2!B92!U<V5D('1O('-P96-I9GD@:6X@=VAI8V@@;&%Y97(@
M=&\@<V5T('1H90T*8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9&5F
M875L="!L87EE<B!I<R`F<75O=#MU<V5R)G%U;W0[+B`@5&AE#0IC;VYF:6=U
M<F%T:6]N('9A;'5E('=I;&P@8F4@<V5T(&9O<B!T:&4@8W5R<F5N="!C:&%N
M;F5L+"!W:&EC:`T*:7,@8V]N=')O;&QE9"!B>2!T:&4@9&5F875L=%]C:&%N
M;F5L(&-O;F9I9W5R871I;VX@=F%R:6%B;&4N#0H\+V1O8SX-"B`\+V-O;F9I
M9RUS970^#0H@/&-O;F9I9RUH96QP/@T*("`\<W5M;6%R>3Y3:&]W($EN9F]R
M;6%T:6]N($%B;W5T(%-E='1I;F<\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD
M;T-O;F9I9TAE;'`\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8V@\+W-H;W)T
M8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/EMP87)A;65T97)=#0I$:7-P
M;&%Y<R!H96QP(&9O<B!A(&-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5VET
M:&]U="!A<F=U;65N=',@:70-"F1I<W!L87ES(&AE;'`@9F]R(&%L;"!C;VYF
M:6=U<F%T:6]N('!A<F%M971E<G,N#0H\+V1O8SX-"B`\+V-O;F9I9RUH96QP
M/@T*(#QC;VYF:6<M8W)E871E/@T*("`\<W5M;6%R>3Y#<F5A=&4@82!$969A
M=6QT(&-O;F9I9W5R871I;VX@9FEL93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N
M/F1O0V]N9FEG0W)E871E/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-O8SPO
M<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/'=I;F1O=W,^#0H@("`@/'-H
M;W)T;W!T/G<\+W-H;W)T;W!T/@T*("`@(#QD;V,^8W)E871E(&$@8V]N9FEG
M(&9I;&4@9F]R(&$@=VEN9&]W<R!I;G-T86QL/"]D;V,^#0H@("`\+W=I;F1O
M=W,^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<F]O="!P871H)F=T.R`F
M;'0[9FEL96YA;64F9W0[#0I#<F5A=&4@82!D969A=6QT(&-O;F9I9W5R871I
M;VX@9FEL92!W:71H(&%L;"!D:7)E8W1O<GD@8V]N9FEG=7)A=&EO;@T*=F%R
M:6%B;&5S('-E="!T;R!S=6)D:7)E8W1O<FEE<R!O9B`F;'0[<F]O="!P871H
M)F=T.RP@86YD('-A=F4@:70@87,@)FQT.V9I;&5N86UE)F=T.RX-"E1H:7,@
M:7,@=7-E9G5L(&5S<&5C:6%L;'D@9F]R(&-R96%T:6YG(&$@8V]N9FEG=7)A
M=&EO;B!F:6QE(&9O<B!A(')E;6]T90T*4$5!4B!I;G-T86QL871I;VX@*'5S
M:6YG('1H92`M+7)E;6]T96-O;F9I9R!O<'1I;VX@;V8@:6YS=&%L;"P@=7!G
M<F%D92P-"F%N9"!U;FEN<W1A;&PI+@T*/"]D;V,^#0H@/"]C;VYF:6<M8W)E
M871E/@T*/"]C;VUM86YD<SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T-O;F9I9RYP
M:'``````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S8S,C<`,3`U,34T
M,S$P-3<`,#(Q,S<W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]#;VYF:6<@
M*&-O;F9I9RUS:&]W+"!C;VYF:6<M9V5T+"!C;VYF:6<M<V5T+"!C;VYF:6<M
M:&5L<"P@8V]N9FEG+6-R96%T92!C;VUM86YD<RD-"B`J#0H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@0V]N9FEG+G!H<"QV(#$N-3$@,C`P-B\P
M,R\P,B`Q,SHS,CHS."!P86IO>64@17AP("0-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J
M*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M
M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O
M<B!M86YA9VEN9R!C;VYF:6=U<F%T:6]N(&1A=&$N#0H@*@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M+PT*8VQA<W,@4$5!4E]#;VUM86YD7T-O;F9I9R!E>'1E;F1S(%!%05)?0V]M
M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@
M=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G8V]N9FEG+7-H;W<G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=3:&]W($%L
M;"!3971T:6YG<R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O
M;F9I9U-H;W<G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8W-H)RP-
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G8VAA;FYE;"<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G<VAO=R!C;VYF:6=U<F%T:6]N('9A<FEA8FQE<R!F;W(@86YO=&AE
M<B!C:&%N;F5L)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T-(
M04XG+`T*("`@("`@("`@("`@("`@("`@("`I+`T**2P-"B`@("`@("`@("`@
M("=D;V,G(#T^("=;;&%Y97)=#0I$:7-P;&%Y<R!A;&P@8V]N9FEG=7)A=&EO
M;B!V86QU97,N("!!;B!O<'1I;VYA;"!A<F=U;65N=`T*;6%Y(&)E('5S960@
M=&\@=&5L;"!W:&EC:"!C;VYF:6=U<F%T:6]N(&QA>65R('1O(&1I<W!L87DN
M("!686QI9`T*8V]N9FEG=7)A=&EO;B!L87EE<G,@87)E(")U<V5R(BP@(G-Y
M<W1E;2(@86YD(")D969A=6QT(BX@5&\@9&ES<&QA>0T*8V]N9FEG=7)A=&EO
M;G,@9F]R(&1I9F9E<F5N="!C:&%N;F5L<RP@<V5T('1H92!D969A=6QT7V-H
M86YN96P-"F-O;F9I9W5R871I;VX@=F%R:6%B;&4@86YD(')U;B!C;VYF:6<M
M<VAO=R!A9V%I;BX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8V]N
M9FEG+6=E="<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@
M)U-H;W<@3VYE(%-E='1I;F<G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]#;VYF:6='970G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M8V<G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=C:&%N;F5L)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=S:&]W(&-O;F9I9W5R871I;VX@=F%R:6%B;&5S(&9O<B!A
M;F]T:&5R(&-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]
M/B`G0TA!3B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0HI+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)SQP87)A;65T97(^(%ML87EE<ET-"D1I<W!L87ES
M('1H92!V86QU92!O9B!O;F4@8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4
M:&4-"F9I<G-T(&%R9W5M96YT(&ES('1H92!N86UE(&]F('1H92!P87)A;65T
M97(L(&%N(&]P=&EO;F%L('-E8V]N9"!A<F=U;65N=`T*;6%Y(&)E('5S960@
M=&\@=&5L;"!W:&EC:"!C;VYF:6=U<F%T:6]N(&QA>65R('1O(&QO;VL@:6XN
M("!686QI9"!C;VYF:6=U<F%T:6]N#0IL87EE<G,@87)E(")U<V5R(BP@(G-Y
M<W1E;2(@86YD(")D969A=6QT(BX@($EF(&YO(&QA>65R(&ES('-P96-I9FEE
M9"P@82!V86QU90T*=VEL;"!B92!P:6-K960@9G)O;2!T:&4@9FER<W0@;&%Y
M97(@=&AA="!D969I;F5S('1H92!P87)A;65T97(L(&EN('1H92!O<F1E<@T*
M:G5S="!S<&5C:69I960N("!4:&4@8V]N9FEG=7)A=&EO;B!V86QU92!W:6QL
M(&)E(')E=')I979E9"!F;W(@=&AE(&-H86YN96P-"G-P96-I9FEE9"!B>2!T
M:&4@9&5F875L=%]C:&%N;F5L(&-O;F9I9W5R871I;VX@=F%R:6%B;&4N#0HG
M+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-O;F9I9RUS970G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=#:&%N9V4@4V5T=&EN
M9R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O;F9I9U-E="<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C<R<L#0H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V-H86YN
M96PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=C)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W-H;W<@
M8V]N9FEG=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@8VAA;FYE;"<L
M#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=#2$%.)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"BDL#0H@("`@("`@("`@("`G9&]C)R`]/B`G
M/'!A<F%M971E<CX@/'9A;'5E/B!;;&%Y97)=#0I3971S('1H92!V86QU92!O
M9B!O;F4@8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9FER<W0@87)G
M=6UE;G0@:7,-"G1H92!N86UE(&]F('1H92!P87)A;65T97(L('1H92!S96-O
M;F0@87)G=6UE;G0@:7,@=&AE(&YE=R!V86QU92X@(%-O;64-"G!A<F%M971E
M<G,@87)E('-U8FIE8W0@=&\@=F%L:61A=&EO;BP@86YD('1H92!C;VUM86YD
M('=I;&P@9F%I;"!W:71H#0IA;B!E<G)O<B!M97-S86=E(&EF('1H92!N97<@
M=F%L=64@9&]E<R!N;W0@;6%K92!S96YS92X@($%N(&]P=&EO;F%L#0IT:&ER
M9"!A<F=U;65N="!M87D@8F4@=7-E9"!T;R!S<&5C:69Y(&EN('=H:6-H(&QA
M>65R('1O('-E="!T:&4-"F-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5&AE
M(&1E9F%U;'0@;&%Y97(@:7,@(G5S97(B+B`@5&AE#0IC;VYF:6=U<F%T:6]N
M('9A;'5E('=I;&P@8F4@<V5T(&9O<B!T:&4@8W5R<F5N="!C:&%N;F5L+"!W
M:&EC:`T*:7,@8V]N=')O;&QE9"!B>2!T:&4@9&5F875L=%]C:&%N;F5L(&-O
M;F9I9W5R871I;VX@=F%R:6%B;&4N#0HG+`T*("`@("`@("`@("`@*2P-"B`@
M("`@("`@)V-O;F9I9RUH96QP)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S
M=6UM87)Y)R`]/B`G4VAO=R!);F9O<FUA=&EO;B!!8F]U="!3971T:6YG)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0V]N9FEG2&5L<"<L#0H@
M("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C:"<L#0H@("`@("`@("`@("`G
M;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;
M<&%R86UE=&5R70T*1&ES<&QA>7,@:&5L<"!F;W(@82!C;VYF:6=U<F%T:6]N
M('!A<F%M971E<BX@(%=I=&AO=70@87)G=6UE;G1S(&ET#0ID:7-P;&%Y<R!H
M96QP(&9O<B!A;&P@8V]N9FEG=7)A=&EO;B!P87)A;65T97)S+@T*)RP-"B`@
M("`@("`@("`@*2P-"B`@("`@("`@)V-O;F9I9RUC<F5A=&4G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=#<F5A=&4@82!$969A=6QT
M(&-O;F9I9W5R871I;VX@9FEL92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG
M(#T^("=D;T-O;F9I9T-R96%T92<L#0H@("`@("`@("`@("`G<VAO<G1C=70G
M(#T^("=C;V,G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=W:6YD;W=S)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G=R<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=C<F5A=&4@82!C;VYF:6<@9FEL92!F;W(@82!W
M:6YD;W=S(&EN<W1A;&PG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<F]O="!P871H
M/B`\9FEL96YA;64^#0I#<F5A=&4@82!D969A=6QT(&-O;F9I9W5R871I;VX@
M9FEL92!W:71H(&%L;"!D:7)E8W1O<GD@8V]N9FEG=7)A=&EO;@T*=F%R:6%B
M;&5S('-E="!T;R!S=6)D:7)E8W1O<FEE<R!O9B`\<F]O="!P871H/BP@86YD
M('-A=F4@:70@87,@/&9I;&5N86UE/BX-"E1H:7,@:7,@=7-E9G5L(&5S<&5C
M:6%L;'D@9F]R(&-R96%T:6YG(&$@8V]N9FEG=7)A=&EO;B!F:6QE(&9O<B!A
M(')E;6]T90T*4$5!4B!I;G-T86QL871I;VX@*'5S:6YG('1H92`M+7)E;6]T
M96-O;F9I9R!O<'1I;VX@;V8@:6YS=&%L;"P@=7!G<F%D92P-"F%N9"!U;FEN
M<W1A;&PI+@T*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("D[#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*
M("`@("`J(%!%05)?0V]M;6%N9%]#;VYF:6<@8V]N<W1R=6-T;W(N#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%!%05)?0V]M;6%N9%]#;VYF:6<H)B1U:2P@)B1C;VYF:6<I#0H@("`@
M>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I+"`D
M8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!D
M;T-O;F9I9U-H;W<H*0T*#0H@("`@9G5N8W1I;VX@9&]#;VYF:6=3:&]W*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF
M("AI<U]A<G)A>2@D<&%R86US*2D@>PT*("`@("`@("`@("`@)&QA>65R(#T@
M:7-S970H)'!A<F%M<ULP72D@/R`D<&%R86US6S!=(#H@3E5,3#L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1L87EE<B`]($Y53$P[#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R`D<&%R86US6S!=("T^('1H92!L87EE<@T*
M("`@("`@("!I9B`H)&5R<F]R(#T@)'1H:7,M/E]C:&5C:TQA>65R*"1L87EE
M<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M8V]N9FEG+7-H;W<Z)&5R<F]R(BD[#0H@("`@("`@('T-"B`@("`@("`@)&ME
M>7,@/2`D=&AI<RT^8V]N9FEG+3YG971+97ES*"D[#0H@("`@("`@('-O<G0H
M)&ME>7,I.PT*("`@("`@("`D8VAA;FYE;"`](&ES<V5T*"1O<'1I;VYS6R=C
M:&%N;F5L)UTI(#\@)&]P=&EO;G-;)V-H86YN96PG72`Z#0H@("`@("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@
M("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@
M("`@("`@(&EF("@A)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE
M;"`B)R`N("1C:&%N;F5L("X@)R(@9&]E<R!N;W0@97AI<W0G*3L-"B`@("`@
M("`@?0T*("`@("`@("`D9&%T82`](&%R<F%Y*"=C87!T:6]N)R`]/B`G0V]N
M9FEG=7)A=&EO;B`H8VAA;FYE;"`G("X@)&-H86YN96P@+B`G*3HG*3L-"B`@
M("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PT*("`@("`@("`@("`@
M)'1Y<&4@/2`D=&AI<RT^8V]N9FEG+3YG9714>7!E*"1K97DI.PT*("`@("`@
M("`@("`@)'9A;'5E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1K97DL("1L87EE
M<BP@)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=P87-S
M=V]R9"<@)B8@)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M)RHJ*BHJ*BHJ)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M=F%L=64@/3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M)V9A;'-E)SL-"B`@("`@("`@("`@('T@96QS96EF("@D=F%L=64@/3T]('1R
M=64I('L-"B`@("`@("`@("`@("`@("`D=F%L=64@/2`G=')U92<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R1T:&ES+3YC
M;VYF:6<M/F=E=$=R;W5P*"1K97DI75M=(#T@87)R87DH)'1H:7,M/F-O;F9I
M9RT^9V5T4')O;7!T*"1K97DI("P@)&ME>2P@)'9A;'5E*3L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]N9FEG+3YG971,87EE<G,H
M*2!A<R`D;&%Y97(I('L-"B`@("`@("`@("`@("1D871A6R=D871A)UU;)T-O
M;F9I9R!&:6QE<R==6UT@/2!A<G)A>2AU8V9I<G-T*"1L87EE<BD@+B`G($-O
M;F9I9W5R871I;VX@1FEL92<L("=&:6QE;F%M92<@+"`D=&AI<RT^8V]N9FEG
M+3YG971#;VYF1FEL92@D;&%Y97(I*3L-"B`@("`@("`@?0T*#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9&]#;VYF:6='970H*0T*#0H@("`@9G5N8W1I;VX@9&]#;VYF:6='
M970H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2D@>PT*("`@("`@("`@("`@)&%R
M9W-?8VYT(#T@,#L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A
M<F=S7V-N="`@/2!C;W5N="@D<&%R86US*3L-"B`@("`@("`@?0T*#0H@("`@
M("`@('-W:71C:"`H)&%R9W-?8VYT*2![#0H@("`@("`@("`@("!C87-E(#$Z
M#0H@("`@("`@("`@("`@("`@)&-O;F9I9U]K97D@/2`D<&%R86US6S!=.PT*
M("`@("`@("`@("`@("`@("1L87EE<B`]($Y53$P[#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E(#(Z#0H@("`@("`@("`@("`@
M("`@)&-O;F9I9U]K97D@/2`D<&%R86US6S!=.PT*("`@("`@("`@("`@("`@
M("1L87EE<B`]("1P87)A;7-;,5T[#0H@("`@("`@("`@("`@("`@:68@*"1E
M<G)O<B`]("1T:&ES+3Y?8VAE8VM,87EE<B@D;&%Y97(I*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]N9FEG
M+6=E=#HD97)R;W(B*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E(#`Z#0H@("`@("`@("`@
M("!D969A=6QT.@T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B8V]N9FEG+6=E="!E>'!E8W1S(#$@;W(@,B!P87)A;65T97)S
M(BD[#0H@("`@("`@('T-"@T*("`@("`@("`D8VAA;FYE;"`](&ES<V5T*"1O
M<'1I;VYS6R=C:&%N;F5L)UTI(#\@)&]P=&EO;G-;)V-H86YN96PG72`Z("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@
M("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"@T*("`@
M("`@("!I9B`H(21R96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-H86YN96P@
M(B<@+B`D8VAA;FYE;"`N("<B(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@("`@
M('T-"@T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F-O
M;F9I9RT^9V5T*"1C;VYF:6=?:V5Y+"`D;&%Y97(L("1C:&%N;F5L*2P@)&-O
M;6UA;F0I.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!D;T-O;F9I9U-E="@I#0H-"B`@("!F=6YC
M=&EO;B!D;T-O;F9I9U-E="@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I
M#0H@("`@>PT*("`@("`@("`O+R`D<&%R86U;,%T@+3X@82!P87)A;65T97(@
M=&\@<V5T#0H@("`@("`@("\O("1P87)A;5LQ72`M/B!T:&4@=F%L=64@9F]R
M('1H92!P87)A;65T97(-"B`@("`@("`@+R\@)'!A<F%M6S)=("T^('1H92!L
M87EE<@T*("`@("`@("`D9F%I;&US9R`]("<G.PT*("`@("`@("!I9B`H<VEZ
M96]F*"1P87)A;7,I(#P@,B!\?"!S:7IE;V8H)'!A<F%M<RD@/B`S*2![#0H@
M("`@("`@("`@("`D9F%I;&US9R`N/2`B8V]N9FEG+7-E="!E>'!E8W1S(#(@
M;W(@,R!P87)A;65T97)S(CL-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1F86EL;7-G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&5R<F]R(#T@)'1H:7,M/E]C:&5C:TQA>65R*$`D<&%R86US6S)=*2D@>PT*
M("`@("`@("`@("`@)&9A:6QM<V<@+CT@)&5R<F]R.PT*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(F-O;F9I9RUS970Z)&9A:6QM<V<B
M*3L-"B`@("`@("`@?0T*("`@("`@("`D8VAA;FYE;"`](&ES<V5T*"1O<'1I
M;VYS6R=C:&%N;F5L)UTI(#\@)&]P=&EO;G-;)V-H86YN96PG72`Z#0H@("`@
M("`@("`@("`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I
M.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@("`@(&EF("@A)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA;FYE
M;"DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M0VAA;FYE;"`B)R`N("1C:&%N;F5L("X@)R(@9&]E<R!N;W0@97AI<W0G*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!A<F%M<ULP72`]/2`G9&5F875L
M=%]C:&%N;F5L)RD@>PT*("`@("`@("`@("`@:68@*"$D<F5G+3YC:&%N;F5L
M17AI<W1S*"1P87)A;7-;,5TI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@)'!A<F%M<ULQ72`N
M("<B(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I(#T](#(I('L-"B`@("`@
M("`@("`@(&%R<F%Y7W!U<V@H)'!A<F%M<RP@)W5S97(G*3L-"B`@("`@("`@
M("`@("1L87EE<B`]("=U<V5R)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1L87EE<B`]("1P87)A;7-;,ET[#0H@("`@("`@('T-"B`@("`@
M("`@87)R87E?<'5S:"@D<&%R86US+"`D8VAA;FYE;"D[#0H@("`@("`@(&EF
M("@A8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)B1T:&ES+3YC;VYF:6<L
M("=S970G*2P@)'!A<F%M<RDI#0H@("`@("`@('L-"B`@("`@("`@("`@(&%R
M<F%Y7W!O<"@D<&%R86US*3L-"B`@("`@("`@("`@("1F86EL;7-G(#T@(F-O
M;F9I9RUS970@*"(@+B!I;7!L;V1E*"(L("(L("1P87)A;7,I("X@(BD@9F%I
M;&5D+"!C:&%N;F5L("1C:&%N;F5L(CL-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-T;W)E*"1L87EE<BD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1F86EL;7-G*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&9A:6QM<V<I.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G8V]N9FEG+7-E="!S
M=6-C965D960G+"`D8V]M;6%N9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-O;F9I9TAE;'`H
M*0T*#0H@("`@9G5N8W1I;VX@9&]#;VYF:6=(96QP*"1C;VUM86YD+"`D;W!T
M:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D<&%R
M86US*2D@>PT*("`@("`@("`@("`@)'!A<F%M<R`]("1T:&ES+3YC;VYF:6<M
M/F=E=$ME>7,H*3L-"B`@("`@("`@?0T*("`@("`@("`D9&%T85LG8V%P=&EO
M;B==("`](")#;VYF:6<@:&5L<"(@+B`H*&-O=6YT*"1P87)A;7,I(#T](#$I
M(#\@(B!F;W(@)'!A<F%M<ULP72(@.B`G)RD[#0H@("`@("`@("1D871A6R=H
M96%D;&EN92==(#T@87)R87DH)TYA;64G+"`G5'EP92<L("=$97-C<FEP=&EO
M;B<I.PT*("`@("`@("`D9&%T85LG8F]R9&5R)UT@("`]('1R=64[#0H@("`@
M("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&YA;64I('L-"B`@("`@("`@("`@
M("1T>7!E(#T@)'1H:7,M/F-O;F9I9RT^9V5T5'EP92@D;F%M92D[#0H@("`@
M("`@("`@("`D9&]C<R`]("1T:&ES+3YC;VYF:6<M/F=E=$1O8W,H)&YA;64I
M.PT*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=S970G*2![#0H@("`@("`@
M("`@("`@("`@)&1O8W,@/2!R=')I;2@D9&]C<RD@+B`B7&Y686QI9"!S970Z
M("(@+@T*("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<@)RP@)'1H:7,M
M/F-O;F9I9RT^9V5T4V5T5F%L=65S*"1N86UE*2D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D;F%M92P@
M)'1Y<&4L("1D;V-S*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@9&]#;VYF:6=#<F5A=&4H*0T*#0H@("`@9G5N
M8W1I;VX@9&]#;VYF:6=#<F5A=&4H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0T*("`@('L-"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I("$](#(I
M('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=C;VYF
M:6<M8W)E871E.B!M=7-T(&AA=F4@,B!P87)A;65T97)S+"!R;V]T('!A=&@@
M86YD("<@+@T*("`@("`@("`@("`@("`@("=F:6QE;F%M92!T;R!S879E(&%S
M)RD[#0H@("`@("`@('T-"B`@("`@("`@)')O;W0@/2`D<&%R86US6S!=.PT*
M("`@("`@("`O+R!#;&5A;B!U<"!T:&4@1$E214-43U)97U-%4$%2051/4B!M
M97-S#0H@("`@("`@("1D<S(@/2!$25)%0U1/4EE?4T5005)!5$]2("X@1$E2
M14-43U)97U-%4$%2051/4CL-"B`@("`@("`@)')O;W0@/2!P<F5G7W)E<&QA
M8V4H87)R87DH)R%<7%Q<*R$G+"`G(2\K(2<L("(A)&1S,BLA(BDL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"<O)RP@)R\G+"`G+R<I
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;V]T*3L-"B`@("`@
M("`@:68@*"1R;V]T>S!]("$]("<O)RD@>PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=W:6YD;W=S)UTI*2![#0H@("`@("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"<O7EM!+5IA+7I=.B\G+"`D<F]O="DI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U)O
M;W0@9&ER96-T;W)Y(&UU<W0@8F4@86X@86)S;VQU=&4@<&%T:"!B96=I;FYI
M;F<@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G=VET:"`B7%PB(&]R
M(")#.EQ<(BP@=V%S.B`B)R`N("1R;V]T("X@)R(G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=2;V]T(&1I<F5C=&]R>2!M=7-T
M(&)E(&%N(&%B<V]L=71E('!A=&@@8F5G:6YN:6YG("<@+@T*("`@("`@("`@
M("`@("`@("`@("`G=VET:"`B+R(L('=A<SH@(B<@+B`D<F]O="`N("<B)RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'=I;F1O=W,@
M/2!I<W-E="@D;W!T:6]N<ULG=VEN9&]W<R==*3L-"B`@("`@("`@:68@*"1W
M:6YD;W=S*2![#0H@("`@("`@("`@("`D<F]O="`]('-T<E]R97!L86-E*"<O
M)RP@)UQ<)RP@)')O;W0I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)'!A<F%M<ULQ72DI('L-"B`@("`@("`@("`@(&EF("@A0'1O
M=6-H*"1P87)A;7-;,5TI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!C<F5A=&4@(B<@+B`D<&%R86US
M6S%=("X@)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D<&%R86US6S%=(#T@<F5A;'!A=&@H)'!A<F%M<ULQ72D[#0H@("`@("`@
M("1C;VYF:6<@/2`F;F5W(%!%05)?0V]N9FEG*"1P87)A;7-;,5TL("<C;F\C
M<WES=&5M(V-O;F9I9R,G+"!F86QS92P@9F%L<V4I.PT*("`@("`@("!I9B`H
M)')O;W1[<W1R;&5N*"1R;V]T*2`M(#%](#T]("<O)RD@>PT*("`@("`@("`@
M("`@)')O;W0@/2!S=6)S='(H)')O;W0L(#`L('-T<FQE;B@D<F]O="D@+2`Q
M*3L-"B`@("`@("`@?0T*("`@("`@("`D8V]N9FEG+3YN;U)E9VES=')Y*"D[
M#0H@("`@("`@("1C;VYF:6<M/G-E="@G<&AP7V1I<B<L("1W:6YD;W=S(#\@
M(B1R;V]T7%QP96%R7%QP:'`B(#H@(B1R;V]T+W!E87(O<&AP(BP@)W5S97(G
M*3L-"B`@("`@("`@)&-O;F9I9RT^<V5T*"=D871A7V1I<B<L("1W:6YD;W=S
M(#\@(B1R;V]T7%QP96%R7%QD871A(B`Z("(D<F]O="]P96%R+V1A=&$B*3L-
M"B`@("`@("`@)&-O;F9I9RT^<V5T*"=E>'1?9&ER)RP@)'=I;F1O=W,@/R`B
M)')O;W1<7'!E87)<7&5X="(@.B`B)')O;W0O<&5A<B]E>'0B*3L-"B`@("`@
M("`@)&-O;F9I9RT^<V5T*"=D;V-?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<
M7'!E87)<7&1O8W,B(#H@(B1R;V]T+W!E87(O9&]C<R(I.PT*("`@("`@("`D
M8V]N9FEG+3YS970H)W1E<W1?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<7'!E
M87)<7'1E<W1S(B`Z("(D<F]O="]P96%R+W1E<W1S(BD[#0H@("`@("`@("1C
M;VYF:6<M/G-E="@G8V%C:&5?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<7'!E
M87)<7&-A8VAE(B`Z("(D<F]O="]P96%R+V-A8VAE(BD[#0H@("`@("`@("1C
M;VYF:6<M/G-E="@G8FEN7V1I<B<L("1W:6YD;W=S(#\@(B1R;V]T7%QP96%R
M(B`Z("(D<F]O="]P96%R(BD[#0H@("`@("`@("1C;VYF:6<M/G=R:71E0V]N
M9FEG1FEL92@I.PT*("`@("`@("`D=&AI<RT^7W-H;W=#;VYF:6<H)&-O;F9I
M9RD[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G4W5C8V5S<V9U
M;&QY(&-R96%T960@9&5F875L="!C;VYF:6=U<F%T:6]N(&9I;&4@(B<@+B`D
M<&%R86US6S%=("X@)R(G+`T*("`@("`@("`@("`@)&-O;6UA;F0I.PT*("`@
M('T-"@T*("`@("\O('U]?0T*#0H@("`@9G5N8W1I;VX@7W-H;W=#;VYF:6<H
M)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("`D<&%R86US(#T@87)R87DH)W5S
M97(G*3L-"B`@("`@("`@)&ME>7,@/2`D8V]N9FEG+3YG971+97ES*"D[#0H@
M("`@("`@('-O<G0H)&ME>7,I.PT*("`@("`@("`D8VAA;FYE;"`]("=P96%R
M+G!H<"YN970G.PT*("`@("`@("`D9&%T82`](&%R<F%Y*"=C87!T:6]N)R`]
M/B`G0V]N9FEG=7)A=&EO;B`H8VAA;FYE;"`G("X@)&-H86YN96P@+B`G*3HG
M*3L-"B`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PT*("`@("`@
M("`@("`@)'1Y<&4@/2`D8V]N9FEG+3YG9714>7!E*"1K97DI.PT*("`@("`@
M("`@("`@)'9A;'5E(#T@)&-O;F9I9RT^9V5T*"1K97DL("=U<V5R)RP@)&-H
M86YN96PI.PT*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=P87-S=V]R9"<@
M)B8@)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)RHJ*BHJ
M*BHJ)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D=F%L=64@
M/3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)V9A;'-E
M)SL-"B`@("`@("`@("`@('T@96QS96EF("@D=F%L=64@/3T]('1R=64I('L-
M"B`@("`@("`@("`@("`@("`D=F%L=64@/2`G=')U92<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R1C;VYF:6<M/F=E=$=R
M;W5P*"1K97DI75M=(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@D8V]N9FEG
M+3YG9710<F]M<'0H)&ME>2D@+"`D:V5Y+"`D=F%L=64I.PT*("`@("`@("!]
M#0H@("`@("`@(&9O<F5A8V@@*"1C;VYF:6<M/F=E=$QA>65R<R@I(&%S("1L
M87EE<BD@>PT*("`@("`@("`@("`@)&1A=&%;)V1A=&$G75LG0V]N9FEG($9I
M;&5S)UU;72`]#0H@("`@("`@("`@("`@("`@87)R87DH=6-F:7)S="@D;&%Y
M97(I("X@)R!#;VYF:6=U<F%T:6]N($9I;&4G+"`G1FEL96YA;64G("P-"B`@
M("`@("`@("`@("`@("`@("`@)&-O;F9I9RT^9V5T0V]N9D9I;&4H)&QA>65R
M*2D[#0H@("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)&1A=&$L("=C;VYF:6<M<VAO=R<I.PT*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H@("`@+R\@>WM[(%]C:&5C:TQA>65R*"D-"@T*("`@("\J
M*@T*("`@("`J($-H96-K<R!I9B!A(&QA>65R(&ES(&1E9FEN960@;W(@;F]T
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1L87EE<B!4:&4@;&%Y
M97(@=&\@<V5A<F-H(&9O<@T*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@
M;VX@;F\@97)R;W(@;W(@=&AE(&5R<F]R(&UE<W-A9V4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?8VAE8VM,87EE<B@D;&%Y97(@/2!N=6QL*0T*("`@('L-
M"B`@("`@("`@:68@*"%E;7!T>2@D;&%Y97(I("8F("1L87EE<B`A/2`G9&5F
M875L="<I('L-"B`@("`@("`@("`@("1L87EE<G,@/2`D=&AI<RT^8V]N9FEG
M+3YG971,87EE<G,H*3L-"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)&QA
M>65R+"`D;&%Y97)S*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`B(&]N
M;'D@=&AE(&QA>65R<SH@7"(B("X@:6UP;&]D92@G(B!O<B`B)RP@)&QA>65R
M<RD@+B`B7"(@87)E('-U<'!O<G1E9"([#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O
M('U]?0T*?0T*#0H_/@T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]);G-T
M86QL+GAM;```````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W-C`T`#$P
M-3$U-#,Q,#4W`#`R,38P-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\:6YS
M=&%L;#X-"B`@/'-U;6UA<GD^26YS=&%L;"!086-K86=E/"]S=6UM87)Y/@T*
M("`\9G5N8W1I;VX^9&]);G-T86QL/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T
M/FD\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QF;W)C93X-"B`@("`\
M<VAO<G1O<'0^9CPO<VAO<G1O<'0^#0H@("`@/&1O8SYW:6QL(&]V97)W<FET
M92!N97=E<B!I;G-T86QL960@<&%C:V%G97,\+V1O8SX-"B`@(#PO9F]R8V4^
M#0H@("`\;&]O<V4^#0H@("`@/'-H;W)T;W!T/FP\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^9&\@;F]T(&-H96-K(&9O<B!R96-O;6UE;F1E9"!D97!E;F1E;F-Y
M('9E<G-I;VX\+V1O8SX-"B`@(#PO;&]O<V4^#0H@("`\;F]D97!S/@T*("`@
M(#QS:&]R=&]P=#YN/"]S:&]R=&]P=#X-"B`@("`\9&]C/FEG;F]R92!D97!E
M;F1E;F-I97,L(&EN<W1A;&P@86YY=V%Y/"]D;V,^#0H@("`\+VYO9&5P<SX-
M"B`@(#QR96=I<W1E<BUO;FQY/@T*("`@(#QS:&]R=&]P=#YR/"]S:&]R=&]P
M=#X-"B`@("`\9&]C/F1O(&YO="!I;G-T86QL(&9I;&5S+"!O;FQY(')E9VES
M=&5R('1H92!P86-K86=E(&%S(&EN<W1A;&QE9#PO9&]C/@T*("`@/"]R96=I
M<W1E<BUO;FQY/@T*("`@/'-O9G0^#0H@("`@/'-H;W)T;W!T/G,\+W-H;W)T
M;W!T/@T*("`@(#QD;V,^<V]F="!I;G-T86QL+"!F86EL('-I;&5N=&QY+"!O
M<B!U<&=R861E(&EF(&%L<F5A9'D@:6YS=&%L;&5D/"]D;V,^#0H@("`\+W-O
M9G0^#0H@("`\;F]B=6EL9#X-"B`@("`\<VAO<G1O<'0^0CPO<VAO<G1O<'0^
M#0H@("`@/&1O8SYD;VXF87!O<SMT(&)U:6QD($,@97AT96YS:6]N<SPO9&]C
M/@T*("`@/"]N;V)U:6QD/@T*("`@/&YO8V]M<')E<W,^#0H@("`@/'-H;W)T
M;W!T/EH\+W-H;W)T;W!T/@T*("`@(#QD;V,^<F5Q=65S="!U;F-O;7!R97-S
M960@9FEL97,@=VAE;B!D;W=N;&]A9&EN9SPO9&]C/@T*("`@/"]N;V-O;7!R
M97-S/@T*("`@/&EN<W1A;&QR;V]T/@T*("`@(#QS:&]R=&]P=#Y2/"]S:&]R
M=&]P=#X-"B`@("`\87)G/D1)4CPO87)G/@T*("`@(#QD;V,^<F]O="!D:7)E
M8W1O<GD@=7-E9"!W:&5N(&EN<W1A;&QI;F<@9FEL97,@*&%L82!02%`F87!O
M<SMS($E.4U1!3$Q?4D]/5"D\+V1O8SX-"B`@(#PO:6YS=&%L;')O;W0^#0H@
M("`\:6=N;W)E+65R<F]R<SX-"B`@("`\9&]C/F9O<F-E(&EN<W1A;&P@979E
M;B!I9B!T:&5R92!W97)E(&5R<F]R<SPO9&]C/@T*("`@/"]I9VYO<F4M97)R
M;W)S/@T*("`@/&%L;&1E<',^#0H@("`@/'-H;W)T;W!T/F$\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^:6YS=&%L;"!A;&P@<F5Q=6ER960@86YD(&]P=&EO;F%L
M(&1E<&5N9&5N8VEE<SPO9&]C/@T*("`@/"]A;&QD97!S/@T*("`@/&]N;'ER
M97%D97!S/@T*("`@(#QS:&]R=&]P=#YO/"]S:&]R=&]P=#X-"B`@("`\9&]C
M/FEN<W1A;&P@86QL(')E<75I<F5D(&1E<&5N9&5N8VEE<SPO9&]C/@T*("`@
M/"]O;FQY<F5Q9&5P<SX-"B`@(#QO9F9L:6YE/@T*("`@(#QS:&]R=&]P=#Y/
M/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!A='1E;7!T('1O(&1O=VYL
M;V%D(&%N>2!U<FQS(&]R(&-O;G1A8W0@8VAA;FYE;',\+V1O8SX-"B`@(#PO
M;V9F;&EN93X-"B`@(#QP<F5T96YD/@T*("`@(#QS:&]R=&]P=#YP/"]S:&]R
M=&]P=#X-"B`@("`\9&]C/D]N;'D@;&ES="!T:&4@<&%C:V%G97,@=&AA="!W
M;W5L9"!B92!D;W=N;&]A9&5D/"]D;V,^#0H@("`\+W!R971E;F0^#0H@(#PO
M;W!T:6]N<SX-"B`@/&1O8SY;8VAA;FYE;"]=)FQT.W!A8VMA9V4F9W0[("XN
M+@T*26YS=&%L;',@;VYE(&]R(&UO<F4@4$5!4B!P86-K86=E<RX@(%EO=2!C
M86X@<W!E8VEF>2!A('!A8VMA9V4@=&\-"FEN<W1A;&P@:6X@9F]U<B!W87ES
M.@T*#0HF<75O=#M086-K86=E+3$N,"YT9WHF<75O=#L@.B!I;G-T86QL<R!F
M<F]M(&$@;&]C86P@9FEL90T*#0HF<75O=#MH='1P.B\O97AA;7!L92YC;VTO
M4&%C:V%G92TQ+C`N=&=Z)G%U;W0[(#H@:6YS=&%L;',@9G)O;0T*86YY=VAE
M<F4@;VX@=&AE(&YE="X-"@T*)G%U;W0[<&%C:V%G92YX;6PF<75O=#L@.B!I
M;G-T86QL<R!T:&4@<&%C:V%G92!D97-C<FEB960@:6X-"G!A8VMA9V4N>&UL
M+B`@57-E9G5L(&9O<B!T97-T:6YG+"!O<B!F;W(@=W)A<'!I;F<@82!014%2
M('!A8VMA9V4@:6X-"F%N;W1H97(@<&%C:V%G92!M86YA9V5R('-U8V@@87,@
M4E!-+@T*#0HF<75O=#M086-K86=E6RUV97)S:6]N+W-T871E75LN=&%R729Q
M=6]T.R`Z('%U97)I97,@>6]U<B!D969A=6QT(&-H86YN96PF87!O<SMS('-E
M<G9E<@T**'MC;VYF:6<@;6%S=&5R7W-E<G9E<GTI(&%N9"!D;W=N;&]A9',@
M=&AE(&YE=V5S="!P86-K86=E('=I=&@-"G1H92!P<F5F97)R960@<75A;&ET
M>2]S=&%T92`H>V-O;F9I9R!P<F5F97)R961?<W1A=&5]*2X-"@T*5&\@<F5T
M<FEE=F4@4&%C:V%G92!V97)S:6]N(#$N,2P@=7-E("9Q=6]T.U!A8VMA9V4M
M,2XQ+"9Q=6]T.R!T;R!R971R:65V90T*4&%C:V%G92!S=&%T92!B971A+"!U
M<V4@)G%U;W0[4&%C:V%G92UB971A+B9Q=6]T.R`@5&\@<F5T<FEE=F4@86X@
M=6YC;VUP<F5S<V5D#0IF:6QE+"!A<'!E;F0@+G1A<B`H;6%K92!S=7)E('1H
M97)E(&ES(&YO(&9I;&4@8GD@=&AE('-A;64@;F%M92!F:7)S="D-"@T*5&\@
M9&]W;FQO860@82!P86-K86=E(&9R;VT@86YO=&AE<B!C:&%N;F5L+"!P<F5F
M:7@@=VET:"!T:&4@8VAA;FYE;"!N86UE(&QI:V4-"B9Q=6]T.V-H86YN96PO
M4&%C:V%G929Q=6]T.PT*#0I-;W)E('1H86X@;VYE('!A8VMA9V4@;6%Y(&)E
M('-P96-I9FEE9"!A="!O;F-E+B`@270@:7,@;VL@=&\@;6EX('1H97-E#0IF
M;W5R('=A>7,@;V8@<W!E8VEF>6EN9R!P86-K86=E<RX-"CPO9&]C/@T*(#PO
M:6YS=&%L;#X-"B`\=7!G<F%D93X-"B`@/'-U;6UA<GD^57!G<F%D92!086-K
M86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]);G-T86QL/"]F=6YC=&EO
M;CX-"B`@/'-H;W)T8W5T/G5P/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@
M("`\9F]R8V4^#0H@("`@/'-H;W)T;W!T/F8\+W-H;W)T;W!T/@T*("`@(#QD
M;V,^;W9E<G=R:71E(&YE=V5R(&EN<W1A;&QE9"!P86-K86=E<SPO9&]C/@T*
M("`@/"]F;W)C93X-"B`@(#QL;V]S93X-"B`@("`\<VAO<G1O<'0^;#PO<VAO
M<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@8VAE8VL@9F]R(')E8V]M;65N9&5D
M(&1E<&5N9&5N8WD@=F5R<VEO;CPO9&]C/@T*("`@/"]L;V]S93X-"B`@(#QN
M;V1E<',^#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M:6=N;W)E(&1E<&5N9&5N8VEE<RP@=7!G<F%D92!A;GEW87D\+V1O8SX-"B`@
M(#PO;F]D97!S/@T*("`@/')E9VES=&5R+6]N;'D^#0H@("`@/'-H;W)T;W!T
M/G(\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T(&EN<W1A;&P@9FEL97,L
M(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@=7!G<F%D960\+V1O8SX-
M"B`@(#PO<F5G:7-T97(M;VYL>3X-"B`@(#QN;V)U:6QD/@T*("`@(#QS:&]R
M=&]P=#Y"/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O;B9A<&]S.W0@8G5I;&0@
M0R!E>'1E;G-I;VYS/"]D;V,^#0H@("`\+VYO8G5I;&0^#0H@("`\;F]C;VUP
M<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^#0H@("`@/&1O8SYR
M97%U97-T('5N8V]M<')E<W-E9"!F:6QE<R!W:&5N(&1O=VYL;V%D:6YG/"]D
M;V,^#0H@("`\+VYO8V]M<')E<W,^#0H@("`\:6YS=&%L;')O;W0^#0H@("`@
M/'-H;W)T;W!T/E(\+W-H;W)T;W!T/@T*("`@(#QA<F<^1$E2/"]A<F<^#0H@
M("`@/&1O8SYR;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS=&%L;&EN9R!F
M:6QE<R`H86QA(%!(4"9A<&]S.W,@24Y35$%,3%]23T]4*3PO9&]C/@T*("`@
M/"]I;G-T86QL<F]O=#X-"B`@(#QI9VYO<F4M97)R;W)S/@T*("`@(#QD;V,^
M9F]R8V4@:6YS=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S/"]D;V,^
M#0H@("`\+VEG;F]R92UE<G)O<G,^#0H@("`\86QL9&5P<SX-"B`@("`\<VAO
M<G1O<'0^83PO<VAO<G1O<'0^#0H@("`@/&1O8SYI;G-T86QL(&%L;"!R97%U
M:7)E9"!A;F0@;W!T:6]N86P@9&5P96YD96YC:65S/"]D;V,^#0H@("`\+V%L
M;&1E<',^#0H@("`\;VYL>7)E<61E<',^#0H@("`@/'-H;W)T;W!T/F\\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^:6YS=&%L;"!A;&P@<F5Q=6ER960@9&5P96YD
M96YC:65S/"]D;V,^#0H@("`\+V]N;'ER97%D97!S/@T*("`@/&]F9FQI;F4^
M#0H@("`@/'-H;W)T;W!T/D\\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T
M(&%T=&5M<'0@=&\@9&]W;FQO860@86YY('5R;',@;W(@8V]N=&%C="!C:&%N
M;F5L<SPO9&]C/@T*("`@/"]O9F9L:6YE/@T*("`@/'!R971E;F0^#0H@("`@
M/'-H;W)T;W!T/G`\+W-H;W)T;W!T/@T*("`@(#QD;V,^3VYL>2!L:7-T('1H
M92!P86-K86=E<R!T:&%T('=O=6QD(&)E(&1O=VYL;V%D960\+V1O8SX-"B`@
M(#PO<')E=&5N9#X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/B9L=#MP86-K86=E
M)F=T.R`N+BX-"E5P9W)A9&5S(&]N92!O<B!M;W)E(%!%05(@<&%C:V%G97,N
M("!3964@9&]C=6UE;G1A=&EO;B!F;W(@=&AE#0HF<75O=#MI;G-T86QL)G%U
M;W0[(&-O;6UA;F0@9F]R('=A>7,@=&\@<W!E8VEF>2!A('!A8VMA9V4N#0H-
M"E=H96X@=7!G<F%D:6YG+"!Y;W5R('!A8VMA9V4@=VEL;"!B92!U<&1A=&5D
M(&EF('1H92!P<F]V:61E9"!N97<-"G!A8VMA9V4@:&%S(&$@:&EG:&5R('9E
M<G-I;VX@;G5M8F5R("AU<V4@=&AE("UF(&]P=&EO;B!I9B!Y;W4@;F5E9"!T
M;PT*=7!G<F%D92!A;GEW87DI+@T*#0I-;W)E('1H86X@;VYE('!A8VMA9V4@
M;6%Y(&)E('-P96-I9FEE9"!A="!O;F-E+@T*/"]D;V,^#0H@/"]U<&=R861E
M/@T*(#QU<&=R861E+6%L;#X-"B`@/'-U;6UA<GD^57!G<F%D92!!;&P@4&%C
M:V%G97,\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TEN<W1A;&P\+V9U;F-T
M:6]N/@T*("`\<VAO<G1C=70^=6$\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-
M"B`@(#QN;V1E<',^#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^:6=N;W)E(&1E<&5N9&5N8VEE<RP@=7!G<F%D92!A;GEW87D\+V1O
M8SX-"B`@(#PO;F]D97!S/@T*("`@/')E9VES=&5R+6]N;'D^#0H@("`@/'-H
M;W)T;W!T/G(\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T(&EN<W1A;&P@
M9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@=7!G<F%D960\
M+V1O8SX-"B`@(#PO<F5G:7-T97(M;VYL>3X-"B`@(#QN;V)U:6QD/@T*("`@
M(#QS:&]R=&]P=#Y"/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O;B9A<&]S.W0@
M8G5I;&0@0R!E>'1E;G-I;VYS/"]D;V,^#0H@("`\+VYO8G5I;&0^#0H@("`\
M;F]C;VUP<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^#0H@("`@
M/&1O8SYR97%U97-T('5N8V]M<')E<W-E9"!F:6QE<R!W:&5N(&1O=VYL;V%D
M:6YG/"]D;V,^#0H@("`\+VYO8V]M<')E<W,^#0H@("`\:6YS=&%L;')O;W0^
M#0H@("`@/'-H;W)T;W!T/E(\+W-H;W)T;W!T/@T*("`@(#QA<F<^1$E2/"]A
M<F<^#0H@("`@/&1O8SYR;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS=&%L
M;&EN9R!F:6QE<R`H86QA(%!(4"9A<&]S.W,@24Y35$%,3%]23T]4*3PO9&]C
M/@T*("`@/"]I;G-T86QL<F]O=#X-"B`@(#QI9VYO<F4M97)R;W)S/@T*("`@
M(#QD;V,^9F]R8V4@:6YS=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S
M/"]D;V,^#0H@("`\+VEG;F]R92UE<G)O<G,^#0H@("`\;&]O<V4^#0H@("`@
M/&1O8SYD;R!N;W0@8VAE8VL@9F]R(')E8V]M;65N9&5D(&1E<&5N9&5N8WD@
M=F5R<VEO;CPO9&]C/@T*("`@/"]L;V]S93X-"B`@/"]O<'1I;VYS/@T*("`\
M9&]C/@T*57!G<F%D97,@86QL('!A8VMA9V5S('1H870@:&%V92!A(&YE=V5R
M(')E;&5A<V4@879A:6QA8FQE+B`@57!G<F%D97,@87)E#0ID;VYE(&]N;'D@
M:68@=&AE<F4@:7,@82!R96QE87-E(&%V86EL86)L92!O9B!T:&4@<W1A=&4@
M<W!E8VEF:65D(&EN#0HF<75O=#MP<F5F97)R961?<W1A=&4F<75O=#L@*&-U
M<G)E;G1L>2![8V]N9FEG('!R969E<G)E9%]S=&%T97TI+"!O<B!A('-T871E
M(&-O;G-I9&5R960-"FUO<F4@<W1A8FQE+@T*/"]D;V,^#0H@/"]U<&=R861E
M+6%L;#X-"B`\=6YI;G-T86QL/@T*("`\<W5M;6%R>3Y5;BUI;G-T86QL(%!A
M8VMA9V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U5N:6YS=&%L;#PO9G5N
M8W1I;VX^#0H@(#QS:&]R=&-U=#YU;CPO<VAO<G1C=70^#0H@(#QO<'1I;VYS
M/@T*("`@/&YO9&5P<SX-"B`@("`\<VAO<G1O<'0^;CPO<VAO<G1O<'0^#0H@
M("`@/&1O8SYI9VYO<F4@9&5P96YD96YC:65S+"!U;FEN<W1A;&P@86YY=V%Y
M/"]D;V,^#0H@("`\+VYO9&5P<SX-"B`@(#QR96=I<W1E<BUO;FQY/@T*("`@
M(#QS:&]R=&]P=#YR/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!R96UO
M=F4@9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V5S(&%S(&YO="!I
M;G-T86QL960\+V1O8SX-"B`@(#PO<F5G:7-T97(M;VYL>3X-"B`@(#QI;G-T
M86QL<F]O=#X-"B`@("`\<VAO<G1O<'0^4CPO<VAO<G1O<'0^#0H@("`@/&%R
M9SY$25(\+V%R9SX-"B`@("`\9&]C/G)O;W0@9&ER96-T;W)Y('5S960@=VAE
M;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A0)F%P;W,[<R!)3E-404Q,7U)/
M3U0I/"]D;V,^#0H@("`\+VEN<W1A;&QR;V]T/@T*("`@/&EG;F]R92UE<G)O
M<G,^#0H@("`@/&1O8SYF;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R
M92!E<G)O<G,\+V1O8SX-"B`@(#PO:6=N;W)E+65R<F]R<SX-"B`@(#QO9F9L
M:6YE/@T*("`@(#QS:&]R=&]P=#Y//"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O
M(&YO="!A='1E;7!T('1O('5N:6YS=&%L;"!R96UO=&5L>3PO9&]C/@T*("`@
M/"]O9F9L:6YE/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^6V-H86YN96PO729L
M=#MP86-K86=E)F=T.R`N+BX-"E5N:6YS=&%L;',@;VYE(&]R(&UO<F4@4$5!
M4B!P86-K86=E<RX@($UO<F4@=&AA;B!O;F4@<&%C:V%G92!M87D@8F4-"G-P
M96-I9FEE9"!A="!O;F-E+B`@4')E9FEX('=I=&@@8VAA;FYE;"!N86UE('1O
M('5N:6YS=&%L;"!F<F]M(&$-"F-H86YN96P@;F]T(&EN('EO=7(@9&5F875L
M="!C:&%N;F5L("A[8V]N9FEG(&1E9F%U;'1?8VAA;FYE;'TI#0H\+V1O8SX-
M"B`\+W5N:6YS=&%L;#X-"B`\8G5N9&QE/@T*("`\<W5M;6%R>3Y5;G!A8VMS
M(&$@4&5C;"!086-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]"=6YD
M;&4\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8G5N/"]S:&]R=&-U=#X-"B`@
M/&]P=&EO;G,^#0H@("`\9&5S=&EN871I;VX^#0H@("`@/'-H;W)T;W!T/F0\
M+W-H;W)T;W!T/@T*("`@(#QA<F<^1$E2/"]A<F<^#0H@("`@/&1O8SY/<'1I
M;VYA;"!D97-T:6YA=&EO;B!D:7)E8W1O<GD@9F]R('5N<&%C:VEN9R`H9&5F
M875L=',@=&\@8W5R<F5N="!P871H(&]R("9Q=6]T.V5X="9Q=6]T.R!I9B!E
M>&ES=',I/"]D;V,^#0H@("`\+V1E<W1I;F%T:6]N/@T*("`@/&9O<F-E/@T*
M("`@(#QS:&]R=&]P=#YF/"]S:&]R=&]P=#X-"B`@("`\9&]C/D9O<F-E('1H
M92!U;G!A8VMI;F<@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R!I;B!T:&4@
M<&%C:V%G93PO9&]C/@T*("`@/"]F;W)C93X-"B`@/"]O<'1I;VYS/@T*("`\
M9&]C/B9L=#MP86-K86=E)F=T.PT*56YP86-K<R!A(%!E8VP@4&%C:V%G92!I
M;G1O('1H92!S96QE8W1E9"!L;V-A=&EO;BX@270@=VEL;"!D;W=N;&]A9"!T
M:&4-"G!A8VMA9V4@:68@;F5E9&5D+@T*/"]D;V,^#0H@/"]B=6YD;&4^#0H@
M/')U;BUS8W)I<'1S/@T*("`\<W5M;6%R>3Y2=6X@4&]S="U);G-T86QL(%-C
M<FEP=',@8G5N9&QE9"!W:71H(&$@<&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U
M;F-T:6]N/F1O4G5N4V-R:7!T<SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YR
M<SPO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.W!A8VMA
M9V4F9W0[#0I2=6X@<&]S="UI;G-T86QL871I;VX@<V-R:7!T<R!I;B!P86-K
M86=E("9L=#MP86-K86=E)F=T.RP@:68@86YY(&5X:7-T+@T*/"]D;V,^#0H@
M/"]R=6XM<V-R:7!T<SX-"CPO8V]M;6%N9',^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+T-O;6UA;F0O26YS=&%L;"YP:'``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$P,3$T-0`Q,#4Q-30S,3`U-P`P,C$U-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\J*@T*
M("H@4$5!4E]#;VUM86YD7TEN<W1A;&P@*&EN<W1A;&PL('5P9W)A9&4L('5P
M9W)A9&4M86QL+"!U;FEN<W1A;&PL(&)U;F1L92P@<G5N+7-C<FEP=',@8V]M
M;6%N9',I#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($EN
M<W1A;&PN<&AP+'8@,2XQ,34@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*
M+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!I;G-T86QL871I;VX@;W(@9&5I
M;G-T86QL871I;VXO=7!G<F%D:6YG(&]F#0H@*B!P86-K86=E<RX-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E
M(#`N,0T*("HO#0IC;&%S<R!014%27T-O;6UA;F1?26YS=&%L;"!E>'1E;F1S
M(%!%05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE
M<PT*#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G:6YS
M=&%L;"<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)TEN
M<W1A;&P@4&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;TEN<W1A;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G:2<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@)V9O<F-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G9B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=W:6QL(&]V97)W<FET92!N97=E<B!I;G-T86QL960@<&%C:V%G97,G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=L;V]S
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)VPG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T
M(&-H96-K(&9O<B!R96-O;6UE;F1E9"!D97!E;F1E;F-Y('9E<G-I;VXG+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=N;V1E
M<',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=N)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)VEG;F]R
M92!D97!E;F1E;F-I97,L(&EN<W1A;&P@86YY=V%Y)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5G:7-T97(M;VYL>2<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)W(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&EN
M<W1A;&P@9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@:6YS
M=&%L;&5D)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`G<V]F="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)W,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G<V]F="!I;G-T86QL+"!F86EL('-I;&5N=&QY+"!O<B!U<&=R861E(&EF
M(&%L<F5A9'D@:6YS=&%L;&5D)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G;F]B=6EL9"<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)T(G+`T*("`@("`@("`@("`@
M("`@("`@("`G9&]C)R`]/B`G9&]N7"=T(&)U:6QD($,@97AT96YS:6]N<R<L
M#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)VYO
M8V]M<')E<W,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO
M<G1O<'0G(#T^("=:)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)W)E<75E<W0@=6YC;VUP<F5S<V5D(&9I;&5S('=H96X@9&]W;FQO861I;F<G
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I
M;G-T86QL<F]O="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)U(G+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]
M/B`G1$E2)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)O;W0@
M9&ER96-T;W)Y('5S960@=VAE;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A0
M7"=S($E.4U1!3$Q?4D]/5"DL('5S92!P86-K86=I;F=R;V]T(&9O<B!24$TG
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=P
M86-K86=I;F=R;V]T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G4"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G
M(#T^("=$25(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<F]O
M="!D:7)E8W1O<GD@=7-E9"!W:&5N('!A8VMA9VEN9R!F:6QE<RP@;&EK92!2
M4$T@<&%C:V%G:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`G:6=N;W)E+65R<F]R<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=F;W)C92!I;G-T86QL(&5V96X@:68@
M=&AE<F4@=V5R92!E<G)O<G,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("=A;&QD97!S)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G82<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=I;G-T86QL(&%L;"!R97%U:7)E9"!A;F0@;W!T
M:6]N86P@9&5P96YD96YC:65S)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G;VYL>7)E<61E<',G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=O)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)VEN<W1A;&P@86QL(')E<75I<F5D(&1E
M<&5N9&5N8VEE<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@
M("`@("`@("`@)V]F9FQI;F4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=/)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)V1O(&YO="!A='1E;7!T('1O(&1O=VYL;V%D(&%N>2!U<FQS
M(&]R(&-O;G1A8W0@8VAA;FYE;',G+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=P<F5T96YD)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<"<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=/;FQY(&QI<W0@=&AE('!A8VMA9V5S('1H
M870@=V]U;&0@8F4@9&]W;FQO861E9"<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("=;8VAA;FYE;"]=/'!A8VMA9V4^("XN+@T*26YS=&%L;',@;VYE(&]R(&UO
M<F4@4$5!4B!P86-K86=E<RX@(%EO=2!C86X@<W!E8VEF>2!A('!A8VMA9V4@
M=&\-"FEN<W1A;&P@:6X@9F]U<B!W87ES.@T*#0HB4&%C:V%G92TQ+C`N=&=Z
M(B`Z(&EN<W1A;&QS(&9R;VT@82!L;V-A;"!F:6QE#0H-"B)H='1P.B\O97AA
M;7!L92YC;VTO4&%C:V%G92TQ+C`N=&=Z(B`Z(&EN<W1A;&QS(&9R;VT-"F%N
M>7=H97)E(&]N('1H92!N970N#0H-"B)P86-K86=E+GAM;"(@.B!I;G-T86QL
M<R!T:&4@<&%C:V%G92!D97-C<FEB960@:6X-"G!A8VMA9V4N>&UL+B`@57-E
M9G5L(&9O<B!T97-T:6YG+"!O<B!F;W(@=W)A<'!I;F<@82!014%2('!A8VMA
M9V4@:6X-"F%N;W1H97(@<&%C:V%G92!M86YA9V5R('-U8V@@87,@4E!-+@T*
M#0HB4&%C:V%G95LM=F5R<VEO;B]S=&%T95U;+G1A<ETB(#H@<75E<FEE<R!Y
M;W5R(&1E9F%U;'0@8VAA;FYE;%PG<R!S97)V97(-"BA[8V]N9FEG(&UA<W1E
M<E]S97)V97)]*2!A;F0@9&]W;FQO861S('1H92!N97=E<W0@<&%C:V%G92!W
M:71H#0IT:&4@<')E9F5R<F5D('%U86QI='DO<W1A=&4@*'MC;VYF:6<@<')E
M9F5R<F5D7W-T871E?2DN#0H-"E1O(')E=')I979E(%!A8VMA9V4@=F5R<VEO
M;B`Q+C$L('5S92`B4&%C:V%G92TQ+C$L(B!T;R!R971R:65V90T*4&%C:V%G
M92!S=&%T92!B971A+"!U<V4@(E!A8VMA9V4M8F5T82XB("!4;R!R971R:65V
M92!A;B!U;F-O;7!R97-S960-"F9I;&4L(&%P<&5N9"`N=&%R("AM86ME('-U
M<F4@=&AE<F4@:7,@;F\@9FEL92!B>2!T:&4@<V%M92!N86UE(&9I<G-T*0T*
M#0I4;R!D;W=N;&]A9"!A('!A8VMA9V4@9G)O;2!A;F]T:&5R(&-H86YN96PL
M('!R969I>"!W:71H('1H92!C:&%N;F5L(&YA;64@;&EK90T*(F-H86YN96PO
M4&%C:V%G92(-"@T*36]R92!T:&%N(&]N92!P86-K86=E(&UA>2!B92!S<&5C
M:69I960@870@;VYC92X@($ET(&ES(&]K('1O(&UI>"!T:&5S90T*9F]U<B!W
M87ES(&]F('-P96-I9GEI;F<@<&%C:V%G97,N#0HG*2P-"B`@("`@("`@)W5P
M9W)A9&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=5
M<&=R861E(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G
M9&]);G-T86QL)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W5P)RP-
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G9F]R8V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M<VAO<G1O<'0G(#T^("=F)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)V]V97)W<FET92!N97=E<B!I;G-T86QL960@<&%C:V%G97,G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=L;V]S92<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)VPG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&-H
M96-K(&9O<B!R96-O;6UE;F1E9"!D97!E;F1E;F-Y('9E<G-I;VXG+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=N;V1E<',G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=N)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)VEG;F]R92!D
M97!E;F1E;F-I97,L('5P9W)A9&4@86YY=V%Y)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5G:7-T97(M;VYL>2<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&EN<W1A
M;&P@9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@=7!G<F%D
M960G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=N;V)U:6QD)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G0B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=D;VY<)W0@8G5I;&0@0R!E>'1E;G-I;VYS)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<F5Q=65S="!U;F-O;7!R
M97-S960@9FEL97,@=VAE;B!D;W=N;&]A9&EN9R<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)VEN<W1A;&QR;V]T)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G4B<L
M#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$25(G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G<F]O="!D:7)E8W1O<GD@=7-E9"!W
M:&5N(&EN<W1A;&QI;F<@9FEL97,@*&%L82!02%!<)W,@24Y35$%,3%]23T]4
M*2P@=7-E('!A8VMA9VEN9W)O;W0@9F]R(%)032<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W!A8VMA9VEN9W)O;W0G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=0
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T1)4B<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R>2!U<V5D
M('=H96X@<&%C:V%G:6YG(&9I;&5S+"!L:6ME(%)032!P86-K86=I;F<G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO
M<F4M97)R;W)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V1O
M8R<@/3X@)V9O<F-E(&EN<W1A;&P@979E;B!I9B!T:&5R92!W97)E(&5R<F]R
M<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M)V%L;&1E<',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO
M<G1O<'0G(#T^("=A)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)VEN<W1A;&P@86QL(')E<75I<F5D(&%N9"!O<'1I;VYA;"!D97!E;F1E;F-I
M97,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=O;FQY<F5Q9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)V\G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G:6YS=&%L;"!A;&P@<F5Q=6ER960@9&5P96YD96YC:65S)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;V9F;&EN
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)T\G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T
M(&%T=&5M<'0@=&\@9&]W;FQO860@86YY('5R;',@;W(@8V]N=&%C="!C:&%N
M;F5L<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)W!R971E;F0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M<VAO<G1O<'0G(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)T]N;'D@;&ES="!T:&4@<&%C:V%G97,@=&AA="!W;W5L9"!B92!D;W=N
M;&]A9&5D)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/B`N+BX-
M"E5P9W)A9&5S(&]N92!O<B!M;W)E(%!%05(@<&%C:V%G97,N("!3964@9&]C
M=6UE;G1A=&EO;B!F;W(@=&AE#0HB:6YS=&%L;"(@8V]M;6%N9"!F;W(@=V%Y
M<R!T;R!S<&5C:69Y(&$@<&%C:V%G92X-"@T*5VAE;B!U<&=R861I;F<L('EO
M=7(@<&%C:V%G92!W:6QL(&)E('5P9&%T960@:68@=&AE('!R;W9I9&5D(&YE
M=PT*<&%C:V%G92!H87,@82!H:6=H97(@=F5R<VEO;B!N=6UB97(@*'5S92!T
M:&4@+68@;W!T:6]N(&EF('EO=2!N965D('1O#0IU<&=R861E(&%N>7=A>2DN
M#0H-"DUO<F4@=&AA;B!O;F4@<&%C:V%G92!M87D@8F4@<W!E8VEF:65D(&%T
M(&]N8V4N#0HG*2P-"B`@("`@("`@)W5P9W)A9&4M86QL)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G57!G<F%D92!!;&P@4&%C:V%G
M97,G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]);G-T86QL)RP-
M"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W5A)RP-"B`@("`@("`@("`@
M("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]D97!S
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=I9VYO<F4@
M9&5P96YD96YC:65S+"!U<&=R861E(&%N>7=A>2<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)E9VES=&5R+6]N;'DG(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=R
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!I;G-T
M86QL(&9I;&5S+"!O;FQY(')E9VES=&5R('1H92!P86-K86=E(&%S('5P9W)A
M9&5D)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G;F]B=6EL9"<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)T(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G9&]N7"=T(&)U:6QD($,@97AT96YS:6]N<R<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=:)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)E<75E<W0@=6YC;VUP
M<F5S<V5D(&9I;&5S('=H96X@9&]W;FQO861I;F<G+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I;G-T86QL<F]O="<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U(G
M+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$E2)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)O;W0@9&ER96-T;W)Y('5S960@
M=VAE;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A07"=S($E.4U1!3$Q?4D]/
M5"DL('5S92!P86-K86=I;F=R;V]T(&9O<B!24$TG+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M97)R;W)S)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V9O<F-E
M(&EN<W1A;&P@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R<L#0H@("`@("`@
M("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)VQO;W-E)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!C
M:&5C:R!F;W(@<F5C;VUM96YD960@9&5P96YD96YC>2!V97)S:6]N)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@)V1O8R<@/3X@)PT*57!G<F%D97,@86QL('!A8VMA9V5S('1H
M870@:&%V92!A(&YE=V5R(')E;&5A<V4@879A:6QA8FQE+B`@57!G<F%D97,@
M87)E#0ID;VYE(&]N;'D@:68@=&AE<F4@:7,@82!R96QE87-E(&%V86EL86)L
M92!O9B!T:&4@<W1A=&4@<W!E8VEF:65D(&EN#0HB<')E9F5R<F5D7W-T871E
M(B`H8W5R<F5N=&QY('MC;VYF:6<@<')E9F5R<F5D7W-T871E?2DL(&]R(&$@
M<W1A=&4@8V]N<VED97)E9`T*;6]R92!S=&%B;&4N#0HG*2P-"B`@("`@("`@
M)W5N:6YS=&%L;"<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@
M/3X@)U5N+6EN<W1A;&P@4&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N8W1I
M;VXG(#T^("=D;U5N:6YS=&%L;"<L#0H@("`@("`@("`@("`G<VAO<G1C=70G
M(#T^("=U;B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@)VYO9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G:6=N;W)E(&1E<&5N9&5N8VEE<RP@=6YI;G-T86QL
M(&%N>7=A>2<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@)W)E9VES=&5R+6]N;'DG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=R)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1O8R<@/3X@)V1O(&YO="!R96UO=F4@9FEL97,L(&]N;'D@<F5G:7-T
M97(@=&AE('!A8VMA9V5S(&%S(&YO="!I;G-T86QL960G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I;G-T86QL<F]O="<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)U(G+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$E2)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)O;W0@9&ER96-T;W)Y('5S
M960@=VAE;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A07"=S($E.4U1!3$Q?
M4D]/5"DG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@("=I9VYO<F4M97)R;W)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)V1O8R<@/3X@)V9O<F-E(&EN<W1A;&P@979E;B!I9B!T:&5R92!W
M97)E(&5R<F]R<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@
M("`@("`@("`@)V]F9FQI;F4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=/)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)V1O(&YO="!A='1E;7!T('1O('5N:6YS=&%L;"!R96UO=&5L
M>2<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;8VAA;FYE;"]=/'!A8VMA9V4^
M("XN+@T*56YI;G-T86QL<R!O;F4@;W(@;6]R92!014%2('!A8VMA9V5S+B`@
M36]R92!T:&%N(&]N92!P86-K86=E(&UA>2!B90T*<W!E8VEF:65D(&%T(&]N
M8V4N("!0<F5F:7@@=VET:"!C:&%N;F5L(&YA;64@=&\@=6YI;G-T86QL(&9R
M;VT@80T*8VAA;FYE;"!N;W0@:6X@>6]U<B!D969A=6QT(&-H86YN96P@*'MC
M;VYF:6<@9&5F875L=%]C:&%N;F5L?2D-"B<I+`T*("`@("`@("`G8G5N9&QE
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G56YP86-K
M<R!A(%!E8VP@4&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^
M("=D;T)U;F1L92<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=B=6XG
M+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("=D97-T:6YA=&EO;B<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G9"<L#0H@("`@("`@("`@("`@("`@("`@
M("=A<F<G(#T^("=$25(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G3W!T:6]N86P@9&5S=&EN871I;VX@9&ER96-T;W)Y(&9O<B!U;G!A8VMI
M;F<@*&1E9F%U;'1S('1O(&-U<G)E;G0@<&%T:"!O<B`B97AT(B!I9B!E>&ES
M=',I)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G9F]R8V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO
M<G1O<'0G(#T^("=F)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)T9O<F-E('1H92!U;G!A8VMI;F<@979E;B!I9B!T:&5R92!W97)E(&5R<F]R
M<R!I;B!T:&4@<&%C:V%G92<L#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^#0I5
M;G!A8VMS(&$@4&5C;"!086-K86=E(&EN=&\@=&AE('-E;&5C=&5D(&QO8V%T
M:6]N+B!)="!W:6QL(&1O=VYL;V%D('1H90T*<&%C:V%G92!I9B!N965D960N
M#0HG*2P-"B`@("`@("`@)W)U;BUS8W)I<'1S)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G4G5N(%!O<W0M26YS=&%L;"!38W)I<'1S
M(&)U;F1L960@=VET:"!A('!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T
M:6]N)R`]/B`G9&]2=6Y38W)I<'1S)RP-"B`@("`@("`@("`@("=S:&]R=&-U
M="<@/3X@)W)S)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA
M9V4^#0I2=6X@<&]S="UI;G-T86QL871I;VX@<V-R:7!T<R!I;B!P86-K86=E
M(#QP86-K86=E/BP@:68@86YY(&5X:7-T+@T*)RDL#0H@("`@*3L-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@
M("`@("H@4$5!4E]#;VUM86YD7TEN<W1A;&P@8V]N<W1R=6-T;W(N#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%!%05)?0V]M;6%N9%]);G-T86QL*"8D=6DL("8D8V]N9FEG*0T*("`@
M('L-"B`@("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N*"1U:2P@
M)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@
M("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@)F=E=$1O=VYL;V%D97(H)B1U:2P@)&]P=&EO;G,L("8D8V]N
M9FEG*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?
M1&]W;FQO861E<B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O1&]W;FQO861E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@
M)FYE=R!014%27T1O=VYL;V%D97(H)'5I+"`D;W!T:6]N<RP@)&-O;F9I9RD[
M#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@)F=E=$EN<W1A;&QE<B@F)'5I*0T*("`@('L-"B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)U!%05)?26YS=&%L;&5R)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(N<&AP)SL-"B`@("`@
M("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]);G-T86QL97(H)'5I*3L-
M"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\O('M[>R!D;TEN
M<W1A;&PH*0T*#0H@("`@9G5N8W1I;VX@9&]);G-T86QL*"1C;VUM86YD+"`D
M;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^:6YS=&%L;&5R*2D@>PT*("`@("`@("`@("`@)'1H:7,M/FEN<W1A
M;&QE<B`]("8D=&AI<RT^9V5T26YS=&%L;&5R*"1T:&ES+3YU:2D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1C;VUM86YD(#T]("=U<&=R861E)RD@>PT*
M("`@("`@("`@("`@)&]P=&EO;G-;)W5P9W)A9&4G72`]('1R=64[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=I;G-T86QL<F]O
M="==*2`F)B!I<W-E="@D;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=%4E)/4CH@
M8V%N;F]T('5S92!B;W1H("TM:6YS=&%L;')O;W0@86YD("TM<&%C:V%G:6YG
M<F]O="<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULG<&%C:V%G:6YG<F]O="==*2`F)B`D=&AI<RT^8V]N9FEG+3YG970H)W9E
M<F)O<V4G*2`^(#(I('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@G=7-I;F<@<&%C:V%G92!R;V]T.B`G("X@)&]P=&EO;G-;)W!A8VMA
M9VEN9W)O;W0G72D[#0H@("`@("`@('T-"B`@("`@("`@)')E9R`]("8D=&AI
M<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!I9B`H)&-O;6UA
M;F0@/3T@)W5P9W)A9&4M86QL)RD@>PT*("`@("`@("`@("`@)&]P=&EO;G-;
M)W5P9W)A9&4G72`]('1R=64[#0H@("`@("`@("`@("`D<F5G(#T@)B1T:&ES
M+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`D<V%V96-H
M86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I
M.PT*("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("!F;W)E86-H("@D<F5G+3YL:7-T0VAA;FYE;',H*2!A<R`D8VAA;FYE;"D@
M>PT*("`@("`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G7U]U<FDG*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E
M9F%U;'1?8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`D
M8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N
M+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?
M;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("`@("`@("`@)&)A<V4@/2`D
M8VAA;BT^9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E
M="@G<')E9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D9&]R97-T(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H
M)')E;6]T92D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&1O<F5S="`](&9A;'-E.PT*("`@("`@("`@("`@("`@
M("`@("`D<F5M;W1E(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@D=&AI
M<RT^8V]N9FEG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)'-T871E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A
M=&4G*3L-"B`@("`@("`@("`@("`@("`D:6YS=&%L;&5D(#T@87)R87E?9FQI
M<"@D<F5G+3YL:7-T4&%C:V%G97,H)&-H86YN96PI*3L-"B`@("`@("`@("`@
M("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD[#0H@("`@("`@("`@("`@("`@:68@*"1D;W)E<W0I('L-"B`@
M("`@("`@("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4D535"@G,2XP)RP@87)R87DH*2D[#0H@("`@("`@("`@("`@("`@("`@("1L
M871E<W0@/2`D<F5S="T^;&ES=$QA=&5S=%5P9W)A9&5S*"1B87-E+"`D<W1A
M=&4L("1I;G-T86QL960L("1C:&%N;F5L+"`D<F5G*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)'-T871E*2!\?"`D<W1A=&4@/3T@)V%N>2<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1L871E<W0@/2`D<F5M;W1E+3YC86QL*")P86-K86=E+FQI
M<W1,871E<W1296QE87-E<R(I.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R96UO
M=&4M/F-A;&PH(G!A8VMA9V4N;&ES=$QA=&5S=%)E;&5A<V5S(BP@)'-T871E
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG
M*"D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QA=&5S
M="D@?'P@(6ES7V%R<F%Y*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;&%T97-T(&%S("1P86-K86=E(#T^("1I;F9O*2![
M#0H@("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D
M<&%C:V%G92D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN
M<W1A;&QE9%LD<&%C:V%G95TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!S:VEP('!A8VMA9V5S('=E(&1O;B=T(&AA=F4@:6YS=&%L;&5D#0H@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D:6YS=%]V97)S:6]N
M(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H
M86YN96PI.PT*("`@("`@("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP
M87)E*"(D:6YF;UMV97)S:6]N72(L("(D:6YS=%]V97)S:6]N(BP@(FQE(BDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&EN<W1A;&QE9"!V97)S
M:6]N(&ES('5P+71O+61A=&4-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1P87)A;7-;72`]("1R96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3
M=')I;F<H87)R87DH)W!A8VMA9V4G(#T^("1P86-K86=E+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1C:&%N;F5L*2D[#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AA<G)A>2@G
M9&%T82<@/3X@(E=I;&P@=7!G<F%D92`D<&%C:V%G92(I+"`D8V]M;6%N9"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V
M96-H86YN96PI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YD;W=N;&]A
M9&5R(#T@)B1T:&ES+3YG971$;W=N;&]A9&5R*"1T:&ES+3YU:2P@)&]P=&EO
M;G,L("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D97)R;W)S(#T@87)R87DH
M*3L-"B`@("`@("`@)&1O=VYL;V%D960@/2!A<G)A>2@I.PT*("`@("`@("`D
M9&]W;FQO861E9"`]("8D=&AI<RT^9&]W;FQO861E<BT^9&]W;FQO860H)'!A
M<F%M<RD[#0H@("`@("`@("1E<G)O<G,@/2`D=&AI<RT^9&]W;FQO861E<BT^
M9V5T17)R;W)-<V=S*"D[#0H@("`@("`@(&EF("AC;W5N="@D97)R;W)S*2D@
M>PT*("`@("`@("`@("`@9F]R96%C:"`H)&5R<F]R<R!A<R`D97)R;W(I('L-
M"B`@("`@("`@("`@("`@("`D97)R6R=D871A)UU;72`](&%R<F%Y*"1E<G)O
M<BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D97)R6R=H96%D;&EN
M92==(#T@)TEN<W1A;&P@17)R;W)S)SL-"B`@("`@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@D97)R*3L-"B`@("`@("`@("`@(&EF("@A8V]U;G0H
M)&1O=VYL;V%D960I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"(D8V]M;6%N9"!F86EL960B*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@
M("`@("`@)VAE861L:6YE)R`]/B`G4&%C:V%G97,@=&AA="!W;W5L9"!B92!)
M;G-T86QL960G#0H@("`@("`@("D[#0H@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULG<')E=&5N9"==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1O
M=VYL;V%D960@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`D9&%T
M85LG9&%T82==6UT@/2!A<G)A>2@D<F5G+3YP87)S961086-K86=E3F%M951O
M4W1R:6YG*"1P86-K86=E+3YG971087)S961086-K86=E*"DI*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D
M9&%T82P@)W!R971E;F0G*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3YI;G-T86QL97(M/G-E=$]P=&EO
M;G,H)&]P=&EO;G,I.PT*("`@("`@("`D=&AI<RT^:6YS=&%L;&5R+3YS;W)T
M4&%C:V%G97-&;W));G-T86QL*"1D;W=N;&]A9&5D*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<B`]("1T:&ES+3YI;G-T86QL97(M/G-E=$1O
M=VYL;V%D961086-K86=E<R@D9&]W;FQO861E9"DI*2![#0H@("`@("`@("`@
M("`D=&AI<RT^<F%I<V5%<G)O<B@D97)R+3YG971-97-S86=E*"DI.PT*("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)&5X
M=')A:6YF;R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1D;W=N;&]A
M9&5D(&%S("1P87)A;2D@>PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@
M("`@)&EN9F\@/2`D=&AI<RT^:6YS=&%L;&5R+3YI;G-T86QL*"1P87)A;2P@
M)&]P=&EO;G,I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN
M9F\I*2![#0H@("`@("`@("`@("`@("`@)&]L9&EN9F\@/2`D:6YF;SL-"B`@
M("`@("`@("`@("`@("`D<&MG(#T@)B1P87)A;2T^9V5T4&%C:V%G949I;&4H
M*3L-"B`@("`@("`@("`@("`@("!I9B`H)&EN9F\M/F=E=$-O9&4H*2`A/2!0
M14%27TE.4U1!3$Q%4E].3T))3D%262D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(2@D:6YF;R`]("1P:V<M/FEN<W1A;&Q":6YA<GDH)'1H:7,M/FEN
M<W1A;&QE<BDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)T524D]2.B`G("XD;VQD:6YF;RT^9V5T365S<V%G
M92@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("\O('=E
M(&IU<W0@:6YS=&%L;&5D(&$@9&EF9F5R96YT('!A8VMA9V4@=&AA;B!R97%U
M97-T960L#0H@("`@("`@("`@("`@("`@("`@("\O(&QE="=S(&-H86YG92!T
M:&4@<&%R86T@86YD(&EN9F\@<V\@=&AA="!T:&4@<F5S="!O9B!T:&ES('=O
M<FMS#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2`]("1I;F9O6S!=.PT*
M("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("1I;F9O6S%=.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D:6YF;RDI('L-"B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M
M+3YG971086-K86=E5'EP92@I(#T]("=E>'1S<F,G('Q\#0H@("`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M+3YG971086-K86=E5'EP92@I(#T]("=E>'1B
M:6XG*2![#0H@("`@("`@("`@("`@("`@("`@("1P:V<@/2`F)'!A<F%M+3YG
M971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&EN
M<W1B:6X@/2`D<&MG+3YG971);G-T86QL961":6YA<GDH*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN<W1P:V<@/2`F)')E9RT^9V5T4&%C:V%G
M92@D:6YS=&)I;BP@)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;G-T<&MG(#T@)B1R96<M/F=E=%!A8VMA9V4H)'!K9RT^9V5T4&%C:V%G92@I
M+"`D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;G-T<&MG+3YG971&
M:6QE;&ES="@I(&%S("1N86UE(#T^("1A='1S*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<&EN9F\@/2!P871H:6YF;R@D871T<ULG:6YS=&%L;&5D
M7V%S)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M<&EN9F];)V5X=&5N<VEO;B==*2!\?`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:6Y?87)R87DH)'!I;F9O6R=E>'1E;G-I;VXG72P@87)R87DH
M)V,G+"`G:"<I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.R`O+R!M86ME('-U<F4@=V4@9&]N)W0@;6%T8V@@<&AP7V)L86@N
M:`T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"AS=')P;W,H)'!I;F9O6R=B87-E;F%M92==+"`G<&AP
M7R<I(#T]/2`P("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&EN9F];)V5X=&5N<VEO;B==(#T]("=D;&PG*2!\?`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@;6]S="!U;FEC97,-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P:6YF;ULG97AT96YS:6]N)UT@/3T@)W-O
M)R!\?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@:'`M=7@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P:6YF;ULG97AT96YS
M:6]N)UT@/3T@)W-L)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E>'1R86EN9F];72`]("=9;W4@<VAO=6QD(&%D9"`B97AT96YS:6]N/2<@
M+B`D<&EN9F];)V)A<V5N86UE)UT-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G(B!T;R!P:'`N:6YI)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E
M)RD@/B`P*2![#0H@("`@("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)'!A
M<F%M+3YG971#:&%N;F5L*"D[#0H@("`@("`@("`@("`@("`@("`@("1L86)E
M;"`]("1R96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8VAA;FYE;"<@/3X@)&-H86YN96PL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1P87)A;2T^9V5T4&%C:V%G
M92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]
M/B`D<&%R86TM/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("DI.PT*("`@("`@("`@("`@("`@("`@("`D;W5T(#T@87)R87DH)V1A
M=&$G(#T^("(D8V]M;6%N9"!O:SH@)&QA8F5L(BD[#0H@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D:6YF;ULG<F5L96%S95]W87)N:6YG<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&]U=%LG<F5L96%S95]W87)N
M:6YG<R==(#T@)&EN9F];)W)E;&5A<V5?=V%R;FEN9W,G73L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)&]U="P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=R96=I<W1E<BUO;FQY)UTI("8F
M("%I<W-E="@D;W!T:6]N<ULG;V9F;&EN92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/FES1&5F:6YE9$QA>65R
M*"=F='`G*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z
M.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3YI
M;G-T86QL97(M/F9T<$EN<W1A;&PH)'!A<F%M*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&EN9F\I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D:6YF;RT^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*")R96UO=&4@:6YS=&%L;"!F86EL960Z("1L86)E;"(I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@B<F5M;W1E(&EN<W1A;&P@;VLZ("1L86)E;"(I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D9&5P<R`]("1P87)A;2T^9V5T1&5P<R@I.PT*("`@
M("`@("`@("`@("`@(&EF("@D9&5P<RD@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<'-;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9W)O=7!S(#T@)&1E<'-;)V=R;W5P)UT[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1G<F]U<'-;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"1G
M<F]U<',I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P<R!A<R`D9W)O=7`I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P6R=A='1R
M:6)S)UU;)VYA;64G72`]/2`G9&5F875L="<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@9&5F875L="!G<F]U<"!I<R!A;'=A>7,@
M:6YS=&%L;&5D+"!U;FQE<W,@=&AE('5S97(-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@97AP;&EC:71L>2!C:&]O<V5S('1O(&EN<W1A
M;&P@86YO=&AE<B!G<F]U<`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"1P87)A;2T^9V5T4&%C:V%G92@I("X@)SH@3W!T:6]N86P@9F5A
M='5R92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R
M;W5P6R=A='1R:6)S)UU;)VYA;64G72`N("<@879A:6QA8FQE("@G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=A='1R:6)S
M)UU;)VAI;G0G72`N("<I)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F%I;F9O6UT@/2`G5&\@
M:6YS=&%L;"!U<V4@(G!E87(@:6YS=&%L;"`G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%C
M:V%G92<@/3X@)'!A<F%M+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D<&%R86TM
M/F=E=$-H86YN96PH*2DL('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(V9E871U<F5N86UE(B<[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1O<'1I;VYS6R=I;G-T86QL<F]O="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P
M:V<@/2`F)')E9RT^9V5T4&%C:V%G92@D<&%R86TM/F=E=%!A8VMA9V4H*2P@
M)'!A<F%M+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("\O("1P
M:V<@;6%Y(&)E($Y53$P@:68@:6YS=&%L;"!I<R!A("=F86ME)R!I;G-T86QL
M('9I82`M+7!A8VMA9VEN9W)O;W0-"B`@("`@("`@("`@("`@("!I9B`H:7-?
M;V)J96-T*"1P:V<I*2![#0H@("`@("`@("`@("`@("`@("`@("1P:V<M/G-E
M=$-O;F9I9R@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1L:7-T(#T@)'!K9RT^;&ES=%!O<W1I;G-T86QL4V-R:7!T<R@I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&X@/2`D<F5G+3YP87)S9610
M86-K86=E3F%M951O4W1R:6YG*&%R<F%Y*"=C:&%N;F5L)R`]/@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3YG971#:&%N;F5L*"DL("=P
M86-K86=E)R`]/B`D<&%R86TM/F=E=%!A8VMA9V4H*2DL('1R=64I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X=')A:6YF;UM=(#T@)'!N("X@)R!H
M87,@<&]S="UI;G-T86QL('-C<FEP=',Z)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1F:6QE*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5X=')A:6YF;UM=(#T@)&9I;&4[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97AT<F%I;F9O6UT@/2`G57-E(")P96%R(')U;BUS8W)I<'1S("<@+B`D
M<&X@+B`G(B!T;R!R=6XG.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M=')A:6YF;UM=(#T@)T1/($Y/5"!254X@4T-225!44R!&4D]-(%5.5%)54U1%
M1"!33U520T53)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9"!F86EL960B
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U
M;G0H)&5X=')A:6YF;RDI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1E>'1R
M86EN9F\@87,@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)&EN9F\I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!D;U5N:6YS=&%L;"@I#0H-"B`@("!F=6YC=&EO;B!D;U5N
M:6YS=&%L;"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/FEN<W1A;&QE<BDI('L-"B`@("`@
M("`@("`@("1T:&ES+3YI;G-T86QL97(@/2`F)'1H:7,M/F=E=$EN<W1A;&QE
M<B@D=&AI<RT^=6DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG<F5M;W1E8V]N9FEG)UTI*2![#0H@("`@("`@("`@("`D92`]
M("1T:&ES+3YC;VYF:6<M/G)E861&5%!#;VYF:6=&:6QE*"1O<'1I;VYS6R=R
M96UO=&5C;VYF:6<G72D[#0H@("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R
M;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^
M<V5T0V]N9FEG*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!L96%S92!S
M=7!P;'D@=&AE('!A8VMA9V4H<RD@>6]U('=A;G0@=&\@=6YI;G-T86QL(BD[
M#0H@("`@("`@('T-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG
M971296=I<W1R>2@I.PT*("`@("`@("`D;F5W<&%R86US(#T@87)R87DH*3L-
M"B`@("`@("`@)&)A9'!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A
M8V@@*"1P87)A;7,@87,@)'!K9RD@>PT*("`@("`@("`@("`@)&-H86YN96P@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@
M("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PT*("`@("`@("`@("`@)'!A<G-E9"`]("1R96<M/G!A
M<G-E4&%C:V%G94YA;64H)'!K9RP@)&-H86YN96PI.PT*("`@("`@("`@("`@
M4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@
M:68@*"$D<&%R<V5D('Q\(%!%05(Z.FES17)R;W(H)'!A<G-E9"DI('L-"B`@
M("`@("`@("`@("`@("`D8F%D<&%R86US6UT@/2`D<&MG.PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'!A8VMA9V4@/2`D<&%R<V5D6R=P86-K86=E)UT[#0H@("`@("`@("`@("`D
M8VAA;FYE;"`]("1P87)S961;)V-H86YN96PG73L-"B`@("`@("`@("`@("1I
M;F9O(#T@)B1R96<M/F=E=%!A8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L*3L-
M"B`@("`@("`@("`@(&EF("@D:6YF;R`]/3T@;G5L;"`F)@T*("`@("`@("`@
M("`@("`@("`H)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<@?'P@)&-H86YN
M96P@/3T@)W!E8VPN<&AP+FYE="<I*2![#0H@("`@("`@("`@("`@("`@+R\@
M;6%K92!S=7)E('1H:7,@:7-N)W0@82!P86-K86=E('1H870@:&%S(&9L:7!P
M960@9G)O;2!P96%R('1O('!E8VP@8G5T#0H@("`@("`@("`@("`@("`@+R\@
M=7-E9"!A('!A8VMA9V4N>&UL(#$N,`T*("`@("`@("`@("`@("`@("1T97-T
M8R`]("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@/R`G<&5C;"YP:'`N
M;F5T)R`Z("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@("`@("1I;F9O
M(#T@)B1R96<M/F=E=%!A8VMA9V4H)'!A8VMA9V4L("1T97-T8RD[#0H@("`@
M("`@("`@("`@("`@:68@*"1I;F9O("$]/2!N=6QL*2![#0H@("`@("`@("`@
M("`@("`@("`@("1C:&%N;F5L(#T@)'1E<W1C.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:6YF;R`]/3T@
M;G5L;"D@>PT*("`@("`@("`@("`@("`@("1B861P87)A;7-;72`]("1P:V<[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1N97=P
M87)A;7-;72`]("8D:6YF;SL-"B`@("`@("`@("`@("`@("`O+R!C:&5C:R!F
M;W(@8FEN87)Y('!A8VMA9V5S("AT:&ES(&ES(&%N(&%L:6%S(&9O<B!T:&]S
M92!P86-K86=E<R!I9B!S;RD-"B`@("`@("`@("`@("`@("!I9B`H)&EN<W1A
M;&QE9&)I;F%R>2`]("1I;F9O+3YG971);G-T86QL961":6YA<GDH*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/FQO9R@G861D:6YG(&)I
M;F%R>2!P86-K86=E("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9RAA<G)A>2@G8VAA;FYE;"<@
M/3X@)&-H86YN96PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M8VMA9V4G(#T^("1I;G-T86QL961B:6YA<GDI+"!T<G5E*2D[#0H@("`@("`@
M("`@("`@("`@("`@("1N97=P87)A;7-;72`]("8D<F5G+3YG971086-K86=E
M*"1I;G-T86QL961B:6YA<GDL("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@+R\@861D('1H92!C;VYT96YT<R!O9B!A
M(&1E<&5N9&5N8WD@9W)O=7`@=&\@=&AE(&QI<W0@;V8@:6YS=&%L;&5D('!A
M8VMA9V5S#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)S961;)V=R
M;W5P)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1G<F]U<"`]("1I;F9O
M+3YG971$97!E;F1E;F-Y1W)O=7`H)'!A<G-E9%LG9W)O=7`G72D[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@D9W)O=7`I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1I;G-T86QL960@/2`F)')E9RT^9V5T26YS=&%L;&5D1W)O
M=7`H)&=R;W5P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:6YS
M=&%L;&5D*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&EN<W1A;&QE9"!A<R`D:2`]/B`D<"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F5W<&%R86US6UT@/2`F)&EN<W1A;&QE9%LD
M:5T[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1E<G(@/2`D=&AI<RT^:6YS=&%L;&5R+3YS;W)T4&%C:V%G97-&;W)5
M;FEN<W1A;&PH)&YE=W!A<F%M<RD[#0H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)&5R<BT^9V5T365S<V%G92@I+"`D8V]M;6%N9"D[#0H@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D<&%R86US(#T@
M)&YE=W!A<F%M<SL-"B`@("`@("`@+R\@='=I<W0@=&AI<R!T;R!U<V4@:70@
M=&\@8VAE8VL@;VX@=VAE=&AE<B!D97!E;F1E;G0@<&%C:V%G97,@87)E(&%L
M<V\@8F5I;F<@=6YI;G-T86QL960-"B`@("`@("`@+R\@9F]R(&-I<F-U;&%R
M(&1E<&5N9&5N8VEE<R!L:6ME('-U8G!A8VMA9V5S#0H@("`@("`@("1T:&ES
M+3YI;G-T86QL97(M/G-E=%5N:6YS=&%L;%!A8VMA9V5S*"1N97=P87)A;7,I
M.PT*("`@("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)'!A<F%M<RP@)&)A
M9'!A<F%M<RD[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!K9RD@
M>PT*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<'5S:$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@:68@*"1E
M<G(@/2`D=&AI<RT^:6YS=&%L;&5R+3YU;FEN<W1A;&PH)'!K9RP@)&]P=&EO
M;G,I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@D97)R+3YG971-97-S86=E*"DL("1C;VUM86YD*3L-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1S879E<&MG(#T@)'!K9SL-"B`@("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@
M/B`P*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K
M9RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P:V<@/2`D<F5G+3YP
M87)S961086-K86=E3F%M951O4W1R:6YG*"1P:V<I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@B=6YI;G-T86QL(&]K.B`D<&MG(BP@)&-O;6UA;F0I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O
M<'1I;VYS6R=O9F9L:6YE)UTI("8F(&ES7V]B:F5C="@D<V%V97!K9RD@)B8-
M"B`@("`@("`@("`@("`@("`@("`@("!D969I;F5D*"=014%27U)%34]414E.
M4U1!3$Q?3TLG*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/F-O;F9I9RT^:7-$969I;F5D3&%Y97(H)V9T<"<I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^:6YS=&%L;&5R+3YP=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;R`]("1T:&ES+3YI;G-T86QL97(M/F9T<%5N:6YS=&%L;"@D
M<V%V97!K9RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:6YS
M=&%L;&5R+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&EN
M9F\M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*")R96UO=&4@=6YI;G-T86QL(&9A
M:6QE9#H@)'!K9R(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H(G)E;6]T92!U;FEN<W1A;&P@;VLZ("1P:V<B*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'!K9R`]("1R96<M/G!A<G-E9%!A8VMA
M9V5.86UE5&]3=')I;F<H)'!K9RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YI;G-T
M86QL(&9A:6QE9#H@)'!K9R(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]"=6YD;&4H*0T*("`@("\J
M#0H@("`@*&-O>"D@270@:G5S="!D;W=N;&]A9',@86YD('5N=&%R<R!T:&4@
M<&%C:V%G92P@9&]E<R!N;W0@9&\-"B`@("`@("`@("`@(&%N>2!C:&5C:R!T
M:&%T('1H92!014%27TEN<W1A;&QE<CHZ7VEN<W1A;&Q&:6QE*"D@9&]E<RX-
M"B`@("`J+PT*#0H@("`@9G5N8W1I;VX@9&]"=6YD;&4H)&-O;6UA;F0L("1O
M<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)&1O=VYL;V%D97(@
M/2`F)'1H:7,M/F=E=$1O=VYL;V%D97(H)'1H:7,M/G5I+"!A<G)A>2@G9F]R
M8V4G(#T^('1R=64L("=N;V1E<',G(#T^('1R=64L#0H@("`@("`@("`@("`G
M<V]F="<@/3X@=')U92DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF
M("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(E!L96%S92!S=7!P;'D@=&AE('!A8VMA9V4@
M>6]U('=A;G0@=&\@8G5N9&QE(BD[#0H@("`@("`@('T-"@T*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)V1E<W1I;F%T:6]N)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES7V1I<B@D;W!T:6]N<ULG9&5S=&EN871I;VXG72DI('L-
M"B`@("`@("`@("`@("`@("!3>7-T96TZ.FUK9&ER*"<M<"`G("X@)&]P=&EO
M;G-;)V1E<W1I;F%T:6]N)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)&1E<W0@/2!R96%L<&%T:"@D;W!T:6]N<ULG9&5S=&EN871I;VXG72D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<'=D(#T@9V5T8W=D
M*"D[#0H@("`@("`@("`@("!I9B`H:7-?9&ER*"1P=V0@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)V5X="<I*2![#0H@("`@("`@("`@("`@("`@)&1E<W0@
M/2`D<'=D("X@1$E214-43U)97U-%4$%2051/4B`N("=E>'0G.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9&5S="`]("1P=V0[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&1O=VYL;V%D
M97(M/G-E=$1O=VYL;V%D1&ER*"1D97-T*3L-"B`@("`@("`@)')E<W5L="`]
M("8D9&]W;FQO861E<BT^9&]W;FQO860H87)R87DH)'!A<F%M<ULP72DI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0[#0H@("`@("`@('T-"B`@("`@("`@)'!K
M9V9I;&4@/2`F)')E<W5L=%LP72T^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@
M("`@)'!K9VYA;64@/2`D<&MG9FEL92T^9V5T3F%M92@I.PT*("`@("`@("`D
M<&MG=F5R<VEO;B`]("1P:V=F:6QE+3YG971697)S:6]N*"D[#0H-"B`@("`@
M("`@+R\@56YP86-K:6YG("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T-"B`@("`@("`@)&1E<W0@+CT@1$E214-4
M3U)97U-%4$%2051/4B`N("1P:V=N86UE.PT*("`@("`@("`D;W)I9R`]("1P
M:V=N86UE("X@)RTG("X@)'!K9W9E<G-I;VX[#0H-"B`@("`@("`@)'1A<B`]
M("9N97<@07)C:&EV95]487(H)'!K9V9I;&4M/F=E=$%R8VAI=F5&:6QE*"DI
M.PT*("`@("`@("!I9B`H(4`D=&%R+3YE>'1R86-T36]D:69Y*"1D97-T+"`D
M;W)I9RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G=6YA8FQE('1O('5N<&%C:R`G("X@)'!K9V9I;&4M/F=E=$%R8VAI=F5&
M:6QE*"DI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@B4&%C:V%G92!R96%D>2!A="`G)&1E<W0G(BD[#0H@("`@+R\@?7U]
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("!F=6YC=&EO;B!D;U)U;E-C
M<FEP=',H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@
M("`@("`@:68@*"%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=R=6XM<V-R:7!T<R!E>'!E8W1S
M(#$@<&%R86UE=&5R.B!A('!A8VMA9V4@;F%M92<I.PT*("`@("`@("!]#0H@
M("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-
M"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PT*("`@("`@("`D<&%R<V5D(#T@)')E9RT^<&%R<V50
M86-K86=E3F%M92@D<&%R86US6S!=+"`D=&AI<RT^8V]N9FEG+3YG970H)V1E
M9F%U;'1?8VAA;FYE;"<I*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%R
M<V5D*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1P87)S960I.PT*("`@("`@("!]#0H@("`@("`@("1P86-K86=E(#T@)B1R
M96<M/F=E=%!A8VMA9V4H)'!A<G-E9%LG<&%C:V%G92==+"`D<&%R<V5D6R=C
M:&%N;F5L)UTI.PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1P86-K86=E*2D@
M>PT*("`@("`@("`@("`@)'!A8VMA9V4M/G-E=$-O;F9I9R@D=&AI<RT^8V]N
M9FEG*3L-"B`@("`@("`@("`@("1P86-K86=E+3YR=6Y0;W-T:6YS=&%L;%-C
M<FEP=',H*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]U;&0@;F]T(')E=')I979E('!A8VMA
M9V4@(B<@+B`D<&%R86US6S!=("X@)R(@9G)O;2!R96=I<W1R>2<I.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G26YS=&%L
M;"!S8W)I<'1S(&-O;7!L971E)RP@)&-O;6UA;F0I.PT*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0I]#0H_/@T*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]086-K86=E+GAM;```````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S-3`S`#$P-3$U-#,Q,#4W`#`R
M,34R-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\<&%C:V%G93X-"B`@/'-U
M;6UA<GD^0G5I;&0@4&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O
M4&%C:V%G93PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YP/"]S:&]R=&-U=#X-
M"B`@/&]P=&EO;G,^#0H@("`\;F]C;VUP<F5S<SX-"B`@("`\<VAO<G1O<'0^
M6CPO<VAO<G1O<'0^#0H@("`@/&1O8SY$;R!N;W0@9WII<"!T:&4@<&%C:V%G
M92!F:6QE/"]D;V,^#0H@("`\+VYO8V]M<')E<W,^#0H@("`\<VAO=VYA;64^
M#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^4')I;G0@
M=&AE(&YA;64@;V8@=&AE('!A8VMA9V5D(&9I;&4N/"]D;V,^#0H@("`\+W-H
M;W=N86UE/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^6V1E<V-F:6QE72!;9&5S
M8V9I;&4R70T*0W)E871E<R!A(%!%05(@<&%C:V%G92!F<F]M(&ET<R!D97-C
M<FEP=&EO;B!F:6QE("AU<W5A;&QY(&-A;&QE9`T*<&%C:V%G92YX;6PI+B`@
M268@82!S96-O;F0@<&%C:V%G969I;&4@:7,@<&%S<V5D(&EN+"!T:&5N#0IT
M:&4@<&%C:V%G97(@=VEL;"!C:&5C:R!T;R!M86ME('-U<F4@=&AA="!O;F4@
M:7,@82!P86-K86=E+GAM;`T*=F5R<VEO;B`Q+C`L(&%N9"!T:&4@;W1H97(@
M:7,@82!P86-K86=E+GAM;"!V97)S:6]N(#(N,"X@(%1H90T*<&%C:V%G92YX
M;6P@=F5R<VEO;B`Q+C`@=VEL;"!B92!S879E9"!A<R`F<75O=#MP86-K86=E
M+GAM;"9Q=6]T.R!I;B!T:&4@87)C:&EV92P-"F%N9"!T:&4@;W1H97(@87,@
M)G%U;W0[<&%C:V%G93(N>&UL)G%U;W0[(&EN('1H92!A<F-H:79E)G%U;W0[
M#0H\+V1O8SX-"B`\+W!A8VMA9V4^#0H@/'!A8VMA9V4M=F%L:61A=&4^#0H@
M(#QS=6UM87)Y/E9A;&ED871E(%!A8VMA9V4@0V]N<VES=&5N8WD\+W-U;6UA
M<GD^#0H@(#QF=6YC=&EO;CYD;U!A8VMA9V5686QI9&%T93PO9G5N8W1I;VX^
M#0H@(#QS:&]R=&-U=#YP=CPO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@
M(#QD;V,^#0H\+V1O8SX-"B`\+W!A8VMA9V4M=F%L:61A=&4^#0H@/&-V<V1I
M9F8^#0H@(#QS=6UM87)Y/E)U;B!A("9Q=6]T.V-V<R!D:69F)G%U;W0[(&9O
M<B!A;&P@9FEL97,@:6X@82!P86-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I
M;VX^9&]#=G-$:69F/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-D/"]S:&]R
M=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\<75I970^#0H@("`@/'-H;W)T;W!T
M/G$\+W-H;W)T;W!T/@T*("`@(#QD;V,^0F4@<75I970\+V1O8SX-"B`@(#PO
M<75I970^#0H@("`\<F5A;&QY<75I970^#0H@("`@/'-H;W)T;W!T/E$\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^0F4@<F5A;&QY('%U:65T/"]D;V,^#0H@("`\
M+W)E86QL>7%U:65T/@T*("`@/&1A=&4^#0H@("`@/'-H;W)T;W!T/D0\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^1&EF9B!A9V%I;G-T(')E=FES:6]N(&]F($1!
M5$4\+V1O8SX-"B`@("`\87)G/D1!5$4\+V%R9SX-"B`@(#PO9&%T93X-"B`@
M(#QR96QE87-E/@T*("`@(#QS:&]R=&]P=#Y2/"]S:&]R=&]P=#X-"B`@("`\
M9&]C/D1I9F8@86=A:6YS="!T86<@9F]R('!A8VMA9V4@<F5L96%S92!214P\
M+V1O8SX-"B`@("`\87)G/E)%3#PO87)G/@T*("`@/"]R96QE87-E/@T*("`@
M/')E=FES:6]N/@T*("`@(#QS:&]R=&]P=#YR/"]S:&]R=&]P=#X-"B`@("`\
M9&]C/D1I9F8@86=A:6YS="!R979I<VEO;B!2158\+V1O8SX-"B`@("`\87)G
M/E)%5CPO87)G/@T*("`@/"]R979I<VEO;CX-"B`@(#QC;VYT97AT/@T*("`@
M(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/D=E;F5R871E(&-O
M;G1E>'0@9&EF9CPO9&]C/@T*("`@/"]C;VYT97AT/@T*("`@/'5N:69I960^
M#0H@("`@/'-H;W)T;W!T/G4\+W-H;W)T;W!T/@T*("`@(#QD;V,^1V5N97)A
M=&4@=6YI9FEE9"!D:69F/"]D;V,^#0H@("`\+W5N:69I960^#0H@("`\:6=N
M;W)E+6-A<V4^#0H@("`@/'-H;W)T;W!T/FD\+W-H;W)T;W!T/@T*("`@(#QD
M;V,^26=N;W)E(&-A<V4L(&-O;G-I9&5R('5P<&5R+2!A;F0@;&]W97(M8V%S
M92!L971T97)S(&5Q=6EV86QE;G0\+V1O8SX-"B`@(#PO:6=N;W)E+6-A<V4^
M#0H@("`\:6=N;W)E+7=H:71E<W!A8V4^#0H@("`@/'-H;W)T;W!T/F(\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^26=N;W)E(&-H86YG97,@:6X@86UO=6YT(&]F
M('=H:71E('-P86-E/"]D;V,^#0H@("`\+VEG;F]R92UW:&ET97-P86-E/@T*
M("`@/&EG;F]R92UB;&%N:RUL:6YE<SX-"B`@("`\<VAO<G1O<'0^0CPO<VAO
M<G1O<'0^#0H@("`@/&1O8SY)9VYO<F4@8VAA;F=E<R!T:&%T(&EN<V5R="!O
M<B!D96QE=&4@8FQA;FL@;&EN97,\+V1O8SX-"B`@(#PO:6=N;W)E+6)L86YK
M+6QI;F5S/@T*("`@/&)R:65F/@T*("`@(#QD;V,^4F5P;W)T(&]N;'D@=VAE
M=&AE<B!T:&4@9FEL97,@9&EF9F5R+"!N;R!D971A:6QS/"]D;V,^#0H@("`\
M+V)R:65F/@T*("`@/&1R>2UR=6X^#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T
M;W!T/@T*("`@(#QD;V,^1&]N)F%P;W,[="!D;R!A;GET:&EN9RP@:G5S="!P
M<F5T96YD/"]D;V,^#0H@("`\+V1R>2UR=6X^#0H@(#PO;W!T:6]N<SX-"B`@
M/&1O8SXF;'0[<&%C:V%G92YX;6PF9W0[#0I#;VUP87)E<R!A;&P@=&AE(&9I
M;&5S(&EN(&$@<&%C:V%G92X@(%=I=&AO=70@86YY(&]P=&EO;G,L('1H:7,-
M"F-O;6UA;F0@=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O9&4@=VET:"!T
M:&4@;&%S="!C:&5C:V5D+6EN(&-O9&4N#0I5<VEN9R!T:&4@+7(@;W(@+5(@
M;W!T:6]N('EO=2!M87D@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@
M=&AA=`T*;V8@82!S<&5C:69I8R!R96QE87-E+@T*/"]D;V,^#0H@/"]C=G-D
M:69F/@T*(#QC=G-T86<^#0H@(#QS=6UM87)Y/E-E="!#5E,@4F5L96%S92!4
M86<\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T-V<U1A9SPO9G5N8W1I;VX^
M#0H@(#QS:&]R=&-U=#YC=#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@
M/'%U:65T/@T*("`@(#QS:&]R=&]P=#YQ/"]S:&]R=&]P=#X-"B`@("`\9&]C
M/D)E('%U:65T/"]D;V,^#0H@("`\+W%U:65T/@T*("`@/')E86QL>7%U:65T
M/@T*("`@(#QS:&]R=&]P=#Y1/"]S:&]R=&]P=#X-"B`@("`\9&]C/D)E(')E
M86QL>2!Q=6EE=#PO9&]C/@T*("`@/"]R96%L;'EQ=6EE=#X-"B`@(#QS;&ED
M93X-"B`@("`\<VAO<G1O<'0^1CPO<VAO<G1O<'0^#0H@("`@/&1O8SY-;W9E
M("AS;&ED92D@=&%G(&EF(&ET(&5X:7-T<SPO9&]C/@T*("`@/"]S;&ED93X-
M"B`@(#QD96QE=&4^#0H@("`@/'-H;W)T;W!T/F0\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^4F5M;W9E('1A9SPO9&]C/@T*("`@/"]D96QE=&4^#0H@("`\9')Y
M+7)U;CX-"B`@("`\<VAO<G1O<'0^;CPO<VAO<G1O<'0^#0H@("`@/&1O8SY$
M;VXF87!O<SMT(&1O(&%N>71H:6YG+"!J=7-T('!R971E;F0\+V1O8SX-"B`@
M(#PO9')Y+7)U;CX-"B`@/"]O<'1I;VYS/@T*("`\9&]C/B9L=#MP86-K86=E
M+GAM;"9G=#L-"E-E=',@82!#5E,@=&%G(&]N(&%L;"!F:6QE<R!I;B!A('!A
M8VMA9V4N("!5<V4@=&AI<R!C;VUM86YD(&%F=&5R('EO=2!H879E#0IP86-K
M86=E9"!A(&1I<W1R:6)U=&EO;B!T87)B86QL('=I=&@@=&AE("9Q=6]T.W!A
M8VMA9V4F<75O=#L@8V]M;6%N9"!T;R!T86<@=VAA=`T*<F5V:7-I;VYS(&]F
M('=H870@9FEL97,@=V5R92!I;B!T:&%T(')E;&5A<V4N("!)9B!N965D('1O
M(&9I>"!S;VUE=&AI;F<-"F%F=&5R(')U;FYI;F<@8W9S=&%G(&]N8V4L(&)U
M="!B969O<F4@=&AE('1A<F)A;&P@:7,@<F5L96%S960@=&\@=&AE('!U8FQI
M8RP-"G5S92!T:&4@)G%U;W0[<VQI9&4F<75O=#L@;W!T:6]N('1O(&UO=F4@
M=&AE(')E;&5A<V4@=&%G+@T*/"]D;V,^#0H@/"]C=G-T86<^#0H@/'!A8VMA
M9V4M9&5P96YD96YC:65S/@T*("`\<W5M;6%R>3Y3:&]W('!A8VMA9V4@9&5P
M96YD96YC:65S/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]086-K86=E1&5P
M96YD96YC:65S/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G!D/"]S:&]R=&-U
M=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SX-"DQI<W0@86QL(&1E<&5N8VEE
M<R!T:&4@<&%C:V%G92!H87,N/"]D;V,^#0H@/"]P86-K86=E+61E<&5N9&5N
M8VEE<SX-"B`\<VEG;CX-"B`@/'-U;6UA<GD^4VEG;B!A('!A8VMA9V4@9&ES
M=')I8G5T:6]N(&9I;&4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U-I9VX\
M+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<VD\+W-H;W)T8W5T/@T*("`\;W!T
M:6]N<R`O/@T*("`\9&]C/B9L=#MP86-K86=E+69I;&4F9W0[#0I3:6=N<R!A
M('!A8VMA9V4@9&ES=')I8G5T:6]N("@N=&%R(&]R("YT9WHI(&9I;&4@=VET
M:"!';G501RX\+V1O8SX-"B`\+W-I9VX^#0H@/&UA:V5R<&T^#0H@(#QS=6UM
M87)Y/D)U:6QD<R!A;B!24$T@<W!E8R!F:6QE(&9R;VT@82!014%2('!A8VMA
M9V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TUA:V524$T\+V9U;F-T:6]N
M/@T*("`\<VAO<G1C=70^<G!M/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@
M("`\<W!E8RUT96UP;&%T93X-"B`@("`\<VAO<G1O<'0^=#PO<VAO<G1O<'0^
M#0H@("`@/&%R9SY&24Q%/"]A<F<^#0H@("`@/&1O8SY5<V4@1DE,12!A<R!2
M4$T@<W!E8R!F:6QE('1E;7!L871E/"]D;V,^#0H@("`\+W-P96,M=&5M<&QA
M=&4^#0H@("`\<G!M+7!K9VYA;64^#0H@("`@/'-H;W)T;W!T/G`\+W-H;W)T
M;W!T/@T*("`@(#QA<F<^1D]234%4/"]A<F<^#0H@("`@/&1O8SY5<V4@1D]2
M34%4(&%S(&9O<FUA="!S=')I;F<@9F]R(%)032!P86-K86=E(&YA;64L("5S
M(&ES(')E<&QA8V5D#0IB>2!T:&4@4$5!4B!P86-K86=E(&YA;64L(&1E9F%U
M;'1S('1O("9Q=6]T.U!%05(Z.B5S)G%U;W0[+CPO9&]C/@T*("`@/"]R<&TM
M<&MG;F%M93X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/B9L=#MP86-K86=E+69I
M;&4F9W0[#0H-"D-R96%T97,@86X@4E!-("YS<&5C(&9I;&4@9F]R('=R87!P
M:6YG(&$@4$5!4B!P86-K86=E(&EN<VED92!A;B!24$T-"G!A8VMA9V4N("!)
M;G1E;F1E9"!T;R!B92!U<V5D(&9R;VT@=&AE(%-014-3(&1I<F5C=&]R>2P@
M=VET:"!T:&4@4$5!4@T*<&%C:V%G92!T87)B86QL(&EN('1H92!33U520T53
M(&1I<F5C=&]R>3H-"@T*)"!P96%R(&UA:V5R<&T@+BXO4T]54D-%4R].971?
M4V]C:V5T+3$N,"YT9WH-"E=R;W1E(%)032!S<&5C(&9I;&4@4$5!4CHZ3F5T
M7T=E;RTQ+C`N<W!E8PT*)"!R<&T@+6)B(%!%05(Z.DYE=%]3;V-K970M,2XP
M+G-P96,-"BXN+@T*5W)O=&4Z("]U<W(O<W)C+W)E9&AA="]24$U3+VDS.#8O
M4$5!4CHZ3F5T7U-O8VME="TQ+C`M,2YI,S@V+G)P;0T*/"]D;V,^#0H@/"]M
M86ME<G!M/@T*(#QC;VYV97)T/@T*("`\<W5M;6%R>3Y#;VYV97)T(&$@<&%C
M:V%G92YX;6P@,2XP('1O('!A8VMA9V4N>&UL(#(N,"!F;W)M870\+W-U;6UA
M<GD^#0H@(#QF=6YC=&EO;CYD;T-O;G9E<G0\+V9U;F-T:6]N/@T*("`\<VAO
M<G1C=70^8S(\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QF;&%T/@T*
M("`@(#QS:&]R=&]P=#YF/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!B
M96%U=&EF>2!T:&4@9FEL96QI<W0N/"]D;V,^#0H@("`\+V9L870^#0H@(#PO
M;W!T:6]N<SX-"B`@/&1O8SY;9&5S8V9I;&5=(%MD97-C9FEL93)=#0I#;VYV
M97)T<R!A('!A8VMA9V4N>&UL(&EN(#$N,"!F;W)M870@:6YT;R!A('!A8VMA
M9V4N>&UL#0II;B`R+C`@9F]R;6%T+B`@5&AE(&YE=R!F:6QE('=I;&P@8F4@
M;F%M960@<&%C:V%G93(N>&UL(&)Y(&1E9F%U;'0L#0IA;F0@<&%C:V%G92YX
M;6P@=VEL;"!B92!U<V5D(&%S('1H92!O;&0@9FEL92!B>2!D969A=6QT+@T*
M5&AI<R!I<R!N;W0@=&AE(&UO<W0@:6YT96QL:6=E;G0@8V]N=F5R<VEO;BP@
M86YD('-H;W5L9"!O;FQY(&)E#0IU<V5D(&9O<B!A=71O;6%T960@8V]N=F5R
M<VEO;B!O<B!L96%R;FEN9R!T:&4@9F]R;6%T+@T*/"]D;V,^#0H@/"]C;VYV
M97)T/@T*/"]C;VUM86YD<SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U!A8VMA9V4N<&AP````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S<P-#<`,3`U,34T,S$P-3<`,#(Q-3(V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]086-K86=E("AP86-K86=E+"!P
M86-K86=E+79A;&ED871E+"!C=G-D:69F+"!C=G-T86<L('!A8VMA9V4M9&5P
M96YD96YC:65S+`T*("H@<VEG;BP@;6%K97)P;2P@8V]N=F5R="!C;VUM86YD
M<RD-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`
M875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!A8VMA9V4N
M<&AP+'8@,2XQ,3D@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@
M*B!014%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@
M("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M+PT*#0IC;&%S<R!014%27T-O;6UA;F1?4&%C:V%G92!E>'1E;F1S(%!%05)?
M0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@
M("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<&%C:V%G92<@
M/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T)U:6QD(%!A
M8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K86=E
M)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W`G+`T*("`@("`@("`@
M("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N;V-O
M;7!R97-S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$
M;R!N;W0@9WII<"!T:&4@<&%C:V%G92!F:6QE)PT*("`@("`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@("=S:&]W;F%M92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4')I;G0@=&AE(&YA;64@;V8@
M=&AE('!A8VMA9V5D(&9I;&4N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD
M97-C9FEL95T@6V1E<V-F:6QE,ET-"D-R96%T97,@82!014%2('!A8VMA9V4@
M9G)O;2!I=',@9&5S8W)I<'1I;VX@9FEL92`H=7-U86QL>2!C86QL960-"G!A
M8VMA9V4N>&UL*2X@($EF(&$@<V5C;VYD('!A8VMA9V5F:6QE(&ES('!A<W-E
M9"!I;BP@=&AE;@T*=&AE('!A8VMA9V5R('=I;&P@8VAE8VL@=&\@;6%K92!S
M=7)E('1H870@;VYE(&ES(&$@<&%C:V%G92YX;6P-"G9E<G-I;VX@,2XP+"!A
M;F0@=&AE(&]T:&5R(&ES(&$@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`N("!4
M:&4-"G!A8VMA9V4N>&UL('9E<G-I;VX@,2XP('=I;&P@8F4@<V%V960@87,@
M(G!A8VMA9V4N>&UL(B!I;B!T:&4@87)C:&EV92P-"F%N9"!T:&4@;W1H97(@
M87,@(G!A8VMA9V4R+GAM;"(@:6X@=&AE(&%R8VAI=F4B#0HG#0H@("`@("`@
M("`@("`I+`T*("`@("`@("`G<&%C:V%G92UV86QI9&%T92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U9A;&ED871E(%!A8VMA9V4@
M0V]N<VES=&5N8WDG+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]0
M86-K86=E5F%L:61A=&4G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M<'8G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@
M("`@)V-V<V1I9F8G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=2=6X@82`B8W9S(&1I9F8B(&9O<B!A;&P@9FEL97,@:6X@82!P86-K
M86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0W9S1&EF9B<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C9"<L#0H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)W%U:65T
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G<2<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("="92!Q=6EE
M="<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M)W)E86QL>7%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G42<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("="92!R96%L;'D@<75I970G+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=D871E)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G1"<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=$:69F(&%G86EN<W0@<F5V:7-I;VX@;V8@1$%4
M12<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$051%)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5L96%S
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)U(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A
M9V%I;G-T('1A9R!F;W(@<&%C:V%G92!R96QE87-E(%)%3"<L#0H@("`@("`@
M("`@("`@("`@("`@("=A<F<G(#T^("=214PG+`T*("`@("`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@("=R979I<VEO;B<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E=FES
M:6]N(%)%5B<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=2158G
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=C
M;VYT97AT)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("='
M96YE<F%T92!C;VYT97AT(&1I9F8G+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=U;FEF:65D)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G=2<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("='96YE<F%T92!U;FEF:65D(&1I9F8G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO
M<F4M8V%S92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R
M=&]P="<@/3X@)VDG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M26=N;W)E(&-A<V4L(&-O;G-I9&5R('5P<&5R+2!A;F0@;&]W97(M8V%S92!L
M971T97)S(&5Q=6EV86QE;G0G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("=I9VYO<F4M=VAI=&5S<&%C92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V(G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E(&-H86YG97,@:6X@
M86UO=6YT(&]F('=H:71E('-P86-E)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E+6)L86YK+6QI;F5S)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G0B<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=)9VYO<F4@8VAA;F=E
M<R!T:&%T(&EN<V5R="!O<B!D96QE=&4@8FQA;FL@;&EN97,G+`T*("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=B<FEE9B<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=297!O<G0@
M;VYL>2!W:&5T:&5R('1H92!F:6QE<R!D:69F97(L(&YO(&1E=&%I;',G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=D<GDM
M<G5N)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;VY<
M)W0@9&\@86YY=&AI;F<L(&IU<W0@<')E=&5N9"<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D
M;V,G(#T^("<\<&%C:V%G92YX;6P^#0I#;VUP87)E<R!A;&P@=&AE(&9I;&5S
M(&EN(&$@<&%C:V%G92X@(%=I=&AO=70@86YY(&]P=&EO;G,L('1H:7,-"F-O
M;6UA;F0@=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O9&4@=VET:"!T:&4@
M;&%S="!C:&5C:V5D+6EN(&-O9&4N#0I5<VEN9R!T:&4@+7(@;W(@+5(@;W!T
M:6]N('EO=2!M87D@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AA
M=`T*;V8@82!S<&5C:69I8R!R96QE87-E+@T*)RP-"B`@("`@("`@("`@("DL
M#0H@("`@("`@("=C=G-T86<G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U
M;6UA<GDG(#T^("=3970@0U93(%)E;&5A<V4@5&%G)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O0W9S5&%G)RP-"B`@("`@("`@("`@("=S:&]R
M=&-U="<@/3X@)V-T)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`G<75I970G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=Q)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)T)E('%U:65T)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5A;&QY<75I970G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=1)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T)E(')E86QL>2!Q=6EE
M="<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M)W-L:61E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G1B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=-
M;W9E("AS;&ED92D@=&%G(&EF(&ET(&5X:7-T<R<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V1E;&5T92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V0G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4F5M;W9E('1A9R<L#0H@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V1R>2UR=6XG
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=N)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1O;EPG="!D
M;R!A;GET:&EN9RP@:G5S="!P<F5T96YD)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)SQP86-K86=E+GAM;#X@6V9I;&5S+BXN70T*4V5T<R!A($-64R!T86<@
M;VX@86QL(&9I;&5S(&EN(&$@<&%C:V%G92X@(%5S92!T:&ES(&-O;6UA;F0@
M869T97(@>6]U(&AA=F4-"G!A8VMA9V5D(&$@9&ES=')I8G5T:6]N('1A<F)A
M;&P@=VET:"!T:&4@(G!A8VMA9V4B(&-O;6UA;F0@=&\@=&%G('=H870-"G)E
M=FES:6]N<R!O9B!W:&%T(&9I;&5S('=E<F4@:6X@=&AA="!R96QE87-E+B`@
M268@;F5E9"!T;R!F:7@@<V]M971H:6YG#0IA9G1E<B!R=6YN:6YG(&-V<W1A
M9R!O;F-E+"!B=70@8F5F;W)E('1H92!T87)B86QL(&ES(')E;&5A<V5D('1O
M('1H92!P=6)L:6,L#0IU<V4@=&AE(")S;&ED92(@;W!T:6]N('1O(&UO=F4@
M=&AE(')E;&5A<V4@=&%G+@T*#0IT;R!I;F-L=61E(&9I;&5S("AS=6-H(&%S
M(&$@<V5C;VYD('!A8VMA9V4N>&UL+"!O<B!T97-T<R!N;W0@:6YC;'5D960@
M:6X@=&AE#0IR96QE87-E*2P@<&%S<R!T:&5M(&%S(&%D9&ET:6]N86P@<&%R
M86UE=&5R<RX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<&%C:V%G
M92UD97!E;F1E;F-I97,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA
M<GDG(#T^("=3:&]W('!A8VMA9V4@9&5P96YD96YC:65S)RP-"B`@("`@("`@
M("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G941E<&5N9&5N8VEE<R<L#0H@
M("`@("`@("`@("`G<VAO<G1C=70G(#T^("=P9"<L#0H@("`@("`@("`@("`G
M;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<-
M"DQI<W0@86QL(&1E<&5N8VEE<R!T:&4@<&%C:V%G92!H87,N)PT*("`@("`@
M("`@("`@*2P-"B`@("`@("`@)W-I9VXG(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@)W-U;6UA<GDG(#T^("=3:6=N(&$@<&%C:V%G92!D:7-T<FEB=71I;VX@
M9FEL92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U-I9VXG+`T*
M("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<VDG+`T*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G
M/'!A8VMA9V4M9FEL93X-"E-I9VYS(&$@<&%C:V%G92!D:7-T<FEB=71I;VX@
M*"YT87(@;W(@+G1G>BD@9FEL92!W:71H($=N=5!'+B<L#0H@("`@("`@("`@
M("`I+`T*("`@("`@("`G;6%K97)P;2<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G<W5M;6%R>2<@/3X@)T)U:6QD<R!A;B!24$T@<W!E8R!F:6QE(&9R;VT@
M82!014%2('!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G
M9&]-86ME4E!-)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)P;2<L
M#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@)W-P96,M=&5M<&QA=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=T)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V%R9R<@/3X@)T9)3$4G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G57-E($9)3$4@87,@4E!-('-P96,@9FEL92!T96UP;&%T92<-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<G!M+7!K
M9VYA;64G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T9/
M4DU!5"<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=5<V4@1D]2
M34%4(&%S(&9O<FUA="!S=')I;F<@9F]R(%)032!P86-K86=E(&YA;64L("5S
M(&ES(')E<&QA8V5D#0IB>2!T:&4@4$5!4B!P86-K86=E(&YA;64L(&1E9F%U
M;'1S('1O(")014%2.CHE<R(N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP
M86-K86=E+69I;&4^#0H-"D-R96%T97,@86X@4E!-("YS<&5C(&9I;&4@9F]R
M('=R87!P:6YG(&$@4$5!4B!P86-K86=E(&EN<VED92!A;B!24$T-"G!A8VMA
M9V4N("!);G1E;F1E9"!T;R!B92!U<V5D(&9R;VT@=&AE(%-014-3(&1I<F5C
M=&]R>2P@=VET:"!T:&4@4$5!4@T*<&%C:V%G92!T87)B86QL(&EN('1H92!3
M3U520T53(&1I<F5C=&]R>3H-"@T*)"!P96%R(&UA:V5R<&T@+BXO4T]54D-%
M4R].971?4V]C:V5T+3$N,"YT9WH-"E=R;W1E(%)032!S<&5C(&9I;&4@4$5!
M4CHZ3F5T7T=E;RTQ+C`N<W!E8PT*)"!R<&T@+6)B(%!%05(Z.DYE=%]3;V-K
M970M,2XP+G-P96,-"BXN+@T*5W)O=&4Z("]U<W(O<W)C+W)E9&AA="]24$U3
M+VDS.#8O4$5!4CHZ3F5T7U-O8VME="TQ+C`M,2YI,S@V+G)P;0T*)RP-"B`@
M("`@("`@("`@("DL#0H@("`@("`@("=C;VYV97)T)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G0V]N=F5R="!A('!A8VMA9V4N>&UL
M(#$N,"!T;R!P86-K86=E+GAM;"`R+C`@9F]R;6%T)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O0V]N=F5R="<L#0H@("`@("`@("`@("`G<VAO
M<G1C=70G(#T^("=C,B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@)V9L870G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=F)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!B96%U=&EF>2!T:&4@9FEL96QI
M<W0N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C9FEL95T@6V1E<V-F
M:6QE,ET-"D-O;G9E<G1S(&$@<&%C:V%G92YX;6P@:6X@,2XP(&9O<FUA="!I
M;G1O(&$@<&%C:V%G92YX;6P-"FEN(#(N,"!F;W)M870N("!4:&4@;F5W(&9I
M;&4@=VEL;"!B92!N86UE9"!P86-K86=E,BYX;6P@8GD@9&5F875L="P-"F%N
M9"!P86-K86=E+GAM;"!W:6QL(&)E('5S960@87,@=&AE(&]L9"!F:6QE(&)Y
M(&1E9F%U;'0N#0I4:&ES(&ES(&YO="!T:&4@;6]S="!I;G1E;&QI9V5N="!C
M;VYV97)S:6]N+"!A;F0@<VAO=6QD(&]N;'D@8F4-"G5S960@9F]R(&%U=&]M
M871E9"!C;VYV97)S:6]N(&]R(&QE87)N:6YG('1H92!F;W)M870N#0HG#0H@
M("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@=F%R("1O=71P=70[
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@
M("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]086-K86=E(&-O;G-T<G5C=&]R
M+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!014%27T-O;6UA;F1?4&%C:V%G92@F)'5I+"`F)&-O;F9I
M9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO
M;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@
M+R\@>WM[(%]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H*0T*#0H@("`@9G5N
M8W1I;VX@7V1I<W!L87E686QI9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R;BP@
M)'-T<FEC="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@9F]R96%C:"`H)&5R
M<B!A<R`D92D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B17)R
M;W(Z("1E7&XB.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1W87)N
M(&%S("1W*2![#0H@("`@("`@("`@("`D=&AI<RT^;W5T<'5T("X](")787)N
M:6YG.B`D=UQN(CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;W5T<'5T
M("X]('-P<FEN=&8H)U9A;&ED871I;VXZ("5D(&5R<F]R*',I+"`E9"!W87)N
M:6YG*',I)RXB7&XB+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<VEZ96]F*"1E<G(I+"!S:7IE;V8H)'=A<FXI*3L-"B`@("`@
M("`@:68@*"1S=')I8W0@)B8@<VEZ96]F*"1E<G(I(#X@,"D@>PT*("`@("`@
M("`@("`@)'1H:7,M/F]U='!U="`N/2`B1FEX('1H97-E(&5R<F]R<R!A;F0@
M=')Y(&%G86EN+B([#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5R*"D-"B`@("![#0H@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5R)RDI('L-"B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E<BYP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5R.PT*
M("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E
M=%!A8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U9R`](&9A;'-E+"`D=&UP9&ER
M(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O0V]M;6]N+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;&%S
M<U]E>&ES=',H)U!%05(O4&%C:V%G949I;&4N<&AP)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@
M("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C
M;VYF:6<L("1D96)U9RP@)'1M<&1I<BD[#0H@("`@("`@("1C;VUM;VX@/2!N
M97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1C;VUM;VXM/G5I(#T@)'1H:7,M
M/G5I.PT*("`@("`@("`D82T^<V5T3&]G9V5R*"1C;VUM;VXI.PT*("`@("`@
M("!R971U<FX@)&$[#0H@("`@?0T*("`@("\O('M[>R!D;U!A8VMA9V4H*0T*
M#0H@("`@9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-
M"B`@("`@("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A<F%M<ULP72D@/R`D
M<&%R86US6S!=(#H@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@)'!K9S(@/2!I
M<W-E="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!N=6QL.PT*("`@("`@
M("!I9B`H(21P:V<R("8F("%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@
M("`@("`@:68@*&9I;&5?97AI<W1S*"=P86-K86=E,BYX;6PG*2D@>PT*("`@
M("`@("`@("`@("`@("1P:V<R(#T@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5R(#T@)B1T:&ES
M+3YG971086-K86=E<B@I.PT*("`@("`@("`D8V]M<')E<W,@/2!E;7!T>2@D
M;W!T:6]N<ULG;F]C;VUP<F5S<R==*2`_('1R=64@.B!F86QS93L-"B`@("`@
M("`@)')E<W5L="`]("1P86-K86=E<BT^<&%C:V%G92@D<&MG:6YF;V9I;&4L
M("1C;VUP<F5S<RP@)'!K9S(I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1R97-U;'0I.PT*("`@("`@("!]#0H@("`@("`@("\O($1O;B=T
M('=A;G0@;W5T<'5T+"!O;FQY('1H92!P86-K86=E(&9I;&4@;F%M92!J=7-T
M(&-R96%T960-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S:&]W;F%M
M92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`]("1R97-U;'0[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YO=71P=70I('L-"B`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T
M+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4&%C:V%G959A
M;&ED871E*"D-"@T*("`@(&9U;F-T:6]N(&1O4&%C:V%G959A;&ED871E*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T
M:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US
M*2`\(#$I('L-"B`@("`@("`@("`@("1P87)A;7-;,%T@/2`B<&%C:V%G92YX
M;6PB.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F)'1H:7,M/F=E=%!A
M8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@
M("`@("`D;V)J+3YR87=2971U<FXH*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC
M4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`D:6YF;R`]("1O8FHM/F9R;VU49WI&:6QE*"1P87)A;7-;,%TL(%!%05)?
M5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&EN9F\I*2![#0H@("`@("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU086-K
M86=E1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D87)C:&EV92`]("1I;F9O
M+3YG971!<F-H:79E1FEL92@I.PT*("`@("`@("`@("`@)'1A<B`]("9N97<@
M07)C:&EV95]487(H)&%R8VAI=F4I.PT*("`@("`@("`@("`@)'1A<BT^97AT
M<F%C="AD:7)N86UE*"1I;F9O+3YG971086-K86=E1FEL92@I*2D[#0H@("`@
M("`@("`@("`D:6YF;RT^<V5T4&%C:V%G949I;&4H9&ER;F%M92@D:6YF;RT^
M9V5T4&%C:V%G949I;&4H*2D@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@
M("`@("`@("`@("`@("`D:6YF;RT^9V5T4&%C:V%G92@I("X@)RTG("X@)&EN
M9F\M/F=E=%9E<G-I;VXH*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@
M("`@("`@("`@("`@(&)A<V5N86UE*"1I;F9O+3YG971086-K86=E1FEL92@I
M*2D[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF
M;RD[#0H@("`@("`@('T-"B`@("`@("`@)'9A;&ED(#T@9F%L<V4[#0H@("`@
M("`@(&EF("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP
M)RD@>PT*("`@("`@("`@("`@:68@*"1V86QI9"`]("1I;F9O+3YV86QI9&%T
M92A014%27U9!3$E$051%7TY/4DU!3"DI('L-"B`@("`@("`@("`@("`@("`D
M:6YF;RT^9FQA='1E;D9I;&5,:7-T*"D[#0H@("`@("`@("`@("`@("`@)'9A
M;&ED(#T@)&EN9F\M/G9A;&ED871E*%!%05)?5D%,241!5$5?4$%#2T%'24Y'
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1V86QI9"`]("1I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%7U!!
M0TM!1TE.1RD[#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`](&%R<F%Y*"D[
M#0H@("`@("`@("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@:68@*"$D=F%L
M:60I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG971686QI9&%T
M:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("!I
M9B`H)&5R<F]R6R=L979E;"==(#T]("=W87)N:6YG)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&5R
M<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&ES
M<&QA>59A;&ED871I;VY297-U;'1S*"1E<G(L("1W87)N*3L-"B`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"1T:&ES+3YO=71P=70L("1C;VUM86YD
M*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&1O0W9S5&%G*"D-"@T*("`@(&9U;F-T:6]N(&1O0W9S
M5&%G*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@
M("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@)%]C;60@/2`D8V]M
M;6%N9#L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@
M("`@("`@("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I.PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N
M9#H@;6ES<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@('T-
M"B`@("`@("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M
M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B
M:BT^9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-
M04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@
M("`@("`@('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-"B`@
M("`@("`@:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@
M9F]R96%C:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1E
M<G)O<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@
M/3T@)W=A<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N6UT@
M/2`D97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE<W-A
M9V4G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N
M4F5S=6QT<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-64R!T
M86<@9F%I;&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@)'9E<G-I;VX@/2`D
M:6YF;RT^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D8W9S=F5R<VEO;B`]('!R
M96=?<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D=F5R<VEO;BD[#0H@
M("`@("`@("1C=G-T86<@/2`B4D5,14%315\D8W9S=F5R<VEO;B([#0H@("`@
M("`@("1F:6QE<R`](&%R<F%Y7VME>7,H)&EN9F\M/F=E=$9I;&5L:7-T*"DI
M.PT*("`@("`@("`D8V]M;6%N9"`](")C=G,B.PT*("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)W%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M;6%N
M9"`N/2`G("UQ)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)W)E86QL>7%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M;6%N
M9"`N/2`G("U1)SL-"B`@("`@("`@?0T*("`@("`@("`D8V]M;6%N9"`N/2`G
M('1A9R<[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VQI9&4G72DI
M('L-"B`@("`@("`@("`@("1C;VUM86YD("X]("<@+48G.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&5L971E)UTI*2![#0H@
M("`@("`@("`@("`D8V]M;6%N9"`N/2`G("UD)SL-"B`@("`@("`@?0T*("`@
M("`@("`D8V]M;6%N9"`N/2`G("<@+B`D8W9S=&%G("X@)R`G("X@97-C87!E
M<VAE;&QA<F<H)'!A<F%M<ULP72D[#0H@("`@("`@(&%R<F%Y7W-H:69T*"1P
M87)A;7,I.PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@
M("`@("`@("\O(&%D9"!I;B!A9&1I=&EO;F%L(&9I;&5S('1O(&)E('1A9V=E
M9`T*("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"`D
M<&%R86US*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9FEL97,@
M87,@)&9I;&4I('L-"B`@("`@("`@("`@("1C;VUM86YD("X]("<@)R`N(&5S
M8V%P97-H96QL87)G*"1F:6QE*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q*2![#0H@("`@("`@
M("`@("`D=&AI<RT^;W5T<'5T("X]("(K("1C;VUM86YD7&XB.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-O;6UA;F1<;B([
M#0H@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9')Y+7)U;B==*2D@>PT*
M("`@("`@("`@("`@)&9P(#T@<&]P96XH)&-O;6UA;F0L(")R(BD[#0H@("`@
M("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2!R=')I;2@D;&EN92DN
M(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('!C;&]S92@D9G`I
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D
M=&AI<RT^;W5T<'5T+"`D7V-M9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-V<T1I9F8H*0T*
M#0H@("`@9G5N8W1I;VX@9&]#=G-$:69F*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-
M"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@("`@
M("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@;6ES
M<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@('T-"B`@("`@
M("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I
M9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O
M;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@
M('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@
M:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@9F]R96%C
M:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1E<G)O<BD@
M>PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@/3T@)W=A
M<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N6UT@/2`D97)R
M;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE<W-A9V4G73L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N4F5S=6QT
M<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-64R!D:69F(&9A
M:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O,2`]("1I;F9O+3YG
M971&:6QE;&ES="@I.PT*("`@("`@("`D9FEL97,@/2`D:6YF;S$[#0H@("`@
M("`@("1C;60@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=Q=6EE="==*2D@>PT*("`@("`@("`@("`@)&-M9"`N/2`G("UQ)SL-"B`@
M("`@("`@("`@('5N<V5T*"1O<'1I;VYS6R=Q=6EE="==*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI
M*2![#0H@("`@("`@("`@("`D8VUD("X]("<@+5$G.PT*("`@("`@("`@("`@
M=6YS970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<F5L96%S92==*2D@>PT*("`@
M("`@("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E<&QA8V4H)R];7F$M>C`M
M.5TO:2<L("=?)RP@)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@("`@
M("`D8W9S=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@("`@
M("`@)&]P=&EO;G-;)W)E=FES:6]N)UT@/2`D8W9S=&%G.PT*("`@("`@("`@
M("`@=6YS970H)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@('T-"B`@
M("`@("`@)&5X96-U=&4@/2!T<G5E.PT*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)V1R>2UR=6XG72DI('L-"B`@("`@("`@("`@("1E>&5C=71E(#T@
M9F%L<V4[#0H@("`@("`@("`@("!U;G-E="@D;W!T:6]N<ULG9')Y+7)U;B==
M*3L-"B`@("`@("`@?0T*("`@("`@("`D8VUD("X]("<@9&EF9B<[#0H@("`@
M("`@("\O('1H92!R97-T(&]F('1H92!O<'1I;VYS(&%R92!P87-S960@<FEG
M:'0@;VX@=&\@(F-V<R!D:69F(@T*("`@("`@("!F;W)E86-H("@D;W!T:6]N
M<R!A<R`D;W!T:6]N(#T^("1O<'1A<F<I('L-"B`@("`@("`@("`@("1A<F<@
M/2!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T:6]N<R==6R1O<'1I
M;VY=6R=A<F<G73L-"B`@("`@("`@("`@("1S:&]R="`]($`D=&AI<RT^8V]M
M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UU;)&]P=&EO;EU;)W-H;W)T;W!T
M)UT[#0H@("`@("`@("`@("`D8VUD("X]("1S:&]R="`_("(@+21S:&]R="(@
M.B`B("TM)&]P=&EO;B([#0H@("`@("`@("`@("!I9B`H)&%R9R`F)B`D;W!T
M87)G*2![#0H@("`@("`@("`@("`@("`@)&-M9"`N/2`H)'-H;W)T(#\@)R<@
M.B`G/2<I("X@97-C87!E<VAE;&QA<F<H)&]P=&%R9RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F
M:6QE*2![#0H@("`@("`@("`@("`D8VUD("X]("<@)R`N(&5S8V%P97-H96QL
M87)G*"1F:6QE6R=N86UE)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#$I('L-"B`@("`@("`@
M("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-M9%QN(CL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&5X96-U=&4I('L-"B`@("`@("`@("`@("1F<"`]('!O
M<&5N*"1C;60L(")R(BD[#0H@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F
M9V5T<R@D9G`L(#$P,C0I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U
M='!U="`N/2!R=')I;2@D;&EN92DN(EQN(CL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('!C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!D;U!A8VMA9V5$97!E;F1E;F-I97,H*0T*#0H@("`@9G5N
M8W1I;VX@9&]086-K86=E1&5P96YD96YC:65S*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("\O("1P87)A;7-;,%T@+3X@
M=&AE(%!%05(@<&%C:V%G92!T;R!L:7-T(&ET<R!I;F9O<FUA=&EO;@T*("`@
M("`@("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8F%D('!A<F%M971E<BAS*2P@
M=')Y(%PB:&5L<"`D8V]M;6%N9%PB(BD[#0H@("`@("`@('T-"B`@("`@("`@
M)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@
M)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;4%N
M>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-
M"B`@("`@("`@)&1E<',@/2`D:6YF;RT^9V5T1&5P<R@I.PT*("`@("`@("!I
M9B`H:7-?87)R87DH)&1E<',I*2![#0H@("`@("`@("`@("!I9B`H)&EN9F\M
M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@("`@
M("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M8V%P=&EO;B<@/3X@)T1E<&5N9&5N8VEE<R!F;W(@<&5A<B\G("X@)&EN9F\M
M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@)V)O<F1E<B<@
M/3X@=')U92P-"B`@("`@("`@("`@("`@("`@("`@)VAE861L:6YE)R`]/B!A
M<G)A>2@B4F5Q=6ER960_(BP@(E1Y<&4B+"`B3F%M92(L(")296QA=&EO;B(L
M(")697)S:6]N(BDL#0H@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9"D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1;)V]P=&EO;F%L)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&1;)V]P=&EO;F%L)UT@/3T@)WEE
M<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@)TYO
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7V1E<'-?<F5L7W1R86YS6R1D6R=R96PG75TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5L(#T@)'1H:7,M/E]D97!S7W)E
M;%]T<F%N<ULD9%LG<F5L)UU=.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E;"`]("1D6R=R96PG
M73L-"B`@("`@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP
M92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@=6-F
M:7)S="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP92==72D[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D='EP92`]("1D6R=T>7!E)UT[#0H@("`@("`@("`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)VYA
M;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)&1;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@("`@("`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;
M)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S
M:6]N(#T@)&1;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)R<[
M#0H@("`@("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@
M("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D<F5Q+"`D='EP92P@)&YA;64L
M("1R96PL("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!](&5L<V4@>R`O+R!P86-K86=E+GAM;"`R+C`@9&5P96YD96YC:65S
M(&1I<W!L87D-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O
M1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@("`@("`@("`D9&5P<R`]("1I
M;F9O+3YG971$97!E;F1E;F-I97,H*3L-"B`@("`@("`@("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1D97!S*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D9"`](&YE=R!014%27T1E<&5N9&5N8WDR*"1T:&ES+3YC;VYF:6<L
M(&%R<F%Y*"DL("<G*3L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G
M1&5P96YD96YC:65S(&9O<B`G("X@)&EN9F\M/F=E=%!A8VMA9V4H*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*")297%U
M:7)E9#\B+"`B5'EP92(L(").86UE(BP@)U9E<G-I;VYI;F<G+"`G1W)O=7`G
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1T>7!E(#T^("1S=6)D*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@*"1T>7!E(#T]("=R97%U
M:7)E9"<I(#\@)UEE<R<@.B`G3F\G.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1T>7!E(#T]("=G<F]U<"<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9W)O=7`@/2`D<W5B9%LG871T<FEB<R==6R=N86UE)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1G<F]U<"`]("<G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D<W5B9%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<W5B9"`](&%R<F%Y*"1S=6)D*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S=6)D
M(&%S("1G<F]U<&$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9W)O=7!A(&%S("1D97!T>7!E(#T^("1D97!I;F9O*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P='EP92`]
M/2`G871T<FEB<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M9&5P='EP92`]/2`G<&5A<FEN<W1A;&QE<B<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D97!T>7!E(#T@)W!E87(@26YS=&%L
M;&5R)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!I
M;F9O6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<&EN9F\@/2!A<G)A>2@D9&5P:6YF;RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&1E<&EN9F\@87,@)&EN9BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M:6YF6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&%L:6%S(#T@)')E9RT^8VAA;FYE;$%L:6%S*"1I
M;F9;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"$D86QI87,I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)RAC:&%N;F5L
M/RD@)R`N)&EN9ELG8VAA;FYE;"==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F%M92`]("1A;&EA<R`N("<O)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=N86UE
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@+CT@)&EN9ELG;F%M92==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1I;F9;)W!A='1E
M<FXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92`N/2`D:6YF6R=P871T97)N)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE("X]("<G.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9;)W5R
M:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N86UE("X]("<@6R<@+B`D:6YF6R=U<FDG72`N("`G72<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG8V]N
M9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9E<B`]("=C;VYF;&EC=',G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F5R(#T@)&0M/E]G971%>'1R
M85-T<FEN9R@D:6YF*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A6R=D871A)UU;72`](&%R<F%Y*"1R97$L('5C9FER<W0H)&1E<'1Y
M<&4I+"`D;F%M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F5R+"`D9W)O=7`I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD
M*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H-"B`@
M("`@("`@+R\@1F%L;&)A8VL-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*")4:&ES('!A8VMA9V4@9&]E<R!N;W0@:&%V92!A;GD@9&5P96YD96YC
M:65S+B(L("1C;VUM86YD*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9&]3:6=N*"D-"@T*("`@(&9U;F-T:6]N(&1O4VEG;B@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!R97%U:7)E
M7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("!R97%U:7)E7V]N8V4@)T%R
M8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@("\O('-H;W5L9"!M;W9E(&UO<W0@
M;V8@=&AI<R!C;V1E(&EN=&\@4$5!4E]086-K86=E<@T*("`@("`@("`O+R!S
M;R!I="=L;"!B92!E87-Y('1O(&EM<&QE;65N="`B<&5A<B!P86-K86=E("TM
M<VEG;B(-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A9"!P87)A
M;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M<ULP72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92!D;V5S
M(&YO="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@("!]#0H@("`@("`@
M("1O8FH@/2`D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@
M)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;51G
M>D9I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-
M"B`@("`@("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D<&%R86US6S!=*3L-
M"B`@("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*"<M9"!P96%R<VEG
M;B<I.PT*("`@("`@("!I9B`H(21T87(M/F5X=')A8W1,:7-T*"=P86-K86=E
M,BYX;6P@<&%C:V%G92YS:6<G+"`D=&UP9&ER*2D@>PT*("`@("`@("`@("`@
M:68@*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G92YX;6P@<&%C:V%G92YS
M:6<G+"`D=&UP9&ER*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&5X=')A8W0@=&%R(&9I;&4B*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL95]E
M>&ES=',H(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")P86-K86=E(&%L<F5A9'D@<VEG
M;F5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5X;6P@/2`G<&%C
M:V%G92YX;6PG.PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H(B1T;7!D:7(O
M<&%C:V%G93(N>&UL(BDI('L-"B`@("`@("`@("`@("1P86-K86=E>&UL(#T@
M)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@0'5N;&EN:R@B
M)'1M<&1I<B]P86-K86=E+G-I9R(I.PT*("`@("`@("`D:6YP=70@/2`D=&AI
M<RT^=6DM/G5S97)$:6%L;V<H)&-O;6UA;F0L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G1VYU4$<@4&%S<W!H<F%S
M92<I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)W!A<W-W;W)D)RDI.PT*("`@("`@("`D9W!G(#T@<&]P96XH(F=P
M9R`M+6)A=&-H("TM<&%S<W!H<F%S92UF9"`P("TM87)M;W(@+2UD971A8V@M
M<VEG;B`M+6]U='!U="`D=&UP9&ER+W!A8VMA9V4N<VEG("1T;7!D:7(O)'!A
M8VMA9V5X;6P@,CXO9&5V+VYU;&PB+"`B=R(I.PT*("`@("`@("!I9B`H(21G
M<&<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M9W!G(&-O;6UA;F0@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@9G=R
M:71E*"1G<&<L("(D:6YP=71;,%U<;B(I.PT*("`@("`@("!I9B`H<&-L;W-E
M*"1G<&<I('Q\("%F:6QE7V5X:7-T<R@B)'1M<&1I<B]P86-K86=E+G-I9R(I
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F=P
M9R!S:6=N(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@("1T87(M/F%D
M9$UO9&EF>2@B)'1M<&1I<B]P86-K86=E+G-I9R(L("<G+"`D=&UP9&ER*3L-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-
M"B`@("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$EN<W1A;&QE<B@F)'5I*0T*("`@
M('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?26YS=&%L;&5R
M)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]);G-T86QL
M97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E])
M;G-T86QL97(H)'5I*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"B`@
M("`-"B`@("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$-O;6UA;F1086-K86=I;F<H
M)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X
M:7-T<R@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R<I*2![#0H@("`@("`@("`@
M("!`:6YC;'5D95]O;F-E("=014%2+T-O;6UA;F0O4&%C:V%G:6YG+G!H<"<[
M#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("AC;&%S<U]E>&ES
M=',H)U!%05)?0V]M;6%N9%]086-K86=I;F<G*2D@>PT*("`@("`@("`@("`@
M)&$@/2`F;F5W(%!%05)?0V]M;6%N9%]086-K86=I;F<H)'5I+"`D8V]N9FEG
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@;G5L;#L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@
M+R\@>WM[(&1O36%K95)032@I#0H-"B`@("!F=6YC=&EO;B!D;TUA:V524$TH
M)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*#0H@("`@("`@("\O($-H96-K('1O
M('-E92!I9B!014%27T-O;6UA;F1?4&%C:V%G:6YG(&ES(&EN<W1A;&QE9"P@
M86YD#0H@("`@("`@("\O('1R86YS<&%R96YT;'D@<W=I=&-H('1O('5S92!T
M:&4@(FUA:V4M<G!M+7-P96,B(&-O;6UA;F0@9G)O;2!I=`T*("`@("`@("`O
M+R!I;G-T96%D+"!I9B!I="!D;V5S+B!/=&AE<G=I<V4L(&-O;G1I;G5E('1O
M('5S92!T:&4@;VQD('9E<G-I;VX-"B`@("`@("`@+R\@;V8@(FUA:V5R<&TB
M('-U<'!L:65D('=I=&@@=&AI<R!P86-K86=E("A014%2*2X-"B`@("`@("`@
M)'!A8VMA9VEN9U]C;60@/2`D=&AI<RT^9V5T0V]M;6%N9%!A8VMA9VEN9R@D
M=&AI<RT^=6DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!I9B`H)'!A8VMA
M9VEN9U]C;60@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R!I<R!I;G-T86QL
M960[('5S:6YG("<N#0H@("`@("`@("`@("`@("`@)VYE=V5R(")M86ME+7)P
M;2US<&5C(B!C;VUM86YD(&EN<W1E860G*3L-"B`@("`@("`@("`@(')E='5R
M;B`D<&%C:V%G:6YG7V-M9"T^<G5N*"=M86ME+7)P;2US<&5C)RP@)&]P=&EO
M;G,L("1P87)A;7,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"=705).24Y'.B`B<&5A<B!M86ME<G!M
M(B!I<R!N;W<@9&5P<F5C871E9#L@86X@)RX-"B`@("`@("`@("`@("`@)VEM
M<')O=F5D('9E<G-I;VX@:7,@879A:6QA8FQE('9I82`B<&5A<B!M86ME+7)P
M;2US<&5C(BP@=VAI8V@@)RX-"B`@("`@("`@("`@("`@)VES(&%V86EL86)L
M92!B>2!I;G-T86QL:6YG(%!%05)?0V]M;6%N9%]086-K86=I;F<G*3L-"B`@
M("`@("`@?0T*("`@("`@("`-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US
M*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(F)A9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M
M<ULP72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B9FEL92!D;V5S(&YO="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@
M("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T
M<GDH*3L-"B`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H
M)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1P9B`]
M("8D<&MG+3YF<F]M06YY1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%
M7TY/4DU!3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-
M"B`@("`@("`@("`@("1U(#T@)'!F+3YG9715<V5R:6YF;R@I.PT*("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1U*2D@>PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1U(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M97)R(#T@)&5R<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D
M97)R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1P87)A;7-;,%T@
M:7,@;F]T(&$@=F%L:60@<&%C:V%G92(I.PT*("`@("`@("!]#0H@("`@("`@
M("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G+"`G<&5A<C)R
M<&TG*2D[#0H@("`@("`@("1I;G-T<F]O="`](%-Y<W1E;3HZ;6MT96UP*&%R
M<F%Y*"<M9"<L("=P96%R,G)P;2<I*3L-"B`@("`@("`@)'1M<"`]("1T:&ES
M+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@("`D=&AI<RT^8V]N
M9FEG+3YS970H)W9E<F)O<V4G+"`P*3L-"B`@("`@("`@)&EN<W1A;&QE<B`]
M("1T:&ES+3YG971);G-T86QL97(H)'1H:7,M/G5I*3L-"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(O4&%C:V%G92YP:'`G.PT*("`@
M("`@("`D<&%C:R`](&YE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D:6YS
M=&%L;&5R*3L-"B`@("`@("`@)'!A8VLM/G-E=%!A8VMA9V5&:6QE*"1P9BD[
M#0H@("`@("`@("1P87)A;7-;,%T@/2`F)'!A8VL[#0H@("`@("`@("1I;G-T
M86QL97(M/G-E=$]P=&EO;G,H87)R87DH)VEN<W1A;&QR;V]T)R`]/B`D:6YS
M=')O;W0L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;F]D97!S)R`]/B!T<G5E+"`G<V]F="<@/3X@=')U92DI.PT*("`@
M("`@("`D:6YS=&%L;&5R+3YS971$;W=N;&]A9&5D4&%C:V%G97,H)'!A<F%M
M<RD[#0H@("`@("`@("1I;F9O(#T@)&EN<W1A;&QE<BT^:6YS=&%L;"@D<&%R
M86US6S!=+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)VEN<W1A;&QR;V]T)R`]/B`D:6YS=')O;W0L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]D97!S)R`]/B!T
M<G5E+"`G<V]F="<@/3X@=')U92DI.PT*("`@("`@("`D<&MG9&ER(#T@)'!F
M+3YG971086-K86=E*"D@+B`G+2<@+B`D<&8M/F=E=%9E<G-I;VXH*3L-"B`@
M("`@("`@)&EN9F];)W)P;5]X;6Q?9&ER)UT@/2`G+W9A<B]L:6(O<&5A<B<[
M#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G=F5R8F]S92<L("1T;7`I
M.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-P96,M=&5M<&QA=&4G
M72DI('L-"B`@("`@("`@("`@("1S<&5C7W1E;7!L871E(#T@)&]P=&EO;G-;
M)W-P96,M=&5M<&QA=&4G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1S<&5C7W1E;7!L871E(#T@)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1A=&$O4$5!4B]T96UP;&%T92YS<&5C)SL-"B`@("`@("`@?0T*
M("`@("`@("`D:6YF;ULG<&]S<VEB;&5?8VAA;FYE;"==(#T@)R<[#0H@("`@
M("`@("1I;F9O6R=E>'1R85]C;VYF:6<G72`]("<G.PT*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)W)P;2UP:V=N86UE)UTI*2![#0H@("`@("`@("`@
M("`D<G!M7W!K9VYA;65?9F]R;6%T(#T@)&]P=&EO;G-;)W)P;2UP:V=N86UE
M)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H)'!F+3YG
M971#:&%N;F5L*"D@/3T@)W!E87(N<&AP+FYE="<@?'P@)'!F+3YG971#:&%N
M;F5L*"D@/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`D
M86QI87,@/2`G4$5!4B<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)'!F+3YG971#
M:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D86QI87,@/2`D8VAA;BT^9V5T06QI87,H*3L-"B`@("`@
M("`@("`@("`@("`D86QI87,@/2!S=')T;W5P<&5R*"1A;&EA<RD[#0H@("`@
M("`@("`@("`@("`@)&EN9F];)W!O<W-I8FQE7V-H86YN96PG72`]("1P9BT^
M9V5T0VAA;FYE;"@I("X@)R\G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)')P;5]P:V=N86UE7V9O<FUA="`]("1A;&EA<R`N("<Z.B5S)SL-"B`@
M("`@("`@?0T*#0H@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@/2`G
M)SL-"B`@("`@("`@)&EN9F];)V1O8U]F:6QE<R==(#T@)R<[#0H@("`@("`@
M("1I;F9O6R=F:6QE<R==(#T@)R<[#0H@("`@("`@("1I;F9O6R=P86-K86=E
M,GAM;"==(#T@)R<[#0H@("`@("`@("1I;F9O6R=R<&U?<&%C:V%G92==(#T@
M<W!R:6YT9B@D<G!M7W!K9VYA;65?9F]R;6%T+"`D<&8M/F=E=%!A8VMA9V4H
M*2D[#0H@("`@("`@("1S<F-F:6QE<R`](#`[#0H@("`@("`@(&9O<F5A8V@@
M*"1I;F9O6R=F:6QE;&ES="==(&%S("1N86UE(#T^("1A='1R*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1A='1R6R=R;VQE)UTI*2![#0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D;F%M92`]('!R96=?<F5P;&%C92@G(5LO.EQ<7%Q=(2<L("<O)RP@)&YA
M;64I.PT*("`@("`@("`@("`@:68@*"1A='1R6R=R;VQE)UT@/3T@)V1O8R<I
M('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG9&]C7V9I;&5S)UT@+CT@(B`D
M;F%M92([#0H@("`@("`@("`@("`O+R!-87`@<F]L92!T;R!T:&4@<G!M('9A
M<G,-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&-?
M<')E9FEX(#T@)R5[7VQI8F1I<GTO<&AP+W!E87(G.PT*("`@("`@("`@("`@
M("`@('-W:71C:"`H)&%T=');)W)O;&4G72D@>PT*("`@("`@("`@("`@("`@
M("`@("!C87-E("=P:'`G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'!R
M969I>"`]("1C7W!R969I>#L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V5X="<Z#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<')E9FEX(#T@)R5[7VQI8F1I<GTO<&AP)SL-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[("\O(%A86"!G;V]D('!L86-E/PT*
M("`@("`@("`@("`@("`@("`@("!C87-E("=S<F,G.@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-R8V9I;&5S*RL[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<')E9FEX(#T@)R5[7VEN8VQU9&5D:7)]+W!H<"<[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.R`O+R!86%@@9V]O9"!P;&%C93\-"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G=&5S="<Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<')E9FEX(#T@(B1C7W!R969I>"]T97-T<R\B("X@)'!F+3YG
M971086-K86=E*"D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!C87-E("=D871A)SH-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+V1A=&$O(B`N("1P9BT^
M9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G<V-R:7!T)SH-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P<F5F:7@@/2`G)7M?8FEN9&ER?2<[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!D969A
M=6QT.B`O+R!N;VXM<W1A;F1A<F0@<F]L97,-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+R1A='1R6W)O;&5=+R(@+B`D
M<&8M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R=E>'1R85]C;VYF:6<G72`N/0T*("`@("`@("`@("`@("`@("`@("`@
M("`@(EQN("`@("`@("`M9"![)&%T=');<F]L95U]7V1I<CTD8U]P<F5F:7@O
M>R1A='1R6W)O;&5=?2!<7"([#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(')O;&4@(B<@+B`D871T
M<ELG<F]L92==("X@)R(@=7-E9"P@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V%N9"!W:6QL(&)E(&EN<W1A;&QE9"!I;B`B)R`N("1C7W!R
M969I>"`N("<O)R`N("1A='1R6R=R;VQE)UT@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<O)R`N("1P9BT^9V5T4&%C:V%G92@I("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G("T@:&%N9"UE9&ET('1H92!F:6YA
M;"`N<W!E8R!I9B!T:&ES(&ES('=R;VYG)RP@)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&YA;64@/2!S=')?<F5P;&%C92@G7%PG+"`G+R<L("1N
M86UE*3L-"B`@("`@("`@("`@("`@("`D:6YF;ULG9FEL97,G72`N/2`B)'!R
M969I>"\D;F%M95QN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'-R8V9I;&5S(#X@,"D@>PT*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=/4R]'=65S<RYP:'`G.PT*("`@("`@("`@("`@)&]S(#T@;F5W
M($]37T=U97-S.PT*("`@("`@("`@("`@)&%R8V@@/2`D;W,M/F=E=$-P=2@I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&%R8V@@/2`G;F]A
M<F-H)SL-"B`@("`@("`@?0T*("`@("`@("`D8V9G(#T@87)R87DH)VUA<W1E
M<E]S97)V97(G+"`G<&AP7V1I<B<L("=E>'1?9&ER)RP@)V1O8U]D:7(G+`T*
M("`@("`@("`@("`@("`@("`@("`@)V)I;E]D:7(G+"`G9&%T85]D:7(G+"`G
M=&5S=%]D:7(G*3L-"B`@("`@("`@9F]R96%C:"`H)&-F9R!A<R`D:RD@>PT*
M("`@("`@("`@("`@:68@*"1K(#T]("=M87-T97)?<V5R=F5R)RD@>PT*("`@
M("`@("`@("`@("`@("1C:&%N(#T@)')E9RT^9V5T0VAA;FYE;"@D<&8M/F=E
M=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1I;F9O6R1K72`]("1C:&%N+3YG971397)V97(H*3L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1I;F9O6R1K72`]("1T:&ES+3YC;VYF:6<M/F=E="@D:RD[
M#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)V%R8V@G72`]("1A<F-H.PT*
M("`@("`@("`D9G`@/2!`9F]P96XH)'-P96-?=&5M<&QA=&4L(")R(BD[#0H@
M("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!O<&5N(%)032!S<&5C(&9I;&4@=&5M
M<&QA=&4@)'-P96-?=&5M<&QA=&4Z("1P:'!?97)R;W)M<V<B*3L-"B`@("`@
M("`@?0T*("`@("`@("`D:6YF;ULG<&%C:V%G92==(#T@)'!F+3YG971086-K
M86=E*"D[#0H@("`@("`@("1I;F9O6R=V97)S:6]N)UT@/2`D<&8M/F=E=%9E
M<G-I;VXH*3L-"B`@("`@("`@)&EN9F];)W)E;&5A<V5?;&EC96YS92==(#T@
M)'!F+3YG971,:6-E;G-E*"D[#0H@("`@("`@(&EF("@D<&8M/F=E=$1E<',H
M*2D@>PT*("`@("`@("`@("`@:68@*"1P9BT^9V5T4&%C:V%G97AM;%9E<G-I
M;VXH*2`]/2`G,2XP)RD@>PT*("`@("`@("`@("`@("`@("1R97%U:7)E<R`]
M("1C;VYF;&EC=',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P9BT^9V5T1&5P<R@I(&%S("1D97`I('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P
M=&EO;F%L)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@(3T@)W!K9R<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M:&%N;F5L)UTI("8F("1D97!;)V-H86YN96PG72`A/2`G<&5A<BYP:'`N;F5T
M)R`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=C:&%N;F5L
M)UT@(3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)&1E<%LG8VAA;FYE;"==
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92`]
M('-T<G1O=7!P97(H)&-H86XM/F=E=$%L:6%S*"DI("X@)SHZ)R`N("1D97!;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@)U!%05(Z.B<@+B`D9&5P
M6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@)'1R86YS(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G/B<@/3X@)SXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SPG
M(#T^("<\)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<^/2<@/3X@)SX]
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<\/2<@/3X@)SP])RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("<])R`]/B`G/2<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G9W0G(#T^("<^)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=L="<@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)V=E)R`]/B`G/CTG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)VQE)R`]
M/B`G/#TG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V5Q)R`]/B`G/2<L
M#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D9&5P6R=R96PG72`]/2`G:&%S)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G93L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1D97!;)W)E;"==(#T]("=N;W0G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G
M93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1D97!;)W)E;"==
M(#T]("=N92<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC
M='-;72`]("1P86-K86=E("X@)R`]("<@+B`D9&5P6R=V97)S:6]N)UT[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D=')A;G-;)&1E
M<%LG<F5L)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I
M<F5S6UT@/2`D<&%C:V%G92`N("<@)R`N("1T<F%N<ULD9&5P6R=R96PG75T@
M+B`G("<@+B`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O
M=6YT*"1R97%U:7)E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)V5X=')A7VAE861E<G,G72`N/2`G4F5Q=6ER97,Z("<@+B!I;7!L;V1E*"<L
M("<L("1R97%U:7)E<RD@+B`B7&XB.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H8V]U;G0H)&-O;F9L:6-T<RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`N/2`G0V]N
M9FQI8W1S.B`G("X@:6UP;&]D92@G+"`G+"`D8V]N9FQI8W1S*2`N(")<;B([
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG72`]("<R)SL@+R\@
M=&5L;"!T:&4@<W!E8R!T;R!U<V4@<&%C:V%G93(N>&UL#0H@("`@("`@("`@
M("`@("`@)')E<75I<F5S(#T@)&-O;F9L:6-T<R`](&%R<F%Y*"D[#0H@("`@
M("`@("`@("`@("`@)&1E<',@/2`D<&8M/F=E=$1E<',H=')U92D[#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K
M86=E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E
M<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G75LP72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@/2!A
M<G)A>2@D9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@(3T@)W!E
M87(N<&AP+FYE="<@)B8@("1D97!;)V-H86YN96PG72`A/2`G<&5C;"YP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C:&%N(#T@
M)B1R96<M/F=E=$-H86YN96PH)&1E<%LG8VAA;FYE;"==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA
M9V4@/2!S=')T;W5P<&5R*"1C:&%N+3YG971!;&EA<R@I*2`N("<Z.B<@+B`D
M9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@)U!%
M05(Z.B<@+B`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG
M8V]N9FQI8W1S)UTI("8F("AI<W-E="@D9&5P6R=M:6XG72D@?'P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1D97!;)VUA>"==*2DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V4@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<')A;F=E6UT@/2!A<G)A>2@D9&5P6R=M:6XG72PG/CTG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V5;72`](&%R
M<F%Y*"1D97!;)VUA>"==+"`G/#TG*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI('Q\
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<W-E
M="@D9&5P6R=E>&-L=61E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P
M6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N
M="@D9&5P<F%N9V4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97AC;"`]("1D97!;)V5X8VQU9&4G73L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&-H86YG92`^/2!T;R`^(&EF
M(&5X8VQU9&EN9R!T:&4@;6EN('9E<G-I;VX-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&-H86YG92`\/2!T;R`\(&EF(&5X8VQU
M9&EN9R!T:&4@;6%X('9E<G-I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<B@D:2`](#`[("1I(#P@8V]U;G0H)&5X8VPI.R`D
M:2LK*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!R86YG95LP72D@)B8-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AC;%LD:5T@/3T@
M)&1E<')A;F=E6S!=6S!=*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!R86YG95LP75LQ72`]("<\)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)&1E<%LG97AC;'5D92==6R1I72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<F%N9V5;,5TI("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X8VQ;)&E=(#T]("1D97!R86YG95LQ75LP72D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V5;
M,5U;,5T@/2`G/B<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1D97!;)V5X8VQU9&4G75LD:5TI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H8V]U;G0H)&1E<%LG97AC;'5D92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D
M92==(#T@87)R87E?=F%L=65S*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W9&5P<F%N9V4@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@<F5M;W9E(&5X8VQU9&5S('1H870@87)E(&]U='-I9&4@=&AE(&5X:7-T
M:6YG(')A;F=E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&5P6R=E>&-L=61E)UTI.R`D
M:2LK*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1D97!;)V5X8VQU9&4G75LD:5T@/"`D9&5P6R=M:6XG72!\?`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!;)V5X8VQU9&4G75LD:5T@/B`D9&5P6R=M87@G72D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M9&5P6R=E>&-L=61E)UU;)&E=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>5]V86QU97,H)&1E<%LG97AC
M;'5D92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5S;W)T*"1D97!;)V5X8VQU9&4G72P@)W9E<G-I;VY?8V]M<&%R92<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&%K92!T
M:&4@<F5M86EN:6YG(&5X8VQU9&5S(&%N9`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@<W!L:70@=&AE(&1E<&5N9&5N8WD@:6YT
M;R!S=6(M<F%N9V5S#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&%S=&UI;B`]("1D97!R86YG95LP73L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1D97!;)V5X8VQU9&4G72D@+2`Q.R`D:2LK*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=V1E<')A;F=E6UT@/2`G
M*"<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%C:V%G92`N("(@>R1L87-T;6EN6S%=?2![)&QA<W1M:6Y;,%U]
M(&%N9"`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A8VMA9V4@+B`G(#P@)R`N("1D97!;)V5X8VQU9&4G75LD
M:5T@+B`G*2<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&QA<W1M:6X@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UU;)&E=+"`G
M/B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1N97=D97!R86YG95M=(#T@)R@G("X@)'!A8VMA9V4@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`B('LD;&%S=&UI;ELQ77T@>R1L87-T;6EN6S!=?2!A;F0@(B`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K
M86=E("X@)R`\("<@+B`D9&5P6R=M87@G72`N("<I)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;72`](&EM<&QO9&4H)R!O
M<B`G+"`D9&5P<F%N9V4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("(@>R1D97!R86YG95LP75LQ
M77T@>R1D97!R86YG95LP75LP77TB("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H:7-S970H)&1E<')A;F=E6S%=*2`_(`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(@86YD
M("1P86-K86=E('LD9&5P<F%N9V5;,5U;,5U]('LD9&5P<F%N9V5;,5U;,%U]
M(@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M)R<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=M
M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA>"==*2`F)@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(6ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG
M8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYF;&EC='-;72`]("1P86-K86=E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4@+B`G(#X]("<@+B`D9&5P
M6R=M:6XG73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER
M97-;72`]("1P86-K86=E("X@)R`\/2`G("X@)&1E<%LG;6%X)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>"`]("1D97!;)V5X8VQU
M9&4G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D97@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97@@/2!A<G)A>2@D97@I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1E>"!A<R`D=F5R*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G92`N
M("<@/2`G("X@)'9E<CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H
M<"<[#0H@("`@("`@("`@("`@("`@("`@("1T87(@/2!N97<@07)C:&EV95]4
M87(H)'!F+3YG971!<F-H:79E1FEL92@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1A<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`@("`@("`@("`@("`D82`]("1T87(M/F5X=')A8W1);E-T
M<FEN9R@G<&%C:V%G93(N>&UL)RD[#0H@("`@("`@("`@("`@("`@("`@("1T
M87(M/G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1A(#T]/2!N=6QL('Q\(%!%05(Z.FES17)R;W(H)&$I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG72`]("<G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AI<R!D;V5S;B=T(&AA
M=F4@82!P86-K86=E+GAM;"!V97)S:6]N(#$N,`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<75I<F5S6UT@/2`G4$5!4CHZ4$5!4B`^/2`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG
M<&5A<FEN<W1A;&QE<B==6R=M:6XG73L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)')E<75I<F5S*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)V5X=')A7VAE861E
M<G,G72`N/2`G4F5Q=6ER97,Z("<@+B!I;7!L;V1E*"<L("<L("1R97%U:7)E
M<RD@+B`B7&XB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AC;W5N="@D8V]N9FQI8W1S*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`N/2`G0V]N
M9FQI8W1S.B`G("X@:6UP;&]D92@G+"`G+"`D8V]N9FQI8W1S*2`N(")<;B([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!R96UO=F4@
M=&AE('1R86EL:6YG(&YE=VQI;F4-"B`@("`@("`@)&EN9F];)V5X=')A7VAE
M861E<G,G72`]('1R:6TH)&EN9F];)V5X=')A7VAE861E<G,G72D[#0H@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI
M('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)'-P
M96-?8V]N=&5N=',@/2!P<F5G7W)E<&QA8V4H)R]`*%MA+7HP+3E?+5TK*4`O
M92<L("<D:6YF;ULB7#$B72<L#0H@("`@("`@("`@("`@("`@9FEL95]G971?
M8V]N=&5N=',H)'-P96-?=&5M<&QA=&4I*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1S<&5C7V-O;G1E;G1S(#T@<')E9U]R97!L86-E*"<O
M0"A;82UZ,"TY7RU=*RE`+V4G+"`G)&EN9F];(EPQ(ETG+`T*("`@("`@("`@
M("`@("`@(&9R96%D*"1F<"P@9FEL97-I>F4H)'-P96-?=&5M<&QA=&4I*2D[
M#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<W!E8U]F:6QE(#T@(B1I;F9O6W)P;5]P86-K86=E72TD:6YF;UMV97)S
M:6]N72YS<&5C(CL-"B`@("`@("`@)'=P(#T@9F]P96XH)'-P96-?9FEL92P@
M(G=B(BD[#0H@("`@("`@(&EF("@A)'=P*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!W<FET92!24$T@<W!E
M8R!F:6QE("1S<&5C7V9I;&4Z("1P:'!?97)R;W)M<V<B*3L-"B`@("`@("`@
M?0T*("`@("`@("!F=W)I=&4H)'=P+"`D<W!E8U]C;VYT96YT<RD[#0H@("`@
M("`@(&9C;&]S92@D=W`I.PT*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H(E=R;W1E(%)032!S<&5C(&9I;&4@)'-P96-?9FEL92(L("1C;VUM86YD
M*3L-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!D;T-O;G9E<G0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*
M("`@('L-"B`@("`@("`@)'!A8VMA9V5X;6P@/2!I<W-E="@D<&%R86US6S!=
M*2`_("1P87)A;7-;,%T@.B`G<&%C:V%G92YX;6PG.PT*("`@("`@("`D;F5W
M<&%C:V%G97AM;"`](&ES<V5T*"1P87)A;7-;,5TI(#\@)'!A<F%M<ULQ72`Z
M(&1I<FYA;64H)'!A8VMA9V5X;6PI("X-"B`@("`@("`@("`@($1)4D5#5$]2
M65]315!!4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@)'!K9R`]
M("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M
M/E]D96)U9RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)'!F(#T@)'!K9RT^
M9G)O;5!A8VMA9V5&:6QE*"1P86-K86=E>&UL+"!014%27U9!3$E$051%7TY/
M4DU!3"D[#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@
M("`@("`@(&EF("AI<U]A*"1P9BP@)U!%05)?4&%C:V%G949I;&5?=C(G*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D<&%C
M:V%G97AM;"`N("<@:7,@86QR96%D>2!A('!A8VMA9V4N>&UL('9E<G-I;VX@
M,BXP)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D9V5N(#T@)B1P9BT^9V5T1&5F875L=$=E
M;F5R871O<B@I.PT*("`@("`@("`@("`@)&YE=W!F(#T@)B1G96XM/G1O5C(H
M*3L-"B`@("`@("`@("`@("1N97=P9BT^<V5T4&%C:V%G969I;&4H)&YE=W!A
M8VMA9V5X;6PI.PT*("`@("`@("`@("`@)&=E;B`]("8D;F5W<&8M/F=E=$1E
M9F%U;'1'96YE<F%T;W(H*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!U
M<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@
M("`@("1S=&%T92`]("AI<W-E="@D;W!T:6]N<ULG9FQA="==*2`_(%!%05)?
M5D%,241!5$5?4$%#2T%'24Y'(#H@4$5!4E]604Q)1$%415].3U)-04PI.PT*
M("`@("`@("`@("`@)'-A=F5D(#T@)&=E;BT^=&]086-K86=E1FEL92AD:7)N
M86UE*"1N97=P86-K86=E>&UL*2P@)'-T871E+`T*("`@("`@("`@("`@("`@
M(&)A<V5N86UE*"1N97=P86-K86=E>&UL*2D[#0H@("`@("`@("`@("!014%2
M.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<V%V960I*2![#0H@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1S879E9"T^9V5T57-E<DEN9F\H*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'-A=F5D+3YG9715<V5R26YF;R@I(&%S
M("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1S879E9"T^9V5T365S<V%G
M92@I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5W)O
M=&4@;F5W('9E<G-I;VX@,BXP('!A8VMA9V4N>&UL('1O("(G("X@)'-A=F5D
M("X@)R(G*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P9BT^9V5T57-E
M<DEN9F\H*2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E
M=%5S97));F9O*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1W87)N:6YG6R=M97-S86=E)UTI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<&8I.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+T-O;6UA;F0O4&EC:VQE+GAM;```````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C<V,P`Q,#4Q-30S,3`U-P`P,C$T,#<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&-O;6UA;F1S('9E<G-I;VX]
M(C$N,"(^#0H@/'!I8VML93X-"B`@/'-U;6UA<GD^0G5I;&0@4$5#3"!086-K
M86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]086-K86=E/"]F=6YC=&EO
M;CX-"B`@/'-H;W)T8W5T/G!I/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@
M("`\;F]C;VUP<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^#0H@
M("`@/&1O8SY$;R!N;W0@9WII<"!T:&4@<&%C:V%G92!F:6QE/"]D;V,^#0H@
M("`\+VYO8V]M<')E<W,^#0H@("`\<VAO=VYA;64^#0H@("`@/'-H;W)T;W!T
M/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^4')I;G0@=&AE(&YA;64@;V8@=&AE
M('!A8VMA9V5D(&9I;&4N/"]D;V,^#0H@("`\+W-H;W=N86UE/@T*("`\+V]P
M=&EO;G,^#0H@(#QD;V,^6V1E<V-F:6QE72!;9&5S8V9I;&4R70T*0W)E871E
M<R!A(%!%0TP@<&%C:V%G92!F<F]M(&ET<R!D97-C<FEP=&EO;B!F:6QE("AU
M<W5A;&QY(&-A;&QE9`T*<&%C:V%G92YX;6PI+B`@268@82!S96-O;F0@<&%C
M:V%G969I;&4@:7,@<&%S<V5D(&EN+"!T:&5N#0IT:&4@<&%C:V%G97(@=VEL
M;"!C:&5C:R!T;R!M86ME('-U<F4@=&AA="!O;F4@:7,@82!P86-K86=E+GAM
M;`T*=F5R<VEO;B`Q+C`L(&%N9"!T:&4@;W1H97(@:7,@82!P86-K86=E+GAM
M;"!V97)S:6]N(#(N,"X@(%1H90T*<&%C:V%G92YX;6P@=F5R<VEO;B`Q+C`@
M=VEL;"!B92!S879E9"!A<R`F<75O=#MP86-K86=E+GAM;"9Q=6]T.R!I;B!T
M:&4@87)C:&EV92P-"F%N9"!T:&4@;W1H97(@87,@)G%U;W0[<&%C:V%G93(N
M>&UL)G%U;W0[(&EN('1H92!A<F-H:79E)G%U;W0[#0H-"DEF(&YO('-E8V]N
M9"!F:6QE(&ES('!A<W-E9"!I;BP@86YD(%MD97-C9FEL95T@:7,@82!P86-K
M86=E+GAM;"`R+C`L#0IA;B!A=71O;6%T:6,@8V]N=F5R<VEO;B!W:6QL(&)E
M(&UA9&4@=&\@82!P86-K86=E+GAM;"`Q+C`N("!.;W1E('1H870-"F]N;'D@
M<VEM<&QE('!A8VMA9V4N>&UL(#(N,"!W:6QL(&)E(&-O;G9E<G1E9"X@('!A
M8VMA9V4N>&UL(#(N,"!W:71H.@T*#0H@+2!D97!E;F1E;F-Y('1Y<&5S(&]T
M:&5R('1H86X@<F5Q=6ER960O;W!T:6]N86P@4$5#3"!P86-K86=E+V5X="]P
M:'`O<&5A<FEN<W1A;&QE<@T*("T@;6]R92!T:&%N(&]N92!E>'1S<F-R96QE
M87-E#0H@+2!E>'1B:6YR96QE87-E+"!P:'!R96QE87-E+"!O<B!B=6YD;&4@
M<F5L96%S92!T>7!E#0H@+2!D97!E;F1E;F-Y(&=R;W5P<PT*("T@:6=N;W)E
M('1A9W,@:6X@<F5L96%S92!F:6QE;&ES=`T*("T@=&%S:W,@;W1H97(@=&AA
M;B!R97!L86-E#0H@+2!C=7-T;VT@<F]L97,-"@T*=VEL;"!C875S92!P:6-K
M;&4@=&\@9F%I;"P@86YD(&]U='!U="!A;B!E<G)O<B!M97-S86=E+B`@268@
M>6]U<B!P86-K86=E,BYX;6P-"G5S97,@86YY(&]F('1H97-E(&9E871U<F5S
M+"!Y;W4@87)E(&)E<W0@;V9F('5S:6YG(%!%05)?4&%C:V%G949I;&5-86YA
M9V5R('1O#0IG96YE<F%T92!B;W1H('!A8VMA9V4N>&UL+CPO9&]C/@T*(#PO
M<&EC:VQE/@T*/"]C;VUM86YD<SX`````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]0:6-K;&4N<&AP````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0P,#8R`#$P-3$U-#,Q,#4W
M`#`R,3,W,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?4&EC:VQE("AP:6-K
M;&4@8V]M;6%N9"D-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H
M<"YN970^#0H@*B!`8V]P>7)I9VAT("`R,#`U+3(P,#8@5&AE(%!(4"!'<F]U
M<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z
M("1)9#H@4&EC:VQE+G!H<"QV(#$N-2`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA
M<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H
M<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,C`P-2TR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C0N,0T*("HO#0H-"F-L87-S(%!%05)?0V]M;6%N9%]0
M:6-K;&4@97AT96YD<R!014%27T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@=F%R
M("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<&EC:VQE)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0G5I;&0@4$5#3"!086-K
M86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G92<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=P:2<L#0H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)VYO8V]M
M<')E<W,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=:)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1O
M(&YO="!G>FEP('1H92!P86-K86=E(&9I;&4G#0H@("`@("`@("`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`@("`@)W-H;W=N86UE)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=0<FEN="!T:&4@;F%M92!O9B!T
M:&4@<&%C:V%G960@9FEL92XG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G6V1E
M<V-F:6QE70T*0W)E871E<R!A(%!%0TP@<&%C:V%G92!F<F]M(&ET<R!P86-K
M86=E,BYX;6P@9FEL92X-"@T*06X@875T;VUA=&EC(&-O;G9E<G-I;VX@=VEL
M;"!B92!M861E('1O(&$@<&%C:V%G92YX;6P@,2XP(&%N9"!W<FET=&5N(&]U
M="!T;PT*9&ES:R!I;B!T:&4@8W5R<F5N="!D:7)E8W1O<GD@87,@(G!A8VMA
M9V4N>&UL(BX@($YO=&4@=&AA=`T*;VYL>2!S:6UP;&4@<&%C:V%G92YX;6P@
M,BXP('=I;&P@8F4@8V]N=F5R=&5D+B`@<&%C:V%G92YX;6P@,BXP('=I=&@Z
M#0H-"B`M(&1E<&5N9&5N8WD@='EP97,@;W1H97(@=&AA;B!R97%U:7)E9"]O
M<'1I;VYA;"!014-,('!A8VMA9V4O97AT+W!H<"]P96%R:6YS=&%L;&5R#0H@
M+2!M;W)E('1H86X@;VYE(&5X='-R8W)E;&5A<V4-"B`M(&5X=&)I;G)E;&5A
M<V4L('!H<')E;&5A<V4L(&]R(&)U;F1L92!R96QE87-E('1Y<&4-"B`M(&1E
M<&5N9&5N8WD@9W)O=7!S#0H@+2!I9VYO<F4@=&%G<R!I;B!R96QE87-E(&9I
M;&5L:7-T#0H@+2!T87-K<R!O=&AE<B!T:&%N(')E<&QA8V4-"B`M(&-U<W1O
M;2!R;VQE<PT*#0IW:6QL(&-A=7-E('!I8VML92!T;R!F86EL+"!A;F0@;W5T
M<'5T(&%N(&5R<F]R(&UE<W-A9V4N("!)9B!Y;W5R('!A8VMA9V4R+GAM;`T*
M=7-E<R!A;GD@;V8@=&AE<V4@9F5A='5R97,L('EO=2!A<F4@8F5S="!O9F8@
M=7-I;F<@4$5!4E]086-K86=E1FEL94UA;F%G97(@=&\-"F=E;F5R871E(&)O
M=&@@<&%C:V%G92YX;6PN#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`I
M.PT*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM86YD7U!A8VMA9V4@8V]N
M<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]0:6-K;&4H)B1U:2P@
M)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N
M9%]#;VUM;VXH)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"@T*("`@("\J*@T*
M("`@("`J($9O<B!U;FET+71E<W1I;F<@96%S90T*("`@("`J#0H@("`@("H@
M0')E='5R;B!014%27U!A8VMA9V5R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M)F=E=%!A8VMA9V5R*"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=014%27U!A8VMA9V5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]086-K86=E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@
M("1A(#T@)FYE=R!014%27U!A8VMA9V5R.PT*("`@("`@("!R971U<FX@)&$[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R('5N:70M=&5S=&EN9R!E
M87-E#0H@("`@("H-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<@)&-O;F9I
M9PT*("`@("`J($!P87)A;2!B;V]L("1D96)U9PT*("`@("`J($!P87)A;2!S
M=')I;F=\;G5L;"`D=&UP9&ER#0H@("`@("H@0')E='5R;B!014%27U!A8VMA
M9V5&:6QE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5&:6QE
M*"1C;VYF:6<L("1D96)U9R`](&9A;'-E+"`D=&UP9&ER(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-O;6UO;B<I
M*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H
M<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%
M05(O4&%C:V%G949I;&4N<&AP)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@("!]#0H@("`@
M("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U
M9RP@)'1M<&1I<BD[#0H@("`@("`@("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM
M;VX[#0H@("`@("`@("1C;VUM;VXM/G5I(#T@)'1H:7,M/G5I.PT*("`@("`@
M("`D82T^<V5T3&]G9V5R*"1C;VUM;VXI.PT*("`@("`@("!R971U<FX@)&$[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD+"`D
M;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P
M=70@/2`G)SL-"B`@("`@("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A<F%M
M<ULP72D@/R`D<&%R86US6S!=(#H@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@
M("1P86-K86=E<B`]("8D=&AI<RT^9V5T4&%C:V%G97(H*3L-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<B`]("1T:&ES+3Y?8V]N=F5R=%!A8VMA
M9V4H)'!K9VEN9F]F:6QE*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D97)R
M.PT*("`@("`@("!]#0H@("`@("`@("1C;VUP<F5S<R`](&5M<'1Y*"1O<'1I
M;VYS6R=N;V-O;7!R97-S)UTI(#\@=')U92`Z(&9A;'-E.PT*("`@("`@("`D
M<F5S=6QT(#T@)'!A8VMA9V5R+3YP86-K86=E*"1P:V=I;F9O9FEL92P@)&-O
M;7!R97-S+"`G<&%C:V%G92YX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<W5L="DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D<F5S=6QT*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!$
M;VXG="!W86YT(&]U='!U="P@;VYL>2!T:&4@<&%C:V%G92!F:6QE(&YA;64@
M:G5S="!C<F5A=&5D#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VAO
M=VYA;64G72DI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@D<F5S=6QT+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V-O;G9E<G1086-K
M86=E*"1P86-K86=E>&UL*0T*("`@('L-"B`@("`@("`@)'!K9R`]("8D=&AI
M<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@("1P
M9C(@/2`F)'!K9RT^9G)O;5!A8VMA9V5&:6QE*"1P86-K86=E>&UL+"!014%2
M7U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@(&EF("@A:7-?82@D<&8R+"`G
M4$5!4E]086-K86=E1FEL95]V,B<I*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!P<F]C97-S("(G("X-"B`@("`@
M("`@("`@("`@("`D<&%C:V%G97AM;"`N("<B+"!I<R!N;W0@82!P86-K86=E
M+GAM;"`R+C`G*3L-"B`@("`@("`@?0T*("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4O=C$N<&AP)SL-"B`@("`@("`@)'!F(#T@;F5W
M(%!%05)?4&%C:V%G949I;&5?=C$[#0H@("`@("`@("1P9BT^<V5T0V]N9FEG
M*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!I9B`H:7-?87)R87DH)'!F,BT^
M9V5T4&%C:V%G951Y<&4H*2`A/2`G97AT<W)C)RDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV
M97)T("(G("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&ES(&YO
M="!A;B!E>'1E;G-I;VX@<V]U<F-E('!A8VMA9V4N("!5<VEN9R!A(%!%05)?
M4&%C:V%G949I;&5-86YA9V5R+6)A<V5D("<@+@T*("`@("`@("`@("`@)W-C
M<FEP="!I<R!A;B!O<'1I;VXG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-?87)R87DH)'!F,BT^9V5T57-E<U)O;&4H*2DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV
M97)T("(G("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A
M:6YS(&-U<W1O;2!R;VQE<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA
M;F%G97(M8F%S960@<V-R:7!T(&]R("<@+@T*("`@("`@("`@("`@)W1H92!C
M;VYV97)T(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1P9C(M/F=E=%5S97-487-K*"DI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S
M869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X-"B`@("`@("`@("`@
M("<B+"!C;VYT86EN<R!C=7-T;VT@=&%S:W,N("!5<VEN9R!A(%!%05)?4&%C
M:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP="!O<B`G("X-"B`@("`@("`@
M("`@("=T:&4@8V]N=F5R="!C;VUM86YD(&ES(&%N(&]P=&EO;B<I.PT*("`@
M("`@("!]#0H@("`@("`@("1D97!S(#T@)'!F,BT^9V5T1&5P96YD96YC:65S
M*"D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG9W)O=7`G72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A
M9F5L>2!C;VYV97)T("(G("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@
M)R(L(&-O;G1A:6YS(&1E<&5N9&5N8WD@9W)O=7!S+B`@57-I;F<@82!014%2
M7U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@)R`N#0H@("`@("`@
M("`@("`G;W(@=&AE(&-O;G9E<G0@8V]M;6%N9"!I<R!A;B!O<'1I;VXG*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D
M)UU;)W-U8G!A8VMA9V4G72D@?'P-"B`@("`@("`@("`@("`@:7-S970H)&1E
M<'-;)V]P=&EO;F%L)UU;)W-U8G!A8VMA9V4G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV
M97)T("(G("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A
M:6YS('-U8G!A8VMA9V4@9&5P96YD96YC:65S+B`@57-I;F<@82!014%27U!A
M8VMA9V5&:6QE36%N86=E<BUB87-E9"`@)RX-"B`@("`@("`@("`@("=S8W)I
M<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=R97%U:7)E9"==6R=O<R==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY(&-O;G9E
M<G0@(B<@+B`D<&%C:V%G97AM;"`N#0H@("`@("`@("`@("`G(BP@8V]N=&%I
M;G,@;W,@9&5P96YD96YC:65S+B`@57-I;F<@82!014%27U!A8VMA9V5&:6QE
M36%N86=E<BUB87-E9"`@)RX-"B`@("`@("`@("`@("=S8W)I<'0@:7,@86X@
M;W!T:6]N)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S
M6R=R97%U:7)E9"==6R=A<F-H)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B)R`N
M("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("<B+"!C;VYT86EN<R!A<F-H
M(&1E<&5N9&5N8VEE<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G
M97(M8F%S960@("<N#0H@("`@("`@("`@("`G<V-R:7!T(&ES(&%N(&]P=&EO
M;B<I.PT*("`@("`@("!]#0H@("`@("`@("1P9BT^<V5T4&%C:V%G92@D<&8R
M+3YG971086-K86=E*"DI.PT*("`@("`@("`D<&8M/G-E=%-U;6UA<GDH)'!F
M,BT^9V5T4W5M;6%R>2@I*3L-"B`@("`@("`@)'!F+3YS971$97-C<FEP=&EO
M;B@D<&8R+3YG971$97-C<FEP=&EO;B@I*3L-"B`@("`@("`@9F]R96%C:"`H
M)'!F,BT^9V5T36%I;G1A:6YE<G,H*2!A<R`D;6%I;G1A:6YE<BD@>PT*("`@
M("`@("`@("`@)'!F+3YA9&1-86EN=&%I;F5R*"1M86EN=&%I;F5R6R=R;VQE
M)UTL("1M86EN=&%I;F5R6R=H86YD;&4G72P-"B`@("`@("`@("`@("`@("`D
M;6%I;G1A:6YE<ELG;F%M92==+"`D;6%I;G1A:6YE<ELG96UA:6PG72D[#0H@
M("`@("`@('T-"B`@("`@("`@)'!F+3YS971697)S:6]N*"1P9C(M/F=E=%9E
M<G-I;VXH*2D[#0H@("`@("`@("1P9BT^<V5T1&%T92@D<&8R+3YG971$871E
M*"DI.PT*("`@("`@("`D<&8M/G-E=$QI8V5N<V4H)'!F,BT^9V5T3&EC96YS
M92@I*3L-"B`@("`@("`@)'!F+3YS9713=&%T92@D<&8R+3YG9713=&%T92@I
M*3L-"B`@("`@("`@)'!F+3YS971.;W1E<R@D<&8R+3YG971.;W1E<R@I*3L-
M"B`@("`@("`@)'!F+3YA9&10:'!$97`H)&1E<'-;)W)E<75I<F5D)UU;)W!H
M<"==6R=M:6XG72P@)V=E)RD[#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG
M<F5Q=6ER960G75LG<&AP)UU;)VUA>"==*2D@>PT*("`@("`@("`@("`@)'!F
M+3YA9&10:'!$97`H)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=M87@G72P@
M)VQE)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R
M97%U:7)E9"==6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UU;,%TI*2![#0H@("`@
M("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72`](&%R
M<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;
M)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D9&5P6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV
M97)T("(G("X@)'!A8VMA9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`G(&-O;G1A:6YS('5R:2UB87-E9"!D97!E;F1E;F-Y(&]N(&$@<&%C
M:V%G92X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%2
M7U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N
M)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D
M9&5P6R=C:&%N;F5L)UT@(3T@)W!E87(N<&AP+FYE="<@)B8@)&1E<%LG8VAA
M;FYE;"==("$]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C
M;VYV97)T("(G("X@)'!A8VMA9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`G(&-O;G1A:6YS(&1E<&5N9&5N8WD@;VX@82!N;VXM<W1A;F1A
M<F0@8VAA;FYE;"!P86-K86=E+B`@57-I;F<@82`G("X-"B`@("`@("`@("`@
M("`@("`@("`@)U!%05)?4&%C:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP
M="!I<R!A;B!O<'1I;VXG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A
M;FYO="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X@)R(G("X-
M"B`@("`@("`@("`@("`@("`@("`@)R!C;VYT86EN<R!C;VYF;&EC=',@9&5P
M96YD96YC>2X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=0
M14%27U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T
M:6]N)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@97AC;'5D92!T
M86=S(&%R92!I9VYO<F5D(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/F%D9%!A8VMA9V5$97`H
M)&1E<%LG;F%M92==+"`D9&5P6R=M:6XG72P@)V=E)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1086-K86=E1&5P
M*"1D97!;)VYA;64G72P@)&1E<%LG;6%X)UTL("=L92<I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)V5X=&5N<VEO;B==*2D@>PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG<F5Q=6ER960G75LG97AT
M96YS:6]N)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I
M<F5D)UU;)V5X=&5N<VEO;B==(#T@87)R87DH)&1E<'-;)W)E<75I<F5D)UU;
M)V5X=&5N<VEO;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1D97!S6R=R97%U:7)E9"==6R=E>'1E;G-I;VXG72!A<R`D9&5P
M*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T
M<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E
M>&UL("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@)R!C;VYT86EN<R!C
M;VYF;&EC=',@9&5P96YD96YC>2X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("=014%27U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I
M<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.
M1SH@97AC;'5D92!T86=S(&%R92!I9VYO<F5D(&EN(&-O;G9E<G-I;VXG*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/F%D
M9$5X=&5N<VEO;D1E<"@D9&5P6R=N86UE)UTL("1D97!;)VUI;B==+"`G9V4G
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M
M/F%D9$5X=&5N<VEO;D1E<"@D9&5P6R=N86UE)UTL("1D97!;)VUA>"==+"`G
M;&4G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=P
M86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=O
M<'1I;VYA;"==6R=P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@
M)&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=O
M<'1I;VYA;"==6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9F]R96%C:"`H)&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G72!A
M<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=C
M:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A
M8VMA9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`G(&-O;G1A
M:6YS('5R:2UB87-E9"!D97!E;F1E;F-Y(&]N(&$@<&%C:V%G92X@(%5S:6YG
M(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A8VMA9V5&:6QE
M36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L
M)UT@(3T@)W!E87(N<&AP+FYE="<@)B8@)&1E<%LG8VAA;FYE;"==("$]("=P
M96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@
M)'!A8VMA9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`G(&-O
M;G1A:6YS(&1E<&5N9&5N8WD@;VX@82!N;VXM<W1A;F1A<F0@8VAA;FYE;"!P
M86-K86=E+B`@57-I;F<@82`G("X-"B`@("`@("`@("`@("`@("`@("`@)U!%
M05)?4&%C:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP="!I<R!A;B!O<'1I
M;VXG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=705).24Y'.B!E>&-L=61E('1A
M9W,@87)E(&EG;F]R960@:6X@8V]N=F5R<VEO;B<I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1P9BT^861D4&%C:V%G941E<"@D
M9&5P6R=N86UE)UTL("1D97!;)VUI;B==+"`G9V4G+"`G>65S)RD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1086-K
M86=E1&5P*"1D97!;)VYA;64G72P@)&1E<%LG;6%X)UTL("=L92<L("=Y97,G
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=E>'1E
M;G-I;VXG72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V]P
M=&EO;F%L)UU;)V5X=&5N<VEO;B==6S!=*2D@>PT*("`@("`@("`@("`@("`@
M("1D97!S6R=O<'1I;VYA;"==6R=E>'1E;G-I;VXG72`](&%R<F%Y*"1D97!S
M6R=O<'1I;VYA;"==6R=E>'1E;G-I;VXG72D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG;W!T:6]N86PG75LG97AT96YS
M:6]N)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@97AC;'5D92!T86=S(&%R92!I
M9VYO<F5D(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D<&8M/F%D9$5X=&5N<VEO;D1E<"@D9&5P6R=N
M86UE)UTL("1D97!;)VUI;B==+"`G9V4G+"`G>65S)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1%>'1E;G-I;VY$
M97`H)&1E<%LG;F%M92==+"`D9&5P6R=M87@G72P@)VQE)RP@)WEE<R<I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D8V]N=&5N=',@/2`D<&8R+3YG971#;VYT96YT<R@I.PT*("`@
M("`@("`D<F5L96%S92`]("1P9C(M/F=E=%)E;&5A<V5S*"D[#0H@("`@("`@
M(&EF("AI<W-E="@D<F5L96%S97-;,%TI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@<')O8V5S<R`B
M)R`N("1P86-K86=E>&UL("X@)R(@8V]N=&%I;G,@)R`-"B`@("`@("`@("`@
M("X@)VUU;'1I<&QE(&5X='-R8W)E;&5A<V4@=&%G<RX@(%5S:6YG(&$@4$5!
M4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T("<@+@T*("`@("`@
M("`@("`@)V]R('1H92!C;VYV97)T(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C;VYF:6=O<'1I;VYS(#T@)'!F
M,BT^9V5T0V]N9FEG=7)E3W!T:6]N<R@I*2![#0H@("`@("`@("`@("!F;W)E
M86-H("@D8V]N9FEG;W!T:6]N<R!A<R`D;W!T:6]N*2![#0H@("`@("`@("`@
M("`@("`@)'!F+3YA9&1#;VYF:6=U<F5/<'1I;VXH)&]P=&EO;ELG;F%M92==
M+"`D;W!T:6]N6R=P<F]M<'0G72P-"B`@("`@("`@("`@("`@("`@("`@:7-S
M970H)&]P=&EO;ELG9&5F875L="==*2`_("1O<'1I;VY;)V1E9F%U;'0G72`Z
M(&9A;'-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEG;F]R92==*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@
M<V%F96QY('!R;V-E<W,@(B<@+B`D<&%C:V%G97AM;"`N("<B(&-O;G1A:6YS
M("<@#0H@("`@("`@("`@("`N("=I9VYO<F4@=&%G<RX@(%5S:6YG(&$@4$5!
M4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T(&]R('1H92!C;VYV
M97)T)R`N#0H@("`@("`@("`@("`G(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1R96QE87-E6R=F:6QE
M;&ES="==6R=I;G-T86QL)UTI("8F#0H@("`@("`@("`@("`@("%I<W-E="@D
M<F5L96%S95LG9FEL96QI<W0G75LG:6YS=&%L;"==6S!=*2D@>PT*("`@("`@
M("`@("`@)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG72`](&%R<F%Y
M*"1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D8V]N=&5N='-;)V1I<B==6R=A='1R:6)S
M)UU;)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`D8F%S96EN
M<W1A;&QD:7(@/2`D8V]N=&5N='-;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I
M;G-T86QL9&ER)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M8F%S96EN<W1A;&QD:7(@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(6ES<V5T*"1C;VYT96YT<ULG9&ER)UU;)V9I;&4G75LP72DI('L-"B`@
M("`@("`@("`@("1C;VYT96YT<ULG9&ER)UU;)V9I;&4G72`](&%R<F%Y*"1C
M;VYT96YT<ULG9&ER)UU;)V9I;&4G72D[#0H@("`@("`@('T-"B`@("`@("`@
M9F]R96%C:"`H)&-O;G1E;G1S6R=D:7(G75LG9FEL92==(&%S("1F:6QE*2![
M#0H@("`@("`@("`@("!I9B`H)&)A<V5I;G-T86QL9&ER("8F("%I<W-E="@D
M9FEL95LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@
M("`@("`@("`@("1F:6QE6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT@
M/2`D8F%S96EN<W1A;&QD:7([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<')O8V5S<T9I;&4@/2`D9FEL93L-"B`@("`@("`@("`@('5N<V5T*"1P
M<F]C97-S1FEL95LG871T<FEB<R==*3L-"B`@("`@("`@("`@(&EF("AC;W5N
M="@D<')O8V5S<T9I;&4I*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'!R;V-E<W-&:6QE(&%S("1N86UE(#T^("1T87-K*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D;F%M92`A/2`D<&8R+3YG971487-K<TYS*"D@+B`G
M.G)E<&QA8V4G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@<')O8V5S<R`B)R`N
M("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B(&-O
M;G1A:6YS('1A<VMS(&]T:&5R('1H86X@<F5P;&%C92X@(%5S:6YG(&$@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`G4$5!4E]086-K86=E1FEL94UA
M;F%G97(M8F%S960@<V-R:7!T(&ES(&%N(&]P=&EO;BXG*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D9FEL95LG871T
M<FEB<R==6R=R97!L86-E)UU;72`]("1T87-K.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH
M)&9I;&5;)V%T=')I8G,G75LG<F]L92==+"!014%27T-O;6UO;CHZ9V5T1FEL
M95)O;&5S*"DI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=#86YN;W0@<V%F96QY(&-O;G9E<G0@(B<@+B`D<&%C:V%G
M97AM;"`N#0H@("`@("`@("`@("`@("`@)R(L(&-O;G1A:6YS(&-U<W1O;2!R
M;VQE<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@
M<V-R:7!T("<@+@T*("`@("`@("`@("`@("`@("=O<B!T:&4@8V]N=F5R="!C
M;VUM86YD(&ES(&%N(&]P=&EO;B<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL
M)UTI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5;)V9I
M;&5L:7-T)UU;)VEN<W1A;&PG72!A<R`D:6YS=&%L;&%S*2![#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D:6YS=&%L;&%S6R=A='1R:6)S)UU;)VYA;64G
M72`]/2`D9FEL95LG871T<FEB<R==6R=N86UE)UTI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1F:6QE6R=A='1R:6)S)UU;)VEN<W1A;&PM87,G72`]
M("1I;G-T86QL87-;)V%T=')I8G,G75LG87,G73L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1P9BT^861D1FEL92@G+R<L("1F:6QE6R=A='1R:6)S)UU;
M)VYA;64G72P@)&9I;&5;)V%T=')I8G,G72D[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1P9C(M/F=E=$-H86YG94QO9R@I*2![#0H@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(&-H86YG96QO9R!I<R!N
M;W0@=')A;G-L871E9"!T;R!P86-K86=E+GAM;"`G("X-"B`@("`@("`@("`@
M("`@("`G,2XP+"!U<V4@4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@
M<V-R:7!T(&EF('EO=2!N965D(&-H86YG96QO9RTG("X-"B`@("`@("`@("`@
M("`@("`G=')A;G-L871I;VX@9F]R('!A8VMA9V4N>&UL(#$N,"<I.PT*("`@
M("`@("!]#0H@("`@("`@("1G96X@/2`F)'!F+3YG971$969A=6QT1V5N97)A
M=&]R*"D[#0H@("`@("`@("1G96XM/G1O4&%C:V%G949I;&4H)RXG*3L-"B`@
M("!]#0I]#0H-"C\^#0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U)E9VES=')Y+GAM;```````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R-C4`,3`U,34T,S$P-3<`,#(R,#`V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QC
M;VUM86YD<R!V97)S:6]N/2(Q+C`B/@T*(#QL:7-T/@T*("`\<W5M;6%R>3Y,
M:7-T($EN<W1A;&QE9"!086-K86=E<R!);B!4:&4@1&5F875L="!#:&%N;F5L
M/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&],:7-T/"]F=6YC=&EO;CX-"B`@
M/'-H;W)T8W5T/FP\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N
M;F5L/@T*("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/FQI
M<W0@:6YS=&%L;&5D('!A8VMA9V5S(&9R;VT@=&AI<R!C:&%N;F5L/"]D;V,^
M#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@("`\86QL
M8VAA;FYE;',^#0H@("`@/'-H;W)T;W!T/F$\+W-H;W)T;W!T/@T*("`@(#QD
M;V,^;&ES="!I;G-T86QL960@<&%C:V%G97,@9G)O;2!A;&P@8VAA;FYE;',\
M+V1O8SX-"B`@(#PO86QL8VAA;FYE;',^#0H@(#PO;W!T:6]N<SX-"B`@/&1O
M8SXF;'0[<&%C:V%G929G=#L-"DEF(&EN=F]K960@=VET:&]U="!P87)A;65T
M97)S+"!T:&ES(&-O;6UA;F0@;&ES=',@=&AE(%!%05(@<&%C:V%G97,-"FEN
M<W1A;&QE9"!I;B!Y;W5R('!H<%]D:7(@*'MC;VYF:6<@<&AP7V1I<GTI+B`@
M5VET:"!A('!A<F%M971E<BP@:70-"FQI<W1S('1H92!F:6QE<R!I;B!A('!A
M8VMA9V4N#0H\+V1O8SX-"B`\+VQI<W0^#0H@/&QI<W0M9FEL97,^#0H@(#QS
M=6UM87)Y/DQI<W0@1FEL97,@26X@26YS=&%L;&5D(%!A8VMA9V4\+W-U;6UA
M<GD^#0H@(#QF=6YC=&EO;CYD;T9I;&5,:7-T/"]F=6YC=&EO;CX-"B`@/'-H
M;W)T8W5T/F9L/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF
M;'0[<&%C:V%G929G=#L-"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A;&QE
M9"!P86-K86=E+@T*/"]D;V,^#0H@/"]L:7-T+69I;&5S/@T*(#QS:&5L;"UT
M97-T/@T*("`\<W5M;6%R>3Y3:&5L;"!38W)I<'0@5&5S=#PO<W5M;6%R>3X-
M"B`@/&9U;F-T:6]N/F1O4VAE;&Q497-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T
M8W5T/G-T/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[
M<&%C:V%G929G=#L@6UMR96QA=&EO;ET@=F5R<VEO;ET-"E1E<W1S(&EF(&$@
M<&%C:V%G92!I<R!I;G-T86QL960@:6X@=&AE('-Y<W1E;2X@5VEL;"!E>&ET
M*#$I(&EF(&ET(&ES(&YO="X-"B`@("9L=#MR96QA=&EO;B9G=#L@("!4:&4@
M=F5R<VEO;B!C;VUP87)I<V]N(&]P97)A=&]R+B!/;F4@;V8Z#0H@("`@("`@
M("`@("`@("`@)FQT.RP@;'0L("9L=#L]+"!L92P@)F=T.RP@9W0L("9G=#L]
M+"!G92P@/3TL(#TL(&5Q+"`A/2P@)FQT.R9G=#LL(&YE#0H@("`F;'0[=F5R
M<VEO;B9G=#L@("`@5&AE('9E<G-I;VX@=&\@8V]M<&%R92!W:71H#0H\+V1O
M8SX-"B`\+W-H96QL+71E<W0^#0H@/&EN9F\^#0H@(#QS=6UM87)Y/D1I<W!L
M87D@:6YF;W)M871I;VX@86)O=70@82!P86-K86=E/"]S=6UM87)Y/@T*("`\
M9G5N8W1I;VX^9&]);F9O/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/FEN/"]S
M:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C:V%G929G
M=#L-"D1I<W!L87ES(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92X@5&AE
M('!A8VMA9V4@87)G=6UE;G0@;6%Y(&)E(&$-"FQO8V%L('!A8VMA9V4@9FEL
M92P@86X@55),('1O(&$@<&%C:V%G92!F:6QE+"!O<B!T:&4@;F%M92!O9B!A
M;@T*:6YS=&%L;&5D('!A8VMA9V4N/"]D;V,^#0H@/"]I;F9O/@T*/"]C;VUM
M86YD<SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!%05(O0V]M;6%N9"]296=I<W1R>2YP:'``````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,3(W-#4U`#$P-3$U-#,Q,#4W`#`R,C`P-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`T*
M+RHJ#0H@*B!014%27T-O;6UA;F1?4F5G:7-T<GD@*&QI<W0L(&QI<W0M9FEL
M97,L('-H96QL+71E<W0L(&EN9F\@8V]M;6%N9',I#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z(%)E9VES=')Y+G!H<"QV(#$N-S`@,C`P
M-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-
M"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O
M0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S
M(&9O<B!R96=I<W1R>2!M86YI<'5L871I;VX-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3
M=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G
M($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@
M("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC
M;&%S<R!014%27T-O;6UA;F1?4F5G:7-T<GD@97AT96YD<R!014%27T-O;6UA
M;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A
M<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)VQI<W0G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=,:7-T($EN<W1A;&QE9"!0
M86-K86=E<R!);B!4:&4@1&5F875L="!#:&%N;F5L)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O3&ES="<L#0H@("`@("`@("`@("`G<VAO<G1C
M=70G(#T^("=L)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V,G+`T*("`@("`@("`@("`@
M("`@("`@("`G9&]C)R`]/B`G;&ES="!I;G-T86QL960@<&%C:V%G97,@9G)O
M;2!T:&ES(&-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]
M/B`G0TA!3B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@)V%L;&-H86YN96QS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G82<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=L:7-T(&EN<W1A;&QE9"!P86-K86=E<R!F<F]M(&%L;"!C
M:&%N;F5L<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G93X-"DEF
M(&EN=F]K960@=VET:&]U="!P87)A;65T97)S+"!T:&ES(&-O;6UA;F0@;&ES
M=',@=&AE(%!%05(@<&%C:V%G97,-"FEN<W1A;&QE9"!I;B!Y;W5R('!H<%]D
M:7(@*'MC;VYF:6<@<&AP7V1I<GTI+B`@5VET:"!A('!A<F%M971E<BP@:70-
M"FQI<W1S('1H92!F:6QE<R!I;B!A('!A8VMA9V4N#0HG+`T*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)VQI<W0M9FEL97,G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W-U;6UA<GDG(#T^("=,:7-T($9I;&5S($EN($EN<W1A;&QE9"!0
M86-K86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O1FEL94QI
M<W0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G9FPG+`T*("`@("`@
M("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G/'!A8VMA9V4^#0I,:7-T('1H92!F:6QE<R!I;B!A;B!I;G-T86QL
M960@<&%C:V%G92X-"B<-"B`@("`@("`@("`@("DL#0H@("`@("`@("=S:&5L
M;"UT97-T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G
M4VAE;&P@4V-R:7!T(%1E<W0G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]3:&5L;%1E<W0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M<W0G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^(%M;<F5L871I;VY=('9E<G-I
M;VY=#0I497-T<R!I9B!A('!A8VMA9V4@:7,@:6YS=&%L;&5D(&EN('1H92!S
M>7-T96TN(%=I;&P@97AI="@Q*2!I9B!I="!I<R!N;W0N#0H@("`\<F5L871I
M;VX^("`@5&AE('9E<G-I;VX@8V]M<&%R:7-O;B!O<&5R871O<BX@3VYE(&]F
M.@T*("`@("`@("`@("`@("`@(#PL(&QT+"`\/2P@;&4L(#XL(&=T+"`^/2P@
M9V4L(#T]+"`]+"!E<2P@(3TL(#P^+"!N90T*("`@/'9E<G-I;VX^("`@(%1H
M92!V97)S:6]N('1O(&-O;7!A<F4@=VET:`T*)RDL#0H@("`@("`@("=I;F9O
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`@/3X@)T1I<W!L
M87D@:6YF;W)M871I;VX@86)O=70@82!P86-K86=E)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O26YF;R<L#0H@("`@("`@("`@("`G<VAO<G1C
M=70G(#T^("=I;B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@(#T^(&%R<F%Y
M*"DL#0H@("`@("`@("`@("`G9&]C)R`@("`@(#T^("<\<&%C:V%G93X-"D1I
M<W!L87ES(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92X@5&AE('!A8VMA
M9V4@87)G=6UE;G0@;6%Y(&)E(&$-"FQO8V%L('!A8VMA9V4@9FEL92P@86X@
M55),('1O(&$@<&%C:V%G92!F:6QE+"!O<B!T:&4@;F%M92!O9B!A;@T*:6YS
M=&%L;&5D('!A8VMA9V4N)PT*("`@("`@("`@("`@*0T*("`@("`@("`I.PT*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O
M*BH-"B`@("`@*B!014%27T-O;6UA;F1?4F5G:7-T<GD@8V]N<W1R=6-T;W(N
M#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]296=I<W1R>2@F)'5I+"`F)&-O;F9I
M9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO
M;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@
M+R\@>WM[(&1O3&ES="@I#0H-"B`@("!F=6YC=&EO;B!?<V]R=&EN9F\H)&$L
M("1B*0T*("`@('L-"B`@("`@("`@)&%P86-K86=E(#T@:7-S970H)&%;)W!A
M8VMA9V4G72D@/R`D85LG<&%C:V%G92==(#H@)&%;)VYA;64G73L-"B`@("`@
M("`@)&)P86-K86=E(#T@:7-S970H)&);)W!A8VMA9V4G72D@/R`D8ELG<&%C
M:V%G92==(#H@)&);)VYA;64G73L-"B`@("`@("`@<F5T=7)N('-T<F-M<"@D
M87!A8VMA9V4L("1B<&%C:V%G92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M9&],:7-T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG86QL8VAA;FYE;',G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&],:7-T06QL*"1C;VUM86YD
M+"!A<G)A>2@I+"`D<&%R86US*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF
M("AC;W5N="@D<&%R86US*2`]/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F1O1FEL94QI<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V-H
M86YN96PG72DI('L-"B`@("`@("`@("`@(&EF("@D<F5G+3YC:&%N;F5L17AI
M<W1S*"1O<'1I;VYS6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&-H86YN96P@/2`D<F5G+3YC:&%N;F5L3F%M92@D;W!T:6]N<ULG8VAA;FYE
M;"==*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@)&]P=&EO
M;G-;)V-H86YN96PG72`N)R(@9&]E<R!N;W0@97AI<W0G*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C:&%N;F5L
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@
M("`@("`@?0T*("`@("`@("`D:6YS=&%L;&5D(#T@)')E9RT^<&%C:V%G94EN
M9F\H;G5L;"P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("!U<V]R="@D:6YS
M=&%L;&5D+"!A<G)A>2@F)'1H:7,L("=?<V]R=&EN9F\G*2D[#0H@("`@("`@
M("1I(#T@)&H@/2`P.PT*("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@
M("`@("`@)V-A<'1I;VXG(#T^("=);G-T86QL960@<&%C:V%G97,L(&-H86YN
M96P@)R`N#0H@("`@("`@("`@("`@("`@)&-H86YN96P@+B`G.B<L#0H@("`@
M("`@("`@("`G8F]R9&5R)R`]/B!T<G5E+`T*("`@("`@("`@("`@)VAE861L
M:6YE)R`]/B!A<G)A>2@G4&%C:V%G92<L("=697)S:6]N)RP@)U-T871E)RD-
M"B`@("`@("`@("`@("D[#0H@("`@("`@(&9O<F5A8V@@*"1I;G-T86QL960@
M87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("1P;V)J(#T@)')E9RT^9V5T
M4&%C:V%G92AI<W-E="@D<&%C:V%G95LG<&%C:V%G92==*2`_#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)W!A
M8VMA9V4G72`Z("1P86-K86=E6R=N86UE)UTL("1C:&%N;F5L*3L-"B`@("`@
M("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1P;V)J+3YG971086-K
M86=E*"DL("1P;V)J+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&]B:BT^9V5T4W1A=&4H*2`_("1P;V)J
M+3YG9713=&%T92@I(#H@;G5L;"D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&-O=6YT*"1I;G-T86QL960I/3TP*2![#0H@("`@("`@("`@("`D9&%T82`]
M("<H;F\@<&%C:V%G97,@:6YS=&%L;&5D(&9R;VT@8VAA;FYE;"`G("X@)&-H
M86YN96P@+B`G*2<[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"B`@("`-"B`@("!F=6YC=&EO;B!D;TQI<W1!;&PH)&-O
M;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)')E
M9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D
M:6YS=&%L;&5D(#T@)')E9RT^<&%C:V%G94EN9F\H;G5L;"P@;G5L;"P@;G5L
M;"D[#0H@("`@("`@(&9O<F5A8V@@*"1I;G-T86QL960@87,@)&-H86YN96P@
M/3X@)'!A8VMA9V5S*2![#0H@("`@("`@("`@("!U<V]R="@D<&%C:V%G97,L
M(&%R<F%Y*"1T:&ES+"`G7W-O<G1I;F9O)RDI.PT*("`@("`@("`@("`@)&D@
M/2`D:B`](#`[#0H@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=C87!T:6]N)R`]/B`G26YS=&%L;&5D('!A8VMA9V5S+"!C
M:&%N;F5L("<@+B`D8VAA;FYE;"`N("<Z)RP-"B`@("`@("`@("`@("`@("`G
M8F]R9&5R)R`]/B!T<G5E+`T*("`@("`@("`@("`@("`@("=H96%D;&EN92<@
M/3X@87)R87DH)U!A8VMA9V4G+"`G5F5R<VEO;B<L("=3=&%T92<I#0H@("`@
M("`@("`@("`@("`@*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E
M<R!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("1P;V)J(#T@)')E
M9RT^9V5T4&%C:V%G92AI<W-E="@D<&%C:V%G95LG<&%C:V%G92==*2`_#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M86-K86=E6R=P86-K86=E)UT@.B`D<&%C:V%G95LG;F%M92==+"`D8VAA;FYE
M;"D[#0H@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH
M)'!O8FHM/F=E=%!A8VMA9V4H*2P@)'!O8FHM/F=E=%9E<G-I;VXH*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]B:BT^
M9V5T4W1A=&4H*2`_("1P;V)J+3YG9713=&%T92@I(#H@;G5L;"D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)'!A8VMA9V5S*3T]
M,"D@>PT*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G26YS=&%L;&5D('!A8VMA9V5S
M+"!C:&%N;F5L("<@+B`D8VAA;FYE;"`N("<Z)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@("`@("`@("`@
M)V1A=&$G(#T^(&%R<F%Y*&%R<F%Y*"<H;F\@<&%C:V%G97,@:6YS=&%L;&5D
M*2<I*2P-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O
M;6UA;F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"B`@("`-"B`@("!F=6YC=&EO;B!D;T9I;&5,:7-T*"1C;VUM86YD+"`D
M;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AC;W5N="@D
M<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)VQI<W0M9FEL97,@97AP96-T<R`Q('!A<F%M971E<B<I.PT*
M("`@("`@("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*"%I<U]D:7(H)'!A<F%M<ULP72D@
M)B8@*&9I;&5?97AI<W1S*"1P87)A;7-;,%TI('Q\("1F<"`]($!F;W!E;B@D
M<&%R86US6S!=+`T*("`@("`@("`@("`@("`G<B<I*2D@>PT*("`@("`@("`@
M("`@0&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05)?4&%C:V%G949I;&4G*2D@>PT*("`@("`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'!K9R`]("9N97<@4$5!4E]086-K86=E1FEL
M92@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@("`@("`@("`@
M(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L-"B`@("`@("`@("`@("1I;F9O(#T@)B1P:V<M/F9R;VU!;GE&:6QE
M*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@
M("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M("`@("1H96%D:6YG<R`](&%R<F%Y*"=086-K86=E($9I;&4G+"`G26YS=&%L
M;"!0871H)RD[#0H@("`@("`@("`@("`D:6YS=&%L;&5D(#T@9F%L<V4[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@
M("`D<&%R<V5D(#T@)')E9RT^<&%R<V5086-K86=E3F%M92@D<&%R86US6S!=
M+"`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I*3L-"B`@
M("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P87)S960I*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P87)S960I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&EN9F\@/2`F)')E9RT^
M9V5T4&%C:V%G92@D<&%R<V5D6R=P86-K86=E)UTL("1P87)S961;)V-H86YN
M96PG72D[#0H@("`@("`@("`@("`D:&5A9&EN9W,@/2!A<G)A>2@G5'EP92<L
M("=);G-T86QL(%!A=&@G*3L-"B`@("`@("`@("`@("1I;G-T86QL960@/2!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I
M;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1I;F9O*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&EN9F\@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M8"1P87)A;7-;,%TG(&YO="!I;G-T86QL960B*3L-"B`@("`@("`@?0T*("`@
M("`@("`D;&ES="`]("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]
M/2`G,2XP)R!\?"`D:6YS=&%L;&5D*2`_#0H@("`@("`@("`@("`D:6YF;RT^
M9V5T1FEL96QI<W0H*2`Z("1I;F9O+3YG971#;VYT96YT<R@I.PT*("`@("`@
M("!I9B`H)&EN<W1A;&QE9"D@>PT*("`@("`@("`@("`@)&-A<'1I;VX@/2`G
M26YS=&%L;&5D($9I;&5S($9O<B`G("X@)'!A<F%M<ULP73L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1C87!T:6]N(#T@)T-O;G1E;G1S(&]F
M("<@+B!B87-E;F%M92@D<&%R86US6S!=*3L-"B`@("`@("`@?0T*("`@("`@
M("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@)V-A<'1I;VXG(#T^("1C
M87!T:6]N+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@
M("`@("`@("=H96%D;&EN92<@/3X@)&AE861I;F=S*3L-"B`@("`@("`@:68@
M*"1I;F9O+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]("<Q+C`G('Q\("1I
M;G-T86QL960I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1F
M:6QE(#T^("1A='0I('L-"B`@("`@("`@("`@("`@("!I9B`H)&EN<W1A;&QE
M9"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)&%T=%LG:6YS
M=&%L;&5D7V%S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D871T6R=R;VQE)UTL("1A
M='1;)VEN<W1A;&QE9%]A<R==*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=%LG8F%S96EN
M<W1A;&QD:7(G72D@)B8@(6EN7V%R<F%Y*"1A='1;)W)O;&4G72P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W1E<W0G+"`G9&%T82<L("=D
M;V,G*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97-T(#T@)&%T
M=%LG8F%S96EN<W1A;&QD:7(G72`N($1)4D5#5$]265]315!!4D%43U(@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<W0@/2`D9FEL93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!S=VET8V@@*"1A='1;)W)O;&4G72D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`G=&5S="<Z#0H@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=D871A)SH-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)V1O8R<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')O;&4@/2`D871T6R=R;VQE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1R;VQE(#T]("=T97-T)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F]L92`N/2`G<R<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97-T(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1R;VQE("X@)U]D:7(G*2`N
M($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;RT^9V5T4&%C:V%G92@I("X@1$E214-43U)97U-%
M4$%2051/4B`N("1D97-T.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G<&AP)SH-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<W0@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)W!H<%]D:7(G*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5S=#L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D9',R(#T@1$E214-43U)9
M7U-%4$%2051/4B`N($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@("`@
M("`@("`@("`@("1D97-T(#T@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA
M)RP@)R$O(2<L("(A)&1S,BLA(BDL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH1$E214-43U)9
M7U-%4$%2051/4BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97-T*3L-"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2!P<F5G7W)E
M<&QA8V4H)R$O*R$G+"`G+R<L("1F:6QE*3L-"B`@("`@("`@("`@("`@("`@
M("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&9I;&4L("1D97-T*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS
M92![("\O('!A8VMA9V4N>&UL(#(N,"P@;F]T(&EN<W1A;&QE9`T*("`@("`@
M("`@("`@:68@*"%I<W-E="@D;&ES=%LG9&ER)UU;)V9I;&4G75LP72DI('L-
M"B`@("`@("`@("`@("`@("`D;&ES=%LG9&ER)UU;)V9I;&4G72`](&%R<F%Y
M*"1L:7-T6R=D:7(G75LG9FEL92==*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1L:7-T6R=D:7(G75LG9FEL92==(&%S("1A='0I
M('L-"B`@("`@("`@("`@("`@("`D871T(#T@)&%T=%LG871T<FEB<R==.PT*
M("`@("`@("`@("`@("`@("1F:6QE(#T@)&%T=%LG;F%M92==.PT*("`@("`@
M("`@("`@("`@("1R;VQE(#T@)E!%05)?26YS=&%L;&5R7U)O;&4Z.F9A8W1O
M<GDH)&EN9F\L("1A='1;)W)O;&4G72P@)'1H:7,M/F-O;F9I9RD[#0H@("`@
M("`@("`@("`@("`@)')O;&4M/G-E='5P*"1T:&ES+"`D:6YF;RP@)&%T="P@
M)&9I;&4I.PT*("`@("`@("`@("`@("`@(&EF("@A)')O;&4M/FES26YS=&%L
M;&%B;&4H*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5S="`]("<H;F]T
M(&EN<W1A;&QA8FQE*2<[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)&1E<W0@/2`D<F]L92T^<')O8V5S<TEN<W1A
M;&QA=&EO;B@D:6YF;RP@)&%T="P@)&9I;&4L("<G*3L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&1E<W0I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5S="`]("<H56YK;F]W;B!R;VQE("(G("X@
M)&%T=%LG<F]L92==("X@)RDG.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@L+"`D9&5S="D@
M/2`D9&5S=#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A
M>2@D9FEL92P@)&1E<W0I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I
M.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9&]3:&5L;%1E<W0H*0T*#0H@("`@9G5N8W1I;VX@9&]3
M:&5L;%1E<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG9712
M96=I<W1R>2@I.PT*("`@("`@("`D:6YF;R`]("1R96<M/G!A<G-E4&%C:V%G
M94YA;64H)'!A<F%M<ULP72P@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT
M7V-H86YN96PG*2D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O
M*2D@>PT*("`@("`@("`@("`@97AI="@Q*3L@+R\@:6YV86QI9"!P86-K86=E
M(&YA;64-"B`@("`@("`@?0T*("`@("`@("`D<&%C:V%G92`]("1I;F9O6R=P
M86-K86=E)UT[#0H@("`@("`@("1C:&%N;F5L(#T@)&EN9F];)V-H86YN96PG
M73L-"B`@("`@("`@+R\@(G!E87(@<VAE;&PM=&5S="!&;V\B#0H@("`@("`@
M(&EF("@A)')E9RT^<&%C:V%G945X:7-T<R@D<&%C:V%G92P@)&-H86YN96PI
M*2![#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN<&AP+FYE
M="<I('L-"B`@("`@("`@("`@("`@("!I9B`H)')E9RT^<&%C:V%G945X:7-T
M<R@D<&%C:V%G92P@)W!E87(N<&AP+FYE="<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[("\O(&UA9VEC86QL
M>2!C:&%N9V4@8VAA;FYE;',@9F]R(&5X=&5N<VEO;G,-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*'-I>F5O9B@D<&%R86US*2`]/2`Q*2![#0H@("`@("`@("`@("!I9B`H(21R
M96<M/G!A8VMA9V5%>&ES=',H)'!A8VMA9V4L("1C:&%N;F5L*2D@>PT*("`@
M("`@("`@("`@("`@(&5X:70H,2D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`O+R`B<&5A<B!S:&5L;"UT97-T($9O;R`Q+C`B#0H@("`@("`@('T@
M96QS96EF("AS:7IE;V8H)'!A<F%M<RD@/3T@,BD@>PT*("`@("`@("`@("`@
M)'8@/2`D<F5G+3YP86-K86=E26YF;R@D<&%C:V%G92P@)W9E<G-I;VXG+"`D
M8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H(21V('Q\("%V97)S:6]N7V-O
M;7!A<F4H(B1V(BP@(GLD<&%R86US6S%=?2(L(")G92(I*2![#0H@("`@("`@
M("`@("`@("`@97AI="@Q*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("\O(")P96%R('-H96QL+71E<W0@1F]O(&=E(#$N,"(-"B`@("`@("`@?2!E
M;'-E:68@*'-I>F5O9B@D<&%R86US*2`]/2`S*2![#0H@("`@("`@("`@("`D
M=B`]("1R96<M/G!A8VMA9V5);F9O*"1P86-K86=E+"`G=F5R<VEO;B<L("1C
M:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("@A)'8@?'P@(79E<G-I;VY?8V]M
M<&%R92@B)'8B+"`B>R1P87)A;7-;,EU](BP@)'!A<F%M<ULQ72DI('L-"B`@
M("`@("`@("`@("`@("!E>&ET*#$I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI
M;F<H*3L-"B`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N
M9#H@97AP96-T<R`Q('1O(#,@<&%R86UE=&5R<R(I.PT*("`@("`@("`@("`@
M97AI="@Q*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!D;TEN9F\-"@T*("`@(&9U;F-T:6]N(&1O26YF;R@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H8V]U
M;G0H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=P96%R(&EN9F\@97AP96-T<R`Q('!A<F%M971E<B<I
M.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O(#T@9F%L<V4[#0H@("`@("`@
M("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@
M("`@:68@*"A`:7-?9FEL92@D<&%R86US6S!=*2`F)B`A:7-?9&ER*"1P87)A
M;7-;,%TI*2!\?"`D9G`@/2!`9F]P96XH)'!A<F%M<ULP72P@)W(G*2D@>PT*
M("`@("`@("`@("`@0&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I;&4G*2D@>PT*("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!K9R`]("9N97<@4$5!4E]0
M86-K86=E1FEL92@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@
M("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1O8FH@/2`F)'!K9RT^9G)O
M;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*
M("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]B:BDI('L-"B`@("`@
M("`@("`@("`@("`D=6EN9F\@/2`D;V)J+3YG9715<V5R26YF;R@I.PT*("`@
M("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=6EN9F\I*2![#0H@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1U:6YF;R!A<R`D;65S<V%G92D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1M97-S86=E
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@
M)&UE<W-A9V5;)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@D;65S<V%G92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1O8FHI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1O8FHM/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-
M"B`@("`@("`@("`@("`@("`D:6YF;R`]("1O8FHM/G1O07)R87DH*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&]);F9O,B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,L("1O
M8FHL(&9A;'-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1P87)S960@/2`D<F5G+3YP87)S95!A8VMA9V5.86UE
M*"1P87)A;7-;,%TL("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N
M;F5L)RDI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!A<G-E
M9"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)'!A<G-E9"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%C
M:V%G92`]("1P87)S961;)W!A8VMA9V4G73L-"B`@("`@("`@("`@("1C:&%N
M;F5L(#T@)'!A<G-E9%LG8VAA;FYE;"==.PT*("`@("`@("`@("`@)&EN9F\@
M/2`D<F5G+3YP86-K86=E26YF;R@D<&%C:V%G92P@;G5L;"P@)&-H86YN96PI
M.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=O;&0G72DI('L-"B`@
M("`@("`@("`@("`@("`D;V)J(#T@)')E9RT^9V5T4&%C:V%G92@D<&%C:V%G
M92P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1O26YF;S(H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US+"`D;V)J+"!T
M<G5E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M:6YF;SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F\I*2![
M#0H@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@B3F\@:6YF;W)M871I
M;VX@9F]U;F0@9F]R(&`D<&%R86US6S!=)R(I.PT*("`@("`@("`@("`@<F5T
M=7)N.PT*("`@("`@("!]#0H@("`@("`@('5N<V5T*"1I;F9O6R=F:6QE;&ES
M="==*3L-"B`@("`@("`@=6YS970H)&EN9F];)V1I<G1R964G72D[#0H@("`@
M("`@('5N<V5T*"1I;F9O6R=C:&%N9V5L;V<G72D[#0H@("`@("`@(&EF("AI
M<W-E="@D:6YF;ULG>'-D=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@)&EN
M9F];)W!A8VMA9V4N>&UL('9E<G-I;VXG72`]("1I;F9O6R=X<V1V97)S:6]N
M)UT[#0H@("`@("`@("`@("!U;G-E="@D:6YF;ULG>'-D=F5R<VEO;B==*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];)W!A8VMA9V5R
M=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@)&EN9F];)W!A8VMA9V5D('=I
M=&@@4$5!4B!V97)S:6]N)UT@/2`D:6YF;ULG<&%C:V%G97)V97)S:6]N)UT[
M#0H@("`@("`@("`@("!U;G-E="@D:6YF;ULG<&%C:V%G97)V97)S:6]N)UTI
M.PT*("`@("`@("!]#0H@("`@("`@("1K97ES(#T@87)R87E?:V5Y<R@D:6YF
M;RD[#0H@("`@("`@("1L;VYG=&5X="`](&%R<F%Y*"=D97-C<FEP=&EO;B<L
M("=S=6UM87)Y)RD[#0H@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI
M('L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF;ULD:V5Y72DI('L-
M"B`@("`@("`@("`@("`@("!S=VET8V@@*"1K97DI('L-"B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G;6%I;G1A:6YE<G,G.B![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D:2`](#`[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M;7-T<B`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&EN9F];)&ME>5T@87,@)&TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&DK*R`^(#`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&US='(@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&US='(@
M+CT@)&U;)VYA;64G72`N("(@/"([#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1M6R=E;6%I;"==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;7-T<B`N/2`D;5LG96UA:6PG73L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;7-T<B`N/2`D;5LG:&%N9&QE)UT@
M+B`G0'!H<"YN970G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;7-T<B`N/2`B/B`H)&U;
M<F]L95TI(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R1K97E=(#T@)&US='([#0H@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!C87-E("=R96QE87-E7V1E<',G.B![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D:2`](#`[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D9'-T<B`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&EN9F];)&ME>5T@87,@)&0I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]D97!S7W)E
M;%]T<F%N<ULD9%LG<F5L)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5L(#T@)'1H:7,M/E]D97!S7W)E;%]T<F%N<ULD9%LG
M<F5L)UU=.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96P@/2`D9%LG
M<F5L)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?
M='EP95]T<F%N<ULD9%LG='EP92==72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1Y<&4@/2!U8V9I<G-T*"1T:&ES+3Y?9&5P<U]T
M>7!E7W1R86YS6R1D6R=T>7!E)UU=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D='EP92`]("1D6R=T>7!E)UT[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9%LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F%M92`]("1D6R=N86UE)UT@+B`G("<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;64@/2`G)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V97)S:6]N(#T@)&1;)W9E<G-I;VXG72`N("<@)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("<G.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1;)V]P=&EO;F%L)UTI("8F("1D6R=O
M<'1I;VYA;"==(#T]("=Y97,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1O<'1I;VYA;"`]("<@*&]P=&EO;F%L*2<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&]P=&EO;F%L(#T@)R<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D<W1R("X]("(D='EP92`D;F%M921R96P@)'9E<G-I;VXD;W!T:6]N
M86Q<;B([#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULD:V5Y72`]("1D<W1R.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<')O=FED97,G(#H@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E8G5G(#T@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=V97)B;W-E)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&1E8G5G(#P@,BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M<W1R(#T@)T-L87-S97,Z("<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<W1R(#T@
M)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D:2`](#`[#0H@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D:6YF;ULD:V5Y72!A<R`D<"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D9&5B=6<@/"`R("8F("1P6R=T>7!E)UT@(3T@
M(F-L87-S(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@3VYL>2!P<FEN="!C;&%S<V5S
M('=H96X@=F5R8F]S:71Y(&UO9&4@:7,@/"`R#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1D96)U9R`\(#(I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1I*RL@/B`P*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2`B+"`B.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P<W1R("X]("1P6R=N86UE)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1I*RL@/B`P*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2`B7&XB.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P<W1R("X]('5C9FER<W0H)'!;)W1Y
M<&4G72D@+B`B("(@+B`D<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'!;)V5X<&QI8VET)UTI("8F("1P
M6R=E>'!L:6-I="==(#T](#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P<W1R("X]("(@*&5X<&QI8VET*2([#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:V5Y72`]("1P<W1R.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G8V]N9FEG=7)E7V]P
M=&EO;G,G(#H@>PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&EN9F];)&ME>5T@87,@)&D@/3X@)'`I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULD:V5Y75LD:5T@/2!A<G)A>5]M87`H;G5L;"P@
M87)R87E?:V5Y<R@D<"DL(&%R<F%Y7W9A;'5E<R@D<"DI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R1K97E=6R1I72`](&%R<F%Y7VUA
M<"AC<F5A=&5?9G5N8W1I;VXH)R1A)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E='5R;B!J;VEN*"(@/2`B+"1A*3LG*2P@)&EN9F];
M)&ME>5U;)&E=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF
M;ULD:V5Y75LD:5T@/2!I;7!L;V1E*"<L("<L("1I;F9O6R1K97E=6R1I72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULD:V5Y72`](&EM<&QO9&4H(EQN(BP@)&EN9F];)&ME
M>5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9&5F875L=#H@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@/2!I;7!L
M;V1E*"(L("(L("1I;F9O6R1K97E=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1K97D@
M/3T@)U]L87-T;6]D:69I960G*2![#0H@("`@("`@("`@("`@("`@)&AD871E
M(#T@9&%T92@G62UM+60G+"`D:6YF;ULD:V5Y72D[#0H@("`@("`@("`@("`@
M("`@=6YS970H)&EN9F];)&ME>5TI.PT*("`@("`@("`@("`@("`@("1I;F9O
M6R=,87-T($UO9&EF:65D)UT@/2`D:&1A=&4[#0H@("`@("`@("`@("!](&5L
M<V5I9B`H)&ME>2`]/2`G7VQA<W1V97)S:6]N)RD@>PT*("`@("`@("`@("`@
M("`@("1I;F9O6R=,87-T($EN<W1A;&QE9"!697)S:6]N)UT@/2`D:6YF;ULD
M:V5Y72`_("1I;F9O6R1K97E=(#H@)RT@3F]N92`M)SL-"B`@("`@("`@("`@
M("`@("!U;G-E="@D:6YF;ULD:V5Y72D[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1I;F9O6R1K97E=(#T@=')I;2@D:6YF;ULD
M:V5Y72D[#0H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1K97DL("1L
M;VYG=&5X="DI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@
M/2!P<F5G7W)E<&QA8V4H)R\@("LO)RP@)R`G+"`D:6YF;ULD:V5Y72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@("1C87!T:6]N(#T@)T%B;W5T("<@+B`D:6YF;ULG<&%C:V%G92==
M("X@)RTG("X@)&EN9F];)W9E<G-I;VXG73L-"B`@("`@("`@)&1A=&$@/2!A
M<G)A>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`D8V%P=&EO;BP-"B`@
M("`@("`@("`@("=B;W)D97(G(#T^('1R=64I.PT*("`@("`@("!F;W)E86-H
M("@D:6YF;R!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@)&ME
M>2`]('5C=V]R9',H=')I;2AS=')?<F5P;&%C92@G7R<L("<@)RP@)&ME>2DI
M*3L-"B`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1K97DL
M("1V86QU92D[#0H@("`@("`@('T-"B`@("`@("`@)&1A=&%;)W)A=R==(#T@
M)&EN9F\[#0H-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A
M+"`G<&%C:V%G92UI;F9O)RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@
M("`O*BH-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?9&]);F9O,B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,L
M("8D;V)J+"`D:6YS=&%L;&5D*0T*("`@('L-"B`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D8V%P=&EO
M;B`]("=!8F]U="`G("X@)&]B:BT^9V5T0VAA;FYE;"@I("X@)R\G("XD;V)J
M+3YG971086-K86=E*"D@+B`G+2<@+@T*("`@("`@("`@("`@)&]B:BT^9V5T
M5F5R<VEO;B@I.PT*("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@
M("`@)V-A<'1I;VXG(#T^("1C87!T:6]N+`T*("`@("`@("`@("`@)V)O<F1E
M<B<@/3X@=')U92D[#0H@("`@("`@('-W:71C:"`H)&]B:BT^9V5T4&%C:V%G
M951Y<&4H*2D@>PT*("`@("`@("`@("`@8V%S92`G<&AP)R`Z#0H@("`@("`@
M("`@("`@("`@)')E;&5A<V4@/2`G4$5!4BUS='EL92!02%`M8F%S960@4&%C
M:V%G92<[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@
M)V5X='-R8R<@.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@)U!%0TPM
M<W1Y;&4@4$A0(&5X=&5N<VEO;B`H<V]U<F-E(&-O9&4I)SL-"B`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G97AT8FEN)R`Z#0H@("`@
M("`@("`@("`@("`@)')E;&5A<V4@/2`G4$5#3"US='EL92!02%`@97AT96YS
M:6]N("AB:6YA<GDI)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92`G8G5N9&QE)R`Z#0H@("`@("`@("`@("`@("`@)')E;&5A<V4@
M/2`G4&%C:V%G92!B=6YD;&4@*&-O;&QE8W1I;VX@;V8@<&%C:V%G97,I)SL-
M"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@("1E>'1E
M;F1S(#T@)&]B:BT^9V5T17AT96YD<R@I.PT*("`@("`@("`D97AT96YD<R`]
M("1E>'1E;F1S(#\-"B`@("`@("`@("`@("1O8FHM/F=E=%!A8VMA9V4H*2`N
M("<@*&5X=&5N9',@)R`N("1E>'1E;F1S("X@)RDG(#H@)&]B:BT^9V5T4&%C
M:V%G92@I.PT*("`@("`@("!I9B`H)'-R8R`]("1O8FHM/F=E=%-O=7)C95!A
M8VMA9V4H*2D@>PT*("`@("`@("`@("`@)&5X=&5N9',@+CT@)R`H<V]U<F-E
M('!A8VMA9V4@)R`N("1S<F-;)V-H86YN96PG72`N("<O)R`N("1S<F-;)W!A
M8VMA9V4G72`N("<I)SL-"B`@("`@("`@?0T*("`@("`@("`D:6YF;R`](&%R
M<F%Y*`T*("`@("`@("`@("`@)U)E;&5A<V4@5'EP92<@/3X@)')E;&5A<V4L
M#0H@("`@("`@("`@("`G3F%M92<@/3X@)&5X=&5N9',L#0H@("`@("`@("`@
M("`G0VAA;FYE;"<@/3X@)&]B:BT^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@
M("`@)U-U;6UA<GDG(#T^('!R96=?<F5P;&%C92@G+R`@*R\G+"`G("<L("1O
M8FHM/F=E=%-U;6UA<GDH*2DL#0H@("`@("`@("`@("`G1&5S8W)I<'1I;VXG
M(#T^('!R96=?<F5P;&%C92@G+R`@*R\G+"`G("<L("1O8FHM/F=E=$1E<V-R
M:7!T:6]N*"DI+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@)&EN9F];)TUA
M:6YT86EN97)S)UT@/2`G)SL-"B`@("`@("`@9F]R96%C:"`H87)R87DH)VQE
M860G+"`G9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<I(&%S
M("1R;VQE*2![#0H@("`@("`@("`@("`D;&5A9',@/2`D;V)J+3Y[(F=E='LD
M<F]L97US(GTH*3L-"B`@("`@("`@("`@(&EF("@A)&QE861S*2![#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&QE861S6R=A8W1I=F4G72DI('L-"B`@("`@("`@
M("`@("`@("`D;&5A9',@/2!A<G)A>2@D;&5A9',I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@9F]R96%C:"`H)&QE861S(&%S("1L96%D*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG36%I;G1A:6YE<G,G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)TUA:6YT86EN97)S
M)UT@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)&EN9F];)TUA:6YT86EN97)S)UT@+CT@)&QE861;)VYA;64G72`N("<@
M/"<[#0H@("`@("`@("`@("`@("`@)&EN9F];)TUA:6YT86EN97)S)UT@+CT@
M)&QE861;)V5M86EL)UT@+B`B/B`H)')O;&4I(CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D:6YF;ULG4F5L96%S92!$871E)UT@/2`D
M;V)J+3YG971$871E*"D[#0H@("`@("`@(&EF("@D=&EM92`]("1O8FHM/F=E
M=%1I;64H*2D@>PT*("`@("`@("`@("`@)&EN9F];)U)E;&5A<V4@1&%T92==
M("X]("<@)R`N("1T:6UE.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O6R=2
M96QE87-E(%9E<G-I;VXG72`]("1O8FHM/F=E=%9E<G-I;VXH*2`N("<@*"<@
M+B`D;V)J+3YG9713=&%T92@I("X@)RDG.PT*("`@("`@("`D:6YF;ULG05!)
M(%9E<G-I;VXG72`]("1O8FHM/F=E=%9E<G-I;VXH)V%P:2<I("X@)R`H)R`N
M("1O8FHM/F=E=%-T871E*"=A<&DG*2`N("<I)SL-"B`@("`@("`@)&EN9F];
M)TQI8V5N<V4G72`]("1O8FHM/F=E=$QI8V5N<V4H*3L-"B`@("`@("`@)'5R
M:2`]("1O8FHM/F=E=$QI8V5N<V5,;V-A=&EO;B@I.PT*("`@("`@("!I9B`H
M)'5R:2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1U<FE;)W5R:2==*2D@
M>PT*("`@("`@("`@("`@("`@("1I;F9O6R=,:6-E;G-E)UT@+CT@)R`H)R`N
M("1U<FE;)W5R:2==("X@)RDG.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D97AT<F$@/2`D;V)J+3YG971);G-T86QL961,;V-A
M=&EO;B@D:6YF;ULG9FEL97-O=7)C92==*3L-"B`@("`@("`@("`@("`@("!I
M9B`H)&5X=')A*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=,:6-E
M;G-E)UT@+CT@)R`H)R`N("1U<FE;)V9I;&5S;W5R8V4G72`N("<I)SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)&EN9F];)U)E;&5A<V4@3F]T97,G72`]("1O8FHM/F=E=$YO=&5S
M*"D[#0H@("`@("`@(&EF("@D8V]M<&%T(#T@)&]B:BT^9V5T0V]M<&%T:6)L
M92@I*2![#0H@("`@("`@("`@("`D:6YF;ULG0V]M<&%T:6)L92!W:71H)UT@
M/2`G)SL-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VUP870@87,@)'!A8VMA
M9V4I('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG0V]M<&%T:6)L92!W:71H
M)UT@+CT@)'!A8VMA9V5;)V-H86YN96PG72`N("<O)R`N("1P86-K86=E6R=P
M86-K86=E)UT@+@T*("`@("`@("`@("`@("`@("`@("`B7&Y697)S:6]N<R`^
M/2`B("X@)'!A8VMA9V5;)VUI;B==("X@)RP@/#T@)R`N("1P86-K86=E6R=M
M87@G73L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V5X
M8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1P86-K86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%C:V%G95LG97AC;'5D92==(#T@:6UP;&]D92@G+"`G+"`D<&%C
M:V%G95LG97AC;'5D92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@0V]M<&%T
M:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF
M;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF
M;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#
M;VUP871I8FQE('=I=&@G72`N/2`D<&%C:V%G95LG8VAA;FYE;"==("X@)R\G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P86-K86=E
M)UT@+B`B7&Y697)S:6]N<R`B("X@)'!A8VMA9V5;)V5X8VQU9&4G73L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)'5S97-R;VQE(#T@)&]B:BT^9V5T57-E<W)O;&4H*3L-"B`@("`@
M("`@:68@*"1U<V5S<F]L92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D
M=7-E<W)O;&5;,%TI*2![#0H@("`@("`@("`@("`@("`@)'5S97-R;VQE(#T@
M87)R87DH)'5S97-R;VQE*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1U<V5S<F]L92!A<R`D<F]L961A=&$I('L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&EN9F];)U5S97,@0W5S=&]M(%)O;&5S)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=5<V5S($-U<W1O;2!2
M;VQE<R==("X](")<;B([#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)&EN9F];)U5S97,@0W5S=&]M(%)O;&5S)UT@
M/2`G)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1R;VQE9&%T85LG<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<F]L97!A8VMA9V4@/2`D<F5G+3YP87)S961086-K86=E3F%M
M951O4W1R:6YG*"1R;VQE9&%T82P@=')U92D[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)')O;&5P86-K86=E(#T@
M)')O;&5D871A6R=U<FDG73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&EN9F];)U5S97,@0W5S=&]M(%)O;&5S)UT@+CT@)')O;&5D
M871A6R=R;VQE)UT@+B`G("@G("X@)')O;&5P86-K86=E("X@)RDG.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1U<V5S=&%S:R`]("1O
M8FHM/F=E=%5S97-T87-K*"D[#0H@("`@("`@(&EF("@D=7-E<W1A<VLI('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'5S97-T87-K6S!=*2D@>PT*("`@
M("`@("`@("`@("`@("1U<V5S=&%S:R`](&%R<F%Y*"1U<V5S=&%S:RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D=7-E<W1A<VL@
M87,@)'1A<VMD871A*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I
M;F9O6R=5<V5S($-U<W1O;2!487-K<R==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULG57-E<R!#=7-T;VT@5&%S:W,G72`N/2`B7&XB.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R=5<V5S($-U<W1O;2!487-K<R==(#T@)R<[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&%S:V1A=&%;)W!A
M8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1A<VMP86-K86=E
M(#T@)')E9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D=&%S:V1A=&$L
M('1R=64I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1T87-K<&%C:V%G92`]("1T87-K9&%T85LG=7)I)UT[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I;F9O6R=5<V5S
M($-U<W1O;2!487-K<R==("X]("1T87-K9&%T85LG=&%S:R==("X@)R`H)R`N
M("1T87-K<&%C:V%G92`N("<I)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D9&5P<R`]("1O8FHM/F=E=$1E<&5N9&5N8VEE<R@I.PT*
M("`@("`@("`D:6YF;ULG4F5Q=6ER960@1&5P96YD96YC:65S)UT@/2`G4$A0
M('9E<G-I;VX@)R`N("1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG;6EN)UT[
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;
M)VUA>"==*2D@>PT*("`@("`@("`@("`@)&EN9F];)U)E<75I<F5D($1E<&5N
M9&5N8VEE<R==("X]("<M)R`N("1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG
M;6%X)UT@+B`B7&XB.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)&EN9F];)U)E<75I<F5D($1E<&5N9&5N8VEE<R==("X](")<;B([#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P
M:'`G75LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D
M:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@
M("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@/2`G)SL-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#
M;VUP871I8FQE('=I=&@G72`N/2`B7&XB.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P:'`G
M75LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("1D97!S6R=R97%U
M:7)E9"==6R=P:'`G75LG97AC;'5D92==(#T-"B`@("`@("`@("`@("`@("`@
M("`@:6UP;&]D92@G+"`G+"`D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;)V5X
M8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D:6YF;ULG
M3F]T($-O;7!A=&EB;&4@=VET:"==("X](")02%`@=F5R<VEO;G-<;B`@(B`N
M#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=E
M>&-L=61E)UT[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)U)E<75I<F5D
M($1E<&5N9&5N8VEE<R==("X]("=014%2(&EN<W1A;&QE<B!V97)S:6]N)SL-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS
M=&%L;&5R)UU;)VUA>"==*2D@>PT*("`@("`@("`@("`@)&EN9F];)U)E<75I
M<F5D($1E<&5N9&5N8VEE<R==("X]("=S("<@+@T*("`@("`@("`@("`@("`@
M("1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UU;)VUI;B==("X@
M)RTG("X-"B`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG<&5A
M<FEN<W1A;&QE<B==6R=M87@G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1I;F9O6R=297%U:7)E9"!$97!E;F1E;F-I97,G72`N/2`G("<@
M+@T*("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS
M=&%L;&5R)UU;)VUI;B==("X@)R!O<B!N97=E<B<[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS=&%L
M;&5R)UU;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@
M("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@
M0V]M<&%T:6)L92!W:71H)UT@+CT@(EQN(CL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D9&5P<ULG<F5Q=6ER960G75LG<&5A
M<FEN<W1A;&QE<B==6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G75LG97AC;'5D92==
M(#T-"B`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D9&5P<ULG
M<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE<B==6R=E>&-L=61E)UTI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE
M('=I=&@G72`N/2`B4$5!4B!I;G-T86QL97)<;B`@5F5R<VEO;G,@(B`N#0H@
M("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL
M97(G75LG97AC;'5D92==.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@
M*&%R<F%Y*"=086-K86=E)RP@)T5X=&5N<VEO;B<I(&%S("1T>7!E*2![#0H@
M("`@("`@("`@("`D:6YD97@@/2!S=')T;VQO=V5R*"1T>7!E*3L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LD:6YD97A=*2D@
M>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G
M75LD:6YD97A=6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1D
M97!S6R=R97%U:7)E9"==6R1I;F1E>%T@/2!A<G)A>2@D9&5P<ULG<F5Q=6ER
M960G75LD:6YD97A=*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;)&EN9&5X72!A<R`D
M<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A
M8VMA9V5;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F]I;F1E>"`]("=.;W0@0V]M<&%T:6)L92!W:71H)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)TYO="!#;VUP
M871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(EQN
M(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O
M:6YD97@@/2`G4F5Q=6ER960@1&5P96YD96YC:65S)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R1I;F9O:6YD97A=("X](")<;B([#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I
M;F1E>"`]/2`G97AT96YS:6]N)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2`D<&%C:V%G95LG;F%M92==.PT*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1P86-K86=E6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`D<&%C:V%G95LG8VAA;FYE;"==("X@)R\G
M("X@)'!A8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2`G7U]U<FDO)R`N("1P86-K86=E6R=N86UE)UT@+B`G("AS=&%T:6,@55))
M*2<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I;F1E
M>%T@+CT@(B1T>7!E("1N86UE(CL-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P86-K86=E6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R1I;F9O:6YD97A=("X](")<;B`@1&]W;FQO860@55))
M.B`D<&%C:V%G95MU<FE=(CL-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG;6%X)UTI("8F(&ES<V5T*"1P
M86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R1I;F9O:6YD97A=("X]("(@7&X@(%9E<G-I;VYS("(@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72`N("<M)R`N
M("1P86-K86=E6R=M87@G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1P86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R1I;F9O:6YD97A=("X]("(@7&X@(%9E<G-I;VX@
M(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI
M;B==("X@)R!O<B!N97=E<B<[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("AI<W-E="@D<&%C:V%G95LG;6%X)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B(%QN("!697)S:6]N
M("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M
M87@G72`N("<@;W(@;VQD97(G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG<F5C;VUM
M96YD960G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I
M;F9O:6YD97A=("X](")<;B`@4F5C;VUM96YD960@=F5R<VEO;CH@)'!A8VMA
M9V5;<F5C;VUM96YD961=(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V5X8VQU9&4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN
M9F];)TYO="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@
M)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W
M:71H)UT@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%C:V%G95LG
M97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M86-K86=E6R=E>&-L=61E)UT@/2!I;7!L;V1E*"<L("<L("1P86-K86=E6R=E
M>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)W!A8VMA9V4G72`]("1P86-K
M86=E6R=N86UE)UT[("\O(&9O<B!P87)S961086-K86=E3F%M951O4W1R:6YG
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E
M6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X]("<]/B!E>&-E<'0@
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`G4&%C
M:V%G92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5G+3YP
M87)S961086-K86=E3F%M951O4W1R:6YG*"1P86-K86=E+"!T<G5E*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W
M:71H)UT@+CT@(EQN("!697)S:6]N<R`B("X@)'!A8VMA9V5;)V5X8VQU9&4G
M73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&1E<'-;)W)E<75I<F5D)UU;)V]S)UTI*2![#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)V]S)UU;)VYA;64G72DI('L-"B`@
M("`@("`@("`@("`@("`D9&5P6R=R97%U:7)E9"==6R=O<R==6R=N86UE)UT@
M/2!A<G)A>2@D9&5P6R=R97%U:7)E9"==6R=O<R==6R=N86UE)UTI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<%LG<F5Q=6ER
M960G75LG;W,G72!A<R`D;W,I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&]S6R=C;VYF;&EC=',G72D@)B8@)&]S6R=C;VYF;&EC=',G72`]/2`G
M>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O
M6R=.;W0@0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B)&]S6VYA;65=($]P
M97)A=&EN9R!3>7-T96TB.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R=297%U:7)E9"!$97!E;F1E;F-I
M97,G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG4F5Q
M=6ER960@1&5P96YD96YC:65S)UT@+CT@(B1O<UMN86UE72!/<&5R871I;F<@
M4WES=&5M(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==
M6R=A<F-H)UTI*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E
M<75I<F5D)UU;)V%R8V@G75LG<&%T=&5R;B==*2D@>PT*("`@("`@("`@("`@
M("`@("1D97!;)W)E<75I<F5D)UU;)V%R8V@G75LG<&%T=&5R;B==(#T@87)R
M87DH)&1E<%LG<F5Q=6ER960G75LG;W,G75LG<&%T=&5R;B==*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)W)E<75I<F5D
M)UU;)V%R8V@G72!A<R`D;W,I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&]S6R=C;VYF;&EC=',G72D@)B8@)&]S6R=C;VYF;&EC=',G72`]/2`G
M>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O
M6R=.;W0@0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B3U,O07)C:"!M871C
M:&EN9R!P871T97)N("<O)&]S6W!A='1E<FY=+R<B.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=297%U
M:7)E9"!$97!E;F1E;F-I97,G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULG4F5Q=6ER960@1&5P96YD96YC:65S)UT@+CT@(D]3+T%R
M8V@@;6%T8VAI;F<@<&%T=&5R;B`G+R1O<UMP871T97)N72\G(CL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@
M("`@9F]R96%C:"`H87)R87DH)U!A8VMA9V4G+"`G17AT96YS:6]N)RD@87,@
M)'1Y<&4I('L-"B`@("`@("`@("`@("`@("`D:6YD97@@/2!S=')T;VQO=V5R
M*"1T>7!E*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)V]P
M=&EO;F%L)UU;)&EN9&5X72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R1I;F1E>%U;)VYA;64G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!S6R=O<'1I;VYA;"==6R1I
M;F1E>%T@/2!A<G)A>2@D9&5P<ULG;W!T:6]N86PG75LD:6YD97A=*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D9&5P<ULG;W!T:6]N86PG75LD:6YD97A=(&%S("1P86-K86=E*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;
M)V-O;F9L:6-T<R==*2`F)B`D<&%C:V%G95LG8V]N9FQI8W1S)UT@/3T@)WEE
M<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;VEN9&5X
M(#T@)TYO="!#;VUP871I8FQE('=I=&@G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)TYO="!#;VUP871I8FQE('=I
M=&@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@
M(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O:6YD97@@/2`G3W!T:6]N86P@1&5P96YD96YC:65S
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I
M;F9O6R=/<'1I;VYA;"!$97!E;F1E;F-I97,G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)T]P=&EO;F%L($1E<&5N9&5N
M8VEE<R==(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)T]P=&EO;F%L($1E<&5N9&5N8VEE<R==("X](")<;B([#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1I;F1E>"`]/2`G97AT
M96YS:6]N)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M(#T@)'!A8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1P86-K86=E6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@)'!A8VMA9V5;)V-H86YN96PG72`N
M("<O)R`N("1P86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64@/2`G7U]U<FDO)R`N("1P86-K86=E6R=N86UE)UT@+B`G
M("AS=&%T:6,@55))*2<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)&EN9F]I;F1E>%T@+CT@(B1T>7!E("1N86UE(CL-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG
M=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)&EN9F]I;F1E>%T@+CT@(EQN("!$;W=N;&]A9"!54DDZ("1P86-K86=E6W5R
M:5TB.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1I;F9O:6YD97@@/3T@)TYO="!#;VUP871I8FQE('=I=&@G
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@8V]N9FQI8W1S
M(&ES(&]N;'D@=7-E9"!T;R!S87D@=&AA="!A;&P@=F5R<VEO;G,@8V]N9FQI
M8W0-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<&%C:V%G95LG;6%X)UTI("8F(&ES<V5T*"1P86-K
M86=E6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:6YF;ULD:6YF;VEN9&5X72`N/2`B(%QN("!697)S:6]N<R`B("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@
M)RTG("X@)'!A8VMA9V5;)VUA>"==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*&ES<V5T*"1P86-K86=E6R=M:6XG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B
M(%QN("!697)S:6]N("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%C:V%G95LG;6EN)UT@+B`G(&]R(&YE=V5R)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<&%C:V%G95LG;6%X
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN
M9F]I;F1E>%T@+CT@(B!<;B`@5F5R<VEO;B`B("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@)R!O<B!O;&1E
M<B<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W)E8V]M;65N9&5D)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I
M;F1E>%T@+CT@(EQN("!296-O;6UE;F1E9"!V97)S:6]N.B`D<&%C:V%G95MR
M96-O;6UE;F1E9%TB.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=E>&-L
M=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB
M;&4@=VET:"==(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B7&XB.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)V5X8VQU
M9&4G72`](&EM<&QO9&4H)RP@)RP@)'!A8VMA9V5;)V5X8VQU9&4G72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@
M(E!A8VMA9V4@)'!A8VMA9V5<;B`@5F5R<VEO;G,@(B`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=E>&-L=61E)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=G<F]U<"==*2D@>PT*("`@
M("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG9W)O=7`G75LP72DI('L-"B`@
M("`@("`@("`@("`@("`D9&5P<ULG9W)O=7`G72`](&%R<F%Y*"1D97!S6R=G
M<F]U<"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1D97!S6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@("`@
M("1I;F9O6R=$97!E;F1E;F-Y($=R;W5P("<@+B`D9W)O=7!;)V%T=')I8G,G
M75LG;F%M92==72`]("1G<F]U<%LG871T<FEB<R==6R=H:6YT)UT[#0H@("`@
M("`@("`@("`@("`@)&=R;W5P:6YD97@@/2`D9W)O=7!;)V%T=')I8G,G75LG
M;F%M92==("X@)R!#;VYT96YT<R<[#0H@("`@("`@("`@("`@("`@)&EN9F];
M)&=R;W5P:6YD97A=(#T@)R<[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M87)R87DH)U!A8VMA9V4G+"`G17AT96YS:6]N)RD@87,@)'1Y<&4I('L-"B`@
M("`@("`@("`@("`@("`@("`@)&EN9&5X(#T@<W1R=&]L;W=E<B@D='EP92D[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)&EN9&5X
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O
M=7!;)&EN9&5X75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1G<F]U<%LD:6YD97A=(#T@87)R87DH)&=R;W5P6R1I;F1E>%TI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&=R;W5P6R1I;F1E>%T@87,@)'!A8VMA9V4I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I
M;F9O6R1G<F]U<&EN9&5X72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X](")<;B([#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D:6YD97@@/3T@)V5X=&5N<VEO;B<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`D<&%C:V%G95LG;F%M
M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C
M:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`D<&%C:V%G95LG8VAA;FYE;"==("X@)R\G
M("X@)'!A8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE(#T@)U]?=7)I+R<@+B`D<&%C:V%G95LG;F%M92==
M("X@)R`H<W1A=&EC(%5222DG.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG
M=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<&%C:V%G95LG8V]N9FQI8W1S)UTI("8F("1P86-K86=E6R=C
M;VYF;&EC=',G72`]/2`G>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X](").;W0@0V]M
M<&%T:6)L92!W:71H("1T>7!E("1N86UE(CL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B)'1Y<&4@
M)&YA;64B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN
M9&5X72`N/2`B7&X@($1O=VYL;V%D(%5223H@)'!A8VMA9V5;=7)I72([#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V-O;F9L:6-T<R==*2`F
M)B`D<&%C:V%G95LG8V]N9FQI8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X]
M(").;W0@0V]M<&%T:6)L92!W:71H("1T>7!E("1N86UE(CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B)'1Y<&4@)&YA;64B.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG
M;6%X)UTI("8F(&ES<V5T*"1P86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X]
M("(@7&X@(%9E<G-I;VYS("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@)RTG("X@)'!A8VMA9V5;
M)VUA>"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("AI<W-E="@D<&%C:V%G95LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B(%QN("!6
M97)S:6]N("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A8VMA9V5;)VUI;B==("X@)R!O<B!N97=E<B<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1P86-K86=E6R=M
M87@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)&=R;W5P:6YD97A=("X]("(@7&X@(%9E<G-I;VX@(B`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG;6EN)UT@
M+B`G(&]R(&]L9&5R)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K
M86=E6R=R96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULD9W)O=7!I;F1E>%T@+CT@(EQN("!296-O;6UE
M;F1E9"!V97)S:6]N.B`D<&%C:V%G95MR96-O;6UE;F1E9%TB.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF
M;ULG3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I
M=&@G72`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN9F];)&=R;W5P:6YD97A=("X](").;W0@0V]M<&%T:6)L92!W:71H7&XB
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%C:V%G
M95LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A8VMA9V5;)V5X8VQU9&4G72`](&EM<&QO9&4H)RP@)RP@
M)'!A8VMA9V5;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN9F];)&=R;W5P:6YD97A=("X]("(@(%!A8VMA9V4@)'!A8VMA9V5<;B`@
M5F5R<VEO;G,@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%C:V%G95LG97AC;'5D92==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&]B:BT^9V5T4&%C:V%G
M951Y<&4H*2`]/2`G8G5N9&QE)RD@>PT*("`@("`@("`@("`@)&EN9F];)T)U
M;F1L960@4&%C:V%G97,G72`]("<G.PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&]B:BT^9V5T0G5N9&QE9%!A8VMA9V5S*"D@87,@)'!A8VMA9V4I('L-"B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R="=6YD;&5D(%!A8VMA
M9V5S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R="=6YD;&5D
M(%!A8VMA9V5S)UT@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=U<FDG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&EN9F];)T)U;F1L960@4&%C:V%G97,G72`N
M/2`G7U]U<FDO)R`N("1P86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R="=6YD;&5D(%!A8VMA9V5S)UT@+CT@(EQN("`H55))
M.B`D<&%C:V%G95MU<FE=(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG0G5N9&QE9"!086-K86=E<R==
M("X]("1P86-K86=E6R=C:&%N;F5L)UT@+B`G+R<@+B`D<&%C:V%G95LG;F%M
M92==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D:6YF;ULG<&%C:V%G92YX;6P@=F5R<VEO;B==(#T@
M)S(N,"<[#0H@("`@("`@(&EF("@D:6YS=&%L;&5D*2![#0H@("`@("`@("`@
M("!I9B`H)&]B:BT^9V5T3&%S=$UO9&EF:65D*"DI('L-"B`@("`@("`@("`@
M("`@("`D:6YF;ULG3&%S="!-;V1I9FEE9"==(#T@9&%T92@G62UM+60@2#II
M)RP@)&]B:BT^9V5T3&%S=$UO9&EF:65D*"DI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'8@/2`D;V)J+3YG971,87-T26YS=&%L;&5D5F5R<VEO
M;B@I.PT*("`@("`@("`@("`@)&EN9F];)TQA<W0@26YS=&%L;&5D(%9E<G-I
M;VXG72`]("1V(#\@)'8@.B`G+2!.;VYE("TG.PT*("`@("`@("!]#0H@("`@
M("`@(&9O<F5A8V@@*"1I;F9O(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@
M("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D:V5Y+"`D=F%L=64I
M.PT*("`@("`@("!]#0H@("`@("`@("1D871A6R=R87<G72`]("1O8FHM/F=E
M=$%R<F%Y*"D[("\O(&YO('9A;&ED871I;VX@;F5E9&5D#0H-"B`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`G<&%C:V%G92UI;F9O)RD[
M#0H@("`@?0T*?0T*#0H_/@T*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA
M;F0O4F5M;W1E+GAM;```````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-34R,``Q,#4Q-30S,3`U-P`P,C$T,C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^
M#0H@/')E;6]T92UI;F9O/@T*("`\<W5M;6%R>3Y);F9O<FUA=&EO;B!!8F]U
M="!296UO=&4@4&%C:V%G97,\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U)E
M;6]T94EN9F\\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<FD\+W-H;W)T8W5T
M/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/B9L=#MP86-K86=E)F=T.PT*1V5T
M(&1E=&%I;',@;VX@82!P86-K86=E(&9R;VT@=&AE('-E<G9E<BX\+V1O8SX-
M"B`\+W)E;6]T92UI;F9O/@T*(#QL:7-T+75P9W)A9&5S/@T*("`\<W5M;6%R
M>3Y,:7-T($%V86EL86)L92!5<&=R861E<SPO<W5M;6%R>3X-"B`@/&9U;F-T
M:6]N/F1O3&ES=%5P9W)A9&5S/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/FQU
M/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SY;<')E9F5R<F5D
M7W-T871E70T*3&ES="!R96QE87-E<R!O;B!T:&4@<V5R=F5R(&]F('!A8VMA
M9V5S('EO=2!H879E(&EN<W1A;&QE9"!W:&5R90T*82!N97=E<B!V97)S:6]N
M(&ES(&%V86EL86)L92!W:71H('1H92!S86UE(')E;&5A<V4@<W1A=&4@*'-T
M86)L92!E=&,N*0T*;W(@=&AE('-T871E('!A<W-E9"!A<R!T:&4@<V5C;VYD
M('!A<F%M971E<BX\+V1O8SX-"B`\+VQI<W0M=7!G<F%D97,^#0H@/')E;6]T
M92UL:7-T/@T*("`\<W5M;6%R>3Y,:7-T(%)E;6]T92!086-K86=E<SPO<W5M
M;6%R>3X-"B`@/&9U;F-T:6]N/F1O4F5M;W1E3&ES=#PO9G5N8W1I;VX^#0H@
M(#QS:&]R=&-U=#YR;#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&-H
M86YN96P^#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M<W!E8VEF>2!A(&-H86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N
M;F5L/"]D;V,^#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^
M#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SX-"DQI<W1S('1H92!P86-K86=E<R!A
M=F%I;&%B;&4@;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L;VYG('=I=&@@
M=&AE#0IL871E<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P86-K86=E+CPO
M9&]C/@T*(#PO<F5M;W1E+6QI<W0^#0H@/'-E87)C:#X-"B`@/'-U;6UA<GD^
M4V5A<F-H(')E;6]T92!P86-K86=E(&1A=&%B87-E/"]S=6UM87)Y/@T*("`\
M9G5N8W1I;VX^9&]396%R8V@\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<W`\
M+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*("`@(#QS
M:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-P96-I9GD@82!C:&%N
M;F5L(&]T:&5R('1H86X@=&AE(&1E9F%U;'0@8VAA;FYE;#PO9&]C/@T*("`@
M(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P=&EO;G,^
M#0H@(#QD;V,^6W!A8VMA9V5N86UE72!;<&%C:V%G96EN9F]=#0I,:7-T<R!A
M;&P@<&%C:V%G97,@=VAI8V@@;6%T8V@@=&AE('-E87)C:"!P87)A;65T97)S
M+B`@5&AE(&9I<G-T#0IP87)A;65T97(@:7,@82!F<F%G;65N="!O9B!A('!A
M8VMA9V5N86UE+B`@5&AE(&1E9F%U;'0@8VAA;FYE;`T*=VEL;"!B92!U<V5D
M('5N;&5S<R!E>'!L:6-I=&QY(&]V97)R:61D96XN("!4:&4@<V5C;VYD('!A
M<F%M971E<@T*=VEL;"!B92!U<V5D('1O(&UA=&-H(&%N>2!P;W)T:6]N(&]F
M('1H92!S=6UM87)Y+V1E<V-R:7!T:6]N/"]D;V,^#0H@/"]S96%R8V@^#0H@
M/&QI<W0M86QL/@T*("`\<W5M;6%R>3Y,:7-T($%L;"!086-K86=E<SPO<W5M
M;6%R>3X-"B`@/&9U;F-T:6]N/F1O3&ES=$%L;#PO9G5N8W1I;VX^#0H@(#QS
M:&]R=&-U=#YL83PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&-H86YN
M96P^#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QD;V,^<W!E
M8VEF>2!A(&-H86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L
M/"]D;V,^#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@
M(#PO;W!T:6]N<SX-"B`@/&1O8SX-"DQI<W1S('1H92!P86-K86=E<R!A=F%I
M;&%B;&4@;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L;VYG('=I=&@@=&AE
M#0IL871E<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P86-K86=E+CPO9&]C
M/@T*(#PO;&ES="UA;&P^#0H@/&1O=VYL;V%D/@T*("`\<W5M;6%R>3Y$;W=N
M;&]A9"!086-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]$;W=N;&]A
M9#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YD/"]S:&]R=&-U=#X-"B`@/&]P
M=&EO;G,^#0H@("`\;F]C;VUP<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO
M<G1O<'0^#0H@("`@/&1O8SYD;W=N;&]A9"!A;B!U;F-O;7!R97-S960@*"YT
M87(I(&9I;&4\+V1O8SX-"B`@(#PO;F]C;VUP<F5S<SX-"B`@/"]O<'1I;VYS
M/@T*("`\9&]C/B9L=#MP86-K86=E)F=T.RXN+@T*1&]W;FQO860@<&%C:V%G
M92!T87)B86QL<RX@(%1H92!F:6QE<R!W:6QL(&)E(&YA;65D(&%S('-U9V=E
M<W1E9"!B>2!T:&4-"G-E<G9E<BP@9F]R(&5X86UP;&4@:68@>6]U(&1O=VYL
M;V%D('1H92!$0B!P86-K86=E(&%N9"!T:&4@;&%T97-T('-T86)L90T*=F5R
M<VEO;B!O9B!$0B!I<R`Q+C8N-2P@=&AE(&1O=VYL;V%D960@9FEL92!W:6QL
M(&)E($1"+3$N-BXU+G1G>BX\+V1O8SX-"B`\+V1O=VYL;V%D/@T*(#QC;&5A
M<BUC86-H93X-"B`@/'-U;6UA<GD^0VQE87(@5V5B(%-E<G9I8V5S($-A8VAE
M/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#;&5A<D-A8VAE/"]F=6YC=&EO
M;CX-"B`@/'-H;W)T8W5T/F-C/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-
M"B`@/&1O8SX-"D-L96%R('1H92!834PM4E!#+U)%4U0@8V%C:&4N("!3964@
M86QS;R!T:&4@8V%C:&5?='1L(&-O;F9I9W5R871I;VX-"G!A<F%M971E<BX-
M"CPO9&]C/@T*(#PO8VQE87(M8V%C:&4^#0H\+V-O;6UA;F1S/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]296UO=&4N<&AP````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8S-S(S`#$P-3$U-#,Q,#4W
M`#`R,30R-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?4F5M;W1E("AR96UO
M=&4M:6YF;RP@;&ES="UU<&=R861E<RP@<F5M;W1E+6QI<W0L('-E87)C:"P@
M;&ES="UA;&PL(&1O=VYL;V%D+`T*("H@8VQE87(M8V%C:&4@8V]M;6%N9',I
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)E;6]T92YP
M:'`L=B`Q+CDP+C(N,B`R,#`V+S`S+S(S(#`U.C0U.C$W(&-E;&QO9R!%>'`@
M)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E
M<75I<F5?;VYC92`G4$5!4B]#;VUM86YD+T-O;6UO;BYP:'`G.PT*<F5Q=6ER
M95]O;F-E("=014%2+U)%4U0N<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA
M;F1S(&9O<B!R96UO=&4@<V5R=F5R('%U97)Y:6YG#0H@*@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M+PT*8VQA<W,@4$5!4E]#;VUM86YD7U)E;6]T92!E>'1E;F1S(%!%05)?0V]M
M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@8V]M;6%N9"!D969I;FET:6]N
M<PT*#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<F5M
M;W1E+6EN9F\G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^
M("=);F9O<FUA=&EO;B!!8F]U="!296UO=&4@4&%C:V%G97,G+`T*("`@("`@
M("`@("`@)V9U;F-T:6]N)R`]/B`G9&]296UO=&5);F9O)RP-"B`@("`@("`@
M("`@("=S:&]R=&-U="<@/3X@)W)I)RP-"B`@("`@("`@("`@("=O<'1I;VYS
M)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E
M/@T*1V5T(&1E=&%I;',@;VX@82!P86-K86=E(&9R;VT@=&AE('-E<G9E<BXG
M+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)VQI<W0M=7!G<F%D97,G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=,:7-T($%V86EL
M86)L92!5<&=R861E<R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;TQI<W15<&=R861E<R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=L
M=2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@
M("`@("`@("=D;V,G(#T^("=;<')E9F5R<F5D7W-T871E70T*3&ES="!R96QE
M87-E<R!O;B!T:&4@<V5R=F5R(&]F('!A8VMA9V5S('EO=2!H879E(&EN<W1A
M;&QE9"!W:&5R90T*82!N97=E<B!V97)S:6]N(&ES(&%V86EL86)L92!W:71H
M('1H92!S86UE(')E;&5A<V4@<W1A=&4@*'-T86)L92!E=&,N*0T*;W(@=&AE
M('-T871E('!A<W-E9"!A<R!T:&4@<V5C;VYD('!A<F%M971E<BXG#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`G<F5M;W1E+6QI<W0G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=,:7-T(%)E;6]T92!086-K86=E
M<R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U)E;6]T94QI<W0G
M+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<FPG+`T*("`@("`@("`@
M("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=C:&%N
M;F5L)R`]/@T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=S<&5C:69Y(&$@8VAA;FYE;"!O=&AE<B!T:&%N
M('1H92!D969A=6QT(&-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G
M87)G)R`]/B`G0TA!3B<L#0H@("`@("`@("`@("`@("`@("`@("D-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*3&ES=',@
M=&AE('!A8VMA9V5S(&%V86EL86)L92!O;B!T:&4@8V]N9FEG=7)E9"!S97)V
M97(@86QO;F<@=VET:"!T:&4-"FQA=&5S="!S=&%B;&4@<F5L96%S92!O9B!E
M86-H('!A8VMA9V4N)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=S96%R
M8V@G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=396%R
M8V@@<F5M;W1E('!A8VMA9V4@9&%T86)A<V4G+`T*("`@("`@("`@("`@)V9U
M;F-T:6]N)R`]/B`G9&]396%R8V@G+`T*("`@("`@("`@("`@)W-H;W)T8W5T
M)R`]/B`G<W`G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S<&5C:69Y
M(&$@8VAA;FYE;"!O=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN96PG+`T*
M("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@("`@
M("`@("`@("`@("`@("D-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)UMP86-K86=E;F%M95T@6W!A8VMA9V5I;F9O70T*3&ES
M=',@86QL('!A8VMA9V5S('=H:6-H(&UA=&-H('1H92!S96%R8V@@<&%R86UE
M=&5R<RX@(%1H92!F:7)S=`T*<&%R86UE=&5R(&ES(&$@9G)A9VUE;G0@;V8@
M82!P86-K86=E;F%M92X@(%1H92!D969A=6QT(&-H86YN96P-"G=I;&P@8F4@
M=7-E9"!U;FQE<W,@97AP;&EC:71L>2!O=F5R<FED9&5N+B`@5&AE('-E8V]N
M9"!P87)A;65T97(-"G=I;&P@8F4@=7-E9"!T;R!M871C:"!A;GD@<&]R=&EO
M;B!O9B!T:&4@<W5M;6%R>2]D97-C<FEP=&EO;B<L#0H@("`@("`@("`@("`I
M+`T*("`@("`@("`G;&ES="UA;&PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=,:7-T($%L;"!086-K86=E<R<L#0H@("`@("`@("`@
M("`G9G5N8W1I;VXG(#T^("=D;TQI<W1!;&PG+`T*("`@("`@("`@("`@)W-H
M;W)T8W5T)R`]/B`G;&$G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/@T*("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S
M<&5C:69Y(&$@8VAA;FYE;"!O=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN
M96PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@
M("`@("`@("`@("`@("`@("`@("D-"B`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@)V1O8R<@/3X@)PT*3&ES=',@=&AE('!A8VMA9V5S(&%V86EL
M86)L92!O;B!T:&4@8V]N9FEG=7)E9"!S97)V97(@86QO;F<@=VET:"!T:&4-
M"FQA=&5S="!S=&%B;&4@<F5L96%S92!O9B!E86-H('!A8VMA9V4N)RP-"B`@
M("`@("`@("`@("DL#0H@("`@("`@("=D;W=N;&]A9"<@/3X@87)R87DH#0H@
M("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T1O=VYL;V%D(%!A8VMA9V4G+`T*
M("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]$;W=N;&]A9"<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=D)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)UHG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&]W;FQO860@
M86X@=6YC;VUP<F5S<V5D("@N=&%R*2!F:6QE)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O
M8R<@/3X@)SQP86-K86=E/BXN+@T*1&]W;FQO860@<&%C:V%G92!T87)B86QL
M<RX@(%1H92!F:6QE<R!W:6QL(&)E(&YA;65D(&%S('-U9V=E<W1E9"!B>2!T
M:&4-"G-E<G9E<BP@9F]R(&5X86UP;&4@:68@>6]U(&1O=VYL;V%D('1H92!$
M0B!P86-K86=E(&%N9"!T:&4@;&%T97-T('-T86)L90T*=F5R<VEO;B!O9B!$
M0B!I<R`Q+C8N-2P@=&AE(&1O=VYL;V%D960@9FEL92!W:6QL(&)E($1"+3$N
M-BXU+G1G>BXG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-L96%R+6-A
M8VAE)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0VQE
M87(@5V5B(%-E<G9I8V5S($-A8VAE)RP-"B`@("`@("`@("`@("=F=6YC=&EO
M;B<@/3X@)V1O0VQE87)#86-H92<L#0H@("`@("`@("`@("`G<VAO<G1C=70G
M(#T^("=C8R<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-
M"B`@("`@("`@("`@("=D;V,G(#T^("<-"D-L96%R('1H92!834PM4E!#+U)%
M4U0@8V%C:&4N("!3964@86QS;R!T:&4@8V%C:&5?='1L(&-O;F9I9W5R871I
M;VX-"G!A<F%M971E<BX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`I
M.PT*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@
M("`O*BH-"B`@("`@*B!014%27T-O;6UA;F1?4F5M;W1E(&-O;G-T<G5C=&]R
M+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!014%27T-O;6UA;F1?4F5M;W1E*"8D=6DL("8D8V]N9FEG
M*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N
M*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("!F
M=6YC=&EO;B!?8VAE8VM#:&%N;F5L1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA
M;BD-"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:7-?82@D8VAA;BP@)U!%05)?0VAA;FYE
M;$9I;&4G*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=);G1E<FYA;"!C;W)R=7!T:6]N(&5R<F]R.B!I;G9A;&ED(&-H86YN
M96P@(B<@+@T*("`@("`@("`@("`@("`@("1C:&%N;F5L("X@)R(G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<F5S="`](&YE=R!014%27U)%4U0H)'1H:7,M
M/F-O;F9I9RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&$@/2`D<F5S="T^
M9&]W;FQO861(='1P*"=H='1P.B\O)R`N("1C:&%N;F5L("X-"B`@("`@("`@
M("`@("<O8VAA;FYE;"YX;6PG+"`D8VAA;BT^;&%S=$UO9&EF:65D*"DI.PT*
M("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D82D@)B8@)&$I('L-"B`@("`@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@8VAA;FYE;"`B
M)R`N("1C:&%N;F5L("X@)R(@:&%S("<@+@T*("`@("`@("`@("`@("`@("=U
M<&1A=&5D(&ET<R!P<F]T;V-O;',L('5S92`B8VAA;FYE;"UU<&1A=&4@)R`N
M("1C:&%N;F5L("X-"B`@("`@("`@("`@("`@("`G(B!T;R!U<&1A=&4G*3L-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('M[>R!D;U)E;6]T94EN9F\H
M*0T*#0H@("`@9G5N8W1I;VX@9&]296UO=&5);F9O*"1C;VUM86YD+"`D;W!T
M:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AS:7IE;V8H)'!A
M<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"(D8V]M;6%N9"!E>'!E8W1S(&]N92!P87)A;3H@=&AE(')E;6]T
M92!P86-K86=E(&YA;64B*3L-"B`@("`@("`@?0T*("`@("`@("`D<V%V96-H
M86YN96P@/2`D8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L
M=%]C:&%N;F5L)RD[#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^
M9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)'!A8VMA9V4@/2`D<&%R86US6S!=
M.PT*("`@("`@("`D<&%R<V5D(#T@)')E9RT^<&%R<V5086-K86=E3F%M92@D
M<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<&%R<V5D*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=);G9A;&ED('!A8VMA9V4@;F%M92`B)R`N("1P86-K86=E("X@
M)R(G*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@)&-H86YN96P@
M/2`D<&%R<V5D6R=C:&%N;F5L)UT[#0H@("`@("`@("1T:&ES+3YC;VYF:6<M
M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@("`D
M8VAA;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?8VAE8VM#:&%N;F5L1F]R
M4W1A='5S*"1C:&%N;F5L+"`D8VAA;BDI*2![#0H@("`@("`@("`@("!R971U
M<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T
M<U)%4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI
M("8F#0H@("`@("`@("`@("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH
M)U)%4U0Q+C`G+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R
M;W(G*2DI('L-"B`@("`@("`@("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M
M/F=E=%)%4U0H)S$N,"<L(&%R<F%Y*"DI.PT*("`@("`@("`@("`@)&EN9F\@
M/2`D<F5S="T^<&%C:V%G94EN9F\H)&)A<V4L("1P87)S961;)W!A8VMA9V4G
M72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<B`]("8D=&AI
M<RT^8V]N9FEG+3YG971296UO=&4H*3L-"B`@("`@("`@("`@("1I;F9O(#T@
M)'(M/F-A;&PH)W!A8VMA9V4N:6YF;R<L("1P87)S961;)W!A8VMA9V4G72D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I
M*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?
M8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A:7-S970H)&EN9F];)VYA;64G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G3F\@<F5M;W1E('!A8VMA9V4@(B<@
M+B`D<&%C:V%G92`N("<B('=A<R!F;W5N9"<I.PT*("`@("`@("!]#0H-"B`@
M("`@("`@)&EN<W1A;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*"1I;F9O6R=N
M86UE)UTL(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@)&EN9F];)VEN<W1A
M;&QE9"==(#T@)&EN<W1A;&QE9%LG=F5R<VEO;B==(#\@)&EN<W1A;&QE9%LG
M=F5R<VEO;B==(#H@)RT@;F\@+2<[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D
M:6YF;ULG:6YS=&%L;&5D)UTI*2![#0H@("`@("`@("`@("`D:6YF;ULG:6YS
M=&%L;&5D)UT@/2`D:6YF;ULG:6YS=&%L;&5D)UU;)W)E;&5A<V4G73L-"B`@
M("`@("`@?0T*#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D:6YF
M;RP@)&-O;6UA;F0I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E
M9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O
M4F5M;W1E3&ES="@I#0H-"B`@("!F=6YC=&EO;B!D;U)E;6]T94QI<W0H)&-O
M;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'-A
M=F5C:&%N;F5L(#T@)&-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E
M9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`D;W!T
M:6]N<ULG8VAA;FYE;"==.PT*("`@("`@("`@("`@:68@*"1R96<M/F-H86YN
M96Q%>&ES=',H)&-H86YN96PI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE;"`B)R`N("1C:&%N;F5L("X@)R(@
M9&]E<R!N;W0@97AI<W0G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?8VAE8VM#
M:&%N;F5L1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA;BDI*2![#0H@("`@("`@
M("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)&QI<W1?;W!T
M:6]N<R`](&9A;'-E.PT*("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T
M*"=P<F5F97)R961?<W1A=&4G*2`]/2`G<W1A8FQE)RD@>PT*("`@("`@("`@
M("`@)&QI<W1?;W!T:6]N<R`]('1R=64[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P
M<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B87-E(#T@
M)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C$G+"`D=&AI<RT^8V]N9FEG+3YG
M970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@("\O('5S
M92!F87-T97(@;&ES="UA;&P@:68@879A:6QA8FQE#0H@("`@("`@("`@("`D
M<F5S="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C$G+"!A<G)A>2@I
M*3L-"B`@("`@("`@("`@("1A=F%I;&%B;&4@/2`D<F5S="T^;&ES=$%L;"@D
M8F%S92P@)&QI<W1?;W!T:6]N<RD[#0H@("`@("`@('T@96QS96EF("@D8VAA
M;BT^<W5P<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D
M7VUI<G)O<B<I*2`F)@T*("`@("`@("`@("`@("`D8F%S92`]("1C:&%N+3YG
M971"87-E55),*"=215-4,2XP)RP@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F
M97)R961?;6ER<F]R)RDI*2![#0H@("`@("`@("`@("`D<F5S="`]("8D=&AI
M<RT^8V]N9FEG+3YG971215-4*"<Q+C`G+"!A<G)A>2@I*3L-"B`@("`@("`@
M("`@("1A=F%I;&%B;&4@/2`D<F5S="T^;&ES=$%L;"@D8F%S92P@)&QI<W1?
M;W!T:6]N<RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<B`]
M("8D=&AI<RT^8V]N9FEG+3YG971296UO=&4H*3L-"B`@("`@("`@("`@(&EF
M("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M("`@("\O(&AA8VL@8F5C875S92!O9B!P;V]R('!E87)W96(@9&5S:6=N#0H@
M("`@("`@("`@("`@("`@)&%V86EL86)L92`]("1R+3YC86QL*"=P86-K86=E
M+FQI<W1!;&PG+"!T<G5E+"`D;&ES=%]O<'1I;VYS+"!F86QS92D[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1A=F%I;&%B;&4@
M/2`D<BT^8V%L;"@G<&%C:V%G92YL:7-T06QL)RP@=')U92P@)&QI<W1?;W!T
M:6]N<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&%V86EL86)L92DI('L-"B`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N
M;F5L*3L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M879A:6QA8FQE*3L-"B`@("`@("`@?0T*("`@("`@("`D:2`]("1J(#T@,#L-
M"B`@("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("=C87!T:6]N
M)R`]/B`G0VAA;FYE;"`G("X@)&-H86YN96P@+B`G($%V86EL86)L92!P86-K
M86=E<SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@
M("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA9V4G+"`G5F5R<VEO
M;B<I+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@:68@*&-O=6YT*"1A=F%I
M;&%B;&4I/3TP*2![#0H@("`@("`@("`@("`D9&%T82`]("<H;F\@<&%C:V%G
M97,@879A:6QA8FQE('EE="DG.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@9F]R96%C:"`H)&%V86EL86)L92!A<R`D;F%M92`]/B`D:6YF;RD@
M>PT*("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1N
M86UE+"`H:7-S970H)&EN9F];)W-T86)L92==*2`F)B`D:6YF;ULG<W1A8FQE
M)UTI#0H@("`@("`@("`@("`@("`@("`@(#\@)&EN9F];)W-T86)L92==(#H@
M)RUN+V$M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@
M("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A
M=F5C:&%N;F5L*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O3&ES=$%L;"@I#0H-"B`@("!F=6YC
M=&EO;B!D;TQI<W1!;&PH)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*
M("`@('L-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN96P@/2`D=&AI
M<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D
M<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@
M("`@)&-H86YN96P@/2`D;W!T:6]N<ULG8VAA;FYE;"==.PT*("`@("`@("`@
M("`@:68@*"1R96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN
M96PG+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0VAA;FYE;"!<
M(B1C:&%N;F5L7"(@9&]E<R!N;W0@97AI<W0B*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D;&ES=%]O<'1I;VYS(#T@9F%L<V4[#0H@
M("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T
M92<I(#T]("=S=&%B;&4G*2![#0H@("`@("`@("`@("`D;&ES=%]O<'1I;VYS
M(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D8VAA;B`]("1R96<M/F=E
M=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D92`]("1T:&ES+3Y?8VAE8VM#:&%N;F5L1F]R4W1A='5S*"1C:&%N;F5L
M+"`D8VAA;BDI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O
M;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@
M("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C$G+"`D=&AI
M<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@
M("`@("`@("\O('5S92!F87-T97(@;&ES="UA;&P@:68@879A:6QA8FQE#0H@
M("`@("`@("`@("`D<F5S="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q
M+C$G+"!A<G)A>2@I*3L-"B`@("`@("`@("`@("1A=F%I;&%B;&4@/2`D<F5S
M="T^;&ES=$%L;"@D8F%S92P@)&QI<W1?;W!T:6]N<RP@9F%L<V4I.PT*("`@
M("`@("!](&5L<V5I9B`H)&-H86XM/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@
M("`@)&)A<V4@/2`D8VAA;BT^9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES
M+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@
M("`@("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4D535"@G,2XP)RP@
M87)R87DH*2D[#0H@("`@("`@("`@("`D879A:6QA8FQE(#T@)')E<W0M/FQI
M<W1!;&PH)&)A<V4L("1L:7-T7V]P=&EO;G,L(&9A;'-E*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1R(#T@)B1T:&ES+3YC;VYF:6<M/F=E
M=%)E;6]T92@I.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R
M+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@+R\@:&%C:R!B96-A=7-E
M(&]F('!O;W(@<&5A<G=E8B!D97-I9VX-"B`@("`@("`@("`@("`@("`D879A
M:6QA8FQE(#T@)'(M/F-A;&PH)W!A8VMA9V4N;&ES=$%L;"<L('1R=64L("1L
M:7-T7V]P=&EO;G,L(&9A;'-E*3L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&%V86EL86)L92`]("1R+3YC86QL*"=P86-K86=E
M+FQI<W1!;&PG+"!T<G5E+"`D;&ES=%]O<'1I;VYS*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D879A
M:6QA8FQE*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D
M969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=4:&4@<&%C:V%G92!L:7-T(&-O
M=6QD(&YO="!B92!F971C:&5D(&9R;VT@=&AE(')E;6]T92!S97)V97(N(%!L
M96%S92!T<GD@86=A:6XN("A$96)U9R!I;F9O.B`B)R`N("1A=F%I;&%B;&4M
M/F=E=$UE<W-A9V4H*2`N("<B*2<I.PT*("`@("`@("!]#0H@("`@("`@("1D
M871A(#T@87)R87DH#0H@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)T%L;"!P
M86-K86=E<SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@
M("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA9V4G+"`G3&%T
M97-T)RP@)TQO8V%L)RDL#0H@("`@("`@("`@("`I.PT*("`@("`@("`D;&]C
M86Q?<&MG<R`]("1R96<M/FQI<W1086-K86=E<R@D8VAA;FYE;"D[#0H-"B`@
M("`@("`@9F]R96%C:"`H)&%V86EL86)L92!A<R`D;F%M92`]/B`D:6YF;RD@
M>PT*("`@("`@("`@("`@)&EN<W1A;&QE9"`]("1R96<M/G!A8VMA9V5);F9O
M*"1N86UE+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)&EN<W1A;&QE9%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@
M("`@("1I;G-T86QL961;)W9E<G-I;VXG72`]("1I;G-T86QL961;)W9E<G-I
M;VXG75LG<F5L96%S92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&1E<V,@/2`D:6YF;ULG<W5M;6%R>2==.PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1P87)A;7-;)&YA;65=*2D@>PT*("`@("`@("`@("`@("`@("1D97-C
M("X](")<;EQN(BXD:6YF;ULG9&5S8W)I<'1I;VXG73L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;6]D92==*2D-
M"B`@("`@("`@("`@('L-"B`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;G-;
M)VUO9&4G72`]/2`G:6YS=&%L;&5D)R`F)B`A:7-S970H)&EN<W1A;&QE9%LG
M=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1O<'1I
M;VYS6R=M;V1E)UT@/3T@)VYO=&EN<W1A;&QE9"<@)B8@:7-S970H)&EN<W1A
M;&QE9%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"1O<'1I;VYS6R=M;V1E)UT@/3T@)W5P9W)A9&5S)PT*("`@("`@("`@("`@
M("`@("`@("`@("8F("@A:7-S970H)&EN<W1A;&QE9%LG=F5R<VEO;B==*2!\
M?"!V97)S:6]N7V-O;7!A<F4H)&EN<W1A;&QE9%LG=F5R<VEO;B==+`T*("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R=S=&%B;&4G72P@)SX])RDI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P;W,@/2!A<G)A
M>5]S96%R8V@H<W1R=&]L;W=E<B@D;F%M92DL("1L;V-A;%]P:V=S*3L-"B`@
M("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PT*("`@("`@("`@("`@
M("`@('5N<V5T*"1L;V-A;%]P:V=S6R1P;W-=*3L-"B`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S=&%B;&4G72D@)B8@
M(21I;F9O6R=S=&%B;&4G72D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=S
M=&%B;&4G72`](&YU;&P[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M9&%T85LG9&%T82==6R1I;F9O6R=C871E9V]R>2==75M=(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@)')E9RT^8VAA;FYE;$%L:6%S*"1C:&%N;F5L*2`N
M("<O)R`N("1N86UE+`T*("`@("`@("`@("`@("`@($`D:6YF;ULG<W1A8FQE
M)UTL#0H@("`@("`@("`@("`@("`@0"1I;G-T86QL961;)W9E<G-I;VXG72P-
M"B`@("`@("`@("`@("`@("!`)&1E<V,L#0H@("`@("`@("`@("`@("`@0"1I
M;F9O6R=D97!S)UTL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;6]D92==*2`F)B!I;E]A
M<G)A>2@D;W!T:6]N<ULG;6]D92==+"!A<G)A>2@G;F]T:6YS=&%L;&5D)RP@
M)W5P9W)A9&5S)RDI*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS
M970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@
M(&9O<F5A8V@@*"1L;V-A;%]P:V=S(&%S("1N86UE*2![#0H@("`@("`@("`@
M("`D:6YF;R`]("8D<F5G+3YG971086-K86=E*"1N86UE+"`D8VAA;FYE;"D[
M#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R=,;V-A;"==6UT@/2!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`D<F5G+3YC:&%N;F5L06QI87,H)&-H86YN
M96PI("X@)R\G("X@)&EN9F\M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@
M("`@("`G)RP-"B`@("`@("`@("`@("`@("`D:6YF;RT^9V5T5F5R<VEO;B@I
M+`T*("`@("`@("`@("`@("`@("1I;F9O+3YG9713=6UM87)Y*"DL#0H@("`@
M("`@("`@("`@("`@)&EN9F\M/F=E=$1E<',H*0T*("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H
M)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9&]396%R8V@H*0T*#0H@("`@9G5N8W1I;VX@9&]396%R8V@H)&-O;6UA
M;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*"@A
M:7-S970H)'!A<F%M<ULP72D@?'P@96UP='DH)'!A<F%M<ULP72DI#0H@("`@
M("`@("`@("`F)B`H(6ES<V5T*"1P87)A;7-;,5TI('Q\(&5M<'1Y*"1P87)A
M;7-;,5TI*2D-"B`@("`@("`@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=N;R!V86QI9"!S96%R8V@@<W1R:6YG('-U<'!L:65D
M)RD[#0H@("`@("`@('T[#0H-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H
M86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I
M.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@("`@("1P86-K86=E(#T@)'!A<F%M<ULP73L-"B`@("`@("`@
M)'-U;6UA<GD@/2!I<W-E="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!F
M86QS93L-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=C:&%N;F5L)UTI
M*2![#0H@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E
M9VES=')Y*"D[#0H@("`@("`@("`@("`D8VAA;FYE;"`]("1O<'1I;VYS6R=C
M:&%N;F5L)UT[#0H@("`@("`@("`@("!I9B`H)')E9RT^8VAA;FYE;$5X:7-T
M<R@D8VAA;FYE;"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG
M+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=#:&%N;F5L("(G("X@)&-H86YN96P@+B`G(B!D;V5S(&YO
M="!E>&ES="<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1C:&%N(#T@)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]C:&5C:T-H86YN96Q&
M;W)3=&%T=7,H)&-H86YN96PL("1C:&%N*2DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-H86XM/G-U<'!O
M<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G
M*2D@)B8-"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T0F%S9552
M3"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI
M<G)O<B<I*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I
M9RT^9V5T4D535"@G,2XP)RP@87)R87DH*2D[#0H@("`@("`@("`@("`D879A
M:6QA8FQE(#T@)')E<W0M/FQI<W1!;&PH)&)A<V4L(&9A;'-E+"!F86QS92P@
M)'!A8VMA9V4L("1S=6UM87)Y*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1R(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@I.PT*("`@
M("`@("`@("`@)&%V86EL86)L92`]("1R+3YC86QL*"=P86-K86=E+G-E87)C
M:"<L("1P86-K86=E+"`D<W5M;6%R>2P@=')U92P@#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2`]/2`G
M<W1A8FQE)RP@=')U92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&%V86EL86)L92DI('L-"B`@("`@("`@("`@("1T:&ES+3YC
M;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D879A:6QA
M8FQE*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21A=F%I;&%B;&4I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F\@<&%C
M:V%G97,@9F]U;F0@=&AA="!M871C:"!P871T97)N("(G("X@)'!A8VMA9V4@
M+B`G(B<I.PT*("`@("`@("!]#0H@("`@("`@("1D871A(#T@87)R87DH#0H@
M("`@("`@("`@("`G8V%P=&EO;B<@/3X@)TUA=&-H960@<&%C:V%G97,L(&-H
M86YN96P@)R`N("1C:&%N;F5L("X@)SHG+`T*("`@("`@("`@("`@)V)O<F1E
M<B<@/3X@=')U92P-"B`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH
M)U!A8VMA9V4G+"`G4W1A8FQE+RA,871E<W0I)RP@)TQO8V%L)RDL#0H@("`@
M("`@("`@("`I.PT*#0H@("`@("`@(&9O<F5A8V@@*"1A=F%I;&%B;&4@87,@
M)&YA;64@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("1I;G-T86QL960@/2`D
M<F5G+3YP86-K86=E26YF;R@D;F%M92P@;G5L;"P@)&-H86YN96PI.PT*("`@
M("`@("`@("`@)&1E<V,@/2`D:6YF;ULG<W5M;6%R>2==.PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1P87)A;7-;)&YA;65=*2D-"B`@("`@("`@("`@("`@
M("`D9&5S8R`N/2`B7&Y<;B(N)&EN9F];)V1E<V-R:7!T:6]N)UT[#0H-"B`@
M("`@("`@("`@("1U;G-T86)L92`]("<G.PT*("`@("`@("`@("`@:68@*"1I
M;F9O6R=U;G-T86)L92==*2![#0H@("`@("`@("`@("`@("`@)'5N<W1A8FQE
M(#T@)R\H)R`N("1I;F9O6R=U;G-T86)L92==("X@)R`G("X@)&EN9F];)W-T
M871E)UT@+B`G*2<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1I;F9O6R=S=&%B;&4G72D@?'P@(21I;F9O6R=S=&%B;&4G72D@
M>PT*("`@("`@("`@("`@("`@("1I;F9O6R=S=&%B;&4G72`]("=N;VYE)SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1V97)S:6]N(#T@:7-?87)R
M87DH)&EN<W1A;&QE9%LG=F5R<VEO;B==*2`_("1I;G-T86QL961;)W9E<G-I
M;VXG75LG<F5L96%S92==(#H-"B`@("`@("`@("`@("`@("`D:6YS=&%L;&5D
M6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R1I;F9O
M6R=C871E9V]R>2==75M=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)&YA
M;64L#0H@("`@("`@("`@("`@("`@)&EN9F];)W-T86)L92==("X@)'5N<W1A
M8FQE+`T*("`@("`@("`@("`@("`@("1V97)S:6]N+`T*("`@("`@("`@("`@
M("`@("1D97-C+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[
M#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L
M)RP@)&-H86YN96PI.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("!F=6YC=&EO;B`F9V5T1&]W;FQO861E<B@D;W!T
M:6]N<RD-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%2
M7T1O=VYL;V%D97(G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+T1O=VYL;V%D97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]
M("9N97<@4$5!4E]$;W=N;&]A9&5R*"1T:&ES+3YU:2P@)&]P=&EO;G,L("1T
M:&ES+3YC;VYF:6<I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*("`@
M("\O('M[>R!D;T1O=VYL;V%D*"D-"@T*("`@(&9U;F-T:6]N(&1O1&]W;FQO
M860H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@
M("`@+R\@;6%K92!C97)T86EN('1H870@9&5P96YD96YC:65S(&%R92!I9VYO
M<F5D#0H@("`@("`@("1O<'1I;VYS6R=D;W=N;&]A9&]N;'DG72`](#$[#0H@
M("`@("`@("\O(&5L:6UI;F%T92!E<G)O<B!M97-S86=E<R!F;W(@<')E9F5R
M<F5D7W-T871E+7)E;&%T960@97)R;W)S#0H@("`@("`@("1O<'1I;VYS6R=I
M9VYO<F5P<F5F97)R961?<W1A=&4G72`](#$[#0H@("`@("`@("1D;W=N;&]A
M9&5R(#T@)B1T:&ES+3YG971$;W=N;&]A9&5R*"1O<'1I;VYS*3L-"B`@("`@
M("`@)&1O=VYL;V%D97(M/G-E=$1O=VYL;V%D1&ER*&=E=&-W9"@I*3L-"B`@
M("`@("`@)&5R<F]R<R`](&%R<F%Y*"D[#0H@("`@("`@("1D;W=N;&]A9&5D
M(#T@87)R87DH*3L-"B`@("`@("`@)&5R<B`]("1D;W=N;&]A9&5R+3YD;W=N
M;&]A9"@D<&%R86US*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@
M("`@("`@("1E<G)O<G,@/2`D9&]W;FQO861E<BT^9V5T17)R;W)-<V=S*"D[
M#0H@("`@("`@(&EF("AC;W5N="@D97)R;W)S*2D@>PT*("`@("`@("`@("`@
M9F]R96%C:"`H)&5R<F]R<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&5R<F]R*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O
M;6UA;F0@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)&1O=VYL;V%D
M960@/2`D9&]W;FQO861E<BT^9V5T1&]W;FQO861E9%!A8VMA9V5S*"D[#0H@
M("`@("`@(&9O<F5A8V@@*"1D;W=N;&]A9&5D(&%S("1P:V<I('L-"B`@("`@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B1FEL92`D<&MG6V9I;&5=
M(&1O=VYL;V%D960B+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&]W;FQO861#
M86QL8F%C:R@D;7-G+"`D<&%R86US(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M(&EF("@D;7-G(#T]("=D;VYE)RD@>PT*("`@("`@("`@("`@)'1H:7,M/F)Y
M=&5S7V1O=VYL;V%D960@/2`D<&%R86US.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O3&ES=%5P9W)A9&5S*"D-"@T*
M("`@(&9U;F-T:6]N(&1O3&ES=%5P9W)A9&5S*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]#;VUM;VXN<&AP)SL-"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;,%TI
M("8F("%014%27T-O;6UO;CHZ8F5T=&5R4W1A=&5S*"1P87)A;7-;,%TI*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!A<F%M
M<ULP72`N("<@:7,@;F]T(&$@=F%L:60@<W1A=&4@*'-T86)L92]B971A+V%L
M<&AA+V1E=F5L+V5T8RXI('1R>2`B<&5A<B!H96QP(&QI<W0M=7!G<F%D97,B
M)RD[#0H@("`@("`@('T-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN
M96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*
M("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@(&9O<F5A8V@@*"1R96<M/FQI<W1#:&%N;F5L<R@I(&%S("1C
M:&%N;F5L*2![#0H@("`@("`@("`@("`D:6YS="`](&%R<F%Y7V9L:7`H)')E
M9RT^;&ES=%!A8VMA9V5S*"1C:&%N;F5L*2D[#0H@("`@("`@("`@("!I9B`H
M(6-O=6YT*"1I;G-T*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=?
M7W5R:2<I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L
M=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1P87)A;7-;,%TI*2![#0H@("`@("`@("`@("`@("`@)'-T871E(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*3L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'-T871E(#T@)'!A<F%M
M<ULP73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C87!T:6]N(#T@
M)&-H86YN96P@+B`G($%V86EL86)L92!5<&=R861E<R<[#0H@("`@("`@("`@
M("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7V-H96-K0VAA
M;FYE;$9O<E-T871U<R@D8VAA;FYE;"P@)&-H86XI*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@D8VAA;BT^<W5P<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G
M<')E9F5R<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@("`@("`@("`@("`@)&)A
M<V4@/2`D8VAA;BT^9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF
M:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@
M("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N,"<L(&%R
M<F%Y*"DI.PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<W1A=&4I('Q\
M("1S=&%T92`]/2`G86YY)RD@>PT*("`@("`@("`@("`@("`@("`@("`D<W1A
M=&4@/2!F86QS93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D8V%P=&EO;B`N/2`G("@G("X@:6UP;&]D92@G+"`G
M+"!014%27T-O;6UO;CHZ8F5T=&5R4W1A=&5S*"1S=&%T92P@=')U92DI("X@
M)RDG.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2
M.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R97-T+3YL:7-T3&%T97-T
M57!G<F%D97,H)&)A<V4L("1S=&%T92P@)&EN<W0L("1C:&%N;F5L+"`D<F5G
M*3L-"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1R96UO=&4@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@
M("`@("`@("`@("`@)')E;6]T92T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<W1A
M=&4I('Q\("1S=&%T92`]/2`G86YY)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T3&%T97-T
M4F5L96%S97,B*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G
M92YL:7-T3&%T97-T4F5L96%S97,B+"`D<W1A=&4I.PT*("`@("`@("`@("`@
M("`@("`@("`D8V%P=&EO;B`N/2`G("@G("X@:6UP;&]D92@G+"`G+"!014%2
M7T-O;6UO;CHZ8F5T=&5R4W1A=&5S*"1S=&%T92P@=')U92DI("X@)RDG.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<F5M;W1E+3YP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&%T97-T*2D@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D;&%T97-T+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&-A<'1I;VX@+CT@)SHG.PT*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E
M8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1L871E<W0[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("=C87!T:6]N)R`]/B`D8V%P=&EO;BP-"B`@("`@("`@
M("`@("`@("`G8F]R9&5R)R`]/B`Q+`T*("`@("`@("`@("`@("`@("=H96%D
M;&EN92<@/3X@87)R87DH)T-H86YN96PG+"`G4&%C:V%G92<L("=,;V-A;"<L
M("=296UO=&4G+"`G4VEZ92<I+`T*("`@("`@("`@("`@("`@("D[#0H@("`@
M("`@("`@("!F;W)E86-H("@H87)R87DI)&QA=&5S="!A<R`D<&MG(#T^("1I
M;F9O*2![#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R
M*"1P:V<I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN<W1;)'!A
M8VMA9V5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`O+R!S:VEP('!A8VMA
M9V5S('=E(&1O;B=T(&AA=F4@:6YS=&%L;&5D#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!E>'1R86-T*"1I;F9O*3L-"B`@("`@("`@("`@("`@("`D:6YS=%]V
M97)S:6]N(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=V97)S:6]N
M)RP@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("1I;G-T7W-T871E("`@
M/2`D<F5G+3YP86-K86=E26YF;R@D<&%C:V%G92P@)W)E;&5A<V5?<W1A=&4G
M+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M
M<&%R92@B)'9E<G-I;VXB+"`B)&EN<W1?=F5R<VEO;B(L(")L92(I*2![#0H@
M("`@("`@("`@("`@("`@("`@("\O(&EN<W1A;&QE9"!V97)S:6]N(&ES('5P
M+71O+61A=&4-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9FEL97-I>F4@
M/CT@,C`T.#`I('L-"B`@("`@("`@("`@("`@("`@("`@)&9I;&5S:7IE("L]
M(#$P,C0@+2`H)&9I;&5S:7IE("4@,3`R-"D[#0H@("`@("`@("`@("`@("`@
M("`@("1F<R`]('-P<FEN=&8H(B5D:T(B+"`D9FEL97-I>F4@+R`Q,#(T*3L-
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&9I;&5S:7IE(#X@,"D@>PT*
M("`@("`@("`@("`@("`@("`@("`D9FEL97-I>F4@*ST@,3`S("T@*"1F:6QE
M<VEZ92`E(#$P,RD[#0H@("`@("`@("`@("`@("`@("`@("1F<R`]('-P<FEN
M=&8H(B4N,69K0B(L("1F:6QE<VEZ92`O(#$P,C0N,"D[#0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&9S(#T@(B`@
M+2([("\O(%A86"!C96YT97(@:6YS=&5A9`T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D8VAA
M;FYE;"P@)'!K9RP@(B1I;G-T7W9E<G-I;VX@*"1I;G-T7W-T871E*2(L("(D
M=F5R<VEO;B`H)'-T871E*2(L("1F<RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H96UP='DH)&1A=&%;)V1A=&$G72DI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)T-H86YN96P@)R`N("1C
M:&%N;F5L("X@)SH@3F\@=7!G<F%D97,@879A:6QA8FQE)RD[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C
M:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O0VQE87)#86-H
M92@I#0H-"B`@("!F=6YC=&EO;B!D;T-L96%R0V%C:&4H)&-O;6UA;F0L("1O
M<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)&-A8VAE7V1I<B`]
M("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD[#0H@("`@("`@("1V
M97)B;W-E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@
M("`@("1O=71P=70@/2`G)SL-"B`@("`@("`@:68@*"$H)&1P(#T@0&]P96YD
M:7(H)&-A8VAE7V1I<BDI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F]P96YD:7(H)&-A8VAE7V1I<BD@9F%I;&5D.B`D<&AP
M7V5R<F]R;7-G(BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1V97)B;W-E
M(#X](#$I('L-"B`@("`@("`@("`@("1O=71P=70@+CT@(G)E861I;F<@9&ER
M96-T;W)Y("1C86-H95]D:7)<;B([#0H@("`@("`@('T-"B`@("`@("`@)&YU
M;2`](#`[#0H@("`@("`@('=H:6QE("@D96YT(#T@<F5A9&1I<B@D9'`I*2![
M#0H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UYX;6QR<&-?8V%C:&5?
M6V$M>C`M.5U[,S)])"\G+"`D96YT*2!\?`T*("`@("`@("`@("`@("`@("`@
M<')E9U]M871C:"@G+W)E<W0N8V%C:&4H9FEL97QI9"DD+R<L("1E;G0I*2![
M#0H@("`@("`@("`@("`@("`@)'!A=&@@/2`D8V%C:&5?9&ER("X@1$E214-4
M3U)97U-%4$%2051/4B`N("1E;G0[#0H@("`@("`@("`@("`@("`@)&]K(#T@
M0'5N;&EN:R@D<&%T:"D[#0H@("`@("`@("`@("`@("`@:68@*"1O:RD@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'9E<F)O<V4@/CT@,BD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B9&5L971E9"`D<&%T
M:%QN(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`D;G5M*RL[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V97)B
M;W-E(#X](#$I('L-"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B
M9F%I;&5D('1O(&1E;&5T92`D<&%T:%QN(CL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@8VQO<V5D:7(H
M)&1P*3L-"B`@("`@("`@:68@*"1V97)B;W-E(#X](#$I('L-"B`@("`@("`@
M("`@("1O=71P=70@+CT@(B1N=6T@8V%C:&4@96YT<FEE<R!C;&5A<F5D7&XB
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AR
M=')I;2@D;W5T<'5T*2P@)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@)&YU
M;3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O36ER<F]R+GAM;```
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$W,@`Q,#4Q-30S,3`U
M-P`P,C$T-#,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&1O=VYL;V%D+6%L
M;#X-"B`@/'-U;6UA<GD^1&]W;FQO861S(&5A8V@@879A:6QA8FQE('!A8VMA
M9V4@9G)O;2!T:&4@9&5F875L="!C:&%N;F5L/"]S=6UM87)Y/@T*("`\9G5N
M8W1I;VX^9&]$;W=N;&]A9$%L;#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YD
M83PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&-H86YN96P^#0H@("`@
M/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QD;V,^<W!E8VEF>2!A(&-H
M86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L/"]D;V,^#0H@
M("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@(#PO;W!T:6]N
M<SX-"B`@/&1O8SX-"E)E<75E<W1S(&$@;&ES="!O9B!A=F%I;&%B;&4@<&%C
M:V%G97,@9G)O;2!T:&4@9&5F875L="!C:&%N;F5L("A[8V]N9FEG(&1E9F%U
M;'1?8VAA;FYE;'TI#0IA;F0@9&]W;FQO861S('1H96T@=&\@8W5R<F5N="!W
M;W)K:6YG(&1I<F5C=&]R>2X@($YO=&4Z(&]N;'D-"G!A8VMA9V5S('=I=&AI
M;B!P<F5F97)R961?<W1A=&4@*'MC;VYF:6<@<')E9F5R<F5D7W-T871E?2D@
M=VEL;"!B92!D;W=N;&]A9&5D/"]D;V,^#0H@/"]D;W=N;&]A9"UA;&P^#0H\
M+V-O;6UA;F1S/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O36ER<F]R
M+G!H<```````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C0U,@`Q,#4Q
M-30S,3`U-P`P,C$T,S4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7TUI<G)O
M<B`H9&]W;FQO860M86QL(&-O;6UA;F0I#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@06QE>&%N9&5R
M($UE<GH@/&%L97AM97)Z0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@36ER<F]R+G!H<"QV(#$N,3@@,C`P
M-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,BXP#0H@*B\-
M"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!
M4B]#;VUM86YD+T-O;6UO;BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N
M9',@9F]R('!R;W9I9&EN9R!F:6QE(&UI<G)O<G,-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!!;&5X86YD97(@365R>B`\86QE>&UE<GI`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XR+C`-"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7TUI<G)O<B!E>'1E;F1S
M(%!%05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE
M<PT*#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G9&]W
M;FQO860M86QL)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]
M/B`G1&]W;FQO861S(&5A8V@@879A:6QA8FQE('!A8VMA9V4@9G)O;2!T:&4@
M9&5F875L="!C:&%N;F5L)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@
M)V1O1&]W;FQO861!;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M9&$G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S<&5C:69Y(&$@8VAA
M;FYE;"!O=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN96PG+`T*("`@("`@
M("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D
M;V,G(#T^("<-"E)E<75E<W1S(&$@;&ES="!O9B!A=F%I;&%B;&4@<&%C:V%G
M97,@9G)O;2!T:&4@9&5F875L="!C:&%N;F5L("A[8V]N9FEG(&1E9F%U;'1?
M8VAA;FYE;'TI#0IA;F0@9&]W;FQO861S('1H96T@=&\@8W5R<F5N="!W;W)K
M:6YG(&1I<F5C=&]R>2X@($YO=&4Z(&]N;'D-"G!A8VMA9V5S('=I=&AI;B!P
M<F5F97)R961?<W1A=&4@*'MC;VYF:6<@<')E9F5R<F5D7W-T871E?2D@=VEL
M;"!B92!D;W=N;&]A9&5D)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@*3L-
M"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@
M("`O*BH-"B`@("`@*B!014%27T-O;6UA;F1?36ER<F]R(&-O;G-T<G5C=&]R
M+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<&%R
M86T@;V)J96-T(%!%05)?1G)O;G1E;F0@82!R969E<F5N8V4@=&\@86X@9G)O
M;G1E;F0-"B`@("`@*B!`<&%R86T@;V)J96-T(%!%05)?0V]N9FEG(&$@<F5F
M97)E;F-E('1O('1H92!C;VYF:6=U<F%T:6]N(&1A=&$-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!014%27T-O;6UA;F1?36ER<F]R*"8D=6DL("8D8V]N9FEG
M*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N
M*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O
M*BH-"B`@("`@*B!&;W(@=6YI="UT97-T:6YG#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@)F9A8W1O<GDH)&$I#0H@("`@>PT*("`@("`@("`D82`]("9014%2
M7T-O;6UA;F0Z.F9A8W1O<GDH)&$L("1T:&ES+3YC;VYF:6<I.PT*("`@("`@
M("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@>WM[(&1O1&]W;FQO861!
M;&PH*0T*("`@("\J*@T*("`@("H@<F5T<FEE=F5S(&$@;&ES="!O9B!A=F%I
M8FQE(%!A8VMA9V5S(&9R;VT@;6%S=&5R('-E<G9E<@T*("`@("H@86YD(&1O
M=VYL;V%D<R!T:&5M#0H@("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`J($!P87)A;2!S=')I;F<@)&-O;6UA;F0@=&AE(&-O;6UA;F0-"B`@("`J
M($!P87)A;2!A<G)A>2`D;W!T:6]N<R!T:&4@8V]M;6%N9"!O<'1I;VYS(&)E
M9F]R92!T:&4@8V]M;6%N9`T*("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M=&AE('-T=69F(&%F=&5R('1H92!C;VUM86YD(&YA;64-"B`@("`J($!R971U
M<FX@8F]O;"!T<G5E(&EF('-U8V-E<V9U;`T*("`@("H@0'1H<F]W(%!%05)?
M17)R;W(@#0H@("`@*B\-"B`@("!F=6YC=&EO;B!D;T1O=VYL;V%D06QL*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1S
M879E8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N
M;F5L)RD[#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@)&-H86YN96P@/2!I<W-E="@D;W!T:6]N<ULG
M8VAA;FYE;"==*2`_("1O<'1I;VYS6R=C:&%N;F5L)UT@.@T*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@
M("`@("`@:68@*"$D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN
M96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@)&-H86YN96P@+B`G(B!D;V5S
M(&YO="!E>&ES="<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YC;VYF
M:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)U5S:6YG($-H86YN96P@)R`N("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI.PT*("`@("`@
M("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B
M87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@
M("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N,"<L(&%R<F%Y
M*"DI.PT*("`@("`@("`@("`@)')E;6]T94EN9F\@/2!A<G)A>5]F;&EP*"1R
M97-T+3YL:7-T4&%C:V%G97,H)&)A<V4I*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1R96UO=&4@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M
M;W1E*"D[#0H@("`@("`@("`@("`D<W1A8FQE(#T@*"1T:&ES+3YC;VYF:6<M
M/F=E="@G<')E9F5R<F5D7W-T871E)RD@/3T@)W-T86)L92<I.PT*("`@("`@
M("`@("`@)')E;6]T94EN9F\@/2`D<F5M;W1E+3YC86QL*")P86-K86=E+FQI
M<W1!;&PB+"!T<G5E+"`D<W1A8FQE+"!F86QS92D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E;6]T94EN9F\I*2![#0H@("`@
M("`@("`@("!R971U<FX@)')E;6]T94EN9F\[#0H@("`@("`@('T-"B`@("`@
M("`@)&-M9"`]("8D=&AI<RT^9F%C=&]R>2@B9&]W;FQO860B*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&-M9"DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D8VUD.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@G57-I;F<@4')E9F5R<F5D(%-T871E(&]F("<@+@T*("`@("`@
M("`@("`@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2D[
M#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G1V%T:&5R:6YG(')E
M;&5A<V4@:6YF;W)M871I;VXL('!L96%S92!W86ET+BXN)RD[#0H@("`@("`@
M("\J*@T*("`@("`@("`@*B!%<G)O<B!H86YD;&EN9R!N;W0@;F5C97-S87)Y
M+"!B96-A=7-E(&%L<F5A9'D@9&]N92!B>2`-"B`@("`@("`@("H@=&AE(&1O
M=VYL;V%D(&-O;6UA;F0-"B`@("`@("`@("HO#0H@("`@("`@(%!%05(Z.G-T
M871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@)&5R<B`]("1C;60M/G)U;B@G9&]W;FQO860G+"!A<G)A>2@G9&]W
M;FQO861O;FQY)R`]/B!T<G5E*2P@87)R87E?:V5Y<R@D<F5M;W1E26YF;RDI
M.PT*("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@
M)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<BDI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D97)R
M+3YG971-97-S86=E*"DI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*?0T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+T-O;6UA;F0O5&5S="YX;6P`````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,R,@`Q,#4Q-30S,3`U-P`P,C$Q,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/&-O;6UA;F1S
M('9E<G-I;VX](C$N,"(^#0H@/')U;BUT97-T<SX-"B`@/'-U;6UA<GD^4G5N
M(%)E9W)E<W-I;VX@5&5S=',\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U)U
M;E1E<W1S/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G)T/"]S:&]R=&-U=#X-
M"B`@/&]P=&EO;G,^#0H@("`\<F5C=7(^#0H@("`@/'-H;W)T;W!T/G(\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^4G5N('1E<W1S(&EN(&-H:6QD(&1I<F5C=&]R
M:65S+"!R96-U<G-I=F5L>2X@(#0@9&ER<R!D965P(&UA>&EM=6T\+V1O8SX-
M"B`@(#PO<F5C=7(^#0H@("`\:6YI/@T*("`@(#QS:&]R=&]P=#YI/"]S:&]R
M=&]P=#X-"B`@("`\9&]C/F%C='5A;"!S=')I;F<@;V8@<V5T=&EN9W,@=&\@
M<&%S<R!T;R!P:'`@:6X@9F]R;6%T("9Q=6]T.R`M9"!S971T:6YG/6)L86@F
M<75O=#L\+V1O8SX-"B`@("`\87)G/E-%5%1)3D=3/"]A<F<^#0H@("`\+VEN
M:3X-"B`@(#QR96%L=&EM96QO9SX-"B`@("`\<VAO<G1O<'0^;#PO<VAO<G1O
M<'0^#0H@("`@/&1O8SY,;V<@=&5S="!R=6YS+W)E<W5L=',@87,@=&AE>2!A
M<F4@<G5N/"]D;V,^#0H@("`\+W)E86QT:6UE;&]G/@T*("`@/'%U:65T/@T*
M("`@(#QS:&]R=&]P=#YQ/"]S:&]R=&]P=#X-"B`@("`\9&]C/D]N;'D@9&ES
M<&QA>2!D971A:6P@9F]R(&9A:6QE9"!T97-T<SPO9&]C/@T*("`@/"]Q=6EE
M=#X-"B`@(#QS:6UP;&4^#0H@("`@/'-H;W)T;W!T/G,\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^1&ES<&QA>2!S:6UP;&4@;W5T<'5T(&9O<B!A;&P@=&5S=',\
M+V1O8SX-"B`@(#PO<VEM<&QE/@T*("`@/'!A8VMA9V4^#0H@("`@/'-H;W)T
M;W!T/G`\+W-H;W)T;W!T/@T*("`@(#QD;V,^5')E870@<&%R86UE=&5R<R!A
M<R!I;G-T86QL960@<&%C:V%G97,@9G)O;2!W:&EC:"!T;R!R=6X@=&5S=',\
M+V1O8SX-"B`@(#PO<&%C:V%G93X-"B`@(#QP:'!U;FET/@T*("`@(#QS:&]R
M=&]P=#YU/"]S:&]R=&]P=#X-"B`@("`\9&]C/E-E87)C:"!P87)A;65T97)S
M(&9O<B!!;&Q497-T<RYP:'`L(&%N9"!U<V4@=&AA="!T;R!R=6X@<&AP=6YI
M="UB87-E9"!T97-T<SPO9&]C/@T*("`@/"]P:'!U;FET/@T*("`\+V]P=&EO
M;G,^#0H@(#QD;V,^6W1E<W1F:6QE?&1I<B`N+BY=#0I2=6X@<F5G<F5S<VEO
M;B!T97-T<R!W:71H(%!(4"9A<&]S.W,@<F5G<F5S<VEO;B!T97-T:6YG('-C
M<FEP="`H<G5N+71E<W1S+G!H<"DN/"]D;V,^#0H@/"]R=6XM=&5S=',^#0H\
M+V-O;6UA;F1S/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]497-T
M+G!H<```````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S-S(P`#$P
M-3$U-#,Q,#4W`#`R,3$P,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?5&5S
M="`H<G5N+71E<W1S*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@
M*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@5&5S="YP:'`L=B`Q+CD@,C`P-B\P,B\P,R`R,CHR.#HP."!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*
M+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P
M+C$-"B`J+PT*#0IC;&%S<R!014%27T-O;6UA;F1?5&5S="!E>'1E;F1S(%!%
M05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*
M#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<G5N+71E
M<W1S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4G5N
M(%)E9W)E<W-I;VX@5&5S=',G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]2=6Y497-T<R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=R
M="<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@)W)E8W5R)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G<B<L#0H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=2=6X@=&5S=',@:6X@8VAI;&0@9&ER96-T;W)I97,L(')E8W5R
M<VEV96QY+B`@-"!D:7)S(&1E97`@;6%X:6UU;2<L#0H@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G:6YI)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G:2<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=A8W1U86P@<W1R:6YG(&]F('-E='1I;F=S
M('1O('!A<W,@=&\@<&AP(&EN(&9O<FUA="`B("UD('-E='1I;F<]8FQA:"(G
M+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G4T545$E.1U,G#0H@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5A;'1I;65L
M;V<G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=L)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)TQO9R!T
M97-T(')U;G,O<F5S=6QT<R!A<R!T:&5Y(&%R92!R=6XG+`T*("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W%U:65T)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<2<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=/;FQY(&1I<W!L87D@9&5T86EL
M(&9O<B!F86EL960@=&5S=',G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)W-I;7!L92<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)W,G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G1&ES<&QA>2!S:6UP;&4@;W5T<'5T(&9O<B!A;&P@=&5S
M=',G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W!A
M8VMA9V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)U1R
M96%T('!A<F%M971E<G,@87,@:6YS=&%L;&5D('!A8VMA9V5S(&9R;VT@=VAI
M8V@@=&\@<G5N('1E<W1S)RP-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("=P:'!U;FET)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G=2<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=396%R8V@@<&%R86UE=&5R<R!F;W(@06QL5&5S=',N<&AP
M+"!A;F0@=7-E('1H870@=&\@<G5N('!H<'5N:70M8F%S960@=&5S=',G+`T*
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)UMT97-T9FEL97QD:7(@+BXN70T*4G5N(')E9W)E<W-I
M;VX@=&5S=',@=VET:"!02%!<)W,@<F5G<F5S<VEO;B!T97-T:6YG('-C<FEP
M="`H<G5N+71E<W1S+G!H<"DN)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@
M("D[#0H-"B`@("!V87(@)&]U='!U=#L-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM
M86YD7U1E<W0@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]4
M97-T*"8D=6DL("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI0
M14%27T-O;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4G5N5&5S=',H*0T*#0H@("`@9G5N
M8W1I;VX@9&]2=6Y497-T<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I
M#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H
M<"<[#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]2=6Y497-T+G!H<"<[
M#0H@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@
M("1L;V<@/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1L;V<M/G5I(#T@
M)B1T:&ES+3YU:3L@+R\@<VQI9VAT;'D@:&%C:WDL(&)U="!I="!W:6QL('=O
M<FL-"B`@("`@("`@)')U;B`](&YE=R!014%27U)U;E1E<W0H)&QO9RP@)&]P
M=&EO;G,I.PT*("`@("`@("`D=&5S=',@/2!A<G)A>2@I.PT*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)W)E8W5R)UTI*2![#0H@("`@("`@("`@("`D
M9&5P=&@@/2`T.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1E
M<'1H(#T@,3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-O=6YT*"1P87)A
M;7,I*2![#0H@("`@("`@("`@("`D<&%R86US6UT@/2`G+B<[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P86-K86=E)UTI*2![
M#0H@("`@("`@("`@("`D;VQD<&%R86US(#T@)'!A<F%M<SL-"B`@("`@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&]L9'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@
M("`D<&YA;64@/2`D<F5G+3YP87)S95!A8VMA9V5.86UE*"1P87)A;2P@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*2D[#0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!N86UE*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!N86UE
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!A8VMA
M9V4@/2`F)')E9RT^9V5T4&%C:V%G92@D<&YA;65;)W!A8VMA9V4G72P@)'!N
M86UE6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@(&EF("@A)'!A8VMA
M9V4I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U5N:VYO=VX@<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P;F%M
M92D@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D9FEL96QI<W0@/2`D<&%C:V%G92T^9V5T1FEL96QI<W0H*3L-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D9FEL96QI<W0@87,@)&YA;64@/3X@)&%T
M=',I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1S6R=R
M;VQE)UTI("8F("1A='1S6R=R;VQE)UT@(3T@)W1E<W0G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W!H<'5N:70G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M<')E9U]M871C:"@G+T%L;%1E<W1S7"YP:'`D+VDG+"`D;F%M92DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G
M+UPN<&AP="0O)RP@)&YA;64I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<UM=(#T@)&%T='-;)VEN<W1A;&QE9%]A<R==.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D<&%R86US(&%S("1P*2![#0H@("`@("`@("`@("!I9B`H:7-?9&ER
M*"1P*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M<&AP=6YI="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&ER(#T@4WES
M=&5M.CIF:6YD*&%R<F%Y*"1P+"`G+71Y<&4G+"`G9B<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+6UA>&1E
M<'1H)RP@)&1E<'1H+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)RUN86UE)RP@)T%L;%1E<W1S+G!H<"<I*3L-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D9&ER(#T@4WES=&5M.CIF:6YD*&%R<F%Y*"1P+"`G+71Y<&4G+"`G9B<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G+6UA>&1E<'1H)RP@)&1E<'1H+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RUN86UE)RP@)RHN<&AP
M="<I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1E
M<W1S(#T@87)R87E?;65R9V4H)'1E<W1S+"`D9&ER*3L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=P:'!U;FET)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A<')E
M9U]M871C:"@G+T%L;%1E<W1S7"YP:'`D+VDG+"`D<"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1T97-T<UM=(#T@)'`[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%`9FEL95]E>&ES=',H)'`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]<+G!H<'0D+R<L("1P*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P("X]("<N<&AP="<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9&ER(#T@4WES=&5M.CIF:6YD*&%R<F%Y*&1I<FYA;64H)'`I+"`G+71Y<&4G
M+"`G9B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)RUM87AD97!T:"<L("1D97!T:"P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M+6YA;64G+"`D<"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1E<W1S
M(#T@87)R87E?;65R9V4H)'1E<W1S+"`D9&ER*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T97-T
M<UM=(#T@)'`[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&EN
M:5]S971T:6YG<R`]("<G.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)VEN:2==*2D@>PT*("`@("`@("`@("`@)&EN:5]S971T:6YG<R`N/2`D;W!T
M:6]N<ULG:6YI)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1?
M14Y66R=415-47U!(4%])3D-,541%7U!!5$@G72DI('L-"B`@("`@("`@("`@
M("1I;FE?<V5T=&EN9W,@+CT@(B`M9"!I;F-L=61E7W!A=&@]>R1?14Y66R=4
M15-47U!(4%])3D-,541%7U!!5$@G77TB.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D:6YI7W-E='1I;F=S*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)U5S:6YG($E.22!S971T:6YG<SH@(B<@+B`D:6YI7W-E
M='1I;F=S("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("`D<VMI<'!E9"`]
M("1P87-S960@/2`D9F%I;&5D(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"=2=6YN:6YG("<@+B!C;W5N="@D=&5S=',I("X@
M)R!T97-T<R<L("1C;VUM86YD*3L-"B`@("`@("`@)'-T87)T(#T@=&EM92@I
M.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QT:6UE;&]G)UTI
M*2![#0H@("`@("`@("`@("!`=6YL:6YK*"=R=6XM=&5S=',N;&]G)RD[#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'1E<W1S(&%S("1T*2![#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QT:6UE;&]G)UTI
M*2![#0H@("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"=R=6XM=&5S=',N
M;&]G)RP@)V$G*3L-"B`@("`@("`@("`@("`@("!I9B`H)&9P*2![#0H@("`@
M("`@("`@("`@("`@("`@(&9W<FET92@D9G`L(")2=6YN:6YG('1E<W0@)'0N
M+BXB*3L-"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@4$5!
M4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`@("`@)')E<W5L="`]("1R=6XM/G)U;B@D="P@)&EN:5]S
M971T:6YG<RD[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;&]G*#`L("1R
M97-U;'0M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)W)E86QT:6UE;&]G)UTI*2![#0H@("`@("`@("`@("`@("`@)&9P
M(#T@0&9O<&5N*"=R=6XM=&5S=',N;&]G)RP@)V$G*3L-"B`@("`@("`@("`@
M("`@("!I9B`H)&9P*2![#0H@("`@("`@("`@("`@("`@("`@(&9W<FET92@D
M9G`L("(D<F5S=6QT7&XB*3L-"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E
M*"1F<"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"1R97-U;'0@/3T@)T9!24Q%1"<I('L-"B`@("`@("`@
M("`@(`DD9F%I;&5D6UT@/2`D=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D<F5S=6QT(#T]("=005-3140G*2![#0H@("`@("`@("`@("`)
M)'!A<W-E9%M=(#T@)'0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)')E<W5L="`]/2`G4TM)4%!%1"<I('L-"B`@("`@("`@("`@(`DD<VMI
M<'!E9%M=(#T@)'0[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'1O=&%L(#T@9&%T92@G:3IS)RP@=&EM92@I("T@)'-T87)T*3L-"B`@
M("`@("`@:68@*&-O=6YT*"1F86EL960I*2![#0H@("`@("`@("`@("`D;W5T
M<'5T(#T@(E1/5$%,(%1)344Z("1T;W1A;%QN(CL-"B`@("`@("`@("`@("1O
M=71P=70@+CT@8V]U;G0H)'!A<W-E9"D@+B`B(%!!4U-%1"!415-44UQN(CL-
M"B`@("`@("`@("`@("1O=71P=70@+CT@8V]U;G0H)'-K:7!P960I("X@(B!3
M2TE04$5$(%1%4U137&XB.PT*("`@(`D))&]U='!U="`N/2!C;W5N="@D9F%I
M;&5D*2`N("(@1D%)3$5$(%1%4U13.EQN(CL-"B`@("`@("`@"69O<F5A8V@@
M*"1F86EL960@87,@)&9A:6QU<F4I('L-"B`@("`@("`@"0DD;W5T<'5T("X]
M("1F86EL=7)E("X@(EQN(CL-"B`@("`@("`@"7T-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULG<F5A;'1I;65L;V<G72DI('L-"B`@("`@("`@
M("`@("`@("`D9G`@/2!`9F]P96XH)W)U;BUT97-T<RYL;V<G+"`G82<I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9G`@/2!`
M9F]P96XH)W)U;BUT97-T<RYL;V<G+"`G=R<I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1F<"D@>PT*("`@("`@("`@("`@("`@(&9W<FET
M92@D9G`L("1O=71P=70L('-T<FQE;B@D;W5T<'5T*2D[#0H@("`@("`@("`@
M("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*"=W<F]T92!L;V<@=&\@(B<@+B!R96%L<&%T:"@G<G5N
M+71E<W1S+FQO9R<I("X@)R(G+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H)W)U;BUT97-T<RYL
M;V<G*2`F)B`A0&ES7V1I<B@G<G5N+71E<W1S+FQO9R<I*2![#0H@("`@("`@
M("`@("!`=6YL:6YK*"=R=6XM=&5S=',N;&]G)RD[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=43U1!3"!424U%.B`G("X@
M)'1O=&%L*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*&-O=6YT
M*"1P87-S960I("X@)R!005-3140@5$535%,G+"`D8V]M;6%N9"D[#0H@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AC;W5N="@D<VMI<'!E9"D@+B`G
M(%-+25!0140@5$535%,G+"`D8V]M;6%N9"D[#0H@("`@("`@(&EF("AC;W5N
M="@D9F%I;&5D*2D@>PT*("`@(`D))'1H:7,M/G5I+3YO=71P=71$871A*&-O
M=6YT*"1F86EL960I("X@)R!&04E,140@5$535%,Z)RP@)&-O;6UA;F0I.PT*
M("`@("`@("`)9F]R96%C:"`H)&9A:6QE9"!A<R`D9F%I;'5R92D@>PT*("`@
M("`@("`)"21T:&ES+3YU:2T^;W5T<'5T1&%T82@D9F%I;'5R92P@)&-O;6UA
M;F0I.PT*("`@("`@("`)?0T*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*?0T*#0H_/@T*````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]!=71H+GAM
M;```````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C4P`#$P-3$U
M-#,Q,#4W`#`R,3`W,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\;&]G:6X^
M#0H@(#QS=6UM87)Y/D-O;FYE8W1S(&%N9"!A=71H96YT:6-A=&5S('1O(')E
M;6]T92!S97)V97(\+W-U;6UA<GD^#0H@(#QS:&]R=&-U=#YL:3PO<VAO<G1C
M=70^#0H@(#QF=6YC=&EO;CYD;TQO9VEN/"]F=6YC=&EO;CX-"B`@/&]P=&EO
M;G,@+SX-"B`@/&1O8SX-"DQO9R!I;B!T;R!T:&4@<F5M;W1E('-E<G9E<BX@
M(%1O('5S92!R96UO=&4@9G5N8W1I;VYS(&EN('1H92!I;G-T86QL97(-"G1H
M870@<F5Q=6ER92!A;GD@:VEN9"!O9B!P<FEV:6QE9V5S+"!Y;W4@;F5E9"!T
M;R!L;V<@:6X@9FER<W0N("!4:&4-"G5S97)N86UE(&%N9"!P87-S=V]R9"!Y
M;W4@96YT97(@:&5R92!W:6QL(&)E('-T;W)E9"!I;B!Y;W5R('!E<BUU<V5R
M#0I014%2(&-O;F9I9W5R871I;VX@*'XO+G!E87)R8R!O;B!5;FEX+6QI:V4@
M<WES=&5M<RDN("!!9G1E<B!L;V=G:6YG#0II;BP@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0@=VEL;"!B92!S96YT(&%L;VYG(&EN('-U8G-E<75E;G0-
M"F]P97)A=&EO;G,@;VX@=&AE(')E;6]T92!S97)V97(N/"]D;V,^#0H@/"]L
M;V=I;CX-"B`\;&]G;W5T/@T*("`\<W5M;6%R>3Y,;V=S(&]U="!F<F]M('1H
M92!R96UO=&4@<V5R=F5R/"]S=6UM87)Y/@T*("`\<VAO<G1C=70^;&\\+W-H
M;W)T8W5T/@T*("`\9G5N8W1I;VX^9&],;V=O=70\+V9U;F-T:6]N/@T*("`\
M;W!T:6]N<R`O/@T*("`\9&]C/@T*3&]G<R!O=70@9G)O;2!T:&4@<F5M;W1E
M('-E<G9E<BX@(%1H:7,@8V]M;6%N9"!D;V5S(&YO="!A8W1U86QL>0T*8V]N
M;F5C="!T;R!T:&4@<F5M;W1E('-E<G9E<BP@:70@;VYL>2!D96QE=&5S('1H
M92!S=&]R960@=7-E<FYA;64@86YD#0IP87-S=V]R9"!F<F]M('EO=7(@=7-E
M<B!C;VYF:6=U<F%T:6]N+CPO9&]C/@T*(#PO;&]G;W5T/@T*/"]C;VUM86YD
M<SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]!
M=71H+G!H<```````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,#4P
M`#$P-3$U-#,Q,#4W`#`R,3`U-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?
M075T:"`H;&]G:6XL(&QO9V]U="!C;VUM86YD<RD-"B`J#0H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@075T:"YP:'`L=B`Q+C(S(#(P,#8O,#,O
M,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-
M"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA
M;F0O0V]M;6]N+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O0V]N9FEG+G!H
M<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7T%U=&@@97AT
M96YD<R!014%27T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E
M<G1I97,-"@T*("`@('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@
M)VQO9VEN)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G
M0V]N;F5C=',@86YD(&%U=&AE;G1I8V%T97,@=&\@<F5M;W1E('-E<G9E<B<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=L:2<L#0H@("`@("`@("`@
M("`G9G5N8W1I;VXG(#T^("=D;TQO9VEN)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*3&]G
M(&EN('1O('1H92!R96UO=&4@<V5R=F5R+B`@5&\@=7-E(')E;6]T92!F=6YC
M=&EO;G,@:6X@=&AE(&EN<W1A;&QE<@T*=&AA="!R97%U:7)E(&%N>2!K:6YD
M(&]F('!R:79I;&5G97,L('EO=2!N965D('1O(&QO9R!I;B!F:7)S="X@(%1H
M90T*=7-E<FYA;64@86YD('!A<W-W;W)D('EO=2!E;G1E<B!H97)E('=I;&P@
M8F4@<W1O<F5D(&EN('EO=7(@<&5R+75S97(-"E!%05(@8V]N9FEG=7)A=&EO
M;B`H?B\N<&5A<G)C(&]N(%5N:7@M;&EK92!S>7-T96US*2X@($%F=&5R(&QO
M9V=I;F<-"FEN+"!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"!W:6QL(&)E
M('-E;G0@86QO;F<@:6X@<W5B<V5Q=65N=`T*;W!E<F%T:6]N<R!O;B!T:&4@
M<F5M;W1E('-E<G9E<BXG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)VQO
M9V]U="<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)TQO
M9W,@;W5T(&9R;VT@=&AE(')E;6]T92!S97)V97(G+`T*("`@("`@("`@("`@
M)W-H;W)T8W5T)R`]/B`G;&\G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&],;V=O=70G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y
M*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0I,;V=S(&]U="!F<F]M('1H
M92!R96UO=&4@<V5R=F5R+B`@5&AI<R!C;VUM86YD(&1O97,@;F]T(&%C='5A
M;&QY#0IC;VYN96-T('1O('1H92!R96UO=&4@<V5R=F5R+"!I="!O;FQY(&1E
M;&5T97,@=&AE('-T;W)E9"!U<V5R;F%M92!A;F0-"G!A<W-W;W)D(&9R;VT@
M>6]U<B!U<V5R(&-O;F9I9W5R871I;VXN)RP-"B`@("`@("`@("`@("D-"@T*
M("`@("`@("`I.PT*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]!=71H(&-O
M;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?075T:"@F)'5I+"`F
M)&-O;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD
M7T-O;6UO;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&1O3&]G:6XH*0T*#0H@("`@+RHJ#0H@("`@("H@17AE
M8W5T92!T:&4@)VQO9VEN)R!C;VUM86YD+@T*("`@("`J#0H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]M;6%N9"!C;VUM86YD(&YA;64-"B`@("`@*@T*("`@
M("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R!O<'1I;VY?;F%M92`]/B!V86QU
M90T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@;&ES="!O
M9B!A9&1I=&EO;F%L('!A<F%M971E<G,-"B`@("`@*@T*("`@("`J($!R971U
M<FX@8F]O;"!44E5%(&]N('-U8V-E<W,@;W(-"B`@("`@*B!A(%!%05(@97)R
M;W(@;VX@9F%I;'5R90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;TQO9VEN*"1C;VUM86YD+"`D;W!T
M:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)&-H86YN96P@/2`D
M=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@
M("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@('T-"B`@
M("`@("`@)'-E<G9E<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D
M7VUI<G)O<B<I.PT*("`@("`@("`D<F5M;W1E(#T@)B1T:&ES+3YC;VYF:6<M
M/F=E=%)E;6]T92@I.PT*("`@("`@("`D=7-E<FYA;64@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)W5S97)N86UE)RD[#0H@("`@("`@(&EF("AE;7!T>2@D=7-E
M<FYA;64I*2![#0H@("`@("`@("`@("`D=7-E<FYA;64@/2!`)%]%3E9;)U53
M15(G73L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H(DQO9V=I;F<@:6X@=&\@)'-E<G9E<BXB+"`D8V]M;6%N9"D[#0H@("`@
M("`@(`T*("`@("`@("!L:7-T*"1U<V5R;F%M92P@)'!A<W-W;W)D*2`]("1T
M:&ES+3YU:2T^=7-E<D1I86QO9R@-"B`@("`@("`@("`@("1C;VUM86YD+`T*
M("`@("`@("`@("`@87)R87DH)U5S97)N86UE)RP@)U!A<W-W;W)D)RDL#0H@
M("`@("`@("`@("!A<G)A>2@G=&5X="<L("`@("`G<&%S<W=O<F0G*2P-"B`@
M("`@("`@("`@(&%R<F%Y*"1U<V5R;F%M92P@("<G*0T*("`@("`@("`@("`@
M*3L-"B`@("`@("`@)'5S97)N86UE(#T@=')I;2@D=7-E<FYA;64I.PT*("`@
M("`@("`D<&%S<W=O<F0@/2!T<FEM*"1P87-S=V]R9"D[#0H@("`@("`@(`T*
M("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)W5S97)N86UE)RP@)'5S97)N
M86UE*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=P87-S=V]R9"<L
M("1P87-S=V]R9"D[#0H-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%
M4U0H*2D@>PT*("`@("`@("`@("`@)&]K(#T@=')U93L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1R96UO=&4M/F5X<&5C=$5R<F]R*#0P,2D[
M#0H@("`@("`@("`@("`D;VL@/2`D<F5M;W1E+3YC86QL*"=L;V=I;G1E<W0G
M*3L-"B`@("`@("`@("`@("1R96UO=&4M/G!O<$5X<&5C="@I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D;VL@/3T]('1R=64I('L-"B`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B3&]G9V5D(&EN+B(L("1C;VUM86YD
M*3L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-T;W)E*"D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(DQO9VEN(&9A:6QE9"$B*3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9&],;V=O=70H*0T*#0H@("`@+RHJ#0H@("`@("H@17AE8W5T92!T:&4@)VQO
M9V]U="<@8V]M;6%N9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;6UA;F0@8V]M;6%N9"!N86UE#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M87)R87D@)&]P=&EO;G,@;W!T:6]N7VYA;64@/3X@=F%L=64-"B`@("`@*@T*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US(&QI<W0@;V8@861D:71I;VYA
M;"!P87)A;65T97)S#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)5
M12!O;B!S=6-C97-S(&]R#0H@("`@("H@82!014%2(&5R<F]R(&]N(&9A:6QU
M<F4-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9&],;V=O=70H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0T*("`@('L-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG
M971296=I<W1R>2@I.PT*("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3YC;VYF
M:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@("1C:&%N(#T@
M)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@?0T*("`@("`@("`D<V5R
M=F5R(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RD[
M#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B3&]G9VEN9R!O=70@
M9G)O;2`D<V5R=F5R+B(L("1C;VUM86YD*3L-"B`@("`@("`@)'1H:7,M/F-O
M;F9I9RT^<F5M;W9E*"=U<V5R;F%M92<I.PT*("`@("`@("`D=&AI<RT^8V]N
M9FEG+3YR96UO=F4H)W!A<W-W;W)D)RD[#0H@("`@("`@("1T:&ES+3YC;VYF
M:6<M/G-T;W)E*"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@("\O('U]?0T*?0T*#0H_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]215-4+P``````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-3<`,#$V-C4P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U)%4U0O,3$N<&AP````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q-S0V-@`Q,#4Q-30S,3`U-P`P,3<V,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\J*@T*("H@
M4$5!4E]215-47S$Q("T@:6UP;&5M96YT(&9A<W1E<B!L:7-T+6%L;"]R96UO
M=&4M;&ES="!C;VUM86YD#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(#$Q+G!H<"QV(#$N-"`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C,-"B`J+PT*#0HO*BH-"B`J($9O<B!D;W=N
M;&]A9&EN9R!215-4('AM;"]T>'0@9FEL97,-"B`J+PT*<F5Q=6ER95]O;F-E
M("=014%2+U)%4U0N<&AP)SL-"@T*+RHJ#0H@*B!);7!L96UE;G0@4D535"`Q
M+C$-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XS#0H@*B\-"F-L87-S(%!%05)?4D535%\Q,0T*
M>PT*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]215-4#0H@("`@("HO#0H@
M("`@=F%R("1?<F5S=#L-"@T*("`@(&9U;F-T:6]N(%!%05)?4D535%\Q,2@D
M8V]N9FEG+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W)E<W0@/2`F;F5W(%!%05)?4D535"@D8V]N9FEG+"`D;W!T:6]N
M<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@;&ES=$%L;"@D8F%S92P@)&1O
M<W1A8FQE+"`D8F%S:6,@/2!T<G5E*0T*("`@('L-"B`@("`@("`@)&-A=&5G
M;W)Y;&ES="`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@
M)V,O8V%T96=O<FEE<RYX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&-A=&5G;W)Y;&ES="DI('L-"B`@("`@("`@("`@(')E='5R;B`D8V%T
M96=O<GEL:7-T.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2!A<G)A>2@I
M.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C871E9V]R>6QI<W1;)V,G72DI
M('L-"B`@("`@("`@("`@("1C871E9V]R>6QI<W1;)V,G72`](&%R<F%Y*"1C
M871E9V]R>6QI<W1;)V,G72D[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("!F;W)E86-H("@D8V%T96=O<GEL:7-T6R=C)UT@87,@)'!R;V=R97-S(#T^
M("1C871E9V]R>2D@>PT*("`@("`@("`@("`@)&-A=&5G;W)Y(#T@)&-A=&5G
M;W)Y6R=?8V]N=&5N="==.PT*("`@("`@("`@("`@)'!A8VMA9V5S:6YF;R`]
M("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X-"B`@("`@("`@
M("`@("`@("`G8R\G("X@=7)L96YC;V1E*"1C871E9V]R>2D@+B`G+W!A8VMA
M9V5S:6YF;RYX;6PG*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1P86-K86=E<VEN9F\I*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P
M86-K86=E<VEN9F\I('Q\("%I<W-E="@D<&%C:V%G97-I;F9O6R=P:2==*2D@
M>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G97-I;F9O6R=P:2==
M*2!\?"`A:7-S970H)'!A8VMA9V5S:6YF;ULG<&DG75LP72DI('L-"B`@("`@
M("`@("`@("`@("`D<&%C:V%G97-I;F9O6R=P:2==(#T@87)R87DH)'!A8VMA
M9V5S:6YF;ULG<&DG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M;W)E86-H("@D<&%C:V%G97-I;F9O6R=P:2==(&%S("1P86-K86=E:6YF;RD@
M>PT*("`@("`@("`@("`@("`@("1I;F9O(#T@)'!A8VMA9V5I;F9O6R=P)UT[
M#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`D:6YF;ULG;B==.PT*("`@
M("`@("`@("`@("`@("1R96QE87-E<R`](&ES<V5T*"1P86-K86=E:6YF;ULG
M82==*2`_("1P86-K86=E:6YF;ULG82==(#H@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@=6YS970H)&QA=&5S="D[#0H@("`@("`@("`@("`@("`@=6YS970H
M)'5N<W1A8FQE*3L-"B`@("`@("`@("`@("`@("!U;G-E="@D<W1A8FQE*3L-
M"B`@("`@("`@("`@("`@("!U;G-E="@D<W1A=&4I.PT*("`@("`@("`@("`@
M("`@(&EF("@D<F5L96%S97,I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<F5L96%S97-;)W(G75LP72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1R96QE87-E<ULG<B==(#T@87)R87DH)')E;&5A<V5S6R=R
M)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1R96QE87-E<ULG<B==(&%S("1R96QE87-E*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L871E<W0I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D;W-T86)L92`F
M)B`D<F5L96%S95LG<R==(#T]("=S=&%B;&4G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D<F5L96%S95LG=B==.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G<W1A
M8FQE)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"$D9&]S=&%B;&4I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R96QE87-E
M6R=V)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T
M92`]("1R96QE87-E6R=S)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D<W1A8FQE*2`F)B`D<F5L96%S95LG
M<R==(#T]("=S=&%B;&4G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T86)L92`]("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=6YS=&%B;&4I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1U;G-T86)L92`]("1S=&%B;&4[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=6YS=&%B;&4I("8F("1R96QE87-E6R=S)UT@(3T@)W-T86)L92<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@)'5N
M<W1A8FQE(#T@)')E;&5A<V5;)W8G73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<W1A=&4@/2`D<F5L96%S95LG<R==.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1L871E<W0I("8F("%I<W-E="@D<W1A=&4I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-T871E(#T@)')E;&5A<V5;)W,G73L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D;&%T97-T*2`F)B!I<W-E="@D<W1A8FQE*2`F)B!I
M<W-E="@D=6YS=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1B87-I8RD@>R`O+R!R96UO=&4M;&ES="!C;VUM86YD#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&QA=&5S="DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<F5T6R1P
M86-K86=E72`](&%R<F%Y*"=S=&%B;&4G(#T^("1L871E<W0I.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@+R\@;&ES="UA;&P@8V]M;6%N9`T*("`@("`@("`@
M("`@("`@("1D97!S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1U;G-T86)L92DI('L-"B`@("`@("`@("`@("`@("`@("`@)'5N
M<W1A8FQE(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("1S=&%T92`]
M("=S=&%B;&4G.PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'-T
M86)L92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D
M=6YS=&%B;&4@/2`D<W1A8FQE.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M)&QA=&5S="`]("1U;G-T86)L93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D;&%T97-T*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D;&%T97-T(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("@D;&%T97-T*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G96EN9F];)V1E<',G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'!A8VMA
M9V5I;F9O6R=D97!S)UTI('Q\#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`A:7-S970H)'!A8VMA9V5I;F9O6R=D97!S)UU;,%TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5I;F9O6R=D97!S)UT@
M/2!A<G)A>2@D<&%C:V%G96EN9F];)V1E<',G72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@)&0@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'!A8VMA9V5I;F9O6R=D97!S)UT@87,@)&1E<"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1D97!;)W8G72`]/2`D;&%T97-T
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&0@/2!U;G-E<FEA
M;&EZ92@D9&5P6R=D)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M6R=R97%U:7)E9"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'!F*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&8@/2!N97<@4$5!4E]086-K86=E1FEL95]V,CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!F+3YS971$97!S*"1D*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&1E<',@/2`D<&8M/F=E=$1E<',H*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1D97!S(#T@)&0[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&1E<',@87,@
M)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P
M6R=T>7!E)UT@(3T]("=P:V<G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<UM=(#T@
M)&1E<#L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1S=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1S=&%B;&4@/2`G+6XO82TG.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=S=&%B;&4G(#T^("1L871E<W0L
M("=S=6UM87)Y)R`]/B`D:6YF;ULG<R==+`T*("`@("`@("`@("`@("`@("`@
M("`G9&5S8W)I<'1I;VXG(#T^#0H@("`@("`@("`@("`@("`@("`@("1I;F9O
M6R=D)UTL("=D97!S)R`]/B`D9&5P<RP@)V-A=&5G;W)Y)R`]/B`D:6YF;ULG
M8V$G75LG7V-O;G1E;G0G72P-"B`@("`@("`@("`@("`@("`@("`@)W5N<W1A
M8FQE)R`]/B`D=6YS=&%B;&4L("=S=&%T92<@/3X@)'-T871E*3L-"B`@("`@
M("`@("`@("`@("`D<F5T6R1P86-K86=E72`]("1I;F9O.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI
M;F<H*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@4F5T=7)N(&%N(&%R<F%Y(&-O;G1A:6YI;F<@86QL(&]F('1H
M92!S=&%T97,@=&AA="!A<F4@;6]R92!S=&%B;&4@=&AA;@T*("`@("`J(&]R
M(&5Q=6%L('1O('1H92!P87-S960@:6X@<W1A=&4-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@4F5L96%S92!S=&%T90T*("`@("`J($!P87)A;2!B
M;V]L96%N($1E=&5R;6EN97,@=VAE=&AE<B!T;R!I;F-L=61E("1S=&%T92!I
M;B!T:&4@;&ES=`T*("`@("`J($!R971U<FX@9F%L<V5\87)R87D@1F%L<V4@
M:68@)'-T871E(&ES(&YO="!A('9A;&ED(')E;&5A<V4@<W1A=&4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!B971T97)3=&%T97,H)'-T871E+"`D:6YC;'5D
M92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1S=&%T97,@/2!A
M<G)A>2@G<VYA<'-H;W0G+"`G9&5V96PG+"`G86QP:&$G+"`G8F5T82<L("=S
M=&%B;&4G*3L-"B`@("`@("`@)&D@/2!A<G)A>5]S96%R8V@H)'-T871E+"`D
M<W1A=&5S*3L-"B`@("`@("`@:68@*"1I(#T]/2!F86QS92D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M:6YC;'5D92D@>PT*("`@("`@("`@("`@)&DM+3L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@87)R87E?<VQI8V4H)'-T871E<RP@)&D@*R`Q*3L-"B`@
M("!]#0I]#0H_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]215-4+S$P+G!H<```````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C$S,#(`,3`U,34T,S$P-3<`
M,#$W-C`P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO*BH-"B`J(%!%05)?4D535%\Q,`T*("H-"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B`Q,"YP:'`L=B`Q+C0P(#(P,#8O
M,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q,@T*("HO
M#0H-"B\J*@T*("H@1F]R(&1O=VYL;V%D:6YG(%)%4U0@>&UL+W1X="!F:6QE
M<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O4D535"YP:'`G.PT*#0HO*BH-
M"B`J($EM<&QE;65N="!215-4(#$N,`T*("H-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3(-"B`J
M+PT*8VQA<W,@4$5!4E]215-47S$P#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A
M<B!014%27U)%4U0-"B`@("`@*B\-"B`@("!V87(@)%]R97-T.PT*("`@(&9U
M;F-T:6]N(%!%05)?4D535%\Q,"@D8V]N9FEG+"`D;W!T:6]N<R`](&%R<F%Y
M*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W)E<W0@/2`F;F5W(%!%05)?
M4D535"@D8V]N9FEG+"`D;W!T:6]N<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T1&]W;FQO86154DPH)&)A<V4L("1P86-K86=E:6YF;RP@)'!R969S
M=&%T92P@)&EN<W1A;&QE9"D-"B`@("![#0H@("`@("`@("1C:&%N;F5L(#T@
M)'!A8VMA9V5I;F9O6R=C:&%N;F5L)UT[#0H@("`@("`@("1P86-K86=E(#T@
M)'!A8VMA9V5I;F9O6R=P86-K86=E)UT[#0H@("`@("`@("1S=&%T97,@/2`D
M=&AI<RT^8F5T=&5R4W1A=&5S*"1P<F5F<W1A=&4L('1R=64I.PT*("`@("`@
M("!I9B`H(21S=&%T97,I('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"<B)R`N("1P<F5F<W1A=&4@+B`G(B!I<R!N;W0@82!V86QI
M9"!S=&%T92<I.PT*("`@("`@("!]#0H@("`@("`@("1S=&%T92`]("1V97)S
M:6]N(#T@;G5L;#L-"B`@("`@("`@:68@*&ES<V5T*"1P86-K86=E:6YF;ULG
M<W1A=&4G72DI('L-"B`@("`@("`@("`@("1S=&%T92`]("1P86-K86=E:6YF
M;ULG<W1A=&4G73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'!A
M8VMA9V5I;F9O6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`D=F5R<VEO
M;B`]("1P86-K86=E:6YF;ULG=F5R<VEO;B==.PT*("`@("`@("!]#0H@("`@
M("`@("1I;F9O(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@
M+B`G<B\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G+V%L;')E;&5A<V5S
M+GAM;"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!R96QE
M87-E<R!A=F%I;&%B;&4@9F]R('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@
M("`@("1C:&%N;F5L("X@)R\G("X@)'!A8VMA9V4@+B`G(B<I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-S970H)&EN9F];)W(G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9F]U
M;F0@/2!F86QS93L-"B`@("`@("`@)')E;&5A<V4@/2!F86QS93L-"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D:6YF;ULG<B==*2!\?"`A:7-S970H)&EN9F];
M)W(G75LP72DI('L-"B`@("`@("`@("`@("1I;F9O6R=R)UT@/2!A<G)A>2@D
M:6YF;ULG<B==*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D:6YF
M;ULG<B==(&%S("1R96QE87-E*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<F5S="T^7V]P=&EO;G-;)V9O<F-E)UTI("8F("@D:6YS=&%L
M;&5D("8F#0H@("`@("`@("`@("`@("`@("!V97)S:6]N7V-O;7!A<F4H)')E
M;&5A<V5;)W8G72P@)&EN<W1A;&QE9"P@)SPG*2DI('L-"B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D<W1A=&4I*2![#0H@("`@("`@("`@("`@("`@:68@*"1R96QE
M87-E6R=S)UT@/3T@)'-T871E*2![#0H@("`@("`@("`@("`@("`@("`@("1F
M;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D
M=F5R<VEO;BDI('L-"B`@("`@("`@("`@("`@("!I9B`H)')E;&5A<V5;)W8G
M72`]/2`D=F5R<VEO;BD@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(&EF("AI;E]A<G)A>2@D<F5L96%S95LG<R==+"`D<W1A=&5S*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5T
M=7)N1&]W;FQO86154DPH)&)A<V4L("1P86-K86=E+"`D<F5L96%S92P@)&EN
M9F\L("1F;W5N9"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&5P1&]W
M;FQO86154DPH)&)A<V4L("1X<V1V97)S:6]N+"`D9&5P96YD96YC>2P@)&1E
M<'!A8VMA9V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R
M969S=&%T92`]("=S=&%B;&4G+"`D:6YS=&%L;&5D(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("`D8VAA;FYE;"`]("1D97!E;F1E;F-Y6R=C:&%N;F5L)UT[
M#0H@("`@("`@("1P86-K86=E(#T@)&1E<&5N9&5N8WE;)VYA;64G73L-"B`@
M("`@("`@)'-T871E<R`]("1T:&ES+3YB971T97)3=&%T97,H)'!R969S=&%T
M92P@=')U92D[#0H@("`@("`@(&EF("@A)'-T871E<RD@>PT*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)R(G("X@)'!R969S=&%T92`N
M("<B(&ES(&YO="!A('9A;&ED('-T871E)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'-T871E(#T@)'9E<G-I;VX@/2!N=6QL.PT*("`@("`@("!I9B`H:7-S
M970H)'!A8VMA9V5I;F9O6R=S=&%T92==*2D@>PT*("`@("`@("`@("`@)'-T
M871E(#T@)'!A8VMA9V5I;F9O6R=S=&%T92==.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D<&%C:V%G96EN9F];)W9E<G-I;VXG72DI('L-"B`@
M("`@("`@("`@("1V97)S:6]N(#T@)'!A8VMA9V5I;F9O6R=V97)S:6]N)UT[
M#0H@("`@("`@('T-"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W)E<W0M/G)E
M=')I979E1&%T82@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E
M*2`N("<O86QL<F5L96%S97,N>&UL)RD[#0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1I;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U!A8VMA9V4@(B<@+B`D9&5P<&%C:V%G95LG8VAA;FYE;"==
M("X@)R\G("X@)&1E<'!A8VMA9V5;)W!A8VMA9V4G70T*("`@("`@("`@("`@
M("`@("X@)R(@9&5P96YD96YC>2`B)R`N("1C:&%N;F5L("X@)R\G("X@)'!A
M8VMA9V4@+B`G(B!H87,@;F\@<F5L96%S97,G*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1I;F9O*2!\?"`A:7-S970H)&EN9F];)W(G
M72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("`D97AC;'5D92`](&%R<F%Y*"D[#0H@("`@("`@("1M:6X@/2`D
M;6%X(#T@)')E8V]M;65N9&5D(#T@9F%L<V4[#0H@("`@("`@(&EF("@D>'-D
M=F5R<VEO;B`]/2`G,2XP)RD@>PT*("`@("`@("`@("`@)'!I;F9O6R=P86-K
M86=E)UT@/2`D9&5P96YD96YC>5LG;F%M92==.PT*("`@("`@("`@("`@)'!I
M;F9O6R=C:&%N;F5L)UT@/2`G<&5A<BYP:'`N;F5T)SL@+R\@=&AI<R!I<R!A
M;'=A>7,@=')U92`M(&1O;B=T(&-H86YG92!T:&ES#0H@("`@("`@("`@("!S
M=VET8V@@*"1D97!E;F1E;F-Y6R=R96PG72D@>PT*("`@("`@("`@("`@("`@
M(&-A<V4@)V=E)R`Z#0H@("`@("`@("`@("`@("`@("`@("1M:6X@/2`D9&5P
M96YD96YC>5LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@(&-A<V4@)V=T)R`Z#0H@("`@("`@("`@("`@("`@
M("`@("1M:6X@/2`D9&5P96YD96YC>5LG=F5R<VEO;B==.PT*("`@("`@("`@
M("`@("`@("`@("`D97AC;'5D92`](&%R<F%Y*"1D97!E;F1E;F-Y6R=V97)S
M:6]N)UTI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@(&-A<V4@)V5Q)R`Z#0H@("`@("`@("`@("`@("`@("`@("1R96-O;6UE
M;F1E9"`]("1D97!E;F1E;F-Y6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G;'0G(#H-"B`@("`@
M("`@("`@("`@("`@("`@)&UA>"`]("1D97!E;F1E;F-Y6R=V97)S:6]N)UT[
M#0H@("`@("`@("`@("`@("`@("`@("1E>&-L=61E(#T@87)R87DH)&1E<&5N
M9&5N8WE;)W9E<G-I;VXG72D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@8V%S92`G;&4G(#H-"B`@("`@("`@("`@("`@("`@
M("`@)&UA>"`]("1D97!E;F1E;F-Y6R=V97)S:6]N)UT[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G;F4G(#H-"B`@
M("`@("`@("`@("`@("`@("`@)&5X8VQU9&4@/2!A<G)A>2@D9&5P96YD96YC
M>5LG=F5R<VEO;B==*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1P:6YF
M;ULG<&%C:V%G92==(#T@)&1E<&5N9&5N8WE;)VYA;64G73L-"B`@("`@("`@
M("`@("1M:6X@/2!I<W-E="@D9&5P96YD96YC>5LG;6EN)UTI(#\@)&1E<&5N
M9&5N8WE;)VUI;B==(#H@9F%L<V4[#0H@("`@("`@("`@("`D;6%X(#T@:7-S
M970H)&1E<&5N9&5N8WE;)VUA>"==*2`_("1D97!E;F1E;F-Y6R=M87@G72`Z
M(&9A;'-E.PT*("`@("`@("`@("`@)')E8V]M;65N9&5D(#T@:7-S970H)&1E
M<&5N9&5N8WE;)W)E8V]M;65N9&5D)UTI(#\-"B`@("`@("`@("`@("`@("`D
M9&5P96YD96YC>5LG<F5C;VUM96YD960G72`Z(&9A;'-E.PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!E;F1E;F-Y6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P96YD96YC>5LG97AC;'5D92==
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D97AC;'5D92`](&%R<F%Y
M*"1D97!E;F1E;F-Y6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D9F]U;F0@/2!F
M86QS93L-"B`@("`@("`@)')E;&5A<V4@/2!F86QS93L-"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D:6YF;ULG<B==*2!\?"`A:7-S970H)&EN9F];)W(G75LP
M72DI('L-"B`@("`@("`@("`@("1I;F9O6R=R)UT@/2!A<G)A>2@D:6YF;ULG
M<B==*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D:6YF;ULG<B==
M(&%S("1R96QE87-E*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<F5S="T^7V]P=&EO;G-;)V9O<F-E)UTI("8F("@D:6YS=&%L;&5D("8F
M#0H@("`@("`@("`@("`@("`@("!V97)S:6]N7V-O;7!A<F4H)')E;&5A<V5;
M)W8G72P@)&EN<W1A;&QE9"P@)SPG*2DI('L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI;E]A
M<G)A>2@D<F5L96%S95LG=B==+"`D97AC;'5D92DI('L@+R\@<VMI<"!E>&-L
M=61E9"!V97)S:6]N<PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@+R\@86QL;W<@;F5W97(@<F5L96%S
M97,@=&\@<V%Y(")))VT@3TL@=VET:"!T:&4@9&5P96YD96YT('!A8VMA9V4B
M#0H@("`@("`@("`@("!I9B`H)'AS9'9E<G-I;VX@/3T@)S(N,"<@)B8@:7-S
M970H)')E;&5A<V5;)V-O)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D<F5L96%S95LG8V\G72D@?'P@(6ES<V5T*"1R96QE87-E6R=C
M;R==6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LG8V\G
M72`](&%R<F%Y*"1R96QE87-E6R=C;R==*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5;)V-O)UT@87,@
M)&5N=')Y*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96YT
M<GE;)W@G72D@)B8@(6ES7V%R<F%Y*"1E;G1R>5LG>"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&5N=')Y6R=X)UT@/2!A<G)A>2@D96YT<GE;
M)W@G72D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@A:7-S970H
M)&5N=')Y6R=X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D96YT
M<GE;)W@G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1E;G1R>5LG8R==(#T]("1D97!P86-K
M86=E6R=C:&%N;F5L)UT@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W1R=&]L;W=E<B@D96YT<GE;)W`G72D@/3T@<W1R=&]L;W=E<B@D9&5P<&%C
M:V%G95LG<&%C:V%G92==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("!V97)S:6]N7V-O;7!A<F4H)&1E<'!A8VMA9V5;)W9E<G-I;VXG72P@)&5N
M=')Y6R=M:6XG72P@)SX])RD@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@=F5R<VEO;E]C;VUP87)E*"1D97!P86-K86=E6R=V97)S:6]N)UTL("1E
M;G1R>5LG;6%X)UTL("<\/2<I("8F#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("%I;E]A<G)A>2@D<F5L96%S95LG=B==+"`D96YT<GE;)W@G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R96-O;6UE;F1E9"`]("1R96QE
M87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<F5C;VUM96YD960I('L-"B`@
M("`@("`@("`@("`@("!I9B`H)')E;&5A<V5;)W8G72`A/2`D<F5C;VUM96YD
M960I('L@+R\@:68@=V4@=V%N="!A('-P96-I9FEC#0H@("`@("`@("`@("`@
M("`@("`@("\O('9E<G-I;VXL('1H96X@<VMI<"!A;&P@;W1H97)S#0H@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)')E
M;&5A<V5;)W,G72P@)'-T871E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O('1H92!S=&%B:6QI='D@:7,@=&]O(&QO=RP@8G5T('=E(&UU<W0@
M<F5T=7)N('1H90T*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<F5C;VUM
M96YD960@=F5R<VEO;B!I9B!P;W-S:6)L90T*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F5T=7)N1&]W;FQO86154DPH)&)A<V4L
M("1P86-K86=E+"`D<F5L96%S92P@)&EN9F\L('1R=64I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"1M:6X@)B8@=F5R<VEO;E]C;VUP87)E*"1R
M96QE87-E6R=V)UTL("1M:6XL("=L="<I*2![("\O('-K:7`@=&]O(&]L9"!V
M97)S:6]N<PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"1M87@@)B8@=F5R<VEO;E]C;VUP87)E
M*"1R96QE87-E6R=V)UTL("1M87@L("=G="<I*2![("\O('-K:7`@=&]O(&YE
M=R!V97)S:6]N<PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"1I;G-T86QL960@)B8@=F5R<VEO
M;E]C;VUP87)E*"1R96QE87-E6R=V)UTL("1I;G-T86QL960L("<\)RDI('L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI;E]A<G)A>2@D<F5L96%S95LG<R==+"`D<W1A=&5S
M*2D@>R`O+R!I9B!I;B!T:&4@<')E9F5R<F5D('-T871E+BXN#0H@("`@("`@
M("`@("`@("`@)&9O=6YD(#T@=')U93L@+R\@+BXN('1H96X@=7-E(&ET#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5T=7)N1&]W;FQO86154DPH
M)&)A<V4L("1P86-K86=E+"`D<F5L96%S92P@)&EN9F\L("1F;W5N9"D[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7W)E='5R;D1O=VYL;V%D55),*"1B87-E
M+"`D<&%C:V%G92P@)')E;&5A<V4L("1I;F9O+"`D9F]U;F0I#0H@("`@>PT*
M("`@("`@("!I9B`H(21F;W5N9"D@>PT*("`@("`@("`@("`@)')E;&5A<V4@
M/2`D:6YF;ULG<B==6S!=.PT*("`@("`@("!]#0H@("`@("`@("1R96QE87-E
M:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5#86-H949I<G-T*"1B87-E
M("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)R\G("X@#0H@("`@
M("`@("`@("`D<F5L96%S95LG=B==("X@)RYX;6PG*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E;&5A<V5I;F9O*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!A8VMA9V4@(B<@+B`D<&%C:V%G
M92`N("<B(%9E<G-I;VX@(B<@+B`D<F5L96%S95LG=B==("X-"B`@("`@("`@
M("`@("`@("`G(B!D;V5S(&YO="!H879E(%)%4U0@>&UL(&%V86EL86)L92<I
M.PT*("`@("`@("!]#0H@("`@("`@("1P86-K86=E>&UL(#T@)'1H:7,M/E]R
M97-T+3YR971R:65V94-A8VAE1FER<W0H)&)A<V4@+B`G<B\G("X@<W1R=&]L
M;W=E<B@D<&%C:V%G92D@+B`G+R<@+@T*("`@("`@("`@("`@)V1E<',N)R`N
M("1R96QE87-E6R=V)UT@+B`G+G1X="<L(&9A;'-E+"!T<G5E*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)'!A8VMA9V5X;6PI*2![#0H@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&%C:V%G92`B)R`N("1P
M86-K86=E("X@)R(@5F5R<VEO;B`B)R`N("1R96QE87-E6R=V)UT@+@T*("`@
M("`@("`@("`@("`@("<B(&1O97,@;F]T(&AA=F4@4D535"!D97!E;F1E;F-Y
M(&EN9F]R;6%T:6]N(&%V86EL86)L92<I.PT*("`@("`@("!]#0H@("`@("`@
M("1P86-K86=E>&UL(#T@=6YS97)I86QI>F4H)'!A8VMA9V5X;6PI.PT*("`@
M("`@("!I9B`H(21P86-K86=E>&UL*2![#0H@("`@("`@("`@("`D<&%C:V%G
M97AM;"`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@)&%L;&EN9F\@
M/2`D=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=R+R<@+B!S
M=')T;VQO=V5R*"1P86-K86=E*2`N#0H@("`@("`@("`@("`G+V%L;')E;&5A
M<V5S+GAM;"<I.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A;&QI;F9O6R=R
M)UTI('Q\("%I<W-E="@D86QL:6YF;ULG<B==6S!=*2D@>PT*("`@("`@("`@
M("`@)&%L;&EN9F];)W(G72`](&%R<F%Y*"1A;&QI;F9O6R=R)UTI.PT*("`@
M("`@("!]#0H@("`@("`@("1C;VUP871I8FQE(#T@9F%L<V4[#0H@("`@("`@
M(&9O<F5A8V@@*"1A;&QI;F9O6R=R)UT@87,@)')E;&5A<V4I('L-"B`@("`@
M("`@("`@(&EF("@D<F5L96%S95LG=B==("$]("1R96QE87-E:6YF;ULG=B==
M*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E6R=C;R==*2D@>PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)&-O;7!A=&EB;&4@/2!A<G)A>2@I.PT*("`@("`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<F5L96%S95LG8V\G72D@?'P@(6ES<V5T*"1R96QE87-E
M6R=C;R==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1R96QE87-E6R=C;R==
M(#T@87)R87DH)')E;&5A<V5;)V-O)UTI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5;)V-O)UT@87,@)&5N=')Y*2![
M#0H@("`@("`@("`@("`@("`@)&-O;7`@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@("1C;VUP6R=N86UE)UT@/2`D96YT<GE;)W`G73L-"B`@("`@("`@
M("`@("`@("`D8V]M<%LG8VAA;FYE;"==(#T@)&5N=')Y6R=C)UT[#0H@("`@
M("`@("`@("`@("`@)&-O;7!;)VUI;B==(#T@)&5N=')Y6R=M:6XG73L-"B`@
M("`@("`@("`@("`@("`D8V]M<%LG;6%X)UT@/2`D96YT<GE;)VUA>"==.PT*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)W@G72D@)B8@(6ES
M7V%R<F%Y*"1E;G1R>5LG>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M8V]M<%LG97AC;'5D92==(#T@)&5N=')Y6R=X)UT[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1C;VUP871I8FQE6UT@/2`D8V]M<#L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D8V]M<&%T
M:6)L92D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("1C;VUP871I8FQE(#T@
M)&-O;7!A=&EB;&5;,%T[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9O=6YD*2![#0H@("`@
M("`@("`@("!R971U<FX@#0H@("`@("`@("`@("`@("`@87)R87DH)W9E<G-I
M;VXG(#T^("1R96QE87-E:6YF;ULG=B==+`T*("`@("`@("`@("`@("`@("`@
M("`@("=I;F9O)R`]/B`D<&%C:V%G97AM;"P-"B`@("`@("`@("`@("`@("`@
M("`@("`G<&%C:V%G92<@/3X@)')E;&5A<V5I;F9O6R=P)UU;)U]C;VYT96YT
M)UTL#0H@("`@("`@("`@("`@("`@("`@("`@)W-T86)I;&ET>2<@/3X@)')E
M;&5A<V5I;F9O6R=S="==+`T*("`@("`@("`@("`@("`@("`@("`@("=U<FPG
M(#T^("1R96QE87-E:6YF;ULG9R==+`T*("`@("`@("`@("`@("`@("`@("`@
M("=C;VUP871I8FQE)R`]/B`D8V]M<&%T:6)L92D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX-"B`@("`@("`@("`@("`@("!A<G)A
M>2@G=F5R<VEO;B<@/3X@)')E;&5A<V5I;F9O6R=V)UTL#0H@("`@("`@("`@
M("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1R96QE87-E:6YF;ULG<"==6R=?
M8V]N=&5N="==+`T*("`@("`@("`@("`@("`@("`@("`@("=S=&%B:6QI='DG
M(#T^("1R96QE87-E:6YF;ULG<W0G72P-"B`@("`@("`@("`@("`@("`@("`@
M("`G:6YF;R<@/3X@)'!A8VMA9V5X;6PL#0H@("`@("`@("`@("`@("`@("`@
M("`@)V-O;7!A=&EB;&4G(#T^("1C;VUP871I8FQE*3L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&QI<W1086-K86=E<R@D8F%S92D-"B`@
M("![#0H@("`@("`@("1P86-K86=E;&ES="`]("1T:&ES+3Y?<F5S="T^<F5T
M<FEE=F5$871A*"1B87-E("X@)W`O<&%C:V%G97,N>&UL)RD[#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1P86-K86=E;&ES="DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D<&%C:V%G96QI<W0[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D<&%C:V%G96QI<W0I('Q\("%I<W-E="@D<&%C:V%G
M96QI<W1;)W`G72DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?87)R87DH)'!A8VMA9V5L:7-T
M6R=P)UTI*2![#0H@("`@("`@("`@("`D<&%C:V%G96QI<W1;)W`G72`](&%R
M<F%Y*"1P86-K86=E;&ES=%LG<"==*3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)'!A8VMA9V5L:7-T6R=P)UT[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@;&ES=$%L;"@D8F%S92P@)&1O<W1A8FQE+"`D8F%S:6,@/2!T<G5E+"`D
M<V5A<F-H<&%C:V%G92`](&9A;'-E+"`D<V5A<F-H<W5M;6%R>2`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@)'!A8VMA9V5L:7-T(#T@)'1H:7,M/E]R97-T
M+3YR971R:65V941A=&$H)&)A<V4@+B`G<"]P86-K86=E<RYX;6PG*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!A8VMA9V5L:7-T*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1P86-K86=E;&ES=#L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'1H:7,M/E]R97-T+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I
M(#X@,"D@>PT*("`@("`@("`@("`@)'5I(#T@)E!%05)?1G)O;G1E;F0Z.G-I
M;F=L971O;B@I.PT*("`@("`@("`@("`@)'5I+3YL;V<H)U)E=')I979I;F<@
M9&%T82XN+C`E)RP@9F%L<V4I.PT*("`@("`@("!]#0H@("`@("`@("1R970@
M/2!A<G)A>2@I.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P86-K86=E;&ES
M="D@?'P@(6ES<V5T*"1P86-K86=E;&ES=%LG<"==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<&%C:V%G96QI<W1;)W`G72DI('L-"B`@("`@("`@("`@("1P86-K
M86=E;&ES=%LG<"==(#T@87)R87DH)'!A8VMA9V5L:7-T6R=P)UTI.PT*("`@
M("`@("!]#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L-"B`@("`@("`@)&YE>'0@/2`N,3L-"B`@("`@("`@
M9F]R96%C:"`H)'!A8VMA9V5L:7-T6R=P)UT@87,@)'!R;V=R97-S(#T^("1P
M86-K86=E*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]R97-T+3YC;VYF
M:6<M/F=E="@G=F5R8F]S92<I(#X@,"D@>PT*("`@("`@("`@("`@("`@(&EF
M("@D<')O9W)E<W,@+R!C;W5N="@D<&%C:V%G96QI<W1;)W`G72D@/CT@)&YE
M>'0I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1N97AT(#T]("XU*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=6DM/FQO9R@G-3`E)RP@9F%L
M<V4I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'5I+3YL;V<H)RXG+"!F86QS92D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&YE>'0@*ST@
M+C$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1B87-I8RD@>R`O+R!R96UO=&4M;&ES="!C;VUM86YD#0H@
M("`@("`@("`@("`@("`@:68@*"1D;W-T86)L92D@>PT*("`@("`@("`@("`@
M("`@("`@("`D;&%T97-T(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H
M)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)R]S=&%B;&4N='AT)RD[#0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]
M("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@)W(O)R`N('-T
M<G1O;&]W97(H)'!A8VMA9V4I("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("<O;&%T97-T+G1X="<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&%T97-T*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D;&%T97-T(#T@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1I;F9O(#T@87)R87DH)W-T86)L92<@
M/3X@)&QA=&5S="D[#0H@("`@("`@("`@("!](&5L<V4@>R`O+R!L:7-T+6%L
M;"!C;VUM86YD#0H@("`@("`@("`@("`@("`@)&EN9B`]("1T:&ES+3Y?<F5S
M="T^<F5T<FEE=F5$871A*"1B87-E("X@)W`O)R`N('-T<G1O;&]W97(H)'!A
M8VMA9V4I("X@)R]I;F9O+GAM;"<I.PT*("`@("`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1I;F8I*2![#0H@("`@("`@("`@("`@("`@("`@(%!%
M05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1I;F8[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("@D<V5A<F-H<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("`@
M("`D9F]U;F0@/2`H(65M<'1Y*"1S96%R8VAP86-K86=E*2`F)B!S=')I<W1R
M*"1P86-K86=E+"`D<V5A<F-H<&%C:V%G92D@(3T](&9A;'-E*3L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"$D9F]U;F0@)B8@(2AI<W-E="@D<V5A<F-H
M<W5M;6%R>2D@)B8@(65M<'1Y*"1S96%R8VAS=6UM87)Y*0T*("`@("`@("`@
M("`@("`@("`@("`@("`@)B8@*'-T<FES='(H)&EN9ELG<R==+"`D<V5A<F-H
M<W5M;6%R>2D@(3T](&9A;'-E#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?'P@<W1R:7-T<B@D:6YF6R=D)UTL("1S96%R8VAS=6UM87)Y*2`A/3T@
M9F%L<V4I*2D-"B`@("`@("`@("`@("`@("`@("`@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R96QE87-E
M<R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@)W(O)R`N
M('-T<G1O;&]W97(H)'!A8VMA9V4I("X-"B`@("`@("`@("`@("`@("`@("`@
M)R]A;&QR96QE87-E<RYX;6PG*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<F5L96%S97,I*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1R96QE87-E<ULG<B==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S97-;)W(G72`](&%R<F%Y*"1R96QE87-E<ULG
M<B==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@=6YS
M970H)&QA=&5S="D[#0H@("`@("`@("`@("`@("`@=6YS970H)'5N<W1A8FQE
M*3L-"B`@("`@("`@("`@("`@("!U;G-E="@D<W1A8FQE*3L-"B`@("`@("`@
M("`@("`@("!U;G-E="@D<W1A=&4I.PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1R96QE87-E<ULG<B==(&%S("1R96QE87-E*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&QA=&5S="DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D9&]S=&%B;&4@)B8@)')E;&5A<V5;)W,G72`]
M/2`G<W1A8FQE)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L
M871E<W0@/2`D<F5L96%S95LG=B==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S=&%T92`]("=S=&%B;&4G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D9&]S=&%B
M;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@
M)')E;&5A<V5;)W8G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1A=&4@/2`D<F5L96%S95LG<R==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'-T86)L92D@)B8@)')E;&5A<V5;)W,G72`]/2`G
M<W1A8FQE)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-T86)L92`]
M("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1U;G-T86)L92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=6YS=&%B;&4@/2`D<W1A8FQE.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'5N<W1A8FQE*2`F)B`D<F5L96%S95LG<R==
M("$]("=S=&%B;&4G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%T
M97-T(#T@)'5N<W1A8FQE(#T@)')E;&5A<V5;)W8G73L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1S=&%T92`]("1R96QE87-E6R=S)UT[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1L871E<W0I("8F("%I<W-E="@D<W1A=&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1A=&4@/2`D<F5L96%S95LG<R==.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M;&%T97-T*2`F)B!I<W-E="@D<W1A8FQE*2`F)B!I<W-E="@D=6YS=&%B;&4I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=6YS=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1U;G-T
M86)L92`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G
M<W1A8FQE)SL-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1S=&%B
M;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@)'5N
M<W1A8FQE(#T@)'-T86)L93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1L
M871E<W0@/2`D=6YS=&%B;&4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&QA=&5S="DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&QA=&5S="`](&9A;'-E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H)&QA=&5S="D@>PT*("`@("`@("`@("`@
M("`@("`@("`D9"`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5#86-H949I<G-T
M*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)R]D97!S
M+B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`N("<N='AT
M)RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D
M9"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D(#T@=6YS97)I86QI
M>F4H)&0I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=R97%U
M:7)E9"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E1FEL95]V,B<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1P9BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P9B`](&YE=R!014%27U!A8VMA9V5&:6QE
M7W8R.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P9BT^<V5T1&5P<R@D9"D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T9&5P<R`]("1P
M9BT^9V5T1&5P<R@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T9&5P
M<R`]("1D.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&1E<',@87,@)&1E
M<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E
M<%LG='EP92==("$]/2`G<&MG)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<'-;72`]("1D97`[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'-T86)L92DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'-T86)L92`]("<M;B]A+2<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@A)'-E87)C:'!A8VMA9V4I('L-"B`@("`@("`@("`@
M("`@("`@("`@)&EN9F\@/2!A<G)A>2@G<W1A8FQE)R`]/B`D;&%T97-T+"`G
M<W5M;6%R>2<@/3X@)&EN9ELG<R==+"`G9&5S8W)I<'1I;VXG(#T^#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF6R=D)UTL("=D97!S)R`]/B`D9&5P
M<RP@)V-A=&5G;W)Y)R`]/B`D:6YF6R=C82==6R=?8V]N=&5N="==+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)W5N<W1A8FQE)R`]/B`D=6YS=&%B;&4L
M("=S=&%T92<@/3X@)'-T871E*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=S=&%B;&4G
M(#T^("1S=&%B;&4L("=S=6UM87)Y)R`]/B`D:6YF6R=S)UTL("=D97-C<FEP
M=&EO;B<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9;)V0G72P@
M)V1E<',G(#T^("1D97!S+"`G8V%T96=O<GDG(#T^("1I;F9;)V-A)UU;)U]C
M;VYT96YT)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`G=6YS=&%B;&4G
M(#T^("1U;G-T86)L92P@)W-T871E)R`]/B`D<W1A=&4I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R971;)'!A
M8VMA9V5=(#T@)&EN9F\[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!L:7-T3&%T97-T57!G<F%D97,H)&)A<V4L("1S
M=&%T92P@)&EN<W1A;&QE9"P@)&-H86YN96PL("8D<F5G*0T*("`@('L-"B`@
M("`@("`@)'!A8VMA9V5L:7-T(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A
M=&$H)&)A<V4@+B`G<"]P86-K86=E<RYX;6PG*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)'!A8VMA9V5L:7-T*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1P86-K86=E;&ES=#L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@
M87)R87DH*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G96QI<W0I
M('Q\("%I<W-E="@D<&%C:V%G96QI<W1;)W`G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?87)R
M87DH)'!A8VMA9V5L:7-T6R=P)UTI*2![#0H@("`@("`@("`@("`D<&%C:V%G
M96QI<W1;)W`G72`](&%R<F%Y*"1P86-K86=E;&ES=%LG<"==*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'-T871E*2![#0H@("`@("`@("`@("`D<W1A
M=&5S(#T@)'1H:7,M/F)E='1E<E-T871E<R@D<W1A=&4L('1R=64I.PT*("`@
M("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1P86-K86=E;&ES=%LG<"==(&%S
M("1P86-K86=E*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86QL
M961;<W1R=&]L;W=E<B@D<&%C:V%G92E=*2D@>PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&EN<W1?
M=F5R<VEO;B`]("1R96<M/G!A8VMA9V5);F9O*"1P86-K86=E+"`G=F5R<VEO
M;B<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1I;F9O
M(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@+B`G<B\G("X@
M<W1R=&]L;W=E<B@D<&%C:V%G92D@+@T*("`@("`@("`@("`@("`@("<O86QL
M<F5L96%S97,N>&UL)RD[#0H@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF
M;RDI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L@+R\@;F\@<F5M;W1E
M(')E;&5A<V5S#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1I;F9O6R=R)UTI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9F]U;F0@/2!F86QS93L-
M"B`@("`@("`@("`@("1R96QE87-E(#T@9F%L<V4[#0H@("`@("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1I;F9O6R=R)UTI('Q\("%I<W-E="@D:6YF;ULG<B==
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=R)UT@/2!A<G)A>2@D
M:6YF;ULG<B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1I;F9O6R=R)UT@87,@)')E;&5A<V4I('L-"B`@("`@("`@("`@("`@
M("!I9B`H)&EN<W1?=F5R<VEO;B`F)B!V97)S:6]N7V-O;7!A<F4H)')E;&5A
M<V5;)W8G72P@)&EN<W1?=F5R<VEO;BP@)SP])RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@D<W1A=&4I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&EN7V%R<F%Y*"1R96QE87-E6R=S)UTL("1S=&%T97,I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H(21F;W5N9"D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E;&EN9F\@/2`D=&AI<RT^
M7W)E<W0M/G)E=')I979E0V%C:&5&:7)S="@D8F%S92`N("=R+R<@+B!S=')T
M;VQO=V5R*"1P86-K86=E*2`N("<O)R`N(`T*("`@("`@("`@("`@("`@("1R
M96QE87-E6R=V)UT@+B`G+GAM;"<I.PT*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)')E;&EN9F\I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1R96QI;F9O.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E=%LD
M<&%C:V%G95T@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W9E<G-I
M;VXG(#T^("1R96QE87-E6R=V)UTL#0H@("`@("`@("`@("`@("`@("`@("=S
M=&%T92<@/3X@)')E;&5A<V5;)W,G72P-"B`@("`@("`@("`@("`@("`@("`@
M)V9I;&5S:7IE)R`]/B`D<F5L:6YF;ULG9B==+`T*("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@<&%C:V%G94EN9F\H)&)A<V4L("1P86-K86=E*0T*
M("`@('L-"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PT*("`@("`@("`D<&EN9F\@/2`D=&AI<RT^7W)E<W0M
M/G)E=')I979E1&%T82@D8F%S92`N("=P+R<@+B!S=')T;VQO=V5R*"1P86-K
M86=E*2`N("<O:6YF;RYX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'!I;F9O*2D@>PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U5N:VYO=VX@<&%C:V%G93H@(B<@+B`D<&%C:V%G92`N("<B("A$96)U9SH@
M)R`N#0H@("`@("`@("`@("`@("`@)'!I;F9O+3YG971-97-S86=E*"D@+B`G
M*2<I.PT*("`@("`@("!]#0H@("`@("`@("1R96QE87-E<R`](&%R<F%Y*"D[
M#0H@("`@("`@("1A;&QR96QE87-E<R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE
M=F5$871A*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X-
M"B`@("`@("`@("`@("<O86QL<F5L96%S97,N>&UL)RD[#0H@("`@("`@(&EF
M("@A4$5!4CHZ:7-%<G)O<B@D86QL<F5L96%S97,I*2![#0H@("`@("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E1FEL95]V,B<I*2![
M#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&
M:6QE+W8R+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1A;&QR96QE87-E<ULG<B==*2D@>PT*("`@("`@("`@("`@
M("`@("1A;&QR96QE87-E<ULG<B==(#T@87)R87DH)&%L;')E;&5A<V5S6R=R
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!F(#T@;F5W(%!%
M05)?4&%C:V%G949I;&5?=C([#0H@("`@("`@("`@("!F;W)E86-H("@D86QL
M<F5L96%S97-;)W(G72!A<R`D<F5L96%S92D@>PT*("`@("`@("`@("`@("`@
M("1D<R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5#86-H949I<G-T*"1B87-E
M("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)R]D97!S+B<@+@T*
M("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LG=B==("X@)RYT>'0G*3L-
M"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9',I*2![#0H@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L871E<W0I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D<F5L96%S95LG=B==.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&8M/G-E=$1E
M<',H=6YS97)I86QI>F4H)&1S*2D[#0H@("`@("`@("`@("`@("`@)&1S(#T@
M)'!F+3YG971$97!S*"D[#0H@("`@("`@("`@("`@("`@)&EN9F\@/2`D=&AI
M<RT^7W)E<W0M/G)E=')I979E0V%C:&5&:7)S="@D8F%S92`N("=R+R<@+B!S
M=')T;VQO=V5R*"1P86-K86=E*0T*("`@("`@("`@("`@("`@("`@("`N("<O
M)R`N("1R96QE87-E6R=V)UT@+B`G+GAM;"<I.PT*("`@("`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)')E;&5A<V5S6R1R96QE87-E6R=V)UU=(#T@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=D;VYE8GDG(#T^("1I;F9O6R=M)UTL#0H@("`@
M("`@("`@("`@("`@("`@("=L:6-E;G-E)R`]/B`D:6YF;ULG;"==+`T*("`@
M("`@("`@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)&EN9F];)W,G72P-"B`@
M("`@("`@("`@("`@("`@("`@)V1E<V-R:7!T:6]N)R`]/B`D:6YF;ULG9"==
M+`T*("`@("`@("`@("`@("`@("`@("`G<F5L96%S961A=&4G(#T^("1I;F9O
M6R=D82==+`T*("`@("`@("`@("`@("`@("`@("`G<F5L96%S96YO=&5S)R`]
M/B`D:6YF;ULG;B==+`T*("`@("`@("`@("`@("`@("`@("`G<W1A=&4G(#T^
M("1R96QE87-E6R=S)UTL#0H@("`@("`@("`@("`@("`@("`@("=D97!S)R`]
M/B`D9',@/R`D9',@.B!A<G)A>2@I+`T*("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M;&%T97-T(#T@)R<[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("!R971U<FX@87)R87DH#0H@("`@("`@
M("`@("`G;F%M92<@/3X@)'!I;F9O6R=N)UTL#0H@("`@("`@("`@("`G8VAA
M;FYE;"<@/3X@)'!I;F9O6R=C)UTL#0H@("`@("`@("`@("`G8V%T96=O<GDG
M(#T^("1P:6YF;ULG8V$G75LG7V-O;G1E;G0G72P-"B`@("`@("`@("`@("=S
M=&%B;&4G(#T^("1L871E<W0L#0H@("`@("`@("`@("`G;&EC96YS92<@/3X@
M)'!I;F9O6R=L)UTL#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)'!I;F9O
M6R=S)UTL#0H@("`@("`@("`@("`G9&5S8W)I<'1I;VXG(#T^("1P:6YF;ULG
M9"==+`T*("`@("`@("`@("`@)W)E;&5A<V5S)R`]/B`D<F5L96%S97,L#0H@
M("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R
M;B!A;B!A<G)A>2!C;VYT86EN:6YG(&%L;"!O9B!T:&4@<W1A=&5S('1H870@
M87)E(&UO<F4@<W1A8FQE('1H86X-"B`@("`@*B!O<B!E<75A;"!T;R!T:&4@
M<&%S<V5D(&EN('-T871E#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(%)E;&5A<V4@<W1A=&4-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!$971E<FUI
M;F5S('=H971H97(@=&\@:6YC;'5D92`D<W1A=&4@:6X@=&AE(&QI<W0-"B`@
M("`@*B!`<F5T=7)N(&9A;'-E?&%R<F%Y($9A;'-E(&EF("1S=&%T92!I<R!N
M;W0@82!V86QI9"!R96QE87-E('-T871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@8F5T=&5R4W1A=&5S*"1S=&%T92P@)&EN8VQU9&4@/2!F86QS92D-"B`@
M("![#0H@("`@("`@('-T871I8R`D<W1A=&5S(#T@87)R87DH)W-N87!S:&]T
M)RP@)V1E=F5L)RP@)V%L<&AA)RP@)V)E=&$G+"`G<W1A8FQE)RD[#0H@("`@
M("`@("1I(#T@87)R87E?<V5A<F-H*"1S=&%T92P@)'-T871E<RD[#0H@("`@
M("`@(&EF("@D:2`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&EN8VQU9&4I('L-"B`@
M("`@("`@("`@("1I+2T[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R
M<F%Y7W-L:6-E*"1S=&%T97,L("1I("L@,2D[#0H@("`@?0T*?0T*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]&<F]N=&5N9"\`
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-3<`,#$W-C4R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+T9R;VYT96YD+T-,22YP:'``````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`V-#0P-0`Q,#4Q-30S,3`U-P`P,C$P,#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\J*@T*
M("H@4$5!4E]&<F]N=&5N9%]#3$D-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\
M<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@0TQ)+G!H<"QV(#$N-3D@,C`P-B\P,R\P,B`Q,SHQ-CHQ
M.2!P86IO>64@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL
M86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0HO*BH-"B`J(&)A<V4@8VQA
M<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T9R;VYT96YD+G!H<"<[#0H-
M"B\J*@T*("H@0V]M;6%N9"UL:6YE($9R;VYT96YD(&9O<B!T:&4@4$5!4B!)
M;G-T86QL97(-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE
M=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?1G)O;G1E;F1?0TQ)
M(&5X=&5N9',@4$5!4E]&<F]N=&5N9`T*>PT*("`@("\O('M[>R!P<F]P97)T
M:65S#0H-"B`@("`O*BH-"B`@("`@*B!7:&%T('1Y<&4@;V8@=7-E<B!I;G1E
M<F9A8V4@=&AI<R!F<F]N=&5N9"!I<R!F;W(N#0H@("`@("H@0'9A<B!S=')I
M;F<-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@('9A<B`D
M='EP92`]("=#3$DG.PT*("`@('9A<B`D;'`@/2`G)SL@+R\@;&EN92!P<F5F
M:7@-"@T*("`@('9A<B`D<&%R86US(#T@87)R87DH*3L-"B`@("!V87(@)'1E
M<FT@/2!A<G)A>2@-"B`@("`@("`@)V)O;&0G(#T^("<G+`T*("`@("`@("`G
M;F]R;6%L)R`]/B`G)RP-"B`@("`@("`@*3L-"@T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("!F=6YC=&EO;B!014%27T9R
M;VYT96YD7T-,22@I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05(H*3L-
M"B`@("`@("`@)'1E<FT@/2!G971E;G8H)U1%4DTG*3L@+R\H8V]X*2`D7T5.
M5B!I<R!E;7!T>2!F;W(@;64@:6X@-"XQ+C$-"B`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G<&]S:7A?:7-A='1Y)RD@)B8@(7!O<VEX7VES871T>2@Q
M*2D@>PT*("`@("`@("`@("`@+R\@;W5T<'5T(&ES(&)E:6YG(')E9&ER96-T
M960@=&\@82!F:6QE(&]R('1H<F]U9V@@82!P:7!E#0H@("`@("`@('T@96QS
M96EF("@D=&5R;2D@>PT*("`@("`@("`@("`@+R\@6%A8(&-A;B!U<V4@;F-U
M<G-E<R!E>'1E;G-I;VX@:&5R92P@:68@879A:6QA8FQE#0H@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UXH>'1E<FU\=G0R,C!\;&EN=7@I+R<L("1T
M97)M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YT97)M6R=B;VQD)UT@
M/2!S<')I;G1F*"(E8R5C)6,E8R(L(#(W+"`Y,2P@-#DL(#$P.2D[#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/G1E<FU;)VYO<FUA;"==/7-P<FEN=&8H(B5C
M)6,E8R(L(#(W+"`Y,2P@,3`Y*3L-"B`@("`@("`@("`@('T@96QS96EF("AP
M<F5G7VUA=&-H*"<O7G9T,3`P+R<L("1T97)M*2D@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YT97)M6R=B;VQD)UT@/2!S<')I;G1F*"(E8R5C)6,E8R5C
M)6,B+"`R-RP@.3$L(#0Y+"`Q,#DL(#`L(#`I.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YT97)M6R=N;W)M86PG73US<')I;G1F*"(E8R5C)6,E8R5C(BP@
M,C<L(#DQ+"`Q,#DL(#`L(#`I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V5I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@+R\@6%A8(&%D
M9"!!3E-)(&-O9&5S(&AE<F4-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(&1I<W!L87E,:6YE*'1E>'0I#0H-"B`@("!F
M=6YC=&EO;B!D:7-P;&%Y3&EN92@D=&5X="D-"B`@("![#0H@("`@("`@('1R
M:6=G97)?97)R;W(H(E!%05)?1G)O;G1E;F1?0TQ).CID:7-P;&%Y3&EN92!D
M97!R96-A=&5D(BP@15]54T527T524D]2*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?9&ES<&QA>4QI;F4H)'1E>'0I#0H@("`@>PT*("`@("`@("!P<FEN
M="`B)'1H:7,M/FQP)'1E>'1<;B([#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&1I<W!L87DH=&5X="D-"@T*("`@(&9U;F-T:6]N(&1I<W!L
M87DH)'1E>'0I#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%2
M7T9R;VYT96YD7T-,23HZ9&ES<&QA>2!D97!R96-A=&5D(BP@15]54T527T52
M4D]2*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&ES<&QA>2@D=&5X="D-
M"B`@("![#0H@("`@("`@('!R:6YT("1T97AT.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D:7-P;&%Y17)R;W(H96]B:BD-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!O8FIE8W0@4$5!4E]%<G)O<B!O8FIE8W0-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!D:7-P;&%Y17)R;W(H)&5O8FHI#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7-P;&%Y3&EN92@D96]B:BT^
M9V5T365S<V%G92@I*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9&ES<&QA>49A=&%L17)R;W(H96]B:BD-"@T*("`@("\J*@T*("`@("`J
M($!P87)A;2!O8FIE8W0@4$5!4E]%<G)O<B!O8FIE8W0-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!D:7-P;&%Y1F%T86Q%<G)O<B@D96]B:BD-"B`@("![#0H@
M("`@("`@("1T:&ES+3YD:7-P;&%Y17)R;W(H)&5O8FHI.PT*("`@("`@("!I
M9B`H8VQA<W-?97AI<W1S*"=014%27T-O;F9I9R<I*2![#0H@("`@("`@("`@
M("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH*3L-"B`@("`@
M("`@("`@(&EF("@D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#4I('L-"B`@
M("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]P<FEN
M=%]B86-K=')A8V4G*2D@>PT*("`@("`@("`@("`@("`@("`@("!D96)U9U]P
M<FEN=%]B86-K=')A8V4H*3L-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B86-K=')A8V4G*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L-"B`@
M("`@("`@("`@("`@("`@("`@)')A:7-E9"`](&9A;'-E.PT*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=')A8V4@87,@)&D@/3X@)&9R86UE*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21R86ES960I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9R86UE6R=C
M;&%S<R==*2`F)B!S=')T;VQO=V5R*"1F<F%M95LG8VQA<W,G72D@/3T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&5A<B<@)B8@<W1R
M=&]L;W=E<B@D9G)A;65;)V9U;F-T:6]N)UTI(#T]("=R86ES965R<F]R)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F%I<V5D(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!`)'1H:7,M/E]D
M:7-P;&%Y3&EN92@B(R1I.B`D9G)A;65;8VQA<W-=)&9R86UE6W1Y<&5=)&9R
M86UE6V9U;F-T:6]N72`D9G)A;65;;&EN95TB*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!E>&ET*#$I.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!D:7-P;&%Y2&5A9&EN9RAT:71L92D-"@T*("`@(&9U
M;F-T:6]N(&1I<W!L87E(96%D:6YG*"1T:71L92D-"B`@("![#0H@("`@("`@
M('1R:6=G97)?97)R;W(H(E!%05)?1G)O;G1E;F1?0TQ).CID:7-P;&%Y2&5A
M9&EN9R!D97!R96-A=&5D(BP@15]54T527T524D]2*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?9&ES<&QA>4AE861I;F<H)'1I=&QE*0T*("`@('L-"B`@
M("`@("`@<')I;G0@)'1H:7,M/FQP+B1T:&ES+3YB;VQD*"1T:71L92DN(EQN
M(CL-"B`@("`@("`@<')I;G0@)'1H:7,M/FQP+G-T<E]R97!E870H(CTB+"!S
M=')L96XH)'1I=&QE*2DN(EQN(CL-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*
M("`@("\J*@T*("`@("`J($EN<W1R=6-T('1H92!R=6Y);G-T86QL4V-R:7!T
M(&UE=&AO9"!T;R!S:VEP(&$@<&%R86UG<F]U<"!T:&%T(&UA=&-H97,@=&AE
M#0H@("`@("H@:60@=F%L=64@<&%S<V5D(&EN+@T*("`@("`J#0H@("`@("H@
M5&AI<R!M971H;V0@:7,@=7-E9G5L(&9O<B!D>6YA;6EC86QL>2!C;VYF:6=U
M<FEN9R!W:&EC:"!S96-T:6]N<R!O9B!A('!O<W0M:6YS=&%L;"!S8W)I<'0-
M"B`@("`@*B!W:6QL(&)E(')U;B!B87-E9"!O;B!T:&4@=7-E<B=S('-E='5P
M+"!W:&EC:"!I<R!V97)Y('5S969U;"!F;W(@;6%K:6YG(&9L97AI8FQE#0H@
M("`@("H@<&]S="UI;G-T86QL('-C<FEP=',@=VET:&]U="!L;W-I;F<@=&AE
M(&-R;W-S+49R;VYT96YD(&%B:6QI='D@=&\@<F5T<FEE=F4@=7-E<B!I;G!U
M=`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S:VEP4&%R86UG<F]U<"@D:60I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-K:7!396-T:6]N<ULD:61=(#T@=')U93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!R=6Y0;W-T:6YS=&%L;%-C<FEP=',H)B1S8W)I<'1S*0T*("`@('L-
M"B`@("`@("`@9F]R96%C:"`H)'-C<FEP=',@87,@)&D@/3X@)'-C<FEP="D@
M>PT*("`@("`@("`@("`@)'1H:7,M/G)U;DEN<W1A;&Q38W)I<'0H)'-C<FEP
M='-;)&E=+3Y?<&%R86US+"`D<V-R:7!T<ULD:5TM/E]O8FHI.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y("1X
M;6P@8V]N=&5N=',@;V8@<&]S=&EN<W1A;&QS8W)I<'0@=&%G#0H@("`@("H@
M0'!A<F%M(&]B:F5C="`D<V-R:7!T('!O<W0M:6YS=&%L;&%T:6]N('-C<FEP
M=`T*("`@("`J($!P87)A;2!S=')I;F<@:6YS=&%L;'QU<&=R861E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<G5N26YS=&%L;%-C<FEP="@D>&UL+"`F)'-C
M<FEP="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<VMI<%-E8W1I;VYS(#T@
M87)R87DH*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D>&UL*2!\?"`A:7-S
M970H)'AM;%LG<&%R86UG<F]U<"==*2D@>PT*("`@("`@("`@("`@)'-C<FEP
M="T^<G5N*&%R<F%Y*"DL("=?9&5F875L="<I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&-O;7!L971E9%!H87-E<R`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1X;6Q;)W!A<F%M9W)O=7`G75LP72DI
M('L-"B`@("`@("`@("`@("`@("`D>&UL6R=P87)A;6=R;W5P)UT@/2!A<G)A
M>2@D>&UL6R=P87)A;6=R;W5P)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9F]R96%C:"`H)'AM;%LG<&%R86UG<F]U<"==(&%S("1G<F]U<"D@
M>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-K:7!396-T
M:6]N<ULD9W)O=7!;)VED)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`O
M+R!T:&4@<&]S="UI;G-T86QL('-C<FEP="!C:&]S92!T;R!S:VEP('1H:7,@
M<V5C=&EO;B!D>6YA;6EC86QL>0T*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1G<F]U<%LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<&%R86UN86UE(#T@97AP;&]D92@G.CHG+"`D9W)O=7!;)VYA;64G72D[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;&%S=&=R;W5P6R=I9"==("$]
M("1P87)A;6YA;65;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1G<F]U<%LG;F%M92==(#T@)'!A<F%M;F%M95LQ73L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;G-W97)S*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;G-W97)S6R1G<F]U<%LG
M;F%M92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=VET
M8V@@*"1G<F]U<%LG8V]N9&ET:6]N='EP92==*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)STG(#H-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D86YS=V5R<ULD9W)O=7!;)VYA
M;64G75T@(3T@)&=R;W5P6R=V86QU92==*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)R$])R`Z#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&%N<W=E<G-;)&=R;W5P6R=N86UE)UU=
M(#T]("1G<F]U<%LG=F%L=64G72D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("=P<F5G7VUA=&-H)R`Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(4!P<F5G7VUA=&-H*"<O)R`N("1G
M<F]U<%LG=F%L=64G72`N("<O)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A;G-W97)S6R1G<F]U<%LG;F%M92==72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5F875L="`Z#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;CL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&QA<W1G
M<F]U<"`]("1G<F]U<#L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=R
M;W5P6R=I;G-T<G5C=&EO;G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D:7-P;&%Y*"1G<F]U<%LG:6YS=')U8W1I;VYS)UTI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1G
M<F]U<%LG<&%R86TG75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&=R
M;W5P6R=P87)A;2==(#T@87)R87DH)&=R;W5P6R=P87)A;2==*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G<F]U
M<%LG<&%R86TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&UE=&AO
M9%]E>&ES=',H)'-C<FEP="P@)W!O<W10<F]C97-S4')O;7!T<R<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<')O;7!T<R`]("1S8W)I<'0M/G!O
M<W10<F]C97-S4')O;7!T<R@D9W)O=7!;)W!A<F%M)UTL("1G<F]U<%LG:60G
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P
M<F]M<'1S*2!\?"!C;W5N="@D<')O;7!T<RD@(3T@8V]U;G0H)&=R;W5P6R=P
M87)A;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YO=71P=71$871A*"=P;W-T:6YS=&%L;"<L("=%<G)O<CH@<&]S="UI;G-T
M86QL('-C<FEP="!D:60@;F]T("<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5T=7)N('!R;W!E<B!P;W-T+7!R;V-E<W-E9"!P<F]M
M<'1S)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R;VUP=',@
M/2`D9W)O=7!;)W!A<F%M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1P<F]M<'1S(&%S("1I(#T^("1V87(I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%R*2!\?"`A:7-S970H
M)'9A<ELG<')O;7!T)UTI('Q\#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("%I<W-E="@D=F%R6R=N86UE)UTI('Q\#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D=F%R6R=N86UE)UT@
M(3T@)&=R;W5P6R=P87)A;2==6R1I75LG;F%M92==*2!\?`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H)'9A<ELG='EP92==("$]
M("1G<F]U<%LG<&%R86TG75LD:5U;)W1Y<&4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YO=71P=71$871A*"=P
M;W-T:6YS=&%L;"<L("=%<G)O<CH@<&]S="UI;G-T86QL('-C<FEP="`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6]D
M:69I960@=&AE('9A<FEA8FQE<R!O<B!P<F]M<'1S+"!S979E<F4@<V5C=7)I
M='D@<FES:RX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)U=I;&P@:6YS=&5A9"!U<V4@=&AE(&1E9F%U;'1S(&9R;VT@
M=&AE('!A8VMA9V4N>&UL)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<')O;7!T<R`]("1G<F]U<%LG<&%R86TG73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1A;G-W97)S(#T@)'1H:7,M/F-O;F9I
M<FU$:6%L;V<H)'!R;VUP=',I.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%N<W=E<G,@/2`D=&AI
M<RT^8V]N9FER;41I86QO9R@D9W)O=7!;)W!A<F%M)UTI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("@H:7-S970H)&%N<W=E<G,I("8F("1A;G-W97)S*2!\?"`A:7-S
M970H)&=R;W5P6R=P87)A;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1A;G-W97)S*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&%N<W=E<G,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&-O;7!L971E
M9%!H87-E<RP@)&=R;W5P6R=I9"==*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"$D<V-R:7!T+3YR=6XH)&%N<W=E<G,L("1G<F]U<%LG:60G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S8W)I<'0M/G)U;B@D8V]M<&QE
M=&5D4&AA<V5S+"`G7W5N9&]/;D5R<F]R)RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D<V-R
M:7!T+3YR=6XH)&-O;7!L971E9%!H87-E<RP@)U]U;F1O3VY%<G)O<B<I.PT*
M("`@("`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@07-K(&9O<B!U<V5R(&EN<'5T+"!C;VYF:7)M('1H92!A;G-W
M97)S(&%N9"!C;VYT:6YU92!U;G1I;"!T:&4@=7-E<B!I<R!S871I<V9I960-
M"B`@("`@*B!`<&%R86T@87)R87D@86X@87)R87D@;V8@87)R87ES+"!F;W)M
M870@87)R87DH)VYA;64G(#T^("=P87)A;6YA;64G+"`G<')O;7!T)R`]/@T*
M("`@("`J("`@("`@("`@("`@("`G=&5X="!T;R!D:7-P;&%Y)RP@)W1Y<&4G
M(#T^("=S=')I;F<G6RP@9&5F875L="`]/B`G9&5F875L="!V86QU92==*0T*
M("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C
M;VYF:7)M1&EA;&]G*"1P87)A;7,I#0H@("`@>PT*("`@("`@("`D86YS=V5R
M<R`](&%R<F%Y*"D[#0H@("`@("`@("1P<F]M<'1S(#T@)'1Y<&5S(#T@87)R
M87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86TI('L-
M"B`@("`@("`@("`@("1P<F]M<'1S6R1P87)A;5LG;F%M92==72`]("1P87)A
M;5LG<')O;7!T)UT[#0H@("`@("`@("`@("`D='EP97-;)'!A<F%M6R=N86UE
M)UU=(#T@)'!A<F%M6R=T>7!E)UT[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'!A<F%M6R=D969A=6QT)UTI*2![#0H@("`@("`@("`@("`@("`@)&%N<W=E
M<G-;)'!A<F%M6R=N86UE)UU=(#T@)'!A<F%M6R=D969A=6QT)UT[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1A;G-W97)S6R1P
M87)A;5LG;F%M92==72`]("<G.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&1O('L-"B`@("`@("`@("`@("1O:R`](&%R<F%Y*"=Y97-N
M;R<@/3X@)VYO)RD[#0H@("`@("`@("`@("!D;R![#0H@("`@("`@("`@("`@
M("`@)&%N<W=E<G,@/2`D=&AI<RT^=7-E<D1I86QO9R@G)RP@)'!R;VUP=',L
M("1T>7!E<RP@)&%N<W=E<G,I.PT*("`@("`@("`@("`@?2!W:&EL92`H8V]U
M;G0H87)R87E?9FEL=&5R*"1A;G-W97)S*2D@(3T@8V]U;G0H)'!R;VUP=',I
M*3L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=71$871A*"=9;W5R(&-H;VEC
M97,Z)RD[#0H@("`@("`@("`@("!F;W)E86-H("@D<')O;7!T<R!A<R`D;F%M
M92`]/B`D<')O;7!T*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U='!U
M=$1A=&$H)'!R;VUP="`N("<Z("<@+B`D86YS=V5R<ULD;F%M95TI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&]K(#T@)'1H:7,M/G5S97)$:6%L
M;V<H)R<L#0H@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=Y97-N;R<@/3X@)U1H97-E($-H;VEC97,@3TL_("AU<V4@(F%B
M;W)T(B!T;R!H86QT*2<-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G>65S;F\G(#T^
M("=S=')I;F<G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=Y97-N;R<@/3X@)WEE
M<R<-"B`@("`@("`@("`@("`@("`I#0H@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@:68@*"1O:ULG>65S;F\G72`]/2`G86)O<G0G*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]('=H:6QE("@D;VM;)WEE<VYO)UT@(3T@)WEE<R<I.PT*("`@("`@("!R
M971U<FX@)&%N<W=E<G,[#0H@("`@?0T*("`@("\O('M[>R!U<V5R1&EA;&]G
M*'!R;VUP="P@6W1Y<&5=+"!;9&5F875L=%TI#0H-"B`@("!F=6YC=&EO;B!U
M<V5R1&EA;&]G*"1C;VUM86YD+"`D<')O;7!T<RP@)'1Y<&5S(#T@87)R87DH
M*2P@)&1E9F%U;'1S(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@("1R97-U
M;'0@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-?87)R87DH)'!R;VUP=',I
M*2![#0H@("`@("`@("`@("`O+R!P:'`@-2XP+C`@:6YE>'!L:6-A8FQY(&)R
M96%K<R!"0R!W:71H('1H:7,@8F5H879I;W(-"B`@("`@("`@("`@("\O(&YO
M=R!R96%D:6YG(&9R;VT@4U1$24X@:7,@=&AE(&EN=&5N9&5D('-Y;G1A>`T*
M("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL
M("<U+C`N,"<L("<\)RDI('L-"B`@("`@("`@("`@("`@("`D9G`@/2!F;W!E
M;B@B<&AP.B\O<W1D:6XB+"`B<B(I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9F]R96%C:"`H)'!R;VUP=',@87,@)&ME>2`]/B`D<')O;7!T*2![
M#0H@("`@("`@("`@("`@("`@)'1Y<&4@/2`D='EP97-;)&ME>5T[#0H@("`@
M("`@("`@("`@("`@)&1E9F%U;'0@/2!`)&1E9F%U;'1S6R1K97E=.PT*("`@
M("`@("`@("`@("`@(&EF("@D='EP92`]/2`G<&%S<W=O<F0G*2![#0H@("`@
M("`@("`@("`@("`@("`@('-Y<W1E;2@G<W1T>2`M96-H;R<I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!P<FEN="`B)'1H:7,M/FQP
M)'!R;VUP="`B.PT*("`@("`@("`@("`@("`@(&EF("@D9&5F875L="D@>PT*
M("`@("`@("`@("`@("`@("`@("!P<FEN="`B6R1D969A=6QT72`B.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!P<FEN="`B.B`B.PT*
M("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO
M;B@I+"`G-2XP+C`G+"`G/"<I*2![#0H@("`@("`@("`@("`@("`@("`@("1L
M:6YE(#T@9F=E=',H)&9P+"`R,#0X*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(61E9FEN960H)U-41$E.
M)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&1E9FEN92@G4U1$24XG
M+"!F;W!E;B@G<&AP.B\O<W1D:6XG+"`G<B<I*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;&EN92`](&9G971S*%-4
M1$E.+"`R,#0X*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*"1T>7!E(#T]("=P87-S=V]R9"<I('L-"B`@("`@("`@("`@("`@
M("`@("`@<WES=&5M*"=S='1Y(&5C:&\G*3L-"B`@("`@("`@("`@("`@("`@
M("`@<')I;G0@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1D969A=6QT("8F('1R:6TH)&QI;F4I(#T]("(B*2![#0H@
M("`@("`@("`@("`@("`@("`@("1R97-U;'1;)&ME>5T@/2`D9&5F875L=#L-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT6R1K97E=(#T@=')I;2@D;&EN92D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'9E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C`N,"<L("<\)RDI('L-"B`@("`@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)')E<W5L=#L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@=7-E<D-O;F9I<FTH<')O;7!T+"!;9&5F875L
M=%TI#0H-"B`@("!F=6YC=&EO;B!U<V5R0V]N9FER;2@D<')O;7!T+"`D9&5F
M875L="`]("=Y97,G*0T*("`@('L-"B`@("`@("`@=')I9V=E<E]E<G)O<B@B
M4$5!4E]&<F]N=&5N9%]#3$DZ.G5S97)#;VYF:7)M(&YO="!Y970@8V]N=F5R
M=&5D(BP@15]54T527T524D]2*3L-"B`@("`@("`@<W1A=&EC("1P;W-I=&EV
M97,@/2!A<G)A>2@G>2<L("=Y97,G+"`G;VXG+"`G,2<I.PT*("`@("`@("!S
M=&%T:6,@)&YE9V%T:79E<R`](&%R<F%Y*"=N)RP@)VYO)RP@)V]F9B<L("<P
M)RD[#0H@("`@("`@('!R:6YT("(D=&AI<RT^;'`D<')O;7!T(%LD9&5F875L
M=%T@.B`B.PT*("`@("`@("`D9G`@/2!F;W!E;B@B<&AP.B\O<W1D:6XB+"`B
M<B(I.PT*("`@("`@("`D;&EN92`](&9G971S*"1F<"P@,C`T."D[#0H@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`D86YS=V5R(#T@<W1R=&]L;W=E
M<BAT<FEM*"1L:6YE*2D[#0H@("`@("`@(&EF("AE;7!T>2@D86YS=V5R*2D@
M>PT*("`@("`@("`@("`@)&%N<W=E<B`]("1D969A=6QT.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI;E]A<G)A>2@D86YS=V5R+"`D<&]S:71I=F5S*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&EN7V%R<F%Y*"1A;G-W97(L("1N96=A=&EV97,I*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&EN7V%R<F%Y*"1D969A=6QT+"`D<&]S:71I=F5S*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!S=&%R=%1A
M8FQE*%MP87)A;7-=*0T*#0H@("`@9G5N8W1I;VX@<W1A<G1486)L92@D<&%R
M86US(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R;W(H
M(E!%05)?1G)O;G1E;F1?0TQ).CIS=&%R=%1A8FQE(&1E<')E8V%T960B+"!%
M7U5315)?15)23U(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]S=&%R=%1A
M8FQE*"1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'!A<F%M
M<ULG=&%B;&5?9&%T82==(#T@87)R87DH*3L-"B`@("`@("`@)'!A<F%M<ULG
M=VED97-T)UT@/2!A<G)A>2@I.R`@+R\@:6YD97AE9"!B>2!C;VQU;6X-"B`@
M("`@("`@)'!A<F%M<ULG:&EG:&5S="==(#T@87)R87DH*3L@+R\@:6YD97AE
M9"!B>2!R;W<-"B`@("`@("`@)'!A<F%M<ULG;F-O;',G72`](#`[#0H@("`@
M("`@("1T:&ES+3YP87)A;7,@/2`D<&%R86US.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!T86)L95)O=RAC;VQU;6YS+"!;<F]W<&%R86US
M72P@6V-O;'!A<F%M<UTI#0H-"B`@("!F=6YC=&EO;B!T86)L95)O=R@D8V]L
M=6UN<RP@)')O=W!A<F%M<R`](&%R<F%Y*"DL("1C;VQP87)A;7,@/2!A<G)A
M>2@I*0T*("`@('L-"B`@("`@("`@=')I9V=E<E]E<G)O<B@B4$5!4E]&<F]N
M=&5N9%]#3$DZ.G1A8FQE4F]W(&1E<')E8V%T960B+"!%7U5315)?15)23U(I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]T86)L95)O=R@D8V]L=6UN<RP@
M)')O=W!A<F%M<R`](&%R<F%Y*"DL("1C;VQP87)A;7,@/2!A<G)A>2@I*0T*
M("`@('L-"B`@("`@("`@)&AI9VAE<W0@/2`Q.PT*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!S:7IE;V8H)&-O;'5M;G,I.R`D:2LK*2![#0H@("`@("`@
M("`@("`D8V]L(#T@)B1C;VQU;6YS6R1I73L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D8V]L<&%R86US6R1I72D@)B8@(65M<'1Y*"1C;VQP87)A;7-;)&E=
M6R=W<F%P)UTI*2![#0H@("`@("`@("`@("`@("`@)&-O;"`]('=O<F1W<F%P
M*"1C;VPL("1C;VQP87)A;7-;)&E=6R=W<F%P)UTL(")<;B(L(#`I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-T<G!O<R@D8V]L+"`B7&XB
M*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE(#T@
M97AP;&]D92@B7&XB+"`D8V]L*3L-"B`@("`@("`@("`@("`@("`D=R`](#`[
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UU;'1I;&EN92!A<R`D;B`]
M/B`D;&EN92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1L
M:6YE*2`^("1W*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=R`]('-T
M<FQE;B@D;&EN92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&QI;F5S(#T@<VEZ96]F*"1M
M=6QT:6QI;F4I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D=R`]('-T<FQE;B@D8V]L*3L-"B`@("`@("`@("`@('T-"@T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP87)A;7-;)W=I9&5S="==6R1I
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)'<@/B`D=&AI<RT^<&%R86US
M6R=W:61E<W0G75LD:5TI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G!A<F%M<ULG=VED97-T)UU;)&E=(#T@)'<[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^<&%R86US6R=W:61E<W0G75LD:5T@/2`D=SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T;7`@/2!C;W5N=%]C:&%R<R@D8V]L=6UN<ULD:5TL
M(#$I.PT*("`@("`@("`@("`@+R\@:&%N9&QE('5N:7@L(&UA8R!A;F0@=VEN
M9&]W<R!F;W)M871S#0H@("`@("`@("`@("`D;&EN97,@/2`H:7-S970H)'1M
M<%LQ,%TI(#\@)'1M<%LQ,%T@.B`H:7-S970H)'1M<%LQ,UTI(#\@)'1M<%LQ
M,UT@.B`P*2D@*R`Q.PT*("`@("`@("`@("`@:68@*"1L:6YE<R`^("1H:6=H
M97-T*2![#0H@("`@("`@("`@("`@("`@)&AI9VAE<W0@/2`D;&EN97,[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*'-I>F5O9B@D
M8V]L=6UN<RD@/B`D=&AI<RT^<&%R86US6R=N8V]L<R==*2![#0H@("`@("`@
M("`@("`D=&AI<RT^<&%R86US6R=N8V]L<R==(#T@<VEZ96]F*"1C;VQU;6YS
M*3L-"B`@("`@("`@?0T*("`@("`@("`D;F5W7W)O=R`](&%R<F%Y*`T*("`@
M("`@("`@("`@)V1A=&$G(#T^("1C;VQU;6YS+`T*("`@("`@("`@("`@)VAE
M:6=H="<@/3X@)&AI9VAE<W0L#0H@("`@("`@("`@("`G<F]W<&%R86US)R`]
M/B`D<F]W<&%R86US+`T*("`@("`@("`@("`@)V-O;'!A<F%M<R<@/3X@)&-O
M;'!A<F%M<RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("1T:&ES+3YP87)A
M;7-;)W1A8FQE7V1A=&$G75M=(#T@)&YE=U]R;W<[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&5N9%1A8FQE*"D-"@T*("`@(&9U;F-T:6]N
M(&5N9%1A8FQE*"D-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R;W(H(E!%
M05)?1G)O;G1E;F1?0TQ).CIE;F1486)L92!D97!R96-A=&5D(BP@15]54T52
M7T524D]2*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?96YD5&%B;&4H*0T*
M("`@('L-"B`@("`@("`@97AT<F%C="@D=&AI<RT^<&%R86US*3L-"B`@("`@
M("`@:68@*"%E;7!T>2@D8V%P=&EO;BDI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?9&ES<&QA>4AE861I;F<H)&-A<'1I;VXI.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AC;W5N="@D=&%B;&5?9&%T82D@/3T@,"D@>PT*("`@("`@("`@
M("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'=I
M9'1H*2D@>PT*("`@("`@("`@("`@)'=I9'1H(#T@)'=I9&5S=#L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1N
M8V]L<SL@)&DK*RD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'=I
M9'1H6R1I72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'=I9'1H6R1I72`]
M("1W:61E<W1;)&E=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D8F]R9&5R(#T@9F%L<V4[#0H@("`@
M("`@(&EF("AE;7!T>2@D8F]R9&5R*2D@>PT*("`@("`@("`@("`@)&-E;&QS
M=&%R="`]("<G.PT*("`@("`@("`@("`@)&-E;&QE;F0@/2`G("<[#0H@("`@
M("`@("`@("`D<F]W96YD(#T@)R<[#0H@("`@("`@("`@("`D<&%D<F]W96YD
M(#T@9F%L<V4[#0H@("`@("`@("`@("`D8F]R9&5R;&EN92`]("<G.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-E;&QS=&%R="`]("=\("<[
M#0H@("`@("`@("`@("`D8V5L;&5N9"`]("<@)SL-"B`@("`@("`@("`@("1R
M;W=E;F0@/2`G?"<[#0H@("`@("`@("`@("`D<&%D<F]W96YD(#T@=')U93L-
M"B`@("`@("`@("`@("1B;W)D97)L:6YE(#T@)RLG.PT*("`@("`@("`@("`@
M9F]R96%C:"`H)'=I9'1H(&%S("1W*2![#0H@("`@("`@("`@("`@("`@)&)O
M<F1E<FQI;F4@+CT@<W1R7W)E<&5A="@G+2<L("1W("L@<W1R;&5N*"1C96QL
M<W1A<G0I("L@<W1R;&5N*"1C96QL96YD*2`M(#$I.PT*("`@("`@("`@("`@
M("`@("1B;W)D97)L:6YE("X]("<K)SL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)&)O<F1E<FQI;F4I('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&)O<F1E<FQI;F4I.PT*("`@("`@("!]
M#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&%B;&5?9&%T
M82D[("1I*RLI('L-"B`@("`@("`@("`@(&5X=')A8W0H)'1A8FQE7V1A=&%;
M)&E=*3L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')O=W!A<F%M<RDI
M('L-"B`@("`@("`@("`@("`@("`D<F]W<&%R86US(#T@87)R87DH*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&-O;'!A
M<F%M<RDI('L-"B`@("`@("`@("`@("`@("`D8V]L<&%R86US(#T@87)R87DH
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R;W=L:6YE<R`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("!I9B`H)&AE:6=H="`^(#$I('L-"B`@("`@
M("`@("`@("`@("!F;W(@*"1C(#T@,#L@)&,@/"!S:7IE;V8H)&1A=&$I.R`D
M8RLK*2![#0H@("`@("`@("`@("`@("`@("`@("1R;W=L:6YE<ULD8UT@/2!P
M<F5G7W-P;&ET*"<O*%QR/UQN?%QR*2\G+"`D9&%T85LD8UTI.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1R;W=L:6YE<ULD8UTI(#P@)&AE
M:6=H="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')O=VQI;F5S6R1C
M72`](&%R<F%Y7W!A9"@D<F]W;&EN97-;)&-=+"`D:&5I9VAT+"`G)RD[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&9O<B`H)&,@/2`P
M.R`D8R`\('-I>F5O9B@D9&%T82D[("1C*RLI('L-"B`@("`@("`@("`@("`@
M("`@("`@)')O=VQI;F5S6R1C72`](&%R<F%Y*"1D871A6R1C72D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R
M("@D<B`](#`[("1R(#P@)&AE:6=H=#L@)'(K*RD@>PT*("`@("`@("`@("`@
M("`@("1R;W=T97AT(#T@)R<[#0H@("`@("`@("`@("`@("`@9F]R("@D8R`]
M(#`[("1C(#P@<VEZ96]F*"1D871A*3L@)&,K*RD@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&-O;'!A<F%M<ULD8UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D871T<FEB<R`](&%R<F%Y7VUE<F=E*"1R;W=P
M87)A;7,L("1C;VQP87)A;7,I.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G,@/2`D<F]W
M<&%R86US.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1W(#T@:7-S970H)'=I9'1H6R1C72D@/R`D=VED=&A;)&-=(#H@
M,#L-"B`@("`@("`@("`@("`@("`@("`@+R\D8V5L;"`]("1D871A6R1C73L-
M"B`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2`D<F]W;&EN97-;)&-=6R1R
M73L-"B`@("`@("`@("`@("`@("`@("`@)&P@/2!S=')L96XH)&-E;&PI.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&P@/B`D=RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-E;&P@/2!S=6)S='(H)&-E;&PL(#`L("1W*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&%T=')I8G-;)V)O;&0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1C96QL(#T@)'1H:7,M/F)O;&0H)&-E;&PI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;"`\
M("1W*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!N;W0@=7-I;F<@
M<W1R7W!A9"!H97)E(&)E8V%U<V4@=V4@;6%Y#0H@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!A9&0@8F]L9"!E<V-A<&4@8VAA<F%C=&5R<R!T;R`D8V5L
M;`T*("`@("`@("`@("`@("`@("`@("`@("`@)&-E;&P@+CT@<W1R7W)E<&5A
M="@G("<L("1W("T@)&PI.PT*("`@("`@("`@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@("`@("`@("`@)')O=W1E>'0@+CT@)&-E;&QS=&%R="`N("1C
M96QL("X@)&-E;&QE;F0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@A)&)O<F1E<BD@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F]W=&5X="`](')T<FEM*"1R;W=T97AT*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)')O=W1E>'0@+CT@)')O=V5N9#L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1R;W=T97AT*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&)O<F1E<FQI
M;F4I('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&)O<F1E
M<FQI;F4I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&]U='!U=$1A=&$H*0T*#0H@("`@9G5N8W1I;VX@;W5T<'5T1&%T
M82@D9&%T82P@)&-O;6UA;F0@/2`G7V1E9F%U;'0G*0T*("`@('L-"B`@("`@
M("`@<W=I=&-H("@D8V]M;6%N9"D@>PT*("`@("`@("`@("`@8V%S92`G8VAA
M;FYE;"UI;F9O)SH-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D9&%T82!A
M<R`D='EP92`]/B`D<V5C=&EO;BD@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'1Y<&4@/3T@)VUA:6XG*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<V5C=&EO;ELG9&%T82==(#T@87)R87E?=F%L=65S*"1S96-T:6]N6R=D
M871A)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YO=71P=71$871A*"1S96-T:6]N*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!C87-E("=I;G-T86QL)SH-"B`@("`@("`@("`@(&-A<V4@)W5P9W)A9&4G
M.@T*("`@("`@("`@("`@8V%S92`G=7!G<F%D92UA;&PG.@T*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&%T85LG<F5L96%S95]W87)N:6YG<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"<G
M*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE*&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@9F%L
M<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)U)E
M;&5A<V4@5V%R;FEN9W,G#0H@("`@("`@("`@("`@("`@("`@("`@("`I*3L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=RAA<G)A>2@D
M9&%T85LG<F5L96%S95]W87)N:6YG<R==*2P@;G5L;"P@87)R87DH,2`]/B!A
M<G)A>2@G=W)A<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?96YD5&%B;&4H*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D:7-P;&%Y3&EN92@G)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&1A=&%;)V1A=&$G72D[
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=S
M96%R8V@G.@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A<G1486)L92@D
M9&%T82D[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=H96%D
M;&EN92==*2`F)B!I<U]A<G)A>2@D9&%T85LG:&5A9&QI;F4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=R@D9&%T85LG:&5A
M9&QI;F4G72P@87)R87DH)V)O;&0G(#T^('1R=64I+"!A<G)A>2@Q(#T^(&%R
M<F%Y*"=W<F%P)R`]/B`U-2DI*3L-"B`@("`@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@("`@("!F;W)E86-H*"1D871A6R=D871A)UT@87,@)&-A=&5G
M;W)Y*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&-A=&5G;W)Y
M(&%S("1P:V<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=&%B;&52;W<H)'!K9RP@;G5L;"P@87)R87DH,2`]/B!A<G)A>2@G=W)A<"<@
M/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!].PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?96YD5&%B;&4H*3L-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)VQI
M<W0M86QL)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B;&4H
M)&1A=&$I.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG:&5A
M9&QI;F4G72D@)B8@:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;)VAE
M861L:6YE)UTL(&%R<F%Y*"=B;VQD)R`]/B!T<G5E*2P@87)R87DH,2`]/B!A
M<G)A>2@G=W)A<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@?0T*#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1C871E
M9V]R>2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"1C871E9V]R
M>2!A<R`D<&MG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M<&MG6S1=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P:V=;
M-5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O
M=R@D<&MG+"!N=6QL+"!A<G)A>2@Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`U-2DI
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T[
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E;F1486)L92@I.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G8V]N9FEG+7-H
M;W<G.@T*("`@("`@("`@("`@("`@("1D871A6R=B;W)D97(G72`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH,"`]/B!A<G)A>2@G
M=W)A<"<@/3X@,S`I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,2`]/B!A<G)A>2@G=W)A<"<@/3X@,C`I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@,B`]/B!A<G)A>2@G=W)A<"<@/3X@,S4I*3L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B;&4H)&1A=&$I.PT*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG:&5A9&QI;F4G72D@)B8@:7-?
M87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;)VAE861L:6YE)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O;&0G
M(#T^('1R=64I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1O<'1S*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1G<F]U<"D@>PT*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H*"1G<F]U<"!A<R`D=F%L=64I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=65;,ET@/3T@)R<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;,ET@/2`B/&YO
M="!S970^(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)'9A;'5E+"!N=6QL
M+"`D;W!T<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E;F1486)L92@I.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G<F5M
M;W1E+6EN9F\G.@T*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G4&%C:V%G92!D971A
M:6QS.B<L#0H@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^(&9A;'-E
M+`T*("`@("`@("`@("`@("`@("`@("`G9&%T82<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@B3&%T97-T(BP@("`@)&1A=&%;
M)W-T86)L92==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"))
M;G-T86QL960B+"`D9&%T85LG:6YS=&%L;&5D)UTI+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH(E!A8VMA9V4B+"`@("1D871A6R=N86UE)UTI
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH(DQI8V5N<V4B+"`@
M("1D871A6R=L:6-E;G-E)UTI+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH(D-A=&5G;W)Y(BP@("1D871A6R=C871E9V]R>2==*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*")3=6UM87)Y(BP@("`D9&%T85LG
M<W5M;6%R>2==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*")$
M97-C<FEP=&EO;B(L("1D871A6R=D97-C<FEP=&EO;B==*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("!D969A=6QT.B![#0H@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1D871A*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-T87)T5&%B;&4H)&1A=&$I.PT*("`@("`@("`@("`@("`@("`@("`D8V]U
M;G0@/2!C;W5N="@D9&%T85LG9&%T82==6S!=*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1C;W5N="`]/2`R*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W!T<R`](&%R<F%Y*#`@/3X@87)R87DH)W=R87`G(#T^(#(U*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`]/B!A
M<G)A>2@G=W)A<"<@/3X@-#@I#0H@("`@("`@("`@("`@("`@("`@("`@("`I
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-O=6YT(#T](#,I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH,"`]
M/B!A<G)A>2@G=W)A<"<@/3X@,S`I+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`R,"DL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#(@/3X@87)R
M87DH)W=R87`G(#T^(#,U*0T*("`@("`@("`@("`@("`@("`@("`@("`@*3L-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O<'1S(#T@;G5L;#L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)VAE861L
M:6YE)UTI("8F(&ES7V%R<F%Y*"1D871A6R=H96%D;&EN92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=R@D9&%T85LG
M:&5A9&QI;F4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V)O;&0G(#T^('1R=64I+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T<RD[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D
M9&%T85LG9&%T82==(&%S("1R;W<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=&%B;&52;W<H)')O=RP@;G5L;"P@)&]P=',I.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?96YD5&%B;&4H*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1D871A*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;&]G*'1E>'0I#0H-
M"@T*("`@(&9U;F-T:6]N(&QO9R@D=&5X="P@)&%P<&5N9%]C<FQF(#T@=')U
M92D-"B`@("![#0H@("`@("`@(&EF("@D87!P96YD7V-R;&8I('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1I<W!L87E,:6YE*"1T97AT*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7-P;&%Y*"1T97AT
M*3L-"B`@("!]#0H-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!B;VQD*"1T
M97AT*0T*#0H@("`@9G5N8W1I;VX@8F]L9"@D=&5X="D-"B`@("![#0H@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^=&5R;5LG8F]L9"==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N('-T<G1O=7!P97(H)'1E>'0I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^=&5R;5LG8F]L9"==("X@)'1E>'0@+B`D
M=&AI<RT^=&5R;5LG;F]R;6%L)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]
M#0H-"C\^#0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B\`````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U
M-P`P,C`P,S``(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS
M=&%L;&5R+U)O;&4O````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#4W`#`R,#<S,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]#;VUM;VXN<&AP````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,34R-#0`,3`U,34T,S$P-3<`,#(R-C<U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J($)A<V4@8VQA<W,@9F]R(&%L;"!I;G-T86QL871I;VX@<F]L
M97,N#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%52
M23H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($-O
M;6UO;BYP:'`L=B`Q+C$P(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X
M<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<R!F;W(@
M86QL(&EN<W1A;&QA=&EO;B!R;VQE<RX-"B`J#0H@*B!4:&ES(&-L87-S(&%L
M;&]W<R!E>'1E;G-I8FEL:71Y(&]F(&9I;&4@<F]L97,N("!086-K86=E<R!W
M:71H(&-O;7!L97@-"B`J(&-U<W1O;6EZ871I;VX@8V%N(&YO=R!P<F]V:61E
M(&-U<W1O;2!F:6QE(')O;&5S(&%L;VYG('=I=&@@=&AE('!O<W-I8FEL:71Y
M(&]F#0H@*B!A9&1I;F<@8V]N9FEG=7)A=&EO;B!V86QU97,@=&\@;6%T8V@N
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]);G-T86QL97)?4F]L
M95]#;VUM;VX-"GL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?0V]N9FEG
M#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V87(@
M)&-O;F9I9SL-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!014%27T-O;F9I
M9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?26YS=&%L;&5R7U)O;&5?
M0V]M;6]N*"8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F-O;F9I
M9R`]("1C;VYF:6<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE
M=F4@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!A8F]U="!A(&9I;&4@<F]L
M92!F<F]M(&ET<R!834P@:6YF;PT*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F]L92!2;VQE($-L87-S;F%M92P@87,@:6X@(E!%05)?26YS=&%L
M;&5R7U)O;&5?1&%T82(-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T26YF;R@D<F]L92D-"B`@("![#0H@("`@("`@
M(&EF("AE;7!T>2@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UU;
M)')O;&5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)U5N:VYO=VX@4F]L92!C;&%S<SH@(B<@+B`D<F]L92`N("<B)RD[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E])3E-4
M04Q,15)?4D],15,G75LD<F]L95T[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@5&AI<R!I<R!C86QL960@9F]R(&5A8V@@9FEL92!T;R!S970@=7`@=&AE
M(&1I<F5C=&]R:65S(&%N9"!F:6QE<PT*("`@("`J($!P87)A;2!014%27U!A
M8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R
M86T@87)R87D@871T<FEB=71E<R!F<F]M('1H92`\9FEL93X@=&%G#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y(&%N(&%R<F%Y(&-O;G-I<W1I;F<@;V8Z#0H@("`@("H-"B`@("`@*B`@
M("`Q('1H92!O<FEG:6YA;"P@<')E+6)A<V5I;G-T86QL9&ER(&EN<W1A;&QA
M=&EO;B!D:7)E8W1O<GD-"B`@("`@*B`@("`R('1H92!F:6YA;"!I;G-T86QL
M871I;VX@9&ER96-T;W)Y#0H@("`@("H@("`@,R!T:&4@9G5L;"!P871H('1O
M('1H92!F:6YA;"!L;V-A=&EO;B!O9B!T:&4@9FEL90T*("`@("`J("`@(#0@
M=&AE(&QO8V%T:6]N(&]F('1H92!P<F4M:6YS=&%L;&%T:6]N(&9I;&4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!P<F]C97-S26YS=&%L;&%T:6]N*"1P:V<L
M("1A='1S+"`D9FEL92P@)'1M<%]P871H+"`D;&%Y97(@/2!N=6QL*0T*("`@
M('L-"B`@("`@("`@)')O;&5);F9O(#T@4$5!4E]);G-T86QL97)?4F]L95]#
M;VUM;VXZ.F=E=$EN9F\H)U!%05)?26YS=&%L;&5R7U)O;&5?)R`N(`T*("`@
M("`@("`@("`@=6-F:7)S="AS=')?<F5P;&%C92@G<&5A<E]I;G-T86QL97)?
M<F]L95\G+"`G)RP@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*2DI*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')O;&5);F9O*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1R;VQE26YF;SL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(21R;VQE26YF;ULG;&]C871I;VYC;VYF:6<G72D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<F]L94EN9F];)VAO;F]R<V)A<V5I;G-T86QL)UTI('L-"B`@("`@("`@("`@
M("1D97-T7V1I<B`]("1S879E7V1E<W1D:7(@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)')O;&5);F9O6R=L;V-A=&EO;F-O;F9I9R==+"`D;&%Y97(L#0H@("`@
M("`@("`@("`@("`@)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@
M(&EF("@A96UP='DH)&%T='-;)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@
M("`@("`@("`@("`@)&1E<W1?9&ER("X]($1)4D5#5$]265]315!!4D%43U(@
M+B`D871T<ULG8F%S96EN<W1A;&QD:7(G73L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E:68@*"1R;VQE26YF;ULG=6YU<W5A;&)A<V5I;G-T86QL
M)UTI('L-"B`@("`@("`@("`@("1D97-T7V1I<B`]("1S879E7V1E<W1D:7(@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)')O;&5);F9O6R=L;V-A=&EO;F-O;F9I
M9R==+`T*("`@("`@("`@("`@("`@("`@("!N=6QL+"`D<&MG+3YG971#:&%N
M;F5L*"DI("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V<M/F=E=%!A8VMA
M9V4H*3L-"B`@("`@("`@("`@(&EF("@A96UP='DH)&%T='-;)V)A<V5I;G-T
M86QL9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<W1?9&ER("X]($1)
M4D5#5$]265]315!!4D%43U(@+B`D871T<ULG8F%S96EN<W1A;&QD:7(G73L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1D97-T7V1I<B`]("1S879E7V1E<W1D:7(@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)')O;&5);F9O6R=L;V-A=&EO;F-O;F9I9R==+`T*("`@("`@("`@("`@
M("`@("`@("!N=6QL+"`D<&MG+3YG971#:&%N;F5L*"DI("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1P:V<M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H9&ER;F%M92@D9FEL92D@(3T@)RXG("8F(&5M<'1Y*"1A
M='1S6R=I;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D9&5S=%]D:7(@
M+CT@1$E214-43U)97U-%4$%2051/4B`N(&1I<FYA;64H)&9I;&4I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D871T<ULG:6YS=&%L;"UA<R==
M*2D@>PT*("`@("`@("`@("`@)&1E<W1?9FEL92`]("1D97-T7V1I<B`N($1)
M4D5#5$]265]315!!4D%43U(@+B!B87-E;F%M92@D9FEL92D[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D9&5S=%]F:6QE(#T@)&1E<W1?9&ER
M("X@1$E214-43U)97U-%4$%2051/4B`N("1A='1S6R=I;G-T86QL+6%S)UT[
M#0H@("`@("`@('T-"B`@("`@("`@)&]R:6=?9FEL92`]("1T;7!?<&%T:"`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL93L-"@T*("`@("`@("`O+R!#
M;&5A;B!U<"!T:&4@1$E214-43U)97U-%4$%2051/4B!M97-S#0H@("`@("`@
M("1D<S(@/2!$25)%0U1/4EE?4T5005)!5$]2("X@1$E214-43U)97U-%4$%2
M051/4CL-"B`@("`@("`@#0H@("`@("`@(&QI<W0H)&1E<W1?9&ER+"`D9&5S
M=%]F:6QE+"`D;W)I9U]F:6QE*2`]('!R96=?<F5P;&%C92AA<G)A>2@G(5Q<
M7%PK(2<L("<A+R$G+"`B(21D<S(K(2(I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*$1)4D5#
M5$]265]315!!4D%43U(L($1)4D5#5$]265]315!!4D%43U(L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1$E214-43U)97U-%4$%2051/4BDL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&1E
M<W1?9&ER+"`D9&5S=%]F:6QE+"`D;W)I9U]F:6QE*2D[#0H@("`@("`@(')E
M='5R;B!A<G)A>2@D<V%V95]D97-T9&ER+"`D9&5S=%]D:7(L("1D97-T7V9I
M;&4L("1O<FEG7V9I;&4I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E
M="!T:&4@;F%M92!O9B!T:&4@8V]N9FEG=7)A=&EO;B!V87)I86)L92!T:&%T
M('-P96-I9FEE<R!T:&4@;&]C871I;VX@;V8@=&AI<R!F:6QE#0H@("`@("H@
M0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971,;V-A=&EO;D-O;F9I9R@I#0H@("`@>PT*("`@("`@("`D<F]L94EN9F\@
M/2!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;CHZ9V5T26YF;R@G4$5!4E])
M;G-T86QL97)?4F]L95\G("X@#0H@("`@("`@("`@("!U8V9I<G-T*'-T<E]R
M97!L86-E*"=P96%R7VEN<W1A;&QE<E]R;VQE7R<L("<G+"!S=')T;VQO=V5R
M*&=E=%]C;&%S<R@D=&AI<RDI*2DI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F]L94EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)')O;&5)
M;F9O.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F]L94EN9F];)VQO
M8V%T:6]N8V]N9FEG)UT[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1&\@
M86YY('5N=7-U86P@<V5T=7`@:&5R90T*("`@("`J($!P87)A;2!014%27TEN
M<W1A;&QE<@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8R#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(&9I;&4@871T<FEB=71E<PT*("`@("`J($!P
M87)A;2!S=')I;F<@9FEL92!N86UE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M<V5T=7`H)B1I;G-T86QL97(L("1P:V<L("1A='1S+"`D9FEL92D-"B`@("![
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-%>&5C=71A8FQE*"D-"B`@("![
M#0H@("`@("`@("1R;VQE26YF;R`](%!%05)?26YS=&%L;&5R7U)O;&5?0V]M
M;6]N.CIG971);F9O*"=014%27TEN<W1A;&QE<E]2;VQE7R<@+B`-"B`@("`@
M("`@("`@('5C9FER<W0H<W1R7W)E<&QA8V4H)W!E87)?:6YS=&%L;&5R7W)O
M;&5?)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI*2D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R;VQE26YF;RDI('L-"B`@("`@
M("`@("`@(')E='5R;B`D<F]L94EN9F\[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1R;VQE26YF;ULG97AE8W5T86)L92==.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&ES26YS=&%L;&%B;&4H*0T*("`@('L-"B`@("`@("`@)')O
M;&5);F9O(#T@4$5!4E]);G-T86QL97)?4F]L95]#;VUM;VXZ.F=E=$EN9F\H
M)U!%05)?26YS=&%L;&5R7U)O;&5?)R`N(`T*("`@("`@("`@("`@=6-F:7)S
M="AS=')?<F5P;&%C92@G<&5A<E]I;G-T86QL97)?<F]L95\G+"`G)RP@<W1R
M=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*2DI*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)')O;&5);F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1R;VQE26YF;SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')O;&5)
M;F9O6R=I;G-T86QL86)L92==.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES
M17AT96YS:6]N*"D-"B`@("![#0H@("`@("`@("1R;VQE26YF;R`](%!%05)?
M26YS=&%L;&5R7U)O;&5?0V]M;6]N.CIG971);F9O*"=014%27TEN<W1A;&QE
M<E]2;VQE7R<@+B`-"B`@("`@("`@("`@('5C9FER<W0H<W1R7W)E<&QA8V4H
M)W!E87)?:6YS=&%L;&5R7W)O;&5?)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L
M87-S*"1T:&ES*2DI*2D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R
M;VQE26YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D<F]L94EN9F\[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R;VQE26YF;ULG<&AP97AT96YS
M:6]N)UT[#0H@("`@?0T*?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B])
M;G-T86QL97(O4F]L92]$871A+G!H<```````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(S,C$`,3`U,34T,S$P-3<`,#(R,S`V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?
M26YS=&%L;&5R7U)O;&5?1&%T80T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@($-64SH@)$ED.B!$871A+G!H<"QV(#$N-B`R,#`V+S`Q+S`V(#`T.C0W
M.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?26YS=&%L;&5R7U)O;&5?1&%T
M82!E>'1E;F1S(%!%05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N('M]#0H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+T1O8RYX;6P`
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4Q,P`Q,#4Q-30S,3`U-P`P
M,C(Q-30`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/')O;&4@=F5R<VEO;CTB,2XP(CX-"B`\<F5L96%S971Y<&5S/G!H<#PO
M<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^97AT<W)C/"]R96QE87-E
M='EP97,^#0H@/')E;&5A<V5T>7!E<SYE>'1B:6X\+W)E;&5A<V5T>7!E<SX-
M"B`\:6YS=&%L;&%B;&4^,3PO:6YS=&%L;&%B;&4^#0H@/&QO8V%T:6]N8V]N
M9FEG/F1O8U]D:7(\+VQO8V%T:6]N8V]N9FEG/@T*(#QH;VYO<G-B87-E:6YS
M=&%L;"`O/@T*(#QU;G5S=6%L8F%S96EN<W1A;&P@+SX-"B`\<&AP9FEL92`O
M/@T*(#QE>&5C=71A8FQE("\^#0H@/'!H<&5X=&5N<VEO;B`O/@T*(#QC;VYF
M:6=?=F%R<R`O/@T*/"]R;VQE/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]$;V,N<&AP````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(S,38`,3`U,34T,S$P-3<`,#(R,30V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(%!%05)?26YS=&%L;&5R7U)O;&5?1&]C#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E
M9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z($1O8RYP:'`L=B`Q+C8@,C`P-B\P
M,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*
M#0HO*BH-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%
M05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE
M=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27TEN<W1A;&QE
M<E]2;VQE7T1O8R!E>'1E;F1S(%!%05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N
M('M]#0H_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2
M;VQE+T5X="YX;6P`````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0T,P`Q
M,#4Q-30S,3`U-P`P,C(R,3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/')O;&4@=F5R<VEO;CTB,2XP(CX-"B`\<F5L96%S
M971Y<&5S/F5X=&)I;CPO<F5L96%S971Y<&5S/@T*(#QI;G-T86QL86)L93XQ
M/"]I;G-T86QL86)L93X-"B`\;&]C871I;VYC;VYF:6<^97AT7V1I<CPO;&]C
M871I;VYC;VYF:6<^#0H@/&AO;F]R<V)A<V5I;G-T86QL/C$\+VAO;F]R<V)A
M<V5I;G-T86QL/@T*(#QU;G5S=6%L8F%S96EN<W1A;&P@+SX-"B`\<&AP9FEL
M92`O/@T*(#QE>&5C=71A8FQE("\^#0H@/'!H<&5X=&5N<VEO;CXQ/"]P:'!E
M>'1E;G-I;VX^#0H@/&-O;F9I9U]V87)S("\^#0H\+W)O;&4^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]%>'0N<&AP
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,38`,3`U,34T,S$P-3<`
M,#(R,C`Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO*BH-"B`J(%!%05)?26YS=&%L;&5R7U)O;&5?17AT#0H@
M*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($5X="YP:'`L
M=B`Q+C8@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*#0HO*BH-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!0
M14%27TEN<W1A;&QE<E]2;VQE7T5X="!E>'1E;F1S(%!%05)?26YS=&%L;&5R
M7U)O;&5?0V]M;6]N('M]#0H_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+TEN<W1A;&QE<B]2;VQE+U!H<"YX;6P`````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#4T-P`Q,#4Q-30S,3`U-P`P,C(R,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/')O;&4@=F5R<VEO;CTB,2XP
M(CX-"B`\<F5L96%S971Y<&5S/G!H<#PO<F5L96%S971Y<&5S/@T*(#QR96QE
M87-E='EP97,^97AT<W)C/"]R96QE87-E='EP97,^#0H@/')E;&5A<V5T>7!E
M<SYE>'1B:6X\+W)E;&5A<V5T>7!E<SX-"B`\:6YS=&%L;&%B;&4^,3PO:6YS
M=&%L;&%B;&4^#0H@/&QO8V%T:6]N8V]N9FEG/G!H<%]D:7(\+VQO8V%T:6]N
M8V]N9FEG/@T*(#QH;VYO<G-B87-E:6YS=&%L;#XQ/"]H;VYO<G-B87-E:6YS
M=&%L;#X-"B`\=6YU<W5A;&)A<V5I;G-T86QL("\^#0H@/'!H<&9I;&4^,3PO
M<&AP9FEL93X-"B`\97AE8W5T86)L92`O/@T*(#QP:'!E>'1E;G-I;VX@+SX-
M"B`\8V]N9FEG7W9A<G,@+SX-"CPO<F]L93X`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O
M4F]L92]0:'`N<&AP````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,38`
M,3`U,34T,S$P-3<`,#(R,3<P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?26YS=&%L;&5R
M7U)O;&5?4&AP#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z(%!H<"YP:'`L=B`Q+C<@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E
M("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*
M("HO#0IC;&%S<R!014%27TEN<W1A;&QE<E]2;VQE7U!H<"!E>'1E;F1S(%!%
M05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N('M]#0H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-C<FEP="YX;6P`````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#4U,@`Q,#4Q-30S,3`U-P`P,C(W,38`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/')O;&4@
M=F5R<VEO;CTB,2XP(CX-"B`\<F5L96%S971Y<&5S/G!H<#PO<F5L96%S971Y
M<&5S/@T*(#QR96QE87-E='EP97,^97AT<W)C/"]R96QE87-E='EP97,^#0H@
M/')E;&5A<V5T>7!E<SYE>'1B:6X\+W)E;&5A<V5T>7!E<SX-"B`\:6YS=&%L
M;&%B;&4^,3PO:6YS=&%L;&%B;&4^#0H@/&QO8V%T:6]N8V]N9FEG/F)I;E]D
M:7(\+VQO8V%T:6]N8V]N9FEG/@T*(#QH;VYO<G-B87-E:6YS=&%L;#XQ/"]H
M;VYO<G-B87-E:6YS=&%L;#X-"B`\=6YU<W5A;&)A<V5I;G-T86QL("\^#0H@
M/'!H<&9I;&4@+SX-"B`\97AE8W5T86)L93XQ/"]E>&5C=71A8FQE/@T*(#QP
M:'!E>'1E;G-I;VX@+SX-"B`\8V]N9FEG7W9A<G,@+SX-"CPO<F]L93X`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!
M4B]);G-T86QL97(O4F]L92]38W)I<'0N<&AP````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(S,C<`,3`U,34T,S$P-3<`,#(R-S`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%
M05)?26YS=&%L;&5R7U)O;&5?4V-R:7!T#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z(%-C<FEP="YP:'`L=B`Q+C8@,C`P-B\P,2\P
M-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO
M*BH-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N
M-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27TEN<W1A;&QE<E]2
M;VQE7U-C<FEP="!E>'1E;F1S(%!%05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N
M('M]#0H_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-R8RYX
M;6P````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,S-P`Q,#4Q-30S,3`U
M-P`P,C(R,#(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/')O;&4@=F5R<VEO;CTB,2XP(CX-"B`\<F5L96%S971Y<&5S/F5X
M='-R8SPO<F5L96%S971Y<&5S/@T*(#QI;G-T86QL86)L92`O/@T*(#QL;V-A
M=&EO;F-O;F9I9R`O/@T*(#QH;VYO<G-B87-E:6YS=&%L;"`O/@T*(#QU;G5S
M=6%L8F%S96EN<W1A;&P@+SX-"B`\<&AP9FEL92`O/@T*(#QE>&5C=71A8FQE
M("\^#0H@/'!H<&5X=&5N<VEO;B`O/@T*(#QC;VYF:6=?=F%R<R`O/@T*/"]R
M;VQE/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]3<F,N<&AP````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(T-S$`,3`U,34T,S$P-3<`,#(R,3<R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(%!%05)?26YS=&%L;&5R7U)O;&5?4W)C#0H@*@T*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%-R8RYP:'`L=B`Q+C8@,C`P
M-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J
M+PT*#0HO*BH-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27TEN<W1A
M;&QE<E]2;VQE7U-R8R!E>'1E;F1S(%!%05)?26YS=&%L;&5R7U)O;&5?0V]M
M;6]N#0I[#0H@("`@9G5N8W1I;VX@<V5T=7`H)B1I;G-T86QL97(L("1P:V<L
M("1A='1S+"`D9FEL92D-"B`@("![#0H@("`@("`@("1I;G-T86QL97(M/G-O
M=7)C95]F:6QE<RLK.PT*("`@('T-"GT-"C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE
M<B]2;VQE+U1E<W0N>&UL````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4Q
M-``Q,#4Q-30S,3`U-P`P,C(S-C<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/')O;&4@=F5R<VEO;CTB,2XP(CX-"B`\<F5L
M96%S971Y<&5S/G!H<#PO<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^
M97AT<W)C/"]R96QE87-E='EP97,^#0H@/')E;&5A<V5T>7!E<SYE>'1B:6X\
M+W)E;&5A<V5T>7!E<SX-"B`\:6YS=&%L;&%B;&4^,3PO:6YS=&%L;&%B;&4^
M#0H@/&QO8V%T:6]N8V]N9FEG/G1E<W1?9&ER/"]L;V-A=&EO;F-O;F9I9SX-
M"B`\:&]N;W)S8F%S96EN<W1A;&P@+SX-"B`\=6YU<W5A;&)A<V5I;G-T86QL
M("\^#0H@/'!H<&9I;&4@+SX-"B`\97AE8W5T86)L92`O/@T*(#QP:'!E>'1E
M;G-I;VX@+SX-"B`\8V]N9FEG7W9A<G,@+SX-"CPO<F]L93X`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]497-T
M+G!H<```````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,C$`,3`U,34T,S$P
M-3<`,#(R,S4T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP#0HO*BH-"B`J(%!%05)?26YS=&%L;&5R7U)O;&5?5&5S
M=`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!497-T
M+G!H<"QV(#$N-B`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#
M;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L
M87-S(%!%05)?26YS=&%L;&5R7U)O;&5?5&5S="!E>'1E;F1S(%!%05)?26YS
M=&%L;&5R7U)O;&5?0V]M;6]N('M]#0H_/@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+TEN<W1A;&QE<B]2;VQE+T1A=&$N>&UL````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#4Q-``Q,#4Q-30S,3`U-P`P,C(S,C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/')O;&4@=F5R<VEO;CTB
M,2XP(CX-"B`\<F5L96%S971Y<&5S/G!H<#PO<F5L96%S971Y<&5S/@T*(#QR
M96QE87-E='EP97,^97AT<W)C/"]R96QE87-E='EP97,^#0H@/')E;&5A<V5T
M>7!E<SYE>'1B:6X\+W)E;&5A<V5T>7!E<SX-"B`\:6YS=&%L;&%B;&4^,3PO
M:6YS=&%L;&%B;&4^#0H@/&QO8V%T:6]N8V]N9FEG/F1A=&%?9&ER/"]L;V-A
M=&EO;F-O;F9I9SX-"B`\:&]N;W)S8F%S96EN<W1A;&P@+SX-"B`\=6YU<W5A
M;&)A<V5I;G-T86QL("\^#0H@/'!H<&9I;&4@+SX-"B`\97AE8W5T86)L92`O
M/@T*(#QP:'!E>'1E;G-I;VX@+SX-"B`\8V]N9FEG7W9A<G,@+SX-"CPO<F]L
M93X`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL
M97(O4F]L92YP:'``````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`R
M,S(`,3`U,34T,S$P-3<`,#(Q-#,V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?26YS=&%L
M;&5R7U)O;&4-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@4F]L92YP:'`L=B`Q+C$S(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G
M($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S
M(&9O<B!I;G-T86QL97(@<F]L97,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2
M+TEN<W1A;&QE<B]2;VQE+T-O;6UO;BYP:'`G.PT*<F5Q=6ER95]O;F-E("=0
M14%2+UA-3%!A<G-E<BYP:'`G.PT*+R\D1TQ/0D%,4ULG7U!%05)?24Y35$%,
M3$527U)/3$53)UT@/2!A<G)A>2@I.PT*+RHJ#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G
M($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@
M("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J
M+PT*8VQA<W,@4$5!4E]);G-T86QL97)?4F]L90T*>PT*("`@("\J*@T*("`@
M("`J(%-E="!U<"!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N('9A<FEA
M8FQE<R!T:&%T(&9I;&4@<F]L97,@<F5Q=6ER90T*("`@("`J#0H@("`@("H@
M3F5V97(@8V%L;"!T:&ES(&1I<F5C=&QY+"!I="!I<R!C86QL960@8GD@=&AE
M(%!%05)?0V]N9FEG(&-O;G-T<G5C=&]R#0H@("`@("H@0'!A<F%M(%!%05)?
M0V]N9FEG#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'-T871I
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN:71I86QI>F5#;VYF:6<H)B1C
M;VYF:6<I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?
M4$5!4E])3E-404Q,15)?4D],15,G72DI('L-"B`@("`@("`@("`@(%!%05)?
M26YS=&%L;&5R7U)O;&4Z.G)E9VES=&5R4F]L97,H*3L-"B`@("`@("`@?0T*
M("`@("`@("!F;W)E86-H("@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/
M3$53)UT@87,@)&-L87-S(#T^("1I;F9O*2![#0H@("`@("`@("`@("!I9B`H
M(21I;F9O6R=C;VYF:6=?=F%R<R==*2![#0H@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8V]N9FEG+3Y?
M861D0V]N9FEG5F%R<R@D:6YF;ULG8V]N9FEG7W9A<G,G72D[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]086-K
M86=E1FEL95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@<F]L92!N86UE#0H@
M("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0')E='5R;B!014%2
M7TEN<W1A;&QE<E]2;VQE7T-O;6UO;@T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D<&MG+"`D<F]L92P@)B1C;VYF
M:6<I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!
M4E])3E-404Q,15)?4D],15,G72DI('L-"B`@("`@("`@("`@(%!%05)?26YS
M=&%L;&5R7U)O;&4Z.G)E9VES=&5R4F]L97,H*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"1R;VQE+"!014%27TEN<W1A;&QE<E]2;VQE
M.CIG971686QI9%)O;&5S*"1P:V<M/F=E=%!A8VMA9V54>7!E*"DI*2D@>PT*
M("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R;B`D
M83L-"B`@("`@("`@?0T*("`@("`@("`D82`]("=014%27TEN<W1A;&QE<E]2
M;VQE7R<@+B!U8V9I<G-T*"1R;VQE*3L-"B`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)&$I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@<W1R7W)E
M<&QA8V4H)U\G+"`G+R<L("1A*2`N("<N<&AP)SL-"B`@("`@("`@?0T*("`@
M("`@("`D8B`](&YE=R`D82@D8V]N9FEG*3L-"B`@("`@("`@<F5T=7)N("1B
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E="!A(&QI<W0@;V8@9FEL
M92!R;VQE<R!T:&%T(&%R92!V86QI9"!F;W(@=&AE('!A<G1I8W5L87(@<F5L
M96%S92!T>7!E+@T*("`@("`J#0H@("`@("H@1F]R(&EN<W1A;F-E+"!S<F,@
M9FEL97,@<V5R=F4@;F\@<'5R<&]S92!I;B!R96=U;&%R('!H<"!R96QE87-E
M<RX@('!H<"!F:6QE<PT*("`@("`J('-E<G9E(&YO('!U<G!O<V4@:6X@97AT
M<W)C(&]R(&5X=&)I;B!R96QE87-E<PT*("`@("`J($!P87)A;2!S=')I;F<-
M"B`@("`@*B!`<&%R86T@8F]O;"!C;&5A<B!C86-H90T*("`@("`J($!R971U
M<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T5F%L:612;VQE<R@D<F5L96%S92P@)&-L96%R(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!4E])3E-4
M04Q,15)?4D],15,G72DI('L-"B`@("`@("`@("`@(%!%05)?26YS=&%L;&5R
M7U)O;&4Z.G)E9VES=&5R4F]L97,H*3L-"B`@("`@("`@?0T*("`@("`@("!S
M=&%T:6,@)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@D8VQE87(I('L-
M"B`@("`@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D<F5T6R1R96QE87-E72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D<F5T6R1R96QE87-E73L-"B`@("`@("`@?0T*("`@("`@("`D
M<F5T6R1R96QE87-E72`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1'
M3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],15,G72!A<R`D<F]L92`]/B`D
M;VMR96QE87-E<RD@>PT*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1R96QE
M87-E+"`D;VMR96QE87-E<ULG<F5L96%S971Y<&5S)UTI*2![#0H@("`@("`@
M("`@("`@("`@)')E=%LD<F5L96%S95U;72`]('-T<G1O;&]W97(H<W1R7W)E
M<&QA8V4H)U!%05)?26YS=&%L;&5R7U)O;&5?)RP@)R<L("1R;VQE*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R971;
M)')E;&5A<V5=.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E="!A(&QI
M<W0@;V8@<F]L97,@=&AA="!R97%U:7)E('1H96ER(&9I;&5S('1O(&)E(&EN
M<W1A;&QE9`T*("`@("`J#0H@("`@("H@36]S="!R;VQE<R!M=7-T(&)E(&EN
M<W1A;&QE9"P@8G5T('-R8R!A;F0@<&%C:V%G92!R;VQE<RP@9F]R(&EN<W1A
M;F-E#0H@("`@("H@87)E('!S975D;RUR;VQE<RX@('-R8R!F:6QE<R!A<F4@
M8V]M<&EL960@:6YT;R!A(&YE=R!E>'1E;G-I;VXN("!086-K86=E#0H@("`@
M("H@<F]L97,@87)E(&%C='5A;&QY(&9U;&QY(&)U;F1L960@<F5L96%S97,@
M;V8@82!P86-K86=E#0H@("`@("H@0'!A<F%M(&)O;VP@8VQE87(@8V%C:&4-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=$EN<W1A;&QA8FQE4F]L97,H)&-L96%R(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?
M4$5!4E])3E-404Q,15)?4D],15,G72DI('L-"B`@("`@("`@("`@(%!%05)?
M26YS=&%L;&5R7U)O;&4Z.G)E9VES=&5R4F]L97,H*3L-"B`@("`@("`@?0T*
M("`@("`@("!S=&%T:6,@)')E=#L-"B`@("`@("`@:68@*"1C;&5A<BD@>PT*
M("`@("`@("`@("`@=6YS970H)')E="D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<W-E="@D<F5T*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)$=,
M3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==(&%S("1R;VQE(#T^("1O
M:W)E;&5A<V5S*2![#0H@("`@("`@("`@("`@("`@:68@*"1O:W)E;&5A<V5S
M6R=I;G-T86QL86)L92==*2![#0H@("`@("`@("`@("`@("`@("`@("1R971;
M72`]('-T<G1O;&]W97(H<W1R7W)E<&QA8V4H)U!%05)?26YS=&%L;&5R7U)O
M;&5?)RP@)R<L("1R;VQE*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A;B!A<G)A>2!O9B!R;VQE
M<R!T:&%T(&%R92!A9F9E8W1E9"!B>2!T:&4@8F%S96EN<W1A;&QD:7(@871T
M<FEB=71E#0H@("`@("H-"B`@("`@*B!-;W-T(')O;&5S(&EG;F]R92!T:&ES
M(&%T=')I8G5T92P@86YD(&EN<W1E860@:6YS=&%L;"!D:7)E8W1L>2!I;G1O
M.@T*("`@("`J(%!A8VMA9V5.86UE+V9I;&5P871H#0H@("`@("H@<V\@82!T
M97-T<R!F:6QE('1E<W1S+V9I;&4N<&AP="!I<R!I;G-T86QL960@:6YT;R!0
M86-K86=E3F%M92]T97-T<R]F:6QE<&%T:"YP:'`-"B`@("`@*B!`<&%R86T@
M8F]O;"!C;&5A<B!C86-H90T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@
M*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T0F%S96EN<W1A
M;&Q2;VQE<R@D8VQE87(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A
M:7-S970H)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==*2D@>PT*
M("`@("`@("`@("`@4$5!4E]);G-T86QL97)?4F]L93HZ<F5G:7-T97)2;VQE
M<R@I.PT*("`@("`@("!]#0H@("`@("`@('-T871I8R`D<F5T.PT*("`@("`@
M("!I9B`H)&-L96%R*2![#0H@("`@("`@("`@("!U;G-E="@D<F5T*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1R970I*2![#0H@("`@("`@
M("`@("!F;W)E86-H("@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53
M)UT@87,@)')O;&4@/3X@)&]K<F5L96%S97,I('L-"B`@("`@("`@("`@("`@
M("!I9B`H)&]K<F5L96%S97-;)VAO;F]R<V)A<V5I;G-T86QL)UTI('L-"B`@
M("`@("`@("`@("`@("`@("`@)')E=%M=(#T@<W1R=&]L;W=E<BAS=')?<F5P
M;&%C92@G4$5!4E]);G-T86QL97)?4F]L95\G+"`G)RP@)')O;&4I*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4F5T=7)N(&%N(&%R<F%Y(&]F(&9I;&4@<F]L97,@=&AA="!S:&]U;&0@8F4@
M86YA;'EZ960@9F]R(%!(4"!C;VYT96YT(&%T('!A8VMA9V4@=&EM92P-"B`@
M("`@*B!L:6ME('1H92`B<&AP(B!R;VQE+@T*("`@("`J($!P87)A;2!B;V]L
M(&-L96%R(&-A8VAE#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S
M=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9710:'!2;VQE<R@D8VQE
M87(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!
M3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==*2D@>PT*("`@("`@("`@("`@
M4$5!4E]);G-T86QL97)?4F]L93HZ<F5G:7-T97)2;VQE<R@I.PT*("`@("`@
M("!]#0H@("`@("`@('-T871I8R`D<F5T.PT*("`@("`@("!I9B`H)&-L96%R
M*2![#0H@("`@("`@("`@("!U;G-E="@D<F5T*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6ES<V5T*"1R970I*2![#0H@("`@("`@("`@("!F;W)E86-H
M("@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UT@87,@)')O;&4@
M/3X@)&]K<F5L96%S97,I('L-"B`@("`@("`@("`@("`@("!I9B`H)&]K<F5L
M96%S97-;)W!H<&9I;&4G72D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T
M6UT@/2!S=')T;VQO=V5R*'-T<E]R97!L86-E*"=014%27TEN<W1A;&QE<E]2
M;VQE7R<L("<G+"`D<F]L92DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!38V%N('1H<F]U9V@@=&AE($-O;6UA
M;F0@9&ER96-T;W)Y(&QO;VMI;F<@9F]R(&-L87-S97,-"B`@("`@*B!A;F0@
M<V5E('=H870@8V]M;6%N9',@=&AE>2!I;7!L96UE;G0N#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!W:&EC:"!D:7)E8W1O<GD@=&\@;&]O:R!F;W(@8VQA<W-E
M<RP@9&5F875L=',@=&\-"B`@("`@*B`@("`@("`@("`@("`@('1H92!);G-T
M86QL97(O4F]L97,@<W5B9&ER96-T;W)Y(&]F#0H@("`@("H@("`@("`@("`@
M("`@("!T:&4@9&ER96-T;W)Y(&9R;VT@=VAE<F4@=&AI<R!F:6QE("A?7T9)
M3$5?7RD@:7,-"B`@("`@*B`@("`@("`@("`@("`@(&EN8VQU9&5D+@T*("`@
M("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@82!0
M14%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R96=I<W1E
M<E)O;&5S*"1D:7(@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)'!A<G-E<B`]
M(&YE=R!014%27UA-3%!A<G-E<CL-"B`@("`@("`@:68@*"1D:7(@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@("1D:7(@/2!D:7)N86UE*%]?1DE,15]?*2`N
M("<O4F]L92<[#0H@("`@("`@('T-"B`@("`@("`@)&1P(#T@0&]P96YD:7(H
M)&1I<BD[#0H@("`@("`@(&EF("AE;7!T>2@D9'`I*2![#0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B<F5G:7-T97)2;VQE<SH@;W!E
M;F1I<B@D9&ER*2!F86EL960B*3L-"B`@("`@("`@?0T*("`@("`@("!W:&EL
M92`H)&5N=')Y(#T@<F5A9&1I<B@D9'`I*2![#0H@("`@("`@("`@("!I9B`H
M)&5N=')Y>S!](#T]("<N)R!\?"!S=6)S='(H)&5N=')Y+"`M-"D@(3T@)RYX
M;6PG*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D8VQA<W,@/2`B4$5!4E]);G-T86QL97)?4F]L
M95\B+G-U8G-T<B@D96YT<GDL(#`L("TT*3L-"B`@("`@("`@("`@("\O($QI
M<W0@;V8@<F]L97,-"B`@("`@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG
M7U!%05)?24Y35$%,3$527U)/3$53)UU;)&-L87-S72DI('L-"B`@("`@("`@
M("`@("`@("`D9FEL92`]("(D9&ER+R1E;G1R>2([#0H@("`@("`@("`@("`@
M("`@)'!A<G-E<BT^<&%R<V4H9FEL95]G971?8V]N=&5N=',H)&9I;&4I*3L-
M"B`@("`@("`@("`@("`@("`D9&%T82`]("1P87)S97(M/F=E=$1A=&$H*3L-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A6R=R96QE87-E
M='EP97,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)W)E;&5A
M<V5T>7!E<R==(#T@87)R87DH)&1A=&%;)W)E;&5A<V5T>7!E<R==*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]0
M14%27TE.4U1!3$Q%4E]23TQ%4R==6R1C;&%S<UT@/2`D9&%T83L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!`8VQO<V5D:7(H)&1P*3L-
M"B`@("`@("`@:W-O<G0H)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%
M4R==*3L-"B`@("`@("`@4$5!4E]);G-T86QL97)?4F]L93HZ9V5T0F%S96EN
M<W1A;&Q2;VQE<RAT<G5E*3L-"B`@("`@("`@4$5!4E]);G-T86QL97)?4F]L
M93HZ9V5T26YS=&%L;&%B;&52;VQE<RAT<G5E*3L-"B`@("`@("`@4$5!4E])
M;G-T86QL97)?4F]L93HZ9V5T4&AP4F]L97,H=')U92D[#0H@("`@("`@(%!%
M05)?26YS=&%L;&5R7U)O;&4Z.F=E=%9A;&ED4F]L97,H)RHJ*BHG+"!T<G5E
M*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*?0T*/SX-"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92\`````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-3<`,#(P,C(V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+U!A8VMA9V5&:6QE+T=E;F5R871O<B\`````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C(Q-30`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O1V5N97)A=&]R+W8R+G!H
M<````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3<R,#`P`#$P-3$U-#,Q,#4W`#`R,S(Q
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!P86-K86=E+GAM;"!G96YE<F%T:6]N(&-L87-S+"!P
M86-K86=E+GAM;"!V97)S:6]N(#(N,`T*("H-"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H
M;6ED="`H;W)I9VEN86P@6$U,7U-E<FEA;&EZ97(@8V]D92D-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!V,BYP:'`L=B`Q
M+C,T(#(P,#8O,#,O,#(@,C`Z-3`Z-3D@8V5L;&]G($5X<"`D#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,&$Q#0H@*B\-"B\J*@T*("H@9FEL92]D:7(@;6%N:7!U;&%T:6]N(')O=71I
M;F5S#0H@*B\-"G)E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0HO*BH-"B`J
M(%1H:7,@8VQA<W,@8V]N=F5R=',@82!014%27U!A8VMA9V5&:6QE7W8R(&]B
M:F5C="!I;G1O(&%N>2!O=71P=70@9F]R;6%T+@T*("H-"B`J(%-U<'!O<G1E
M9"!O=71P=70@9F]R;6%T<R!I;F-L=61E(&%R<F%Y+"!834P@<W1R:6YG("AU
M<VEN9R!3+B!38VAM:61T)W,-"B`J(%A-3%]397)I86QI>F5R+"!S;&EG:'1L
M>2!C=7-T;VUI>F5D*0T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@4W1E<&AA;B!38VAM:61T("AO
M<FEG:6YA;"!834Q?4V5R:6%L:7IE<B!C;V1E*0T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R#0I[
M#0H@("`O*BH-"B`@("`J(&1E9F%U;'0@;W!T:6]N<R!F;W(@=&AE('-E<FEA
M;&EZ871I;VX-"B`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("H@0'9A<B!A
M<G)A>2`D7V1E9F%U;'1/<'1I;VYS#0H@("`@*B\-"B`@("!V87(@)%]D969A
M=6QT3W!T:6]N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("=I;F1E;G0G("`@("`@("`@("`@(#T^("<@)RP@("`@("`@("`@("`@("`@
M("`@("\O('-T<FEN9R!U<V5D(&9O<B!I;F1E;G1A=&EO;@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("=L:6YE8G)E86LG("`@("`@("`@(#T^(")<;B(L
M("`@("`@("`@("`@("`@("`@+R\@<W1R:6YG('5S960@9F]R(&YE=VQI;F5S
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&5(:6YT<R<@("`@("`@
M("`@/3X@9F%L<V4L("`@("`@("`@("`@("`@("`O+R!A=71O;6%T:6-A;&QY
M(&%D9"!T>7!E(&AI;B!A='1R:6)U=&5S#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@)V%D9$1E8VPG("`@("`@("`@("`@/3X@=')U92P@("`@("`@("`@
M("`@("`@("\O(&%D9"!A;B!834P@9&5C;&%R871I;VX-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&5F875L=%1A9TYA;64G("`@("`]/B`G6$U,7U-E
M<FEA;&EZ97)?5&%G)RP@("\O('1A9R!U<V5D(&9O<B!I;F1E>&5D(&%R<F%Y
M<R!O<B!I;G9A;&ED(&YA;65S#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-L87-S07-486=.86UE)R`@("`@/3X@9F%L<V4L("`@("`@("`@("`@("`@
M("`O+R!U<V4@8VQA<W-N86UE(&9O<B!O8FIE8W1S(&EN(&EN9&5X960@87)R
M87ES#0H@("`@("`@("`@("`@("`@("`@("`@("`@)VME>4%T=')I8G5T92<@
M("`@("`@/3X@)U]O<FEG:6YA;$ME>2<L("`@("`@("`O+R!A='1R:6)U=&4@
M=VAE<F4@;W)I9VEN86P@:V5Y(&ES('-T;W)E9`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E071T<FEB=71E)R`@("`@(#T^("=?='EP92<L("`@
M("`@("`@("`@("`@+R\@871T<FEB=71E(&9O<B!T>7!E("AO;FQY(&EF('1Y
M<&5(:6YT<R`]/B!T<G5E*0T*("`@("`@("`@("`@("`@("`@("`@("`@("=C
M;&%S<T%T=')I8G5T92<@("`@(#T^("=?8VQA<W,G+"`@("`@("`@("`@("`@
M+R\@871T<FEB=71E(&9O<B!C;&%S<R!O9B!O8FIE8W1S("AO;FQY(&EF('1Y
M<&5(:6YT<R`]/B!T<G5E*0T*("`@("`@("`@("`@("`@("`@("`@("`@("=S
M8V%L87)!<T%T=')I8G5T97,G(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@
M+R\@<V-A;&%R('9A;'5E<R`H<W1R:6YG<RP@:6YT<RPN+BD@=VEL;"!B92!S
M97)I86QI>F5D(&%S(&%T=')I8G5T90T*("`@("`@("`@("`@("`@("`@("`@
M("`@("=P<F5P96YD071T<FEB=71E<R<@(#T^("<G+"`@("`@("`@("`@("`@
M("`@("`@+R\@<')E<&5N9"!S=')I;F<@9F]R(&%T=')I8G5T97,-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G:6YD96YT071T<FEB=71E<R<@("`]/B!F
M86QS92P@("`@("`@("`@("`@("`@("\O(&EN9&5N="!T:&4@871T<FEB=71E
M<RP@:68@<V5T('1O("=?875T;R<L(&ET('=I;&P@:6YD96YT(&%T=')I8G5T
M97,@<V\@=&AE>2!A;&P@<W1A<G0@870@=&AE('-A;64@8V]L=6UN#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@)VUO9&4G("`@("`@("`@("`@("`@/3X@
M)W-I;7!L97AM;"<L("`@("`@("`@("`@("\O('5S92`G<VEM<&QE>&UL)R!T
M;R!U<V4@<&%R96YT(&YA;64@87,@=&%G;F%M92!I9B!T<F%N<V9O<FUI;F<@
M86X@:6YD97AE9"!A<G)A>0T*("`@("`@("`@("`@("`@("`@("`@("`@("=A
M9&1$;V-T>7!E)R`@("`@("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@
M+R\@861D(&$@9&]C='EP92!D96-L87)A=&EO;@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("=D;V-T>7!E)R`@("`@("`@("`@(#T^(&YU;&PL("`@("`@
M("`@("`@("`@("`@+R\@<W5P<&QY(&$@<W1R:6YG(&]R(&%N(&%R<F%Y('=I
M=&@@:60@86YD('5R:2`H>T!S964@4$5!4E]086-K86=E1FEL95]'96YE<F%T
M;W)?=C)?4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ
M.F=E=$1O8W1Y<&5$96-L87)A=&EO;B@I?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("=R;V]T3F%M92<@("`@("`@("`@(#T^("=P86-K86=E)RP@("`@
M("`@("`@("`@("`@("`O+R!N86UE(&]F('1H92!R;V]T('1A9PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("=R;V]T071T<FEB=71E<R<@("`@(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@
M/3X@)S(N,"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X;6QN
M<R<@/3X@)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,BXP)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAM;&YS.G1A<VMS)R`]
M/B`G:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)WAM;&YS.GAS:2<@/3X@)VAT='`Z
M+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)WAS:3IS8VAE;6%,;V-A=&EO;B<@
M/3X@)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,`T*:'1T<#HO
M+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP+GAS9`T*:'1T<#HO+W!E87(N
M<&AP+FYE="]D=&0O<&%C:V%G92TR+C`-"FAT='`Z+R]P96%R+G!H<"YN970O
M9'1D+W!A8VMA9V4M,BXP+GAS9"<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@*2P@("`@("`@("`@("`@("`O+R!A='1R:6)U=&5S(&]F('1H92!R;V]T
M('1A9PT*("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&5S07)R
M87DG("`@(#T^("=A='1R:6)S)RP@("`@("`@("`@("`@("`@("`O+R!A;&P@
M=F%L=65S(&EN('1H:7,@:V5Y('=I;&P@8F4@=')E871E9"!A<R!A='1R:6)U
M=&5S#0H@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G1E;G1.86UE)R`@
M("`@("`@/3X@)U]C;VYT96YT)RP@("`@("`@("`@("`@("`@("`@+R\@=&AI
M<R!V86QU92!W:6QL(&)E('5S960@9&ER96-T;'D@87,@8V]N=&5N="P@:6YS
M=&5A9"!O9B!C<F5A=&EN9R!A(&YE=R!T86<L(&UA>2!O;FQY(&)E('5S960@
M:6X@8V]N:G5C=&EO;B!W:71H(&%T=')I8G5T97-!<G)A>0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("=B96%U=&EF>49I;&5L:7-T)R`@(#T^(&9A;'-E
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("=E;F-O9&EN9R<@/3X@)U54
M1BTX)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("\J*@T*
M("`@("H@;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I;VX-"B`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("H@0'9A<B!A<G)A>2`D;W!T:6]N<PT*("`@
M("HO#0H@("`@=F%R("1O<'1I;VYS(#T@87)R87DH*3L-"@T*("`@+RHJ#0H@
M("`@*B!C=7)R96YT('1A9R!D97!T:`T*("`@("H@0'9A<B!I;G1E9V5R("1?
M=&%G1&5P=&@-"B`@("`J+PT*("`@('9A<B`D7W1A9T1E<'1H(#T@,#L-"@T*
M("`@+RHJ#0H@("`@*B!S97)I;&EA;&EZ960@<F5P<F5S96YT871I;VX@;V8@
M=&AE(&1A=&$-"B`@("`J($!V87(@<W1R:6YG("1?<V5R:6%L:7IE9$1A=&$-
M"B`@("`J+PT*("`@('9A<B`D7W-E<FEA;&EZ961$871A(#T@;G5L;#L-"B`@
M("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@
M*B\-"B`@("!V87(@)%]P86-K86=E9FEL93L-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R*"8D<&%C:V%G969I
M;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE(#T@)B1P
M86-K86=E9FEL93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N
M('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V5R5F5R
M<VEO;B@I#0H@("`@>PT*("`@("`@("!R971U<FX@)S$N-"XY)SL-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E<@T*("`@
M("`J($!P87)A;2!B;V]L(&=E;F5R871E(&$@+G1G>B!O<B!A("YT87(-"B`@
M("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@=&5M<&]R87)Y(&1I<F5C=&]R>2!T
M;R!P86-K86=E(&EN#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]49WHH)B1P
M86-K86=E<BP@)&-O;7!R97-S(#T@=')U92P@)'=H97)E(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@("1A(#T@;G5L;#L-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YT;U1G>C(H)'!A8VMA9V5R+"`D82P@)&-O;7!R97-S+"`D=VAE<F4I.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%!A8VMA9V4@=7`@8F]T:"!A('!A
M8VMA9V4N>&UL(&%N9"!P86-K86=E,BYX;6P@9F]R('1H92!S86UE(')E;&5A
M<V4-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E<@T*("`@("`J($!P87)A
M;2!014%27U!A8VMA9V5&:6QE7W8Q#0H@("`@("H@0'!A<F%M(&)O;VP@9V5N
M97)A=&4@82`N=&=Z(&]R(&$@+G1A<@T*("`@("`J($!P87)A;2!S=')I;F=\
M;G5L;"!T96UP;W)A<GD@9&ER96-T;W)Y('1O('!A8VMA9V4@:6X-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!T;U1G>C(H)B1P86-K86=E<BP@)B1P9C$L("1C
M;VUP<F5S<R`]('1R=64L("1W:&5R92`](&YU;&PI#0H@("`@>PT*("`@("`@
M("!R97%U:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@(&EF
M("@A)'1H:7,M/E]P86-K86=E9FEL92T^:7-%<75I=F%L96YT*"1P9C$I*2![
M#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]0
M86-K86=E9FEL95]V,CHZ=&]49WHZ("(G("X-"B`@("`@("`@("`@("`@("!B
M87-E;F%M92@D<&8Q+3YG971086-K86=E1FEL92@I*2`N#0H@("`@("`@("`@
M("`@("`@)R(@:7,@;F]T(&5Q=6EV86QE;G0@=&\@(B<@+B!B87-E;F%M92@D
M=&AI<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E1FEL92@I*0T*("`@("`@
M("`@("`@("`@("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'=H
M97)E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!I9B`H(2@D=VAE<F4@/2!3
M>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G*2DI*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?
M=C(Z.G1O5&=Z.B!M:W1E;7`@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS96EF("@A0%-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@
M)'=H97)E*2DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=014%27U!A8VMA9V5F:6QE7W8R.CIT;U1G>CH@(B<@+B`D=VAE<F4@
M+B`G(B!C;W5L9"<@+@T*("`@("`@("`@("`@("`@("<@;F]T(&)E(&-R96%T
M960G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL95]E>&ES=',H)'=H
M97)E("X@1$E214-43U)97U-%4$%2051/4B`N("=P86-K86=E+GAM;"<I("8F
M#0H@("`@("`@("`@("`@("%I<U]F:6QE*"1W:&5R92`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G<&%C:V%G92YX;6PG*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O
M5&=Z.B!U;F%B;&4@=&\@<V%V92!P86-K86=E+GAM;"!A<R<@+@T*("`@("`@
M("`@("`@("`@("<@(B<@+B`D=VAE<F4@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)W!A8VMA9V4N>&UL(B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)'1H:7,M/E]P86-K86=E9FEL92T^=F%L:61A=&4H4$5!4E]604Q)1$%415]0
M04-+04=)3D<I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]49WHZ(&EN=F%L:60@<&%C
M:V%G92YX;6PG*3L-"B`@("`@("`@?0T*("`@("`@("`D97AT(#T@)&-O;7!R
M97-S(#\@)RYT9WHG(#H@)RYT87(G.PT*("`@("`@("`D<&MG=F5R(#T@)'1H
M:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G92@I("X@)RTG("X@)'1H:7,M
M/E]P86-K86=E9FEL92T^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D9&5S=%]P
M86-K86=E(#T@9V5T8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!K
M9W9E<B`N("1E>'0[#0H@("`@("`@(&EF("AF:6QE7V5X:7-T<RAG971C=V0H
M*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG=F5R("X@)&5X="D@)B8-
M"B`@("`@("`@("`@("`@(6ES7V9I;&4H9V5T8W=D*"D@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)'!K9W9E<B`N("1E>'0I*2![#0H@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ
M=&]49WHZ(&-A;FYO="!C<F5A=&4@=&=Z(&9I;&4@(B<@+@T*("`@("`@("`@
M("`@("`@(&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V
M97(@+B`D97AT("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!K
M9V9I;&4@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E1FEL92@I
M*2![#0H@("`@("`@("`@("`D<&MG9&ER(#T@9&ER;F%M92AR96%L<&%T:"@D
M<&MG9FEL92DI.PT*("`@("`@("`@("`@)'!K9V9I;&4@/2!B87-E;F%M92@D
M<&MG9FEL92D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]4
M9WHZ('!A8VMA9V4@9FEL92!O8FIE8W0@;75S="`G("X-"B`@("`@("`@("`@
M("`@("`G8F4@8W)E871E9"!F<F]M(&$@<F5A;"!F:6QE)RD[#0H@("`@("`@
M('T-"B`@("`@("`@+R\@>WM[($-R96%T92!T:&4@<&%C:V%G92!F:6QE(&QI
M<W0-"B`@("`@("`@)&9I;&5L:7-T(#T@87)R87DH*3L-"B`@("`@("`@)&D@
M/2`P.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YF;&%T=&5N1FEL
M96QI<W0H*3L-"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P86-K86=E
M9FEL92T^9V5T0V]N=&5N=',H*3L-"B`@("`@("`@:68@*&ES<V5T*"1C;VYT
M96YT<ULG8G5N9&QE9'!A8VMA9V4G72DI('L@+R\@8G5N9&QE<R!O9B!P86-K
M86=E<PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)&-O;G1E;G1S6R=B=6YD
M;&5D<&%C:V%G92==.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D8V]N=&5N
M='-;,%TI*2![#0H@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@87)R87DH
M)&-O;G1E;G1S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P86-K
M86=E1&ER(#T@)'=H97)E.PT*("`@("`@("`@("`@9F]R96%C:"`H)&-O;G1E
M;G1S(&%S("1I(#T^("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@)&9N
M86UE(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`D<&MG
M9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@("`@
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'!A8VMA9V5R+3YR86ES945R<F]R*")&:6QE
M(&1O97,@;F]T(&5X:7-T.B`D9FYA;64B*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1F:6QE(#T@)'!A8VMA9V5$:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)&9N86UE.PT*("`@("`@("`@("`@("`@(%-Y
M<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@9&ER;F%M92@D=&9I;&4I*2D[#0H@
M("`@("`@("`@("`@("`@8V]P>2@D9FEL92P@)'1F:6QE*3L-"B`@("`@("`@
M("`@("`@("`D9FEL96QI<W1;)&DK*UT@/2`D=&9I;&4[#0H@("`@("`@("`@
M("`@("`@)'!A8VMA9V5R+3YL;V<H,BP@(D%D9&EN9R!P86-K86=E("1F;F%M
M92(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>R`O+R!N;W)M
M86P@<&%C:V%G97,-"B`@("`@("`@("`@("1C;VYT96YT<R`]("1C;VYT96YT
M<ULG9&ER)UU;)V9I;&4G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&-O
M;G1E;G1S6S!=*2D@>PT*("`@("`@("`@("`@("`@("1C;VYT96YT<R`](&%R
M<F%Y*"1C;VYT96YT<RD[#0H@("`@("`@("`@("!]#0H@("`@#0H@("`@("`@
M("`@("`D<&%C:V%G941I<B`]("1W:&5R93L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1C;VYT96YT<R!A<R`D:2`]/B`D9FEL92D@>PT*("`@("`@("`@("`@
M("`@("1F;F%M92`]("1F:6QE6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@
M("`@("`@("`@("`D871T<R`]("1F:6QE6R=A='1R:6)S)UT[#0H@("`@("`@
M("`@("`@("`@)&]R:6<@/2`D9FEL93L-"B`@("`@("`@("`@("`@("`D9FEL
M92`]("1P:V=D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9N86UE.PT*
M("`@("`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&4I*2![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D<&%C:V%G97(M/G)A:7-E17)R
M;W(H(D9I;&4@9&]E<R!N;W0@97AI<W0Z("1F;F%M92(I.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1T9FEL92`]
M("1P86-K86=E1&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1F;F%M93L-
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&]R:6=;)V%T=')I8G,G72D[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D;W)I9RDI('L@+R\@
M9FEL92!W:71H('1A<VMS#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!R
M=6X@86YY('!A8VMA9V4M=&EM92!T87-K<PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`]
M(&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9P(#T@9F]P96XH)&9I;&4L(")R(BD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;G1E;G1S(#T@0&9R96%D*"1F<"P@9FEL97-I>F4H)&9I
M;&4I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1O<FEG(&%S("1T86<@/3X@)')A=RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T86<@/2!S=')?<F5P;&%C
M92@D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971487-K<TYS*"D@+B`G.B<L("<G
M+"`D=&%G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&%S:R`]
M(")014%27U1A<VM?)'1A9R([#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1A<VL@/2`F;F5W("1T87-K*"1T:&ES+3Y?<&%C:V%G969I;&4M/E]C
M;VYF:6<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G969I;&4M/E]L;V=G97(L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?5$%32U]004-+04=%*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&%S:RT^:6YI="@D<F%W+"`D871T<RP@;G5L
M;"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<R`]("1T87-K
M+3YS=&%R=%-E<W-I;VXH)'1H:7,M/E]P86-K86=E9FEL92P@)&-O;G1E;G1S
M+"`D=&9I;&4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M)')E<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L@+R\@<VMI<"!T:&ES('1A<VL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)')E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97,[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M<R`]("1R97,[("\O('-A=F4@8VAA;F=E<PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@9&ER;F%M92@D
M=&9I;&4I*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=P(#T@
M9F]P96XH)'1F:6QE+"`B=V(B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F=W)I=&4H)'=P+"`D8V]N=&5N=',I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9C;&]S92@D=W`I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A9FEL95]E>&ES=',H)'1F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@4WES=&5M.CIM:V1I<BAA<G)A>2@G+7`G+"!D:7)N
M86UE*"1T9FEL92DI*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O<'DH
M)&9I;&4L("1T9FEL92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)&9I;&5L:7-T6R1I*RM=(#T@)'1F:6QE.PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YS971&:6QE
M071T<FEB=71E*"1F;F%M92P@)VUD-7-U;2<L(&UD-5]F:6QE*"1T9FEL92DL
M("1I("T@,2D[#0H@("`@("`@("`@("`@("`@("`@("1P86-K86=E<BT^;&]G
M*#(L(")!9&1I;F<@9FEL92`D9FYA;64B*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@("`@("\O('U]
M?0T*("`@("`@("!I9B`H)'!F,2`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@
M)&YA;64@/2`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1N86UE(#T@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@?0T*
M("`@("`@("`D<&%C:V%G97AM;"`]("1T:&ES+3YT;U!A8VMA9V5&:6QE*"1W
M:&5R92P@4$5!4E]604Q)1$%415]004-+04=)3D<L("1N86UE*3L-"B`@("`@
M("`@:68@*"1P86-K86=E>&UL*2![#0H@("`@("`@("`@("`D=&%R(#TF(&YE
M=R!!<F-H:79E7U1A<B@D9&5S=%]P86-K86=E+"`D8V]M<')E<W,I.PT*("`@
M("`@("`@("`@)'1A<BT^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[("\O(%A86"!$;VXG="!P<FEN="!E<G)O<G,-"B`@("`@("`@("`@
M("\O("TM+2TM($-R96%T97,@=VET:"!T:&4@<&%C:V%G92YX;6P@9FEL90T*
M("`@("`@("`@("`@)&]K(#T@)'1A<BT^8W)E871E36]D:69Y*&%R<F%Y*"1P
M86-K86=E>&UL*2P@)R<L("1W:&5R92D[#0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D;VLI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P
M86-K86=E<BT^<F%I<V5%<G)O<B@D;VLI.PT*("`@("`@("`@("`@?2!E;'-E
M:68@*"$D;VLI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'!A8VMA9V5R
M+3YR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8R.CIT;U1G>B@I.B!A
M9&1I;F<@)R`N("1N86UE("X-"B`@("`@("`@("`@("`@("`@("`@)R!F86EL
M960G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O("TM+2TM($%D
M9"!T:&4@8V]N=&5N="!O9B!T:&4@<&%C:V%G90T*("`@("`@("`@("`@:68@
M*"$D=&%R+3YA9&1-;V1I9GDH)&9I;&5L:7-T+"`D<&MG=F5R+"`D=VAE<F4I
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P86-K86=E<BT^<F%I<V5%
M<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@)U!%05)?4&%C:V%G969I;&5?
M=C(Z.G1O5&=Z*"DZ('1A<F)A;&P@8W)E871I;VX@9F%I;&5D)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`O+R!A9&0@=&AE('!A8VMA9V4N>&UL
M('9E<G-I;VX@,2XP#0H@("`@("`@("`@("!I9B`H)'!F,2`A/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@("`@("1P9F=E;B`]("8D<&8Q+3YG971$969A=6QT
M1V5N97)A=&]R*"D[#0H@("`@("`@("`@("`@("`@)'!A8VMA9V5X;6PQ(#T@
M)'!F9V5N+3YT;U!A8VMA9V5&:6QE*"1W:&5R92P@4$5!4E]604Q)1$%415]0
M04-+04=)3D<L#0H@("`@("`@("`@("`@("`@("`@("=P86-K86=E+GAM;"<L
M('1R=64I.PT*("`@("`@("`@("`@("`@(&EF("@A)'1A<BT^861D36]D:69Y
M*&%R<F%Y*"1P86-K86=E>&UL,2DL("<G+"`D=VAE<F4I*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<&%C:V%G97(M/G)A:7-E17)R;W(H#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G4$5!4E]086-K86=E9FEL95]V,CHZ
M=&]49WHH*3H@861D:6YG('!A8VMA9V4N>&UL(&9A:6QE9"<I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R
M;B`D9&5S=%]P86-K86=E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@=&]086-K86=E1FEL92@D=VAE<F4@/2!N=6QL+"`D<W1A=&4@/2!0
M14%27U9!3$E$051%7TY/4DU!3"P@)&YA;64@/2`G<&%C:V%G92YX;6PG*0T*
M("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7W!A8VMA9V5F:6QE+3YV86QI
M9&%T92@D<W1A=&4I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]086-K86=E1FEL93H@
M:6YV86QI9"!P86-K86=E+GAM;"<L#0H@("`@("`@("`@("`@("`@;G5L;"P@
M;G5L;"P@;G5L;"P@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T5F%L:61A=&EO
M;E=A<FYI;F=S*"DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=VAE<F4@
M/3T](&YU;&PI('L-"B`@("`@("`@("`@(&EF("@A*"1W:&5R92`](%-Y<W1E
M;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*2DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ
M=&]086-K86=E1FEL93H@;6MT96UP(&9A:6QE9"<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!](&5L<V5I9B`H(4!3>7-T96TZ.FUK1&ER*&%R<F%Y*"<M
M<"<L("1W:&5R92DI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]086-K86=E1FEL93H@
M(B<@+B`D=VAE<F4@+B`G(B!C;W5L9"<@+@T*("`@("`@("`@("`@("`@("<@
M;F]T(&)E(&-R96%T960G*3L-"B`@("`@("`@?0T*("`@("`@("`D;F5W<&MG
M9FEL92`]("1W:&5R92`N($1)4D5#5$]265]315!!4D%43U(@+B`D;F%M93L-
M"B`@("`@("`@)&YP(#T@0&9O<&5N*"1N97=P:V=F:6QE+"`G=V(G*3L-"B`@
M("`@("`@:68@*"$D;G`I('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8R.CIT;U!A8VMA9V5&:6QE
M.B!U;F%B;&4@=&\@<V%V92`G("X-"B`@("`@("`@("`@("`@("(D;F%M92!A
M<R`D;F5W<&MG9FEL92(I.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET92@D
M;G`L("1T:&ES+3YT;UAM;"@D<W1A=&4I*3L-"B`@("`@("`@9F-L;W-E*"1N
M<"D[#0H@("`@("`@(')E='5R;B`D;F5W<&MG9FEL93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B`F=&]6,B@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H
M:7,M/E]P86-K86=E9FEL93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2
M971U<FX@86X@6$U,(&1O8W5M96YT(&)A<V5D(&]N('1H92!P86-K86=E(&EN
M9F\@*&%S(')E='5R;F5D#0H@("`@("H@8GD@=&AE(%!%05)?0V]M;6]N.CII
M;F9O1G)O;2H@;65T:&]D<RDN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!834P@9&%T80T*("`@("`J+PT*("`@(&9U;F-T:6]N('1O6&UL*"1S
M=&%T92`](%!%05)?5D%,241!5$5?3D]234%,+"`D;W!T:6]N<R`](&%R<F%Y
M*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YS971$
M871E*&1A=&4H)UDM;2UD)RDI.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5F
M:6QE+3YS9714:6UE*&1A=&4H)T@Z:3IS)RDI.PT*("`@("`@("!I9B`H(21T
M:&ES+3Y?<&%C:V%G969I;&4M/G9A;&ED871E*"1S=&%T92DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-?87)R87DH)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`D=&AI<RT^;W!T
M:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O
M<'1I;VYS*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES
M+3YO<'1I;VYS(#T@)'1H:7,M/E]D969A=6QT3W!T:6]N<SL-"B`@("`@("`@
M?0T*("`@("`@("`D87)R(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T07)R
M87DH*3L-"B`@("`@("`@:68@*&ES<V5T*"1A<G);)V9I;&5L:7-T)UTI*2![
M#0H@("`@("`@("`@("!U;G-E="@D87)R6R=F:6QE;&ES="==*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&%R<ELG7VQA<W1V97)S:6]N)UTI
M*2![#0H@("`@("`@("`@("!U;G-E="@D87)R6R=?;&%S='9E<G-I;VXG72D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1S=&%T92!>(%!%05)?5D%,241!
M5$5?4$%#2T%'24Y'("8F("%I<W-E="@D87)R6R=B=6YD;&4G72DI('L-"B`@
M("`@("`@("`@("1U<V4@/2`D=&AI<RT^7W)E8W5R<VEV95AM;$9I;&5L:7-T
M*"1A<G);)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI.PT*("`@("`@("`@
M("`@=6YS970H)&%R<ELG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72D[#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'5S95LG9&ER)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&%R<ELG8V]N=&5N=',G75LG9&ER)UU;)V1I<B==(#T@)'5S
M95LG9&ER)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'5S95LG9FEL92==*2D@>PT*("`@("`@("`@("`@("`@("1A<G);)V-O
M;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT@/2`D=7-E6R=F:6QE)UT[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<ULG8F5A=71I
M9GE&:6QE;&ES="==(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D87)R
M6R=A='1R:6)S)UU;)W!A8VMA9V5R=F5R<VEO;B==(#T@)S$N-"XY)SL-"B`@
M("`@("`@:68@*"1T:&ES+3YS97)I86QI>F4H)&%R<BP@)&]P=&EO;G,I*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S97)I86QI>F5D1&%T82`N
M(")<;B([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"@T*#0H@("`@9G5N8W1I;VX@7W)E8W5R<VEV95AM;$9I;&5L:7-T*"1L
M:7-T*0T*("`@('L-"B`@("`@("`@)&1I<G,@/2!A<G)A>2@I.PT*("`@("`@
M("!I9B`H:7-S970H)&QI<W1;)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@
M("1F:6QE(#T@)&QI<W1;)V%T=')I8G,G75LG;F%M92==.PT*("`@("`@("`@
M("`@=6YS970H)&QI<W1;)V%T=')I8G,G75LG;F%M92==*3L-"B`@("`@("`@
M("`@("1A='1R:6)U=&5S(#T@)&QI<W1;)V%T=')I8G,G73L-"B`@("`@("`@
M("`@("1T:&ES+3Y?861D1&ER*"1D:7)S+"!E>'!L;V1E*"<O)RP@9&ER;F%M
M92@D9FEL92DI+"`D9FEL92P@)&%T=')I8G5T97,I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&$I('L-"B`@
M("`@("`@("`@("`@("`D9FEL92`]("1A6R=A='1R:6)S)UU;)VYA;64G73L-
M"B`@("`@("`@("`@("`@("`D871T<FEB=71E<R`]("1A6R=A='1R:6)S)UT[
M#0H@("`@("`@("`@("`@("`@=6YS970H)&%;)V%T=')I8G,G72D[#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1$:7(H)&1I<G,L(&5X<&QO9&4H)R\G
M+"!D:7)N86UE*"1F:6QE*2DL("1F:6QE+"`D871T<FEB=71E<RP@)&$I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9F]R
M;6%T1&ER*"1D:7)S*3L-"B`@("`@("`@)'1H:7,M/E]D949O<FUA="@D9&ER
M<RD[#0H@("`@("`@(')E='5R;B`D9&ER<SL-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?861D1&ER*"8D9&ER<RP@)&1I<BP@)&9I;&4@/2!N=6QL+"`D871T
M<FEB=71E<R`](&YU;&PL("1T87-K<R`](&YU;&PI#0H@("`@>PT*("`@("`@
M("!I9B`H(21T87-K<RD@>PT*("`@("`@("`@("`@)'1A<VMS(#T@87)R87DH
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&1I<B`]/2!A<G)A>2@I('Q\
M("1D:7(@/3T@87)R87DH)RXG*2D@>PT*("`@("`@("`@("`@)&1I<G-;)V9I
M;&4G75MB87-E;F%M92@D9FEL92E=(#T@)'1A<VMS.PT*("`@("`@("`@("`@
M)&%T=')I8G5T97-;)VYA;64G72`](&)A<V5N86UE*"1F:6QE*3L-"B`@("`@
M("`@("`@("1D:7)S6R=F:6QE)UU;8F%S96YA;64H)&9I;&4I75LG871T<FEB
M<R==(#T@)&%T=')I8G5T97,[#0H@("`@("`@("`@("!R971U<FX[#0H@("`@
M("`@('T-"B`@("`@("`@)&-U<F1I<B`](&%R<F%Y7W-H:69T*"1D:7(I.PT*
M("`@("`@("!I9B`H(6ES<V5T*"1D:7)S6R=D:7(G75LD8W5R9&ER72DI('L-
M"B`@("`@("`@("`@("1D:7)S6R=D:7(G75LD8W5R9&ER72`](&%R<F%Y*"D[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]A9&1$:7(H)&1I<G-;)V1I
M<B==6R1C=7)D:7)=+"`D9&ER+"`D9FEL92P@)&%T=')I8G5T97,L("1T87-K
M<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V9O<FUA=$1I<B@F)&1I<G,I
M#0H@("`@>PT*("`@("`@("!I9B`H(6-O=6YT*"1D:7)S*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@)&YE
M=V1I<G,@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S970H)&1I<G-;)V1I
M<B==*2D@>PT*("`@("`@("`@("`@)&YE=V1I<G-;)V1I<B==(#T@)&1I<G-;
M)V1I<B==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&ER<ULG
M9FEL92==*2D@>PT*("`@("`@("`@("`@)&YE=V1I<G-;)V9I;&4G72`]("1D
M:7)S6R=F:6QE)UT[#0H@("`@("`@('T-"B`@("`@("`@)&1I<G,@/2`D;F5W
M9&ER<SL-"B`@("`@("`@:68@*&ES<V5T*"1D:7)S6R=D:7(G72DI('L-"B`@
M("`@("`@("`@('5K<V]R="@D9&ER<ULG9&ER)UTL("=S=')N871C87-E8VUP
M)RD[#0H@("`@("`@("`@("!F;W)E86-H("@D9&ER<ULG9&ER)UT@87,@)&1I
M<B`]/B`D8V]N=&5N=',I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O
M<FUA=$1I<B@D9&ER<ULG9&ER)UU;)&1I<ETI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&ER<ULG9FEL92==*2D@
M>PT*("`@("`@("`@("`@=6MS;W)T*"1D:7)S6R=F:6QE)UTL("=S=')N871C
M87-E8VUP)RD[#0H@("`@("`@('T[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7V1E1F]R;6%T*"8D9&ER<RD-"B`@("![#0H@("`@("`@(&EF("@A8V]U;G0H
M)&1I<G,I*2![#0H@("`@("`@("`@("!R971U<FX@87)R87DH*3L-"B`@("`@
M("`@?0T*("`@("`@("`D;F5W9&ER<R`](&%R<F%Y*"D[#0H@("`@("`@(&EF
M("AI<W-E="@D9&ER<ULG9&ER)UTI*2![#0H@("`@("`@("`@("!F;W)E86-H
M("@D9&ER<ULG9&ER)UT@87,@)&1I<B`]/B`D8V]N=&5N=',I('L-"B`@("`@
M("`@("`@("`@("`D;F5W9&ER(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`D;F5W9&ER6R=A='1R:6)S)UU;)VYA;64G72`]("1D:7([#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D949O<FUA="@D8V]N=&5N=',I.PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT<R!A<R`D=&%G(#T^("1V86PI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&YE=V1I<ELD=&%G72`]("1V86P[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=D:7)S
M6R=D:7(G75M=(#T@)&YE=V1I<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AC;W5N="@D;F5W9&ER<ULG9&ER)UTI(#T](#$I('L-"B`@("`@
M("`@("`@("`@("`D;F5W9&ER<ULG9&ER)UT@/2`D;F5W9&ER<ULG9&ER)UU;
M,%T[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1D:7)S6R=F:6QE)UTI*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M9&ER<ULG9FEL92==(&%S("1N86UE(#T^("1F:6QE*2![#0H@("`@("`@("`@
M("`@("`@)&YE=V1I<G-;)V9I;&4G75M=(#T@)&9I;&4[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&YE=V1I<G-;)V9I;&4G72D@
M/3T@,2D@>PT*("`@("`@("`@("`@("`@("1N97=D:7)S6R=F:6QE)UT@/2`D
M;F5W9&ER<ULG9FEL92==6S!=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@("1D:7)S(#T@)&YE=V1I<G,[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@*B!R97-E="!A;&P@;W!T:6]N<R!T;R!D969A=6QT(&]P=&EO;G,-
M"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<V5E("`@
M("`@<V5T3W!T:6]N*"DL(%A-3%]5;G-E<FEA;&EZ97(H*0T*("`@("HO#0H@
M("`@9G5N8W1I;VX@<F5S971/<'1I;VYS*"D-"B`@("![#0H@("`@("`@("1T
M:&ES+3YO<'1I;VYS(#T@)'1H:7,M/E]D969A=6QT3W!T:6]N<SL-"B`@("!]
M#0H-"B`@("\J*@T*("`@("H@<V5T(&%N(&]P=&EO;@T*("`@("H-"B`@("`J
M(%EO=2!C86X@=7-E('1H:7,@;65T:&]D(&EF('EO=2!D;R!N;W0@=V%N="!T
M;R!S970@86QL(&]P=&EO;G,@:6X@=&AE(&-O;G-T<G5C=&]R#0H@("`@*@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-E92`@("`@(')E<V5T
M3W!T:6]N*"DL(%A-3%]397)I86QI>F5R*"D-"B`@("`J+PT*("`@(&9U;F-T
M:6]N('-E=$]P=&EO;B@D;F%M92P@)'9A;'5E*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/F]P=&EO;G-;)&YA;65=(#T@)'9A;'5E.PT*("`@('T-"B`@("`-
M"B`@("\J*@T*("`@("H@<V5T<R!S979E<F%L(&]P=&EO;G,@870@;VYC90T*
M("`@("H-"B`@("`J(%EO=2!C86X@=7-E('1H:7,@;65T:&]D(&EF('EO=2!D
M;R!N;W0@=V%N="!T;R!S970@86QL(&]P=&EO;G,@:6X@=&AE(&-O;G-T<G5C
M=&]R#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-E
M92`@("`@(')E<V5T3W!T:6]N*"DL(%A-3%]5;G-E<FEA;&EZ97(H*2P@<V5T
M3W!T:6]N*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H)&]P
M=&EO;G,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y
M7VUE<F=E*"1T:&ES+3YO<'1I;VYS+"`D;W!T:6]N<RD[#0H@("`@?0T*#0H@
M("`O*BH-"B`@("`J('-E<FEA;&EZ92!D871A#0H@("`@*@T*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PT*("`@("H@0'!A<F%M("`@(&UI>&5D("`@("1D871A
M(&1A=&$@=&\@<V5R:6%L:7IE#0H@("`@*B!`<F5T=7)N("`@8F]O;&5A;B`@
M=')U92!O;B!S=6-C97-S+"!P96%R(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`J
M+PT*("`@(&9U;F-T:6]N('-E<FEA;&EZ92@D9&%T82P@)&]P=&EO;G,@/2!N
M=6QL*0T*("`@('L-"B`@("`@("`@+R\@:68@;W!T:6]N<R!H879E(&)E96X@
M<W!E8VEF:65D+"!U<V4@=&AE;2!I;G-T96%D#0H@("`@("`@("\O(&]F('1H
M92!P<F5V:6]U<VQY(&1E9FEN960@;VYE<PT*("`@("`@("!I9B`H:7-?87)R
M87DH)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`D;W!T:6]N<T)A:R`]("1T
M:&ES+3YO<'1I;VYS.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=O=F5R<FED94]P=&EO;G,G72D@)B8@)&]P=&EO;G-;)V]V97)R:61E3W!T
M:6]N<R==(#T]('1R=64I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;W!T
M:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O
M<'1I;VYS*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI<RT^;W!T:6]N
M<RP@)&]P=&EO;G,I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&5L<V4@>PT*("`@("`@("`@("`@)&]P=&EO;G-"86L@/2!N=6QL.PT*
M("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`O+R`@<W1A<G0@9&5P=&@@
M:7,@>F5R;PT*("`@("`@("`D=&AI<RT^7W1A9T1E<'1H(#T@,#L-"@T*("`@
M("`@("`D=&AI<RT^7W-E<FEA;&EZ961$871A(#T@)R<[#0H@("`@("`@("\O
M('-E<FEA;&EZ92!A;B!A<G)A>0T*("`@("`@("!I9B`H:7-?87)R87DH)&1A
M=&$I*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;
M)W)O;W1.86UE)UTI*2![#0H@("`@("`@("`@("`@("`@)'1A9TYA;64@/2`D
M=&AI<RT^;W!T:6]N<ULG<F]O=$YA;64G73L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)'1A9TYA;64@/2`G87)R87DG.PT*("`@
M("`@("`@("`@?0T*#0H@("`@("`@("`@("`D=&AI<RT^7W-E<FEA;&EZ961$
M871A("X]("1T:&ES+3Y?<V5R:6%L:7IE07)R87DH)&1A=&$L("1T86=.86UE
M+"`D=&AI<RT^;W!T:6]N<ULG<F]O=$%T=')I8G5T97,G72D[#0H@("`@("`@
M('T-"B`@("`@("`@#0H@("`@("`@("\O(&%D9"!D;V-T>7!E(&1E8VQA<F%T
M:6]N#0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG861D1&]C='EP92==
M(#T]/2!T<G5E*2![#0H@("`@("`@("`@("`D=&AI<RT^7W-E<FEA;&EZ961$
M871A(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ
M.F=E=$1O8W1Y<&5$96-L87)A=&EO;B@D=&%G3F%M92P@)'1H:7,M/F]P=&EO
M;G-;)V1O8W1Y<&4G72D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7W-E<FEA;&EZ
M961$871A.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@(&)U:6QD('AM;"!D
M96-L87)A=&EO;@T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V%D9$1E
M8VPG72D@>PT*("`@("`@("`@("`@)&%T=',@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6R=E;F-O9&EN9R==*2`I
M('L-"B`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2`D=&AI<RT^;W!T:6]N
M<ULG96YC;V1I;F<G73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&5N8V]D:6YG(#T@;G5L;#L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ9V5T6$U,1&5C;&%R871I
M;VXH)S$N,"<L("1E;F-O9&EN9RD-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`D=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7W-E
M<FEA;&EZ961$871A.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`-
M"@D):68@*"1O<'1I;VYS0F%K("$]/2!N=6QL*2![#0H)"0DD=&AI<RT^;W!T
M:6]N<R`]("1O<'1I;VYS0F%K.PT*"0E]#0H)"0T*("`@("`@("!R971U<FX@
M('1R=64[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&=E="!T:&4@<F5S=6QT
M(&]F('1H92!S97)I86QI>F%T:6]N#0H@("`@*@T*("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`J($!R971U<FX@<W1R:6YG('-E<FEA;&EZ960@6$U,#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!G971397)I86QI>F5D1&%T82@I#0H@("`@
M>PT*("`@("`@("!I9B`H)'1H:7,M/E]S97)I86QI>F5D1&%T82`]/2!N=6QL
M("D@>PT*("`@("`@("`@("`@<F5T=7)N("`D=&AI<RT^<F%I<V5%<G)O<B@G
M3F\@<V5R:6%L:7IE9"!D871A(&%V86EL86)L92X@57-E(%A-3%]397)I86QI
M>F5R.CIS97)I86QI>F4H*2!F:7)S="XG+"!834Q?4T5224%,25I%4E]%4E)/
M4E].3U]315))04Q)6D%424].*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)'1H:7,M/E]S97)I86QI>F5D1&%T83L-"B`@("!]#0H@("`@#0H@("`O
M*BH-"B`@("`J('-E<FEA;&EZ92!A;GD@=F%L=64-"B`@("`J#0H@("`@*B!4
M:&ES(&UE=&AO9"!C:&5C:W,@9F]R('1H92!T>7!E(&]F('1H92!V86QU92!A
M;F0@8V%L;',@=&AE(&%P<')O<')I871E(&UE=&AO9`T*("`@("H-"B`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("H@0'!A<F%M("!M:7AE9"`@("`@)'9A
M;'5E#0H@("`@*B!`<&%R86T@('-T<FEN9R`@("`D=&%G3F%M90T*("`@("H@
M0'!A<F%M("!A<G)A>2`@("`@)&%T=')I8G5T97,-"B`@("`J($!R971U<FX@
M<W1R:6YG#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?<V5R:6%L:7IE5F%L=64H
M)'9A;'5E+"`D=&%G3F%M92`](&YU;&PL("1A='1R:6)U=&5S(#T@87)R87DH
M*2D-"B`@("![#0H@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2![#0H@
M("`@("`@("`@("`D>&UL(#T@)'1H:7,M/E]S97)I86QI>F5!<G)A>2@D=F%L
M=64L("1T86=.86UE+"`D871T<FEB=71E<RD[#0H@("`@("`@('T@96QS96EF
M("AI<U]O8FIE8W0H)'9A;'5E*2D@>PT*("`@("`@("`@("`@)'AM;"`]("1T
M:&ES+3Y?<V5R:6%L:7IE3V)J96-T*"1V86QU92P@)'1A9TYA;64I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1A9R`](&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<6YA;64G("`@("`@/3X@)'1A9TYA
M;64L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&5S)R`]
M/B`D871T<FEB=71E<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O
M;G1E;G0G("`@(#T^("1V86QU90T*("`@("`@("`@("`@("`@("`@("`@("`@
M*3L-"B`@("`@("`@("`@("1X;6P@/2`D=&AI<RT^7V-R96%T95A-3%1A9R@D
M=&%G*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'AM;#L-"B`@("!]
M#0H@("`@#0H@("`O*BH-"B`@("`J('-E<FEA;&EZ92!A;B!A<G)A>0T*("`@
M("H-"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B!`<&%R86T@("`@
M87)R87D@("`D87)R87D@("`@("`@87)R87D@=&\@<V5R:6%L:7IE#0H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`D=&%G3F%M92`@("`@;F%M92!O9B!T:&4@
M<F]O="!T86<-"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1A='1R:6)U=&5S
M("!A='1R:6)U=&5S(&9O<B!T:&4@<F]O="!T86<-"B`@("`J($!R971U<FX@
M("!S=')I;F<@("1S=')I;F<@("`@("!S97)I86QI>F5D(&1A=&$-"B`@("`J
M($!U<V5S("`@("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?
M571I;#HZ:7-686QI9$YA;64H*2!T;R!C:&5C:RP@=VAE=&AE<B!K97D@:&%S
M('1O(&)E('-U8G-T:71U=&5D#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?<V5R
M:6%L:7IE07)R87DH)B1A<G)A>2P@)'1A9TYA;64@/2!N=6QL+"`D871T<FEB
M=71E<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D7V-O;G1E;G0@/2!N
M=6QL.PT*("`@("`@("`-"B`@("`@("`@+RHJ#0H@("`@("`@("`J(&-H96-K
M(&9O<B!S<&5C:6%L(&%T=')I8G5T97,-"B`@("`@("`@("HO#0H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG871T<FEB=71E<T%R<F%Y)UT@(3T](&YU
M;&PI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D87)R87E;)'1H:7,M/F]P
M=&EO;G-;)V%T=')I8G5T97-!<G)A>2==72DI('L-"B`@("`@("`@("`@("`@
M("`D871T<FEB=71E<R`]("1A<G)A>5LD=&AI<RT^;W!T:6]N<ULG871T<FEB
M=71E<T%R<F%Y)UU=.PT*("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD
M=&AI<RT^;W!T:6]N<ULG871T<FEB=71E<T%R<F%Y)UU=*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("\J*@T*("`@("`@("`@("`@("H@8VAE8VL@
M9F]R('-P96-I86P@8V]N=&5N=`T*("`@("`@("`@("`@("HO#0H@("`@("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V-O;G1E;G1.86UE)UT@(3T](&YU
M;&PI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1T:&ES
M+3YO<'1I;VYS6R=C;VYT96YT3F%M92==72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)%]C;VYT96YT(#T@)&%R<F%Y6R1T:&ES+3YO<'1I;VYS6R=C;VYT
M96YT3F%M92==73L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%R<F%Y
M6R1T:&ES+3YO<'1I;VYS6R=C;VYT96YT3F%M92==72D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@
M+RH-"B`@("`@("`@*B!I9B!M;V1E(&ES('-E="!T;R!S:6UP;&5834PL(&-H
M96-K('=H971H97(-"B`@("`@("`@*B!T:&4@87)R87D@:7,@87-S;V-I871I
M=F4@;W(@:6YD97AE9`T*("`@("`@("`J+PT*("`@("`@("!I9B`H:7-?87)R
M87DH)&%R<F%Y*2`F)B`D=&AI<RT^;W!T:6]N<ULG;6]D92==(#T]("=S:6UP
M;&5X;6PG*2![#0H@("`@("`@("`@("`D:6YD97AE9"`]('1R=64[#0H@("`@
M("`@("`@("!I9B`H(6-O=6YT*"1A<G)A>2DI('L-"B`@("`@("`@("`@("`@
M("`D:6YD97AE9"`](&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A;"D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A:7-?:6YT*"1K97DI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1I;F1E>&5D(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"@T*
M("`@("`@("`@("`@:68@*"1I;F1E>&5D("8F("1T:&ES+3YO<'1I;VYS6R=M
M;V1E)UT@/3T@)W-I;7!L97AM;"<I('L-"B`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@)R<[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S
M("1K97D@/3X@)'9A;"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)V)E875T:69Y1FEL96QI<W0G72`F)B`D=&%G3F%M92`]
M/2`G9&ER)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V-U<F1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-U<F1I<B`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'-A=F5D:7(@/2`D
M=&AI<RT^7V-U<F1I<CL-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=F%L6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1V86Q;)V%T=')I8G,G75LG;F%M92==(#T]("<O)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U
M<F1I<B`]("<O)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]C=7)D:7(@/3T@)R\G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-U<F1I<B`]("<G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8W5R9&ER("X]("<O)R`N("1V86Q;)V%T
M=')I8G,G75LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("1T:&ES
M+3Y?<V5R:6%L:7IE5F%L=64H("1V86PL("1T86=.86UE+"`D871T<FEB=71E
M<RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M8F5A=71I9GE&:6QE;&ES="==("8F("1T86=.86UE(#T]("=D:7(G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("<@/"$M+2`G("X@
M)'1H:7,M/E]C=7)D:7(@+B`G("TM/B<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H96UP='DH)'-A=F5D:7(I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=6YS970H)'1H:7,M/E]C=7)D:7(I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-U<F1I<B`]("1S879E9&ER.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(`T*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG
M("X]("1T:&ES+3YO<'1I;VYS6R=L:6YE8G)E86LG73L-"B`@("`@("`@"0D)
M+R\)9&\@:6YD96YT871I;VX-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=I;F1E;G0G72$]/6YU;&P@)B8@)'1H:7,M/E]T86=$
M97!T:#XP*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]
M('-T<E]R97!E870H)'1H:7,M/F]P=&EO;G-;)VEN9&5N="==+"`D=&AI<RT^
M7W1A9T1E<'1H*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@<G1R:6TH)'-T<FEN
M9RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@#0H)"6EF
M("@D=&AI<RT^;W!T:6]N<ULG<V-A;&%R07-!='1R:6)U=&5S)UT@/3T]('1R
M=64I('L-"@D@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V
M86QU92D@>PT*"0D)"6EF("AI<U]S8V%L87(H)'9A;'5E*2`F)B`H4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES5F%L:61.86UE
M*"1K97DI(#T]/2!T<G5E*2D@>PT*"0D)"0EU;G-E="@D87)R87E;)&ME>5TI
M.PT*"0D)"0DD871T<FEB=71E<ULD=&AI<RT^;W!T:6]N<ULG<')E<&5N9$%T
M=')I8G5T97,G72XD:V5Y72`]("1V86QU93L-"@D)"0E]#0H)"0E]#0H)"7T-
M"@T*("`@("`@("`O+R!C:&5C:R!F;W(@96UP='D@87)R87D@/3X@8W)E871E
M(&5M<'1Y('1A9PT*("`@("`@("!I9B`H96UP='DH)&%R<F%Y*2D@>PT*("`@
M("`@("`@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=Q;F%M92<@("`@("`]/B`D=&%G3F%M92P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8V]N=&5N="<@("`@/3X@)%]C;VYT96YT+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&5S)R`]/B`D
M871T<FEB=71E<PT*("`@("`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=$97!T:"LK
M.PT*("`@("`@("`@("`@)'1M<"`]("1T:&ES+3YO<'1I;VYS6R=L:6YE8G)E
M86LG73L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^
M("1V86QU92D@>PT*("`@(`D)"2\O"61O(&EN9&5N=&%T:6]N#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G0G72$]/6YU;&P@
M)B8@)'1H:7,M/E]T86=$97!T:#XP*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T;7`@+CT@<W1R7W)E<&5A="@D=&AI<RT^;W!T:6]N<ULG:6YD96YT)UTL
M("1T:&ES+3Y?=&%G1&5P=&@I.PT*("`@("`@("`@("`@("`@('T-"B`@("`-
M"B`@("`)"0DO+PEC;W!Y(&ME>0T*("`@(`D)"21O<FEG2V5Y"3T))&ME>3L-
M"B`@("`)"0DO+PEK97D@8V%N;F]T(&)E('5S960@87,@=&%G;F%M92`]/B!U
M<V4@9&5F875L="!T86<-"B`@("`@("`@("`@("`@("`D=F%L:60@/2!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ:7-686QI9$YA
M;64H)&ME>2D[#0H@("`@"2`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'9A
M;&ED*2D@>PT*("`@(`D@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)V-L87-S07-486=.86UE)UT@)B8@:7-?;V)J96-T*"1V86QU92DI('L-"B`@
M("`)("`@("`@("`@("`@("`@("1K97D@/2!G971?8VQA<W,H)'9A;'5E*3L-
M"B`@("`)("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(`D@("`@
M("`@("1K97D@/2`D=&AI<RT^;W!T:6]N<ULG9&5F875L=%1A9TYA;64G73L-
M"B`@("`)("`@("`@("`@("`@?0T*("`@("`@("`@("`)(`E]#0H@("`@("`@
M("`@("`@("`@)&%T=',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG='EP94AI;G1S)UT@/3T]('1R=64I('L-"B`@
M("`@("`@("`@("`@("`@("`@)&%T='-;)'1H:7,M/F]P=&EO;G-;)W1Y<&5!
M='1R:6)U=&4G75T@/2!G971T>7!E*"1V86QU92D[#0H@("`@"0D)"6EF("@D
M:V5Y("$]/2`D;W)I9TME>2D@>PT*("`@(`D)"0D))&%T='-;)'1H:7,M/F]P
M=&EO;G-;)VME>4%T=')I8G5T92==72`]("AS=')I;F<I)&]R:6=+97D[#0H@
M("`@"0D)"7T-"B`@("`-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=B96%U=&EF>49I;&5L:7-T)UT@
M)B8@)&ME>2`]/2`G9&ER)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?8W5R9&ER*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C=7)D:7(@/2`G)SL-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`D<V%V961I<B`]("1T:&ES+3Y?
M8W5R9&ER.PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;'5E
M6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)'9A;'5E6R=A='1R:6)S)UU;)VYA;64G72`]/2`G+R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<F1I<B`]("<O)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)D:7(@+CT@)R\G("X@)'9A;'5E
M6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@("`@(&EF("AI<U]S=')I;F<H)'9A;'5E*2`F)B`D
M=F%L=64@)B8@*"1V86QU97MS=')L96XH)'9A;'5E*2`M(#%](#T](")<;B(I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1V86QU92`N/2!S=')?<F5P96%T
M*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$97!T:"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T;7`@+CT@
M)'1H:7,M/E]C<F5A=&5834Q486<H87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W%N86UE)R`@
M("`@(#T^("1K97DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1S+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C;VYT96YT)R`@("`]/B`D=F%L=64@*0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG8F5A=71I9GE&:6QE;&ES="==
M("8F("1K97D@/3T@)V1I<B<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1V86QU95LG871T<FEB<R==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1M<"`N/2`G(#PA+2T@)R`N("1T:&ES+3Y?8W5R9&ER("X@
M)R`M+3XG.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1S
M879E9&ER*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?8W5R9&ER*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M=7)D:7(@/2`D<V%V961I<CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D=&UP("X]("1T:&ES+3YO<'1I;VYS6R=L:6YE8G)E
M86LG73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(`T*("`@("`@("`@
M("`@)'1H:7,M/E]T86=$97!T:"TM.PT*("`@("`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6R=I;F1E;G0G72$]/6YU;&P@)B8@)'1H:7,M/E]T86=$97!T
M:#XP*2![#0H@("`@("`@("`@("`@("`@)'1M<"`N/2!S=')?<F5P96%T*"1T
M:&ES+3YO<'1I;VYS6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$97!T:"D[#0H@
M("`@("`@("`@("!]#0H@("`@#0H@("`@"0EI9B`H=')I;2@D=&UP*2`]/3T@
M)R<I('L-"B`@("`)"0DD=&UP(#T@;G5L;#L-"B`@("`)"7T-"B`@("`)"0T*
M("`@("`@("`@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=Q;F%M92<@("`@("`]/B`D=&%G3F%M92P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8V]N=&5N="<@("`@/3X@)'1M<"P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E<R<@/3X@)&%T
M=')I8G5T97,-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=T>7!E2&EN=',G72`]
M/3T@=')U92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&%G6R=A='1R
M:6)U=&5S)UU;)'1H:7,M/F]P=&EO;G-;)W1Y<&5!='1R:6)U=&4G75TI*2![
M#0H@("`@("`@("`@("`@("`@)'1A9ULG871T<FEB=71E<R==6R1T:&ES+3YO
M<'1I;VYS6R=T>7!E071T<FEB=71E)UU=(#T@)V%R<F%Y)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("1S=')I;F<@/2`D=&AI<RT^
M7V-R96%T95A-3%1A9R@D=&%G+"!F86QS92D[#0H@("`@("`@(')E='5R;B`D
M<W1R:6YG.PT*("`@('T-"B`@#0H@("`O*BH-"B`@("`J(&-R96%T92!A('1A
M9R!F<F]M(&%N(&%R<F%Y#0H@("`@*B!T:&ES(&UE=&AO9"!A=V%I=',@86X@
M87)R87D@:6X@=&AE(&9O;&QO=VEN9R!F;W)M870-"B`@("`J(&%R<F%Y*`T*
M("`@("H@("`@("`@)W%N86UE)R`@("`@("`@/3X@)'1A9TYA;64L#0H@("`@
M*B`@("`@("`G871T<FEB=71E<R<@("`]/B!A<G)A>2@I+`T*("`@("H@("`@
M("`@)V-O;G1E;G0G("`@("`@/3X@)&-O;G1E;G0L("`@("`@+R\@;W!T:6]N
M86P-"B`@("`J("`@("`@("=N86UE<W!A8V4G("`@(#T^("1N86UE<W!A8V4@
M("`@("\O(&]P=&EO;F%L#0H@("`@*B`@("`@("`G;F%M97-P86-E57)I)R`]
M/B`D;F%M97-P86-E57)I("`O+R!O<'1I;VYA;`T*("`@("H@("`I#0H@("`@
M*@T*("`@("H@0&%C8V5S<R`@('!R:79A=&4-"B`@("`J($!P87)A;2`@("!A
M<G)A>2`@("1T86<@=&%G(&1E9FEN:71I;VX-"B`@("`J($!P87)A;2`@("!B
M;V]L96%N("1R97!L86-E16YT:71I97,@=VAE=&AE<B!T;R!R97!L86-E(%A-
M3"!E;G1I=&EE<R!I;B!C;VYT96YT(&]R(&YO=`T*("`@("H@0')E='5R;B`@
M('-T<FEN9R`@)'-T<FEN9R!834P@=&%G#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!?8W)E871E6$U,5&%G*"`D=&%G+"`D<F5P;&%C945N=&ET:65S(#T@=')U
M92`I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)VEN9&5N
M=$%T=')I8G5T97,G72`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("1M=6QT
M:6QI;F4@/2!T<G5E.PT*("`@("`@("`@("`@)&EN9&5N="`@("`]('-T<E]R
M97!E870H)'1H:7,M/F]P=&EO;G-;)VEN9&5N="==+"`D=&AI<RT^7W1A9T1E
M<'1H*3L-"@T*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=I;F1E
M;G1!='1R:6)U=&5S)UT@/3T@)U]A=71O)RD@>PT*("`@("`@("`@("`@("`@
M("1I;F1E;G0@+CT@<W1R7W)E<&5A="@G("<L("AS=')L96XH)'1A9ULG<6YA
M;64G72DK,BDI.PT*#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1I;F1E;G0@+CT@)'1H:7,M/F]P=&EO;G-;)VEN9&5N=$%T=')I
M8G5T97,G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1M=6QT:6QI;F4@/2!F86QS93L-"B`@("`@("`@("`@("1I
M;F1E;G0@("`@/2!F86QS93L-"B`@("`@("`@?0T*("`@(`T*("`@("`@("!I
M9B`H:7-?87)R87DH)'1A9ULG8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@
M:68@*&5M<'1Y*"1T86=;)V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@("`@
M("`D=&%G6R=C;VYT96YT)UT@/2`@("<G.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!](&5L<V5I9BAI<U]S8V%L87(H)'1A9ULG8V]N=&5N="==*2`F)B`H
M<W1R:6YG*21T86=;)V-O;G1E;G0G72`]/2`G)RD@>PT*("`@("`@("`@("`@
M)'1A9ULG8V]N=&5N="==(#T@("`G)SL-"B`@("`@("`@?0T*("`@(`T*("`@
M("`@("!I9B`H:7-?<V-A;&%R*"1T86=;)V-O;G1E;G0G72D@?'P@:7-?;G5L
M;"@D=&%G6R=C;VYT96YT)UTI*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;)V5N8V]D:6YG)UT@/3T@)U541BTX)R`F)@T*("`@("`@("`@
M("`@("`@("`@=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP
M)RP@)VQT)RDI('L-"B`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]5
M5$8X7UA-3#L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)&5N8V]D:6YG(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6Q?14Y4251)15-?6$U,.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)'1A9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-
M3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RP@)')E<&QA8V5%;G1I
M=&EE<RP@)&UU;'1I;&EN92P@)&EN9&5N="P@)'1H:7,M/F]P=&EO;G-;)VQI
M;F5B<F5A:R==+"`D96YC;V1I;F<I.PT*("`@("`@("!](&5L<V5I9B`H:7-?
M87)R87DH)'1A9ULG8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@)'1A9R`@
M("`]("`@)'1H:7,M/E]S97)I86QI>F5!<G)A>2@D=&%G6R=C;VYT96YT)UTL
M("1T86=;)W%N86UE)UTL("1T86=;)V%T=')I8G5T97,G72D[#0H@("`@("`@
M('T@96QS96EF("AI<U]O8FIE8W0H)'1A9ULG8V]N=&5N="==*2D@>PT*("`@
M("`@("`@("`@)'1A9R`@("`]("`@)'1H:7,M/E]S97)I86QI>F5/8FIE8W0H
M)'1A9ULG8V]N=&5N="==+"`D=&%G6R=Q;F%M92==+"`D=&%G6R=A='1R:6)U
M=&5S)UTI.PT*("`@("`@("!](&5L<V5I9B`H:7-?<F5S;W5R8V4H)'1A9ULG
M8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@<V5T='EP92@D=&%G6R=C;VYT
M96YT)UTL("=S=')I;F<G*3L-"B`@("`@("`@("`@("1T86<@("`@/2`@(%!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&54
M86=&<F]M07)R87DH)'1A9RP@)')E<&QA8V5%;G1I=&EE<RD[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("`D=&%G.PT*("`@('T-"GT-"@T*+R\@=V5L
M;"P@:70G<R!O;F4@=V%Y('1O(&1O('1H:6YG<R!W:71H;W5T(&5X=')A(&1E
M<',@+BXN#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-#H@*B\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#(@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!3=&5P:&%N
M(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^("`@("`@("`@("`@("`@
M("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M#0HO+R`@("`D260Z('8R+G!H<"QV(#$N,S0@,C`P-B\P,R\P,B`R,#HU,#HU
M.2!C96QL;V<@17AP("0-"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!I;G9A
M;&ED(&-H87)S(&EN(%A-3"!N86UE#0H@*B\-"F1E9FEN92@B4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?15)23U)?24Y604Q)1%]#
M2$%24R(L(#4Q*3L-"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!I;G9A;&ED
M(&-H87)S(&EN(%A-3"!N86UE#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?15)23U)?24Y604Q)1%]35$%2
M5"(L(#4R*3L-"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!N;VXM<V-A;&%R
M('1A9R!C;VYT96YT#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6Q?15)23U)?3D].7U-#04Q!4E]#3TY414Y4
M(BP@-C`I.PT*("`@(`T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!M:7-S:6YG
M('1A9R!N86UE#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?15)23U)?3D]?5$%'7TY!344B+"`V,2D[#0H@
M("`@#0HO*BH-"B`J(')E<&QA8V4@6$U,(&5N=&ET:65S#0H@*B\-"F1E9FEN
M92@B4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?4D50
M3$%#15]%3E1)5$E%4R(L(#$I.PT*#0HO*BH-"B`J(&5M8F5D9"!C;VYT96YT
M(&EN(&$@0T1A=&$@4V5C=&EO;@T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T-$051!7U-%0U1)3TXB+"`R
M*3L-"@T*+RHJ#0H@*B!D;R!N;W0@<F5P;&%C92!E;G1I=&ET97,-"B`J+PT*
M9&5F:6YE*")014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I
M;%]%3E1)5$E%4U].3TY%(BP@,"D[#0H-"B\J*@T*("H@<F5P;&%C92!A;&P@
M6$U,(&5N=&ET:71E<PT*("H@5&AI<R!S971T:6YG('=I;&P@<F5P;&%C92`\
M+"`^+"`B+"`G(&%N9"`F#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,(BP@,2D[#0H-
M"B\J*@T*("H@<F5P;&%C92!O;FQY(')E<75I<F5D(%A-3"!E;G1I=&ET97,-
M"B`J(%1H:7,@<V5T=&EN9R!W:6QL(')E<&QA8V4@/"P@(B!A;F0@)@T*("HO
M#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5
M=&EL7T5.5$E424537UA-3%]215%525)%1"(L(#(I.PT*#0HO*BH-"B`J(')E
M<&QA8V4@2%1-3"!E;G1I=&ET97,-"B`J($!L:6YK("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]H=&UL96YT:71I97,-"B`J+PT*9&5F:6YE*")014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U](5$U,(BP@
M,RD[#0H-"B\J*@T*("H@<F5P;&%C92!A;&P@6$U,(&5N=&ET:71E<RP@86YD
M(&5N8V]D92!F<F]M($E33RTX.#4Y+3$@=&\@551&+3@-"B`J(%1H:7,@<V5T
M=&EN9R!W:6QL(')E<&QA8V4@/"P@/BP@(BP@)R!A;F0@)@T*("HO#0ID969I
M;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.
M5$E424537U541CA?6$U,(BP@-"D[#0H-"B\J*@T*("H@=71I;&ET>2!C;&%S
M<R!F;W(@=V]R:VEN9R!W:71H(%A-3"!D;V-U;65N=',-"B`J(`T*("H@8W5S
M=&]M:7IE9"!V97)S:6]N(&]F(%A-3%]5=&EL(#`N-BXP#0H@*@T*("H@0&-A
M=&5G;W)Y(%A-3`T*("H@0'!A8VMA9V4@(%!%05(-"B`J($!V97)S:6]N("`P
M+C8N,`T*("H@0&%U=&AO<B`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("!'<F5G;W)Y($)E879E<B`\8V5L;&]G0'!H
M<"YN970^#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL('L-"@T*("`@+RHJ#0H@("`@*B!R971U<FX@05!)('9E
M<G-I;VX-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`
M<W1A=&EC#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D=F5R<VEO;B!!4$D@
M=F5R<VEO;@T*("`@("HO#0H@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@(C`N-B([#0H@("`@?0T*#0H@("`O*BH-
M"B`@("`J(')E<&QA8V4@6$U,(&5N=&ET:65S#0H@("`@*@T*("`@("H@5VET
M:"!T:&4@;W!T:6]N86P@<V5C;VYD('!A<F%M971E<BP@>6]U(&UA>2!S96QE
M8W0L('=H:6-H#0H@("`@*B!E;G1I=&EE<R!S:&]U;&0@8F4@<F5P;&%C960N
M#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-
M3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(')E<&QA8V4@6$U,(&5N
M=&ET97,Z#0H@("`@*B`D<W1R:6YG(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@B5&AI<R!S=')I
M;F<@8V]N=&%I;G,@/"`F(#XN(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@<W1R:6YG('=H97)E(%A-3"!S<&5C:6%L(&-H
M87)S('-H;W5L9"!B92!R97!L86-E9`T*("`@("H@0'!A<F%M("`@(&EN=&5G
M97(@<V5T=&EN9R!F;W(@96YT:71I97,@:6X@871T<FEB=71E('9A;'5E<R`H
M;VYE(&]F(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M7T5.5$E424537UA-3"P@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6Q?14Y4251)15-?6$U,7U)%455)4D5$+"!014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U](5$U,*0T*("`@
M("H@0')E='5R;B`@('-T<FEN9R`@<W1R:6YG('=I=&@@<F5P;&%C960@8VAA
M<G,-"B`@("`J+PT*("`@(&9U;F-T:6]N(')E<&QA8V5%;G1I=&EE<R@D<W1R
M:6YG+"`D<F5P;&%C945N=&ET:65S(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,*0T*("`@('L-"B`@("`@
M("`@<W=I=&-H("@D<F5P;&%C945N=&ET:65S*2![#0H@("`@("`@("`@("!C
M87-E(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.
M5$E424537U541CA?6$U,.@T*("`@("`@("`@("`@("`@(')E='5R;B!S=')T
M<BAU=&8X7V5N8V]D92@D<W1R:6YG*2QA<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<F)R`@/3X@)R9A;7`[)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<^
M)R`@/3X@)R9G=#LG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)SPG("`]/B`G)FQT.R<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(B<@(#T^("<F<75O=#LG+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)UPG
M)R`]/B`G)F%P;W,[)R`I*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@(&-A<V4@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6Q?14Y4251)15-?6$U,.@T*("`@("`@("`@("`@("`@(')E='5R
M;B!S=')T<B@D<W1R:6YG+&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R8G("`]/B`G)F%M<#LG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SXG("`]/B`G
M)F=T.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/"<@(#T^("<F;'0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B)R`@/3X@)R9Q=6]T.R<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7"<G(#T^("<F
M87!O<SLG("DI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I
M;%]%3E1)5$E%4U]834Q?4D5154E2140Z#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('-T<G1R*"1S=')I;F<L87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G)B<@(#T^("<F86UP.R<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/"<@(#T^
M("<F;'0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<B)R`@/3X@)R9Q=6]T.R<@*2D[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E(%!%05)?4&%C:V%G949I;&5?1V5N
M97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537TA434PZ#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(&AT;6QS<&5C:6%L8VAA<G,H)'-T<FEN9RD[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1S=')I;F<[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&)U:6QD(&%N('AM
M;"!D96-L87)A=&EO;@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q
M=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!G
M970@86X@6$U,(&1E8VQA<F%T:6]N.@T*("`@("H@)'AM;$1E8VP@/2!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ9V5T6$U,1&5C
M;&%R871I;VXH(C$N,"(L(")55$8M."(L('1R=64I.PT*("`@("H@/"]C;V1E
M/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T
M:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1V97)S:6]N("`@("!X;6P@
M=F5R<VEO;@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&5N8V]D:6YG("`@
M(&-H87)A8W1E<B!E;F-O9&EN9PT*("`@("H@0'!A<F%M("`@(&)O;VQE86X@
M)'-T86YD06QO;F4@(&1O8W5M96YT(&ES('-T86YD86QO;F4@*&]R(&YO="D-
M"B`@("`J($!R971U<FX@("!S=')I;F<@("1D96-L('AM;"!D96-L87)A=&EO
M;@T*("`@("H@0'5S97,@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H*2!T;R!S97)I86QI
M>F4@=&AE(&%T=')I8G5T97,@;V8@=&AE(%A-3"!D96-L87)A=&EO;@T*("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T6$U,1&5C;&%R871I;VXH)'9E<G-I;VX@
M/2`B,2XP(BP@)&5N8V]D:6YG(#T@;G5L;"P@)'-T86YD86QO;F4@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B=F5R<VEO;B(@/3X@)'9E<G-I;VXL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`O+R!A
M9&0@96YC;V1I;F<-"B`@("`@("`@:68@*"1E;F-O9&EN9R`A/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@)&%T=')I8G5T97-;(F5N8V]D:6YG(ET@/2`D96YC
M;V1I;F<[#0H@("`@("`@('T-"B`@("`@("`@+R\@861D('-T86YD86QO;F4L
M(&EF('-P96-I9FEE9`T*("`@("`@("!I9B`H)'-T86YD86QO;F4@(3T](&YU
M;&PI('L-"B`@("`@("`@("`@("1A='1R:6)U=&5S6R)S=&%N9&%L;VYE(ET@
M/2`D<W1A;F1A;&]N92`_(")Y97,B(#H@(FYO(CL-"B`@("`@("`@?0T*("`@
M("`@("`-"B`@("`@("`@<F5T=7)N('-P<FEN=&8H(CP_>&UL)7,_/B(L(%!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIA='1R:6)U
M=&5S5&]3=')I;F<H)&%T=')I8G5T97,L(&9A;'-E*2D[#0H@("`@?0T*#0H@
M("`O*BH-"B`@("`J(&)U:6QD(&$@9&]C=6UE;G0@='EP92!D96-L87)A=&EO
M;@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=8
M34PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!G970@82!D;V-T>7!E
M(&1E8VQA<F%T:6]N.@T*("`@("H@)'AM;$1E8VP@/2!014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ9V5T1&]C5'EP941E8VQA<F%T
M:6]N*")R;V]T5&%G(BPB;7E$;V-4>7!E+F1T9"(I.PT*("`@("H@/"]C;V1E
M/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T
M:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1R;V]T("`@("`@("`@;F%M
M92!O9B!T:&4@<F]O="!T86<-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1U
M<FD@("`@("`@("`@=7)I(&]F('1H92!D;V-T>7!E(&1E9FEN:71I;VX@*&]R
M(&%R<F%Y('=I=&@@=7)I(&%N9"!P=6)L:6,@:60I#0H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`D:6YT97)N86Q$=&0@(&EN=&5R;F%L(&1T9"!E;G1R:65S
M("`@#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D9&5C;"`@("`@("`@(&1O
M8W1Y<&4@9&5C;&%R871I;VX-"B`@("`J($!S:6YC92`@("`P+C(-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=$1O8U1Y<&5$96-L87)A=&EO;B@D<F]O="P@
M)'5R:2`](&YU;&PL("1I;G1E<FYA;$1T9"`](&YU;&PI#0H@("`@>PT*("`@
M("`@("!I9B`H:7-?87)R87DH)'5R:2DI('L-"B`@("`@("`@("`@("1R968@
M/2!S<')I;G1F*"`G(%!50DQ)0R`B)7,B("(E<R(G+"`D=7)I6R)I9")=+"`D
M=7)I6R)U<FDB72`I.PT*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1U<FDI
M*2![#0H@("`@("`@("`@("`D<F5F(#T@<W!R:6YT9B@@)R!365-414T@(B5S
M(B<L("1U<FD@*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R
M968@/2`B(CL-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("AE;7!T>2@D:6YT
M97)N86Q$=&0I*2![#0H@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@B/"%$
M3T-465!%("5S)7,^(BP@)')O;W0L("1R968I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H(CPA1$]#5%E012`E<R5S
M(%M<;B5S7&Y=/B(L("1R;V]T+"`D<F5F+"`D:6YT97)N86Q$=&0I.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&-R96%T92!S=')I;F<@
M<F5P<F5S96YT871I;VX@;V8@86X@871T<FEB=71E(&QI<W0-"B`@("`J#0H@
M("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP
M)SL-"B`@("`J(`T*("`@("H@+R\@8G5I;&0@86X@871T<FEB=71E('-T<FEN
M9PT*("`@("H@)&%T="`](&%R<F%Y*`T*("`@("H@("`@("`@("`@("`@(")F
M;V\B("`@/3X@(")B87(B+`T*("`@("H@("`@("`@("`@("`@(")A<F=H(B`@
M/3X@(")T;VUA=&\B#0H@("`@*B`@("`@("`@("`@("D[#0H@("`@*@T*("`@
M("H@)&%T=$QI<W0@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]8
M34Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='0I.R`@("`-"B`@("`J
M(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@("`D871T
M<FEB=71E<R`@("`@("`@871T<FEB=71E(&%R<F%Y#0H@("`@*B!`<&%R86T@
M("`@8F]O;&5A;GQA<G)A>2`D<V]R="`@("`@("`@("`@("`@<V]R="!A='1R
M:6)U=&4@;&ES="!A;'!H86)E=&EC86QL>2P@;6%Y(&%L<V\@8F4@86X@87-S
M;V,@87)R87D@8V]N=&%I;FEN9R!T:&4@:V5Y<R`G<V]R="<L("=M=6QT:6QI
M;F4G+"`G:6YD96YT)RP@)VQI;F5B<F5A:R<@86YD("=E;G1I=&EE<R<-"B`@
M("`J($!P87)A;2`@("!B;V]L96%N("`@("`@("1M=6QT:6QI;F4@("`@("`@
M("!U<V4@;&EN96)R96%K<RP@:68@;6]R92!T:&%N(&]N92!A='1R:6)U=&4@
M:7,@9VEV96X-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("1I;F1E
M;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!F;W(@:6YD96YT871I;VX@;V8@
M;75L=&EL:6YE(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("`@("`@("1L:6YE8G)E86L@("`@("`@("!S=')I;F<@=7-E9"!F;W(@;&EN
M96)R96%K<R!O9B!M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("H@0'!A<F%M
M("`@(&EN=&5G97(@("`@("`@)&5N=&ET:65S("`@("`@("`@('-E='1I;F<@
M9F]R(&5N=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,@*&]N92!O9B!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U].
M3TY%+"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%
M3E1)5$E%4U]834PL(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-
M3%]5=&EL7T5.5$E424537UA-3%]215%525)%1"P@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?2%1-3"D-"B`@("`J
M($!R971U<FX@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&%T=')I8G5T97,-"B`@("`J
M($!U<V5S("`@("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?
M571I;#HZ<F5P;&%C945N=&ET:65S*"D@=&\@<F5P;&%C92!834P@96YT:71I
M97,@:6X@871T<FEB=71E('9A;'5E<PT*("`@("H@0'1O9&\@("`@(&%L;&]W
M('-O<G0@86QS;R!T;R!B92!A;B!O<'1I;VYS(&%R<F%Y#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!A='1R:6)U=&5S5&]3=')I;F<H)&%T=')I8G5T97,L("1S
M;W)T(#T@=')U92P@)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@)R`@
M("`G+"`D;&EN96)R96%K(#T@(EQN(BP@)&5N=&ET:65S(#T@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,*0T*
M("`@('L-"B`@("`@("`@+RHJ#0H@("`@("`@("`J('-E8V]N9"!P87)A;65T
M97(@;6%Y(&)E(&%N(&%R<F%Y#0H@("`@("`@("`J+PT*("`@("`@("!I9B`H
M:7-?87)R87DH)'-O<G0I*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O
M<G1;)VUU;'1I;&EN92==*2D@>PT*("`@("`@("`@("`@("`@("1M=6QT:6QI
M;F4@/2`D<V]R=%LG;75L=&EL:6YE)UT[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'-O<G1;)VEN9&5N="==*2D@>PT*("`@("`@
M("`@("`@("`@("1I;F1E;G0@/2`D<V]R=%LG:6YD96YT)UT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;)VQI;F5B<F5A
M:R==*2D@>PT*("`@("`@("`@("`@("`@("1M=6QT:6QI;F4@/2`D<V]R=%LG
M;&EN96)R96%K)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'-O<G1;)V5N=&ET:65S)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&5N=&ET:65S(#T@)'-O<G1;)V5N=&ET:65S)UT[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;)W-O<G0G72DI('L-"B`@
M("`@("`@("`@("`@("`D<V]R="`]("1S;W)T6R=S;W)T)UT[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1S;W)T(#T@=')U93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<W1R:6YG(#T@
M)R<[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D871T<FEB=71E<RD@)B8@(65M
M<'1Y*"1A='1R:6)U=&5S*2D@>PT*("`@("`@("`@("`@:68@*"1S;W)T*2![
M#0H@("`@("`@("`@("`@("`@:W-O<G0H)&%T=')I8G5T97,I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68H("$D;75L=&EL:6YE('Q\(&-O=6YT
M*"1A='1R:6)U=&5S*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1E;G1I=&EE<R`A/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U].3TY%*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F5P;&%C945N=&ET:65S*"1V86QU
M92P@)&5N=&ET:65S*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`D<W1R:6YG("X]("<@)RXD:V5Y+B<](B<N)'9A;'5E
M+B<B)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1F:7)S="`]('1R=64[#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1E;G1I=&EE<R`A/2!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U].
M3TY%*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F5P;&%C945N
M=&ET:65S*"1V86QU92P@)&5N=&ET:65S*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&9I<G-T*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("(@(BXD:V5Y+B<](B<N
M)'9A;'5E+B<B)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1F:7)S="`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`D;&EN96)R96%K+B1I;F1E
M;G0N)&ME>2XG/2(G+B1V86QU92XG(B<[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1S=')I;F<[#0H@("`@?0T*#0H@("`O*BH-
M"B`@("`J(&-R96%T92!A('1A9PT*("`@("H-"B`@("`J(%1H:7,@;65T:&]D
M('=I;&P@8V%L;"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?
M571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"DL('=H:6-H#0H@("`@*B!I<R!M
M;W)E(&9L97AI8FQE+@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q
M=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C
M<F5A=&4@86X@6$U,('1A9SH-"B`@("`J("1T86<@/2!014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G*")M>4YS.FUY
M5&%G(BP@87)R87DH(F9O;R(@/3X@(F)A<B(I+"`B5&AI<R!I<R!I;G-I9&4@
M=&AE('1A9R(L(")H='1P.B\O=W=W+G<S8RYO<F<O;7E.<R,B*3L-"B`@("`J
M(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<6YA;64@("`@
M("`@("`@("`@<75A;&EF:65D('1A9VYA;64@*&EN8VQU9&EN9R!N86UE<W!A
M8V4I#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@("`@
M("`@87)R87D@8V]N=&%I;F<@871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@
M(&UI>&5D("`@)&-O;G1E;G0-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1N
M86UE<W!A8V55<FD@("`@("!54DD@;V8@=&AE(&YA;65S<&%C90T*("`@("H@
M0'!A<F%M("`@(&EN=&5G97(@)')E<&QA8V5%;G1I=&EE<R`@('=H971H97(@
M=&\@<F5P;&%C92!834P@<W!E8VEA;"!C:&%R<R!I;B!C;VYT96YT+"!E;6)E
M9&0@:70@:6X@82!#1&%T82!S96-T:6]N(&]R(&YO;F4@;V8@8F]T:`T*("`@
M("H@0'!A<F%M("`@(&)O;VQE86X@)&UU;'1I;&EN92`@("`@("`@('=H971H
M97(@=&\@8W)E871E(&$@;75L=&EL:6YE('1A9R!W:&5R92!E86-H(&%T=')I
M8G5T92!G971S('=R:71T96X@=&\@82!S:6YG;&4@;&EN90T*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@)&EN9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D
M('1O(&EN9&5N="!A='1R:6)U=&5S("A?875T;R!I;F1E;G1S(&%T=')I8G5T
M97,@<V\@=&AE>2!S=&%R="!A="!T:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S
M960@9F]R(&QI;F5B<F5A:W,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1E
M;F-O9&EN9R`@("`@("`@("!E;F-O9&EN9R!T:&%T('-H;W5L9"!B92!U<V5D
M('1O('1R86YS;&%T92!C;VYT96YT#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG
M("`D<W1R:6YG("`@("`@("`@("`@6$U,('1A9PT*("`@("H@0'-E92`@("`@
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A
M=&5486=&<F]M07)R87DH*0T*("`@("H@0'5S97,@("`@(%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R
M87DH*2!T;R!C<F5A=&4@=&AE('1A9PT*("`@("HO#0H@("`@9G5N8W1I;VX@
M8W)E871E5&%G*"1Q;F%M92P@)&%T=')I8G5T97,@/2!A<G)A>2@I+"`D8V]N
M=&5N="`](&YU;&PL("1N86UE<W!A8V55<FD@/2!N=6QL+"`D<F5P;&%C945N
M=&ET:65S(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T
M:6Q?4D503$%#15]%3E1)5$E%4RP@)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD
M96YT(#T@(E]A=71O(BP@)&QI;F5B<F5A:R`](")<;B(L("1E;F-O9&EN9R`]
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E4
M24537UA-3"D-"B`@("![#0H@("`@("`@("1T86<@/2!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`]/B`D<6YA;64L#0H@("`@
M("`@("`@("`@("`@("`@("`B871T<FEB=71E<R(@/3X@)&%T=')I8G5T97,-
M"B`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@("`@("`O+R!A9&0@=&%G
M(&-O;G1E;G0-"B`@("`@("`@:68@*"1C;VYT96YT("$]/2!N=6QL*2![#0H@
M("`@("`@("`@("`D=&%G6R)C;VYT96YT(ET@/2`D8V]N=&5N=#L-"B`@("`@
M("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@861D(&YA;65S<&%C92!5<FD-
M"B`@("`@("`@:68@*"1N86UE<W!A8V55<FD@(3T](&YU;&PI('L-"B`@("`@
M("`@("`@("1T86=;(FYA;65S<&%C955R:2)=(#T@)&YA;65S<&%C955R:3L-
M"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T
M86<L("1R97!L86-E16YT:71I97,L("1M=6QT:6QI;F4L("1I;F1E;G0L("1L
M:6YE8G)E86LL("1E;F-O9&EN9RD[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J
M(&-R96%T92!A('1A9R!F<F]M(&%N(&%R<F%Y#0H@("`@*B!T:&ES(&UE=&AO
M9"!A=V%I=',@86X@87)R87D@:6X@=&AE(&9O;&QO=VEN9R!F;W)M870-"B`@
M("`J(#QP<F4^#0H@("`@*B!A<G)A>2@-"B`@("`J("`B<6YA;64B("`@("`@
M("`]/B`D<6YA;64@("`@("`@("`O+R!Q=6%L:69I960@;F%M92!O9B!T:&4@
M=&%G#0H@("`@*B`@(FYA;65S<&%C92(@("`@/3X@)&YA;65S<&%C92`@("`@
M+R\@;F%M97-P86-E('!R969I>"`H;W!T:6]N86PL(&EF('%N86UE(&ES('-P
M96-I9FEE9"!O<B!N;R!N86UE<W!A8V4I#0H@("`@*B`@(FQO8V%L<&%R="(@
M("`@/3X@)&QO8V%L<&%R="P@("`@+R\@;&]C86P@<&%R="!O9B!T:&4@=&%G
M;F%M92`H;W!T:6]N86PL(&EF('%N86UE(&ES('-P96-I9FEE9"D-"B`@("`J
M("`B871T<FEB=71E<R(@("`]/B!A<G)A>2@I+"`@("`@("`O+R!A<G)A>2!C
M;VYT86EN:6YG(&%L;"!A='1R:6)U=&5S("AO<'1I;VYA;"D-"B`@("`J("`B
M8V]N=&5N="(@("`@("`]/B`D8V]N=&5N="P@("`@("`O+R!T86<@8V]N=&5N
M="`H;W!T:6]N86PI#0H@("`@*B`@(FYA;65S<&%C955R:2(@/3X@)&YA;65S
M<&%C955R:2`@+R\@;F%M97-P86-E57)I(&9O<B!T:&4@9VEV96X@;F%M97-P
M86-E("AO<'1I;VYA;"D-"B`@("`J("`@*0T*("`@("H@/"]P<F4^#0H@("`@
M*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL
M+G!H<"<[#0H@("`@*B`-"B`@("`J("1T86<@/2!A<G)A>2@-"B`@("`J("`@
M("`@("`@("`B<6YA;64B("`@("`@("`]/B`B9F]O.F)A<B(L#0H@("`@*B`@
M("`@("`@("`@(FYA;65S<&%C955R:2(@/3X@(FAT='`Z+R]F;V\N8V]M(BP-
M"B`@("`J("`@("`@("`@("`B871T<FEB=71E<R(@("`]/B!A<G)A>2@@(FME
M>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F<G5I="9V96=E=&%B;&4B("DL
M#0H@("`@*B`@("`@("`@("`@(F-O;G1E;G0B("`@("`@/3X@(DDG;2!I;G-I
M9&4@=&AE('1A9R(L#0H@("`@*B`@("`@("`@("`@("D[#0H@("`@*B`O+R!C
M<F5A=&EN9R!A('1A9R!W:71H('%U86QI9FEE9"!N86UE(&%N9"!N86UE<W!A
M8V55<FD-"B`@("`J("1S=')I;F<@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<I.PT*
M("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-
M"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1T86<@
M("`@("`@("`@("`@("!T86<@9&5F:6YI=&EO;@T*("`@("H@0'!A<F%M("`@
M(&EN=&5G97(@)')E<&QA8V5%;G1I=&EE<R`@('=H971H97(@=&\@<F5P;&%C
M92!834P@<W!E8VEA;"!C:&%R<R!I;B!C;VYT96YT+"!E;6)E9&0@:70@:6X@
M82!#1&%T82!S96-T:6]N(&]R(&YO;F4@;V8@8F]T:`T*("`@("H@0'!A<F%M
M("`@(&)O;VQE86X@)&UU;'1I;&EN92`@("`@("`@('=H971H97(@=&\@8W)E
M871E(&$@;75L=&EL:6YE('1A9R!W:&5R92!E86-H(&%T=')I8G5T92!G971S
M('=R:71T96X@=&\@82!S:6YG;&4@;&EN90T*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@)&EN9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D('1O(&EN9&5N
M="!A='1R:6)U=&5S("A?875T;R!I;F1E;G1S(&%T=')I8G5T97,@<V\@=&AE
M>2!S=&%R="!A="!T:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`D;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI
M;F5B<F5A:W,-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@
M("`@("`@("!834P@=&%G#0H@("`@*B!`<V5E("`@("`@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@
M*B!`=7-E<R`@("`@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@I('1O('-E<FEA;&EZ92!T:&4@
M871T<FEB=71E<R!O9B!T:&4@=&%G#0H@("`@*B!`=7-E<R`@("`@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G-P;&ET475A;&EF
M:65D3F%M92@I('1O(&=E="!L;V-A;"!P87)T(&%N9"!N86UE<W!A8V4@;V8@
M82!Q=6%L:69I960@;F%M90T*("`@("HO#0H@("`@9G5N8W1I;VX@8W)E871E
M5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,@/2!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]215!,04-%7T5.5$E4
M2453+"`D;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@/2`B7V%U=&\B+"`D
M;&EN96)R96%K(#T@(EQN(BP@)&5N8V]D:6YG(#T@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T86=;(F-O;G1E;G0B72D@)B8@(6ES7W-C
M86QA<B@D=&%G6R)C;VYT96YT(ETI*2![#0H@("`@("`@("`@("!R971U<FX@
M4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G)A:7-E
M17)R;W(H(")3=7!P;&EE9"!N;VXM<V-A;&%R('9A;'5E(&%S('1A9R!C;VYT
M96YT(BP@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?
M15)23U)?3D].7U-#04Q!4E]#3TY414Y4("D[#0H@("`@("`@('T-"@T*("`@
M("`@("!I9B`H(6ES<V5T*"1T86=;)W%N86UE)UTI("8F("%I<W-E="@D=&%G
M6R=L;V-A;%!A<G0G72DI('L-"B`@("`@("`@("`@(')E='5R;B!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F%I<V5%<G)O<B@@
M)UEO=2!M=7-T(&5I=&AE<B!S=7!P;'D@82!Q=6%L:69I960@;F%M92`H<6YA
M;64I(&]R(&QO8V%L('1A9R!N86UE("AL;V-A;%!A<G0I+B<L(%!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T524D]27TY/7U1!1U].
M04U%("D[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!I9B!N;R!A='1R:6)U
M=&5S(&AA=B!B965N('-E="P@=7-E(&5M<'1Y(&%T=')I8G5T97,-"B`@("`@
M("`@:68@*"%I<W-E="@D=&%G6R)A='1R:6)U=&5S(ETI('Q\("%I<U]A<G)A
M>2@D=&%G6R)A='1R:6)U=&5S(ETI*2![#0H@("`@("`@("`@("`D=&%G6R)A
M='1R:6)U=&5S(ET@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@(`T*
M("`@("`@("`O+R!Q=6%L:69I960@;F%M92!I<R!N;W0@9VEV96X-"B`@("`@
M("`@:68@*"%I<W-E="@D=&%G6R)Q;F%M92)=*2D@>PT*("`@("`@("`@("`@
M+R\@8VAE8VL@9F]R(&YA;65S<&%C90T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T86=;(FYA;65S<&%C92)=*2`F)B`A96UP='DH)'1A9ULB;F%M97-P86-E
M(ETI*2![#0H@("`@("`@("`@("`@("`@)'1A9ULB<6YA;64B72`]("1T86=;
M(FYA;65S<&%C92)=+B(Z(BXD=&%G6R)L;V-A;%!A<G0B73L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1A9ULB<6YA;64B72`]
M("1T86=;(FQO8V%L4&%R=")=.PT*("`@("`@("`@("`@?0T*("`@("`@("`O
M+R!N86UE<W!A8V4@55))(&ES('-E="P@8G5T(&YO(&YA;65S<&%C90T*("`@
M("`@("!](&5L<V5I9B`H:7-S970H)'1A9ULB;F%M97-P86-E57)I(ETI("8F
M("%I<W-E="@D=&%G6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@("`@("1P
M87)T<R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M.CIS<&QI=%%U86QI9FEE9$YA;64H)'1A9ULB<6YA;64B72D[#0H@("`@("`@
M("`@("`D=&%G6R)L;V-A;%!A<G0B72`]("1P87)T<ULB;&]C86Q087)T(ET[
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<G1S6R)N86UE<W!A8V4B72DI
M('L-"B`@("`@("`@("`@("`@("`D=&%G6R)N86UE<W!A8V4B72`]("1P87)T
M<ULB;F%M97-P86-E(ET[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*
M("`@("`@("!I9B`H:7-S970H)'1A9ULB;F%M97-P86-E57)I(ETI("8F("%E
M;7!T>2@D=&%G6R)N86UE<W!A8V55<FDB72DI('L-"B`@("`@("`@("`@("\O
M(&ES(&$@;F%M97-P86-E(&=I=F5N#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1A9ULB;F%M97-P86-E(ETI("8F("%E;7!T>2@D=&%G6R)N86UE<W!A8V4B
M72DI('L-"B`@("`@("`@("`@("`@("`D=&%G6R)A='1R:6)U=&5S(EU;(GAM
M;&YS.B(N)'1A9ULB;F%M97-P86-E(EU=(#T@)'1A9ULB;F%M97-P86-E57)I
M(ET[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("\O
M(&1E9FEN92!T:&ES(%5R:2!A<R!T:&4@9&5F875L="!N86UE<W!A8V4-"B`@
M("`@("`@("`@("`@("`D=&%G6R)A='1R:6)U=&5S(EU;(GAM;&YS(ET@/2`D
M=&%G6R)N86UE<W!A8V55<FDB73L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O(&-H96-K(&9O<B!M=6QT:6QI;F4@871T<FEB=71E
M<PT*("`@("`@("!I9B`H)&UU;'1I;&EN92`]/3T@=')U92D@>PT*("`@("`@
M("`@("`@:68@*"1I;F1E;G0@/3T](")?875T;R(I('L-"B`@("`@("`@("`@
M("`@("`D:6YD96YT(#T@<W1R7W)E<&5A="@B("(L("AS=')L96XH)'1A9ULB
M<6YA;64B72DK,BDI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(`T*("`@("`@("`O+R!C<F5A=&4@871T<FEB=71E(&QI<W0-"B`@("`@
M("`@)&%T=$QI<W0@("`@/2`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H)'1A9ULB871T<FEB
M=71E<R)=+"!T<G5E+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R96%K
M("D[#0H@("`@("`@(&EF("@A:7-S970H)'1A9ULB8V]N=&5N=")=*2!\?"`H
M<W1R:6YG*21T86=;(F-O;G1E;G0B72`]/2`G)RD@>PT*("`@("`@("`@("`@
M)'1A9R`@("`]("`@<W!R:6YT9B@B/"5S)7,@+SXB+"`D=&%G6R)Q;F%M92)=
M+"`D871T3&ES="D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I
M9B`H)')E<&QA8V5%;G1I=&EE<R`]/2!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;%]215!,04-%7T5.5$E42453*2![#0H@("`@("`@
M("`@("`@("`@)'1A9ULB8V]N=&5N=")=(#T@4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=&%G6R)C
M;VYT96YT(ETL("1E;F-O9&EN9RD[#0H@("`@("`@("`@("!](&5L<V5I9B`H
M)')E<&QA8V5%;G1I=&EE<R`]/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;%]#1$%405]314-424].*2![#0H@("`@("`@("`@("`@
M("`@)'1A9ULB8V]N=&5N=")=(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T
M;W)?=C)?6$U,7U5T:6PZ.F-R96%T94-$871A4V5C=&EO;B@D=&%G6R)C;VYT
M96YT(ETI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1A9R`@("`]
M("`@<W!R:6YT9B@B/"5S)7,^)7,\+R5S/B(L("1T86=;(G%N86UE(ETL("1A
M='1,:7-T+"`D=&%G6R)C;VYT96YT(ETL("1T86=;(G%N86UE(ET@*3L-"B`@
M("`@("`@?2`@("`@("`@#0H@("`@("`@(')E='5R;B`@)'1A9SL-"B`@("!]
M#0H-"B`@("\J*@T*("`@("H@8W)E871E(&$@<W1A<G0@96QE;65N=`T*("`@
M("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I
M;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,('-T87)T
M(&5L96UE;G0Z#0H@("`@*B`D=&%G(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T95-T87)T16QE;65N="@B;7E.<SIM
M>51A9R(L(&%R<F%Y*")F;V\B(#T^(")B87(B*2`L(FAT='`Z+R]W=W<N=S-C
M+F]R9R]M>4YS(R(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1Q;F%M92`@("`@("`@("`@("!Q=6%L:69I960@=&%G;F%M
M92`H:6YC;'5D:6YG(&YA;65S<&%C92D-"B`@("`J($!P87)A;2`@("!A<G)A
M>2`@("1A='1R:6)U=&5S("`@("`@("!A<G)A>2!C;VYT86EN9R!A='1R:6)U
M=&5S#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D;F%M97-P86-E57)I("`@
M("`@55))(&]F('1H92!N86UE<W!A8V4-"B`@("`J($!P87)A;2`@("!B;V]L
M96%N("1M=6QT:6QI;F4@("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A(&UU
M;'1I;&EN92!T86<@=VAE<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N
M('1O(&$@<VEN9VQE(&QI;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1I
M;F1E;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB
M=71E<R`H7V%U=&\@:6YD96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A<G0@
M870@=&AE('-A;64@8V]L=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M)&QI;F5B<F5A:R`@("`@("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS
M#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@("`@("`@("`@
M6$U,('-T87)T(&5L96UE;G0-"B`@("`J($!S964@("`@("!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E16YD16QE;65N
M="@I+"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ
M8W)E871E5&%G*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T95-T87)T
M16QE;65N="@D<6YA;64L("1A='1R:6)U=&5S(#T@87)R87DH*2P@)&YA;65S
M<&%C955R:2`](&YU;&PL("1M=6QT:6QI;F4@/2!F86QS92P@)&EN9&5N="`]
M("=?875T;R<L("1L:6YE8G)E86L@/2`B7&XB*0T*("`@('L-"B`@("`@("`@
M+R\@:68@;F\@871T<FEB=71E<R!H878@8F5E;B!S970L('5S92!E;7!T>2!A
M='1R:6)U=&5S#0H@("`@("`@(&EF("@A:7-S970H)&%T=')I8G5T97,I('Q\
M("%I<U]A<G)A>2@D871T<FEB=71E<RDI('L-"B`@("`@("`@("`@("1A='1R
M:6)U=&5S(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@
M("`@:68@*"1N86UE<W!A8V55<FD@(3T@;G5L;"D@>PT*("`@("`@("`@("`@
M)'!A<G1S(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T
M:6PZ.G-P;&ET475A;&EF:65D3F%M92@D<6YA;64I.PT*("`@("`@("!]#0H-
M"B`@("`@("`@+R\@8VAE8VL@9F]R(&UU;'1I;&EN92!A='1R:6)U=&5S#0H@
M("`@("`@(&EF("@D;75L=&EL:6YE(#T]/2!T<G5E*2![#0H@("`@("`@("`@
M("!I9B`H)&EN9&5N="`]/3T@(E]A=71O(BD@>PT*("`@("`@("`@("`@("`@
M("1I;F1E;G0@/2!S=')?<F5P96%T*"(@(BP@*'-T<FQE;B@D<6YA;64I*S(I
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D
M;F%M97-P86-E57)I("$](&YU;&PI('L-"B`@("`@("`@("`@("\O(&ES(&$@
M;F%M97-P86-E(&=I=F5N#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<G1S
M6R)N86UE<W!A8V4B72D@)B8@(65M<'1Y*"1P87)T<ULB;F%M97-P86-E(ETI
M*2![#0H@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;(GAM;&YS.B(N)'!A
M<G1S6R)N86UE<W!A8V4B75T@/2`D;F%M97-P86-E57)I.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O+R!D969I;F4@=&AI<R!5
M<FD@87,@=&AE(&1E9F%U;'0@;F%M97-P86-E#0H@("`@("`@("`@("`@("`@
M)&%T=')I8G5T97-;(GAM;&YS(ET@/2`D;F%M97-P86-E57)I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@8W)E871E(&%T=')I
M8G5T92!L:7-T#0H@("`@("`@("1A='1,:7-T("`@(#T@("!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ871T<FEB=71E<U1O4W1R
M:6YG*"1A='1R:6)U=&5S+"!T<G5E+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D
M;&EN96)R96%K*3L-"B`@("`@("`@)&5L96UE;G0@("`@/2`@('-P<FEN=&8H
M(CPE<R5S/B(L("1Q;F%M92P@)&%T=$QI<W0I.PT*("`@("`@("!R971U<FX@
M("1E;&5M96YT.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@
M96YD(&5L96UE;G0-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I
M<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E
M871E(&%N(%A-3"!S=&%R="!E;&5M96YT.@T*("`@("H@)'1A9R`](%!%05)?
M4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5%;F1%
M;&5M96YT*")M>4YS.FUY5&%G(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)'%N86UE("`@("`@("`@("`@('%U86QI9FEE
M9"!T86=N86UE("AI;F-L=61I;F<@;F%M97-P86-E*0T*("`@("H@0')E='5R
M;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-3"!E;F0@96QE;65N
M=`T*("`@("H@0'-E92`@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL.CIC<F5A=&53=&%R=$5L96UE;G0H*2P@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5%;F1%;&5M96YT*"1Q;F%M92D-
M"B`@("![#0H@("`@("`@("1E;&5M96YT("`@(#T@("!S<')I;G1F*"(\+R5S
M/B(L("1Q;F%M92D[#0H@("`@("`@(')E='5R;B`@)&5L96UE;G0[#0H@("`@
M?0T*("`@(`T*("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@6$U,(&-O;6UE;G0-
M"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,
M+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!S
M=&%R="!E;&5M96YT.@T*("`@("H@)'1A9R`](%!%05)?4&%C:V%G949I;&5?
M1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5#;VUM96YT*"))(&%M(&$@
M8V]M;65N="(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("1C;VYT96YT("`@("`@("`@("!C;VYT96YT(&]F('1H92!C;VUM
M96YT#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D8V]M;65N="`@("`@("`@
M("`@6$U,(&-O;6UE;G0-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T94-O
M;6UE;G0H)&-O;G1E;G0I#0H@("`@>PT*("`@("`@("`D8V]M;65N="`@("`]
M("`@<W!R:6YT9B@B/"$M+2`E<R`M+3XB+"`D8V]N=&5N="D[#0H@("`@("`@
M(')E='5R;B`@)&-O;6UE;G0[#0H@("`@?0T*("`@(`T*("`@+RHJ#0H@("`@
M*B!C<F5A=&4@82!#1&%T82!S96-T:6]N#0H@("`@*@T*("`@("H@/&-O9&4^
M#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-
M"B`@("`J("\O(&-R96%T92!A($-$871A('-E8W1I;VX-"B`@("`J("1T86<@
M/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E
M871E0T1A=&%396-T:6]N*"))(&%M(&-O;G1E;G0N(BD[#0H@("`@*B`\+V-O
M9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T
M871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&1A=&$@("`@("`@("`@
M("`@(&1A=&$@;V8@=&AE($-$871A('-E8W1I;VX-"B`@("`J($!R971U<FX@
M("!S=')I;F<@("1S=')I;F<@("`@("`@("`@("!#1&%T82!S96-T:6]N('=I
M=&@@8V]N=&5N=`T*("`@("HO#0H@("`@9G5N8W1I;VX@8W)E871E0T1A=&%3
M96-T:6]N*"1D871A*0T*("`@('L-"B`@("`@("`@<F5T=7)N("!S<')I;G1F
M*"(\(5M#1$%405LE<UU=/B(L("1D871A*3L-"B`@("!]#0H-"B`@("\J*@T*
M("`@("H@<W!L:70@<75A;&EF:65D(&YA;64@86YD(')E='5R;B!N86UE<W!A
M8V4@86YD(&QO8V%L('!A<G0-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J
M(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@
M+R\@<W!L:70@<75A;&EF:65D('1A9PT*("`@("H@)'!A<G1S(#T@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G-P;&ET475A;&EF
M:65D3F%M92@B>'-L=#IS='EL97-H965T(BD[#0H@("`@*B`\+V-O9&4^#0H@
M("`@*B!T:&4@<F5T=7)N960@87)R87D@=VEL;"!C;VYT86EN('1W;R!E;&5M
M96YT<SH-"B`@("`J(#QP<F4^#0H@("`@*B!A<G)A>2@-"B`@("`J("`@("`@
M(")N86UE<W!A8V4B(#T^(")X<VQT(BP-"B`@("`J("`@("`@(")L;V-A;%!A
M<G0B(#T^(")S='EL97-H965T(@T*("`@("H@("`@("`I.PT*("`@("H@/"]P
M<F4^#0H@("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J($!S=&%T
M:6,-"B`@("`J($!P87)A;2`@<W1R:6YG("`@("1Q;F%M92`@("`@('%U86QI
M9FEE9"!T86<@;F%M90T*("`@("H@0'!A<F%M("!S=')I;F<@("`@)&1E9F%U
M;'1.<R`@9&5F875L="!N86UE<W!A8V4@*&]P=&EO;F%L*0T*("`@("H@0')E
M='5R;B!A<G)A>2`@("`@)'!A<G1S("`@("`@87)R87D@8V]N=&%I;FEN9R!N
M86UE<W!A8V4@86YD(&QO8V%L('!A<G0-"B`@("`J+PT*("`@(&9U;F-T:6]N
M('-P;&ET475A;&EF:65D3F%M92@D<6YA;64L("1D969A=6QT3G,@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@:68@*'-T<G-T<B@D<6YA;64L("<Z)RDI('L-
M"B`@("`@("`@("`@("1T;7`@/2!E>'!L;V1E*"(Z(BP@)'%N86UE*3L-"B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(FYA;65S<&%C92(@/3X@)'1M<%LP72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(FQO8V%L4&%R="(@/3X@)'1M<%LQ70T*("`@("`@("`@
M("`@("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@(FYA;65S<&%C92(@/3X@
M)&1E9F%U;'1.<RP-"B`@("`@("`@("`@("`@("`@("`@("`B;&]C86Q087)T
M(B`]/B`D<6YA;64-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("!]#0H-
M"B`@("\J*@T*("`@("H@8VAE8VLL('=H971H97(@<W1R:6YG(&ES('9A;&ED
M(%A-3"!N86UE#0H@("`@*@T*("`@("H@/'`^6$U,(&YA;65S(&%R92!U<V5D
M(&9O<B!T86=N86UE+"!A='1R:6)U=&4@;F%M97,@86YD('9A<FEO=7,-"B`@
M("`J(&]T:&5R+"!L97-S97(@:VYO=VX@96YT:71I97,N/"]P/@T*("`@("H@
M/'`^06X@6$U,(&YA;64@;6%Y(&]N;'D@8V]N<VES="!O9B!A;'!H86YU;65R
M:6,@8VAA<F%C=&5R<RP-"B`@("`J(&1A<VAE<RP@=6YD97-C;W)E<R!A;F0@
M<&5R:6]D<RP@86YD(&AA<R!T;R!S=&%R="!W:71H(&$@;&5T=&5R#0H@("`@
M*B!O<B!A;B!U;F1E<G-C;W)E+@T*("`@("H@/"]P/@T*("`@("H-"B`@("`J
M(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*
M("`@("H@#0H@("`@*B`O+R!V97)I9GD@=&%G(&YA;64-"B`@("`J("1R97-U
M;'0@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ
M:7-686QI9$YA;64H(FEN=F%L:61486<_(BD[#0H@("`@*B!I9B`H4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES17)R;W(H)')E
M<W5L="DI('L-"B`@("`J("`@('!R:6YT("));G9A;&ED(%A-3"!N86UE.B`B
M("X@)')E<W5L="T^9V5T365S<V%G92@I.PT*("`@("H@?0T*("`@("H@/"]C
M;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@('!U8FQI8PT*("`@("H@0'-T
M871I8PT*("`@("H@0'!A<F%M("`@<W1R:6YG("`D<W1R:6YG('-T<FEN9R!T
M:&%T('-H;W5L9"!B92!C:&5C:V5D#0H@("`@*B!`<F5T=7)N("!M:7AE9"`@
M("1V86QI9"`@=')U92P@:68@<W1R:6YG(&ES(&$@=F%L:60@6$U,(&YA;64L
M(%!%05(@97)R;W(@;W1H97)W:7-E#0H@("`@*B!`=&]D;R`@("!S=7!P;W)T
M(&9O<B!O=&AE<B!C:&%R<V5T<PT*("`@("HO#0H@("`@9G5N8W1I;VX@:7-6
M86QI9$YA;64H)'-T<FEN9RD-"B`@("![#0H@("`@("`@("\O(&-H96-K(&9O
M<B!I;G9A;&ED(&-H87)S#0H@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY;
M6SIA;&YU;3I=7UPM+ETD+R(L("1S=')I;F=[,'TI*2![#0H@("`@("`@("`@
M("!R971U<FX@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T
M:6PZ.G)A:7-E17)R;W(H(")834P@;F%M97,@;6%Y(&]N;'D@<W1A<G0@=VET
M:"!L971T97(@;W(@=6YD97)S8V]R92(L(%!%05)?4&%C:V%G949I;&5?1V5N
M97)A=&]R7W8R7UA-3%]5=&EL7T524D]27TE.5D%,241?4U1!4E0@*3L-"B`@
M("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@8VAE8VL@9F]R(&EN=F%L
M:60@8VAA<G,-"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7BA;82UZ02U:
M7UTH6V$M>D$M6C`M.5]<+5PN72HI/SHI/UMA+7I!+5I?72A;82UZ02U:,"TY
M7UPM7"Y=*RD_)"\B+"`D<W1R:6YG*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIR86ES
M945R<F]R*"`B6$U,(&YA;65S(&UA>2!O;FQY(&-O;G1A:6X@86QP:&%N=6UE
M<FEC(&-H87)S+"!P97)I;V0L(&AY<&AE;BP@8V]L;VX@86YD('5N9&5R<V-O
M<F5S(BP@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?
M15)23U)?24Y604Q)1%]#2$%24R`I.PT*("`@("`@("`@?0T*("`@("`@("`O
M+R!834P@;F%M92!I<R!V86QI9`T*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("\J*@T*("`@("H@<F5P;&%C96UE;G0@9F]R(%!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIR86ES945R<F]R#0H@
M("`@*@T*("`@("H@079O:61S('1H92!N96-E<W-I='D@=&\@86QW87ES(')E
M<75I<F4-"B`@("`J(%!%05(N<&AP#0H@("`@*@T*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&5R<F]R(&UE
M<W-A9V4-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("`@("!E<G)O<B!C;V1E
M#0H@("`@*B!`<F5T=7)N("`@;V)J96-T(%!%05)?17)R;W(-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&US9RP@)&-O9&4I#0H@("`@>PT*
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)&US9RP@)&-O9&4I.PT*("`@('T-"GT-
M"C\^+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G
M949I;&4O1V5N97)A=&]R+W8Q+G!H<```````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30U
M,3,P`#$P-3$U-#,Q,#4W`#`R,S(Q-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RHJ#0H@*B!P86-K86=E+GAM
M;"!G96YE<F%T:6]N(&-L87-S+"!P86-K86=E+GAM;"!V97)S:6]N(#$N,`T*
M("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS
M92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B
M+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!V,2YP:'`L
M=B`Q+C<P(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C0N,&$Q#0H@*B\-"B\J*@T*("H@;F5E9&5D(&9O<B!014%27U9!3$E$051%
M7RH@8V]N<W1A;G1S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]686QI9&%T
M92YP:'`G.PT*<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"G)E<75I<F5?
M;VYC92`G4$5!4B]086-K86=E1FEL92]V,BYP:'`G.PT*+RHJ#0H@*B!4:&ES
M(&-L87-S(&-O;G9E<G1S(&$@4$5!4E]086-K86=E1FEL95]V,2!O8FIE8W0@
M:6YT;R!A;GD@;W5T<'5T(&9O<FUA="X-"B`J#0H@*B!3=7!P;W)T960@;W5T
M<'5T(&9O<FUA=',@:6YC;'5D92!A<G)A>2P@6$U,('-T<FEN9RP@86YD(&$@
M4$5!4E]086-K86=E1FEL95]V,@T*("H@;V)J96-T+"!F;W(@8V]N=F5R=&EN
M9R!P86-K86=E+GAM;"`Q+C`@:6YT;R!P86-K86=E+GAM;"`R+C`@=VET:"!N
M;R!S=V5A="X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,0T*>PT*("`@("\J*@T*("`@("`J($!V87(@
M4$5!4E]086-K86=E1FEL95]V,0T*("`@("`J+PT*("`@('9A<B`D7W!A8VMA
M9V5F:6QE.PT*("`@(&9U;F-T:6]N(%!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8Q*"8D<&%C:V%G969I;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5F:6QE(#T@)B1P86-K86=E9FEL93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971086-K86=E<E9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("<Q+C0N.2<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M(%!%05)?4&%C:V%G97(-"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E
M+"!A("YT9WH@:7,@=W)I='1E;BP@;W1H97)W:7-E(&$@+G1A<B!I<R!W<FET
M=&5N#0H@("`@("H@0'!A<F%M('-T<FEN9WQN=6QL(&1I<F5C=&]R>2!I;B!W
M:&EC:"!T;R!S879E('1H92`N=&=Z#0H@("`@("H@0')E='5R;B!S=')I;F=\
M4$5!4E]%<G)O<B!L;V-A=&EO;B!O9B!P86-K86=E(&]R(&5R<F]R(&]B:F5C
M=`T*("`@("`J+PT*("`@(&9U;F-T:6]N('1O5&=Z*"8D<&%C:V%G97(L("1C
M;VUP<F5S<R`]('1R=64L("1W:&5R92`](&YU;&PI#0H@("`@>PT*("`@("`@
M("!R97%U:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@(&EF
M("@D=VAE<F4@/3T](&YU;&PI('L-"B`@("`@("`@("`@(&EF("@A*"1W:&5R
M92`](%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*2DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E
M9FEL95]V,3HZ=&]49WHZ(&UK=&5M<"!F86EL960G*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?2!E;'-E:68@*"%`4WES=&5M.CIM:T1I<BAA<G)A>2@G
M+7`G+"`D=VAE<F4I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B`B)R`N("1W
M:&5R92`N("<B(&-O=6QD)R`N#0H@("`@("`@("`@("`@("`@)R!N;W0@8F4@
M8W)E871E9"<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AF:6QE7V5X:7-T
M<R@D=VAE<F4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA9V4N>&UL
M)RD@)B8-"B`@("`@("`@("`@("`@(6ES7V9I;&4H)'=H97)E("X@1$E214-4
M3U)97U-%4$%2051/4B`N("=P86-K86=E+GAM;"<I*2![#0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V
M,3HZ=&]49WHZ('5N86)L92!T;R!S879E('!A8VMA9V4N>&UL(&%S)R`N#0H@
M("`@("`@("`@("`@("`@)R`B)R`N("1W:&5R92`N($1)4D5#5$]265]315!!
M4D%43U(@+B`G<&%C:V%G92YX;6PB)RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"$D=&AI<RT^7W!A8VMA9V5F:6QE+3YV86QI9&%T92A014%27U9!3$E$
M051%7U!!0TM!1TE.1RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT;U1G>CH@:6YV86QI
M9"!P86-K86=E(&9I;&4G*3L-"B`@("`@("`@?0T*("`@("`@("`D<&MG:6YF
M;R`]("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$%R<F%Y*"D[#0H@("`@("`@
M("1E>'0@/2`D8V]M<')E<W,@/R`G+G1G>B<@.B`G+G1A<B<[#0H@("`@("`@
M("1P:V=V97(@/2`D<&MG:6YF;ULG<&%C:V%G92==("X@)RTG("X@)'!K9VEN
M9F];)W9E<G-I;VXG73L-"B`@("`@("`@)&1E<W1?<&%C:V%G92`](&=E=&-W
M9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V97(@+B`D97AT.PT*
M("`@("`@("!I9B`H9FEL95]E>&ES=',H9V5T8W=D*"D@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)'!K9W9E<B`N("1E>'0I("8F#0H@("`@("`@("`@("`@
M("%I<U]F:6QE*&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P
M:V=V97(@+B`D97AT*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B!C86YN;W0@
M8W)E871E('1G>B!F:6QE("(G("X-"B`@("`@("`@("`@("`@("!G971C=V0H
M*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG=F5R("X@)&5X="`N("<B
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P:V=F:6QE(#T@)'1H:7,M
M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G949I;&4H*2D@>PT*("`@("`@("`@
M("`@)'!K9V1I<B`](&1I<FYA;64H<F5A;'!A=&@H)'!K9V9I;&4I*3L-"B`@
M("`@("`@("`@("1P:V=F:6QE(#T@8F%S96YA;64H)'!K9V9I;&4I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B!P86-K86=E(&9I
M;&4@;V)J96-T(&UU<W0@)R`N#0H@("`@("`@("`@("`@("`@)V)E(&-R96%T
M960@9G)O;2!A(')E86P@9FEL92<I.PT*("`@("`@("!]#0H@("`@("`@("\O
M('M[>R!#<F5A=&4@=&AE('!A8VMA9V4@9FEL92!L:7-T#0H@("`@("`@("1F
M:6QE;&ES="`](&%R<F%Y*"D[#0H@("`@("`@("1I(#T@,#L-"@T*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971&:6QE;&ES="@I
M(&%S("1F;F%M92`]/B`D871T<RD@>PT*("`@("`@("`@("`@)&9I;&4@/2`D
M<&MG9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@
M("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&4I*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D9I;&4@9&]E<R!N;W0@
M97AI<W0Z("1F;F%M92(I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D9FEL96QI<W1;)&DK*UT@/2`D9FEL93L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1A='1S6R=M9#5S=6TG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92T^<V5T1FEL94%T
M=')I8G5T92@D9FYA;64L("=M9#5S=6TG+"!M9#5?9FEL92@D9FEL92DI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&%C:V%G97(M
M/FQO9R@R+"`B061D:6YG(&9I;&4@)&9N86UE(BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@+R\@?7U]#0H@("`@("`@("1P86-K86=E
M>&UL(#T@)'1H:7,M/G1O4&%C:V%G949I;&4H)'=H97)E+"!014%27U9!3$E$
M051%7U!!0TM!1TE.1RP@)W!A8VMA9V4N>&UL)RP@=')U92D[#0H@("`@("`@
M(&EF("@D<&%C:V%G97AM;"D@>PT*("`@("`@("`@("`@)'1A<B`])B!N97<@
M07)C:&EV95]487(H)&1E<W1?<&%C:V%G92P@)&-O;7!R97-S*3L-"B`@("`@
M("`@("`@("1T87(M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.R`O+R!86%@@1&]N)W0@<')I;G0@97)R;W)S#0H@("`@("`@("`@("`O
M+R`M+2TM+2!#<F5A=&5S('=I=&@@=&AE('!A8VMA9V4N>&UL(&9I;&4-"B`@
M("`@("`@("`@("1O:R`]("1T87(M/F-R96%T94UO9&EF>2AA<G)A>2@D<&%C
M:V%G97AM;"DL("<G+"`D=VAE<F4I.PT*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&]K*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D;VL[
M#0H@("`@("`@("`@("!](&5L<V5I9B`H(21O:RD@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE
M7W8Q.CIT;U1G>CH@=&%R8F%L;"!C<F5A=&EO;B!F86EL960G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("\O("TM+2TM($%D9"!T:&4@8V]N=&5N
M="!O9B!T:&4@<&%C:V%G90T*("`@("`@("`@("`@:68@*"$D=&%R+3YA9&1-
M;V1I9GDH)&9I;&5L:7-T+"`D<&MG=F5R+"`D<&MG9&ER*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A8VMA
M9V5F:6QE7W8Q.CIT;U1G>CH@=&%R8F%L;"!C<F5A=&EO;B!F86EL960G*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D9&5S=%]P86-K
M86=E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M('-T<FEN9WQN=6QL(&1I<F5C=&]R>2!T;R!P;&%C92!T:&4@<&%C:V%G
M92YX;6P@:6XL(&]R(&YU;&P@9F]R(&$@=&5M<&]R87)Y(&1I<@T*("`@("`J
M($!P87)A;2!I;G0@;VYE(&]F('1H92!014%27U9!3$E$051%7RH@8V]N<W1A
M;G1S#0H@("`@("H@0'!A<F%M('-T<FEN9R!N86UE(&]F('1H92!G96YE<F%T
M960@9FEL90T*("`@("`J($!P87)A;2!B;V]L(&EF('1R=64L('1H96X@;F\@
M86YA;'ES:7,@=VEL;"!B92!P97)F;W)M960@;VX@<F]L93TB<&AP(B!F:6QE
M<PT*("`@("`J($!R971U<FX@<W1R:6YG?%!%05)?17)R;W(@<&%T:"!T;R!T
M:&4@8W)E871E9"!F:6QE(&]N('-U8V-E<W,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!T;U!A8VMA9V5&:6QE*"1W:&5R92`](&YU;&PL("1S=&%T92`](%!%
M05)?5D%,241!5$5?3D]234%,+"`D;F%M92`]("=P86-K86=E+GAM;"<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]F:6QE8VAE8VMI;F<@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E9FEL
M92T^=F%L:61A=&4H)'-T871E+"`D;F]F:6QE8VAE8VMI;F<I*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E
M9FEL95]V,3HZ=&]086-K86=E1FEL93H@:6YV86QI9"!P86-K86=E+GAM;"<L
M#0H@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@)'1H:7,M/E]P
M86-K86=E9FEL92T^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"DI.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D=VAE<F4@/3T](&YU;&PI('L-"B`@("`@("`@
M("`@(&EF("@A*"1W:&5R92`](%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I
M*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]086-K86=E1FEL93H@;6MT96UP
M(&9A:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H
M(4!3>7-T96TZ.FUK1&ER*&%R<F%Y*"<M<"<L("1W:&5R92DI*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E
M9FEL95]V,3HZ=&]086-K86=E1FEL93H@(B<@+B`D=VAE<F4@+B`G(B!C;W5L
M9"<@+@T*("`@("`@("`@("`@("`@("<@;F]T(&)E(&-R96%T960G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D;F5W<&MG9FEL92`]("1W:&5R92`N($1)4D5#
M5$]265]315!!4D%43U(@+B`D;F%M93L-"B`@("`@("`@)&YP(#T@0&9O<&5N
M*"1N97=P:V=F:6QE+"`G=V(G*3L-"B`@("`@("`@:68@*"$D;G`I('L-"B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A8VMA
M9V5F:6QE7W8Q.CIT;U!A8VMA9V5&:6QE.B!U;F%B;&4@=&\@<V%V92`G("X-
M"B`@("`@("`@("`@("`@("(D;F%M92!A<R`D;F5W<&MG9FEL92(I.PT*("`@
M("`@("!]#0H@("`@("`@(&9W<FET92@D;G`L("1T:&ES+3YT;UAM;"@D<W1A
M=&4L('1R=64I*3L-"B`@("`@("`@9F-L;W-E*"1N<"D[#0H@("`@("`@(')E
M='5R;B`D;F5W<&MG9FEL93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!F
M:7@@8F]T:"!834P@96YC;V1I;F<@=&\@8F4@551&."P@86YD(')E<&QA8V4@
M<W1A;F1A<F0@6$U,(&5N=&ET:65S(#P@/B`B("8@)PT*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG#0H@("`@("H@0')E='5R;B!S=')I
M;F<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?9FEX6&UL16YC;V1I;F<H)'-T<FEN9RD-"B`@("![#0H@("`@("`@
M(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-2XP+C`G+"`G
M;'0G*2D@>PT*("`@("`@("`@("`@)'-T<FEN9R`]('5T9CA?96YC;V1E*"1S
M=')I;F<I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!S=')T<B@D<W1R
M:6YG+"!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<F)R`@/3X@)R9A;7`[)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<^)R`@/3X@)R9G=#LG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SPG("`]
M/B`G)FQT.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(B<@(#T^("<F<75O=#LG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)UPG)R`]/B`G)F%P;W,[)R`I*3L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@86X@6$U,(&1O8W5M
M96YT(&)A<V5D(&]N('1H92!P86-K86=E(&EN9F\@*&%S(')E='5R;F5D#0H@
M("`@("H@8GD@=&AE(%!%05)?0V]M;6]N.CII;F9O1G)O;2H@;65T:&]D<RDN
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!834P@9&%T80T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('1O6&UL*"1S=&%T92`](%!%05)?5D%,241!
M5$5?3D]234%,+"`D;F]F:6QE=F%L:61A=&EO;B`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92T^<V5T1&%T92AD871E*"=9
M+6TM9"<I*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7W!A8VMA9V5F:6QE+3YV
M86QI9&%T92@D<W1A=&4L("1N;V9I;&5V86QI9&%T:6]N*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1P:V=I
M;F9O(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T07)R87DH*3L-"B`@("`@
M("`@<W1A=&EC("1M86EN=%]M87`@/2!A<G)A>2@-"B`@("`@("`@("`@(")H
M86YD;&4B(#T^(")U<V5R(BP-"B`@("`@("`@("`@(")N86UE(B`]/B`B;F%M
M92(L#0H@("`@("`@("`@("`B96UA:6PB(#T^(")E;6%I;"(L#0H@("`@("`@
M("`@("`B<F]L92(@/3X@(G)O;&4B+`T*("`@("`@("`@("`@*3L-"B`@("`@
M("`@)')E="`]("(\/WAM;"!V97)S:6]N/5PB,2XP7"(@96YC;V1I;F<]7")5
M5$8M.%PB(#\^7&XB.PT*("`@("`@("`D<F5T("X]("(\(41/0U194$4@<&%C
M:V%G92!365-414T@7")H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E
M+3$N,%PB/EQN(CL-"B`@("`@("`@)')E="`N/2`B/'!A8VMA9V4@=F5R<VEO
M;CU<(C$N,%PB('!A8VMA9V5R=F5R<VEO;CU<(C$N-"XY7"(^7&XB("X-"B(@
M/&YA;64^)'!K9VEN9F];<&%C:V%G95T\+VYA;64^(CL-"B`@("`@("`@:68@
M*&ES<V5T*"1P:V=I;F9O6R=E>'1E;F1S)UTI*2![#0H@("`@("`@("`@("`D
M<F5T("X](")<;CQE>'1E;F1S/B1P:V=I;F9O6V5X=&5N9'-=/"]E>'1E;F1S
M/B([#0H@("`@("`@('T-"B`@("`@("`@)')E="`N/0T*(")<;B`\<W5M;6%R
M>3XB+B1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)'!K9VEN9F];)W-U;6UA<GDG
M72DN(CPO<W5M;6%R>3Y<;B(@+@T*(B`\9&5S8W)I<'1I;VX^(BYT<FEM*"1T
M:&ES+3Y?9FEX6&UL16YC;V1I;F<H)'!K9VEN9F];)V1E<V-R:7!T:6]N)UTI
M*2XB7&X@/"]D97-C<FEP=&EO;CY<;B(@+@T*(B`\;6%I;G1A:6YE<G,^7&XB
M.PT*("`@("`@("!F;W)E86-H("@D<&MG:6YF;ULG;6%I;G1A:6YE<G,G72!A
M<R`D;6%I;G0I('L-"B`@("`@("`@("`@("1R970@+CT@(B`@/&UA:6YT86EN
M97(^7&XB.PT*("`@("`@("`@("`@9F]R96%C:"`H)&UA:6YT7VUA<"!A<R`D
M:61X(#T^("1E;&TI('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("(@("`\
M)&5L;3XB.PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H:7,M/E]F:7A8
M;6Q%;F-O9&EN9R@D;6%I;G1;)&ED>%TI.PT*("`@("`@("`@("`@("`@("1R
M970@+CT@(CPO)&5L;3Y<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<F5T("X]("(@(#PO;6%I;G1A:6YE<CY<;B([#0H@("`@("`@('T-"B`@
M("`@("`@)')E="`N/2`B("`\+VUA:6YT86EN97)S/EQN(CL-"B`@("`@("`@
M)')E="`N/2`D=&AI<RT^7VUA:V5296QE87-E6&UL*"1P:V=I;F9O+"!F86QS
M92P@)'-T871E*3L-"B`@("`@("`@:68@*&ES<V5T*"1P:V=I;F9O6R=C:&%N
M9V5L;V<G72D@)B8@8V]U;G0H)'!K9VEN9F];)V-H86YG96QO9R==*2`^(#`I
M('L-"B`@("`@("`@("`@("1R970@+CT@(B`\8VAA;F=E;&]G/EQN(CL-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1P:V=I;F9O6R=C:&%N9V5L;V<G72!A<R`D
M;VQD<F5L96%S92D@>PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H:7,M
M/E]M86ME4F5L96%S95AM;"@D;VQD<F5L96%S92P@=')U92D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D<F5T("X]("(@/"]C:&%N9V5L;V<^7&XB
M.PT*("`@("`@("!]#0H@("`@("`@("1R970@+CT@(CPO<&%C:V%G93Y<;B([
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!?;6%K95)E;&5A<V58;6PH*0T*#0H@("`@+RHJ#0H@("`@
M("H@1V5N97)A=&4@<&%R="!O9B!A;B!834P@9&5S8W)I<'1I;VX@=VET:"!R
M96QE87-E(&EN9F]R;6%T:6]N+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R
M<F%Y("`D<&MG:6YF;R`@("!A<G)A>2!W:71H(')E;&5A<V4@:6YF;W)M871I
M;VX-"B`@("`@*B!`<&%R86T@8F]O;"`@("1C:&%N9V5L;V<@('=H971H97(@
M=&AE(')E<W5L="!W:6QL(&)E(&EN(&$@8VAA;F=E;&]G(&5L96UE;G0-"B`@
M("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(%A-3"!D871A#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?;6%K95)E;&5A<V58;6PH)'!K9VEN9F\L("1C:&%N9V5L;V<@/2!F86QS
M92P@)'-T871E(#T@4$5!4E]604Q)1$%415].3U)-04PI#0H@("`@>PT*("`@
M("`@("`O+R!86%@@455/5$4@14Y4251)15,@24X@4$-$051!+"!/4B!%34)%
M1"!)3B!#1$%402!"3$]#2U,A(0T*("`@("`@("`D:6YD96YT(#T@)&-H86YG
M96QO9R`_("(@("(@.B`B(CL-"B`@("`@("`@)')E="`]("(D:6YD96YT(#QR
M96QE87-E/EQN(CL-"B`@("`@("`@:68@*"%E;7!T>2@D<&MG:6YF;ULG=F5R
M<VEO;B==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/'9E
M<G-I;VX^)'!K9VEN9F];=F5R<VEO;ET\+W9E<G-I;VX^7&XB.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A96UP='DH)'!K9VEN9F];)W)E;&5A<V5?9&%T
M92==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/&1A=&4^
M)'!K9VEN9F];<F5L96%S95]D871E73PO9&%T93Y<;B([#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%E;7!T>2@D<&MG:6YF;ULG<F5L96%S95]L:6-E;G-E
M)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\;&EC96YS
M93XD<&MG:6YF;UMR96QE87-E7VQI8V5N<V5=/"]L:6-E;G-E/EQN(CL-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(65M<'1Y*"1P:V=I;F9O6R=R96QE87-E
M7W-T871E)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\
M<W1A=&4^)'!K9VEN9F];<F5L96%S95]S=&%T95T\+W-T871E/EQN(CL-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(65M<'1Y*"1P:V=I;F9O6R=R96QE87-E
M7VYO=&5S)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\
M;F]T97,^(BYT<FEM*"1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)'!K9VEN9F];
M)W)E;&5A<V5?;F]T97,G72DI#0H@("`@("`@("`@("`N(EQN)&EN9&5N="`@
M/"]N;W1E<SY<;B([#0H@("`@("`@('T-"B`@("`@("`@:68@*"%E;7!T>2@D
M<&MG:6YF;ULG<F5L96%S95]W87)N:6YG<R==*2D@>PT*("`@("`@("`@("`@
M)')E="`N/2`B)&EN9&5N="`@/'=A<FYI;F=S/B(N)'1H:7,M/E]F:7A8;6Q%
M;F-O9&EN9R@D<&MG:6YF;ULG<F5L96%S95]W87)N:6YG<R==*2XB/"]W87)N
M:6YG<SY<;B([#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1P:V=I
M;F9O6R=R96QE87-E7V1E<',G72D@)B8@<VEZ96]F*"1P:V=I;F9O6R=R96QE
M87-E7V1E<',G72D@/B`P*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD
M96YT("`\9&5P<SY<;B([#0H@("`@("`@("`@("!F;W)E86-H("@D<&MG:6YF
M;ULG<F5L96%S95]D97!S)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@
M("1R970@+CT@(B1I;F1E;G0@("`\9&5P('1Y<&4]7"(D9&5P6W1Y<&5=7"(@
M<F5L/5PB)&1E<%MR96Q=7"(B.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R
M970@+CT@(B!V97)S:6]N/5PB)&1E<%MV97)S:6]N75PB(CL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V]P
M=&EO;F%L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@(B!O
M<'1I;VYA;#U<(B1D97!;;W!T:6]N86Q=7"(B.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(^)&1E<%MN86UE73PO
M9&5P/EQN(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5T("X]("(O/EQN(CL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT
M("`\+V1E<',^7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M<&MG:6YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@
M("1R970@+CT@(B1I;F1E;G0@(#QC;VYF:6=U<F5O<'1I;VYS/EQN(CL-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1P:V=I;F9O6R=C;VYF:6=U<F5?;W!T:6]N
M<R==(&%S("1C*2![#0H@("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N
M="`@(#QC;VYF:6=U<F5O<'1I;VX@;F%M93U<(B(N#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)&-;)VYA;64G72D@+B`B
M7"(B.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8ULG9&5F875L="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(@9&5F875L=#U<
M(B(@+B`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1C6R=D969A=6QT)UTI("X@
M(EPB(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E
M="`N/2`B('!R;VUP=#U<(B(@+B`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1C
M6R=P<F]M<'0G72D@+B`B7"(B.PT*("`@("`@("`@("`@("`@("1R970@+CT@
M(B\^7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`N/2`B
M)&EN9&5N="`@/"]C;VYF:6=U<F5O<'1I;VYS/EQN(CL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)'!K9VEN9F];)W!R;W9I9&5S)UTI*2![#0H@
M("`@("`@("`@("!F;W)E86-H("@D<&MG:6YF;ULG<')O=FED97,G72!A<R`D
M:V5Y(#T^("1W:&%T*2![#0H@("`@("`@("`@("`@("`@)')E="`N/2`B)&EN
M9&5N="`@/'!R;W9I9&5S('1Y<&4]7"(D=VAA=%MT>7!E75PB("([#0H@("`@
M("`@("`@("`@("`@)')E="`N/2`B;F%M93U<(B1W:&%T6VYA;65=7"(@(CL-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'=H871;)V5X=&5N9',G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B97AT96YD<SU<(B1W
M:&%T6V5X=&5N9'-=7"(@(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)')E="`N/2`B+SY<;B([#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1P:V=I;F9O6R=F:6QE;&ES="==
M*2D@>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/&9I;&5L:7-T
M/EQN(CL-"B`@("`@("`@("`@(&EF("@D<W1A=&4@7B!014%27U9!3$E$051%
M7U!!0TM!1TE.1RD@>PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H:7,M
M/G)E8W5R<VEV95AM;$9I;&5L:7-T*"1P:V=I;F9O6R=F:6QE;&ES="==*3L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!K9VEN9F];)V9I;&5L:7-T)UT@87,@)&9I;&4@/3X@)&9A*2![#0H@
M("`@("`@("`@("`@("`@("`@($`D<F5T("X]("(D:6YD96YT("`@/&9I;&4@
M<F]L93U<(B1F85MR;VQE75PB(CL-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1F85LG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R970@+CT@)R!B87-E:6YS=&%L;&1I<CTB)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]F:7A8;6Q%;F-O
M9&EN9R@D9F%;)V)A<V5I;G-T86QL9&ER)UTI("X@)R(G.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9F%;)VUD-7-U;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M="`N/2`B(&UD-7-U;3U<(B1F85MM9#5S=6U=7"(B.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9F%;
M)W!L871F;W)M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T
M("X]("(@<&QA=&9O<FT]7"(D9F%;<&QA=&9O<FU=7"(B.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)&9A6R=I;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T("X]("<@:6YS=&%L;"UA<STB)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D9F%;)VEN<W1A
M;&PM87,G72D@+B`G(B<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)')E="`N/2`G(&YA;64](B<@+B`D=&AI<RT^7V9I
M>%AM;$5N8V]D:6YG*"1F:6QE*2`N("<B)SL-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&5M<'1Y*"1F85LG<F5P;&%C96UE;G1S)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T("X]("(O/EQN(CL-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R
M970@+CT@(CY<;B([#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D9F%;)W)E<&QA8V5M96YT<R==(&%S("1R*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@("`\<F5P;&%C92([
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'(@87,@
M)&L@/3X@)'8I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E="`N/2`B("1K/5PB(B`N("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)'8I
M("XG(B<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M0"1R970@+CT@(B1I;F1E;G0@("`\+V9I;&4^7&XB.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/"]F:6QE;&ES=#Y<;B([
M#0H@("`@("`@('T-"B`@("`@("`@)')E="`N/2`B)&EN9&5N="`\+W)E;&5A
M<V4^7&XB.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(')E8W5R<VEV95AM;$9I;&5L
M:7-T*"1L:7-T*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]D:7)S(#T@87)R
M87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&9I;&4@/3X@)&%T
M=')I8G5T97,I('L-"B`@("`@("`@("`@("1T:&ES+3Y?861D1&ER*"1T:&ES
M+3Y?9&ER<RP@97AP;&]D92@G+R<L(&1I<FYA;64H)&9I;&4I*2P@)&9I;&4L
M("1A='1R:6)U=&5S*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H
M:7,M/E]F;W)M871$:7(H)'1H:7,M/E]D:7)S*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<&%R86T@87)R87D-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P-"B`@("`@*B!`<&%R86T@87)R
M87E\;G5L;`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]A9&1$:7(H)B1D:7)S+"`D9&ER+"`D9FEL92`](&YU;&PL
M("1A='1R:6)U=&5S(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D9&ER
M(#T](&%R<F%Y*"D@?'P@)&1I<B`]/2!A<G)A>2@G+B<I*2![#0H@("`@("`@
M("`@("`D9&ER<ULG9FEL97,G75MB87-E;F%M92@D9FEL92E=(#T@)&%T=')I
M8G5T97,[#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@
M("`@)&-U<F1I<B`](&%R<F%Y7W-H:69T*"1D:7(I.PT*("`@("`@("!I9B`H
M(6ES<V5T*"1D:7)S6R=D:7)S)UU;)&-U<F1I<ETI*2![#0H@("`@("`@("`@
M("`D9&ER<ULG9&ER<R==6R1C=7)D:7)=(#T@87)R87DH*3L-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^7V%D9$1I<B@D9&ER<ULG9&ER<R==6R1C=7)D
M:7)=+"`D9&ER+"`D9FEL92P@)&%T=')I8G5T97,I.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!S=')I
M;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V9O<FUA=$1I<B@D9&ER<RP@
M)&EN9&5N="`]("<G+"`D8W5R9&ER(#T@)R<I#0H@("`@>PT*("`@("`@("`D
M<F5T(#T@)R<[#0H@("`@("`@(&EF("@A8V]U;G0H)&1I<G,I*2![#0H@("`@
M("`@("`@("!R971U<FX@)R<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1D:7)S6R=D:7)S)UTI*2![#0H@("`@("`@("`@("!U:W-O<G0H)&1I
M<G-;)V1I<G,G72P@)W-T<FYA=&-A<V5C;7`G*3L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1D:7)S6R=D:7)S)UT@87,@)&1I<B`]/B`D8V]N=&5N=',I('L-
M"B`@("`@("`@("`@("`@("`D=7-E9&ER(#T@(B1C=7)D:7(O)&1I<B([#0H@
M("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@(#QD:7(@;F%M93U<
M(B1D:7)<(CY<;B([#0H@("`@("`@("`@("`@("`@)')E="`N/2`D=&AI<RT^
M7V9O<FUA=$1I<B@D8V]N=&5N=',L("(D:6YD96YT("(L("1U<V5D:7(I.PT*
M("`@("`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`\+V1I<CX@/"$M
M+2`D=7-E9&ER("TM/EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&1I<G-;)V9I;&5S)UTI*2![#0H@("`@("`@
M("`@("!U:W-O<G0H)&1I<G-;)V9I;&5S)UTL("=S=')N871C87-E8VUP)RD[
M#0H@("`@("`@("`@("!F;W)E86-H("@D9&ER<ULG9FEL97,G72!A<R`D9FEL
M92`]/B`D871T<FEB<RD@>PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H
M:7,M/E]F;W)M871&:6QE*"1F:6QE+"`D871T<FEB<RP@)&EN9&5N="D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@
M("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9F]R
M;6%T1FEL92@D9FEL92P@)&%T=')I8G5T97,L("1I;F1E;G0I#0H@("`@>PT*
M("`@("`@("`D<F5T(#T@(B1I;F1E;G0@("`\9FEL92!R;VQE/5PB)&%T=')I
M8G5T97-;<F]L95U<(B([#0H@("`@("`@(&EF("AI<W-E="@D871T<FEB=71E
M<ULG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("1R970@+CT@
M)R!B87-E:6YS=&%L;&1I<CTB)R`N#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]F:7A8;6Q%;F-O9&EN9R@D871T<FEB=71E<ULG8F%S96EN<W1A;&QD:7(G
M72D@+B`G(B<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1A='1R
M:6)U=&5S6R=M9#5S=6TG72DI('L-"B`@("`@("`@("`@("1R970@+CT@(B!M
M9#5S=6T]7"(D871T<FEB=71E<UMM9#5S=6U=7"(B.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D871T<FEB=71E<ULG<&QA=&9O<FTG72DI('L-
M"B`@("`@("`@("`@("1R970@+CT@(B!P;&%T9F]R;3U<(B1A='1R:6)U=&5S
M6W!L871F;W)M75PB(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(65M<'1Y
M*"1A='1R:6)U=&5S6R=I;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D
M<F5T("X]("<@:6YS=&%L;"UA<STB)R`N#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]F:7A8;6Q%;F-O9&EN9R@D871T<FEB=71E<ULG:6YS=&%L;"UA<R==
M*2`N("<B)SL-"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]("<@;F%M93TB
M)R`N("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)&9I;&4I("X@)R(G.PT*("`@
M("`@("!I9B`H96UP='DH)&%T=')I8G5T97-;)W)E<&QA8V5M96YT<R==*2D@
M>PT*("`@("`@("`@("`@)')E="`N/2`B+SY<;B([#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D<F5T("X]("(^7&XB.PT*("`@("`@("`@("`@
M9F]R96%C:"`H)&%T=')I8G5T97-;)W)E<&QA8V5M96YT<R==(&%S("1R*2![
M#0H@("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@("`\<F5P;&%C
M92([#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'(@87,@)&L@/3X@)'8I
M('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B("1K/5PB(B`N("1T
M:&ES+3Y?9FEX6&UL16YC;V1I;F<H)'8I("XG(B<[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@(#PO9FEL
M93Y<;B([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+R\@>WM[(%]U;DEN9&5N="@I#0H-"B`@("`O*BH-"B`@("`@
M*B!5;FEN9&5N="!G:79E;B!S=')I;F<@*#\I#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S='(@5&AE('-T<FEN9R!T:&%T(&AA<R!T;R!B92!U
M;FEN9&5N=&5D+@T*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5N26YD96YT
M*"1S='(I#0H@("`@>PT*("`@("`@("`O+R!R96UO=F4@;&5A9&EN9R!N97=L
M:6YE<PT*("`@("`@("`D<W1R(#T@<')E9U]R97!L86-E*"<O7EM<<EQN72LO
M)RP@)R<L("1S='(I.PT*("`@("`@("`O+R!F:6YD('=H:71E<W!A8V4@870@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FER<W0@;&EN90T*("`@("`@("`D:6YD
M96YT7VQE;B`]('-T<G-P;B@D<W1R+"`B(%QT(BD[#0H@("`@("`@("1I;F1E
M;G0@/2!S=6)S='(H)'-T<BP@,"P@)&EN9&5N=%]L96XI.PT*("`@("`@("`D
M9&%T82`]("<G.PT*("`@("`@("`O+R!R96UO=F4@=&AE('-A;64@86UO=6YT
M(&]F('=H:71E<W!A8V4@9G)O;2!F;VQL;W=I;F<@;&EN97,-"B`@("`@("`@
M9F]R96%C:"`H97AP;&]D92@B7&XB+"`D<W1R*2!A<R`D;&EN92D@>PT*("`@
M("`@("`@("`@:68@*'-U8G-T<B@D;&EN92P@,"P@)&EN9&5N=%]L96XI(#T]
M("1I;F1E;G0I('L-"B`@("`@("`@("`@("`@("`D9&%T82`N/2!S=6)S='(H
M)&QI;F4L("1I;F1E;G1?;&5N*2`N(")<;B([#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1D871A.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!D97!E;F1E;F-I97-4;U8R*"D-"B`@("![#0H@("`@("`@("1A<G(@
M/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^7V-O;G9E<G1$97!E;F1E;F-I
M97,R7S`H)&%R<BD[#0H@("`@("`@(')E='5R;B`D87)R6R=D97!E;F1E;F-I
M97,G73L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#;VYV97)T(&$@<&%C
M:V%G92YX;6P@=F5R<VEO;B`Q+C`@:6YT;R!V97)S:6]N(#(N,`T*("`@("`J
M#0H@("`@("H@3F]T92!T:&%T('1H:7,@9&]E<R!A(&)A<VEC(&-O;G9E<G-I
M;VXL('1O(&%L;&]W(&UO<F4@861V86YC960-"B`@("`@*B!F96%T=7)E<R!L
M:6ME(&)U;F1L97,@86YD(&UU;'1I<&QE(')E;&5A<V5S#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!T:&4@8VQA<W-N86UE('1O(&EN<W1A;G1I871E(&%N9"!R
M971U<FXN("!4:&ES(&UU<W0@8F4-"B`@("`@*B`@("`@("`@("`@("`@(%!%
M05)?4&%C:V%G949I;&5?=C(@;W(@82!D97-C96YD86YT#0H@("`@("H@0'!A
M<F%M(&)O;VQE86X@:68@=')U92P@;VYL>2!V86QI9"P@9&5T97)M:6YI<W1I
M8R!P86-K86=E+GAM;"`Q+C`@87,@9&5F:6YE9"!B>2!T:&4-"B`@("`@*B`@
M("`@("`@("`@("`@("!S=')I8W1E<W0@<&%R86UE=&5R<R!W:6QL(&)E(&-O
M;G9E<G1E9`T*("`@("`J($!R971U<FX@4$5!4E]086-K86=E1FEL95]V,GQ0
M14%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)G1O5C(H)&-L87-S
M(#T@)U!%05)?4&%C:V%G949I;&5?=C(G+"`D<W1R:6-T(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("!I9B`H)'-T<FEC="D@>PT*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^7W!A8VMA9V5F:6QE+3YV86QI9&%T92@I*2![#0H@("`@("`@
M("`@("`@("`@)&$@/2!014%2.CIR86ES945R<F]R*"=I;G9A;&ED('!A8VMA
M9V4N>&UL('9E<G-I;VX@,2XP(&-A;FYO="!B92!C;VYV97)T960G("X-"B`@
M("`@("`@("`@("`@("`@("`@)R!T;R!V97)S:6]N(#(N,"<L(&YU;&PL(&YU
M;&PL(&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M969I;&4M/F=E=%9A;&ED871I;VY787)N:6YG<RAT<G5E*2D[#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@("1A<G(@/2!A<G)A>2@-"B`@("`@("`@("`@("=A='1R:6)S
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9E
M<G-I;VXG(#T^("<R+C`G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G>&UL;G,G(#T^("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E
M+3(N,"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X;6QN<SIT
M87-K<R<@/3X@)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,"<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X;6QN<SIX<VDG(#T^
M("=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X<VDZ<V-H96UA3&]C
M871I;VXG(#T^(")H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C!<
M;B(@+@T*(FAT='`Z+R]P96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,"YX<V1<
M;B(@+@T*(FAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,BXP7&XB
M("X-"B=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"YX<V0G
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G
M;F%M92<@/3X@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G92@I+`T*
M("`@("`@("`@("`@)V-H86YN96PG(#T^("=P96%R+G!H<"YN970G+`T*("`@
M("`@("`I.PT*("`@("`@("`D87)R6R=S=6UM87)Y)UT@/2`D=&AI<RT^7W!A
M8VMA9V5F:6QE+3YG9713=6UM87)Y*"D[#0H@("`@("`@("1A<G);)V1E<V-R
M:7!T:6]N)UT@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971$97-C<FEP=&EO
M;B@I.PT*("`@("`@("`D;6%I;G1A:6YE<G,@/2`D=&AI<RT^7W!A8VMA9V5F
M:6QE+3YG971-86EN=&%I;F5R<R@I.PT*("`@("`@("!F;W)E86-H("@D;6%I
M;G1A:6YE<G,@87,@)&UA:6YT86EN97(I('L-"B`@("`@("`@("`@(&EF("@D
M;6%I;G1A:6YE<ELG<F]L92==("$]("=L96%D)RD@>PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&YE
M=R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;6%I;G1A
M:6YE<ELG;F%M92==+`T*("`@("`@("`@("`@("`@("=U<V5R)R`]/B`D;6%I
M;G1A:6YE<ELG:&%N9&QE)UTL#0H@("`@("`@("`@("`@("`@)V5M86EL)R`]
M/B`D;6%I;G1A:6YE<ELG96UA:6PG72P-"B`@("`@("`@("`@("`@("`G86-T
M:79E)R`]/B`G>65S)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("`@("`D
M87)R6R=L96%D)UU;72`]("1N97<[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%I<W-E="@D87)R6R=L96%D)UTI*2![("\O('-O;64@<&5O<&QE+BXN('EO
M=2!K;F]W/PT*("`@("`@("`@("`@)&%R<ELG;&5A9"==(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@)VYA;64G(#T^("=U;FMN;W=N)RP-"B`@("`@("`@
M("`@("`@("`G=7-E<B<@/3X@)W5N:VYO=VXG+`T*("`@("`@("`@("`@("`@
M("=E;6%I;"<@/3X@)VYO;&5A9&UA:6YT86EN97)`97AA;7!L92YC;VTG+`T*
M("`@("`@("`@("`@("`@("=A8W1I=F4G(#T^("=N;R<L#0H@("`@("`@("`@
M("`I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D87)R6R=L96%D
M)UTI(#T](#$I('L-"B`@("`@("`@("`@("1A<G);)VQE860G72`]("1A<G);
M)VQE860G75LP73L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D;6%I
M;G1A:6YE<G,@87,@)&UA:6YT86EN97(I('L-"B`@("`@("`@("`@(&EF("@D
M;6%I;G1A:6YE<ELG<F]L92==(#T]("=L96%D)RD@>PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&YE
M=R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;6%I;G1A
M:6YE<ELG;F%M92==+`T*("`@("`@("`@("`@("`@("=U<V5R)R`]/B`D;6%I
M;G1A:6YE<ELG:&%N9&QE)UTL#0H@("`@("`@("`@("`@("`@)V5M86EL)R`]
M/B`D;6%I;G1A:6YE<ELG96UA:6PG72P-"B`@("`@("`@("`@("`@("`G86-T
M:79E)R`]/B`G>65S)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("`@("`D
M87)R6R1M86EN=&%I;F5R6R=R;VQE)UU=6UT@/2`D;F5W.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D87)R6R=D979E;&]P97(G72D@)B8@8V]U
M;G0H)&%R<ELG9&5V96QO<&5R)UTI(#T](#$I('L-"B`@("`@("`@("`@("1A
M<G);)V1E=F5L;W!E<B==(#T@)&%R<ELG9&5V96QO<&5R)UU;,%T[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1A<G);)V-O;G1R:6)U=&]R)UTI
M("8F(&-O=6YT*"1A<G);)V-O;G1R:6)U=&]R)UTI(#T](#$I('L-"B`@("`@
M("`@("`@("1A<G);)V-O;G1R:6)U=&]R)UT@/2`D87)R6R=C;VYT<FEB=71O
M<B==6S!=.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D87)R6R=H
M96QP97(G72D@)B8@8V]U;G0H)&%R<ELG:&5L<&5R)UTI(#T](#$I('L-"B`@
M("`@("`@("`@("1A<G);)VAE;'!E<B==(#T@)&%R<ELG:&5L<&5R)UU;,%T[
M#0H@("`@("`@('T-"B`@("`@("`@)&%R<ELG9&%T92==(#T@)'1H:7,M/E]P
M86-K86=E9FEL92T^9V5T1&%T92@I.PT*("`@("`@("`D87)R6R=V97)S:6]N
M)UT@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)W)E
M;&5A<V4G(#T^("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%9E<G-I;VXH*2P-
M"B`@("`@("`@("`@("`@("`G87!I)R`]/B`D=&AI<RT^7W!A8VMA9V5F:6QE
M+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`I.PT*("`@("`@("`D87)R
M6R=S=&%B:6QI='DG72`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`G<F5L96%S92<@/3X@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T
M4W1A=&4H*2P-"B`@("`@("`@("`@("`@("`G87!I)R`]/B`D=&AI<RT^7W!A
M8VMA9V5F:6QE+3YG9713=&%T92@I+`T*("`@("`@("`@("`@*3L-"B`@("`@
M("`@)&QI8V5N<V5M87`@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@
M("`@("`@("`@)W!H<"<@/3X@)VAT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M)RP-"B`@("`@("`@("`@("`@("`G<&AP(&QI8V5N<V4G(#T^("=H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92<L#0H@("`@("`@("`@("`@("`@)VQG<&PG
M(#T^("=H='1P.B\O=W=W+F=N=2YO<F<O8V]P>6QE9G0O;&5S<V5R+FAT;6PG
M+`T*("`@("`@("`@("`@("`@("=B<V0G(#T^("=H='1P.B\O=W=W+F]P96YS
M;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"<L#0H@("`@("`@
M("`@("`@("`@)V)S9"!S='EL92<@/3X@)VAT='`Z+R]W=W<N;W!E;G-O=7)C
M92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP)RP-"B`@("`@("`@("`@
M("`@("`G8G-D+7-T>6QE)R`]/B`G:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R
M9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`G+`T*("`@("`@("`@("`@("`@
M("=M:70G(#T^("=H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+VUI="UL:6-E;G-E+G!H<"<L#0H@("`@("`@("`@("`@("`@)V=P;"<@/3X@
M)VAT='`Z+R]W=W<N9VYU+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"<L#0H@("`@
M("`@("`@("`@("`@)V%P86-H92<@/3X@)VAT='`Z+R]W=W<N;W!E;G-O=7)C
M92YO<F<O;&EC96YS97,O87!A8VAE,BXP+G!H<"<-"B`@("`@("`@("`@("D[
M#0H@("`@("`@(&EF("AI<W-E="@D;&EC96YS96UA<%MS=')T;VQO=V5R*"1T
M:&ES+3Y?<&%C:V%G969I;&4M/F=E=$QI8V5N<V4H*2E=*2D@>PT*("`@("`@
M("`@("`@)&%R<ELG;&EC96YS92==(#T@87)R87DH#0H@("`@("`@("`@("`@
M("`@)V%T=')I8G,G(#T^(&%R<F%Y*"=U<FDG(#T^#0H@("`@("`@("`@("`@
M("`@("`@("1L:6-E;G-E;6%P6W-T<G1O;&]W97(H)'1H:7,M/E]P86-K86=E
M9FEL92T^9V5T3&EC96YS92@I*5TI+`T*("`@("`@("`@("`@("`@("=?8V]N
M=&5N="<@/3X@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T3&EC96YS92@I#0H@
M("`@("`@("`@("`@("`@*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("\O(&1O;B=T('5S92!B;V=U<R!U<FD-"B`@("`@("`@("`@("1A<G);
M)VQI8V5N<V4G72`]("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$QI8V5N<V4H
M*3L-"B`@("`@("`@?0T*("`@("`@("`D87)R6R=N;W1E<R==(#T@)'1H:7,M
M/E]P86-K86=E9FEL92T^9V5T3F]T97,H*3L-"B`@("`@("`@)'1E;7`@/2!A
M<G)A>2@I.PT*("`@("`@("`D87)R6R=C;VYT96YT<R==(#T@)'1H:7,M/E]C
M;VYV97)T1FEL96QI<W0R7S`H)'1E;7`I.PT*("`@("`@("`D=&AI<RT^7V-O
M;G9E<G1$97!E;F1E;F-I97,R7S`H)&%R<BD[#0H@("`@("`@("1R96QE87-E
M(#T@*"1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$-O;F9I9W5R94]P=&EO;G,H
M*2!\?"`D=&AI<RT^7VES17AT96YS:6]N*2`_#0H@("`@("`@("`@("`G97AT
M<W)C<F5L96%S92<@.B`G<&AP<F5L96%S92<[#0H@("`@("`@(&EF("@D<F5L
M96%S92`]/2`G97AT<W)C<F5L96%S92<I('L-"B`@("`@("`@("`@("1A<G);
M)V-H86YN96PG72`]("=P96-L+G!H<"YN970G.PT*("`@("`@("`@("`@)&%R
M<ELG<')O=FED97-E>'1E;G-I;VXG72`]("1A<G);)VYA;64G73L@+R\@87-S
M=6UP=&EO;@T*("`@("`@("!]#0H@("`@("`@("1A<G);)')E;&5A<V5=(#T@
M87)R87DH*3L-"B`@("`@("`@:68@*"1T:&ES+3Y?<&%C:V%G969I;&4M/F=E
M=$-O;F9I9W5R94]P=&EO;G,H*2D@>PT*("`@("`@("`@("`@)&%R<ELD<F5L
M96%S95U;)V-O;F9I9W5R96]P=&EO;B==(#T@)'1H:7,M/E]P86-K86=E9FEL
M92T^9V5T0V]N9FEG=7)E3W!T:6]N<R@I.PT*("`@("`@("`@("`@9F]R96%C
M:"`H)&%R<ELD<F5L96%S95U;)V-O;F9I9W5R96]P=&EO;B==(&%S("1I(#T^
M("1O<'0I('L-"B`@("`@("`@("`@("`@("`D87)R6R1R96QE87-E75LG8V]N
M9FEG=7)E;W!T:6]N)UU;)&E=(#T@87)R87DH)V%T=')I8G,G(#T^("1O<'0I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT*"1A<G);
M)')E;&5A<V5=6R=C;VYF:6=U<F5O<'1I;VXG72D@/3T@,2D@>PT*("`@("`@
M("`@("`@("`@("1A<G);)')E;&5A<V5=6R=C;VYF:6=U<F5O<'1I;VXG72`]
M("1A<G);)')E;&5A<V5=6R=C;VYF:6=U<F5O<'1I;VXG75LP73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-O;G9E<G12
M96QE87-E,E\P*"1A<G);)')E;&5A<V5=+"`D=&5M<"D[#0H@("`@("`@(&EF
M("@D<F5L96%S92`]/2`G97AT<W)C<F5L96%S92<@)B8@8V]U;G0H)&%R<ELD
M<F5L96%S95TI(#X@,2D@>PT*("`@("`@("`@("`@+R\@;75L=&EP;&4@97AT
M<W)C<F5L96%S92!T86=S(&%D9&5D(&EN(%!%05(@,2XT+C$-"B`@("`@("`@
M("`@("1A<G);)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P96%R:6YS
M=&%L;&5R)UU;)VUI;B==(#T@)S$N-"XQ)SL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&-L(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T0VAA;F=E;&]G
M*"DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;"!A<R`D<F5L96%S92D@
M>PT*("`@("`@("`@("`@("`@("1R96P@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@("1R96Q;)W9E<G-I;VXG72`]#0H@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@)W)E;&5A<V4G(#T^
M("1R96QE87-E6R=V97)S:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G87!I)R`]/B`D<F5L96%S95LG=F5R<VEO;B==+`T*("`@("`@("`@("`@
M("`@("`@("`I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')E;&5A
M<V5;)W)E;&5A<V5?<W1A=&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)')E;&5A<V5;)W)E;&5A<V5?<W1A=&4G72`]("=S=&%B;&4G.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<F5L6R=S=&%B:6QI='DG
M72`]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E;&5A<V4G(#T^("1R96QE87-E6R=R96QE87-E7W-T
M871E)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`G87!I)R`]/B`D<F5L
M96%S95LG<F5L96%S95]S=&%T92==+`T*("`@("`@("`@("`@("`@("`@("`I
M.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5L96%S95LG<F5L96%S
M95]D871E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R96Q;)V1A=&4G
M72`]("1R96QE87-E6R=R96QE87-E7V1A=&4G73L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D<F5L6R=D871E)UT@
M/2!D871E*"=9+6TM9"<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)')E;&5A<V5;)W)E;&5A<V5?;&EC96YS92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&QI8V5N<V5M
M87!;<W1R=&]L;W=E<B@D<F5L96%S95LG<F5L96%S95]L:6-E;G-E)UTI72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1U<FD@/2`D;&EC96YS96UA
M<%MS=')T;VQO=V5R*"1R96QE87-E6R=R96QE87-E7VQI8V5N<V4G72E=.PT*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'5R:2`]("=H='1P.B\O=W=W+F5X86UP;&4N8V]M)SL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<F5L
M6R=L:6-E;G-E)UT@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G871T<FEB<R<@/3X@87)R87DH)W5R:2<@/3X@)'5R:2DL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)U]C;VYT96YT)R`]/B`D<F5L96%S
M95LG<F5L96%S95]L:6-E;G-E)UT-"B`@("`@("`@("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)')E;%LG;&EC96YS92==(#T@)&%R<ELG;&EC96YS92==.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R
M96QE87-E6R=R96QE87-E7VYO=&5S)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1R96QE87-E6R=R96QE87-E7VYO=&5S)UT@/2`G;F\@<F5L96%S92!N
M;W1E<R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R
M96Q;)VYO=&5S)UT@/2`D<F5L96%S95LG<F5L96%S95]N;W1E<R==.PT*("`@
M("`@("`@("`@("`@("1A<G);)V-H86YG96QO9R==6R=R96QE87-E)UU;72`]
M("1R96P[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)')E
M="`](&YE=R`D8VQA<W,[#0H@("`@("`@("1R970M/G-E=$-O;F9I9R@D=&AI
M<RT^7W!A8VMA9V5F:6QE+3Y?8V]N9FEG*3L-"B`@("`@("`@)')E="T^<V5T
M3&]G9V5R*"1T:&ES+3Y?<&%C:V%G969I;&4M/E]L;V=G97(I.PT*("`@("`@
M("`D<F5T+3YF<F]M07)R87DH)&%R<BD[#0H@("`@("`@(')E='5R;B`D<F5T
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@
M("`J($!P87)A;2!B;V]L#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@7V-O;G9E<G1$97!E;F1E;F-I97,R7S`H)B1R
M96QE87-E+"`D:6YT97)N86P@/2!F86QS92D-"B`@("![#0H@("`@("`@("1P
M96%R9&5P(#T@87)R87DH)W!E87)I;G-T86QL97(G(#T^#0H@("`@("`@("`@
M("!A<G)A>2@G;6EN)R`]/B`G,2XT+C!B,2<I*3L@+R\@=&AI<R!I<R!A(&QO
M="!S869E<@T*("`@("`@("`D<F5Q=6ER960@/2`D;W!T:6]N86P@/2!A<G)A
M>2@I.PT*("`@("`@("`D<F5L96%S95LG9&5P96YD96YC:65S)UT@/2!A<G)A
M>2@I.PT*("`@("`@("!I9B`H)'1H:7,M/E]P86-K86=E9FEL92T^:&%S1&5P
M<R@I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A8VMA9V5F
M:6QE+3YG971$97!S*"D@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&1E<%LG;W!T:6]N86PG72D@?'P@)&1E<%LG;W!T:6]N86PG
M72`]/2`G;F\G*2![#0H@("`@("`@("`@("`@("`@("`@("1R97%U:7)E9%M=
M(#T@)&1E<#L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D;W!T:6]N86Q;72`]("1D97`[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H87)R
M87DH)W)E<75I<F5D)RP@)V]P=&EO;F%L)RD@87,@)&%R<BD@>PT*("`@("`@
M("`@("`@("`@("1D97!S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D)&%R<B!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@
M("\O(&]R9V%N:7IE(&1E<',@8GD@9&5P96YD96YC>2!T>7!E(&%N9"!N86UE
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)&1E<%LG
M='EP92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!S6R1D
M97!;)W1Y<&4G75T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=N86UE)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULD9&5P6R=T>7!E
M)UU=6R1D97!;)VYA;64G75U;72`]("1D97`[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULD
M9&5P6R=T>7!E)UU=6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&1O('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=P:'`G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P:'`@/2!A<G)A>2@I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1D97!S6R=P:'`G72D@
M/B`Q*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<"`]("1T
M:&ES+3Y?<')O8V5S<U!H<$1E<',H)&1E<'-;)W!H<"==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG<&AP)UU;,%TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)&ME>2P@)&)L86@I
M(#T@96%C:"`H)&1E<'-;)W!H<"==*3L@+R\@<W1U<&ED(&)U9V=Y('9E<G-I
M;VYS#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!S6R=P
M:'`G72`](&%R<F%Y*"1B;&%H6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<"`]
M("1T:&ES+3Y?<')O8V5S<T1E<"@D9&5P<ULG<&AP)UU;,%TI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A)'!H<"D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL@+R\@<&]O<B!M86YS('1H
M<F]W#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M;&5A<V5;)V1E<&5N9&5N8VEE<R==6R1A<G)=6R=P:'`G72`]("1P:'`[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]('=H:6QE
M("AF86QS92D[#0H@("`@("`@("`@("`@("`@9&\@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<'-;)W!K9R==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!K9R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<&MG(#T@)'1H:7,M/E]P<F]C97-S375L=&EP;&5$97!S
M3F%M92@D9&5P<ULG<&MG)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"$D<&MG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L[("\O('!O;W(@;6%N<R!T:')O=PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)V1E<&5N
M9&5N8VEE<R==6R1A<G)=6R=P86-K86=E)UT@/2`D<&MG.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!W:&EL92`H9F%L<V4I
M.PT*("`@("`@("`@("`@("`@(&1O('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D97!S6R=E>'0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P:V<@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!K9R`]("1T:&ES+3Y?<')O8V5S<TUU;'1I<&QE1&5P<TYA;64H)&1E
M<'-;)V5X="==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E
M6R=D97!E;F1E;F-I97,G75LD87)R75LG97AT96YS:6]N)UT@/2`D<&MG.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!W:&EL
M92`H9F%L<V4I.PT*("`@("`@("`@("`@("`@("\O('-K:7`@<V%P:2`M(&ET
M)W,@;F]T('-U<'!O<G1E9"!S;R!N;V)O9'D@=VEL;"!H879E('5S960@:70-
M"B`@("`@("`@("`@("`@("`O+R!S:VEP(&]S("T@:70G<R!N;W0@<W5P<&]R
M=&5D(&EN(#$N,`T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D
M)UTI*2![#0H@("`@("`@("`@("`D<F5L96%S95LG9&5P96YD96YC:65S)UU;
M)W)E<75I<F5D)UT@/0T*("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1P
M96%R9&5P+"`D<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UTI
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)')E;&5A<V5;)V1E
M<&5N9&5N8VEE<R==6R=R97%U:7)E9"==(#T@)'!E87)D97`[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%I<W-E="@D<F5L96%S95LG9&5P96YD96YC:65S
M)UU;)W)E<75I<F5D)UU;)W!H<"==*2D@>PT*("`@("`@("`@("`@)')E;&5A
M<V5;)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P:'`G72`]#0H@("`@
M("`@("`@("`@("`@87)R87DH)VUI;B<@/3X@)S0N,"XP)RD[#0H@("`@("`@
M('T-"B`@("`@("`@)&]R9&5R(#T@87)R87DH*3L-"B`@("`@("`@)&)E=VT@
M/2`D<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UT[#0H@("`@
M("`@("1O<F1E<ELG<&AP)UT@/2`D8F5W;5LG<&AP)UT[#0H@("`@("`@("1O
M<F1E<ELG<&5A<FEN<W1A;&QE<B==(#T@)&)E=VU;)W!E87)I;G-T86QL97(G
M73L-"B`@("`@("`@:7-S970H)&)E=VU;)W!A8VMA9V4G72D@/R`D;W)D97);
M)W!A8VMA9V4G72`]("1B97=M6R=P86-K86=E)UT@.C`[#0H@("`@("`@(&ES
M<V5T*"1B97=M6R=E>'1E;G-I;VXG72D@/R`D;W)D97);)V5X=&5N<VEO;B==
M(#T@)&)E=VU;)V5X=&5N<VEO;B==(#HP.PT*("`@("`@("`D<F5L96%S95LG
M9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UT@/2`D;W)D97([#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V-O;G9E<G1&:6QE
M;&ES=#)?,"@F)'!A8VMA9V4I#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R
M87DH)V1I<B<@/3X-"B`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH)VYA;64G
M(#T^("<O)RDL#0H@("`@("`@("`@("`@("`@("`@("`@("`G9FEL92<@/3X@
M87)R87DH*0T*("`@("`@("`@("`@("`@("`@("`@("`@*0T*("`@("`@("`@
M("`@("`@("`@("`I.PT*("`@("`@("`D<&%C:V%G95LG<&QA=&9O<FTG72`]
M#0H@("`@("`@("1P86-K86=E6R=I;G-T86QL+6%S)UT@/2!A<G)A>2@I.PT*
M("`@("`@("`D=&AI<RT^7VES17AT96YS:6]N(#T@9F%L<V4[#0H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$9I;&5L:7-T*"D@
M87,@)&YA;64@/3X@)&9I;&4I('L-"B`@("`@("`@("`@("1F:6QE6R=N86UE
M)UT@/2`D;F%M93L-"B`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG<F]L
M92==*2`F)B`D9FEL95LG<F]L92==(#T]("=S<F,G*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I<T5X=&5N<VEO;B`]('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&9I;&5;)W)E<&QA8V5M96YT
M<R==*2D@>PT*("`@("`@("`@("`@("`@("1R97!L(#T@)&9I;&5;)W)E<&QA
M8V5M96YT<R==.PT*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE6R=R97!L
M86-E;65N=',G72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@('5N<V5T*"1R97!L*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D9FEL95LG:6YS=&%L;"UA<R==*2D@>PT*("`@("`@
M("`@("`@("`@("1P86-K86=E6R=I;G-T86QL+6%S)UU;)&YA;65=(#T@)&9I
M;&5;)VEN<W1A;&PM87,G73L-"B`@("`@("`@("`@("`@("!U;G-E="@D9FEL
M95LG:6YS=&%L;"UA<R==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D9FEL95LG<&QA=&9O<FTG72DI('L-"B`@("`@("`@("`@
M("`@("`D<&%C:V%G95LG<&QA=&9O<FTG75LD;F%M95T@/2`D9FEL95LG<&QA
M=&9O<FTG73L-"B`@("`@("`@("`@("`@("!U;G-E="@D9FEL95LG<&QA=&9O
M<FTG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9FEL92`](&%R
M<F%Y*"=A='1R:6)S)R`]/B`D9FEL92D[#0H@("`@("`@("`@("!I9B`H:7-S
M970H)')E<&PI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E<&P@
M87,@)')E<&QA8V4@*2![#0H@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T
M87-K<SIR97!L86-E)UU;72`](&%R<F%Y*"=A='1R:6)S)R`]/B`D<F5P;&%C
M92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D<F5P;"D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("`@("`D9FEL
M95LG=&%S:W,Z<F5P;&%C92==(#T@)&9I;&5;)W1A<VMS.G)E<&QA8V4G75LP
M73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D<F5T6R=D:7(G75LG9FEL92==6UT@/2`D9FEL93L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!0;W-T+7!R;V-E<W,@<W!E8VEA;"!F:6QE<R!W:71H(&EN<W1A;&PM
M87,O<&QA=&9O<FT@871T<FEB=71E<R!A;F0-"B`@("`@*B!M86ME('1H92!R
M96QE87-E('1A9RX-"B`@("`@*B`-"B`@("`@*B!4:&ES(&-O;7!L97@@;65T
M:&]D(&9O;&QO=W,@=&AI<R!W;W)K+69L;W<@=&\@8W)E871E('1H92!R96QE
M87-E('1A9W,Z#0H@("`@("H@#0H@("`@("H@/'!R93X-"B`@("`@*B`M(&EF
M(&%N>2!I;G-T86QL+6%S+W!L871F;W)M(&5X:7-T+"!C<F5A=&4@82!G96YE
M<FEC(')E;&5A<V4@86YD(&9I;&P@:70@=VET:`T*("`@("`J("`@;R`\:6YS
M=&%L;"!A<STN+CX@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@:6YS=&%L;"UA
M<STN+BX^#0H@("`@("H@("!O(#QI;G-T86QL(&%S/2XN/B!T86=S(&9O<B`\
M9FEL92!N86UE/2XN+B!P;&%T9F]R;3TA+BXN(&EN<W1A;&PM87,]+BX^#0H@
M("`@("H@("!O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L
M871F;W)M/2XN+CX-"B`@("`@*B`@(&\@/&EG;F]R93X@=&%G<R!F;W(@/&9I
M;&4@;F%M93TN+BX@<&QA=&9O<FT]+BXN(&EN<W1A;&PM87,]+BX^#0H@("`@
M("H@+2!C<F5A=&4@82!R96QE87-E(&9O<B!E86-H('!L871F;W)M(&5N8V]U
M;G1E<F5D(&%N9"!F:6QL('=I=&@-"B`@("`@*B`@(&\@/&EN<W1A;&P@87,N
M+CX@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@:6YS=&%L;"UA<STN+BX^#0H@
M("`@("H@("!O(#QI;G-T86QL(&%S+BX^('1A9W,@9F]R(#QF:6QE(&YA;64]
M+BXN('!L871F;W)M/71H:7,@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@
M("`@*B`@(&\@/&EN<W1A;&P@87,N+CX@=&%G<R!F;W(@/&9I;&4@;F%M93TN
M+BX@<&QA=&9O<FT](6]T:&5R('!L871F;W)M(&EN<W1A;&PM87,]+BX^#0H@
M("`@("H@("!O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L
M871F;W)M/2%T:&ES('!L871F;W)M/@T*("`@("`J("`@;R`\:6=N;W)E/B!T
M86=S(&9O<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3UO=&AE<B!P;&%T9F]R
M;3X-"B`@("`@*B`@(&\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@;F%M93TN
M+BX@<&QA=&9O<FT];W1H97(@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@
M("`@*B`@(&\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@<&QA
M=&9O<FT](71H:7,@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@*B`\
M+W!R93X-"B`@("`@*B`-"B`@("`@*B!)="!D;V5S('1H:7,@8GD@86-C97-S
M:6YG('1H92`D<&%C:V%G92!P87)A;65T97(L('=H:6-H(&-O;G1A:6YS(&%N
M(&%R<F%Y('=I=&@-"B`@("`@*B!I;F1I8V5S.@T*("`@("`J(`T*("`@("`J
M("`M('!L871F;W)M.B!M87!P:6YG(&]F(&9I;&4@/3X@3U,@=&AE(&9I;&4@
M<VAO=6QD(&)E(&EN<W1A;&QE9"!O;@T*("`@("`J("`M(&EN<W1A;&PM87,Z
M(&UA<'!I;F<@;V8@9FEL92`]/B!I;G-T86QL960@;F%M90T*("`@("`J("`M
M(&]S;6%P.B!M87!P:6YG(&]F($]3(#T^(&QI<W0@;V8@9FEL97,@=&AA="!S
M:&]U;&0@8F4@:6YS=&%L;&5D#0H@("`@("H@("`@;VX@=&AA="!/4PT*("`@
M("`J("`M(&YO=&]S;6%P.B!M87!P:6YG(&]F($]3(#T^(&QI<W0@;V8@9FEL
M97,@=&AA="!S:&]U;&0@;F]T(&)E#0H@("`@("H@("`@:6YS=&%L;&5D(&]N
M('1H870@3U,-"B`@("`@*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J
M($!P87)A;2!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]C;VYV97)T4F5L96%S93)?,"@F)')E;&5A<V4L
M("1P86-K86=E*0T*("`@('L-"B`@("`@("`@+R\M(&EF(&%N>2!I;G-T86QL
M+6%S+W!L871F;W)M(&5X:7-T+"!C<F5A=&4@82!G96YE<FEC(')E;&5A<V4@
M86YD(&9I;&P@:70@=VET:"`-"B`@("`@("`@:68@*&-O=6YT*"1P86-K86=E
M6R=P;&%T9F]R;2==*2!\?"!C;W5N="@D<&%C:V%G95LG:6YS=&%L;"UA<R==
M*2D@>PT*("`@("`@("`@("`@)&=E;F5R:6,@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@)&=E;F5R:6-)9VYO<F4@/2!A<G)A>2@I.PT*("`@("`@("`@("`@
M9F]R96%C:"`H)'!A8VMA9V5;)VEN<W1A;&PM87,G72!A<R`D9FEL92`]/B`D
M87,I('L-"B`@("`@("`@("`@("`@("`O+V\@/&EN<W1A;&P@87,]+BX^('1A
M9W,@9F]R(#QF:6QE(&YA;64]+BXN(&EN<W1A;&PM87,]+BXN/@T*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I
M;&5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9V5N97)I8UM=(#T@)&9I
M;&4[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`O+V\@/&EN<W1A;&P@87,]+BX^
M('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M/2$N+BX@:6YS=&%L
M;"UA<STN+CX-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;
M)W!L871F;W)M)UU;)&9I;&5=*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE77LP?2`]/2`G(2<I('L-"B`@
M("`@("`@("`@("`@("`@("`@)&=E;F5R:6-;72`]("1F:6QE.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@+R]O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA
M;64]+BXN('!L871F;W)M/2XN+B!I;G-T86QL+6%S/2XN/@T*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95TI
M("8F#0H@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M
M)UU;)&9I;&5=>S!]("$]("<A)RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M9V5N97)I8TEG;F]R95M=(#T@)&9I;&4[#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E6R=P;&%T9F]R;2==(&%S
M("1F:6QE(#T^("1P;&%T9F]R;2D@>PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<&%C:V%G95LG:6YS=&%L;"UA<R==6R1F:6QE72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("@D<&QA=&9O<FU[,'T@(3T@)R$G*2![#0H@
M("`@("`@("`@("`@("`@("`@("\O;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL
M92!N86UE/2XN+B!P;&%T9F]R;3TN+BX^#0H@("`@("`@("`@("`@("`@("`@
M("1G96YE<FEC26=N;W)E6UT@/2`D9FEL93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)'!A8VMA
M9V5;)W!L871F;W)M)UTI*2![#0H@("`@("`@("`@("`@("`@)&]S97,@/2`D
M;F]T<&QA=&9O<FT@/2`D<&QA=&9O<FT@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1P86-K86=E6R=P;&%T9F]R;2==(&%S("1F:6QE
M(#T^("1O<RD@>PT*("`@("`@("`@("`@("`@("`@("`O+R!G970@82!L:7-T
M(&]F(&]S97,-"B`@("`@("`@("`@("`@("`@("`@:68@*"1O<WLP?2`]/2`G
M(2<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W-E
M<UMS=6)S='(H)&]S+"`Q*5TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D;W-E<UMS=6)S='(H)&]S+"`Q*5T@
M/2!C;W5N="@D;W-E<RD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]S97-;)&]S
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1O<V5S6R1O<UT@/2!C;W5N="@D;W-E<RD[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@+R\M(&-R96%T92!A(')E;&5A<V4@9F]R(&5A8V@@<&QA=&9O<FT@96YC
M;W5N=&5R960@86YD(&9I;&P@=VET:`T*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1O<V5S(&%S("1O<R`]/B`D<F5L96%S94YU;2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU;5U;)VEN<W1A;&QC;VYD
M:71I;VYS)UU;)V]S)UU;)VYA;64G72`]("1O<SL-"B`@("`@("`@("`@("`@
M("`@("`@)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F:6QE;&ES="==(#T@87)R
M87DH)VEN<W1A;&PG(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G:6=N;W)E)R`]/B!A<G)A>2@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!A8VMA9V5;)VEN<W1A;&PM87,G72!A<R`D9FEL92`]
M/B`D87,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6YS=&%L
M;"!A<STN+CX@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@:6YS=&%L;"UA<STN
M+BX^#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P86-K
M86=E6R=P;&%T9F]R;2==6R1F:6QE72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;
M)VEN<W1A;&PG75M=(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G871T<FEB<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A<R<@/3X@)&%S+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6YS=&%L;"!A
M<RXN/B!T86=S(&9O<@T*("`@("`@("`@("`@("`@("`@("`@("`@+R\@(#QF
M:6QE(&YA;64]+BXN('!L871F;W)M/71H:7,@<&QA=&9O<FT@:6YS=&%L;"UA
M<STN+CX-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C
M:V%G95LG<&QA=&9O<FTG75LD9FEL95TI("8F#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95T@/3T@
M)&]S*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;
M)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I;G-T86QL)UU;72`]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N
M86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G87,G(#T^("1A<RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`O+V\@/&EN<W1A;&P@87,N+CX@=&%G<R!F;W(-"B`@("`@
M("`@("`@("`@("`@("`@("`@("\O("`\9FEL92!N86UE/2XN+B!P;&%T9F]R
M;3TA;W1H97(@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG<&QA=&9O<FTG75LD
M9FEL95TI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C
M:V%G95LG<&QA=&9O<FTG75LD9FEL95T@(3T@(B$D;W,B("8F#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG<&QA=&9O<FTG75LD
M9FEL95U[,'T@/3T@)R$G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I;G-T86QL
M)UU;72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I
M8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G87,G(#T^("1A<RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`O+V\@/&EG;F]R93X@=&%G<R!F;W(-
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O("`\9FEL92!N86UE/2XN+B!P
M;&%T9F]R;3TA=&AI<R!P;&%T9F]R;2!I;G-T86QL+6%S/2XN/@T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=P;&%T9F]R
M;2==6R1F:6QE72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE72`]/2`B(21O<R(I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU
M;5U;)V9I;&5L:7-T)UU;)VEG;F]R92==6UT@/0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&9I
M;&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@+R]O(#QI9VYO
M<F4^('1A9W,@9F]R#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R`@/&9I
M;&4@;F%M93TN+BX@<&QA=&9O<FT];W1H97(@<&QA=&9O<FT@:6YS=&%L;"UA
M<STN+CX-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C
M:V%G95LG<&QA=&9O<FTG75LD9FEL95TI("8F#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95U[,'T@
M(3T@)R$G("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C
M:V%G95LG<&QA=&9O<FTG75LD9FEL95T@(3T@)&]S*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F:6QE
M;&ES="==6R=I9VYO<F4G75M=(#T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<&%C:V%G95LG<&QA=&9O<FTG72!A<R`D9FEL92`]/B`D
M<&QA=&9O<FTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%C:V%G95LG:6YS=&%L;"UA<R==6R1F:6QE72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6=N
M;W)E/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3TA=&AI<R!P
M;&%T9F]R;3X-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<&QA=&9O
M<FT@/3T@(B$D;W,B*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I9VYO<F4G75M=
M(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("\O;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL92!N86UE/2XN
M+B!P;&%T9F]R;3UO=&AE<B!P;&%T9F]R;3X-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D<&QA=&9O<FU[,'T@(3T@)R$G("8F("1P;&%T9F]R;2`A
M/2`D;W,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S
M95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;)VEG;F]R92==6UT@/0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)')E;&5A
M<V5;)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I;G-T86QL)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D<F5L96%S95LD<F5L96%S
M94YU;5U;)V9I;&5L:7-T)UU;)VEN<W1A;&PG72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%C;W5N="@D<F5L
M96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;)VEG;F]R92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)')E;&5A<V5;)')E;&5A
M<V5.=6U=6R=F:6QE;&ES="==6R=I9VYO<F4G72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1G96YE<FEC*2!\?"!C;W5N="@D9V5N97)I8TEG;F]R92DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;8V]U;G0H)&]S97,I
M72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D
M9V5N97)I8RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1G96YE<FEC(&%S("1F:6QE*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=I;G-T86QL+6%S)UU;)&9I;&5=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%L
M;&%S(#T@)'!A8VMA9V5;)VEN<W1A;&PM87,G75LD9FEL95T[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN<W1A;&QA<R`]("1F:6QE.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5L96%S95MC;W5N="@D;W-E<RE=6R=F:6QE;&ES="==6R=I
M;G-T86QL)UU;72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G87,G(#T^("1I;G-T86QL
M87,L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&-O=6YT*"1G96YE<FEC26=N;W)E*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=E;F5R:6-)9VYO
M<F4@87,@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5L96%S95MC;W5N="@D;W-E<RE=6R=F:6QE;&ES="==6R=I9VYO<F4G75M=
M(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("\O(&-L96%N=7`-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5L
M96%S92!A<R`D:2`]/B`D<F5L*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<F5L6R=F:6QE;&ES="==6R=I;G-T86QL)UTI("8F#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O=6YT*"1R96Q;)V9I;&5L:7-T)UU;
M)VEN<W1A;&PG72D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E;&5A<V5;)&E=6R=F:6QE;&ES="==6R=I;G-T86QL)UT@/0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E6R1I75LG9FEL96QI<W0G
M75LG:6YS=&%L;"==6S!=.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5L6R=F:6QE;&ES="==6R=I
M9VYO<F4G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@8V]U;G0H
M)')E;%LG9FEL96QI<W0G75LG:6=N;W)E)UTI(#T](#$I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1R96QE87-E6R1I75LG9FEL96QI<W0G75LG:6=N
M;W)E)UT@/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E
M6R1I75LG9FEL96QI<W0G75LG:6=N;W)E)UU;,%T[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1R96QE87-E*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@
M("`@("1R96QE87-E(#T@)')E;&5A<V5;,%T[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O+R!N
M;R!P;&%T9F]R;2!A='1S+"!B=70@<V]M92!I;G-T86QL+6%S(&%T=',-"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G95LG:6YS=&%L;"UA<R==
M(&%S("1F:6QE(#T^("1V86QU92D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5L96%S95LG9FEL96QI<W0G75LG:6YS=&%L;"==6UT@/0T*("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A<R<@/3X@)'9A;'5E#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*0T*("`@("`@("`@("`@("`@("`@("`@("`@
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O
M=6YT*"1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI(#T](#$I('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEN
M<W1A;&PG72`]("1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UU;,%T[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@
M("H@0')E='5R;B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]P<F]C97-S1&5P*"1D97`I#0H@("`@>PT*
M("`@("`@("!I9B`H)&1E<%LG='EP92==(#T]("=P:'`G*2![#0H@("`@("`@
M("`@("!I9B`H)&1E<%LG<F5L)UT@/3T@)VAA<R<I('L-"B`@("`@("`@("`@
M("`@("`O+R!C;VUE(&]N("T@979E<GEO;F4@:&%S('!H<"$-"B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@)'!H<"`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@D9&5P
M6R=T>7!E)UT@(3T@)W!H<"<I('L-"B`@("`@("`@("`@("1P:'!;)VYA;64G
M72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@(&EF("@D9&5P6R=T>7!E
M)UT@/3T@)W!K9R<I('L-"B`@("`@("`@("`@("`@("`D<&AP6R=C:&%N;F5L
M)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!S=VET8V@@*"1D97!;)W)E;"==*2![#0H@("`@("`@("`@
M("!C87-E("=G="<@.@T*("`@("`@("`@("`@("`@("1P:'!;)VUI;B==(#T@
M)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@("1P:'!;)V5X8VQU
M9&4G72`]("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G9V4G(#H-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1D97!;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1D97!;)W1Y<&4G72`]/2`G<&AP)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VYA;64G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=V97)S:6]N)UT@/2`D9&5P
M6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'!H<%LG;6EN)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)VQT)R`Z#0H@("`@("`@
M("`@("`@("`@)'!H<%LG;6%X)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@
M("`@("`@("`@("`@)'!H<%LG97AC;'5D92==(#T@)&1E<%LG=F5R<VEO;B==
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=L92<@
M.@T*("`@("`@("`@("`@("`@("1P:'!;)VUA>"==(#T@)&1E<%LG=F5R<VEO
M;B==.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=E
M<2<@.@T*("`@("`@("`@("`@("`@("1P:'!;)VUI;B==(#T@)&1E<%LG=F5R
M<VEO;B==.PT*("`@("`@("`@("`@("`@("1P:'!;)VUA>"==(#T@)&1E<%LG
M=F5R<VEO;B==.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C
M87-E("=N92<@.@T*("`@("`@("`@("`@("`@("1P:'!;)V5X8VQU9&4G72`]
M("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G;F]T)R`Z#0H@("`@("`@("`@("`@("`@)'!H<%LG8V]N
M9FQI8W1S)UT@/2`G>65S)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D<&AP.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!R971U<FX@87)R87D-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?<')O8V5S<U!H<$1E<',H)&1E<',I#0H@
M("`@>PT*("`@("`@("`D=&5S="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A
M8V@@*"1D97!S(&%S("1D97`I('L-"B`@("`@("`@("`@("1T97-T6UT@/2`D
M=&AI<RT^7W!R;V-E<W-$97`H)&1E<"D[#0H@("`@("`@('T-"B`@("`@("`@
M)&UI;B`](&%R<F%Y*"D[#0H@("`@("`@("1M87@@/2!A<G)A>2@I.PT*("`@
M("`@("!F;W)E86-H("@D=&5S="!A<R`D9&5P*2![#0H@("`@("`@("`@("!I
M9B`H(21D97`I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI
M('L-"B`@("`@("`@("`@("`@("`D;6EN6R1D97!;)VUI;B==72`](&-O=6YT
M*"1M:6XI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("1M87A;)&1E<%LG
M;6%X)UU=(#T@8V]U;G0H)&UA>"D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&-O=6YT*"1M:6XI(#X@,"D@>PT*("`@("`@("`@
M("`@=6MS;W)T*"1M:6XL("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H8V]U;G0H)&UA>"D@/B`P*2![#0H@("`@("`@("`@
M("!U:W-O<G0H)&UA>"P@)W9E<G-I;VY?8V]M<&%R92<I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AC;W5N="@D;6EN*2D@>PT*("`@("`@("`@("`@+R\@
M9V5T('1H92!H:6=H97-T(&UI;FEM=6T-"B`@("`@("`@("`@("1M:6X@/2!A
M<G)A>5]P;W`H)&$@/2!A<G)A>5]F;&EP*"1M:6XI*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1M:6X@/2!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H8V]U;G0H)&UA>"DI('L-"B`@("`@("`@("`@("\O(&=E
M="!T:&4@;&]W97-T(&UA>&EM=6T-"B`@("`@("`@("`@("1M87@@/2!A<G)A
M>5]S:&EF="@D82`](&%R<F%Y7V9L:7`H)&UA>"DI.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&UA>"`](&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D;6EN*2![#0H@("`@("`@("`@("`D<&AP6R=M:6XG72`]
M("1M:6X[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M87@I('L-"B`@("`@
M("`@("`@("1P:'!;)VUA>"==(#T@)&UA>#L-"B`@("`@("`@?0T*("`@("`@
M("`D97AC;'5D92`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T97-T
M(&%S("1D97`I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG97AC
M;'5D92==*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)&5X8VQU9&5;72`]("1D97!;)V5X8VQU
M9&4G73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)&5X8VQU9&4I
M*2![#0H@("`@("`@("`@("`D<&AP6R=E>&-L=61E)UT@/2`D97AC;'5D93L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'!H<#L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!P<F]C97-S(&UU;'1I<&QE(&1E<&5N9&5N8VEE<R!T
M:&%T(&AA=F4@82!N86UE+"!L:6ME('!A8VMA9V4@9&5P<PT*("`@("`J($!P
M87)A;2!A<G)A>0T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<')O8V5S<TUU
M;'1I<&QE1&5P<TYA;64H)&1E<',I#0H@("`@>PT*("`@("`@("`D=&5S=',@
M/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D;F%M92`]
M/B`D9&5P*2![#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P(&%S("1D*2![
M#0H@("`@("`@("`@("`@("`@)'1E<W1S6R1N86UE75M=(#T@)'1H:7,M/E]P
M<F]C97-S1&5P*"1D*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("@D=&5S=',@87,@)&YA;64@/3X@)'1E<W0I('L-"B`@
M("`@("`@("`@("1P:'`@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)&UI;B`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("`D;6%X(#T@87)R87DH*3L-"B`@("`@
M("`@("`@("1P:'!;)VYA;64G72`]("1N86UE.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)'1E<W0@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!H<%LG8VAA
M;FYE;"==(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72D@
M)B8@)&1E<%LG8V]N9FQI8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'!H<%LG8V]N9FQI8W1S)UT@/2`G>65S)SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI
M;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;6EN6R1D97!;)VUI;B==
M72`](&-O=6YT*"1M:6XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1M87A;)&1E<%LG;6%X)UU=(#T@8V]U;G0H)&UA>"D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&-O=6YT*"1M:6XI(#X@,"D@>PT*("`@("`@("`@("`@("`@('5K<V]R
M="@D;6EN+"`G=F5R<VEO;E]C;VUP87)E)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H8V]U;G0H)&UA>"D@/B`P*2![#0H@("`@("`@("`@
M("`@("`@=6MS;W)T*"1M87@L("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D;6EN*2D@>PT*("`@
M("`@("`@("`@("`@("\O(&=E="!T:&4@:&EG:&5S="!M:6YI;75M#0H@("`@
M("`@("`@("`@("`@)&UI;B`](&%R<F%Y7W!O<"@D82`](&%R<F%Y7V9L:7`H
M)&UI;BDI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D;6EN(#T@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H8V]U;G0H)&UA>"DI('L-"B`@("`@("`@("`@("`@("`O+R!G970@=&AE
M(&QO=V5S="!M87AI;75M#0H@("`@("`@("`@("`@("`@)&UA>"`](&%R<F%Y
M7W-H:69T*"1A(#T@87)R87E?9FQI<"@D;6%X*2D[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1M87@@/2!F86QS93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@D;6EN*2![#0H@("`@("`@("`@
M("`@("`@)'!H<%LG;6EN)UT@/2`D;6EN.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"1M87@I('L-"B`@("`@("`@("`@("`@("`D<&AP6R=M
M87@G72`]("1M87@[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D97AC
M;'5D92`](&%R<F%Y*"D[#0H@("`@("`@("`@("!F;W)E86-H("@D=&5S="!A
M<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=E
M>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D97AC;'5D95M=
M(#T@)&1E<%LG97AC;'5D92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&-O=6YT*"1E>&-L=61E*2D@>PT*("`@("`@("`@("`@("`@("1P
M:'!;)V5X8VQU9&4G72`]("1E>&-L=61E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)')E=%M=(#T@)'!H<#L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"B`@("!]#0I]#0H_/@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL
M92]087)S97(O````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-3<`,#(Q-#8R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+U!A8VMA9V5&:6QE+U!A<G-E<B]V,BYP:'``````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-C<W,``Q,#4Q-30S,3`U-P`P,C(U,S$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\J*@T*
M("H@<&%C:V%G92YX;6P@<&%R<VEN9R!C;&%S<RP@<&%C:V%G92YX;6P@=F5R
M<VEO;B`R+C`-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@=C(N<&AP+'8@,2XQ.2`R,#`V+S`Q+S(S(#$W.C,Y.C4R(&-E;&QO9R!%
M>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J(&)A<V4@>&UL('!A<G-E
M<B!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O6$U,4&%R<V5R+G!H
M<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-
M"B\J*@T*("H@4&%R<V5R(&9O<B!P86-K86=E+GAM;"!V97)S:6]N(#(N,`T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@0%!%05(M
M5D520`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E1FEL
M95]087)S97)?=C(@97AT96YD<R!014%27UA-3%!A<G-E<@T*>PT*("`@('9A
M<B`D7V-O;F9I9SL-"B`@("!V87(@)%]L;V=G97([#0H@("`@=F%R("1?<F5G
M:7-T<GD[#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F)&,[#0H@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GD@/2`F)&,M/F=E=%)E9VES=')Y*"D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D;"D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?;&]G9V5R(#T@)B1L.PT*("`@('T-"B`@("`O*BH-"B`@("`@*B!5
M;FEN9&5N="!G:79E;B!S=')I;F<-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)'-T<B!4:&4@<W1R:6YG('1H870@:&%S('1O(&)E('5N:6YD96YT
M960N#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=6Y);F1E;G0H)'-T<BD-
M"B`@("![#0H@("`@("`@("\O(')E;6]V92!L96%D:6YG(&YE=VQI;F5S#0H@
M("`@("`@("1S='(@/2!P<F5G7W)E<&QA8V4H)R]>6UQR7&Y=*R\G+"`G)RP@
M)'-T<BD[#0H@("`@("`@("\O(&9I;F0@=VAI=&5S<&%C92!A="!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:7)S="!L:6YE#0H@("`@("`@("1I;F1E;G1?;&5N
M(#T@<W1R<W!N*"1S='(L("(@7'0B*3L-"B`@("`@("`@)&EN9&5N="`]('-U
M8G-T<B@D<W1R+"`P+"`D:6YD96YT7VQE;BD[#0H@("`@("`@("1D871A(#T@
M)R<[#0H@("`@("`@("\O(')E;6]V92!T:&4@<V%M92!A;6]U;G0@;V8@=VAI
M=&5S<&%C92!F<F]M(&9O;&QO=VEN9R!L:6YE<PT*("`@("`@("!F;W)E86-H
M("AE>'!L;V1E*")<;B(L("1S='(I(&%S("1L:6YE*2![#0H@("`@("`@("`@
M("!I9B`H<W5B<W1R*"1L:6YE+"`P+"`D:6YD96YT7VQE;BD@/3T@)&EN9&5N
M="D@>PT*("`@("`@("`@("`@("`@("1D871A("X]('-U8G-T<B@D;&EN92P@
M)&EN9&5N=%]L96XI("X@(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@<&]S="UP<F]C97-S(&1A=&$-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@)&1A=&$-"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;&5M96YT
M(&5L96UE;G0@;F%M90T*("`@("`J+PT*("`@(&9U;F-T:6]N('!O<W10<F]C
M97-S*"1D871A+"`D96QE;65N="D-"B`@("![#0H@("`@("`@(&EF("@D96QE
M;65N="`]/2`G;F]T97,G*2![#0H@("`@("`@("`@("!R971U<FX@=')I;2@D
M=&AI<RT^7W5N26YD96YT*"1D871A*2D[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N('1R:6TH)&1A=&$I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!P87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M
M92!O9B!T:&4@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A
M;'-E(&YA;64@;V8@=&AE(&%R8VAI=F4@=&AI<R!P86-K86=E+GAM;"!C86UE
M(&9R;VTL(&EF(&%N>0T*("`@("`J($!P87)A;2!S=')I;F<@8VQA<W,@;F%M
M92!T;R!I;G-T86YT:6%T92!A;F0@<F5T=7)N+B`@5&AI<R!M=7-T(&)E(%!%
M05)?4&%C:V%G949I;&5?=C(@;W(-"B`@("`@*B`@("`@("`@("`@("`@(&$@
M<W5B8VQA<W,-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5?=C(-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F<&%R<V4H)&1A=&$L("1F:6QE+"`D
M87)C:&EV92`](&9A;'-E+"`D8VQA<W,@/2`G4$5!4E]086-K86=E1FEL95]V
M,B<I#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@
M<&%R96YT.CIP87)S92@D9&%T82P@)&9I;&4I*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1E<G([#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&YE=R`D
M8VQA<W,[#0H@("`@("`@("1R970M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I
M9RD[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VQO9V=E<BDI('L-"B`@
M("`@("`@("`@("1R970M/G-E=$QO9V=E<B@D=&AI<RT^7VQO9V=E<BD[#0H@
M("`@("`@('T-"B`@("`@("`@)')E="T^9G)O;4%R<F%Y*"1T:&ES+3Y?=6YS
M97)I86QI>F5D1&%T82D[#0H@("`@("`@("1R970M/G-E=%!A8VMA9V5F:6QE
M*"1F:6QE+"`D87)C:&EV92D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"GT-"C\^```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]086-K86=E1FEL92]087)S97(O=C$N<&AP````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-#$U-S``,3`U,34T,S$P-3<`,#(R-3(U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP#0HO*BH-
M"B`J('!A8VMA9V4N>&UL('!A<G-I;F<@8VQA<W,L('!A8VMA9V4N>&UL('9E
M<G-I;VX@,2XP#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z('8Q+G!H<"QV(#$N,C$@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!P86-K86=E+GAM;"!A
M8G-T<F%C=&EO;B!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O4&%C
M:V%G949I;&4O=C$N<&AP)SL-"B\J*@T*("H@4&%R<V5R(&9O<B!P86-K86=E
M+GAM;"!V97)S:6]N(#$N,`T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@0%!%05(M5D520`T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA
M<W,@4$5!4E]086-K86=E1FEL95]087)S97)?=C$-"GL-"B`@("!V87(@)%]R
M96=I<W1R>3L-"B`@("!V87(@)%]C;VYF:6<[#0H@("`@=F%R("1?;&]G9V5R
M.PT*("`@("\J*@T*("`@("`J($)#(&AA8VL@=&\@86QL;W<@4$5!4E]#;VUM
M;VXZ.FEN9F]&<F]M4W1R:6YG*"D@=&\@<V]R="!O9@T*("`@("`J('=O<FL@
M=VET:"!T:&4@=F5R<VEO;B`R+C`@9F]R;6%T("T@=&AE<F4G<R!N;R!F:6QE
M;&ES="!T:&]U9V@-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V
M,@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&9R;VU6,B@D<&%C:V%G969I;&4I
M#0H@("`@>PT*("`@("`@("`D:6YF;R`]("1P86-K86=E9FEL92T^9V5T07)R
M87DH=')U92D[#0H@("`@("`@("1R970@/2!N97<@4$5!4E]086-K86=E1FEL
M95]V,3L-"B`@("`@("`@)')E="T^9G)O;4%R<F%Y*"1I;F9O6R=O;&0G72D[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG*"8D8RD-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)B1C.PT*("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y(#T@)B1C+3YG971296=I<W1R>2@I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N('-E=$QO9V=E<B@F)&PI#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7VQO9V=E<B`]("8D;#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&-O;G1E;G1S(&]F('!A8VMA9V4N>&UL(&9I;&4L
M('9E<G-I;VX@,2XP#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@
M<&%R<VEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('!A<G-E*"1D871A+"`D
M9FEL92P@)&%R8VAI=F4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A
M97AT96YS:6]N7VQO861E9"@G>&UL)RDI('L-"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=#86YN;W0@8W)E871E('AM;"!P87)S97(@
M9F]R('!A<G-I;F<@<&%C:V%G92YX;6PL(&YO('AM;"!E>'1E;G-I;VXG*3L-
M"B`@("`@("`@?0T*("`@("`@("`D>'`@/2!`>&UL7W!A<G-E<E]C<F5A=&4H
M*3L-"B`@("`@("`@:68@*"$D>'`I('L-"B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=#86YN;W0@8W)E871E('AM;"!P87)S97(@9F]R
M('!A<G-I;F<@<&%C:V%G92YX;6PG*3L-"B`@("`@("`@?0T*("`@("`@("!X
M;6Q?<V5T7V]B:F5C="@D>'`L("1T:&ES*3L-"B`@("`@("`@>&UL7W-E=%]E
M;&5M96YT7VAA;F1L97(H)'AP+"`G7V5L96UE;G1?<W1A<G1?,5\P)RP@)U]E
M;&5M96YT7V5N9%\Q7S`G*3L-"B`@("`@("`@>&UL7W-E=%]C:&%R86-T97)?
M9&%T85]H86YD;&5R*"1X<"P@)U]P:V=I;F9O7V-D871A7S%?,"<I.PT*("`@
M("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'AP+"!834Q?3U!424].7T-!
M4T5?1D],1$E.1RP@9F%L<V4I.PT*#0H@("`@("`@("1T:&ES+3YE;&5M96YT
M7W-T86-K(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;R`](&%R<F%Y*"=P<F]V:61E<R<@/3X@87)R87DH*2D[#0H@("`@("`@("1T
M:&ES+3YC=7)R96YT7V5L96UE;G0@/2!F86QS93L-"B`@("`@("`@=6YS970H
M)'1H:7,M/F1I<E]I;G-T86QL*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG9FEL96QI<W0G72`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3YF
M:6QE;&ES="`])B`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==.PT*
M("`@("`@("`D=&AI<RT^9&ER7VYA;65S(#T@87)R87DH*3L-"B`@("`@("`@
M)'1H:7,M/FEN7V-H86YG96QO9R`](&9A;'-E.PT*("`@("`@("`D=&AI<RT^
M9%]I(#T@,#L-"B`@("`@("`@)'1H:7,M/F-D871A(#T@)R<[#0H@("`@("`@
M("1T:&ES+3Y?:7-686QI9"`]('1R=64[#0H-"B`@("`@("`@:68@*"%X;6Q?
M<&%R<V4H)'AP+"`D9&%T82P@,2DI('L-"B`@("`@("`@("`@("1C;V1E(#T@
M>&UL7V=E=%]E<G)O<E]C;V1E*"1X<"D[#0H@("`@("`@("`@("`D;&EN92`]
M('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D>'`I.PT*("`@("`@("`@
M("`@>&UL7W!A<G-E<E]F<F5E*"1X<"D[#0H@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*")834P@97)R;W(Z("5S(&%T(&QI
M;F4@)60B+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`]('AM
M;%]E<G)O<E]S=')I;F<H)&-O9&4I+"`D;&EN92DL(#(I.PT*("`@("`@("!]
M#0H-"B`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1X<"D[#0H-"B`@("`@("`@
M)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C$[#0H@("`@("`@("1P9BT^
M<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?;&]G9V5R*2D@>PT*("`@("`@("`@("`@)'!F+3YS971,;V=G
M97(H)'1H:7,M/E]L;V=G97(I.PT*("`@("`@("!]#0H@("`@("`@("1P9BT^
M<V5T4&%C:V%G969I;&4H)&9I;&4L("1A<F-H:79E*3L-"B`@("`@("`@)'!F
M+3YF<F]M07)R87DH)'1H:7,M/E]P86-K86=E26YF;RD[#0H@("`@("`@(')E
M='5R;B`D<&8[#0H@("`@?0T*("`@("\O('M[>R!?=6Y);F1E;G0H*0T*#0H@
M("`@+RHJ#0H@("`@("H@56YI;F1E;G0@9VEV96X@<W1R:6YG#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@5&AE('-T<FEN9R!T:&%T(&AA
M<R!T;R!B92!U;FEN9&5N=&5D+@T*("`@("`J($!R971U<FX@<W1R:6YG#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7W5N26YD96YT*"1S='(I#0H@("`@>PT*("`@("`@("`O+R!R96UO=F4@;&5A
M9&EN9R!N97=L:6YE<PT*("`@("`@("`D<W1R(#T@<')E9U]R97!L86-E*"<O
M7EM<<EQN72LO)RP@)R<L("1S='(I.PT*("`@("`@("`O+R!F:6YD('=H:71E
M<W!A8V4@870@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FER<W0@;&EN90T*("`@
M("`@("`D:6YD96YT7VQE;B`]('-T<G-P;B@D<W1R+"`B(%QT(BD[#0H@("`@
M("`@("1I;F1E;G0@/2!S=6)S='(H)'-T<BP@,"P@)&EN9&5N=%]L96XI.PT*
M("`@("`@("`D9&%T82`]("<G.PT*("`@("`@("`O+R!R96UO=F4@=&AE('-A
M;64@86UO=6YT(&]F('=H:71E<W!A8V4@9G)O;2!F;VQL;W=I;F<@;&EN97,-
M"B`@("`@("`@9F]R96%C:"`H97AP;&]D92@B7&XB+"`D<W1R*2!A<R`D;&EN
M92D@>PT*("`@("`@("`@("`@:68@*'-U8G-T<B@D;&EN92P@,"P@)&EN9&5N
M=%]L96XI(#T]("1I;F1E;G0I('L-"B`@("`@("`@("`@("`@("`D9&%T82`N
M/2!S=6)S='(H)&QI;F4L("1I;F1E;G1?;&5N*2`N(")<;B([#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1D871A.PT*("`@
M('T-"@T*("`@("\O(%-U<'!O<G0@9F]R('!A8VMA9V4@1%1$('8Q+C`Z#0H@
M("`@+R\@>WM[(%]E;&5M96YT7W-T87)T7S%?,"@I#0H-"B`@("`O*BH-"B`@
M("`@*B!834P@<&%R<V5R(&-A;&QB86-K(&9O<B!E;F1I;F<@96QE;65N=',N
M("!5<V5D(&9O<B!V97)S:6]N(#$N,`T*("`@("`J('!A8VMA9V5S+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M(')E<V]U<F-E("`D>'`@("`@6$U,('!A<G-E
M<B!R97-O=7)C90T*("`@("`J($!P87)A;2!S=')I;F<@("`@)&YA;64@(&YA
M;64@;V8@96YD:6YG(&5L96UE;G0-"B`@("`@*@T*("`@("`J($!R971U<FX@
M=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V5L96UE;G1?<W1A<G1?,5\P*"1X<"P@)&YA;64L
M("1A='1R:6)S*0T*("`@('L-"B`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^
M96QE;65N=%]S=&%C:RP@)&YA;64I.PT*("`@("`@("`D=&AI<RT^8W5R<F5N
M=%]E;&5M96YT(#T@)&YA;64[#0H@("`@("`@("1S<&]S(#T@<VEZ96]F*"1T
M:&ES+3YE;&5M96YT7W-T86-K*2`M(#([#0H@("`@("`@("1T:&ES+3YP<F5V
M7V5L96UE;G0@/2`H)'-P;W,@/CT@,"D@/R`D=&AI<RT^96QE;65N=%]S=&%C
M:ULD<W!O<UT@.B`G)SL-"B`@("`@("`@)'1H:7,M/F-U<G)E;G1?871T<FEB
M=71E<R`]("1A='1R:6)S.PT*("`@("`@("`D=&AI<RT^8V1A=&$@/2`G)SL-
M"B`@("`@("`@<W=I=&-H("@D;F%M92D@>PT*("`@("`@("`@("`@8V%S92`G
M9&ER)SH-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO
M9RD@>PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H
M)VYA;64G+"`D871T<FEB<RD@)B8@)&%T=')I8G-;)VYA;64G72`A/2`G+R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@)&%T=')I8G-;)VYA;64G72`]('!R
M96=?<F5P;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A+RLA)RDL(&%R<F%Y*"<O
M)RP@)R\G*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)S6R=N
M86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R<G!O<R@D871T
M<FEB<ULG;F%M92==+"`G+R<I(#T]('-T<FQE;B@D871T<FEB<ULG;F%M92==
M*2`M(#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)S6R=N
M86UE)UT@/2!S=6)S='(H)&%T=')I8G-;)VYA;64G72P@,"P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=')L96XH)&%T=')I8G-;)VYA;64G72D@
M+2`Q*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1A='1R:6)S6R=N86UE)UTL("<O)RD@/3T](#`I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)S6R=N86UE)UT@
M/2!S=6)S='(H)&%T=')I8G-;)VYA;64G72P@,2D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1I<E]N86UE
M<UM=(#T@)&%T=')I8G-;)VYA;64G73L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R:6)S6R=B87-E:6YS=&%L
M;&1I<B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&ER7VEN
M<W1A;&P@/2`D871T<FEB<ULG8F%S96EN<W1A;&QD:7(G73L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R:6)S
M6R=R;VQE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD:7)?
M<F]L92`]("1A='1R:6)S6R=R;VQE)UT[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G9FEL
M92<Z#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I
M('L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<FEB<ULG;F%M
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%T:"`]("<G.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/F1I<E]N86UE<RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD
M:7)?;F%M97,@87,@)&1I<BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P871H("X]("1D:7(@+B`G+R<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@)'!A=&@@+CT@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@
M)R$O*R$G*2P@87)R87DH)R\G+"`G+R<I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%T=')I8G-;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1A='1R:6)S6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8W5R<F5N=%]P871H(#T@)'!A=&@[#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YF:6QE;&ES=%LD<&%T:%T@/2`D871T<FEB<SL-"B`@
M("`@("`@("`@("`@("`@("`@+R\@4V5T('1H92!B87-E:6YS=&%L;&1I<B!O
M;FQY(&EF('1H92!F:6QE(&1O;B=T(&AA=F4@=&AI<R!A='1R:6(-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^9FEL96QI<W1;)'!A
M=&A=6R=B87-E:6YS=&%L;&1I<B==*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("`@:7-S970H)'1H:7,M/F1I<E]I;G-T86QL*2D-"B`@("`@("`@("`@
M("`@("`@("`@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I
M;&5L:7-T6R1P871H75LG8F%S96EN<W1A;&QD:7(G72`]("1T:&ES+3YD:7)?
M:6YS=&%L;#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`O+R!3970@=&AE(%)O;&4-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=R;VQE)UTI("8F
M(&ES<V5T*"1T:&ES+3YD:7)?<F]L92DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YF:6QE;&ES=%LD<&%T:%U;)W)O;&4G72`]("1T:&ES
M+3YD:7)?<F]L93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@)W)E<&QA8V4G.@T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M
M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9FEL96QI<W1;)'1H:7,M/F-U<G)E;G1?<&%T:%U;)W)E<&QA8V5M96YT<R==
M6UT@/2`D871T<FEB<SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=M86EN=&%I;F5R<R<Z
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A
M:6YE<G,G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/FU?
M:2`](#`[("\O(&UA:6YT86EN97)S(&%R<F%Y(&EN9&5X#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=M86EN=&%I;F5R)SH-
M"B`@("`@("`@("`@("`@("`O+R!C;VUP871I8FEL:71Y(&-H96-K#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=M
M86EN=&%I;F5R<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==(#T@87)R87DH*3L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FU?:2`](#`[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA
M:6YT86EN97)S)UU;)'1H:7,M/FU?:5T@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YC=7)R96YT7VUA:6YT86EN97(@/28@)'1H:7,M/E]P
M86-K86=E26YF;ULG;6%I;G1A:6YE<G,G75LD=&AI<RT^;5]I73L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V-H86YG96QO
M9R<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8VAA
M;F=E;&]G)UT@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YC
M7VD@/2`P.R`O+R!C:&%N9V5L;V<@87)R87D@:6YD97@-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^:6Y?8VAA;F=E;&]G(#T@=')U93L-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W)E;&5A<V4G.@T*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO
M9R==6R1T:&ES+3YC7VE=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S92`]("8D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C:&%N9V5L;V<G75LD=&AI<RT^8U]I73L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N
M=%]R96QE87-E(#T@)B1T:&ES+3Y?<&%C:V%G94EN9F\[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M8V%S92`G9&5P<R<Z#0H@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^:6Y?
M8VAA;F=E;&]G*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)W)E;&5A<V5?9&5P<R==(#T@87)R87DH*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!C87-E("=D97`G.@T*("`@("`@("`@("`@("`@("\O(&1E<&5N9&5N8VEE
M<R!A<G)A>2!I;F1E>`T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN
M7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9%]I
M*RL[#0H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1A='1R:6)S6R=T>7!E
M)UTI(#\@*"1A='1R:6)S6R=T>7!E)UT@/2!S=')T;VQO=V5R*"1A='1R:6)S
M6R=T>7!E)UTI*2`Z(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E<',G75LD=&AI<RT^9%]I72`]
M("1A='1R:6)S.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W5R96]P=&EO;G,G
M.@T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG96QO9RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VYF:6=U<F5?;W!T:6]N<R==(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E
M("=C;VYF:6=U<F5O<'1I;VXG.@T*("`@("`@("`@("`@("`@(&EF("@A)'1H
M:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=C;VYF:6=U<F5?;W!T:6]N<R==6UT@/2`D871T
M<FEB<SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E("=P<F]V:61E<R<Z#0H@("`@("`@("`@
M("`@("`@:68@*&5M<'1Y*"1A='1R:6)S6R=T>7!E)UTI('Q\(&5M<'1Y*"1A
M='1R:6)S6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D871T<FEB
M<ULG97AP;&EC:70G72`]('1R=64[#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG<')O=FED97,G75LB)&%T=')I8G-;='EP95T[)&%T
M=')I8G-;;F%M95TB72`]("1A='1R:6)S.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G<&%C:V%G92<@.@T*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D871T<FEB<ULG=F5R<VEO;B==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=X<V1V97)S
M:6]N)UT@/2!T<FEM*"1A='1R:6)S6R=V97)S:6]N)UTI.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)WAS9'9E<G-I;VXG72`]("<Q+C`G.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')I8G-;
M)W!A8VMA9V5R=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=P86-K86=E<G9E<G-I;VXG72`]("1A='1R
M:6)S6R=P86-K86=E<G9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7V5L96UE;G1?96YD7S%?,"@I#0H-"B`@
M("`O*BH-"B`@("`@*B!834P@<&%R<V5R(&-A;&QB86-K(&9O<B!E;F1I;F<@
M96QE;65N=',N("!5<V5D(&9O<B!V97)S:6]N(#$N,`T*("`@("`J('!A8VMA
M9V5S+@T*("`@("`J#0H@("`@("H@0'!A<F%M(')E<V]U<F-E("`D>'`@("`@
M6$U,('!A<G-E<B!R97-O=7)C90T*("`@("`J($!P87)A;2!S=')I;F<@("`@
M)&YA;64@(&YA;64@;V8@96YD:6YG(&5L96UE;G0-"B`@("`@*@T*("`@("`J
M($!R971U<FX@=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V5L96UE;G1?96YD7S%?,"@D>'`L
M("1N86UE*0T*("`@('L-"B`@("`@("`@)&1A=&$@/2!T<FEM*"1T:&ES+3YC
M9&%T82D[#0H@("`@("`@('-W:71C:"`H)&YA;64I('L-"B`@("`@("`@("`@
M(&-A<V4@)VYA;64G.@T*("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M
M/G!R979?96QE;65N="D@>PT*("`@("`@("`@("`@("`@("`@("!C87-E("=P
M86-K86=E)SH-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)W!A8VMA9V4G72`]("1D871A.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VUA
M:6YT86EN97(G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U
M<G)E;G1?;6%I;G1A:6YE<ELG;F%M92==(#T@)&1A=&$[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=E>'1E;F1S
M)R`Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG97AT
M96YD<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E("=S=6UM87)Y)SH-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=S=6UM87)Y)UT@/2`D9&%T83L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V1E<V-R:7!T:6]N
M)SH-"B`@("`@("`@("`@("`@("`D9&%T82`]("1T:&ES+3Y?=6Y);F1E;G0H
M)'1H:7,M/F-D871A*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D97-C<FEP=&EO;B==(#T@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=U<V5R)SH-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^8W5R<F5N=%]M86EN=&%I;F5R6R=H86YD;&4G72`]
M("1D871A.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M8V%S92`G96UA:6PG.@T*("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT
M7VUA:6YT86EN97);)V5M86EL)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W)O;&4G.@T*("`@("`@("`@
M("`@("`@("1T:&ES+3YC=7)R96YT7VUA:6YT86EN97);)W)O;&4G72`]("1D
M871A.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G=F5R<VEO;B<Z#0H@("`@("`@("`@("`@("`@+R\D9&%T82`](&5R96=?
M<F5P;&%C92`H)UM>82UZ02U:,"TY+E]<+5TG+"`G7R<L("1D871A*3L-"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]R96QE87-E6R=V97)S
M:6]N)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N
M)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=D871E)SH-"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]R96QE87-E6R=R96QE87-E7V1A
M=&4G72`]("1D871A.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?
M9&%T92==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G;F]T97,G.@T*("`@
M("`@("`@("`@("`@("\O('1R>2!T;R`B9&4M:6YD96YT(B!R96QE87-E(&YO
M=&5S(&EN(&-A<V4@<V]M96]N90T*("`@("`@("`@("`@("`@("\O(&AA<R!B
M965N(&]V97(M:6YD96YT:6YG('1H96ER('AM;"`[+2D-"B`@("`@("`@("`@
M("`@("`D9&%T82`]("1T:&ES+3Y?=6Y);F1E;G0H)'1H:7,M/F-D871A*3L-
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]R96QE87-E6R=R
M96QE87-E7VYO=&5S)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=R96QE87-E7VYO=&5S)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=W
M87)N:6YG<R<Z#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N
M9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?
M<F5L96%S95LG<F5L96%S95]W87)N:6YG<R==(#T@)&1A=&$[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG<F5L96%S95]W87)N:6YG<R==(#T@)&1A=&$[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@8V%S92`G<W1A=&4G.@T*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YC=7)R96YT7W)E;&5A<V5;)W)E;&5A<V5?<W1A=&4G72`]("1D871A
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?<W1A=&4G72`]("1D
M871A.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@(&-A<V4@)VQI8V5N<V4G.@T*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YC=7)R96YT7W)E;&5A<V5;)W)E;&5A<V5?;&EC96YS
M92==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]L
M:6-E;G-E)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=D97`G.@T*("`@
M("`@("`@("`@("`@(&EF("@D9&%T82`F)B`A)'1H:7,M/FEN7V-H86YG96QO
M9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=R96QE87-E7V1E<',G75LD=&AI<RT^9%]I75LG;F%M92==(#T@)&1A=&$[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G9&ER)SH-"B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@87)R
M87E?<&]P*"1T:&ES+3YD:7)?;F%M97,I.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G9FEL92<Z#0H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("@D9&%T82D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%T:"`]
M("<G.PT*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/F1I
M<E]N86UE<RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YD:7)?;F%M97,@87,@)&1I<BD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P871H("X]("1D:7(@+B`G+R<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)'!A=&@@+CT@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YF:6QE;&ES=%LD<&%T:%T@/2`D=&AI<RT^8W5R<F5N
M=%]A='1R:6)U=&5S.PT*("`@("`@("`@("`@("`@("`@("`O+R!3970@=&AE
M(&)A<V5I;G-T86QL9&ER(&]N;'D@:68@=&AE(&9I;&4@9&]N)W0@:&%V92!T
M:&ES(&%T=')I8@T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3YF:6QE;&ES=%LD<&%T:%U;)V)A<V5I;G-T86QL9&ER)UTI("8F#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^9&ER7VEN<W1A
M;&PI*0T*("`@("`@("`@("`@("`@("`@("![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=B87-E:6YS=&%L;&1I
M<B==(#T@)'1H:7,M/F1I<E]I;G-T86QL.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("\O(%-E="!T:&4@4F]L90T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YF:6QE;&ES=%LD
M<&%T:%U;)W)O;&4G72D@)B8@:7-S970H)'1H:7,M/F1I<E]R;VQE*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I;&5L:7-T6R1P871H
M75LG<F]L92==(#T@)'1H:7,M/F1I<E]R;VQE.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE<B<Z#0H@("`@("`@
M("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT
M86EN97)S)UU;)'1H:7,M/FU?:5U;)W)O;&4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G75LD
M=&AI<RT^;5]I75LG<F]L92==(#T@)VQE860G.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^;5]I*RL[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=R96QE87-E)SH-"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8U]I*RL[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G8VAA;F=E;&]G)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^:6Y?8VAA
M;F=E;&]G(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@('T-"B`@("`@("`@87)R87E?<&]P*"1T:&ES+3YE;&5M96YT7W-T86-K
M*3L-"B`@("`@("`@)'-P;W,@/2!S:7IE;V8H)'1H:7,M/F5L96UE;G1?<W1A
M8VLI("T@,3L-"B`@("`@("`@)'1H:7,M/F-U<G)E;G1?96QE;65N="`]("@D
M<W!O<R`^(#`I(#\@)'1H:7,M/F5L96UE;G1?<W1A8VM;)'-P;W-=(#H@)R<[
M#0H@("`@("`@("1T:&ES+3YC9&%T82`]("<G.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!?<&MG:6YF;U]C9&%T85\Q7S`H*0T*#0H@("`@
M+RHJ#0H@("`@("H@6$U,('!A<G-E<B!C86QL8F%C:R!F;W(@8VAA<F%C=&5R
M(&1A=&$N("!5<V5D(&9O<B!V97)S:6]N(#$N,`T*("`@("`J('!A8VMA9V5S
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M(')E<V]U<F-E("`D>'`@("`@6$U,
M('!A<G-E<B!R97-O=7)C90T*("`@("`J($!P87)A;2!S=')I;F<@("`@)&YA
M;64@(&-H87)A8W1E<B!D871A#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O
M:60-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]P:V=I;F9O7V-D871A7S%?,"@D>'`L("1D871A*0T*
M("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC9&%T82DI('L-"B`@
M("`@("`@("`@("1T:&ES+3YC9&%T82`N/2`D9&%T83L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\O('U]?0T*?0T*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O=C(O````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#4W`#`R,#4U
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL
M92]V,B]R=RYP:'``````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-C<T,30`
M,3`U,34T,S$P-3<`,#(Q-S,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?4&%C:V%G949I
M;&5?=C(L('!A8VMA9V4N>&UL('9E<G-I;VX@,BXP+"!R96%D+W=R:71E('9E
M<G-I;VX-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M<G<N<&AP+'8@,2XQ-2`R,#`V+S`Q+S(X(#$W.C,U.C$Q(&-E;&QO9R!%>'`@
M)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C!A.`T*("HO#0HO*BH-"B`J($9O<B!B87-E(&-L87-S#0H@
M*B\-"G)E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V,BYP:'`G.PT*
M+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83@-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E1FEL
M95]V,E]R=R!E>'1E;F1S(%!%05)?4&%C:V%G949I;&5?=C(-"GL-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG($5X=&5N<VEO;B!N86UE#0H@("`@
M("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@;W!E<F%T:6]N#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<V5T4')O=FED97-%>'1E;G-I;VXH)&5X=&5N<VEO
M;BD-"B`@("![#0H@("`@("`@(&EF("AI;E]A<G)A>2@D=&AI<RT^9V5T4&%C
M:V%G951Y<&4H*2P@87)R87DH)V5X='-R8R<L("=E>'1B:6XG*2DI('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O
M=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`O+R!E;G-U
M<F4@=&AA="!T:&4@8VAA;FYE;"!T86<@:7,@<V5T('5P(&EN('1H92!R:6=H
M="!L;V-A=&EO;@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O
M+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=7-E<W)O;&4G+"`G=7-E
M<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP<F5L96%S92<L
M#0H@("`@("`@("`@("`@("`@("`@("=E>'1S<F-R96QE87-E)RP@)V5X=&)I
M;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@("`@("`@
M("`@("`@("`@("`D97AT96YS:6]N+"`G<')O=FED97-E>'1E;G-I;VXG*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)W!R;W9I9&5S97AT96YS:6]N)UT@/2`D97AT96YS:6]N.PT*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%!A8VMA9V4H)'!A
M8VMA9V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V%T=')I
M8G,G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2!A
M<G)A>5]M97)G92AA<G)A>2@G871T<FEB<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)S(N,"<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>&UL;G,G(#T^
M("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>&UL;G,Z=&%S:W,G(#T^
M("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C`G+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAM;&YS.GAS:2<@/3X@)VAT
M='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E)RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X<VDZ<V-H96UA3&]C
M871I;VXG(#T^("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C`-
M"B`@("!H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C`N>'-D#0H@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TR+C`-"B`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"YX<V0G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I*2P@)'1H:7,M/E]P86-K86=E
M26YF;RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E26YF;R`](&%R<F%Y7VUE<F=E*&%R<F%Y*"=N86UE
M)R`]/B`D<&%C:V%G92DL#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG;F%M92==(#T@)'!A8VMA9V4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@<V5T57)I*"1U<FDI#0H@("`@>PT*("`@("`@("!U;G-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=C:&%N;F5L)UTI.PT*("`@("`@("`D=&AI<RT^7VES
M5F%L:60@/2`P.PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W5R:2==*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@
M=&AE('5R:2!T86<@:7,@<V5T('5P(&EN('1H92!R:6=H="!L;V-A=&EO;@T*
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS
M97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L(`T*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=E>'1E;F1S)RP@)W-U;6UA<GDG+"`G9&5S8W)I<'1I;VXG
M+"`G;&5A9"<L#0H@("`@("`@("`@("`@("`@)V1E=F5L;W!E<B<L("=C;VYT
M<FEB=71O<B<L("=H96QP97(G+"`G9&%T92<L("=T:6UE)RP@)W9E<G-I;VXG
M+`T*("`@("`@("`@("`@("`@("=S=&%B:6QI='DG+"`G;&EC96YS92<L("=N
M;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@("`@
M("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S
M97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-
M"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E
M)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G
M+"`G8VAA;F=E;&]G)RDL("1U<FDL("=U<FDG*3L-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=U<FDG72`]("1U<FD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@<V5T0VAA;FYE;"@D8VAA;FYE;"D-"B`@("![
M#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5R:2==*3L-
M"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N;F5L)UTI*2![#0H@("`@
M("`@("`@("`O+R!E;G-U<F4@=&AA="!T:&4@8VAA;FYE;"!T86<@:7,@<V5T
M('5P(&EN('1H92!R:6=H="!L;V-A=&EO;@T*("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?
M<&%C:V%G94EN9F\L#0H@("`@("`@("`@("`@("`@87)R87DH)V5X=&5N9',G
M+"`G<W5M;6%R>2<L("=D97-C<FEP=&EO;B<L("=L96%D)RP-"B`@("`@("`@
M("`@("`@("`G9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<L
M("=D871E)RP@)W1I;64G+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@
M)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@
M)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G
M+"`G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG
M+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@("`@("=P
M:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@
M("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)&-H
M86YN96PL("=C:&%N;F5L)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG8VAA;FYE;"==(#T@)&-H86YN96P[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@<V5T17AT96YD<R@D97AT96YD<RD-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG97AT96YD<R==*2D@>PT*("`@("`@
M("`@("`@+R\@96YS=7)E('1H870@=&AE(&5X=&5N9',@=&%G(&ES('-E="!U
M<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A
M8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=S=6UM87)Y)RP@
M)V1E<V-R:7!T:6]N)RP@)VQE860G+`T*("`@("`@("`@("`@("`@("=D979E
M;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G:&5L<&5R)RP@)V1A=&4G+"`G=&EM
M92<L("=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`G<W1A8FEL:71Y)RP@
M)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L
M#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X
M=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L("=S<F-P86-K86=E
M)RP@)W-R8W5R:2<L#0H@("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G
M97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@("`@)V5X=&)I;G)E;&5A
M<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+"`D97AT96YD<RP@)V5X=&5N
M9',G*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=E>'1E;F1S)UT@/2`D97AT96YD<SL-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!S9713=6UM87)Y*"1S=6UM87)Y*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@("`O+R!E;G-U
M<F4@=&AA="!T:&4@<W5M;6%R>2!T86<@:7,@<V5T('5P(&EN('1H92!R:6=H
M="!L;V-A=&EO;@T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]
M("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L#0H@
M("`@("`@("`@("`@("`@87)R87DH)V1E<V-R:7!T:6]N)RP@)VQE860G+`T*
M("`@("`@("`@("`@("`@("=D979E;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G
M:&5L<&5R)RP@)V1A=&4G+"`G=&EM92<L("=V97)S:6]N)RP-"B`@("`@("`@
M("`@("`@("`G<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N
M=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N
M9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U
M<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@
M("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@
M("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO
M9R<I+"`D<W5M;6%R>2P@)W-U;6UA<GDG*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=S=6UM87)Y)UT@/2`D<W5M;6%R>3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971$97-C<FEP=&EO;B@D9&5S8RD-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG
M72DI('L-"B`@("`@("`@("`@("\O(&5N<W5R92!T:&%T('1H92!D97-C<FEP
M=&EO;B!T86<@:7,@<V5T('5P(&EN('1H92!R:6=H="!L;V-A=&EO;@T*("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T
M0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L#0H@("`@("`@("`@("`@("`@
M87)R87DH)VQE860G+`T*("`@("`@("`@("`@("`@("=D979E;&]P97(G+"`G
M8V]N=')I8G5T;W(G+"`G:&5L<&5R)RP@)V1A=&4G+"`G=&EM92<L("=V97)S
M:6]N)RP-"B`@("`@("`@("`@("`@("`G<W1A8FEL:71Y)RP@)VQI8V5N<V4G
M+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@
M("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L
M("=U<V5S<F]L92<L("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R
M:2<L#0H@("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L
M96%S92<L#0H@("`@("`@("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N
M9&QE)RP@)V-H86YG96QO9R<I+"`D9&5S8RP@)V1E<V-R:7!T:6]N)RD[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5S8W)I
M<'1I;VXG72`]("1D97-C.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($%D
M9',@82!N97<@;6%I;G1A:6YE<B`M(&YO(&-H96-K:6YG(&]F(&1U<&QI8V%T
M97,@:7,@<&5R9F]R;65D+"!U<V4-"B`@("`@*B!U<&1A=&5M86EN=&%I;F5R
M(&9O<B!T:&%T('!U<G!O<V4N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D
M36%I;G1A:6YE<B@D<F]L92P@)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C
M=&EV92`]("=Y97,G*0T*("`@('L-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D
M<F]L92P@87)R87DH)VQE860G+"`G9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R
M)RP@)VAE;'!E<B<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1R;VQE72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULD<F]L95U;,%TI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T@/2!A<G)A>2@D=&AI<RT^7W!A
M8VMA9V5);F9O6R1R;VQE72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE75M=(#T-"B`@("`@("`@("`@
M("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1N
M86UE+`T*("`@("`@("`@("`@("`@("`@("`G=7-E<B<@/3X@)&AA;F1L92P-
M"B`@("`@("`@("`@("`@("`@("`@)V5M86EL)R`]/B`D96UA:6PL#0H@("`@
M("`@("`@("`@("`@("`@("=A8W1I=F4G(#T^("1A8W1I=F4L#0H@("`@("`@
M("`@("`@("`@*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T
M97-T87)R(#T@87)R87DH)VQE860G+`T*("`@("`@("`@("`@("`@("`@("`G
M9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<L("=D871E)RP@
M)W1I;64G+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("=S=&%B
M:6QI='DG+"`G;&EC96YS92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP
M871I8FQE)RP-"B`@("`@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L
M("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L
M#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L
M("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@
M("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G
M)RD[#0H@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G;&5A9"<L("=D979E
M;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G:&5L<&5R)RD@87,@)'1E<W1R;VQE
M*2![#0H@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)'1E<W1A<G(I.PT*
M("`@("`@("`@("`@("`@(&EF("@D<F]L92`]/2`D=&5S=')O;&4I('L-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R1R;VQE72DI('L-"B`@("`@("`@("`@("`@("`O+R!E
M;G-U<F4@=&AA="!T:&4@97AT96YD<R!T86<@:7,@<V5T('5P(&EN('1H92!R
M:6=H="!L;V-A=&EO;@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5)
M;F9O+"`D=&5S=&%R<BP-"B`@("`@("`@("`@("`@("`@("`@87)R87DH*2P@
M)')O;&4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULD<F]L95T@/0T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@
M("`@("`@("`@("`@("=U<V5R)R`]/B`D:&%N9&QE+`T*("`@("`@("`@("`@
M("`@("`@("`G96UA:6PG(#T^("1E;6%I;"P-"B`@("`@("`@("`@("`@("`@
M("`@)V%C=&EV92<@/3X@)&%C=&EV92P-"B`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@=7!D871E36%I;G1A:6YE<B@D;F5W<F]L92P@
M)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C=&EV92`]("=Y97,G*0T*("`@
M('L-"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@
M*&%R<F%Y*"=L96%D)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H
M96QP97(G*2!A<R`D<F]L92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72DI('L-"B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1I;F9O
M(#T@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T[#0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1I;F9O6S!=*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M:6YF;ULG=7-E<B==(#T]("1H86YD;&4I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@9F]R96%C:"`H)&EN9F\@87,@)&D@/3X@)&UA:6YT86EN97(I('L-"B`@
M("`@("`@("`@("`@("!I9B`H)&UA:6YT86EN97);)W5S97(G72`]/2`D:&%N
M9&QE*2![#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]("1I.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:R`R.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9O=6YD
M(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YA9&1-
M86EN=&%I;F5R*"1N97=R;VQE+"`D:&%N9&QE+"`D;F%M92P@)&5M86EL+"`D
M86-T:79E*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9O=6YD("$]/2!F
M86QS92D@>PT*("`@("`@("`@("`@:68@*"1F;W5N9"`]/3T@=')U92D@>PT*
M("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O
M;&5=*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95U;)&9O=6YD72D[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T@/2!A
M<G)A>5]V86QU97,H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95TI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YA9&1-86EN
M=&%I;F5R*"1N97=R;VQE+"`D:&%N9&QE+"`D;F%M92P@)&5M86EL+"`D86-T
M:79E*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!D96QE=&5-86EN=&%I;F5R*"1H86YD;&4I#0H@("`@
M>PT*("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H
M87)R87DH)VQE860G+"`G9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE
M;'!E<B<I(&%S("1R;VQE*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=*2D@>PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE75LP72DI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72`](&%R<F%Y
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O
M;&5=(&%S("1I(#T^("1M86EN=&%I;F5R*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1M86EN=&%I;F5R6R=U<V5R)UT@/3T@)&AA;F1L92D@>PT*("`@("`@
M("`@("`@("`@("`@("`D9F]U;F0@/2`D:3L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1F;W5N9"`A/3T@9F%L<V4I('L-"B`@("`@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE75LD9F]U
M;F1=*3L-"B`@("`@("`@("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)')O;&5=*2`F)B`D<F]L92`]/2`G;&5A9"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R1R;VQE72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95TI.PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T@/0T*
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]V86QU97,H)'1H:7,M/E]P86-K
M86=E26YF;ULD<F]L95TI.PT*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72D@/3T@,2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72`]("1T:&ES
M+3Y?<&%C:V%G94EN9F];)')O;&5=6S!=.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W!A8VMA9V5);F9O6R1R
M;VQE72D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)')O;&5=(#T@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95U;,%T[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%)E;&5A<V5697)S:6]N
M*"1V97)S:6]N*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)W9E<G-I;VXG72D@)B8-"B`@("`@("`@("`@("`@:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==6R=R96QE87-E)UTI
M*2![#0H@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=V
M97)S:6]N)UU;)W)E;&5A<V4G72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P
M86-K86=E26YF;RP@)'9E<G-I;VXL(&%R<F%Y*`T*("`@("`@("`@("`@)W9E
M<G-I;VXG(#T^(&%R<F%Y*"=S=&%B:6QI='DG+"`G;&EC96YS92<L("=N;W1E
M<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@
M("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R
M;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@
M("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-
M"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G
M8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`G<F5L96%S92<@/3X@87)R87DH
M)V%P:2<I*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@<V5T05!)5F5R<VEO;B@D=F5R<VEO;BD-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=V
M97)S:6]N)UTI("8F#0H@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W9E<G-I;VXG75LG87!I)UTI*2![#0H@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;)V%P:2==*3L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H
M:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D=F5R<VEO;BP@
M87)R87DH#0H@("`@("`@("`@("`G=F5R<VEO;B<@/3X@87)R87DH)W-T86)I
M;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A
M=&EB;&4G+`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O
M=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+"`G<W)C
M<&%C:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@("`@("=P:'!R96QE
M87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B
M:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@
M("`@("=A<&DG(#T^(&%R<F%Y*"DI*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@,#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!S;F%P<VAO='QD
M979E;'QA;'!H87QB971A?'-T86)L90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('-E=%)E;&5A<V53=&%B:6QI='DH)'-T871E*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==*2`F
M)@T*("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S
M=&%B:6QI='DG75LG<F5L96%S92==*2D@>PT*("`@("`@("`@("`@=6YS970H
M)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)W)E;&5A<V4G72D[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T
M:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)'-T871E+"!A
M<G)A>2@-"B`@("`@("`@("`@("=S=&%B:6QI='DG(#T^(&%R<F%Y*"=L:6-E
M;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@
M("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I
M;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S
M<F-U<FDG+`T*("`@("`@("`@("`@("`@("=P:'!R96QE87-E)RP@)V5X='-R
M8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@
M)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("=R96QE87-E
M)R`]/B!A<G)A>2@G87!I)RDI*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@,#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@9&5V96Q\
M86QP:&%\8F5T87QS=&%B;&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971!
M4$E3=&%B:6QI='DH)'-T871E*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==*2`F)@T*("`@("`@
M("`@("`@("!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG
M75LG87!I)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=S=&%B:6QI='DG75LG87!I)UTI.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T
M:&ES+3Y?<&%C:V%G94EN9F\L("1S=&%T92P@87)R87DH#0H@("`@("`@("`@
M("`G<W1A8FEL:71Y)R`]/B!A<G)A>2@G;&EC96YS92<L("=N;W1E<R<L("=C
M;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`G9&5P
M96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@
M)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@
M("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@
M("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E
M;&]G)RDL#0H@("`@("`@("`@("`G87!I)R`]/B!A<G)A>2@I*2D[#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@<V5T3&EC96YS92@D;&EC96YS92P@)'5R:2`](&9A;'-E+"`D9FEL97-O
M=7)C92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=L:6-E;G-E)UTI*2![#0H@("`@("`@("`@("`O
M+R!E;G-U<F4@=&AA="!T:&4@;&EC96YS92!T86<@:7,@<V5T('5P(&EN('1H
M92!R:6=H="!L;V-A=&EO;@T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN
M9F\L#0H@("`@("`@("`@("`@("`@87)R87DH)VYO=&5S)RP@)V-O;G1E;G1S
M)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I
M97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A
M<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@("`@
M("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@
M("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@
M,"P@)VQI8V5N<V4G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'5R:2!\
M?"`D9FEL97-O=7)C92D@>PT*("`@("`@("`@("`@)&%T=')I8G,@/2!A<G)A
M>2@I.PT*("`@("`@("`@("`@:68@*"1U<FDI('L-"B`@("`@("`@("`@("`@
M("`D871T<FEB<ULG=7)I)UT@/2`D=7)I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'5R:2`]('1R=64[("\O(&9O<B!T97-T(&)E;&]W#0H@("`@
M("`@("`@("!I9B`H)&9I;&5S;W5R8V4I('L-"B`@("`@("`@("`@("`@("`D
M871T<FEB<ULG9FEL97-O=7)C92==(#T@)&9I;&5S;W5R8V4[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&QI8V5N<V4@/2`D=7)I(#\@
M87)R87DH)V%T=')I8G,G(#T^("1A='1R:6)S+"`G7V-O;G1E;G0G(#T^("1L
M:6-E;G-E*2`Z("1L:6-E;G-E.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=L:6-E;G-E)UT@/2`D;&EC96YS93L-"B`@("`@("`@)'1H:7,M/E]I
M<U9A;&ED(#T@,#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971.;W1E<R@D
M;F]T97,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VYO=&5S
M)UTI*2![#0H@("`@("`@("`@("`O+R!E;G-U<F4@=&AA="!T:&4@;F]T97,@
M=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R
M92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y
M*"=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`G
M9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE
M)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@
M("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@
M("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA
M;F=E;&]G)RDL("1N;W1E<RP@)VYO=&5S)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG;F]T97,G72`]("1N;W1E<SL-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES(&]N;'D@=7-E9"!A="!I
M;G-T86QL+71I;64L(&%F=&5R(&%L;"!S97)I86QI>F%T:6]N#0H@("`@("H@
M:7,@;W9E<BX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M90T*("`@
M("`J($!P87)A;2!S=')I;F<@:6YS=&%L;&5D('!A=&@-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!S971);G-T86QL961!<R@D9FEL92P@)'!A=&@I#0H@("`@
M>PT*("`@("`@("!I9B`H)'!A=&@I('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L
M;&5D7V%S)UT@/2`D<&%T:#L-"B`@("`@("`@?0T*("`@("`@("!U;G-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L
M;&5D7V%S)UTI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@:7,@
M;VYL>2!U<V5D(&%T(&EN<W1A;&PM=&EM92P@869T97(@86QL('-E<FEA;&EZ
M871I;VX-"B`@("`@*B!I<R!O=F5R+@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&EN<W1A;&QE9$9I;&4H)&9I;&4L("1A='1S*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I
M;&5=*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL
M96QI<W0G75LD9FEL95T@/0T*("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=+"`D871T
M<ULG871T<FEB<R==*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=(#T@)&%T
M='-;)V%T=')I8G,G73L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%)E<V5T('1H92!L:7-T:6YG(&]F('!A8VMA9V4@8V]N=&5N=',-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&)A<V4@:6YS=&%L;&%T:6]N(&1I<B!F
M;W(@=&AE('=H;VQE('!A8VMA9V4L(&EF(&%N>0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&-L96%R0V]N=&5N=',H)&)A<V5I;G-T86QL(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7V9I;&5S5F%L:60@/2!F86QS93L-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F
M;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L#0H@("`@("`@("`@("`@("`@87)R
M87DH)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("`@("`G9&5P96YD
M96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S
M97-T87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G
M<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@
M("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C
M:&%N9V5L;V<G*2P@87)R87DH*2P@)V-O;G1E;G1S)RD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1T:&ES+3YG971086-K86=E5'EP92@I("$]("=B=6YD
M;&4G*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT
M96YT<R==(#T@#0H@("`@("`@("`@("`@("`@87)R87DH)V1I<B<@/3X@87)R
M87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G+R<I*2D[#0H@("`@
M("`@("`@("!I9B`H)&)A<V5I;G-T86QL*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V%T=')I
M8G,G75LG8F%S96EN<W1A;&QD:7(G72`]("1B87-E:6YS=&%L;#L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!P87)A;2!S=')I;F<@<F5L871I=F4@<&%T:"!O9B!T:&4@8G5N9&QE9"!P
M86-K86=E+@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$)U;F1L961086-K
M86=E*"1P871H*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K
M86=E5'EP92@I("$]("=B=6YD;&4G*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]F:6QE<U9A;&ED
M(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T
M:&ES+3Y?<&%C:V%G94EN9F\L("1P871H+"!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G8V]N=&5N=',G(#T^(&%R<F%Y*"=C;VUP871I8FQE)RP@)V1E<&5N
M9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L#0H@("`@("`@("`@("`@
M("`@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C
M=7)I)RP@)W!H<')E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1S<F-R
M96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO
M9R<I+`T*("`@("`@("`@("`@("`@("=B=6YD;&5D<&%C:V%G92<@/3X@87)R
M87DH*2DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I
M;F<@9FEL92!N86UE#0H@("`@("H@0'!A<F%M(%!%05)?5&%S:U]#;VUM;VX@
M82!R96%D+W=R:71E('1A<VL-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&14
M87-K5&]&:6QE*"1F:6QE;F%M92P@)'1A<VLI#0H@("`@>PT*("`@("`@("!I
M9B`H(6UE=&AO9%]E>&ES=',H)'1A<VLL("=G9718;6PG*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M;65T:&]D7V5X:7-T<R@D=&%S:RP@)V=E=$YA;64G*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A;65T
M:&]D7V5X:7-T<R@D=&%S:RP@)W9A;&ED871E)RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T87-K
M+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YG
M971487-K<TYS*"D[("\O(&1I<V-O=F5R('1H92!T87-K<R!N86UE<W!A8V4@
M:68@;F]T(&1O;F4@86QR96%D>0T*("`@("`@("`D9FEL97,@/2`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==.PT*("`@
M("`@("!I9B`H(6ES<V5T*"1F:6QE<ULP72DI('L-"B`@("`@("`@("`@("1F
M:6QE<R`](&%R<F%Y*"1F:6QE<RD[#0H@("`@("`@("`@("`D:6YD(#T@9F%L
M<V4[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D:6YD(#T@=')U
M93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&D@
M/3X@)&9I;&4I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG871T
M<FEB<R==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D9FEL95LG871T<FEB
M<R==6R=N86UE)UT@/3T@)&9I;&5N86UE*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D:6YD*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D="`]
M(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==
M6R=F:6QE)UU;)&E=#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;
M)V%T=')I8G,G75LD=&AI<RT^7W1A<VMS3G,@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)SHG("X@)'1A<VLM/F=E=$YA;64H*5TI(#\-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)&E=#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!;)V%T=')I8G,G75LD=&AI<RT^7W1A<VMS
M3G,@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SHG("X@)'1A
M<VLM/F=E=$YA;64H*5T@.B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D="`F)B`A:7-S970H)'1;,%TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G
M75LG9&ER)UU;)V9I;&4G75LD:5T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@6R1T:&ES+3Y?=&%S:W-.<R`N("<Z)R`N("1T87-K+3YG971.
M86UE*"E=(#T@87)R87DH)'0I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LD:5U;)'1H:7,M/E]T87-K
M<TYS("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.B<@+B`D=&%S
M:RT^9V5T3F%M92@I75M=(#T@)'1A<VLM/F=E=%AM;"@I.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'0@/2!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D
M:7(G75LG9FEL92==#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;
M)V%T=')I8G,G75LD=&AI<RT^7W1A<VMS3G,@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)SHG("X@)'1A<VLM/F=E=$YA;64H*5TI(#\@)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G70T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A='1R:6)S)UU;)'1H
M:7,M/E]T87-K<TYS("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<Z)R`N("1T87-K+3YG971.86UE*"E=(#H@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)'0@)B8@(6ES<V5T*"1T6S!=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6R1T:&ES+3Y?=&%S:W-.<R`N("<Z)R`N("1T87-K
M+3YG971.86UE*"E=(#T@87)R87DH)'0I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LD=&AI<RT^7W1A
M<VMS3G,@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Z)R`N("1T
M87-K+3YG971.86UE*"E=6UT@/2`D=&%S:RT^9V5T6&UL*"D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@<W1R:6YG('!A=&@@=&\@=&AE(&9I;&4-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&9I;&5N86UE#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(&5X=')A(&%T=')I8G5T97,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1&
M:6QE*"1D:7(L("1F:6QE+"`D871T<G,I#0H@("`@>PT*("`@("`@("!I9B`H
M)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V)U;F1L92<I('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7V9I;&5S5F%L:60@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@,#L-"B`@("`@("`@)&1I<B`]('!R96=?<F5P;&%C92AA<G)A>2@G
M(5Q<7%PK(2<L("<A+RLA)RDL(&%R<F%Y*"<O)RP@)R\G*2P@)&1I<BD[#0H@
M("`@("`@(&EF("@D9&ER(#T]("<O)R!\?"`D9&ER(#T]("<G*2![#0H@("`@
M("`@("`@("`D9&ER(#T@)R<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D9&ER("X]("<O)SL-"B`@("`@("`@?0T*("`@("`@("`D871T<G-;
M)VYA;64G72`]("1D:7(@+B`D9FEL93L-"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==*2D@>PT*("`@("`@("`@
M("`@+R\@96YS=7)E('1H870@=&AE(&-O;G1E;G1S('1A9R!I<R!S970@=7`-
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN
M<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=C;VUP871I8FQE)RP@)V1E<&5N9&5N8VEE<R<L("=P<F]V
M:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@
M("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A
M<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@("`@)V5X=&)I
M;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+"!A<G)A>2@I+"`G
M8V]N=&5N=',G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72DI
M('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LP72DI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G
M75LG9FEL92==(#T-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6UU;)V%T=')I8G,G72`]("1A
M='1R<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)V%T=')I
M8G,G72`]("1A='1R<SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!S=')I;F<@1&5P96YD96YT('!A8VMA9V4@;F%M90T*
M("`@("`J($!P87)A;2!S=')I;F<@1&5P96YD96YT('!A8VMA9V4G<R!C:&%N
M;F5L(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI;FEM=6T@=F5R<VEO
M;B!O9B!S<&5C:69I960@<&%C:V%G92!T:&%T('1H:7,@<F5L96%S92!I<R!G
M=6%R86YT965D('1O(&)E#0H@("`@("H@("`@("`@("`@("`@("!C;VUP871I
M8FQE('=I=&@-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R<VEO
M;B!O9B!S<&5C:69I960@<&%C:V%G92!T:&%T('1H:7,@<F5L96%S92!I<R!G
M=6%R86YT965D('1O(&)E#0H@("`@("H@("`@("`@("`@("`@("!C;VUP871I
M8FQE('=I=&@-"B`@("`@*B!`<&%R86T@<W1R:6YG('9E<G-I;VYS(&]F('-P
M96-I9FEE9"!P86-K86=E('1H870@=&AI<R!R96QE87-E(&ES(&YO="!C;VUP
M871I8FQE('=I=&@-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1#;VUP871I
M8FQE4&%C:V%G92@D;F%M92P@)&-H86YN96PL("1M:6XL("1M87@L("1E>&-L
M=61E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@
M/2`P.PT*("`@("`@("`D<V5T(#T@87)R87DH#0H@("`@("`@("`@("`G;F%M
M92<@/3X@)&YA;64L#0H@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)&-H86YN
M96PL#0H@("`@("`@("`@("`G;6EN)R`]/B`D;6EN+`T*("`@("`@("`@("`@
M)VUA>"<@/3X@)&UA>"P-"B`@("`@("`@*3L-"B`@("`@("`@:68@*"1E>&-L
M=61E*2![#0H@("`@("`@("`@("`D<V5T6R=E>&-L=61E)UT@/2`D97AC;'5D
M93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A
M9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D<V5T+"!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`G8V]M<&%T:6)L92<@/3X@87)R87DH)V1E<&5N9&5N8VEE<R<L
M("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L
M#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L
M("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S
M92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G
M)RD-"B`@("`@("`@("`@("DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%)E;6]V97,@=&AE(#QU<V5S<F]L93X@=&%G(&5N=&ER96QY#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<F5S9715<V5S<F]L92@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W)O;&4G72DI
M('L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5S
M97-R;VQE)UTI.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G
M92!N86UE(&]R('5R:0T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N
M86UE(&EF(&YO;BUU<FD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&15<V5S
M<F]L92@D<F]L92P@)'!A8VMA9V5/<E5R:2P@)&-H86YN96P@/2!F86QS92D@
M>PT*("`@("`@("`D<V5T(#T@87)R87DH)W)O;&4G(#T^("1R;VQE*3L-"B`@
M("`@("`@:68@*"1C:&%N;F5L*2![#0H@("`@("`@("`@("`D<V5T6R=P86-K
M86=E)UT@/2`D<&%C:V%G94]R57)I.PT*("`@("`@("`@("`@)'-E=%LG8VAA
M;FYE;"==(#T@)&-H86YN96P[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D<V5T6R=U<FDG72`]("1P86-K86=E3W)5<FD[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K
M86=E26YF;RP@)'-E="P@87)R87DH#0H@("`@("`@("`@("`@("`@)W5S97-R
M;VQE)R`]/B!A<G)A>2@G=7-E<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U
M<FDG+`T*("`@("`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S
M<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG
M96QO9R<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!296UO=F5S('1H92`\=7-E<W1A<VL^('1A9R!E;G1I<F5L>0T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(')E<V5T57-E<W1A<VLH*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K
M)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=U<V5S=&%S:R==*3L-"B`@("`@("`@?0T*("`@('T-"@T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!S=')I;F<@
M<&%C:V%G92!N86UE(&]R('5R:0T*("`@("`J($!P87)A;2!S=')I;F<@8VAA
M;FYE;"!N86UE(&EF(&YO;BUU<FD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A
M9&15<V5S=&%S:R@D=&%S:RP@)'!A8VMA9V5/<E5R:2P@)&-H86YN96P@/2!F
M86QS92D@>PT*("`@("`@("`D<V5T(#T@87)R87DH)W1A<VLG(#T^("1T87-K
M*3L-"B`@("`@("`@:68@*"1C:&%N;F5L*2![#0H@("`@("`@("`@("`D<V5T
M6R=P86-K86=E)UT@/2`D<&%C:V%G94]R57)I.PT*("`@("`@("`@("`@)'-E
M=%LG8VAA;FYE;"==(#T@)&-H86YN96P[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D<V5T6R=U<FDG72`]("1P86-K86=E3W)5<FD[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M
M/E]P86-K86=E26YF;RP@)'-E="P@87)R87DH#0H@("`@("`@("`@("`@("`@
M)W5S97-T87-K)R`]/B!A<G)A>2@G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*
M("`@("`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE
M87-E)RP@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I
M#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2
M96UO=F4@86QL(&-O;7!A=&EB;&4@=&%G<PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&-L96%R0V]M<&%T:6)L92@I#0H@("`@>PT*("`@("`@("!U;G-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP871I8FQE)UTI.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%)E<V5T(&1E<&5N9&5N8VEE<R!P<FEO<B!T;R!A
M9&1I;F<@;F5W(&]N97,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;&5A<D1E
M<',H*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D97!E;F1E;F-I97,G72DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C
M:V%G94EN9F\L(&%R<F%Y*"DL#0H@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P
M<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG
M+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A
M<V4G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C:&%N
M9V5L;V<G*2DI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E<&5N9&5N8VEE<R==(#T@87)R87DH*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI;FEM=6T@4$A0('9E<G-I
M;VX@86QL;W=E9`T*("`@("`J($!P87)A;2!S=')I;F<@;6%X:6UU;2!02%`@
M=F5R<VEO;B!A;&QO=V5D#0H@("`@("H@0'!A<F%M(&%R<F%Y("1E>&-L=61E
M(&EN8V]M<&%T:6)L92!02%`@=F5R<VEO;G,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!S9710:'!$97`H)&UI;BP@)&UA>"`](&9A;'-E+"`D97AC;'5D92`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-
M"B`@("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`G;6EN)R`]/B`D;6EN+`T*("`@("`@("`@("`@*3L-"B`@("`@
M("`@:68@*"1M87@I('L-"B`@("`@("`@("`@("1D97!;)VUA>"==(#T@)&UA
M>#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&5X8VQU9&4I('L-"B`@("`@
M("`@("`@(&EF("AC;W5N="@D97AC;'5D92D@/3T@,2D@>PT*("`@("`@("`@
M("`@("`@("1E>&-L=61E(#T@)&5X8VQU9&5;,%T[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UU;)W!H<"==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=W
M87)N:6YG)RP@87)R87DH)V1E<"<@/3X-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P:'`G
M72DL#0H@("`@("`@("`@("`@("`@)W=A<FYI;F<Z(%!(4"!D97!E;F1E;F-Y
M(&%L<F5A9'D@97AI<W1S+"!O=F5R=W)I=&EN9R<I.PT*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)W)E
M<75I<F5D)UU;)W!H<"==*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA
M9V5);F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH)W!R;W9I9&5S97AT96YS
M:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-"B`@("`@("`@("`@("`@
M("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G
M97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@
M("`@("`G<F5Q=6ER960G(#T^(&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I
M+`T*("`@("`@("`@("`@("`@("=P:'`G(#T^(&%R<F%Y*"=P96%R:6YS=&%L
M;&5R)RP@)W!A8VMA9V4G+"`G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G
M;W,G+"`G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!M:6YI;75M(&%L;&]W960@4$5!4B!I;G-T86QL97(@=F5R<VEO;@T*("`@
M("`J($!P87)A;2!S=')I;F<@;6%X:6UU;2!A;&QO=V5D(%!%05(@:6YS=&%L
M;&5R('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(')E8V]M;65N9&5D
M(%!%05(@:6YS=&%L;&5R('9E<G-I;VX-"B`@("`@*B!`<&%R86T@87)R87D@
M:6YC;VUP871I8FQE('9E<G-I;VX@;V8@=&AE(%!%05(@:6YS=&%L;&5R#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4&5A<FEN<W1A;&QE<D1E<"@D;6EN
M+"`D;6%X(#T@9F%L<V4L("1R96-O;6UE;F1E9"`](&9A;'-E+"`D97AC;'5D
M92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@
M,#L-"B`@("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`G;6EN)R`]/B`D;6EN+`T*("`@("`@("`@("`@*3L-"B`@
M("`@("`@:68@*"1M87@I('L-"B`@("`@("`@("`@("1D97!;)VUA>"==(#T@
M)&UA>#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')E8V]M;65N9&5D*2![
M#0H@("`@("`@("`@("`D9&5P6R=R96-O;6UE;F1E9"==(#T@)')E8V]M;65N
M9&5D.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D97AC;'5D92D@>PT*("`@
M("`@("`@("`@:68@*&-O=6YT*"1E>&-L=61E*2`]/2`Q*2![#0H@("`@("`@
M("`@("`@("`@)&5X8VQU9&4@/2`D97AC;'5D95LP73L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`]("1E>&-L=61E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE
M<B==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=W87)N:6YG)RP@87)R87DH)V1E<"<@/3X-"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R97%U
M:7)E9"==6R=P96%R:6YS=&%L;&5R)UTI+`T*("`@("`@("`@("`@("`@("=W
M87)N:6YG.B!014%2($EN<W1A;&QE<B!D97!E;F1E;F-Y(&%L<F5A9'D@97AI
M<W1S+"!O=F5R=W)I=&EN9R<I.PT*("`@("`@("`@("`@=6YS970H)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UU;)W!E
M87)I;G-T86QL97(G72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E
M26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO
M;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@
M("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X
M='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@
M("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@
M("`@)W)E<75I<F5D)R`]/B!A<G)A>2@G;W!T:6]N86PG+"`G9W)O=7`G*2P-
M"B`@("`@("`@("`@("`@("`G<&5A<FEN<W1A;&QE<B<@/3X@87)R87DH)W!A
M8VMA9V4G+"`G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G;W,G+"`G87)C
M:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!-87)K(&$@<&%C:V%G92!A<R!C;VYF;&EC=&EN9R!W:71H('1H:7,@<&%C
M:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&5X=&5N<VEO;B!T:&ES('!A8VMA9V4@<')O=FED97,L(&EF
M(&%N>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-O;F9L:6-T:6YG4&%C
M:V%G941E<%=I=&A#:&%N;F5L*"1N86UE+"`D8VAA;FYE;"P@)'!R;W9I9&5S
M97AT96YS:6]N(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES
M5F%L:60@/2`P.PT*("`@("`@("`D9&5P(#T-"B`@("`@("`@("`@(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@("`@
M("`@("`@("`G8VAA;FYE;"<@/3X@)&-H86YN96PL#0H@("`@("`@("`@("`@
M("`@)V-O;F9L:6-T<R<@/3X@)R<L#0H@("`@("`@("`@("`I.PT*("`@("`@
M("!I9B`H)'!R;W9I9&5S97AT96YS:6]N*2![#0H@("`@("`@("`@("`D9&5P
M6R=P<F]V:61E<V5X=&5N<VEO;B==(#T@)'!R;W9I9&5S97AT96YS:6]N.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI
M<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@
M("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S
M)R`]/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G
M=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L
M("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X
M=&)I;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@
M)V-H86YG96QO9R<I+`T*("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@
M87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RDL#0H@("`@("`@("`@("`@("`@
M)W!A8VMA9V4G(#T^(&%R<F%Y*"=S=6)P86-K86=E)RP@)V5X=&5N<VEO;B<L
M("=O<R<L("=A<F-H)RD-"B`@("`@("`@("`@("DI.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($UA<FL@82!P86-K86=E(&%S(&-O;F9L:6-T:6YG('=I
M=&@@=&AI<R!P86-K86=E#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E
M(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@8VAA;FYE;`T*
M("`@("`J($!P87)A;2!S=')I;F<@97AT96YS:6]N('1H:7,@<&%C:V%G92!P
M<F]V:61E<RP@:68@86YY#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D0V]N
M9FQI8W1I;F=086-K86=E1&5P5VET:%5R:2@D;F%M92P@)'5R:2P@)'!R;W9I
M9&5S97AT96YS:6]N(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7VES5F%L:60@/2`P.PT*("`@("`@("`D9&5P(#T-"B`@("`@("`@("`@(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@
M("`@("`@("`@("`G=7)I)R`]/B`D=7)I+`T*("`@("`@("`@("`@("`@("=C
M;VYF;&EC=',G(#T^("<G+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@:68@
M*"1P<F]V:61E<V5X=&5N<VEO;BD@>PT*("`@("`@("`@("`@)&1E<%LG<')O
M=FED97-E>'1E;G-I;VXG72`]("1P<F]V:61E<V5X=&5N<VEO;CL-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M
M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@("`@("`@
M("`@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@
M87)R87DH)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T
M87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C
M=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR
M96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C:&%N
M9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&%R<F%Y
M*"=O<'1I;VYA;"<L("=G<F]U<"<I+`T*("`@("`@("`@("`@("`@("=P86-K
M86=E)R`]/B!A<G)A>2@G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G;W,G
M+"`G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!A9&1$97!E;F1E;F-Y1W)O=7`H)&YA;64L("1H:6YT*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K
M86=E26YF;RP-"B`@("`@("`@("`@(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A
M>2@G;F%M92<@/3X@)&YA;64L("=H:6YT)R`]/B`D:&EN="DI+`T*("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@
M/3X@87)R87DH)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S
M97-T87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G
M<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B
M:6YR96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C
M:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`G9W)O=7`G(#T^(&%R<F%Y
M*"DL#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S
M=')I;F=\9F%L<V4@8VAA;FYE;"!N86UE+"!F86QS92!I9B!T:&ES(&ES(&$@
M=7)I#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!U<FD@;F%M92P@9F%L
M<V4@:68@=&AI<R!I<R!A(&-H86YN96P-"B`@("`@*B!`<&%R86T@<W1R:6YG
M?&9A;'-E(&UI;FEM=6T@=F5R<VEO;B!R97%U:7)E9`T*("`@("`J($!P87)A
M;2!S=')I;F=\9F%L<V4@;6%X:6UU;2!V97)S:6]N(&%L;&]W960-"B`@("`@
M*B!`<&%R86T@<W1R:6YG?&9A;'-E(')E8V]M;65N9&5D(&EN<W1A;&QA=&EO
M;B!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y?&9A;'-E('9E<G-I;VYS
M('1O(&5X8VQU9&4@9G)O;2!I;G-T86QL871I;VX-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&5X=&5N<VEO;B!T:&ES('!A8VMA9V4@<')O=FED97,L(&EF(&%N
M>0T*("`@("`J($!P87)A;2!B;V]L(&EF('1R=64L('1E;&QS('1H92!I;G-T
M86QL97(@=&\@:6=N;W)E('1H92!D969A=6QT(&]P=&EO;F%L(&1E<&5N9&5N
M8WD@9W)O=7`-"B`@("`@*B`@("`@("`@("`@("!W:&5N(&EN<W1A;&QI;F<@
M=&AI<R!P86-K86=E#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C;VYS=')U
M8W1$97`H)&YA;64L("1C:&%N;F5L+"`D=7)I+"`D;6EN+"`D;6%X+"`D<F5C
M;VUM96YD960L("1E>&-L=61E+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!R;W9I9&5S97AT96YS:6]N(#T@9F%L<V4L("1N;V1E9F%U;'0@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1D97`@/0T*("`@("`@("`@("`@87)R
M87DH#0H@("`@("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`T*("`@("`@
M("`@("`@*3L-"B`@("`@("`@:68@*"1C:&%N;F5L*2![#0H@("`@("`@("`@
M("`D9&5P6R=C:&%N;F5L)UT@/2`D8VAA;FYE;#L-"B`@("`@("`@?2!E;'-E
M:68@*"1U<FDI('L-"B`@("`@("`@("`@("1D97!;)W5R:2==(#T@)'5R:3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UI;BD@>PT*("`@("`@("`@("`@
M)&1E<%LG;6EN)UT@/2`D;6EN.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M;6%X*2![#0H@("`@("`@("`@("`D9&5P6R=M87@G72`]("1M87@[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1R96-O;6UE;F1E9"D@>PT*("`@("`@("`@
M("`@)&1E<%LG<F5C;VUM96YD960G72`]("1R96-O;6UE;F1E9#L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)&5X8VQU9&4I('L-"B`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D97AC;'5D92D@)B8@8V]U;G0H)&5X8VQU9&4I(#T](#$I
M('L-"B`@("`@("`@("`@("`@("`D97AC;'5D92`]("1E>&-L=61E6S!=.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@
M)&5X8VQU9&4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1N;V1E9F%U;'0I
M('L-"B`@("`@("`@("`@("1D97!;)VYO9&5F875L="==(#T@)R<[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1P<F]V:61E<V5X=&5N<VEO;BD@>PT*("`@
M("`@("`@("`@)&1E<%LG<')O=FED97-E>'1E;G-I;VXG72`]("1P<F]V:61E
M<V5X=&5N<VEO;CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&1E<#L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<&%C:V%G97QS=6)P
M86-K86=E#0H@("`@("H@0'!A<F%M('-T<FEN9R!G<F]U<"!N86UE#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('!A8VMA9V4@8VAA;FYE;`T*("`@("`J($!P87)A;2!S=')I;F<@
M;6EN:6UU;2!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!M87AI;75M
M('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(')E8V]M;65N9&5D('9E
M<G-I;VX-"B`@("`@*B!`<&%R86T@87)R87E\9F%L<V4@;W!T:6]N86P@97AC
M;'5D960@=F5R<VEO;G,-"B`@("`@*B!`<&%R86T@<W1R:6YG(&5X=&5N<VEO
M;B!T:&ES('!A8VMA9V4@<')O=FED97,L(&EF(&%N>0T*("`@("`J($!P87)A
M;2!B;V]L(&EF('1R=64L('1E;&QS('1H92!I;G-T86QL97(@=&\@:6=N;W)E
M('1H92!D969A=6QT(&]P=&EO;F%L(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@
M*B`@("`@("`@("`@("!W:&5N(&EN<W1A;&QI;F<@=&AI<R!P86-K86=E#0H@
M("`@("H@0')E='5R;B!B;V]L(&9A;'-E(&EF('1H92!D97!E;F1E;F-Y(&=R
M;W5P(&AA<R!N;W0@8F5E;B!I;FET:6%L:7IE9"!W:71H#0H@("`@("H@("`@
M("`@("`@("`@('M`;&EN:R!A9&1$97!E;F1E;F-Y1W)O=7`H*7TL(&]R(&$@
M<W5B<&%C:V%G92!I<R!A9&1E9"!W:71H#0H@("`@("H@("`@("`@("`@("`@
M(&$@<')O=FED97-E>'1E;G-I;VX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A
M9&1'<F]U<%!A8VMA9V5$97!7:71H0VAA;FYE;"@D='EP92P@)&=R;W5P;F%M
M92P@)&YA;64L("1C:&%N;F5L+"`D;6EN(#T@9F%L<V4L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M87@@/2!F86QS92P@)')E
M8V]M;65N9&5D(#T@9F%L<V4L("1E>&-L=61E(#T@9F%L<V4L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F]V:61E<V5X=&5N
M<VEO;B`](&9A;'-E+"`D;F]D969A=6QT(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H)'1Y<&4@/3T@)W-U8G!A8VMA9V4G("8F("1P<F]V:61E<V5X
M=&5N<VEO;BD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.R`O+R!S=6)P
M86-K86=E<R!M=7-T(&)E('!H<"!P86-K86=E<PT*("`@("`@("!]#0H@("`@
M("`@("1D97`@/2`D=&AI<RT^7V-O;G-T<G5C=$1E<"@D;F%M92P@)&-H86YN
M96PL(&9A;'-E+"`D;6EN+"`D;6%X+"`D<F5C;VUM96YD960L("1E>&-L=61E
M+`T*("`@("`@("`@("`@)'!R;W9I9&5S97AT96YS:6]N+"`D;F]D969A=6QT
M*3L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?861D1W)O=7!$97!E;F1E;F-Y
M*"1T>7!E+"`D9&5P+"`D9W)O=7!N86UE*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@<&%C:V%G97QS=6)P86-K86=E#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!G<F]U<"!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!P
M86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@=7)I
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@=&AI<R!P86-K86=E
M('!R;W9I9&5S+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E
M+"!T96QL<R!T:&4@:6YS=&%L;&5R('1O(&EG;F]R92!T:&4@9&5F875L="!O
M<'1I;VYA;"!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@("`@("`@("`@("`@
M=VAE;B!I;G-T86QL:6YG('1H:7,@<&%C:V%G90T*("`@("`J($!R971U<FX@
M8F]O;"!F86QS92!I9B!T:&4@9&5P96YD96YC>2!G<F]U<"!H87,@;F]T(&)E
M96X@:6YI=&EA;&EZ960@=VET:`T*("`@("`J("`@("`@("`@("`@("![0&QI
M;FL@861D1&5P96YD96YC>4=R;W5P*"E]#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@861D1W)O=7!086-K86=E1&5P5VET:%5222@D='EP92P@)&=R;W5P;F%M
M92P@)&YA;64L("1U<FDL("1P<F]V:61E<V5X=&5N<VEO;B`](&9A;'-E+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&5F
M875L="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1T>7!E(#T]("=S
M=6)P86-K86=E)R`F)B`D<')O=FED97-E>'1E;G-I;VXI('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L@+R\@<W5B<&%C:V%G97,@;75S="!B92!P:'`@
M<&%C:V%G97,-"B`@("`@("`@?0T*("`@("`@("`D9&5P(#T@)'1H:7,M/E]C
M;VYS=')U8W1$97`H)&YA;64L(&9A;'-E+"`D=7)I+"!F86QS92P@9F%L<V4L
M(&9A;'-E+"!F86QS92P-"B`@("`@("`@("`@("1P<F]V:61E<V5X=&5N<VEO
M;BP@)&YO9&5F875L="D[#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V%D9$=R
M;W5P1&5P96YD96YC>2@D='EP92P@)&1E<"P@)&=R;W5P;F%M92D[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!G<F]U<"!N86UE
M("AM=7-T(&)E('!R92UE>&ES=&EN9RD-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&5X=&5N<VEO;B!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M
M('9E<G-I;VX@86QL;W=E9`T*("`@("`J($!P87)A;2!S=')I;F<@;6%X:6UU
M;2!V97)S:6]N(&%L;&]W960-"B`@("`@*B!`<&%R86T@<W1R:6YG(')E8V]M
M;65N9&5D('9E<G-I;VX-"B`@("`@*B!`<&%R86T@87)R87D@:6YC;VUP871I
M8FQE('9E<G-I;VYS#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D1W)O=7!%
M>'1E;G-I;VY$97`H)&=R;W5P;F%M92P@)&YA;64L("1M:6X@/2!F86QS92P@
M)&UA>"`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5C;VUM96YD960@/2!F86QS92P@)&5X8VQU9&4@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@
M("`@("`@("1D97`@/2`D=&AI<RT^7V-O;G-T<G5C=$1E<"@D;F%M92P@9F%L
M<V4L(&9A;'-E+"`D;6EN+"`D;6%X+"`D<F5C;VUM96YD960L("1E>&-L=61E
M*3L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?861D1W)O=7!$97!E;F1E;F-Y
M*"=E>'1E;G-I;VXG+"`D9&5P+"`D9W)O=7!N86UE*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<&%R86T@<&%C:V%G97QS=6)P86-K86=E?&5X=&5N
M<VEO;@T*("`@("`J($!P87)A;2!A<G)A>2!D97!E;F1E;F-Y(&-O;G1E;G1S
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!N86UE(&]F('1H92!D97!E;F1E;F-Y
M(&=R;W5P('1O(&%D9"!T:&ES('1O#0H@("`@("H@0')E='5R;B!B;V]L96%N
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7V%D9$=R;W5P1&5P96YD96YC>2@D='EP92P@)&1E<"P@)&=R;W5P;F%M
M92D-"B`@("![#0H@("`@("`@("1A<G(@/2!A<G)A>2@G<W5B<&%C:V%G92<L
M("=E>'1E;G-I;VXG*3L-"B`@("`@("`@:68@*"1T>7!E("$]("=P86-K86=E
M)RD@>PT*("`@("`@("`@("`@87)R87E?<VAI9G0H)&%R<BD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1T>7!E(#T]("=E>'1E;G-I;VXG*2![#0H@("`@
M("`@("`@("!A<G)A>5]S:&EF="@D87)R*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE
M<R==6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG9W)O=7`G75LP72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]P86-K86=E26YF;ULG
M9&5P96YD96YC:65S)UU;)V=R;W5P)UU;)V%T=')I8G,G75LG;F%M92==(#T]
M("1G<F]U<&YA;64I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UT@/2`D=&AI<RT^
M7VUE<F=E5&%G*`T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UTL("1D97`L#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D='EP92`]/B`D87)R#0H@("`@("`@("`@("`@("`@
M("`@("`@("`I*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@,#L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UT@87,@)&D@/3X@
M)&=R;W5P*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D9W)O=7!;)V%T
M=')I8G,G75LG;F%M92==(#T]("1G<F]U<&YA;64I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;
M)V=R;W5P)UU;)&E=(#T@)'1H:7,M/E]M97)G951A9R@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE
M<R==6R=G<F]U<"==6R1I72P@)&1E<"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E
M(#T^("1A<G(-"B`@("`@("`@("`@("`@("`@("`@("`@("DI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O<'1I;VYA;'QR97%U:7)E
M9`T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&UI;FEM=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@
M;6%X:6UU;2!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE
M;F1E9"!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@
M=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@
M8F]O;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L;&5R('1O(&EG;F]R92!T
M:&4@9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@
M("`@("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H:7,@<&%C:V%G90T*("`@
M("`J($!P87)A;2!A<G)A>7QF86QS92!O<'1I;VYA;"!E>&-L=61E9"!V97)S
M:6]N<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9%!A8VMA9V5$97!7:71H
M0VAA;FYE;"@D='EP92P@)&YA;64L("1C:&%N;F5L+"`D;6EN(#T@9F%L<V4L
M("1M87@@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E8V]M;65N9&5D(#T@9F%L<V4L("1E>&-L=61E(#T@9F%L
M<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M<F]V:61E<V5X=&5N<VEO;B`](&9A;'-E+"`D;F]D969A=6QT(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@
M("`D87)R(#T@87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RD[#0H@("`@("`@
M(&EF("@D='EP92`A/2`G<F5Q=6ER960G*2![#0H@("`@("`@("`@("!A<G)A
M>5]S:&EF="@D87)R*3L-"B`@("`@("`@?0T*("`@("`@("`D9&5P(#T@)'1H
M:7,M/E]C;VYS=')U8W1$97`H)&YA;64L("1C:&%N;F5L+"!F86QS92P@)&UI
M;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92P-"B`@("`@("`@("`@
M("1P<F]V:61E<V5X=&5N<VEO;BP@)&YO9&5F875L="D[#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?
M<&%C:V%G94EN9F\L("1D97`L#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`G9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O=FED97-E
M>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@
M("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP<F5L96%S
M92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+`T*("`@("`@
M("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@("`@
M("`@("`@("`@("1T>7!E(#T^("1A<G(L#0H@("`@("`@("`@("`@("`@)W!A
M8VMA9V4G(#T^(&%R<F%Y*"=S=6)P86-K86=E)RP@)V5X=&5N<VEO;B<L("=O
M<R<L("=A<F-H)RD-"B`@("`@("`@("`@("DI.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!O<'1I;VYA;'QR97%U:7)E9`T*("`@("`J($!P
M87)A;2!S=')I;F<@;F%M92!O9B!T:&4@<&%C:V%G90T*("`@("`J($!P87)A
M;2!S=')I;F<@=7)I(&]F('1H92!P86-K86=E#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!E>'1E;G-I;VX@=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-
M"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L
M;&5R('1O(&EG;F]R92!T:&4@9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y
M(&=R;W5P#0H@("`@("H@("`@("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H
M:7,@<&%C:V%G90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9%!A8VMA9V5$
M97!7:71H57)I*"1T>7!E+"`D;F%M92P@)'5R:2P@)'!R;W9I9&5S97AT96YS
M:6]N(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YO9&5F875L="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&%R<B`](&%R<F%Y*"=O<'1I;VYA
M;"<L("=G<F]U<"<I.PT*("`@("`@("!I9B`H)'1Y<&4@(3T@)W)E<75I<F5D
M)RD@>PT*("`@("`@("`@("`@87)R87E?<VAI9G0H)&%R<BD[#0H@("`@("`@
M('T-"B`@("`@("`@)&1E<"`]("1T:&ES+3Y?8V]N<W1R=6-T1&5P*"1N86UE
M+"!F86QS92P@)'5R:2P@9F%L<V4L(&9A;'-E+"!F86QS92P@9F%L<V4L#0H@
M("`@("`@("`@("`D<')O=FED97-E>'1E;G-I;VXL("1N;V1E9F%U;'0I.PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A
M9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R
M87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH
M)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-
M"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@
M)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G
M*2P-"B`@("`@("`@("`@("`@("`D='EP92`]/B`D87)R+`T*("`@("`@("`@
M("`@("`@("=P86-K86=E)R`]/B!A<G)A>2@G<W5B<&%C:V%G92<L("=E>'1E
M;G-I;VXG+"`G;W,G+"`G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960@
M;W!T:6]N86PL(')E<75I<F5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K
M86=E(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@8VAA;FYE
M;`T*("`@("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!V97)S:6]N#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!M87AI;75M('9E<G-I;VX-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(')E8V]M;65N9&5D('9E<G-I;VX-"B`@("`@*B!`<&%R86T@
M87)R87D@:6YC;VUP871I8FQE('9E<G-I;VYS#0H@("`@("H@0'!A<F%M(&)O
M;VP@:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE
M(&1E9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@
M("`@("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&13=6)P86-K86=E1&5P5VET:$-H86YN96PH
M)'1Y<&4L("1N86UE+"`D8VAA;FYE;"P@)&UI;B`](&9A;'-E+"`D;6%X(#T@
M9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R96-O;6UE;F1E9"`](&9A;'-E+"`D97AC;'5D92`](&9A;'-E+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]D
M969A=6QT(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2`P.PT*("`@("`@("`D87)R(#T@87)R87DH)V]P=&EO;F%L)RP@)V=R
M;W5P)RD[#0H@("`@("`@(&EF("@D='EP92`A/2`G<F5Q=6ER960G*2![#0H@
M("`@("`@("`@("!A<G)A>5]S:&EF="@D87)R*3L-"B`@("`@("`@?0T*("`@
M("`@("`D9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L("1C:&%N
M;F5L+"!F86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D
M92P-"B`@("`@("`@("`@("1N;V1E9F%U;'0I.PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA
M9V5);F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH)W!R;W9I9&5S97AT96YS
M:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-"B`@("`@("`@("`@("`@
M("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G
M97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@
M("`@("`D='EP92`]/B`D87)R+`T*("`@("`@("`@("`@("`@("=S=6)P86-K
M86=E)R`]/B!A<G)A>2@G97AT96YS:6]N)RP@)V]S)RP@)V%R8V@G*0T*("`@
M("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M(&]P=&EO;F%L?')E<75I<F5D(&]P=&EO;F%L+"!R97%U:7)E9`T*("`@("`J
M($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!P86-K86=E('5R:2!F;W(@9&]W;FQO860-"B`@("`@*B!`<&%R86T@
M8F]O;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L;&5R('1O(&EG;F]R92!T
M:&4@9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@
M("`@("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H:7,@<&%C:V%G90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&%D9%-U8G!A8VMA9V5$97!7:71H57)I*"1T
M>7!E+"`D;F%M92P@)'5R:2P@)&YO9&5F875L="`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&%R<B`]
M(&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I.PT*("`@("`@("!I9B`H)'1Y
M<&4@(3T@)W)E<75I<F5D)RD@>PT*("`@("`@("`@("`@87)R87E?<VAI9G0H
M)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`]("1T:&ES+3Y?8V]N
M<W1R=6-T1&5P*"1N86UE+"!F86QS92P@)'5R:2P@9F%L<V4L(&9A;'-E+"!F
M86QS92P@9F%L<V4L("1N;V1E9F%U;'0I.PT*("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5)
M;F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH)W!R;W9I9&5S97AT96YS:6]N
M)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-"B`@("`@("`@("`@("`@("`@
M("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT
M<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@
M("`D='EP92`]/B`D87)R+`T*("`@("`@("`@("`@("`@("=S=6)P86-K86=E
M)R`]/B!A<G)A>2@G97AT96YS:6]N)RP@)V]S)RP@)V%R8V@G*0T*("`@("`@
M("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&]P
M=&EO;F%L?')E<75I<F5D(&]P=&EO;F%L+"!R97%U:7)E9`T*("`@("`J($!P
M87)A;2!S=')I;F<@97AT96YS:6]N(&YA;64-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&UI;FEM=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@;6%X
M:6UU;2!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E
M9"!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y(&EN8V]M<&%T:6)L92!V
M97)S:6]N<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$5X=&5N<VEO;D1E
M<"@D='EP92P@)&YA;64L("1M:6X@/2!F86QS92P@)&UA>"`](&9A;'-E+"`D
M<F5C;VUM96YD960@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5X8VQU9&4@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1A<G(@/2!A<G)A>2@G;W!T:6]N
M86PG+"`G9W)O=7`G*3L-"B`@("`@("`@:68@*"1T>7!E("$]("=R97%U:7)E
M9"<I('L-"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@
M("!]#0H@("`@("`@("1D97`@/2`D=&AI<RT^7V-O;G-T<G5C=$1E<"@D;F%M
M92P@9F%L<V4L(&9A;'-E+"`D;6EN+"`D;6%X+"`D<F5C;VUM96YD960L("1E
M>&-L=61E*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES
M+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@("`@
M("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G
M(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U
M<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@
M)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT
M8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G
M8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@)'1Y<&4@/3X@)&%R<BP-
M"B`@("`@("`@("`@("`@("`G97AT96YS:6]N)R`]/B!A<G)A>2@G;W,G+"`G
M87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@<W1R:6YG($]P97)A=&EN9R!S>7-T96T@;F%M90T*("`@
M("`J($!P87)A;2!B;V]L96%N('1R=64@:68@=&AI<R!P86-K86=E(&-A;FYO
M="!B92!I;G-T86QL960@;VX@=&AI<R!/4PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&%D9$]S1&5P*"1N86UE+"`D8V]N9FQI8W1S(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D9&5P
M(#T@87)R87DH)VYA;64G(#T^("1N86UE*3L-"B`@("`@("`@:68@*"1C;VYF
M;&EC=',I('L-"B`@("`@("`@("`@("1D97!;)V-O;F9L:6-T<R==(#T@)R<[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T
M:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I
M97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L
M("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E
M)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G
M97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G
M+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]
M/B!A<G)A>2@G;W!T:6]N86PG+"`G9W)O=7`G*2P-"B`@("`@("`@("`@("`@
M("`G;W,G(#T^(&%R<F%Y*"=A<F-H)RD-"B`@("`@("`@("`@("DI.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@07)C:&ET96-T
M=7)E(&UA=&-H:6YG('!A='1E<FX-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!T
M<G5E(&EF('1H:7,@<&%C:V%G92!C86YN;W0@8F4@:6YS=&%L;&5D(&]N('1H
M:7,@87)C:&ET96-T=7)E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D07)C
M:$1E<"@D<&%T=&5R;BP@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&1E<"`](&%R
M<F%Y*"=P871T97)N)R`]/B`D<&%T=&5R;BD[#0H@("`@("`@(&EF("@D8V]N
M9FQI8W1S*2![#0H@("`@("`@("`@("`D9&5P6R=C;VYF;&EC=',G72`]("<G
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D
M=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@
M("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC
M:65S)R`]/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G
M+"`G=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G
M92<L("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@
M)V5X=&)I;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE
M)RP@)V-H86YG96QO9R<I+`T*("`@("`@("`@("`@("`@("=R97%U:7)E9"<@
M/3X@87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RDL#0H@("`@("`@("`@("`@
M("`@)V%R8V@G(#T^(&%R<F%Y*"D-"B`@("`@("`@("`@("DI.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@:VEN9"!O9B!P86-K86=E+"!A
M;F0@97)A<V4@86QL(')E;&5A<V4@=&%G<PT*("`@("`J#0H@("`@("H@+2!A
M('!H<"!P86-K86=E(&ES(&$@4$5!4BUS='EL92!P86-K86=E#0H@("`@("H@
M+2!A;B!E>'1B:6X@<&%C:V%G92!I<R!A(%!%0TPM<W1Y;&4@97AT96YS:6]N
M(&)I;F%R>0T*("`@("`J("T@86X@97AT<W)C('!A8VMA9V4@:7,@82!014-,
M+7-T>6QE('-O=7)C92!F;W(@82!B:6YA<GD-"B`@("`@*B`M(&$@8G5N9&QE
M('!A8VMA9V4@:7,@82!C;VQL96-T:6]N(&]F(&]T:&5R('!R92UP86-K86=E
M9"!P86-K86=E<PT*("`@("`J($!P87)A;2!P:'!\97AT8FEN?&5X='-R8WQB
M=6YD;&4-"B`@("`@*B!`<F5T=7)N(&)O;VP@<W5C8V5S<PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=%!A8VMA9V54>7!E*"1T>7!E*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@:68@*"%I;E]A
M<G)A>2@D='EP92P@87)R87DH)W!H<"<L("=E>'1B:6XG+"`G97AT<W)C)RP@
M)V)U;F1L92<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D='EP92`A/2`G8G5N9&QE)RD@>PT*("`@
M("`@("`@("`@)'1Y<&4@+CT@)W)E;&5A<V4G.PT*("`@("`@("!]#0H@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y*"=P:'!R96QE87-E)RP@)V5X=&)I;G)E;&5A
M<V4G+"`G97AT<W)C<F5L96%S92<L("=B=6YD;&4G*2!A<R`D=&5S="D@>PT*
M("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULD=&5S=%TI
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULD='EP95TI*2![#0H@("`@("`@("`@("`O+R!E;G-U<F4@=&AA
M="!T:&4@<F5L96%S92!T86<@:7,@<V5T('5P#0H@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M
M/E]P86-K86=E26YF;RP@87)R87DH)V-H86YG96QO9R<I+`T*("`@("`@("`@
M("`@("`@(&%R<F%Y*"DL("1T>7!E*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R1T>7!E72`](&%R<F%Y*"D[#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U
M<FX@8F]O;"!T<G5E(&EF('!A8VMA9V4@='EP92!I<R!S970@=7`-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&1296QE87-E*"D-"B`@("![#0H@("`@("`@
M(&EF("@D='EP92`]("1T:&ES+3YG971086-K86=E5'EP92@I*2![#0H@("`@
M("`@("`@("!I9B`H)'1Y<&4@(3T@)V)U;F1L92<I('L-"B`@("`@("`@("`@
M("`@("`D='EP92`N/2`G<F5L96%S92<[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A
M9R@D=&AI<RT^7W!A8VMA9V5);F9O+"!A<G)A>2@I+`T*("`@("`@("`@("`@
M("`@(&%R<F%Y*"1T>7!E(#T^(&%R<F%Y*"=C:&%N9V5L;V<G*2DI.PT*("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@
M8W5R<F5N="!R96QE87-E('1A9R!I;B!O<F1E<B!T;R!A9&0@=&\@:70-"B`@
M("`@*B!`<&%R86T@8F]O;"!R971U<FYS(&]N;'D@<F5L96%S97,@=&AA="!H
M879E(&EN<W1A;&QC;VYD:71I;VX@:68@=')U90T*("`@("`J($!R971U<FX@
M87)R87E\;G5L;`T*("`@("`J+PT*("`@(&9U;F-T:6]N("9?9V5T0W5R<F5N
M=%)E;&5A<V4H)'-T<FEC="`]('1R=64I#0H@("`@>PT*("`@("`@("!I9B`H
M)'`@/2`D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2D@>PT*("`@("`@("`@("`@
M:68@*"1S=')I8W0I('L-"B`@("`@("`@("`@("`@("!I9B`H)'`@/3T@)V5X
M='-R8R<I('L-"B`@("`@("`@("`@("`@("`@("`@)&$@/2!N=6QL.PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1P("$]("=B=6YD
M;&4G*2![#0H@("`@("`@("`@("`@("`@)'`@+CT@)W)E;&5A<V4G.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)'!=6S!=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R1P75MC;W5N="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1P72D@+2`Q73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)'!=.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&$@
M/2!N=6QL.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@061D(&$@9FEL92!T;R!T:&4@8W5R
M<F5N="!R96QE87-E('1H870@<VAO=6QD(&)E(&EN<W1A;&QE9"!U;F1E<B!A
M(&1I9F9E<F5N="!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R`\8V]N=&5N
M=',^('!A=&@@=&\@9FEL90T*("`@("`J($!P87)A;2!S=')I;F<@;F%M92!T
M:&4@9FEL92!S:&]U;&0@8F4@:6YS=&%L;&5D(&%S#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@861D26YS=&%L;$%S*"1P871H+"`D87,I#0H@("`@>PT*("`@
M("`@("`D<B`]("8D=&AI<RT^7V=E=$-U<G)E;G1296QE87-E*"D[#0H@("`@
M("`@(&EF("@D<B`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[
M#0H@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D<BP@87)R87DH)V%T
M=')I8G,G(#T^(&%R<F%Y*"=N86UE)R`]/B`D<&%T:"P@)V%S)R`]/B`D87,I
M*2P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=F:6QE
M;&ES="<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("`@("`G:6YS=&%L;"<@
M/3X@87)R87DH)VEG;F]R92<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!!9&0@82!F:6QE('1O('1H92!C=7)R96YT(')E
M;&5A<V4@=&AA="!S:&]U;&0@8F4@:6=N;W)E9`T*("`@("`J($!P87)A;2!S
M=')I;F<@/&-O;G1E;G1S/B!P871H('1O(&9I;&4-"B`@("`@*B!`<F5T=7)N
M(&)O;VP@<W5C8V5S<R!O9B!O<&5R871I;VX-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!A9&1)9VYO<F4H)'!A=&@I#0H@("`@>PT*("`@("`@("`D<B`]("8D
M=&AI<RT^7V=E=$-U<G)E;G1296QE87-E*"D[#0H@("`@("`@(&EF("@D<B`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1R
M(#T@)'1H:7,M/E]M97)G951A9R@D<BP@87)R87DH)V%T=')I8G,G(#T^(&%R
M<F%Y*"=N86UE)R`]/B`D<&%T:"DI+`T*("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@)V9I;&5L:7-T)R`]/B!A<G)A>2@I+`T*("`@("`@
M("`@("`@("`@("=I9VYO<F4G(#T^(&%R<F%Y*"D-"B`@("`@("`@("`@("DI
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($%D9"!A;B!E>'1E;G-I;VX@
M8FEN87)Y('!A8VMA9V4@9F]R('1H:7,@97AT96YS:6]N('-O=7)C92!C;V1E
M(')E;&5A<V4-"B`@("`@*@T*("`@("`J($YO=&4@=&AA="!T:&4@<&%C:V%G
M92!M=7-T(&)E(&9R;VT@=&AE('-A;64@8VAA;FYE;"!A<R!T:&4@97AT96YS
M:6]N('-O=7)C92!P86-K86=E#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&%D9$)I;F%R>7!A8VMA9V4H)'!A8VMA9V4I
M#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@
M(3T@)V5X='-R8R<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("`D<B`]("8D=&AI<RT^7V=E=$-U<G)E;G1296QE
M87-E*&9A;'-E*3L-"B`@("`@("`@:68@*"1R(#T]/2!N=6QL*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)'(@/2`D=&AI<RT^7VUE<F=E
M5&%G*"1R+"`D<&%C:V%G92P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=B:6YA<GEP86-K86=E)R`]/B!A<G)A>2@G9FEL96QI<W0G
M*2P-"B`@("`@("`@("`@("DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($%D9"!A(&-O;F9I9W5R96]P=&EO;B!T;R!A;B!E>'1E;G-I;VX@<V]U<F-E
M('!A8VMA9V4-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0'!A<F%M
M('-T<FEN9PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!A9&1#;VYF:6=U<F5/<'1I;VXH)&YA;64L("1P<F]M<'0L("1D
M969A=6QT(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^9V5T
M4&%C:V%G951Y<&4H*2`A/2`G97AT<W)C)RD@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1R(#T@)B1T:&ES+3Y?
M9V5T0W5R<F5N=%)E;&5A<V4H9F%L<V4I.PT*("`@("`@("!I9B`H)'(@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D;W!T(#T@87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=N
M86UE)R`]/B`D;F%M92P@)W!R;VUP="<@/3X@)'!R;VUP="DI.PT*("`@("`@
M("!I9B`H)&1E9F%U;'0@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1O<'1;
M)V1E9F%U;'0G72`]("1D969A=6QT.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1R(#T@)'1H:7,M/E]M97)G
M951A9R@D<BP@)&]P="P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("=C;VYF:6=U<F5O<'1I;VXG(#T^(&%R<F%Y*"=B:6YA<GEP86-K
M86=E)RP@)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!3970@86X@:6YS=&%L;&%T:6]N(&-O;F1I=&EO
M;B!B87-E9"!O;B!P:'`@=F5R<VEO;B!F;W(@=&AE(&-U<G)E;G0@<F5L96%S
M92!S970-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI;FEM=6T@=F5R<VEO;@T*
M("`@("`J($!P87)A;2!S=')I;F<@;6%X:6UU;2!V97)S:6]N#0H@("`@("H@
M0'!A<F%M(&9A;'-E?&%R<F%Y(&EN8V]M<&%T:6)L92!V97)S:6]N<R!O9B!0
M2%`-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S9710:'!);G-T86QL0V]N9&ET
M:6]N*"1M:6XL("1M87@L("1E>&-L=61E(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("`D<B`]("8D=&AI<RT^7V=E=$-U<G)E;G1296QE87-E*"D[#0H@("`@
M("`@(&EF("@D<B`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[
M#0H@("`@("`@(&EF("AI<W-E="@D<ELG:6YS=&%L;&-O;F1I=&EO;G,G75LG
M<&AP)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D<ELG:6YS=&%L;&-O;F1I
M=&EO;G,G75LG<&AP)UTI.PT*("`@("`@("!]#0H@("`@("`@("1D97`@/2!A
M<G)A>2@G;6EN)R`]/B`D;6EN+"`G;6%X)R`]/B`D;6%X*3L-"B`@("`@("`@
M:68@*"1E>&-L=61E*2![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)&5X
M8VQU9&4I("8F(&-O=6YT*"1E>&-L=61E*2`]/2`Q*2![#0H@("`@("`@("`@
M("`@("`@)&5X8VQU9&4@/2`D97AC;'5D95LP73L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`]("1E>&-L=61E.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`]
M/2`G97AT<W)C)RD@>PT*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7VUE<F=E
M5&%G*"1R+"`D9&5P+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G:6YS=&%L;&-O;F1I=&EO;G,G(#T^(&%R<F%Y*"=C
M;VYF:6=U<F5O<'1I;VXG+"`G8FEN87)Y<&%C:V%G92<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@("`@
M("`@)W!H<"<@/3X@87)R87DH)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H)RD-
M"B`@("`@("`@("`@("`@("`I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D<BP@)&1E<"P-"B`@("`@
M("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN<W1A
M;&QC;VYD:71I;VYS)R`]/B!A<G)A>2@G9FEL96QI<W0G*2P-"B`@("`@("`@
M("`@("`@("`@("`@)W!H<"<@/3X@87)R87DH)V5X=&5N<VEO;B<L("=O<R<L
M("=A<F-H)RD-"B`@("`@("`@("`@("`@("`I*3L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O<'1I;VYA;'QR97%U:7)E
M9"!O<'1I;VYA;"P@<F5Q=6ER960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&5X
M=&5N<VEO;B!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M('9E
M<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R<VEO;@T*
M("`@("`J($!P87)A;2!S=')I;F<@<F5C;VUM96YD960@=F5R<VEO;@T*("`@
M("`J($!P87)A;2!A<G)A>2!I;F-O;7!A=&EB;&4@=F5R<VEO;G,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&1%>'1E;G-I;VY);G-T86QL0V]N9&ET:6]N
M*"1N86UE+"`D;6EN(#T@9F%L<V4L("1M87@@/2!F86QS92P@)')E8V]M;65N
M9&5D(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97AC;'5D92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I
M9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@
M("`@("`D9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L(&9A;'-E
M+"!F86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92D[
M#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`]/2`G97AT
M<W)C)RD@>PT*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7VUE<F=E5&%G*"1R
M+"`D9&5P+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G:6YS=&%L;&-O;F1I=&EO;G,G(#T^(&%R<F%Y*"=C;VYF:6=U
M<F5O<'1I;VXG+"`G8FEN87)Y<&%C:V%G92<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@("`@("`@)V5X
M=&5N<VEO;B<@/3X@87)R87DH)V]S)RP@)V%R8V@G*0T*("`@("`@("`@("`@
M("`@("DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'(@/2`D
M=&AI<RT^7VUE<F=E5&%G*"1R+"`D9&5P+`T*("`@("`@("`@("`@("`@(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G:6YS=&%L;&-O;F1I=&EO;G,G
M(#T^(&%R<F%Y*"=F:6QE;&ES="<I+`T*("`@("`@("`@("`@("`@("`@("`G
M97AT96YS:6]N)R`]/B!A<G)A>2@G;W,G+"`G87)C:"<I#0H@("`@("`@("`@
M("`@("`@*2D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!3970@86X@:6YS=&%L;&%T:6]N(&-O;F1I=&EO;B!B87-E9"!O;B!O<&5R
M871I;F<@<WES=&5M(&9O<B!T:&4@8W5R<F5N="!R96QE87-E('-E=`T*("`@
M("`J($!P87)A;2!S=')I;F<@3U,@;F%M90T*("`@("`J($!P87)A;2!B;V]L
M('=H971H97(@=&AI<R!/4R!I<R!I;F-O;7!A=&EB;&4@=VET:"!T:&4@8W5R
M<F5N="!R96QE87-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T3W-);G-T
M86QL0V]N9&ET:6]N*"1N86UE+"`D8V]N9FQI8W1S(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("`D<B`]("8D=&AI<RT^7V=E=$-U<G)E;G1296QE87-E*"D[
M#0H@("`@("`@(&EF("@D<B`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI
M9"`](#`[#0H@("`@("`@(&EF("AI<W-E="@D<ELG:6YS=&%L;&-O;F1I=&EO
M;G,G75LG;W,G72DI('L-"B`@("`@("`@("`@('5N<V5T*"1R6R=I;G-T86QL
M8V]N9&ET:6]N<R==6R=O<R==*3L-"B`@("`@("`@?0T*("`@("`@("`D9&5P
M(#T@87)R87DH)VYA;64G(#T^("1N86UE*3L-"B`@("`@("`@:68@*"1C;VYF
M;&EC=',I('L-"B`@("`@("`@("`@("1D97!;)V-O;F9L:6-T<R==(#T@)R<[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K86=E5'EP
M92@I(#T]("=E>'1S<F,G*2![#0H@("`@("`@("`@("`D<B`]("1T:&ES+3Y?
M;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET:6]N<R<@/3X@87)R
M87DH)V-O;F9I9W5R96]P=&EO;B<L("=B:6YA<GEP86-K86=E)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=F:6QE;&ES="<I+`T*("`@("`@("`@("`@
M("`@("`@("`G;W,G(#T^(&%R<F%Y*"=A<F-H)RD-"B`@("`@("`@("`@("`@
M("`I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R(#T@)'1H
M:7,M/E]M97)G951A9R@D<BP@)&1E<"P-"B`@("`@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]
M/B!A<G)A>2@G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@("`@("`@)V]S
M)R`]/B!A<G)A>2@G87)C:"<I#0H@("`@("`@("`@("`@("`@*2D[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3970@86X@:6YS=&%L
M;&%T:6]N(&-O;F1I=&EO;B!B87-E9"!O;B!A<F-H:71E8W1U<F4@9F]R('1H
M92!C=7)R96YT(')E;&5A<V4@<V5T#0H@("`@("H@0'!A<F%M('-T<FEN9R!A
M<F-H:71E8W1U<F4@<&%T=&5R;@T*("`@("`J($!P87)A;2!B;V]L('=H971H
M97(@=&AI<R!A<F-H(&ES(&EN8V]M<&%T:6)L92!W:71H('1H92!C=7)R96YT
M(')E;&5A<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971!<F-H26YS=&%L
M;$-O;F1I=&EO;B@D<&%T=&5R;BP@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I
M.PT*("`@("`@("!I9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2`P.PT*("`@("`@("!I9B`H:7-S970H)');)VEN<W1A;&QC;VYD:71I
M;VYS)UU;)V%R8V@G72DI('L-"B`@("`@("`@("`@('5N<V5T*"1R6R=I;G-T
M86QL8V]N9&ET:6]N<R==6R=A<F-H)UTI.PT*("`@("`@("!]#0H@("`@("`@
M("1D97`@/2!A<G)A>2@G<&%T=&5R;B<@/3X@)'!A='1E<FXI.PT*("`@("`@
M("!I9B`H)&-O;F9L:6-T<RD@>PT*("`@("`@("`@("`@)&1E<%LG8V]N9FQI
M8W1S)UT@/2`G)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/F=E
M=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R8R<I('L-"B`@("`@("`@("`@("1R
M(#T@)'1H:7,M/E]M97)G951A9R@D<BP@)&1E<"P-"B`@("`@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN<W1A;&QC;VYD:71I
M;VYS)R`]/B!A<G)A>2@G8V]N9FEG=7)E;W!T:6]N)RP@)V)I;F%R>7!A8VMA
M9V4G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&5L:7-T)RDL#0H@
M("`@("`@("`@("`@("`@("`@("=A<F-H)R`]/B!A<G)A>2@I#0H@("`@("`@
M("`@("`@("`@*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M<B`]("1T:&ES+3Y?;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@("`@
M("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET
M:6]N<R<@/3X@87)R87DH)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@
M("`@("=A<F-H)R`]/B!A<G)A>2@I#0H@("`@("`@("`@("`@("`@*2D[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@97AT96YS
M:6]N(&)I;F%R>2!R96QE87-E<RP@=&AI<R!I<R!U<V5D('1O('-P96-I9GD@
M96ET:&5R('1H90T*("`@("`J('-T871I8R!54DD@=&\@82!S;W5R8V4@<&%C
M:V%G92P@;W(@=&AE('!A8VMA9V4@;F%M92!A;F0@8VAA;FYE;"!O9B!T:&4@
M97AT<W)C#0H@("`@("H@<&%C:V%G92!I="!I<R!B87-E9"!O;BX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(%!A8VMA9V4@;F%M92P@;W(@9G5L;"!54DD@=&\@
M<V]U<F-E('!A8VMA9V4@*&5X='-R8R!T>7!E*0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=%-O=7)C95!A8VMA9V4H)'!A8VMA9V5/<E5R:2D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N;F5L)UTI*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"
M969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP@87)R87DH)W!H<')E;&5A<V4G
M+`T*("`@("`@("`@("`@("`@("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E
M;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@("`@("`@("`@
M("`@("1P86-K86=E3W)5<FDL("=S<F-P86-K86=E)RD[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H
M:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP@87)R87DH
M)W!H<')E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1S<F-R96QE87-E
M)RP@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+"`D
M<&%C:V%G94]R57)I+"`G<W)C=7)I)RD[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!'96YE<F%T92!A('9A;&ED(&-H86YG92!L;V<@
M96YT<GD@9G)O;2!T:&4@8W5R<F5N="!P86-K86=E+GAM;`T*("`@("`J($!P
M87)A;2!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G96YE
M<F%T94-H86YG94QO9T5N=')Y*"1N;W1E<R`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@("`@("`@)W9E<G-I;VXG(#T^
M(`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<F5L96%S92<@/3X@)'1H:7,M/F=E=%9E<G-I;VXH)W)E;&5A<V4G*2P-
M"B`@("`@("`@("`@("`@("`@("`@)V%P:2<@/3X@)'1H:7,M/F=E=%9E<G-I
M;VXH)V%P:2<I+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@)W-T86)I;&ET>2<@/3X-"B`@("`@("`@("`@("`@("`D=&AI<RT^9V5T
M4W1A8FEL:71Y*"DL#0H@("`@("`@("`@("`G9&%T92<@/3X@)'1H:7,M/F=E
M=$1A=&4H*2P-"B`@("`@("`@("`@("=L:6-E;G-E)R`]/B`D=&AI<RT^9V5T
M3&EC96YS92AT<G5E*2P-"B`@("`@("`@("`@("=N;W1E<R<@/3X@)&YO=&5S
M(#\@)&YO=&5S(#H@)'1H:7,M/F=E=$YO=&5S*"D-"B`@("`@("`@("`@("D[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96QE
M87-E('9E<G-I;VX@=&\@<V5T(&-H86YG92!L;V<@;F]T97,@9F]R#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&]U='!U="!O9B![0&QI;FL@9V5N97)A=&5#:&%N
M9V5,;V=%;G1R>2@I?0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$-H86YG
M96QO9T5N=')Y*"1R96QE87-E=F5R<VEO;BP@)&-O;G1E;G1S*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-H86YG96QO9R==6R=R96QE87-E)UT@/2`D8V]N=&5N=',[#0H@("`@("`@
M("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==6S!=
M*2D@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H
M86YG96QO9R==6R=R96QE87-E)UU;)W9E<G-I;VXG75LG<F5L96%S92==(#T]
M("1R96QE87-E=F5R<VEO;BD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E)UT@/2!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8VAA
M;F=E;&]G)UU;)W)E;&5A<V4G72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO
M9R==6R=R96QE87-E)UT@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UU;)W)E;&5A<V4G72D[
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-H86YG96QO9R==6R=R96QE87-E)UU;72`]("1C;VYT96YT<SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E)UT@87,@)&EN9&5X
M(#T^("1C:&%N9V5L;V<I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D8VAA
M;F=E;&]G6R=V97)S:6]N)UTI("8F#0H@("`@("`@("`@("`@("`@("!S=')N
M871C87-E8VUP*"1C:&%N9V5L;V=;)W9E<G-I;VXG75LG<F5L96%S92==+"`D
M<F5L96%S979E<G-I;VXI(#T](#`I('L-"B`@("`@("`@("`@("`@("`D8W5R
M;&]G(#T@)&EN9&5X.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D8W5R;&]G*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UU;)W)E;&5A<V4G75LD8W5R;&]G
M72`]("1C;VYT96YT<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E)UU;
M72`]("1C;VYT96YT<SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%)E;6]V92!T:&4@8VAA;F=E;&]G(&5N=&ER96QY#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@8VQE87)#:&%N9V5,;V<H*0T*("`@('L-"B`@("`@
M("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UTI.PT*
M("`@('T-"GT-"C\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8R+U9A;&ED871O
M<BYP:'`````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(S-C4V-P`Q,#4Q-30S,3`U-P`P
M,C,R,S,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\O#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-
M"B\O('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`T*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R.B!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z(%9A
M;&ED871O<BYP:'`L=B`Q+C@V(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G
M($5X<"`D#0HO*BH-"B`J(%!R:79A=&4@=F%L:61A=&EO;B!C;&%S<R!U<V5D
M(&)Y(%!%05)?4&%C:V%G949I;&5?=C(@+2!D;R!N;W0@=7-E(&1I<F5C=&QY
M+"!I=',-"B`J('-O;&4@<'5R<&]S92!I<R!T;R!S<&QI="!U<"!T:&4@4$5!
M4B]086-K86=E1FEL92]V,BYP:'`@9FEL92!T;R!M86ME(&ET('-M86QL97(-
M"B`J($!A=71H;W(@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&%C8V5S<R!P<FEV871E#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?
M=C)?5F%L:61A=&]R#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!A<G)A>0T*
M("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5);F9O.PT*("`@("\J*@T*("`@
M("`J($!V87(@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J+PT*("`@('9A
M<B`D7W!F.PT*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]%<G)O<E-T86-K
M#0H@("`@("HO#0H@("`@=F%R("1?<W1A8VL[#0H@("`@+RHJ#0H@("`@("H@
M0'9A<B!I;G0-"B`@("`@*B\-"B`@("!V87(@)%]I<U9A;&ED(#T@,#L-"B`@
M("`O*BH-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J+PT*("`@('9A<B`D7V9I
M;&5S5F%L:60@/2`P.PT*("`@("\J*@T*("`@("`J($!V87(@:6YT#0H@("`@
M("HO#0H@("`@=F%R("1?8W5R4W1A=&4@/2`P.PT*("`@("\J*@T*("`@("`J
M($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M(&EN
M=`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E*"8D<&8L("1S=&%T
M92`](%!%05)?5D%,241!5$5?3D]234%,*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]P9B`]("8D<&8[#0H@("`@("`@("1T:&ES+3Y?8W5R4W1A=&4@/2`D
M<W1A=&4[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^
M7W!F+3YG971!<G)A>2@I.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`D
M=&AI<RT^7W!F+3Y?:7-686QI9#L-"B`@("`@("`@)'1H:7,M/E]F:6QE<U9A
M;&ED(#T@)'1H:7,M/E]P9BT^7V9I;&5S5F%L:60[#0H@("`@("`@("1T:&ES
M+3Y?<W1A8VL@/2`F)'!F+3Y?<W1A8VL[#0H@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/F=E=$5R<F]R<RAT<G5E*3L-"B`@("`@("`@:68@*"@D=&AI<RT^7VES
M5F%L:60@)B`D<W1A=&4I(#T]("1S=&%T92D@>PT*("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O*2!\?"`A:7-?87)R87DH)'1H:7,M/E]P86-K86=E
M26YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V%T
M=')I8G,G75LG=F5R<VEO;B==*2!\?`T*("`@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=A='1R:6)S)UU;)W9E<G-I;VXG72`A/2`G,BXP)RD@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]N;U!A8VMA9V5697)S:6]N*"D[#0H@
M("`@("`@('T-"B`@("`@("`@)'-T<G5C='5R92`]#0H@("`@("`@(&%R<F%Y
M*`T*("`@("`@("`@("`@)VYA;64G+`T*("`@("`@("`@("`@)V-H86YN96Q\
M=7)I)RP-"B`@("`@("`@("`@("<J97AT96YD<R<L("\O(&-A;B=T(&)E(&UU
M;'1I<&QE+"!B=70@=&AI<R!W;W)K<R!F:6YE#0H@("`@("`@("`@("`G<W5M
M;6%R>2<L#0H@("`@("`@("`@("`G9&5S8W)I<'1I;VXG+`T*("`@("`@("`@
M("`@)RML96%D)RP@+R\@=&AE<V4@86QL(&YE960@8V]N=&5N="!C:&5C:W,-
M"B`@("`@("`@("`@("<J9&5V96QO<&5R)RP-"B`@("`@("`@("`@("<J8V]N
M=')I8G5T;W(G+`T*("`@("`@("`@("`@)RIH96QP97(G+`T*("`@("`@("`@
M("`@)V1A=&4G+`T*("`@("`@("`@("`@)RIT:6UE)RP-"B`@("`@("`@("`@
M("=V97)S:6]N)RP-"B`@("`@("`@("`@("=S=&%B:6QI='DG+`T*("`@("`@
M("`@("`@)VQI8V5N<V4M/C]U<FDM/C]F:6QE<V]U<F-E)RP-"B`@("`@("`@
M("`@("=N;W1E<R<L#0H@("`@("`@("`@("`G8V]N=&5N=',G+"`O+W-P96-I
M86P@=F%L:61A=&EO;B!N965D960-"B`@("`@("`@("`@("<J8V]M<&%T:6)L
M92<L#0H@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@+R]S<&5C:6%L('9A
M;&ED871I;VX@;F5E9&5D#0H@("`@("`@("`@("`G*G5S97-R;VQE)RP-"B`@
M("`@("`@("`@("<J=7-E<W1A<VLG+"`O+R!R97-E<G9E('1H97-E(&9O<B`Q
M+C0N,&$Q('1O(&EM<&QE;65N=`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("\O('1H:7,@=VEL;"!A;&QO=R!A('!A8VMA9V4N>&UL('1O(&=R86-E9G5L
M;'D@<V%Y(&ET#0H@("`@("`@("`@("`@("`@("`@("`@("`@+R\@;F5E9',@
M82!C97)T86EN('!A8VMA9V4@:6YS=&%L;&5D(&EN(&]R9&5R('1O(&EM<&QE
M;65N="!A(')O;&4@;W(@=&%S:PT*("`@("`@("`@("`@)RIP<F]V:61E<V5X
M=&5N<VEO;B<L#0H@("`@("`@("`@("`G*G-R8W!A8VMA9V5\*G-R8W5R:2<L
M#0H@("`@("`@("`@("`G*W!H<')E;&5A<V5\*V5X='-R8W)E;&5A<V5\*V5X
M=&)I;G)E;&5A<V5\8G5N9&QE)RP@+R]S<&5C:6%L('9A;&ED871I;VX@;F5E
M9&5D#0H@("`@("`@("`@("`G*F-H86YG96QO9R<L#0H@("`@("`@("D[#0H@
M("`@("`@("1T97-T(#T@)'1H:7,M/E]P86-K86=E26YF;SL-"B`@("`@("`@
M+R\@:6=N;W)E('!O<W0M:6YS=&%L;&%T:6]N(&%R<F%Y(&9I96QD<PT*("`@
M("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G9FEL96QI<W0G+"`D=&5S="DI
M('L-"B`@("`@("`@("`@('5N<V5T*"1T97-T6R=F:6QE;&ES="==*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G7VQA<W1M
M;V1I9FEE9"<L("1T97-T*2D@>PT*("`@("`@("`@("`@=6YS970H)'1E<W1;
M)U]L87-T;6]D:69I960G72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H)R-B:6YA<GEP86-K86=E)RP@)'1E<W0I*2![#0H@
M("`@("`@("`@("!U;G-E="@D=&5S=%LG(V)I;F%R>7!A8VMA9V4G72D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V]L9"<L
M("1T97-T*2D@>PT*("`@("`@("`@("`@=6YS970H)'1E<W1;)V]L9"==*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G7VQA
M<W1V97)S:6]N)RP@)'1E<W0I*2![#0H@("`@("`@("`@("!U;G-E="@D=&5S
M=%LG7VQA<W1V97)S:6]N)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1E<W0L
M("<\<&%C:V%G93XG*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A;FYO
M=$)E16UP='DH)VYA;64G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG=7)I)UTI*2![#0H@("`@("`@("`@
M("`D=&5S="`]("=U<FDG.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'1E<W0@/2`G8VAA;FYE;"<[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)'1E<W1=*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]T86=#86YN;W1"945M<'1Y*"1T97-T*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]P86-K86=E26YF
M;ULG;&EC96YS92==*2`F)@T*("`@("`@("`@("`@("`H(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G75LG7V-O;G1E;G0G72D@?'P-"B`@
M("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS
M92==6R=?8V]N=&5N="==*2DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=&%G
M0V%N;F]T0F5%;7!T>2@G;&EC96YS92<I.PT*("`@("`@("!](&5L<V5I9B`H
M96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"945M<'1Y*"=L:6-E;G-E)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W-U;6UA<GDG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=&%G
M0V%N;F]T0F5%;7!T>2@G<W5M;6%R>2<I.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97-C<FEP=&EO;B==
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"945M<'1Y*"=D
M97-C<FEP=&EO;B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=D871E)UTI*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7W1A9T-A;FYO=$)E16UP='DH)V1A=&4G*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG;F]T97,G
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@G
M;F]T97,G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG=&EM92==*2`F)B!E;7!T>2@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=T:6UE)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A
M;FYO=$)E16UP='DH)W1I;64G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1&5P96YD96YC:65S*"D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;7!A=&EB;&4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5#;VUP871I8FQE*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N
M=&5N=',G75LG9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F
M:6QE;&ES=$UU<W1#;VYT86EN1&ER*"=C;VYT96YT<R<I.PT*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==
M6R=F:6QE)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F:6QE;&ES
M=$-A;FYO=$-O;G1A:6Y&:6QE*"=C;VYT96YT<R<I.PT*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7W9A;&ED871E36%I;G1A:6YE<G,H*3L-"B`@("`@
M("`@)'1H:7,M/E]V86QI9&%T95-T86)I;&ET>59E<G-I;VXH*3L-"B`@("`@
M("`@)&9A:6P@/2!F86QS93L-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)W5S97-R;VQE)RP@)'1H:7,M/E]P86-K86=E26YF;RDI('L-"B`@("`@
M("`@("`@("1R;VQE<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-R;VQE
M)UT[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R;VQE<RD@?'P@(6ES
M<V5T*"1R;VQE<ULP72DI('L-"B`@("`@("`@("`@("`@("`D<F]L97,@/2!A
M<G)A>2@D<F]L97,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R
M96%C:"`H)')O;&5S(&%S("1R;VQE*2![#0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<F]L95LG<F]L92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W5S97-R;VQE=&%S:TUU<W1(879E4F]L951A<VLH)W5S97-R
M;VQE)RP@)W)O;&4G*3L-"B`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)')O;&5;)V-H86YN96PG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')O;&5;)W5R:2==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<W)O
M;&5T87-K375S=$AA=F5#:&%N;F5L3W)5<FDH)')O;&5;)W)O;&4G72P@)W5S
M97-R;VQE)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6P@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1R;VQE6R=P86-K86=E)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R;VQE
M=&%S:TUU<W1(879E4&%C:V%G92@D<F]L95LG<F]L92==+"`G=7-E<W)O;&4G
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H87)R87E?:V5Y7V5X
M:7-T<R@G=7-E<W1A<VLG+"`D=&AI<RT^7W!A8VMA9V5);F9O*2D@>PT*("`@
M("`@("`@("`@)')O;&5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W1A
M<VLG73L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')O;&5S*2!\?"`A
M:7-S970H)')O;&5S6S!=*2D@>PT*("`@("`@("`@("`@("`@("1R;VQE<R`]
M(&%R<F%Y*"1R;VQE<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M;W)E86-H("@D<F]L97,@87,@)')O;&4I('L-"B`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1R;VQE6R=T87-K)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=7-E<W)O;&5T87-K375S=$AA=F52;VQE5&%S:R@G=7-E
M<W1A<VLG+"`G=&%S:R<I.PT*("`@("`@("`@("`@("`@("`@("`D9F%I;"`]
M('1R=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<F]L95LG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F]L95LG=7)I)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5S
M<F]L971A<VM-=7-T2&%V94-H86YN96Q/<E5R:2@D<F]L95LG=&%S:R==+"`G
M=7-E<W1A<VLG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F%I
M;"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("@A:7-S970H)')O;&5;)W!A8VMA9V4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<W)O
M;&5T87-K375S=$AA=F5086-K86=E*"1R;VQE6R=T87-K)UTL("=U<V5S=&%S
M:R<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D9F%I;"D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?=F%L:61A=&5&:6QE;&ES="@I.PT*("`@("`@("`D=&AI<RT^
M7W9A;&ED871E4F5L96%S92@I.PT*("`@("`@("!I9B`H(21T:&ES+3Y?<W1A
M8VLM/FAA<T5R<F]R<R@I*2![#0H@("`@("`@("`@("`D8VAA;B`]("1T:&ES
M+3Y?<&8M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D=&AI<RT^7W!F+3YG971#
M:&%N;F5L*"DL('1R=64I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]U;FMN;W=N
M0VAA;FYE;"@D=&AI<RT^7W!F+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=F%L<&%C:R`]("1C:&%N
M+3YG971686QI9&%T:6]N4&%C:V%G92@I.PT*("`@("`@("`@("`@("`@("\O
M(&9O<B!C:&%N;F5L('9A;&ED871O<B!P86-K86=E<RP@86QW87ES('5S92!T
M:&4@9&5F875L="!014%2('9A;&ED871O<BX-"B`@("`@("`@("`@("`@("`O
M+R!O=&AE<G=I<V4L('1H97D@8V%N)W0@8F4@:6YS=&%L;&5D(&]R('!A8VMA
M9V5D#0H@("`@("`@("`@("`@("`@)'9A;&ED871O<B`]("1C:&%N+3YG9716
M86QI9&%T:6]N3V)J96-T*"1T:&ES+3Y?<&8M/F=E=%!A8VMA9V4H*2D[#0H@
M("`@("`@("`@("`@("`@:68@*"$D=F%L:61A=&]R*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?;65R9V4H
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG
M(#T^("1C:&%N+3YG971.86UE*"DL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1T:&ES+3Y?<&8M/F=E=%!A8VMA
M9V4H*2DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L<&%C
M:PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%C:V%G92`B)6-H86YN96PE+R5P86-K86=E)2(@
M8V%N;F]T(&)E('!R;W!E<FQY('9A;&ED871E9"!W:71H;W5T("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)W9A;&ED871I;VX@<&%C:V%G92`B)6-H
M86YN96PE+R5N86UE)2TE=F5R<VEO;B4B)RD[#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=F%L:61A=&]R+3YS971086-K86=E
M1FEL92@D=&AI<RT^7W!F*3L-"B`@("`@("`@("`@("`@("`D=F%L:61A=&]R
M+3YV86QI9&%T92@D<W1A=&4I.PT*("`@("`@("`@("`@("`@("1F86EL=7)E
M<R`]("1V86QI9&%T;W(M/F=E=$9A:6QU<F5S*"D[#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&9A:6QU<F5S6R=E<G)O<G,G72!A<R`D97)R;W(I('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=E<G)O<B<L("1E<G)O<BP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=#:&%N;F5L('9A;&ED871O<B!E<G)O<CH@9FEE;&0@(B5F:65L
M9"4B("T@)7)E87-O;B4G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&9A:6QU<F5S6R=W87)N:6YG<R==(&%S("1W
M87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L("1W87)N:6YG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)T-H86YN96P@=F%L:61A=&]R('=A<FYI
M;F<Z(&9I96QD("(E9FEE;&0E(B`M("5R96%S;VXE)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?<&8M/E]I<U9A;&ED(#T@)'1H:7,M/E]I<U9A;&ED(#T@(21T:&ES
M+3Y?<W1A8VLM/FAA<T5R<F]R<R@G97)R;W(G*3L-"B`@("`@("`@:68@*"1T
M:&ES+3Y?:7-686QI9"`F)B`D<W1A=&4@/3T@4$5!4E]604Q)1$%415]004-+
M04=)3D<@)B8@(21T:&ES+3Y?9FEL97-686QI9"D@>PT*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?<&8M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V)U;F1L92<I
M('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]A;F%L>7IE0G5N9&QE
M9%!A8VMA9V5S*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]F
M:6QE<U9A;&ED(#T@)'1H:7,M/E]P9BT^7V9I;&5S5F%L:60@/2!T<G5E.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&8M/E]I<U9A;&ED(#T@)'1H:7,M/E]I<U9A;&ED(#T@,#L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]A;F%L>7IE4&AP1FEL97,H*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!F+3Y?:7-686QI9"`]
M("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]F:6QE<U9A;&ED(#T@
M)'1H:7,M/E]P9BT^7V9I;&5S5F%L:60@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P9BT^7VES5F%L:60@/2`D=&AI<RT^7VES5F%L:60@/2`D<W1A=&4[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&8M/E]I<U9A;&ED
M(#T@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P@)'AM;"P@)')O
M;W0I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1X;6PI*2![#0H@
M("`@("`@("`@("`D>&UL(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@
M("`D:V5Y<R`](&%R<F%Y7VME>7,H)'AM;"D[#0H@("`@("`@(')E<V5T*"1K
M97ES*3L-"B`@("`@("`@)&ME>2`](&-U<G)E;G0H)&ME>7,I.PT*("`@("`@
M("!W:&EL92`H)&ME>2`]/2`G871T<FEB<R<@?'P@)&ME>2`]/2`G7V-O;G1E
M;G1S)RD@>PT*("`@("`@("`@("`@)&ME>2`](&YE>'0H)&ME>7,I.PT*("`@
M("`@("!]#0H@("`@("`@("1U;F9O=6YD=&%G<R`]("1O<'1I;VYA;'1A9W,@
M/2!A<G)A>2@I.PT*("`@("`@("`D<F5T(#T@=')U93L-"B`@("`@("`@)&UI
M<VUA=&-H(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*"1S=')U8W1U<F4@
M87,@)'-T<G5C*2![#0H@("`@("`@("`@("!I9B`H)&ME>2D@>PT*("`@("`@
M("`@("`@("`@("1T86<@/2`D>&UL6R1K97E=.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'1E<W0@/2`D=&AI<RT^7W!R;V-E<W-3=')U8W1U<F4H
M)'-T<G5C*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&5S=%LG8VAO:6-E
M<R==*2D@>PT*("`@("`@("`@("`@("`@("1L;V]S92`]('1R=64[#0H@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'1E<W1;)V-H;VEC97,G72!A<R`D8VAO
M:6-E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D:V5Y(#T]("1C:&]I
M8V5;)W1A9R==*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@
M;F5X="@D:V5Y<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!W:&EL92`H
M)&ME>2`]/2`G871T<FEB<R<@?'P@)&ME>2`]/2`G7V-O;G1E;G1S)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1K97D@/2!N97AT*"1K97ES
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1U;F9O=6YD=&%G<R`]("1O<'1I;VYA;'1A9W,@/2!A<G)A
M>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&UI<VUA=&-H(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&ME>2`F)B`D:V5Y
M("$]("1C:&]I8V5;)W1A9R==("8F(&ES<V5T*"1C:&]I8V5;)VUU;'1I<&QE
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5N9F]U;F1T
M86=S6UT@/2`D8VAO:6-E6R=T86<G73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;W!T:6]N86QT86=S6UT@/2`D8VAO:6-E6R=T86<G73L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&ME>2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;6ES;6%T8V@@/2!T<G5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1R970@)CT@
M)'1H:7,M/E]P<F]C97-S071T<FEB<R@D8VAO:6-E+"`D=&%G+"`D<F]O="D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'5N9F]U;F1T86=S6UT@/2`D8VAO:6-E6R=T86<G73L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1M:7-M871C:"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M8VAO:6-E6R=M=6QT:7!L92==*2!\?"`D8VAO:6-E6R=M=6QT:7!L92==("$]
M("<J)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&QO;W-E(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D;W!T:6]N86QT86=S6UT@/2`D8VAO:6-E6R=T86<G
M73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H(21L;V]S92D@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@D=6YF;W5N9'1A9W,L
M("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@:68@*"1K97D@(3T@)'1E<W1;)W1A9R==*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&5S=%LG;75L=&EP
M;&4G72D@)B8@)'1E<W1;)VUU;'1I<&QE)UT@(3T@)RHG*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D=6YF;W5N9'1A9W-;72`]("1T97-T6R=T86<G
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%1A
M9T]R9&5R*"1U;F9O=6YD=&%G<RP@)&ME>2P@)')O;W0I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1K
M97DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6ES;6%T8V@@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'5N9F]U;F1T86=S6UT@/2`D=&5S=%LG=&%G)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N86QT86=S6UT@/2`D
M=&5S=%LG=&%G)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&5S=%LG;75L=&EP;&4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%1A9T]R
M9&5R*"1U;F9O=6YD=&%G<RP@)&ME>2P@)')O;W0I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1U;F9O=6YD
M=&%G<R`]("1O<'1I;VYA;'1A9W,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@
M("`@("`@("`D;6ES;6%T8V@@/2!F86QS93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&ME>2`](&YE>'0H)&ME>7,I.PT*("`@("`@
M("`@("`@("`@('=H:6QE("@D:V5Y(#T]("=A='1R:6)S)R!\?"`D:V5Y(#T]
M("=?8V]N=&5N=',G*2![#0H@("`@("`@("`@("`@("`@("`@("1K97D@/2!N
M97AT*"1K97ES*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*"1K97D@)B8@)&ME>2`A/2`D=&5S=%LG=&%G)UT@)B8@:7-S970H
M)'1E<W1;)VUU;'1I<&QE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1U
M;F9O=6YD=&%G<UM=(#T@)'1E<W1;)W1A9R==.PT*("`@("`@("`@("`@("`@
M("`@("`D;W!T:6]N86QT86=S6UT@/2`D=&5S=%LG=&%G)UT[#0H@("`@("`@
M("`@("`@("`@("`@("1M:7-M871C:"`]('1R=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1R970@)CT@)'1H:7,M/E]P<F]C97-S
M071T<FEB<R@D=&5S="P@)'1A9RP@)')O;W0I.PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@A)&UI<VUA=&-H("8F(&-O=6YT*"1O<'1I;VYA;'1A9W,I*2![#0H@
M("`@("`@("`@("`O+R!D;VXG="!E<G)O<B!O=70@;VX@86YY(&]P=&EO;F%L
M('1A9W,-"B`@("`@("`@("`@("1U;F9O=6YD=&%G<R`](&%R<F%Y7V1I9F8H
M)'5N9F]U;F1T86=S+"`D;W!T:6]N86QT86=S*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H8V]U;G0H)'5N9F]U;F1T86=S*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]I;G9A;&ED5&%G3W)D97(H)'5N9F]U;F1T86=S+"`D:V5Y+"`D
M<F]O="D[#0H@("`@("`@('T@96QS96EF("@D:V5Y*2![#0H@("`@("`@("`@
M("`O+R!U;FMN;W=N('1A9W,-"B`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI
M9%1A9T]R9&5R*"<J;F\@=&%G<R!A;&QO=V5D(&AE<F4J)RP@)&ME>2P@)')O
M;W0I.PT*("`@("`@("`@("`@=VAI;&4@*"1K97D@/2!N97AT*"1K97ES*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%1A9T]R9&5R*"<J
M;F\@=&%G<R!A;&QO=V5D(&AE<F4J)RP@)&ME>2P@)')O;W0I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]P<F]C97-S071T<FEB<R@D8VAO:6-E+"`D
M=&%G+"`D8V]N=&5X="D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D8VAO
M:6-E6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1T86<I*2![#0H@("`@("`@("`@("`@("`@)'1A9R`](&%R<F%Y*"1T86<I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1A9W,@/2`D=&%G.PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&%G<ULP72DI('L-"B`@("`@("`@
M("`@("`@("`D=&%G<R`](&%R<F%Y*"1T86=S*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1R970@/2!T<G5E.PT*("`@("`@("`@("`@9F]R96%C
M:"`H)'1A9W,@87,@)&D@/3X@)'1A9RD@>PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-?87)R87DH)'1A9RD@?'P@(6ES<V5T*"1T86=;)V%T=')I8G,G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&-H;VEC95LG871T
M<FEB<R==(&%S("1A='1R:6(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D871T<FEB>S!]("$]("<_)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R970@)CT@)'1H:7,M/E]T86=(87-.;T%T=')I8G,H)&-H
M;VEC95LG=&%G)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C;VYT97AT*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU92`R.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1C:&]I8V5;)V%T=')I8G,G72!A<R`D871T<FEB*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D871T<FEB>S!]("$]("<_)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&%G6R=A
M='1R:6)S)UU;)&%T=')I8ETI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E="`F/2`D=&AI<RT^7W1A9TUI<W-I;F=!='1R:6)U=&4H)&-H
M;VEC95LG=&%G)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1A='1R:6(L("1C;VYT97AT*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]P<F]C97-S4W1R=6-T=7)E*"1K97DI#0H@("`@>PT*("`@("`@
M("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@:68@*&-O=6YT*"1P:65C97,@
M/2!E>'!L;V1E*"=\)RP@)&ME>2DI(#X@,2D@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)'!I96-E<R!A<R`D<&EE8V4I('L-"B`@("`@("`@("`@("`@("`D
M<F5T6R=C:&]I8V5S)UU;72`]("1T:&ES+3Y?<')O8V5S<U-T<G5C='5R92@D
M<&EE8V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1R
M970[#0H@("`@("`@('T-"B`@("`@("`@)&UU;'1I(#T@)&ME>7LP?3L-"B`@
M("`@("`@:68@*"1M=6QT:2`]/2`G*R<@?'P@)&UU;'1I(#T]("<J)RD@>PT*
M("`@("`@("`@("`@)')E=%LG;75L=&EP;&4G72`]("1K97E[,'T[#0H@("`@
M("`@("`@("`D:V5Y(#T@<W5B<W1R*"1K97DL(#$I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AC;W5N="@D871T<G,@/2!E>'!L;V1E*"<M/B<L("1K97DI
M*2`^(#$I('L-"B`@("`@("`@("`@("1R971;)W1A9R==(#T@87)R87E?<VAI
M9G0H)&%T=')S*3L-"B`@("`@("`@("`@("1R971;)V%T=')I8G,G72`]("1A
M='1R<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R971;)W1A
M9R==(#T@)&ME>3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&53=&%B:6QI='E697)S
M:6]N*"D-"B`@("![#0H@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@G<F5L
M96%S92<L("=A<&DG*3L-"B`@("`@("`@)&$@/2`D=&AI<RT^7W-T=7!I9%-C
M:&5M859A;&ED871E*"1S=')U8W1U<F4L("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W9E<G-I;VXG72P@)SQV97)S:6]N/B<I.PT*("`@("`@("`D82`F/2`D=&AI
M<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L("1T:&ES+3Y?
M<&%C:V%G94EN9F];)W-T86)I;&ET>2==+"`G/'-T86)I;&ET>3XG*3L-"B`@
M("`@("`@:68@*"1A*2![#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H
M)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==6R=R
M96QE87-E)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED
M5F5R<VEO;B@G<F5L96%S92<L("1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I
M;VXG75LG<F5L96%S92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK
M7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=V97)S:6]N)UU;)V%P:2==*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6YV86QI9%9E<G-I;VXH)V%P:2<L("1T:&ES+3Y?<&%C:V%G94EN
M9F];)W9E<G-I;VXG75LG87!I)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"%I;E]A<G)A>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B
M:6QI='DG75LG<F5L96%S92==+`T*("`@("`@("`@("`@("`@("`@87)R87DH
M)W-N87!S:&]T)RP@)V1E=F5L)RP@)V%L<&AA)RP@)V)E=&$G+"`G<W1A8FQE
M)RDI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED4W1A=&4H
M)W)E;&5A<V4G+"`D=&AI<RT^7W!A8VMA9V5I;F9O6R=S=&%B:6QI='DG75LG
M<F5L96%S92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M:6Y?87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)V%P
M:2==+`T*("`@("`@("`@("`@("`@("`@87)R87DH)V1E=F5L)RP@)V%L<&AA
M)RP@)V)E=&$G+"`G<W1A8FQE)RDI*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]I;G9A;&ED4W1A=&4H)V%P:2<L("1T:&ES+3Y?<&%C:V%G96EN9F];
M)W-T86)I;&ET>2==6R=A<&DG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5-86EN=&%I;F5R
M<R@I#0H@("`@>PT*("`@("`@("`D<W1R=6-T=7)E(#T-"B`@("`@("`@("`@
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N86UE)RP-"B`@("`@("`@("`@
M("`@("`G=7-E<B<L#0H@("`@("`@("`@("`@("`@)V5M86EL)RP-"B`@("`@
M("`@("`@("`@("`G86-T:79E)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y*"=L96%D)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB
M=71O<B<L("=H96QP97(G*2!A<R`D='EP92D@>PT*("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1T>7!E72DI('L-"B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1T>7!E75LP72DI
M('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1T>7!E72!A<R`D;&5A9"D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L("1L96%D
M+"`G/"<@+B`D='EP92`N("<^)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T
M=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L("1T:&ES+3Y?<&%C:V%G
M94EN9F];)'1Y<&5=+`T*("`@("`@("`@("`@("`@("`@("`G/"<@+B`D='EP
M92`N("<^)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?=F%L:61A=&50:'!$97`H)&1E<"P@)&EN<W1A;&QC
M;VYD:71I;VX@/2!F86QS92D-"B`@("![#0H@("`@("`@("1S=')U8W1U<F4@
M/2!A<G)A>2@-"B`@("`@("`@("`@("=M:6XG+`T*("`@("`@("`@("`@)RIM
M87@G+`T*("`@("`@("`@("`@)RIE>&-L=61E)RP-"B`@("`@("`@*3L-"B`@
M("`@("`@)'1Y<&4@/2`D:6YS=&%L;&-O;F1I=&EO;B`_("<\:6YS=&%L;&-O
M;F1I=&EO;CX\<&AP/B<@.B`G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!H
M<#XG.PT*("`@("`@("`D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S
M=')U8W1U<F4L("1D97`L("1T>7!E*3L-"B`@("`@("`@:68@*&ES<V5T*"1D
M97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O
M7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R@_.BU;82UZ02U:,"TY
M72LI/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;)VUI;B==*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH)'1Y<&4@
M+B`G/&UI;CXG+"`D9&5P6R=M:6XG72D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@
M("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;
M82UZ02U:72M<9"HI/R@_.BU;82UZ02U:,"TY72LI/R0O)RP-"B`@("`@("`@
M("`@("`@("`@("1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6YV86QI9%9E<G-I;VXH)'1Y<&4@+B`G/&UA>#XG+"`D9&5P6R=M
M87@G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?=F%L:61A=&5096%R:6YS=&%L;&5R1&5P*"1D97`I#0H@
M("`@>PT*("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@
M("`G;6EN)RP-"B`@("`@("`@("`@("<J;6%X)RP-"B`@("`@("`@("`@("<J
M<F5C;VUM96YD960G+`T*("`@("`@("`@("`@)RIE>&-L=61E)RP-"B`@("`@
M("`@*3L-"B`@("`@("`@)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D
M<W1R=6-T=7)E+"`D9&5P+"`G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E
M87)I;G-T86QL97(^)RD[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG
M72DI('L-"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<
M+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@
M("`D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN
M=F%L:61697)S:6]N*"<\9&5P96YD96YC:65S/CQR97%U:7)E9#X\<&5A<FEN
M<W1A;&QE<CX\;6EN/B<L#0H@("`@("`@("`@("`@("`@("`@("1D97!;)VUI
M;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*
M("`@("`@("`@("`@("`@("`@)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;B@G/&1E<&5N9&5N8VEE<SX\
M<F5Q=6ER960^/'!E87)I;G-T86QL97(^/&UA>#XG+`T*("`@("`@("`@("`@
M("`@("`@("`D9&5P6R=M87@G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI*2![
M#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI
M*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E
M<%LG<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEN=F%L:61697)S:6]N*"<\9&5P96YD96YC:65S/CQR97%U:7)E9#X\<&5A
M<FEN<W1A;&QE<CX\<F5C;VUM96YD960^)RP-"B`@("`@("`@("`@("`@("`@
M("`@)&1E<%LG<F5C;VUM96YD960G72D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-
M"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG97AC;'5D92==*2D@
M>PT*("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D
M97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M;W)E86-H("@D9&5P6R=E>&-L=61E)UT@87,@)&5X8VQU9&4I('L-"B`@("`@
M("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_
M.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@("`@("1E
M>&-L=61E*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L
M:61697)S:6]N*"<\9&5P96YD96YC:65S/CQR97%U:7)E9#X\<&5A<FEN<W1A
M;&QE<CX\97AC;'5D93XG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M8VQU9&4I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T95!A8VMA
M9V5$97`H)&1E<"P@)&=R;W5P+"`D='EP92`]("<\<&%C:V%G93XG*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@
M("`@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)VYA;64G+`T*("`@("`@("`@("`@("`@("`@("`G=7)I)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V-O;F9L:6-T<R<L#0H@("`@("`@("`@("`@
M("`@("`@("<J<')O=FED97-E>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1S
M=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VYA;64G
M+`T*("`@("`@("`@("`@("`@("`@("`G=7)I)RP-"B`@("`@("`@("`@("`@
M("`@("`@)RIP<F]V:61E<V5X=&5N<VEO;B<L#0H@("`@("`@("`@("`@("`@
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@
M("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("=N86UE)RP-"B`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG+`T*
M("`@("`@("`@("`@("`@("`@("`G*FUI;B<L#0H@("`@("`@("`@("`@("`@
M("`@("<J;6%X)RP-"B`@("`@("`@("`@("`@("`@("`@)RIE>&-L=61E)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V-O;F9L:6-T<R<L#0H@("`@("`@("`@
M("`@("`@("`@("<J<')O=FED97-E>'1E;G-I;VXG+`T*("`@("`@("`@("`@
M("`@("D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VYA
M;64G+`T*("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<L#0H@("`@("`@
M("`@("`@("`@("`@("<J;6EN)RP-"B`@("`@("`@("`@("`@("`@("`@)RIM
M87@G+`T*("`@("`@("`@("`@("`@("`@("`G*G)E8V]M;65N9&5D)RP-"B`@
M("`@("`@("`@("`@("`@("`@)RIE>&-L=61E)RP-"B`@("`@("`@("`@("`@
M("`@("`@)RIN;V1E9F%U;'0G+`T*("`@("`@("`@("`@("`@("`@("`G*G!R
M;W9I9&5S97AT96YS:6]N)RP-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=N
M86UE)UTI*2![#0H@("`@("`@("`@("`D='EP92`N/2`G/&YA;64^)R`N("1D
M97!;)VYA;64G72`N("<\+VYA;64^)SL-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L("1D97`L
M("<\9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92D[#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=U<FDG72D@)B8@*&ES<V5T*"1D97!;)VUI;B==
M*2!\?"!I<W-E="@D9&5P6R=M87@G72D@?'P-"B`@("`@("`@("`@("`@:7-S
M970H)&1E<%LG<F5C;VUM96YD960G72D@?'P@:7-S970H)&1E<%LG97AC;'5D
M92==*2DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=7)I1&5P<T-A;FYO=$AA
M=F5697)S:6]N:6YG*"<\9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP
M92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V-H86YN
M96PG72D@)B8@<W1R=&]L;W=E<B@D9&5P6R=C:&%N;F5L)UTI(#T]("=?7W5R
M:2<I('L-"B`@("`@("`@("`@("1T:&ES+3Y?1&5P8VAA;FYE;$-A;FYO=$)E
M57)I*"<\9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;
M82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;)VUI
M;B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I
M;VXH)SQD97!E;F1E;F-I97,^)R`N("1G<F]U<"`N("1T>7!E("X@)SQM:6X^
M)RP@)&1E<%LG;6EN)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@
M(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK
M7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"<\9&5P
M96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92`N("<\;6%X/B<L("1D97!;
M)VUA>"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&1E<%LG<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@
M(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK
M7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=R96-O;6UE;F1E
M9"==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I
M;VXH)SQD97!E;F1E;F-I97,^)R`N("1G<F]U<"`N("1T>7!E("X@)SQR96-O
M;6UE;F1E9#XG+`T*("`@("`@("`@("`@("`@("`@("`D9&5P6R=R96-O;6UE
M;F1E9"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@:68@
M*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@
M("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)V5X
M8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D
M+R<L#0H@("`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH)SQD97!E
M;F1E;F-I97,^)R`N("1G<F]U<"`N("1T>7!E("X@)SQE>&-L=61E/B<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D97AC;'5D92D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@7W9A;&ED871E4W5B<&%C:V%G941E<"@D9&5P+"`D9W)O
M=7`I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W9A;&ED871E4&%C:V%G941E
M<"@D9&5P+"`D9W)O=7`L("<\<W5B<&%C:V%G93XG*3L-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!;)W!R;W9I9&5S97AT96YS:6]N)UTI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W-U8G!A8VMA9V5#86YN;W10<F]V:61E17AT96YS:6]N
M*$`D9&5P6R=N86UE)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M<W5B<&%C:V%G97-#86YN;W1#;VYF;&EC="A`)&1E<%LG;F%M92==*3L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T945X=&5N
M<VEO;D1E<"@D9&5P+"`D9W)O=7`@/2!F86QS92P@)&EN<W1A;&QC;VYD:71I
M;VX@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("1S=')U8W1U<F4@/2!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`G;F%M92<L#0H@("`@("`@("`@("`@("`@
M)RIM:6XG+`T*("`@("`@("`@("`@("`@("<J;6%X)RP-"B`@("`@("`@("`@
M("`@("`G*F5X8VQU9&4G+`T*("`@("`@("`@("`@("`@("=C;VYF;&EC=',G
M+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F%M
M92<L#0H@("`@("`@("`@("`@("`@)RIM:6XG+`T*("`@("`@("`@("`@("`@
M("<J;6%X)RP-"B`@("`@("`@("`@("`@("`G*G)E8V]M;65N9&5D)RP-"B`@
M("`@("`@("`@("`@("`G*F5X8VQU9&4G+`T*("`@("`@("`@("`@*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)&EN<W1A;&QC;VYD:71I;VXI('L-"B`@
M("`@("`@("`@("1T>7!E(#T@)SQI;G-T86QL8V]N9&ET:6]N/CQE>'1E;G-I
M;VX^)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T>7!E(#T@
M)SQD97!E;F1E;F-I97,^)R`N("1G<F]U<"`N("<\97AT96YS:6]N/B<[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VYA;64G72DI('L-
M"B`@("`@("`@("`@("1T>7!E("X]("<\;F%M93XG("X@)&1E<%LG;F%M92==
M("X@)SPO;F%M93XG.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<W1U
M<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P@)&1E<"P@)'1Y<&4I.PT*
M("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=
M*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E<%LG;6EN)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;BAS=6)S
M='(H)'1Y<&4L(#$I("X@)SQM:6XG+"`D9&5P6R=M:6XG72D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA
M>"==*2D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_
M.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@
M("`@("1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E+"`Q*2`N("<\;6%X)RP@)&1E
M<%LG;6%X)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=R96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@
M("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:
M72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;)W)E8V]M;65N
M9&5D)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R
M<VEO;BAS=6)S='(H)'1Y<&4L(#$I("X@)SQR96-O;6UE;F1E9"<L("1D97!;
M)W)E8V]M;65N9&5D)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@
M("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L
M=61E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H
M)&1E<%LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@("`@
M("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:
M72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("`@("`D97AC;'5D92DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO
M;BAS=6)S='(H)'1Y<&4L(#$I("X@)SQE>&-L=61E)RP@)&5X8VQU9&4I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T94]S1&5P*"1D97`L("1I
M;G-T86QL8V]N9&ET:6]N(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D<W1R
M=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`G;F%M92<L#0H@("`@("`@
M("`@("`G*F-O;F9L:6-T<R<L#0H@("`@("`@("D[#0H@("`@("`@("1T>7!E
M(#T@)&EN<W1A;&QC;VYD:71I;VX@/R`G/&EN<W1A;&QC;VYD:71I;VX^/&]S
M/B<@.B`G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/&]S/B<[#0H@("`@("`@
M(&EF("@D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L
M("1D97`L("1T>7!E*2D@>PT*("`@("`@("`@("`@:68@*"1D97!;)VYA;64G
M72`]/2`G*B<I('L-"B`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X
M:7-T<R@G8V]N9FQI8W1S)RP@)&1E<"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C86YN;W1#;VYF;&EC=%=I=&A!;&Q/<R@D='EP92D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E07)C:$1E<"@D9&5P+"`D
M:6YS=&%L;&-O;F1I=&EO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'-T
M<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@)W!A='1E<FXG+`T*("`@
M("`@("`@("`@)RIC;VYF;&EC=',G+`T*("`@("`@("`I.PT*("`@("`@("`D
M='EP92`]("1I;G-T86QL8V]N9&ET:6]N(#\@)SQI;G-T86QL8V]N9&ET:6]N
M/CQA<F-H/B<@.B`G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/&%R8V@^)SL-
M"B`@("`@("`@)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T
M=7)E+"`D9&5P+"`D='EP92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A
M;&ED871E26YS=&%L;$-O;F1I=&EO;G,H)&-O;F0L("1R96QE87-E*0T*("`@
M('L-"B`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@
M)RIP:'`G+`T*("`@("`@("`@("`@)RIE>'1E;G-I;VXG+`T*("`@("`@("`@
M("`@)RIO<R<L#0H@("`@("`@("`@("`G*F%R8V@G+`T*("`@("`@("`I.PT*
M("`@("`@("!I9B`H(21T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T
M<G5C='5R92P-"B`@("`@("`@("`@("`@)&-O;F0L("1R96QE87-E*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y*"=P:'`G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R
M8V@G*2!A<R`D='EP92D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYD
M6R1T>7!E72DI('L-"B`@("`@("`@("`@("`@("`D:71E<B`]("1C;VYD6R1T
M>7!E73L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I=&5R*2!\
M?"`A:7-S970H)&ET97);,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1I
M=&5R(#T@87)R87DH)&ET97(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D:71E<B!A<R`D<&%C:V%G92D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)V5X=&5N<VEO;B<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y[(E]V86QI9&%T97LD
M='EP97U$97`B?2@D<&%C:V%G92P@9F%L<V4L('1R=64I.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/GLB7W9A;&ED871E>R1T>7!E?41E<")]*"1P86-K86=E+"!T<G5E
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]V86QI9&%T941E<&5N9&5N8VEE<R@I#0H@("`@>PT*("`@("`@("`D
M<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`G<F5Q=6ER960G+`T*
M("`@("`@("`@("`@)RIO<'1I;VYA;"<L#0H@("`@("`@("`@("`G*F=R;W5P
M+3YN86UE+3YH:6YT)PT*("`@("`@("`I.PT*("`@("`@("!I9B`H(21T:&ES
M+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P-"B`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UTL("<\
M9&5P96YD96YC:65S/B<I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H87)R87DH)W)E<75I<F5D
M)RP@)V]P=&EO;F%L)RD@87,@)'-I;7!L961E<"D@>PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==
M6R1S:6UP;&5D97!=*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D<VEM<&QE
M9&5P(#T]("=O<'1I;VYA;"<I('L-"B`@("`@("`@("`@("`@("`@("`@)'-T
M<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@)RIP
M86-K86=E)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<J<W5B<&%C:V%G
M92<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G*F5X=&5N<VEO;B<L#0H@
M("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@)W!H<"<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`G<&5A<FEN<W1A;&QE<B<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G*G!A8VMA9V4G+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)RIS=6)P86-K86=E)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<J97AT
M96YS:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<J;W,G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)RIA<F-H)RP-"B`@("`@("`@("`@("`@
M("`@("`@*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P-
M"B`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D
M97!E;F1E;F-I97,G75LD<VEM<&QE9&5P72P-"B`@("`@("`@("`@("`@("`@
M("`@("`B/&1E<&5N9&5N8VEE<SX\)'-I;7!L961E<#XB*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G<&%C:V%G92<L("=S=6)P
M86-K86=E)RP@)V5X=&5N<VEO;B<I(&%S("1T>7!E*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M9&5P96YD96YC:65S)UU;)'-I;7!L961E<%U;)'1Y<&5=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1I=&5R(#T@)'1H:7,M/E]P86-K86=E
M26YF;ULG9&5P96YD96YC:65S)UU;)'-I;7!L961E<%U;)'1Y<&5=.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&ET97);,%TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I=&5R(#T@
M87)R87DH)&ET97(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:71E<B!A
M<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1Y<&4@(3T@)V5X=&5N<VEO;B<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG=7)I
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P86-K86=E6R=C:&%N;F5L)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M57)L3W)#:&%N;F5L*"1T>7!E+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VYA;64G72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1P86-K86=E6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?3F]#:&%N;F5L
M*"1T>7!E+"`D<&%C:V%G95LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/GLB7W9A;&ED871E>R1T>7!E?41E<")]*"1P86-K86=E+"`B/"1S:6UP
M;&5D97`^(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<VEM<&QE9&5P(#T]("=O<'1I
M;VYA;"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y*"=P:'`G+"`G<&5A<FEN<W1A;&QE<B<L("=O<R<L("=A
M<F-H)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LD
M<VEM<&QE9&5P75LD='EP95TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&ET97(@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I
M97,G75LD<VEM<&QE9&5P75LD='EP95T[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D:71E<ELP72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&ET97(@/2!A<G)A>2@D:71E<BD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5R(&%S("1P86-K86=E*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y[(E]V86QI
M9&%T97LD='EP97U$97`B?2@D<&%C:V%G92D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG9W)O=7`G72DI('L-"B`@
M("`@("`@("`@("1G<F]U<',@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E
M;F1E;F-I97,G75LG9W)O=7`G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&=R;W5P<ULP72DI('L-"B`@("`@("`@("`@("`@("`D9W)O=7!S(#T@87)R
M87DH)&=R;W5P<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<W1R
M=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)RIP86-K86=E)RP-
M"B`@("`@("`@("`@("`@("`G*G-U8G!A8VMA9V4G+`T*("`@("`@("`@("`@
M("`@("<J97AT96YS:6]N)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("`@
M("!F;W)E86-H("@D9W)O=7!S(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U
M<F4L("1G<F]U<"P@)SQG<F]U<#XG*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(5!%05)?5F%L:61A=&4Z.G9A;&ED1W)O=7!.86UE*"1G<F]U<%LG
M871T<FEB<R==6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEN=F%L:61$97!'<F]U<$YA;64H)&=R;W5P6R=A='1R:6)S
M)UU;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)W!A8VMA9V4G+"`G<W5B<&%C
M:V%G92<L("=E>'1E;G-I;VXG*2!A<R`D='EP92D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LD='EP95TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&ET97(@/2`D9W)O=7!;)'1Y<&5=
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&ET
M97);,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M=&5R(#T@87)R87DH)&ET97(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M:71E<B!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)'1Y<&4@(3T@)V5X=&5N<VEO;B<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G
M95LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=C:&%N;F5L)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?57)L3W)#:&%N;F5L1W)O=7`H)'1Y<&4L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG
M;F%M92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&=R;W5P6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%C:V%G95LG
M8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7TYO0VAA;FYE;$=R;W5P*"1T>7!E+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A8VMA9V5;)VYA;64G72P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG;F%M92==*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/GLB7W9A;&ED871E>R1T>7!E?41E<")]*"1P
M86-K86=E+"`G/&=R;W5P(&YA;64](B<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&=R;W5P6R=A='1R:6)S)UU;)VYA;64G72`N
M("<B/B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T94-O;7!A=&EB;&4H*0T*
M("`@('L-"B`@("`@("`@)&-O;7!A="`]("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;7!A=&EB;&4G73L-"B`@("`@("`@:68@*"%I<W-E="@D8V]M<&%T6S!=
M*2D@>PT*("`@("`@("`@("`@)&-O;7!A="`](&%R<F%Y*"1C;VUP870I.PT*
M("`@("`@("!]#0H@("`@("`@("1R97%U:7)E9"`](&%R<F%Y*"=N86UE)RP@
M)V-H86YN96PG+"`G;6EN)RP@)VUA>"<L("<J97AC;'5D92<I.PT*("`@("`@
M("!F;W)E86-H("@D8V]M<&%T(&%S("1P86-K86=E*2![#0H@("`@("`@("`@
M("`D='EP92`]("<\8V]M<&%T:6)L93XG.PT*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1P86-K86=E*2`F)B!A<G)A>5]K97E?97AI<W1S*"=N86UE)RP@
M)'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@)'1Y<&4@+CT@)SQN86UE
M/B<@+B`D<&%C:V%G95LG;F%M92==("X@)SPO;F%M93XG.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T
M92@D<F5Q=6ER960L("1P86-K86=E+"`D='EP92D[#0H@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'!A8VMA9V4I("8F(&%R<F%Y7VME>5]E>&ES=',H)VUI
M;B<L("1P86-K86=E*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A<')E9U]M
M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L#0H@
M("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*'-U8G-T
M<B@D='EP92P@,2D@+B`G/&UI;B<L("1P86-K86=E6R=M:6XG72D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1P86-K86=E*2`F)B!A<G)A>5]K97E?97AI<W1S*"=M87@G
M+"`D<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M87@G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;BAS=6)S='(H
M)'1Y<&4L(#$I("X@)SQM87@G+"`D<&%C:V%G95LG;6%X)UTI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D<&%C:V%G92D@)B8@87)R87E?:V5Y7V5X:7-T<R@G97AC;'5D
M92<L("1P86-K86=E*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'!A8VMA9V5;)V5X8VQU9&4G72`](&%R<F%Y*"1P86-K86=E6R=E>&-L
M=61E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<&%C:V%G95LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<
M+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E>&-L=61E*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;BAS=6)S='(H)'1Y<&4L(#$I("X@
M)SQE>&-L=61E)RP@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E0G5N9&QE*"1L:7-T
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;&ES="D@?'P@(6ES
M<V5T*"1L:7-T6R=B=6YD;&5D<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?3F]"=6YD;&5D4&%C:V%G97,H*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1L:7-T6R=B=6YD;&5D<&%C:V%G
M92==*2!\?"`A:7-S970H)&QI<W1;)V)U;F1L961P86-K86=E)UU;,%TI*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]!=$QE87-T,D)U;F1L9610
M86-K86=E<R@I.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1L:7-T
M6R=B=6YD;&5D<&%C:V%G92==(&%S("1P86-K86=E*2![#0H@("`@("`@("`@
M("!I9B`H(6ES7W-T<FEN9R@D<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V)U;F1L961086-K86=E<TUU<W1"949I;&5N86UE*"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?=F%L:61A=&5&:6QE;&ES="@D;&ES="`](&9A;'-E+"`D86QL;W=I9VYO
M<F4@/2!F86QS92P@)&1I<G,@/2`G)RD-"B`@("![#0H@("`@("`@("1I<V-O
M;G1E;G1S(#T@9F%L<V4[#0H@("`@("`@(&EF("@A)&QI<W0I('L-"B`@("`@
M("`@("`@("1I<V-O;G1E;G1S(#T@=')U93L-"B`@("`@("`@("`@("1L:7-T
M(#T@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G73L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]V86QI9&%T94)U
M;F1L92@D;&ES="D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1A;&QO=VEG;F]R92D@>PT*("`@("`@("`@("`@)'-T<G5C(#T@
M87)R87DH#0H@("`@("`@("`@("`@("`@)RII;G-T86QL+3YN86UE+3YA<R<L
M#0H@("`@("`@("`@("`@("`@)RII9VYO<F4M/FYA;64G#0H@("`@("`@("`@
M("`I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'-T<G5C(#T@
M87)R87DH#0H@("`@("`@("`@("`@("`@)RID:7(M/FYA;64M/C]B87-E:6YS
M=&%L;&1I<B<L#0H@("`@("`@("`@("`@("`@)RIF:6QE+3YN86UE+3YR;VQE
M+3X_8F%S96EN<W1A;&QD:7(M/C]M9#5S=6TG#0H@("`@("`@("`@("`I.PT*
M("`@("`@("`@("`@:68@*&ES<V5T*"1L:7-T6R=D:7(G72D@)B8@:7-S970H
M)&QI<W1;)V9I;&4G72DI('L-"B`@("`@("`@("`@("`@("`O+R!S=&%V92!O
M9F8@=F%L:61A=&EO;B!E<G)O<G,@=VET:&]U="!R97%U:7)I;F<@82!S970@
M;W)D97(N#0H@("`@("`@("`@("`@("`@)%]O;&0@/2`D;&ES=#L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&QI<W1;)V%T=')I8G,G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&QI<W0@/2!A<G)A>2@G871T<FEB<R<@/3X@
M)%]O;&1;)V%T=')I8G,G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1L:7-T6R=D:7(G72`]("1?;VQD6R=D:7(G73L-"B`@("`@
M("`@("`@("`@("`D;&ES=%LG9FEL92==(#T@)%]O;&1;)V9I;&4G73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1L
M:7-T6R=A='1R:6)S)UTI('Q\("%I<W-E="@D;&ES=%LG871T<FEB<R==6R=N
M86UE)UTI*2![#0H@("`@("`@("`@("`D=6YK;F]W;B`]("1A;&QO=VEG;F]R
M92`_("<\9FEL96QI<W0^)R`Z("<\9&ER(&YA;64](BIU;FMN;W=N*B(^)SL-
M"B`@("`@("`@("`@("1D:7)N86UE(#T@)&ES8V]N=&5N=',@/R`G/&-O;G1E
M;G1S/B<@.B`D=6YK;F]W;CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1D:7)N86UE(#T@)SQD:7(@;F%M93TB)R`N("1L:7-T6R=A='1R:6)S
M)UU;)VYA;64G72`N("<B/B<[#0H@("`@("`@('T-"B`@("`@("`@)')E<R`]
M("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C+"`D;&ES="P@
M)&1I<FYA;64I.PT*("`@("`@("!I9B`H)&%L;&]W:6=N;W)E("8F("1R97,I
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&8M/F=E=$9I;&5L:7-T*"D[#0H@
M("`@("`@("`@("`D9F-O;G1E;G1S(#T@)'1H:7,M/E]P9BT^9V5T0V]N=&5N
M=',H*3L-"B`@("`@("`@("`@("1F:6QE;&ES="`](&%R<F%Y*"D[#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1F8V]N=&5N='-;)V1I<B==6R=F:6QE)UU;
M,%TI*2![#0H@("`@("`@("`@("`@("`@)&9C;VYT96YT<ULG9&ER)UU;)V9I
M;&4G72`](&%R<F%Y*"1F8V]N=&5N='-;)V1I<B==6R=F:6QE)UTI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&9C;VYT96YT<ULG
M9&ER)UU;)V9I;&4G72!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("1F
M:6QE;&ES=%LD9FEL95LG871T<FEB<R==6R=N86UE)UU=(#T@=')U93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;&ES=%LG:6YS
M=&%L;"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&QI<W1;
M)VEN<W1A;&PG75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&QI<W1;
M)VEN<W1A;&PG72`](&%R<F%Y*"1L:7-T6R=I;G-T86QL)UTI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D;&ES=%LG
M:6YS=&%L;"==(&%S("1F:6QE*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&9I;&5L:7-T6R1F:6QE6R=A='1R:6)S)UU;)VYA;64G75TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VYO=$EN0V]N
M=&5N=',H)&9I;&5;)V%T=')I8G,G75LG;F%M92==+"`G:6YS=&%L;"<I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1L:7-T6R=I9VYO
M<F4G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R=I
M9VYO<F4G75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&QI<W1;)VEG
M;F]R92==(#T@87)R87DH)&QI<W1;)VEG;F]R92==*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI<W1;)VEG;F]R
M92==(&%S("1F:6QE*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&9I;&5L:7-T6R1F:6QE6R=A='1R:6)S)UU;)VYA;64G75TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VYO=$EN0V]N=&5N=',H
M)&9I;&5;)V%T=')I8G,G75LG;F%M92==+"`G:6=N;W)E)RD[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D86QL;W=I9VYO<F4@)B8@
M:7-S970H)&QI<W1;)V9I;&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)&QI<W1;)V9I;&4G75LP72DI('L-"B`@("`@("`@("`@("`@("`O+R!S
M:6YG;&4@9FEL90T*("`@("`@("`@("`@("`@("1L:7-T6R=F:6QE)UT@/2!A
M<G)A>2@D;&ES=%LG9FEL92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1L:7-T6R=F:6QE)UT@87,@)&D@/3X@)&9I;&4I#0H@
M("`@("`@("`@("![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F:6QE
M6R=A='1R:6)S)UTI("8F(&ES<V5T*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G
M72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG871T<FEB<R==
M6R=N86UE)UU[,'T@/3T@)RXG("8F#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEL95LG871T<FEB<R==6R=N86UE)UU[,7T@/3T@)R\G*2![#0H@("`@
M("`@("`@("`@("`@("`@("\O(&YA;64@:7,@<V]M971H:6YG(&QI:V4@(BXO
M9&]C+W=H871E=F5R+G1X="(-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;G9A;&ED1FEL94YA;64H)&9I;&5;)V%T=')I8G,G75LG;F%M92==*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1F:6QE6R=A='1R:6)S)UTI("8F(&ES<V5T*"1F:6QE6R=A='1R:6)S)UU;
M)W)O;&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^
M7W9A;&ED871E4F]L92@D9FEL95LG871T<FEB<R==6R=R;VQE)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG=7-E<W)O;&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F]L97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L
M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)')O;&5S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F]L97,@/2!A<G)A>2@D<F]L97,I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D<F]L97,@87,@)')O;&4I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1R;VQE6R=R;VQE)UT@/2`D9FEL95LG871T<FEB
M<R==6R=R;VQE)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M<V<@/2`G5&AI<R!P86-K86=E(&-O;G1A:6YS(')O;&4@(B5R
M;VQE)2(@86YD(')E<75I<F5S("<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=P86-K86=E("(E<&%C:V%G924B('1O(&)E
M('5S960G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1R;VQE6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH)W)O;&4G
M(#T^("1R;VQE6R=R;VQE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B`D<F]L95LG=7)I)UTI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%R86US(#T@87)R87DH)W)O;&4G(#T^("1R;VQE6R=R;VQE)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P86-K
M86=E)R`]/B`D=&AI<RT^7W!F+3Y?<F5G:7-T<GDM/@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P87)S961086-K86=E
M3F%M951O4W1R:6YG*&%R<F%Y*"=P86-K86=E)R`]/@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O;&5;)W!A
M8VMA9V4G72P@)V-H86YN96PG(#T^("1R;VQE6R=C:&%N;F5L)UTI+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=')U92DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S=&%C:RT^<'5S:"@G7VUU<W1);G-T86QL4F]L92<L("=E<G)O<B<L("1P
M87)A;7,L("1M<V<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]I;G9A;&ED1FEL95)O;&4H)&9I;&5;)V%T=')I8G,G75LG;F%M92==
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)N86UE+"`D9FEL
M95LG871T<FEB<R==6R=R;VQE)UTI.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&9I;&5;)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1S879E(#T@)&9I;&5;)V%T=')I8G,G73L-"B`@("`@("`@("`@("`@("!I
M9B`H)&1I<G,I('L-"B`@("`@("`@("`@("`@("`@("`@)'-A=F5;)VYA;64G
M72`]("1D:7)S("X@)R\G("X@)'-A=F5;)VYA;64G73L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@=6YS970H)&9I;&5;)V%T=')I8G,G
M72D[#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1F:6QE*2`F)B`D=&AI
M<RT^7V-U<E-T871E("$](%!%05)?5D%,241!5$5?1$]73DQ/041)3D<I('L@
M+R\@:&%S('1A<VMS#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F
M:6QE(&%S("1T87-K(#T^("1V86QU92D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1T86=#;&%S<R`]("1T:&ES+3Y?<&8M/F=E=%1A<VLH)'1A
M<VLI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D=F%L=64I('Q\("%I<W-E="@D=F%L=65;,%TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`](&%R<F%Y*"1V86QU
M92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D=BD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@8V%L;%]U
M<V5R7V9U;F,H87)R87DH)'1A9T-L87-S+"`G=F%L:61A=&58;6PG*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&8L
M("1V+"`D=&AI<RT^7W!F+3Y?8V]N9FEG+"`D<V%V92D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;G9A;&ED5&%S:R@D=&%S:RP@)')E="P@0"1S879E6R=N86UE)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W1A<VLG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')O;&5S(#T@)'1H:7,M/E]P86-K
M86=E26YF;ULG=7-E<W1A<VLG73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<F]L97-;,%TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F]L97,@/2!A<G)A>2@D<F]L
M97,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R;VQE<R!A
M<R`D<F]L92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1R;VQE6R=T87-K)UT@/2`D=&%S:RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M<V<@/2`G5&AI<R!P86-K
M86=E(&-O;G1A:6YS('1A<VL@(B5T87-K)2(@86YD(')E<75I<F5S("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%C:V%G92`B)7!A8VMA9V4E(B!T;R!B92!U<V5D)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)')O;&5;
M)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US(#T@87)R87DH)W1A<VLG(#T^("1R;VQE6R=T
M87-K)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<&%C:V%G92<@/3X@)')O;&5;)W5R:2==*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%R86US(#T@87)R87DH)W1A<VLG(#T^("1R;VQE6R=T87-K)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%C:V%G92<@/3X@)'1H:7,M/E]P9BT^7W)E9VES=')Y+3X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!A<G-E
M9%!A8VMA9V5.86UE5&]3=')I;F<H87)R87DH)W!A8VMA9V4G(#T^#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')O;&5;)W!A8VMA9V4G72P@)V-H86YN96PG(#T^("1R;VQE6R=C:&%N
M;F5L)UTI+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1R=64I*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"@G7VUU<W1)
M;G-T86QL5&%S:R<L("=E<G)O<B<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,L("1M<V<I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=6YK;F]W;E1A<VLH)'1A<VLL("1S879E6R=N86UE)UTI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D;&ES=%LG:6=N;W)E)UTI*2![#0H@("`@("`@("`@
M("!I9B`H(21A;&QO=VEG;F]R92D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:6=N;W)E3F]T06QL;W=E9"@G:6=N;W)E)RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1L:7-T6R=I;G-T86QL
M)UTI*2![#0H@("`@("`@("`@("!I9B`H(21A;&QO=VEG;F]R92D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6=N;W)E3F]T06QL;W=E9"@G:6YS=&%L
M;"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D;&ES=%LG9FEL92==*2D@>PT*("`@("`@("`@("`@:68@*"1A;&QO
M=VEG;F]R92D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL94YO=$%L
M;&]W960H)V9I;&4G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&QI<W1;)V1I<B==*2D@>PT*("`@("`@("`@("`@
M:68@*"1A;&QO=VEG;F]R92D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9FEL94YO=$%L;&]W960H)V1I<B<I.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R=D:7(G75LP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&QI<W1;)V1I<B==(#T@87)R87DH
M)&QI<W1;)V1I<B==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&QI<W1;)V1I<B==(&%S("1D:7(I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D:7);)V%T=')I8G,G72D@)B8@
M:7-S970H)&1I<ELG871T<FEB<R==6R=N86UE)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&1I<ELG871T<FEB<R==6R=N86UE)UT@/3T@
M)R\G('Q\#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V1I<B==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&%L=V%Y<R!U
M<V4@;F]T:&EN9R!I9B!T:&4@9FEL96QI<W0@:&%S(&%L<F5A9'D@8F5E;B!F
M;&%T=&5N960-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W9&ER
M<R`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1D
M:7)S(#T]("<G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE
M=V1I<G,@/2`D9&ER6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YE=V1I<G,@/2`D9&ER<R`N("<O)R`N("1D:7);)V%T=')I8G,G
M75LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&YE=V1I<G,@/2`D9&ER<SL-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1FEL96QI<W0H
M)&1I<BP@)&%L;&]W:6=N;W)E+"`D;F5W9&ER<RD[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7W9A;&ED871E4F5L96%S92@I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<&AP<F5L96%S92==*2D@
M>PT*("`@("`@("`@("`@)')E;&5A<V4@/2`G<&AP<F5L96%S92<[#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED
M97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A
M;FYO=%!R;W9I9&5%>'1E;G-I;VXH)')E;&5A<V4I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)W-R8W!A8VMA9V4G72D@?'P@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M<W)C=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C86YN;W1(
M879E4W)C<&%C:V%G92@D<F5L96%S92D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<F5L96%S97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=P:'!R
M96QE87-E)UT[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R96QE87-E
M<RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)')E;&5A<V5S6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("1R96QE87-E<R`](&%R<F%Y*"1R96QE87-E
M<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D<F5L
M96%S97,@87,@)')E;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1U
M<&ED4V-H96UA5F%L:61A=&4H87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("<J:6YS=&%L;&-O;F1I=&EO;G,G+`T*("`@("`@("`@("`@("`@("`@("`G
M*F9I;&5L:7-T)RP-"B`@("`@("`@("`@("`@("`I+"`D<F5L+"`G/'!H<')E
M;&5A<V4^)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V5X='-R8W)E;&5A<V4G
M72DI('L-"B`@("`@("`@("`@("1R96QE87-E(#T@)V5X='-R8W)E;&5A<V4G
M.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;75S=%!R;W9I9&5%>'1E;G-I;VXH)')E;&5A<V4I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W-R8W!A8VMA9V4G72D@?'P@:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG<W)C=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M86YN;W1(879E4W)C<&%C:V%G92@D<F5L96%S92D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<F5L96%S97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=E>'1S<F-R96QE87-E)UT[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1R96QE87-E<RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)')E;&5A
M<V5S6S!=*2D@>PT*("`@("`@("`@("`@("`@("1R96QE87-E<R`](&%R<F%Y
M*"1R96QE87-E<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D<F5L96%S97,@87,@)')E;"D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("<J:6YS=&%L;&-O;F1I=&EO;G,G+`T*("`@("`@("`@("`@
M("`@("`@("`G*F-O;F9I9W5R96]P=&EO;BT^;F%M92T^<')O;7!T+3X_9&5F
M875L="<L#0H@("`@("`@("`@("`@("`@("`@("<J8FEN87)Y<&%C:V%G92<L
M#0H@("`@("`@("`@("`@("`@("`@("<J9FEL96QI<W0G+`T*("`@("`@("`@
M("`@("`@("DL("1R96PL("<\97AT<W)C<F5L96%S93XG*3L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)')E;%LG8FEN87)Y<&%C:V%G92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R96Q;)V)I;F%R
M>7!A8VMA9V4G72D@?'P@(6ES<V5T*"1R96Q;)V)I;F%R>7!A8VMA9V4G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96Q;)V)I;F%R>7!A
M8VMA9V4G72`](&%R<F%Y*"1R96Q;)V)I;F%R>7!A8VMA9V4G72D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)')E;%LG8FEN87)Y<&%C:V%G92==(&%S("1B:6XI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-?<W1R:6YG*"1B:6XI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B:6YA<GE086-K86=E
M375S=$)E4&%C:V%G96YA;64H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG97AT8FEN<F5L96%S92==*2D@>PT*("`@
M("`@("`@("`@)')E;&5A<V4@/2`G97AT8FEN<F5L96%S92<[#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S
M97AT96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]M=7-T
M4')O=FED945X=&5N<VEO;B@D<F5L96%S92D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA
M;FYE;"==*2`F)@T*("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)W-R8W!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VUU<W13<F-086-K86=E*"1R96QE87-E*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=U<FDG72D@)B8@(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-R
M8W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?;75S=%-R8W5R
M:2@D<F5L96%S92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5L
M96%S97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1B:6YR96QE87-E)UT[
M#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R96QE87-E<RDI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)')E;&5A<V5S6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("1R96QE87-E<R`](&%R<F%Y*"1R96QE87-E<RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D<F5L96%S97,@87,@
M)')E;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1U<&ED4V-H96UA
M5F%L:61A=&4H87)R87DH#0H@("`@("`@("`@("`@("`@("`@("<J:6YS=&%L
M;&-O;F1I=&EO;G,G+`T*("`@("`@("`@("`@("`@("`@("`G*F9I;&5L:7-T
M)RP-"B`@("`@("`@("`@("`@("`I+"`D<F5L+"`G/&5X=&)I;G)E;&5A<V4^
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V)U;F1L92==*2D@>PT*("`@("`@
M("`@("`@)')E;&5A<V4@/2`G8G5N9&QE)SL-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<V5X=&5N<VEO;B==
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%N;F]T4')O=FED945X
M=&5N<VEO;B@D<F5L96%S92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W)C<&%C:V%G92==
M*2!\?"!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-U<FDG72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A;FYO=$AA=F53<F-P86-K86=E
M*"1R96QE87-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R96QE
M87-E<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V)U;F1L92==.PT*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S97,I('Q\("%I<W-E="@D<F5L
M96%S97-;,%TI*2![#0H@("`@("`@("`@("`@("`@)')E;&5A<V5S(#T@87)R
M87DH)')E;&5A<V5S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1R96QE87-E<R!A<R`D<F5L*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92AA<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)RII;G-T86QL8V]N9&ET:6]N<R<L#0H@("`@("`@("`@
M("`@("`@("`@("<J9FEL96QI<W0G+`T*("`@("`@("`@("`@("`@("DL("1R
M96PL("<\8G5N9&QE/B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&9O<F5A8V@@*"1R96QE87-E<R!A<R`D<F5L*2![#0H@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)')E;"D@)B8@87)R87E?:V5Y7V5X:7-T<R@G
M:6YS=&%L;&-O;F1I=&EO;G,G+"`D<F5L*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=F%L:61A=&5);G-T86QL0V]N9&ET:6]N<R@D<F5L6R=I;G-T
M86QL8V]N9&ET:6]N<R==+`T*("`@("`@("`@("`@("`@("`@("`B/"1R96QE
M87-E/CQI;G-T86QL8V]N9&ET:6]N<SXB*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5L*2`F)B!A<G)A>5]K97E?97AI
M<W1S*"=F:6QE;&ES="<L("1R96PI*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1R96Q;)V9I;&5L:7-T)UTI('L-"B`@("`@("`@("`@("`@("`@("`@#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5&:6QE;&ES="@D
M<F5L6R=F:6QE;&ES="==+"!T<G5E*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!4:&ES(&ES(&AE<F4@=&\@86QL;W<@<F]L92!E>'1E;G-I;VX@=&AR
M;W5G:"!P;'5G:6YS#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]V86QI9&%T95)O;&4H)')O;&4I#0H@("`@>PT*("`@
M("`@("!R971U<FX@:6Y?87)R87DH)')O;&4L(%!%05)?26YS=&%L;&5R7U)O
M;&4Z.F=E=%9A;&ED4F]L97,H)'1H:7,M/E]P9BT^9V5T4&%C:V%G951Y<&4H
M*2DI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED5&%G3W)D97(H
M)&]K=&%G<RP@)&%C='5A;"P@)')O;W0I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP-"B`@("`@
M("`@("`@(&%R<F%Y*"=O:W1A9W,G(#T^("1O:W1A9W,L("=A8W1U86PG(#T^
M("1A8W1U86PL("=R;V]T)R`]/B`D<F]O="DL#0H@("`@("`@("`@("`G26YV
M86QI9"!T86<@;W)D97(@:6X@)7)O;W0E+"!F;W5N9"`\)6%C='5A;"4^(&5X
M<&5C=&5D(&]N92!O9B`B)6]K=&%G<R4B)RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7VEG;F]R94YO=$%L;&]W960H)'1Y<&4I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@
M87)R87DH)W1Y<&4G(#T^("1T>7!E*2P-"B`@("`@("`@("`@("<\)71Y<&4E
M/B!I<R!N;W0@86QL;W=E9"!I;G-I9&4@9VQO8F%L(#QC;VYT96YT<SXL(&]N
M;'D@:6YS:61E("<@+@T*("`@("`@("`@("`@)SQP:'!R96QE87-E/B\\97AT
M8FEN<F5L96%S93XL('5S92`\9&ER/B!A;F0@/&9I;&4^(&]N;'DG*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!?9FEL94YO=$%L;&]W960H)'1Y<&4I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?
M7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G(#T^("1T>7!E*2P-"B`@("`@("`@
M("`@("<\)71Y<&4E/B!I<R!N;W0@86QL;W=E9"!I;G-I9&4@<F5L96%S92`\
M9FEL96QI<W0^+"!O;FQY(&EN<VED92`G("X-"B`@("`@("`@("`@("<\8V]N
M=&5N=',^+"!U<V4@/&EG;F]R93X@86YD(#QI;G-T86QL/B!O;FQY)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7W1A9TUI<W-I;F=!='1R:6)U=&4H)'1A
M9RP@)&%T='(L("1C;VYT97AT*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S
M=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T86<G
M(#T^("1T86<L#0H@("`@("`@("`@("`G871T<FEB=71E)R`]/B`D871T<BP@
M)V-O;G1E>'0G(#T^("1C;VYT97AT*2P-"B`@("`@("`@("`@("=T86<@/"5T
M86<E/B!I;B!C;VYT97AT("(E8V]N=&5X="4B(&AA<R!N;R!A='1R:6)U=&4@
M(B5A='1R:6)U=&4E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]T86=(
M87-.;T%T=')I8G,H)'1A9RP@)&-O;G1E>'0I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R
M87DH)W1A9R<@/3X@)'1A9RP-"B`@("`@("`@("`@("=C;VYT97AT)R`]/B`D
M8V]N=&5X="DL#0H@("`@("`@("`@("`G=&%G(#PE=&%G)3X@:&%S(&YO(&%T
M=')I8G5T97,@:6X@8V]N=&5X="`B)6-O;G1E>'0E(B<I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]I;G9A;&ED26YT97)N86Q3=')U8W1U<F4H*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L
M("=E>&-E<'1I;VXG+"!A<G)A>2@I+`T*("`@("`@("`@("`@)VEN=&5R;F%L
M(&%R<F%Y('=A<R!N;W0@9V5N97)A=&5D(&)Y(&-O;7!A=&EB;&4@<&%R<V5R
M+"!O<B!E>'1R96UE('!A<G-E<B!E<G)O<BP@8V%N;F]T(&-O;G1I;G5E)RD[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN=F%L:61&:6QE4F]L92@D9FEL
M92P@)&1I<BP@)')O;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH#0H@("`@("`@
M("`@("`G9FEL92<@/3X@)&9I;&4L("=D:7(G(#T^("1D:7(L("=R;VQE)R`]
M/B`D<F]L92P-"B`@("`@("`@("`@("=R;VQE<R<@/3X@4$5!4E]);G-T86QL
M97)?4F]L93HZ9V5T5F%L:612;VQE<R@D=&AI<RT^7W!F+3YG971086-K86=E
M5'EP92@I*2DL#0H@("`@("`@("`@("`G1FEL92`B)69I;&4E(B!I;B!D:7)E
M8W1O<GD@(B5D:7(E(B!H87,@:6YV86QI9"!R;VQE("(E<F]L924B+"!S:&]U
M;&0@8F4@;VYE(&]F("5R;VQE<R4G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?:6YV86QI9$9I;&5.86UE*"1F:6QE+"`D9&ER*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L
M(&%R<F%Y*`T*("`@("`@("`@("`@)V9I;&4G(#T^("1F:6QE*2P-"B`@("`@
M("`@("`@("=&:6QE("(E9FEL924B(&-A;FYO="!B96=I;B!W:71H("(N(B<I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]F:6QE;&ES=$-A;FYO=$-O;G1A
M:6Y&:6QE*"1F:6QE;&ES="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]
M/B`D9FEL96QI<W0I+`T*("`@("`@("`@("`@)SPE=&%G)3X@8V%N(&]N;'D@
M8V]N=&%I;B`\9&ER/BP@8V]N=&%I;G,@/&9I;&4^+B`@57-E("<@+@T*("`@
M("`@("`@("`@)SQD:7(@;F%M93TB+R(^(&%S('1H92!F:7)S="!D:7(@96QE
M;65N="<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]F:6QE;&ES=$UU<W1#
M;VYT86EN1&ER*"1F:6QE;&ES="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G
M)R`]/B`D9FEL96QI<W0I+`T*("`@("`@("`@("`@)SPE=&%G)3X@;75S="!C
M;VYT86EN(#QD:7(^+B`@57-E(#QD:7(@;F%M93TB+R(^(&%S('1H92`G("X-
M"B`@("`@("`@("`@("=F:7)S="!D:7(@96QE;65N="<I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]T86=#86YN;W1"945M<'1Y*"1T86<I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH)W1A9R<@/3X@)'1A9RDL#0H@("`@("`@("`@("`G/"5T
M86<E/B!C86YN;W0@8F4@96UP='D@*#PE=&%G)2\^*2<I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]5<FQ/<D-H86YN96PH)'1Y<&4L("1N86UE*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L
M("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P-"B`@("`@("`@("`@
M("=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@("`@("`G4F5Q=6ER960@9&5P
M96YD96YC>2`\)71Y<&4E/B`B)6YA;64E(B!C86X@:&%V92!E:71H97(@=7)L
M($]2("<@+@T*("`@("`@("`@("`@)V-H86YN96P@871T<FEB=71E<RP@86YD
M(&YO="!B;W1H)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7TYO0VAA;FYE
M;"@D='EP92P@)&YA;64I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G(#T^
M("1T>7!E+`T*("`@("`@("`@("`@)VYA;64G(#T^("1N86UE*2P-"B`@("`@
M("`@("`@("=297%U:7)E9"!D97!E;F1E;F-Y(#PE='EP924^("(E;F%M924B
M(&UU<W0@:&%V92!E:71H97(@=7)L($]2("<@+@T*("`@("`@("`@("`@)V-H
M86YN96P@871T<FEB=71E<R<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]5
M<FQ/<D-H86YN96Q'<F]U<"@D='EP92P@)&YA;64L("1G<F]U<"D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L#0H@("`@("`@("`@("`G
M;F%M92<@/3X@)&YA;64L("=G<F]U<"<@/3X@)&=R;W5P*2P-"B`@("`@("`@
M("`@("='<F]U<"`B)6=R;W5P)2(@9&5P96YD96YC>2`\)71Y<&4E/B`B)6YA
M;64E(B!C86X@:&%V92!E:71H97(@=7)L($]2("<@+@T*("`@("`@("`@("`@
M)V-H86YN96P@871T<FEB=71E<RP@86YD(&YO="!B;W1H)RD[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@7TYO0VAA;FYE;$=R;W5P*"1T>7!E+"`D;F%M92P@
M)&=R;W5P*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?
M7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P-
M"B`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P@)V=R;W5P)R`]/B`D9W)O
M=7`I+`T*("`@("`@("`@("`@)T=R;W5P("(E9W)O=7`E(B!D97!E;F1E;F-Y
M(#PE='EP924^("(E;F%M924B(&UU<W0@:&%V92!E:71H97(@=7)L($]2("<@
M+@T*("`@("`@("`@("`@)V-H86YN96P@871T<FEB=71E<R<I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]U;FMN;W=N0VAA;FYE;"@D8VAA;FYE;"D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?
M+"`G97)R;W(G+"!A<G)A>2@G8VAA;FYE;"<@/3X@)&-H86YN96PI+`T*("`@
M("`@("`@("`@)U5N:VYO=VX@8VAA;FYE;"`B)6-H86YN96PE(B<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]N;U!A8VMA9V5697)S:6]N*"D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@I+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#QP
M86-K86=E/B!T86<@:&%S(&YO('9E<G-I;VX@871T<FEB=71E+"!O<B!V97)S
M:6]N(&ES(&YO="`R+C`G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?3F]"
M=6YD;&5D4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C
M:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"DL#0H@("`@
M("`@("`@("`G3F\@/&)U;F1L961P86-K86=E/B!T86<@=V%S(&9O=6YD(&EN
M(#QC;VYT96YT<SXL(')E<75I<F5D(&9O<B!B=6YD;&4@<&%C:V%G97,G*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?071,96%S=#)"=6YD;&5D4&%C:V%G
M97,H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"DL#0H@("`@("`@("`@("`G070@
M;&5A<W0@,B!P86-K86=E<R!M=7-T(&)E(&)U;F1L960@:6X@82!B=6YD;&4@
M<&%C:V%G92<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]#:&%N;F5L3W)5
M<FDH)&YA;64I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H
M*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)VYA;64G(#T^("1N86UE
M*2P-"B`@("`@("`@("`@("="=6YD;&5D('!A8VMA9V4@(B5N86UE)2(@8V%N
M(&AA=F4@96ET:&5R(&$@=7)I(&]R(&$@8VAA;FYE;"P@;F]T(&)O=&@G*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?;F]#:&EL9%1A9R@D8VAI;&0L("1T
M86<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.
M0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V-H:6QD)R`]/B`D8VAI;&0L("=T
M86<G(#T^("1T86<I+`T*("`@("`@("`@("`@)U1A9R`\)71A9R4^(&ES(&UI
M<W-I;F<@8VAI;&0@=&%G(#PE8VAI;&0E/B<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]I;G9A;&ED5F5R<VEO;B@D='EP92P@)'9A;'5E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E
M<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P@)W9A;'5E)R`]/B`D=F%L
M=64I+`T*("`@("`@("`@("`@)U9E<G-I;VX@='EP92`\)71Y<&4E/B!I<R!N
M;W0@82!V86QI9"!V97)S:6]N("@E=F%L=64E*2<I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%]I;G9A;&ED4W1A=&4H)'1Y<&4L("1V86QU92D-"B`@("![
M#0H@("`@("`@("1S=&%T97,@/2!A<G)A>2@G<W1A8FQE)RP@)V)E=&$G+"`G
M86QP:&$G+"`G9&5V96PG*3L-"B`@("`@("`@:68@*"1T>7!E("$]("=A<&DG
M*2![#0H@("`@("`@("`@("`D<W1A=&5S6UT@/2`G<VYA<'-H;W0G.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AS=')T;VQO=V5R*"1V86QU92D@/3T@)W)C
M)RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-4
M24].7U\L("=E<G)O<B<L#0H@("`@("`@("`@("`@("`@87)R87DH)W9E<G-I
M;VXG(#T^("1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG75LG<F5L96%S
M92==*2P-"B`@("`@("`@("`@("`@("`G4D,@:7,@;F]T(&$@<W1A=&4L(&ET
M(&ES(&$@=F5R<VEO;B!P;W-T9FEX+"!T<GD@)79E<G-I;VXE4D,Q+"!S=&%B
M:6QI='D@8F5T82<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G='EP92<@
M/3X@)'1Y<&4L("=V86QU92<@/3X@)'9A;'5E+`T*("`@("`@("`@("`@)W1Y
M<&5S)R`]/B`D<W1A=&5S*2P-"B`@("`@("`@("`@("=3=&%B:6QI='D@='EP
M92`\)71Y<&4E/B!I<R!N;W0@82!V86QI9"!S=&%B:6QI='D@*"5V86QU924I
M+"!M=7-T(&)E(&]N92!O9B`G("X-"B`@("`@("`@("`@("<E='EP97,E)RD[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN=F%L:61487-K*"1T87-K+"`D
M<F5T+"`D9FEL92D-"B`@("![#0H@("`@("`@('-W:71C:"`H)')E=%LP72D@
M>PT*("`@("`@("`@("`@8V%S92!014%27U1!4TM?15)23U)?34E34TE.1U]!
M5%1224(@.@T*("`@("`@("`@("`@("`@("1I;F9O(#T@87)R87DH)V%T=')I
M8B<@/3X@)')E=%LQ72P@)W1A<VLG(#T^("1T87-K+"`G9FEL92<@/3X@)&9I
M;&4I.PT*("`@("`@("`@("`@("`@("1M<V<@/2`G=&%S:R`\)71A<VLE/B!I
M<R!M:7-S:6YG(&%T=')I8G5T92`B)6%T=')I8B4B(&EN(&9I;&4@)69I;&4E
M)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!014%2
M7U1!4TM?15)23U)?3D]!5%1224)3(#H-"B`@("`@("`@("`@("`@("`D:6YF
M;R`](&%R<F%Y*"=T87-K)R`]/B`D=&%S:RP@)V9I;&4G(#T^("1F:6QE*3L-
M"B`@("`@("`@("`@("`@("`D;7-G(#T@)W1A<VL@/"5T87-K)3X@:&%S(&YO
M(&%T=')I8G5T97,@:6X@9FEL92`E9FEL924G.PT*("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E(%!%05)?5$%32U]%4E)/4E]74D].1U]!
M5%1224)?5D%,544@.@T*("`@("`@("`@("`@("`@("1I;F9O(#T@87)R87DH
M)V%T=')I8B<@/3X@)')E=%LQ72P@)W9A;'5E<R<@/3X@)')E=%LS72P-"B`@
M("`@("`@("`@("`@("`@("`@)W=A<R<@/3X@)')E=%LR72P@)W1A<VLG(#T^
M("1T87-K+"`G9FEL92<@/3X@)&9I;&4I.PT*("`@("`@("`@("`@("`@("1M
M<V<@/2`G=&%S:R`\)71A<VLE/B!A='1R:6)U=&4@(B5A='1R:6(E(B!H87,@
M=&AE('=R;VYG('9A;'5E("(E=V%S)2(@)RX-"B`@("`@("`@("`@("`@("`@
M("`@)VEN(&9I;&4@)69I;&4E+"!E>'!E8W1I;F<@;VYE(&]F("(E=F%L=65S
M)2(G.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E(%!%
M05)?5$%32U]%4E)/4E])3E9!3$E$(#H-"B`@("`@("`@("`@("`@("`D:6YF
M;R`](&%R<F%Y*"=R96%S;VXG(#T^("1R971;,5TL("=T87-K)R`]/B`D=&%S
M:RP@)V9I;&4G(#T^("1F:6QE*3L-"B`@("`@("`@("`@("`@("`D;7-G(#T@
M)W1A<VL@/"5T87-K)3X@:6X@9FEL92`E9FEL924@:7,@:6YV86QI9"!B96-A
M=7-E(&]F("(E<F5A<V]N)2(G.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L("1I;F9O+"`D;7-G*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?=6YK;F]W;E1A<VLH)'1A<VLL("1F:6QE*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L
M(&%R<F%Y*"=T87-K)R`]/B`D=&%S:RP@)V9I;&4G(#T^("1F:6QE*2P-"B`@
M("`@("`@("`@("=5;FMN;W=N('1A<VL@(B5T87-K)2(@<&%S<V5D(&EN(&9I
M;&4@/&9I;&4@;F%M93TB)69I;&4E(CXG*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?<W5B<&%C:V%G94-A;FYO=%!R;W9I9&5%>'1E;G-I;VXH)&YA;64I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)
M3TY?7RP@)V5R<F]R)RP@87)R87DH)VYA;64G(#T^("1N86UE*2P-"B`@("`@
M("`@("`@("=3=6)P86-K86=E(&1E<&5N9&5N8WD@(B5N86UE)2(@8V%N;F]T
M('5S92`\<')O=FED97-E>'1E;G-I;VX^+"`G("X-"B`@("`@("`@("`@("=O
M;FQY('!A8VMA9V4@9&5P96YD96YC:65S(&-A;B!U<V4@=&AI<R!T86<G*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?<W5B<&%C:V%G97-#86YN;W1#;VYF
M;&EC="@D;F%M92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U
M<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G;F%M92<@/3X@)&YA
M;64I+`T*("`@("`@("`@("`@)U-U8G!A8VMA9V4@9&5P96YD96YC>2`B)6YA
M;64E(B!C86YN;W0@=7-E(#QC;VYF;&EC=',O/BP@)R`N#0H@("`@("`@("`@
M("`G;VYL>2!P86-K86=E(&1E<&5N9&5N8VEE<R!C86X@=7-E('1H:7,@=&%G
M)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V-A;FYO=%!R;W9I9&5%>'1E
M;G-I;VXH)')E;&5A<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W)E;&5A<V4G
M(#T^("1R96QE87-E*2P-"B`@("`@("`@("`@("<\)7)E;&5A<V4E/B!P86-K
M86=E<R!C86YN;W0@=7-E(#QP<F]V:61E<V5X=&5N<VEO;CXL(&]N;'D@97AT
M8FEN<F5L96%S92!A;F0@97AT<W)C<F5L96%S92!C86X@<')O=FED92!A(%!(
M4"!E>'1E;G-I;VXG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?;75S=%!R
M;W9I9&5%>'1E;G-I;VXH)')E;&5A<V4I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH
M)W)E;&5A<V4G(#T^("1R96QE87-E*2P-"B`@("`@("`@("`@("<\)7)E;&5A
M<V4E/B!P86-K86=E<R!M=7-T('5S92`\<')O=FED97-E>'1E;G-I;VX^('1O
M(&EN9&EC871E('=H:6-H(%!(4"!E>'1E;G-I;VX@:7,@<')O=FED960G*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?8V%N;F]T2&%V95-R8W!A8VMA9V4H
M)')E;&5A<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H
M*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W)E;&5A<V4G(#T^("1R
M96QE87-E*2P-"B`@("`@("`@("`@("<\)7)E;&5A<V4E/B!P86-K86=E<R!C
M86YN;W0@<W!E8VEF>2!A('-O=7)C92!C;V1E('!A8VMA9V4L(&]N;'D@97AT
M96YS:6]N(&)I;F%R:65S(&UA>2!U<V4@=&AE(#QS<F-P86-K86=E/B!T86<G
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?;75S=%-R8U!A8VMA9V4H)')E
M;&5A<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W)E;&5A<V4G(#T^("1R96QE
M87-E*2P-"B`@("`@("`@("`@("<\97AT8FEN<F5L96%S93X@<&%C:V%G97,@
M;75S="!S<&5C:69Y(&$@<V]U<F-E(&-O9&4@<&%C:V%G92!W:71H(#QS<F-P
M86-K86=E/B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]M=7-T4W)C=7)I
M*"1R96QE87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D
M<F5L96%S92DL#0H@("`@("`@("`@("`G/&5X=&)I;G)E;&5A<V4^('!A8VMA
M9V5S(&UU<W0@<W!E8VEF>2!A('-O=7)C92!C;V1E('!A8VMA9V4@=VET:"`\
M<W)C=7)I/B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]U<FE$97!S0V%N
M;F]T2&%V959E<G-I;VYI;F<H)'1Y<&4I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH
M)W1Y<&4G(#T^("1T>7!E*2P-"B`@("`@("`@("`@("<E='EP924Z(&1E<&5N
M9&5N8VEE<R!W:71H(&$@/'5R:3X@=&%G(&-A;FYO="!H879E(&%N>2!V97)S
M:6]N:6YG(&EN9F]R;6%T:6]N)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7V-O;F9L:6-T:6YG1&5P<T-A;FYO=$AA=F5697)S:6]N:6YG*"1T>7!E*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92DL#0H@("`@("`@
M("`@("`G)71Y<&4E.B!C;VYF;&EC=&EN9R!D97!E;F1E;F-I97,@8V%N;F]T
M(&AA=F4@=F5R<VEO;FEN9R!I;F9O+"!U<V4@/&5X8VQU9&4^('1O("<@+@T*
M("`@("`@("`@("`@)V5X8VQU9&4@<W!E8VEF:6,@=F5R<VEO;G,@;V8@82!D
M97!E;F1E;F-Y)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7T1E<&-H86YN
M96Q#86YN;W1"955R:2@D='EP92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G='EP
M92<@/3X@)'1Y<&4I+`T*("`@("`@("`@("`@)R5T>7!E)3H@8VAA;FYE;"!C
M86YN;W0@8F4@7U]U<FDL('1H:7,@:7,@82!P<V5U9&\M8VAA;FYE;"!R97-E
M<G9E9"!F;W(@=7)I("<@+@T*("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R!O
M;FQY)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V)U;F1L961086-K86=E
M<TUU<W1"949I;&5N86UE*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@I+`T*("`@
M("`@("`@("`@)SQB=6YD;&5D<&%C:V%G93X@=&%G<R!M=7-T(&-O;G1A:6X@
M;VYL>2!T:&4@9FEL96YA;64@;V8@82!P86-K86=E(')E;&5A<V4@)R`N#0H@
M("`@("`@("`@("`G:6X@=&AE(&)U;F1L92<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]B:6YA<GE086-K86=E375S=$)E4&%C:V%G96YA;64H*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L
M("=E<G)O<B<L(&%R<F%Y*"DL#0H@("`@("`@("`@("`G/&)I;F%R>7!A8VMA
M9V4^('1A9W,@;75S="!C;VYT86EN('1H92!N86UE(&]F(&$@<&%C:V%G92!T
M:&%T(&ES("<@+@T*("`@("`@("`@("`@)V$@8V]M<&EL960@=F5R<VEO;B!O
M9B!T:&ES(&5X='-R8R!P86-K86=E)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@7V9I;&5.;W1&;W5N9"@D9FEL92D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G
M9FEL92<@/3X@)&9I;&4I+`T*("`@("`@("`@("`@)T9I;&4@(B5F:6QE)2(@
M:6X@<&%C:V%G92YX;6P@9&]E<R!N;W0@97AI<W0G*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?;F]T26Y#;VYT96YT<R@D9FEL92P@)'1A9RD-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@G9FEL92<@/3X@)&9I;&4L("=T86<G(#T^("1T86<I
M+`T*("`@("`@("`@("`@)SPE=&%G)2!N86UE/2(E9FEL924B/B!I<R!I;G9A
M;&ED+"!F:6QE(&ES(&YO="!I;B`\8V]N=&5N=',^)RD[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@7V-A;FYO=%9A;&ED871E3F]0871H4V5T*"D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@I+`T*("`@("`@("`@("`@)T-A;FYO="!V86QI9&%T
M92!F:6QE<RP@;F\@<&%T:"!T;R!P86-K86=E(&9I;&4@:7,@<V5T("AU<V4@
M<V5T4&%C:V%G949I;&4H*2DG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?
M=7-E<W)O;&5T87-K375S=$AA=F5#:&%N;F5L3W)5<FDH)')O;&4L("1T86<I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)
M3TY?7RP@)V5R<F]R)RP@87)R87DH)W)O;&4G(#T^("1R;VQE+"`G=&%G)R`]
M/B`D=&%G*2P-"B`@("`@("`@("`@("<\)71A9R4^(&UU<W0@8V]N=&%I;B!E
M:71H97(@/'5R:3XL(&]R(#QC:&%N;F5L/B!A;F0@/'!A8VMA9V4^)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7W5S97-R;VQE=&%S:TUU<W1(879E4&%C
M:V%G92@D<F]L92P@)'1A9RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G<F]L92<@
M/3X@)')O;&4L("=T86<G(#T^("1T86<I+`T*("`@("`@("`@("`@)SPE=&%G
M)3X@;75S="!C;VYT86EN(#QP86-K86=E/B<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]U<V5S<F]L971A<VM-=7-T2&%V95)O;&5487-K*"1T86<L("1T
M>7!E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T86<G(#T^("1T86<L("=T>7!E
M)R`]/B`D='EP92DL#0H@("`@("`@("`@("`G/"5T86<E/B!M=7-T(&-O;G1A
M:6X@/"5T>7!E)3X@9&5F:6YI;F<@=&AE("5T>7!E)2!T;R!B92!U<V5D)RD[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V-A;FYO=$-O;F9L:6-T5VET:$%L
M;$]S*"1T>7!E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T86<G(#T^("1T86<I
M+`T*("`@("`@("`@("`@)R5T86<E(&-A;FYO="!C;VYF;&EC="!W:71H(&%L
M;"!/4V5S)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN=F%L:61$97!'
M<F]U<$YA;64H)&YA;64I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V=R;W5P)R`]
M/B`D;F%M92DL#0H@("`@("`@("`@("`G26YV86QI9"!D97!E;F1E;F-Y(&=R
M;W5P(&YA;64@(B5N86UE)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?
M86YA;'EZ94)U;F1L961086-K86=E<R@I#0H@("`@>PT*("`@("`@("!I9B`H
M(21T:&ES+3Y?:7-686QI9"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/E]P9BT^9V5T4&%C
M:V%G951Y<&4H*2`]/2`G8G5N9&QE)RD@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P9BT^7W!A8VMA9V5&:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1D:7)?<')E9FEX(#T@9&ER;F%M
M92@D=&AI<RT^7W!F+3Y?<&%C:V%G949I;&4I.PT*("`@("`@("`D;&]G(#T@
M:7-S970H)'1H:7,M/E]P9BT^7VQO9V=E<BD@/R!A<G)A>2@F)'1H:7,M/E]P
M9BT^7VQO9V=E<BP@)VQO9R<I(#H-"B`@("`@("`@("`@(&%R<F%Y*"=014%2
M7T-O;6UO;B<L("=L;V<G*3L-"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W!F
M+3YG971#;VYT96YT<R@I.PT*("`@("`@("`D:6YF;R`]("1I;F9O6R=B=6YD
M;&5D<&%C:V%G92==.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I;F9O*2D@
M>PT*("`@("`@("`@("`@)&EN9F\@/2!A<G)A>2@D:6YF;RD[#0H@("`@("`@
M('T-"B`@("`@("`@)'!K9R`]("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI
M<RT^7W!F+3Y?8V]N9FEG*3L-"B`@("`@("`@9F]R96%C:"`H)&EN9F\@87,@
M)'!A8VMA9V4I('L-"B`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&1I
M<E]P<F5F:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!A8VMA9V4I*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F:6QE3F]T1F]U;F0H)&1I<E]P
M<F5F:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!A8VMA9V4I.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8U]A<G)A>2@D;&]G+"!A<G)A>2@Q+"`B06YA;'EZ:6YG
M(&)U;F1L960@<&%C:V%G92`D<&%C:V%G92(I*3L-"B`@("`@("`@("`@(%!%
M05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@("`@("1R970@/2`D<&MG+3YF<F]M06YY1FEL92@D9&ER7W!R969I
M>"`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&%C:V%G92P-"B`@("`@("`@
M("`@("`@("!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@("`@("!0
M14%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E
M<E]F=6YC7V%R<F%Y*"1L;V<L(&%R<F%Y*#`L(")%4E)/4CH@<&%C:V%G92`D
M<&%C:V%G92!I<R!N;W0@82!V86QI9"`B("X-"B`@("`@("`@("`@("`@("`@
M("`@)W!A8VMA9V4G*2D[#0H@("`@("`@("`@("`@("`@)&EN9B`]("1R970M
M/F=E=%5S97));F9O*"D[#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1I;F8I*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F8@
M87,@)&5R<BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@8V%L;%]U<V5R
M7V9U;F-?87)R87DH)&QO9RP@87)R87DH,2P@)&5R<ELG;65S<V%G92==*2D[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%]A;F%L>7IE4&AP1FEL97,H*0T*("`@('L-"B`@("`@("`@
M:68@*"$D=&AI<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&8M/E]P86-K86=E1FEL92DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8V%N
M;F]T5F%L:61A=&5.;U!A=&A3970H*3L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9&ER7W!R969I>"`](&1I<FYA
M;64H)'1H:7,M/E]P9BT^7W!A8VMA9V5&:6QE*3L-"B`@("`@("`@)&-O;6UO
M;B`](&YE=R!014%27T-O;6UO;CL-"B`@("`@("`@)&QO9R`](&ES<V5T*"1T
M:&ES+3Y?<&8M/E]L;V=G97(I(#\@87)R87DH)B1T:&ES+3Y?<&8M/E]L;V=G
M97(L("=L;V<G*2`Z#0H@("`@("`@("`@("!A<G)A>2@F)&-O;6UO;BP@)VQO
M9R<I.PT*("`@("`@("`D:6YF;R`]("1T:&ES+3Y?<&8M/F=E=$-O;G1E;G1S
M*"D[#0H@("`@("`@("1I;F9O(#T@)&EN9F];)V1I<B==6R=F:6QE)UT[#0H@
M("`@("`@(&EF("AI<W-E="@D:6YF;ULG871T<FEB<R==*2D@>PT*("`@("`@
M("`@("`@)&EN9F\@/2!A<G)A>2@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'!R;W9I9&5S(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&EN
M9F\@87,@)&9A*2![#0H@("`@("`@("`@("`D9F$@/2`D9F%;)V%T=')I8G,G
M73L-"B`@("`@("`@("`@("1F:6QE(#T@)&9A6R=N86UE)UT[#0H@("`@("`@
M("`@("!I9B`H(69I;&5?97AI<W1S*"1D:7)?<')E9FEX("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9FEL94YO=$9O=6YD*"1D:7)?<')E9FEX("X@1$E214-43U)97U-%4$%2
M051/4B`N("1F:6QE*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2`P.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1F85LG<F]L92==+"!0
M14%27TEN<W1A;&QE<E]2;VQE.CIG9710:'!2;VQE<R@I*2`F)B`D9&ER7W!R
M969I>"D@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y
M*"1L;V<L(&%R<F%Y*#$L(")!;F%L>7II;F<@)&9I;&4B*2D[#0H@("`@("`@
M("`@("`@("`@)'-R8VEN9F\@/2`D=&AI<RT^86YA;'EZ95-O=7)C94-O9&4H
M)&1I<E]P<F5F:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4I.PT*
M("`@("`@("`@("`@("`@(&EF("@D<W)C:6YF;RD@>PT*("`@("`@("`@("`@
M("`@("`@("`D<')O=FED97,@/2!A<G)A>5]M97)G92@D<')O=FED97,L("1T
M:&ES+3Y?8G5I;&10<F]V:61E<T%R<F%Y*"1S<F-I;F9O*2D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94YA;64@/2`D<&X@/2`D=&AI<RT^7W!F+3YG9710
M86-K86=E*"D[#0H@("`@("`@("1P;FP@/2!S=')L96XH)'!N*3L-"B`@("`@
M("`@9F]R96%C:"`H)'!R;W9I9&5S(&%S("1K97D@/3X@)'=H870I('L-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D=VAA=%LG97AP;&EC:70G72D@?'P@(21W
M:&%T*2![#0H@("`@("`@("`@("`@("`@+R\@<VMI<"!C;VYF;W)M86YC92!C
M:&5C:W,@:68@=&AE('!R;W9I9&5S(&5N=')Y(&ES#0H@("`@("`@("`@("`@
M("`@+R\@<W!E8VEF:65D(&EN('1H92!P86-K86=E+GAM;"!F:6QE#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!E>'1R86-T*"1W:&%T*3L-"B`@("`@("`@("`@(&EF("@D='EP92`]
M/2`G8VQA<W,G*2![#0H@("`@("`@("`@("`@("`@:68@*"%S=')N8V%S96-M
M<"@D;F%M92P@)'!N+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=W87)N:6YG)RP-
M"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F:6QE+"`G
M='EP92<@/3X@)'1Y<&4L("=N86UE)R`]/B`D;F%M92P@)W!A8VMA9V4G(#T^
M("1P;BDL#0H@("`@("`@("`@("`@("`@("`@("=I;B`E9FEL924Z("5T>7!E
M)2`B)6YA;64E(B!N;W0@<')E9FEX960@=VET:"!P86-K86=E(&YA;64@(B5P
M86-K86=E)2(G*3L-"B`@("`@("`@("`@('T@96QS96EF("@D='EP92`]/2`G
M9G5N8W1I;VXG*2![#0H@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D;F%M
M92P@)SHZ)RD@?'P@(7-T<FYC87-E8VUP*"1N86UE+"`D<&XL("1P;FPI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)W=A<FYI;F<G+`T*("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEL92<@/3X@)&9I;&4L("=T>7!E)R`]/B`D='EP92P@)VYA;64G
M(#T^("1N86UE+"`G<&%C:V%G92<@/3X@)'!N*2P-"B`@("`@("`@("`@("`@
M("`@("`@)VEN("5F:6QE)3H@)71Y<&4E("(E;F%M924B(&YO="!P<F5F:7AE
M9"!W:71H('!A8VMA9V4@;F%M92`B)7!A8VMA9V4E(B<I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7VES5F%L
M:60[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@06YA;'EZ92!T:&4@<V]U
M<F-E(&-O9&4@;V8@=&AE(&=I=F5N(%!(4"!F:6QE#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@('-T<FEN9R!&:6QE;F%M92!O9B!T:&4@4$A0(&9I;&4-"B`@
M("`@*B!`<&%R86T@(&)O;VQE86X@=VAE=&AE<B!T;R!A;F%L>7IE("1F:6QE
M(&%S('1H92!F:6QE(&-O;G1E;G1S#0H@("`@("H@0')E='5R;B!M:7AE9`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&%N86QY>F53;W5R8V5#;V1E*"1F:6QE
M+"`D<W1R:6YG(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(69U;F-T
M:6]N7V5X:7-T<R@B=&]K96Y?9V5T7V%L;"(I*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R
M87DH)V9I;&4G(#T^("1F:6QE*2P-"B`@("`@("`@("`@("`@("`G4&%R<V5R
M(&5R<F]R.B!T;VME;E]G971?86QL*"D@9G5N8W1I;VX@;75S="!E>&ES="!T
M;R!A;F%L>7IE('-O=7)C92!C;V1E)RD[#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%D969I;F5D*"=47T1/
M0U]#3TU-14Y4)RDI('L-"B`@("`@("`@("`@(&1E9FEN92@G5%]$3T-?0T]-
M345.5"<L(%1?0T]-345.5"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%D
M969I;F5D*"=47TE.5$521D%#12<I*2![#0H@("`@("`@("`@("!D969I;F4H
M)U1?24Y415)&04-%)RP@+3$I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M9&5F:6YE9"@G5%])35!,14U%3E13)RDI('L-"B`@("`@("`@("`@(&1E9FEN
M92@G5%])35!,14U%3E13)RP@+3$I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D<W1R:6YG*2![#0H@("`@("`@("`@("`D8V]N=&5N=',@/2`D9FEL93L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@A)&9P(#T@0&9O
M<&5N*"1F:6QE+"`B<B(I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@("`@("1C;VYT96YT<R`]
M(&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@0&9R96%D*"1F<"P@
M9FEL97-I>F4H)&9I;&4I*3L-"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&]K96YS
M(#T@=&]K96Y?9V5T7V%L;"@D8V]N=&5N=',I.PT*+RH-"B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@<VEZ96]F*"1T;VME;G,I.R`D:2LK*2![#0H@("`@
M("`@("`@("!`;&ES="@D=&]K96XL("1D871A*2`]("1T;VME;G-;)&E=.PT*
M("`@("`@("`@("`@:68@*&ES7W-T<FEN9R@D=&]K96XI*2![#0H@("`@("`@
M("`@("`@("`@=F%R7V1U;7`H)'1O:V5N*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<')I;G0@=&]K96Y?;F%M92@D=&]K96XI
M("X@)R`G.PT*("`@("`@("`@("`@("`@('9A<E]D=6UP*')T<FEM*"1D871A
M*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"BHO#0H@("`@("`@("1L
M;V]K7V9O<B`](#`[#0H@("`@("`@("1P87)E;E]L979E;"`](#`[#0H@("`@
M("`@("1B<F%C:V5T7VQE=F5L(#T@,#L-"B`@("`@("`@)&)R86-E7VQE=F5L
M(#T@,#L-"B`@("`@("`@)&QA<W1P:'!D;V,@/2`G)SL-"B`@("`@("`@)&-U
M<G)E;G1?8VQA<W,@/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?:6YT97)F86-E
M(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V-L87-S7VQE=F5L(#T@+3$[#0H@
M("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@("1C=7)R
M96YT7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@("`@("`@("1D96-L87)E9%]C
M;&%S<V5S(#T@87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C
M97,@/2!A<G)A>2@I.PT*("`@("`@("`D9&5C;&%R961?9G5N8W1I;VYS(#T@
M87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7VUE=&AO9',@/2!A<G)A>2@I
M.PT*("`@("`@("`D=7-E9%]C;&%S<V5S(#T@87)R87DH*3L-"B`@("`@("`@
M)'5S961?9G5N8W1I;VYS(#T@87)R87DH*3L-"B`@("`@("`@)&5X=&5N9',@
M/2!A<G)A>2@I.PT*("`@("`@("`D:6UP;&5M96YT<R`](&%R<F%Y*"D[#0H@
M("`@("`@("1N;V1E<',@/2!A<G)A>2@I.PT*("`@("`@("`D:6YQ=6]T92`]
M(&9A;'-E.PT*("`@("`@("`D:6YT97)F86-E(#T@9F%L<V4[#0H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T;VME;G-;)&E=*2D@>PT*("`@
M("`@("`@("`@("`@(&QI<W0H)'1O:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I
M73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1O
M:V5N(#T@)'1O:V5N<ULD:5T[#0H@("`@("`@("`@("`@("`@)&1A=&$@/2`G
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:6YQ=6]T92D@
M>PT*("`@("`@("`@("`@("`@(&EF("@D=&]K96X@(3T@)R(G("8F("1T;VME
M;B`A/2!47T5.1%](15)%1$]#*2![#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1I;G%U;W1E(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('-W:71C:"`H)'1O:V5N*2![#0H@("`@("`@("`@
M("`@("`@8V%S92!47U=(251%4U!!0T4@.@T*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!C87-E("<[)SH-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1I;G1E<F9A8V4I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]("TQ
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)R(G.@T*("`@("`@("`@
M("`@("`@(&-A<V4@5%]35$%25%](15)%1$]#.@T*("`@("`@("`@("`@("`@
M("`@("`D:6YQ=6]T92`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]#55),65]/4$5..@T*("`@
M("`@("`@("`@("`@(&-A<V4@5%]$3TQ,05)?3U!%3E]#55),65]"4D%#15,Z
M#0H@("`@("`@("`@("`@("`@8V%S92`G>R<Z("1B<F%C95]L979E;"LK.R!C
M;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@)WTG.@T*("`@("`@
M("`@("`@("`@("`@("`D8G)A8V5?;&5V96PM+3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1C=7)R96YT7V-L87-S7VQE=F5L(#T]("1B<F%C95]L979E
M;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W,@
M/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S
M7VQE=F5L(#T@+3$[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T]("1B
M<F%C95]L979E;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?9G5N8W1I;VX@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1C
M=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@
M("`@("`@("`@("!C87-E("=;)SH@)&)R86-K971?;&5V96PK*SL@8V]N=&EN
M=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("==)SH@)&)R86-K971?;&5V
M96PM+3L@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("<H)SH@
M)'!A<F5N7VQE=F5L*RL[("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@
M("!C87-E("<I)SH@)'!A<F5N7VQE=F5L+2T[("`@8V]N=&EN=64@,CL-"B`@
M("`@("`@("`@("`@("!C87-E(%1?24Y415)&04-%.@T*("`@("`@("`@("`@
M("`@("`@("`D:6YT97)F86-E(#T@=')U93L-"B`@("`@("`@("`@("`@("!C
M87-E(%1?0TQ!4U,Z#0H@("`@("`@("`@("`@("`@("`@(&EF("@H)&-U<G)E
M;G1?8VQA<W-?;&5V96P@(3T@+3$I('Q\("@D8W5R<F5N=%]F=6YC=&EO;E]L
M979E;"`A/2`M,2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G
M9FEL92<@/3X@)&9I;&4I+`T*("`@("`@("`@("`@("`@("`@("`@("`@)U!A
M<G-E<B!E<G)O<CH@:6YV86QI9"!02%`@9F]U;F0@:6X@9FEL92`B)69I;&4E
M(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8V%S92!4
M7T953D-424]..@T*("`@("`@("`@("`@("`@(&-A<V4@5%].15<Z#0H@("`@
M("`@("`@("`@("`@8V%S92!47T585$5.1%,Z#0H@("`@("`@("`@("`@("`@
M8V%S92!47TE-4$Q%345.5%,Z#0H@("`@("`@("`@("`@("`@("`@("1L;V]K
M7V9O<B`]("1T;VME;CL-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@
M,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?4U1224Y'.@T*("`@("`@("`@
M("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I
M+"`G,BXP)RP@)SPG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*'-T<G1O;&]W97(H)&1A=&$I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=P=6)L:6,G+"`G<')I=F%T92<L("=P<F]T
M96-T960G+"`G86)S=')A8W0G+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=I;G1E<F9A8V4G+"`G:6UP;&5M96YT<R<L("=T:')O=R<I
M(`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H
M7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9FEL92<@/3X@)&9I;&4I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G17)R;W(L(%!(4#4@=&]K96X@
M96YC;W5N=&5R960@:6X@)69I;&4E+"<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(&%N86QY<VES('-H;W5L9"!B92!I;B!02%`U)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1L;V]K7V9O<B`]/2!4
M7T-,05-3*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C
M;&%S<R`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?8VQA<W-?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5C;&%R961?8VQA<W-E<UM=(#T@)&-U<G)E;G1?8VQA
M<W,[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@
M/3T@5%])3E1%4D9!0T4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C
M=7)R96YT7VEN=&5R9F%C92`]("1D871A.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?:6YT97)F86-E<UM=
M(#T@)&-U<G)E;G1?:6YT97)F86-E.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?24U03$5-14Y44RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EM<&QE;65N='-;)&-U<G)E;G1?8VQA<W-=
M(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O
M:U]F;W(@/3T@5%]%6%1%3D13*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97AT96YD<ULD8W5R<F5N=%]C;&%S<UT@/2`D9&%T83L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47T953D-424].
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&-U<G)E;G1?8VQA
M<W,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F
M=6YC=&EO;B`]("(D8W5R<F5N=%]C;&%S<SHZ)&1A=&$B.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]M971H;V1S6R1C=7)R96YT
M7V-L87-S75M=(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&-U<G)E;G1?:6YT97)F86-E*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`B)&-U<G)E;G1?
M:6YT97)F86-E.CHD9&%T82([#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E8VQA<F5D7VUE=&AO9'-;)&-U<G)E;G1?:6YT97)F86-E75M=(#T@
M)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@
M)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D
M7V9U;F-T:6]N<UM=(#T@)&-U<G)E;G1?9G5N8W1I;VX[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=%]F=6YC=&EO;E]L979E;"`]("1B<F%C95]L979E;#L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1M(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47TY%5RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'5S961?8VQA<W-E<ULD9&%T85T@/2!T<G5E
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1L;V]K7V9O<B`](#`[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M(#([#0H@("`@("`@("`@("`@("`@8V%S92!47U9!4DE!0DQ%.@T*("`@("`@
M("`@("`@("`@("`@("`D;&]O:U]F;W(@/2`P.PT*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]$3T-?
M0T]-345.5#H-"B`@("`@("`@("`@("`@("!C87-E(%1?0T]-345.5#H-"B`@
M("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R%>+UPJ7"I<<R$G
M+"`D9&%T82DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1L87-T<&AP
M9&]C(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<')E
M9U]M871C:%]A;&PH)R]`;F]D97!<<RLH7%,K*2\G+"`D;&%S='!H<&1O8RP@
M)&TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&5P<R`]
M(&%R<F%Y7VUE<F=E*"1N;V1E<',L("1M6S%=*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@
M5%]$3U5"3$5?0T],3TXZ#0H@("`@("`@("`@("`@("`@("`@(&EF("@A*"1T
M;VME;G-;)&D@+2`Q75LP72`]/2!47U=(251%4U!!0T4@?'P@)'1O:V5N<ULD
M:2`M(#%=6S!=(#T](%1?4U1224Y'*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=W87)N
M:6YG)RP@87)R87DH)V9I;&4G(#T^("1F:6QE*2P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G4&%R<V5R(&5R<F]R.B!I;G9A;&ED(%!(4"!F;W5N
M9"!I;B!F:6QE("(E9FEL924B)RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)&-L87-S(#T@)'1O:V5N<ULD:2`M(#%=6S%=.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D8VQA<W,I("$]
M("=P87)E;G0G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=7-E9%]C
M;&%S<V5S6R1C;&%S<UT@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@
M("`@("`@(G-O=7)C95]F:6QE(B`]/B`D9FEL92P-"B`@("`@("`@("`@(")D
M96-L87)E9%]C;&%S<V5S(B`]/B`D9&5C;&%R961?8VQA<W-E<RP-"B`@("`@
M("`@("`@(")D96-L87)E9%]I;G1E<F9A8V5S(B`]/B`D9&5C;&%R961?:6YT
M97)F86-E<RP-"B`@("`@("`@("`@(")D96-L87)E9%]M971H;V1S(B`]/B`D
M9&5C;&%R961?;65T:&]D<RP-"B`@("`@("`@("`@(")D96-L87)E9%]F=6YC
M=&EO;G,B(#T^("1D96-L87)E9%]F=6YC=&EO;G,L#0H@("`@("`@("`@("`B
M=7-E9%]C;&%S<V5S(B`]/B!A<G)A>5]D:69F*&%R<F%Y7VME>7,H)'5S961?
M8VQA<W-E<RDL("1N;V1E<',I+`T*("`@("`@("`@("`@(FEN:&5R:71A;F-E
M(B`]/B`D97AT96YD<RP-"B`@("`@("`@("`@(")I;7!L96UE;G1S(B`]/B`D
M:6UP;&5M96YT<RP-"B`@("`@("`@("`@("D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0G5I;&0@82`B<')O=FED97,B(&%R<F%Y(&9R;VT@9&%T82!R
M971U<FYE9"!B>0T*("`@("`J(&%N86QY>F53;W5R8V5#;V1E*"DN("!4:&4@
M9F]R;6%T(&]F('1H92!B=6EL="!A<G)A>2!I<R!L:6ME#0H@("`@("H@=&AI
M<SH-"B`@("`@*@T*("`@("`J("!A<G)A>2@-"B`@("`@*B`@("`G8VQA<W,[
M37E#;&%S<R<@/3X@)V%R<F%Y*"=T>7!E)R`]/B`G8VQA<W,G+"`G;F%M92<@
M/3X@)TUY0VQA<W,G*2P-"B`@("`@*B`@("`N+BX-"B`@("`@*B`@*0T*("`@
M("`J#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87D@)'-R8VEN9F\@87)R
M87D@=VET:"!I;F9O<FUA=&EO;B!A8F]U="!A('-O=7)C92!F:6QE#0H@("`@
M("H@87,@<F5T=7)N960@8GD@=&AE(&%N86QY>F53;W5R8V5#;V1E*"D@;65T
M:&]D+@T*("`@("`J#0H@("`@("H@0')E='5R;B!V;VED#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*@T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]B=6EL9%!R;W9I9&5S07)R87DH)'-R8VEN9F\I#0H@("`@>PT*
M("`@("`@("!I9B`H(21T:&ES+3Y?:7-686QI9"D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@)'!R;W9I9&5S
M<F5T(#T@87)R87DH*3L-"B`@("`@("`@)&9I;&4@/2!B87-E;F%M92@D<W)C
M:6YF;ULG<V]U<F-E7V9I;&4G72D[#0H@("`@("`@("1P;B`]("1T:&ES+3Y?
M<&8M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@)'!N;"`]('-T<FQE;B@D<&XI
M.PT*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R961?8VQA<W-E
M<R==(&%S("1C;&%S<RD@>PT*("`@("`@("`@("`@)&ME>2`](")C;&%S<SLD
M8VQA<W,B.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]V:61E<W)E=%LD
M:V5Y72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1P<F]V:61E<W)E=%LD:V5Y72`]#0H@("`@
M("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L("=T>7!E)R`]/B`G
M8VQA<W,G+"`G;F%M92<@/3X@)&-L87-S*3L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D<W)C:6YF;ULG:6YH97)I=&%N8V4G75LD8VQA<W-=*2D@>PT*("`@
M("`@("`@("`@("`@("1P<F]V:61E<W)E=%LD:V5Y75LG97AT96YD<R==(#T-
M"B`@("`@("`@("`@("`@("`@("`@)'-R8VEN9F];)VEN:&5R:71A;F-E)UU;
M)&-L87-S73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F
M;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R961?;65T:&]D<R==(&%S("1C;&%S
M<R`]/B`D;65T:&]D<RD@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&UE=&AO
M9',@87,@)&UE=&AO9"D@>PT*("`@("`@("`@("`@("`@("1F=6YC=&EO;B`]
M("(D8VQA<W,Z.B1M971H;V0B.PT*("`@("`@("`@("`@("`@("1K97D@/2`B
M9G5N8W1I;VX[)&9U;F-T:6]N(CL-"B`@("`@("`@("`@("`@("!I9B`H)&UE
M=&AO9'LP?2`]/2`G7R<@?'P@(7-T<F-A<V5C;7`H)&UE=&AO9"P@)&-L87-S
M*2!\?`T*("`@("`@("`@("`@("`@("`@("!I<W-E="@D<')O=FED97-R971;
M)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<')O=FED97-R971;
M)&ME>5T@/0T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D
M9FEL92P@)W1Y<&4G(#T^("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I
M;VXI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@9F]R
M96%C:"`H)'-R8VEN9F];)V1E8VQA<F5D7V9U;F-T:6]N<R==(&%S("1F=6YC
M=&EO;BD@>PT*("`@("`@("`@("`@)&ME>2`](")F=6YC=&EO;CLD9G5N8W1I
M;VXB.PT*("`@("`@("`@("`@:68@*"1F=6YC=&EO;GLP?2`]/2`G7R<@?'P@
M:7-S970H)'!R;W9I9&5S<F5T6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%S
M=')S='(H)&9U;F-T:6]N+"`G.CHG*2`F)B!S=')N8V%S96-M<"@D9G5N8W1I
M;VXL("1P;BP@)'!N;"DI('L-"B`@("`@("`@("`@("`@("`D=V%R;FEN9W-;
M72`](")I;C$@(B`N("1F:6QE("X@(CH@9G5N8W1I;VX@7"(D9G5N8W1I;VY<
M(B!N;W0@<')E9FEX960@=VET:"!P86-K86=E(&YA;64@7"(D<&Y<(B([#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D<')O=FED97-R971;)&ME>5T@
M/0T*("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE+"`G='EP
M92<@/3X@)V9U;F-T:6]N)RP@)VYA;64G(#T^("1F=6YC=&EO;BD[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1P<F]V:61E<W)E=#L-"B`@("!]#0I]
M#0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4&%C
M:V%G949I;&4O=C(N<&AP````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,C$Q,S`T`#$P-3$U-#,Q,#4W`#`R,3(V-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27U!A
M8VMA9V5&:6QE7W8R+"!P86-K86=E+GAM;"!V97)S:6]N(#(N,`T*("H-"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!V,BYP:'`L=B`Q+C$R
M.2XR+C$@,C`P-B\P,R\R,R`P-#HP-SHU,2!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*+RHJ#0H@*B!&;W(@97)R;W(@:&%N9&QI;F<-"B`J+PT*
M<F5Q=6ER95]O;F-E("=014%2+T5R<F]R4W1A8VLN<&AP)SL-"B\J*@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?=C(-"GL-
M"@T*("`@("\J*@T*("`@("`J(%!A<G-E9"!P86-K86=E(&EN9F]R;6%T:6]N
M#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5);F9O(#T@87)R87DH*3L-"@T*
M("`@("\J*@T*("`@("`J('!A=&@@=&\@<&%C:V%G92`N=&=Z(&]R(&9A;'-E
M(&EF('1H:7,@:7,@82!L;V-A;"]E>'1R86-T960@<&%C:V%G92YX;6P-"B`@
M("`@*B!`=F%R('-T<FEN9WQF86QS90T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@('9A<B`D7V%R8VAI=F5&:6QE.PT*#0H@("`@+RHJ
M#0H@("`@("H@<&%T:"!T;R!P86-K86=E("YX;6P@;W(@9F%L<V4@:68@=&AI
M<R!I<R!A;B!A8G-T<F%C="!P87)S960M9G)O;2US=')I;F<@>&UL#0H@("`@
M("H@0'9A<B!S=')I;F=\9F%L<V4-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!V87(@)%]P86-K86=E1FEL93L-"@T*("`@("\J*@T*
M("`@("`J(%1H:7,@:7,@=7-E9"!B>2!F:6QE(&%N86QY<VES(')O=71I;F5S
M('1O(&QO9R!P<F]G<F5S<R!I;F9O<FUA=&EO;@T*("`@("`J($!V87(@4$5!
M4E]#;VUM;VX-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*
M("`@('9A<B`D7VQO9V=E<CL-"@T*("`@("\J*@T*("`@("`J(%1H:7,@:7,@
M<V5T('1O('1H92!H:6=H97-T('9A;&ED871I;VX@;&5V96P@=&AA="!H87,@
M8F5E;B!V86QI9&%T960-"B`@("`@*@T*("`@("`J($EF('1H92!P86-K86=E
M+GAM;"!I<R!I;G9A;&ED(&]R('5N:VYO=VXL('1H:7,@:7,@<V5T('1O(#`N
M("!)9@T*("`@("`J(&YO<FUA;"!V86QI9&%T:6]N(&AA<R!O8V-U<G)E9"P@
M=&AI<R!I<R!S970@=&\@4$5!4E]604Q)1$%415].3U)-04PN("!)9@T*("`@
M("`J(&1O=VYL;V%D:6YG+VEN<W1A;&QA=&EO;B!V86QI9&%T:6]N(&AA<R!O
M8V-U<G)E9"!I="!I<R!S970@=&\@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.
M1PT*("`@("`J(&]R($E.4U1!3$Q)3D<L(&%N9"!S;R!O;B!U<"!T;R!014%2
M7U9!3$E$051%7U!!0TM!1TE.1RX@(%1H:7,@86QL;W=S('9A;&ED871I;VX-
M"B`@("`@*B`B8V%C:&EN9R(@=&\@;V-C=7(L('=H:6-H(&ES('!A<G1I8W5L
M87)L>2!I;7!O<G1A;G0@9F]R('!A8VMA9V4@=F%L:61A=&EO;BP@<V\-"B`@
M("`@*B!T:&%T(%!(4"!F:6QE<R!A<F4@;F]T('9A;&ED871E9"!T=VEC90T*
M("`@("`J($!V87(@:6YT#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@=F%R("1?:7-686QI9"`](#`[#0H-"B`@("`O*BH-"B`@("`@
M*B!4<G5E(&EF('1H92!F:6QE;&ES="!H87,@8F5E;B!V86QI9&%T960-"B`@
M("`@*B!`<&%R86T@8F]O;`T*("`@("`J+PT*("`@('9A<B`D7V9I;&5S5F%L
M:60@/2!F86QS93L-"@T*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]296=I
M<W1R>0T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@
M=F%R("1?<F5G:7-T<GD[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?
M0V]N9FEG#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@
M("!V87(@)%]C;VYF:6<[#0H-"B`@("`O*BH-"B`@("`@*B!/<'1I;VYA;"!$
M97!E;F1E;F-Y(&=R;W5P(')E<75E<W1E9"!F;W(@:6YS=&%L;&%T:6]N#0H@
M("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]R97%U97-T961'<F]U<"`](&9A;'-E.PT*#0H@
M("`@+RHJ#0H@("`@("H@0'9A<B!014%27T5R<F]R4W1A8VL-"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D7W-T86-K.PT*
M#0H@("`@+RHJ#0H@("`@("H@3F%M97-P86-E('!R969I>"!U<V5D(&9O<B!T
M87-K<R!I;B!T:&ES('!A8VMA9V4N>&UL("T@=7-E('1A<VMS.B!W:&5N979E
M<B!P;W-S:6)L90T*("`@("`J+PT*("`@('9A<B`D7W1A<VMS3G,[#0H-"B`@
M("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AI<R!P86-K86=E
M9FEL92!W87,@:6YI=&EA;&EZ960@;VYL>2!W:71H('!A<G1I86P@<&%C:V%G
M92!I;F9O#0H@("`@("H-"B`@("`@*B!)9B!T:&ES('!A8VMA9V4@9FEL92!W
M87,@8V]N<W1R=6-T960@=FEA('!A<G-I;F<@4D535"P@:70@=VEL;"!O;FQY
M(&-O;G1A:6X-"B`@("`@*@T*("`@("`J("T@<&%C:V%G92!N86UE#0H@("`@
M("H@+2!C:&%N;F5L(&YA;64-"B`@("`@*B`M(&1E<&5N9&5N8VEE<R`-"B`@
M("`@*B!`=F%R(&)O;VQE86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]I;F-O;7!L971E(#T@=')U93L-"@T*("`@("\J
M*@T*("`@("`J($!V87(@4$5!4E]086-K86=E1FEL95]V,E]686QI9&%T;W(-
M"B`@("`@*B\-"B`@("!V87(@)%]V,E9A;&ED871O<CL-"@T*("`@("\J*@T*
M("`@("`J(%1H92!C;VYS=')U8W1O<B!M97)E;'D@<V5T<R!U<"!T:&4@<')I
M=F%T92!E<G)O<B!S=&%C:PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?
M4&%C:V%G949I;&5?=C(H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C
M:R`](&YE=R!014%27T5R<F]R4W1A8VLH)U!%05)?4&%C:V%G949I;&5?=C(G
M+"!F86QS92P@;G5L;"D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A
M;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1O(&UA:V4@=6YI="UT
M97-T:6YG(&5A<VEE<@T*("`@("`J($!P87)A;2!014%27T9R;VYT96YD7RH-
M"B`@("`@*B!`<&%R86T@87)R87D@;W!T:6]N<PT*("`@("`J($!P87)A;2!0
M14%27T-O;F9I9PT*("`@("`J($!R971U<FX@4$5!4E]$;W=N;&]A9&5R#0H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B`F9V5T4$5!4D1O=VYL;V%D97(H)B1I+"`D;RP@)B1C*0T*("`@('L-"B`@
M("`@("`@)'H@/2`F;F5W(%!%05)?1&]W;FQO861E<B@D:2P@)&\L("1C*3L-
M"B`@("`@("`@<F5T=7)N("1Z.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%1O(&UA:V4@=6YI="UT97-T:6YG(&5A<VEE<@T*("`@("`J($!P87)A;2!0
M14%27T-O;F9I9PT*("`@("`J($!P87)A;2!A<G)A>2!O<'1I;VYS#0H@("`@
M("H@0'!A<F%M(&%R<F%Y('!A8VMA9V4@;F%M92!A<R!R971U<FYE9"!F<F]M
M('M`;&EN:R!014%27U)E9VES=')Y.CIP87)S95!A8VMA9V5.86UE*"E]#0H@
M("`@("H@0'!A<F%M(&EN="!014%27U9!3$E$051%7RH@8V]N<W1A;G0-"B`@
M("`@*B!`<F5T=7)N(%!%05)?1&5P96YD96YC>3(-"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N("9G971014%21&5P
M96YD96YC>3(H)B1C+"`D;RP@)'`L("1S(#T@4$5!4E]604Q)1$%415])3E-4
M04Q,24Y'*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%
M05)?1&5P96YD96YC>3(G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+T1E<&5N9&5N8WDR+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@
M)'H@/2`F;F5W(%!%05)?1&5P96YD96YC>3(H)&,L("1O+"`D<"P@)',I.PT*
M("`@("`@("!R971U<FX@)'H[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T
M26YS=&%L;&5D0FEN87)Y*"D-"B`@("![#0H@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R<C8FEN87)Y<&%C:V%G92==*2`_("1T
M:&ES+3Y?<&%C:V%G94EN9F];)R-B:6YA<GEP86-K86=E)UT@.@T*("`@("`@
M("`@("`@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@26YS=&%L
M;&%T:6]N(&]F('-O=7)C92!P86-K86=E(&AA<R!F86EL960L(&%T=&5M<'0@
M=&\@9&]W;FQO860@86YD(&EN<W1A;&P@=&AE#0H@("`@("H@8FEN87)Y('9E
M<G-I;VX@;V8@=&AI<R!P86-K86=E+@T*("`@("`J($!P87)A;2!014%27TEN
M<W1A;&QE<@T*("`@("`J($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!I;G-T86QL0FEN87)Y*"8D:6YS=&%L;&5R*0T*("`@
M('L-"B`@("`@("`@:68@*"%/4U]724Y$3U=3*2![#0H@("`@("`@("`@("`D
M82`](&9A;'-E.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`]/2`G97AT
M<W)C)RD@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D:6YS=&%L;&5R
M+3YG971);G-T86QL4&%C:V%G97,H*2DI('L-"B`@("`@("`@("`@("`@("`D
M82`](&9A;'-E.PT*("`@("`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;G-T86QL97(M/F=E
M=$EN<W1A;&Q086-K86=E<R@I(&%S("1P*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1P+3YI<T5X=&5N<VEO;B@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V
M:61E<V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'`M/F=E=%!A8VMA9V54>7!E*"D@(3T@)V5X='-R8R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)&$[("\O('1H92!U<V5R('!R;V)A8FQY(&1O=VYL
M;V%D960@:70@<V5P87)A=&5L>0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V5X='-R8W)E;&5A<V4G
M75LG8FEN87)Y<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("1I;G-T
M86QL97(M/FQO9R@P+"`G071T96UP=&EN9R!T;R!D;W=N;&]A9"!B:6YA<GD@
M=F5R<VEO;B!O9B!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<V5X=&5N<VEO;B==("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("`D<&%R86US(#T@)'1H:7,M/E]P86-K
M86=E26YF;ULG97AT<W)C<F5L96%S92==6R=B:6YA<GEP86-K86=E)UT[#0H@
M("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2!\?"`A:7-S
M970H)'!A<F%M<ULP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"1P87)A;7,I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA
M;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%R
M86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M<ULD:5T@/2!A<G)A>2@G8VAA;FYE;"<@/3X@)'1H:7,M/E]P
M86-K86=E26YF;ULG8VAA;FYE;"==+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E)R`]/B`D<&%R86TL("=V97)S:6]N)R`]/B`D=&AI
M<RT^9V5T5F5R<VEO;B@I*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D9&P@/2`F)'1H:7,M
M/F=E=%!%05)$;W=N;&]A9&5R*"1I;G-T86QL97(M/G5I+"`D:6YS=&%L;&5R
M+3YG971/<'1I;VYS*"DL#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL
M97(M/F-O;F9I9RD[#0H@("`@("`@("`@("`@("`@)'9E<F)O<V4@/2`D9&PM
M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@("`@("`@("`@("`@)&1L
M+3YC;VYF:6<M/G-E="@G=F5R8F]S92<L("TQ*3L-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2D@>PT*("`@("`@("`@("`@
M("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[#0H@("`@("`@("`@("`@("`@("`@("1R970@/2`D9&PM/F1O=VYL
M;V%D*&%R<F%Y*"1P87)A;2DI.PT*("`@("`@("`@("`@("`@("`@("!014%2
M.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D<F5T*2`F)B!C;W5N="@D<F5T*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&1L+3YC;VYF
M:6<M/G-E="@G=F5R8F]S92<L("1V97)B;W-E*3L-"B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1R970I(#T](#$I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P9B`]("1R971;,%TM/F=E=%!A8VMA9V5&:6QE*"D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D97)R
M(#T@)&EN<W1A;&QE<BT^:6YS=&%L;"@D<F5T6S!=*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)R-B:6YA<GEP86-K86=E)UT@/2`D<F5T6S!=+3YG971086-K86=E*"D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@(FEN<W1A;&PB('-E;&8L
M('-O(&%L;"!D97!E;F1E;F-I97,@=VEL;"!W;W)K('1R86YS<&%R96YT;'D-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M+3YA9&1086-K86=E,B@D=&AI<RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&EN<W1A;&QE<BT^;&]G*#`L("=$;W=N;&]A9"!A;F0@:6YS=&%L
M;"!O9B!B:6YA<GD@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G
M94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D<&8M/F=E=$-H86YN96PH*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P
M86-K86=E)R`]/B`D<&8M/F=E=%!A8VMA9V4H*2DL('1R=64I("X@)R(@<W5C
M8V5S<V9U;"<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A(#T@
M87)R87DH)')E=%LP72P@)&5R<BD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QE<BT^;&]G*#`L("=$
M;W=N;&]A9"!A;F0@:6YS=&%L;"!O9B!B:6YA<GD@97AT96YS:6]N("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1P9BT^
M9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1P9BT^9V5T4&%C:V%G92@I*2P@
M=')U92D@+B`G(B!F86EL960G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V4@17AT
M96YS:6]N(&YA;64-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9710<F]V:61E
M<T5X=&5N<VEO;B@I#0H@("`@>PT*("`@("`@("!I9B`H:6Y?87)R87DH)'1H
M:7,M/F=E=%!A8VMA9V54>7!E*"DL(&%R<F%Y*"=E>'1S<F,G+"`G97AT8FEN
M)RDI*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG<')O=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E>'1E;G-I
M;VXG73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!%>'1E;G-I;VX@;F%M90T*("`@("`J($!R971U<FX@8F]O;`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&ES17AT96YS:6]N*"1E>'1E;G-I;VXI#0H@
M("`@>PT*("`@("`@("!I9B`H:6Y?87)R87DH)'1H:7,M/F=E=%!A8VMA9V54
M>7!E*"DL(&%R<F%Y*"=E>'1S<F,G+"`G97AT8FEN)RDI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E>'1E
M;G-I;VXG72`]/2`D97AT96YS:6]N.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!497-T<R!W
M:&5T:&5R(&5V97)Y('!A<G0@;V8@=&AE('!A8VMA9V4N>&UL(#$N,"!I<R!R
M97!R97-E;G1E9"!I;@T*("`@("`J('1H:7,@<&%C:V%G92YX;6P@,BXP#0H@
M("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C$-"B`@("`@*B!`<F5T
M=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T5Q=6EV86QE;G0H
M)'!F,2D-"B`@("![#0H@("`@("`@(&EF("@A)'!F,2D@>PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES
M+3YG971086-K86=E5'EP92@I(#T]("=B=6YD;&4G*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]S
M=&%C:RT^9V5T17)R;W)S*'1R=64I.PT*("`@("`@("!I9B`H(21P9C$M/G9A
M;&ED871E*%!%05)?5D%,241!5$5?3D]234%,*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1P87-S(#T@=')U
M93L-"B`@("`@("`@:68@*"1P9C$M/F=E=%!A8VMA9V4H*2`A/2`D=&AI<RT^
M9V5T4&%C:V%G92@I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1I9F9E<F5N
M=%!A8VMA9V4H)'!F,2T^9V5T4&%C:V%G92@I*3L-"B`@("`@("`@("`@("1P
M87-S(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P9C$M/F=E
M=%9E<G-I;VXH*2`A/2`D=&AI<RT^9V5T5F5R<VEO;B@I*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7V1I9F9E<F5N=%9E<G-I;VXH)'!F,2T^9V5T5F5R<VEO
M;B@I*3L-"B`@("`@("`@("`@("1P87-S(#T@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*'1R:6TH)'!F,2T^9V5T4W5M;6%R>2@I*2`A/2`D=&AI
M<RT^9V5T4W5M;6%R>2@I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1I9F9E
M<F5N=%-U;6UA<GDH)'!F,2T^9V5T4W5M;6%R>2@I*3L-"B`@("`@("`@("`@
M("1P87-S(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*'!R96=?
M<F5P;&%C92@G+UQS*R\G+"`G)RP@)'!F,2T^9V5T1&5S8W)I<'1I;VXH*2D@
M(3T-"B`@("`@("`@("`@("`@<')E9U]R97!L86-E*"<O7',K+R<L("<G+"`D
M=&AI<RT^9V5T1&5S8W)I<'1I;VXH*2DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?9&EF9F5R96YT1&5S8W)I<'1I;VXH)'!F,2T^9V5T1&5S8W)I<'1I;VXH
M*2D[#0H@("`@("`@("`@("`D<&%S<R`](&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D<&8Q+3YG9713=&%T92@I("$]("1T:&ES+3YG9713=&%T
M92@I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1I9F9E<F5N=%-T871E*"1P
M9C$M/F=E=%-T871E*"DI.PT*("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(7-T<G-T<BAP<F5G7W)E<&QA8V4H
M)R]<<RLO)RP@)R<L("1T:&ES+3YG971.;W1E<R@I*2P-"B`@("`@("`@("`@
M("`@<')E9U]R97!L86-E*"<O7',K+R<L("<G+"`D<&8Q+3YG971.;W1E<R@I
M*2DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&EF9F5R96YT3F]T97,H)'!F
M,2T^9V5T3F]T97,H*2D[#0H@("`@("`@("`@("`D<&%S<R`](&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@("1M>6UA:6YT86EN97)S(#T@)'1H:7,M/F=E
M=$UA:6YT86EN97)S*"D[#0H@("`@("`@("1Y;W5R;6%I;G1A:6YE<G,@/2`D
M<&8Q+3YG971-86EN=&%I;F5R<R@I.PT*("`@("`@("!F;W(@*"1I,2`](#`[
M("1I,2`\(&-O=6YT*"1Y;W5R;6%I;G1A:6YE<G,I.R`D:3$K*RD@>PT*("`@
M("`@("`@("`@)')E<V5T(#T@9F%L<V4[#0H@("`@("`@("`@("!F;W(@*"1I
M,B`](#`[("1I,B`\(&-O=6YT*"1M>6UA:6YT86EN97)S*3L@)&DR*RLI('L-
M"B`@("`@("`@("`@("`@("!I9B`H)&UY;6%I;G1A:6YE<G-;)&DR75LG:&%N
M9&QE)UT@/3T@)'EO=7)M86EN=&%I;F5R<ULD:3%=6R=H86YD;&4G72D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&UY;6%I;G1A:6YE<G-;)&DR75LG
M<F]L92==("$]("1Y;W5R;6%I;G1A:6YE<G-;)&DQ75LG<F]L92==*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I9F9E<F5N=%)O;&4H
M)&UY;6%I;G1A:6YE<G-;)&DR75LG:&%N9&QE)UTL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'EO=7)M86EN=&%I;F5R<ULD:3%=6R=R;VQE)UTL
M("1M>6UA:6YT86EN97)S6R1I,EU;)W)O;&4G72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%S<R`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;7EM86EN=&%I;F5R<ULD
M:3)=6R=E;6%I;"==("$]("1Y;W5R;6%I;G1A:6YE<G-;)&DQ75LG96UA:6PG
M72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E
M;G1%;6%I;"@D;7EM86EN=&%I;F5R<ULD:3)=6R=H86YD;&4G72P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D>6]U<FUA:6YT86EN97)S6R1I,5U;
M)V5M86EL)UTL("1M>6UA:6YT86EN97)S6R1I,EU;)V5M86EL)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&UY;6%I
M;G1A:6YE<G-;)&DR75LG;F%M92==("$]("1Y;W5R;6%I;G1A:6YE<G-;)&DQ
M75LG;F%M92==*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1I9F9E<F5N=$YA;64H)&UY;6%I;G1A:6YE<G-;)&DR75LG:&%N9&QE)UTL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'EO=7)M86EN=&%I;F5R
M<ULD:3%=6R=N86UE)UTL("1M>6UA:6YT86EN97)S6R1I,EU;)VYA;64G72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%S<R`](&9A;'-E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1M>6UA:6YT86EN97)S6R1I,ETI.PT*("`@("`@("`@("`@("`@("`@("`D
M;7EM86EN=&%I;F5R<R`](&%R<F%Y7W9A;'5E<R@D;7EM86EN=&%I;F5R<RD[
M#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1Y;W5R;6%I;G1A:6YE<G-;
M)&DQ72D[#0H@("`@("`@("`@("`@("`@("`@("1Y;W5R;6%I;G1A:6YE<G,@
M/2!A<G)A>5]V86QU97,H)'EO=7)M86EN=&%I;F5R<RD[#0H@("`@("`@("`@
M("`@("`@("`@("1R97-E="`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D<F5S970I('L-"B`@("`@("`@("`@("`@("`D:3$@
M/2`M,3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7W5N;6%T8VAE9$UA:6YT86EN97)S*"1M>6UA:6YT86EN97)S+"`D>6]U
M<FUA:6YT86EN97)S*3L-"B`@("`@("`@)&9I;&5L:7-T(#T@)'1H:7,M/F=E
M=$9I;&5L:7-T*"D[#0H@("`@("`@(&9O<F5A8V@@*"1P9C$M/F=E=$9I;&5L
M:7-T*"D@87,@)&9I;&4@/3X@)&%T=',I('L-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)&9I;&5L:7-T6R1F:6QE72DI('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VUI<W-I;F=&:6QE*"1F:6QE*3L-"B`@("`@("`@("`@("`@("`D
M<&%S<R`](&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D<&%S<SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&EF
M9F5R96YT4&%C:V%G92@D<&%C:V%G92D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G
M<&%C:V%G92<@/3X@)'!A8VMA9V4L#0H@("`@("`@("`@("`G<V5L9B<@/3X@
M)'1H:7,M/F=E=%!A8VMA9V4H*2DL#0H@("`@("`@("`@("`G<&%C:V%G92YX
M;6P@,2XP('!A8VMA9V4@(B5P86-K86=E)2(@9&]E<R!N;W0@;6%T8V@@(B5S
M96QF)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT5F5R
M<VEO;B@D=F5R<VEO;BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=F5R<VEO;B<@
M/3X@)'9E<G-I;VXL#0H@("`@("`@("`@("`G<V5L9B<@/3X@)'1H:7,M/F=E
M=%9E<G-I;VXH*2DL#0H@("`@("`@("`@("`G<&%C:V%G92YX;6P@,2XP('9E
M<G-I;VX@(B5V97)S:6]N)2(@9&]E<R!N;W0@;6%T8V@@(B5S96QF)2(G*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT4W1A=&4H)'-T871E
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-4
M24].7U\L("=E<G)O<B<L(&%R<F%Y*"=S=&%T92<@/3X@)'-T871E+`T*("`@
M("`@("`@("`@)W-E;&8G(#T^("1T:&ES+3YG9713=&%T92@I*2P-"B`@("`@
M("`@("`@("=P86-K86=E+GAM;"`Q+C`@<W1A=&4@(B5S=&%T924B(&1O97,@
M;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7V1I9F9E<F5N=%)O;&4H)&AA;F1L92P@)')O;&4L("1S96QF<F]L92D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?
M+"`G97)R;W(G+"!A<G)A>2@G:&%N9&QE)R`]/B`D:&%N9&QE+`T*("`@("`@
M("`@("`@)W)O;&4G(#T^("1R;VQE+"`G<V5L9B<@/3X@)'-E;&9R;VQE*2P-
M"B`@("`@("`@("`@("=P86-K86=E+GAM;"`Q+C`@;6%I;G1A:6YE<B`B)6AA
M;F1L924B(')O;&4@(B5R;VQE)2(@9&]E<R!N;W0@;6%T8V@@(B5S96QF)2(G
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT16UA:6PH)&AA
M;F1L92P@)&5M86EL+"`D<V5L9F5M86EL*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y
M*"=H86YD;&4G(#T^("1H86YD;&4L#0H@("`@("`@("`@("`G96UA:6PG(#T^
M("1E;6%I;"P@)W-E;&8G(#T^("1S96QF96UA:6PI+`T*("`@("`@("`@("`@
M)W!A8VMA9V4N>&UL(#$N,"!M86EN=&%I;F5R("(E:&%N9&QE)2(@96UA:6P@
M(B5E;6%I;"4B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N=$YA;64H)&AA;F1L92P@)&YA;64L
M("1S96QF;F%M92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U
M<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G:&%N9&QE)R`]/B`D
M:&%N9&QE+`T*("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+"`G<V5L9B<@
M/3X@)'-E;&9N86UE*2P-"B`@("`@("`@("`@("=P86-K86=E+GAM;"`Q+C`@
M;6%I;G1A:6YE<B`B)6AA;F1L924B(&YA;64@(B5N86UE)2(@9&]E<R!N;W0@
M;6%T8V@@(B5S96QF)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=6YM
M871C:&5D36%I;G1A:6YE<G,H)&UY+"`D>6]U<G,I#0H@("`@>PT*("`@("`@
M("!I9B`H)&UY*2![#0H@("`@("`@("`@("!A<G)A>5]W86QK*"1M>2P@8W)E
M871E7V9U;F-T:6]N*"<F)&DL("1K)RP@)R1I(#T@)&E;(FAA;F1L92)=.R<I
M*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G97)R;W(G+"!A<G)A>2@G:&%N9&QE<R<@/3X@)&UY*2P-"B`@("`@
M("`@("`@("`@("`G<&%C:V%G92YX;6P@,BXP(&AA<R!U;FUA=&-H960@97AT
M<F$@;6%I;G1A:6YE<G,@(B5H86YD;&5S)2(G*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'EO=7)S*2![#0H@("`@("`@("`@("!A<G)A>5]W86QK*"1Y
M;W5R<RP@8W)E871E7V9U;F-T:6]N*"<F)&DL("1K)RP@)R1I(#T@)&E;(FAA
M;F1L92)=.R<I*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H
M7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G:&%N9&QE<R<@/3X@)'EO
M=7)S*2P-"B`@("`@("`@("`@("`@("`G<&%C:V%G92YX;6P@,2XP(&AA<R!U
M;FUA=&-H960@97AT<F$@;6%I;G1A:6YE<G,@(B5H86YD;&5S)2(G*3L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D:69F97)E;G1.;W1E
M<R@D;F]T97,I#0H@("`@>PT*("`@("`@("`D=')U;F-N;W1E<R`]('-T<FQE
M;B@D;F]T97,I(#P@,C4@/R`D;F]T97,@.B!S=6)S='(H)&YO=&5S+"`P+"`R
M-"D@+B`G+BXN)SL-"B`@("`@("`@)'1R=6YC;7EN;W1E<R`]('-T<FQE;B@D
M=&AI<RT^9V5T3F]T97,H*2D@/"`R-2`_("1T:&ES+3YG971.;W1E<R@I(#H-
M"B`@("`@("`@("`@('-U8G-T<B@D=&AI<RT^9V5T3F]T97,H*2P@,"P@,C0I
M("X@)RXN+B<[#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G;F]T97,G(#T^("1T<G5N8VYO=&5S
M+`T*("`@("`@("`@("`@)W-E;&8G(#T^("1T<G5N8VUY;F]T97,I+`T*("`@
M("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!R96QE87-E(&YO=&5S("(E;F]T
M97,E(B!D;R!N;W0@;6%T8V@@(B5S96QF)2(G*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?9&EF9F5R96YT4W5M;6%R>2@D<W5M;6%R>2D-"B`@("![#0H@
M("`@("`@("1T<G5N8W-U;6UA<GD@/2!S=')L96XH)'-U;6UA<GDI(#P@,C4@
M/R`D<W5M;6%R>2`Z('-U8G-T<B@D<W5M;6%R>2P@,"P@,C0I("X@)RXN+B<[
M#0H@("`@("`@("1T<G5N8VUY<W5M;6%R>2`]('-T<FQE;B@D=&AI<RT^9V5T
M<W5M;6%R>2@I*2`\(#(U(#\@)'1H:7,M/F=E=%-U;6UA<GDH*2`Z#0H@("`@
M("`@("`@("!S=6)S='(H)'1H:7,M/F=E='-U;6UA<GDH*2P@,"P@,C0I("X@
M)RXN+B<[#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G97)R;W(G+"!A<G)A>2@G<W5M;6%R>2<@/3X@)'1R=6YC<W5M;6%R
M>2P-"B`@("`@("`@("`@("=S96QF)R`]/B`D=')U;F-M>7-U;6UA<GDI+`T*
M("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!S=6UM87)Y("(E<W5M;6%R
M>24B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7V1I9F9E<F5N=$1E<V-R:7!T:6]N*"1D97-C<FEP=&EO;BD-
M"B`@("![#0H@("`@("`@("1T<G5N8V1E<V-R:7!T:6]N(#T@=')I;2AS=')L
M96XH)&1E<V-R:7!T:6]N*2`\(#(U(#\@)&1E<V-R:7!T:6]N(#H@<W5B<W1R
M*"1D97-C<FEP=&EO;BP@,"P@,C0I("X@)RXN+B<I.PT*("`@("`@("`D=')U
M;F-M>61E<V-R:7!T:6]N(#T@=')I;2AS=')L96XH)'1H:7,M/F=E=$1E<V-R
M:7!T:6]N*"DI(#P@,C4@/R`D=&AI<RT^9V5T1&5S8W)I<'1I;VXH*2`Z#0H@
M("`@("`@("`@("!S=6)S='(H)'1H:7,M/F=E=&1E<V-R:7!T:6]N*"DL(#`L
M(#(T*2`N("<N+BXG*3L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?
M7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=D97-C<FEP=&EO;B<@/3X@
M)'1R=6YC9&5S8W)I<'1I;VXL#0H@("`@("`@("`@("`G<V5L9B<@/3X@)'1R
M=6YC;7ED97-C<FEP=&EO;BDL#0H@("`@("`@("`@("`G<&%C:V%G92YX;6P@
M,2XP(&1E<V-R:7!T:6]N("(E9&5S8W)I<'1I;VXE(B!D;V5S(&YO="!M871C
M:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]M:7-S:6YG
M1FEL92@D9FEL92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U
M<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G9FEL92<@/3X@)&9I
M;&4I+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!F:6QE("(E9FEL
M924B(&ES(&YO="!P<F5S96YT(&EN(#QC;VYT96YT<SXG*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!705).24Y'("T@9&\@;F]T('5S92!T:&ES(&9U
M;F-T:6]N('5N;&5S<R!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=%)A=U-T871E*"1S=&%T92D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==6R=R
M96QE87-E)UT@/2`D<W1A=&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M5T%23DE.1R`M(&1O(&YO="!U<V4@=&AI<R!F=6YC=&EO;B!U;FQE<W,@>6]U
M(&MN;W<@=VAA="!Y;W4G<F4@9&]I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S971287=#;VUP871I8FQE*"1C;VUP871I8FQE*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]M<&%T:6)L92==(#T@)&-O;7!A
M=&EB;&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5T%23DE.1R`M(&1O
M(&YO="!U<V4@=&AI<R!F=6YC=&EO;B!U;FQE<W,@>6]U(&MN;W<@=VAA="!Y
M;W4G<F4@9&]I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971287=086-K
M86=E*"1P86-K86=E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG;F%M92==(#T@)'!A8VMA9V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@5T%23DE.1R`M(&1O(&YO="!U<V4@=&AI<R!F=6YC=&EO;B!U;FQE
M<W,@>6]U(&MN;W<@=VAA="!Y;W4G<F4@9&]I;F<-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971287=#:&%N;F5L*"1C:&%N;F5L*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;FYE;"==(#T@)&-H86YN96P[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T4F5Q=65S=&5D1W)O=7`H)&=R
M;W5P*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]R97%U97-T961'<F]U<"`]
M("1G<F]U<#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971297%U97-T961'
M<F]U<"@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]R97%U
M97-T961'<F]U<"DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)E
M<75E<W1E9$=R;W5P.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@<V%V:6YG(&EN('1H
M92!R96=I<W1R>2X-"B`@("`@*@T*("`@("`J(%-E="!T:&4@;&%S="!V97)S
M:6]N('1H870@=V%S(&EN<W1A;&QE9`T*("`@("`J($!P87)A;2!S=')I;F<-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971,87-T26YS=&%L;&5D5F5R<VEO
M;B@D=F5R<VEO;BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)U]L87-T=F5R<VEO;B==(#T@)'9E<G-I;VX[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!G971,87-T26YS=&%L;&5D5F5R<VEO;B@I#0H@("`@>PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1V
M97)S:6]N)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;ULG7VQA<W1V97)S:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R
M;6EN97,@=VAE=&AE<B!T:&ES('!A8VMA9V4N>&UL(&AA<R!P;W-T+6EN<W1A
M;&P@<V-R:7!T<R!O<B!N;W0-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@;&ES=%!O<W1I;G-T86QL4V-R:7!T
M<R@I#0H@("`@>PT*("`@("`@("`D9FEL96QI<W0@/2`D=&AI<RT^9V5T1FEL
M96QI<W0H*3L-"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/F=E=$-O;G1E
M;G1S*"D[#0H@("`@("`@("1C;VYT96YT<R`]("1C;VYT96YT<ULG9&ER)UU;
M)V9I;&4G73L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]N=&5N=',I('Q\
M("%I<W-E="@D8V]N=&5N='-;,%TI*2![#0H@("`@("`@("`@("`D8V]N=&5N
M=',@/2!A<G)A>2@D8V]N=&5N=',I.PT*("`@("`@("!]#0H@("`@("`@("1T
M87-K9FEL97,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D8V]N=&5N
M=',@87,@)&9I;&4I('L-"B`@("`@("`@("`@("1A='1S(#T@)&9I;&5;)V%T
M=')I8G,G73L-"B`@("`@("`@("`@('5N<V5T*"1F:6QE6R=A='1R:6)S)UTI
M.PT*("`@("`@("`@("`@:68@*&-O=6YT*"1F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@("1T87-K9FEL97-;)&%T='-;)VYA;64G75T@/2`D9FEL93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D8V]M;6]N(#T@;F5W
M(%!%05)?0V]M;6]N.PT*("`@("`@("`D8V]M;6]N+3YD96)U9R`]("1T:&ES
M+3Y?8V]N9FEG+3YG970H)W9E<F)O<V4G*3L-"B`@("`@("`@)'1H:7,M/E]S
M8W)I<'1S(#T@87)R87DH*3L-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@
M("`@("`@(&9O<F5A8V@@*"1T87-K9FEL97,@87,@)&YA;64@/3X@)'1A<VMS
M*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1F:6QE;&ES=%LD;F%M95TI
M*2![#0H@("`@("`@("`@("`@("`@+R\@:6=N;W)E9"!F:6QE<R!W:6QL(&YO
M="!B92!I;B!T:&4@9FEL96QI<W0-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1A='1S(#T@)&9I;&5L
M:7-T6R1N86UE73L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T87-K<R!A<R`D
M=&%G(#T^("1R87<I('L-"B`@("`@("`@("`@("`@("`D=&%S:R`]("1T:&ES
M+3YG971487-K*"1T86<I.PT*("`@("`@("`@("`@("`@("1T87-K(#T@)FYE
M=R`D=&%S:R@D=&AI<RT^7V-O;F9I9RP@)&-O;6UO;BP@4$5!4E]405-+7TE.
M4U1!3$PI.PT*("`@("`@("`@("`@("`@(&EF("@D=&%S:RT^:7-38W)I<'0H
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D9FEL96QI<W1;
M)&YA;65=6R=I;G-T86QL961?87,G73L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT*"1R
M970I*2![#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@26YI=&EA;&EZ92!P;W-T+6EN<W1A;&P@<V-R:7!T<R!F;W(@<G5N;FEN
M9PT*("`@("`J#0H@("`@("H@5&AI<R!M971H;V0@8V%N(&)E('5S960@=&\@
M9&5T96-T('!O<W0M:6YS=&%L;"!S8W)I<'1S+"!A<R!T:&4@<F5T=7)N('9A
M;'5E#0H@("`@("H@:6YD:6-A=&5S('=H971H97(@86YY(&5X:7-T#0H@("`@
M("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YI=%!O
M<W1I;G-T86QL4V-R:7!T<R@I#0H@("`@>PT*("`@("`@("`D9FEL96QI<W0@
M/2`D=&AI<RT^9V5T1FEL96QI<W0H*3L-"B`@("`@("`@)&-O;G1E;G1S(#T@
M)'1H:7,M/F=E=$-O;G1E;G1S*"D[#0H@("`@("`@("1C;VYT96YT<R`]("1C
M;VYT96YT<ULG9&ER)UU;)V9I;&4G73L-"B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D8V]N=&5N=',I('Q\("%I<W-E="@D8V]N=&5N='-;,%TI*2![#0H@("`@
M("`@("`@("`D8V]N=&5N=',@/2!A<G)A>2@D8V]N=&5N=',I.PT*("`@("`@
M("!]#0H@("`@("`@("1T87-K9FEL97,@/2!A<G)A>2@I.PT*("`@("`@("!F
M;W)E86-H("@D8V]N=&5N=',@87,@)&9I;&4I('L-"B`@("`@("`@("`@("1A
M='1S(#T@)&9I;&5;)V%T=')I8G,G73L-"B`@("`@("`@("`@('5N<V5T*"1F
M:6QE6R=A='1R:6)S)UTI.PT*("`@("`@("`@("`@:68@*&-O=6YT*"1F:6QE
M*2D@>PT*("`@("`@("`@("`@("`@("1T87-K9FEL97-;)&%T='-;)VYA;64G
M75T@/2`D9FEL93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D8V]M;6]N(#T@;F5W(%!%05)?0V]M;6]N.PT*("`@("`@("`D8V]M;6]N
M+3YD96)U9R`]("1T:&ES+3Y?8V]N9FEG+3YG970H)W9E<F)O<V4G*3L-"B`@
M("`@("`@)'1H:7,M/E]S8W)I<'1S(#T@87)R87DH*3L-"B`@("`@("`@9F]R
M96%C:"`H)'1A<VMF:6QE<R!A<R`D;F%M92`]/B`D=&%S:W,I('L-"B`@("`@
M("`@("`@("1A='1S(#T@)&9I;&5L:7-T6R1N86UE73L-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T87-K<R!A<R`D=&%G(#T^("1R87<I('L-"B`@("`@("`@
M("`@("`@("`D=&%S:VYA;64@/2`D=&AI<RT^9V5T5&%S:R@D=&%G*3L-"B`@
M("`@("`@("`@("`@("`D=&%S:R`]("9N97<@)'1A<VMN86UE*"1T:&ES+3Y?
M8V]N9FEG+"`D8V]M;6]N+"!014%27U1!4TM?24Y35$%,3"D[#0H@("`@("`@
M("`@("`@("`@:68@*"$D=&%S:RT^:7-38W)I<'0H*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L@+R\@<V-R:7!T<R!A<F4@;VYL>2!H86YD
M;&5D(&%F=&5R(&EN<W1A;&QA=&EO;@T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D;&%S='9E<G-I;VX@/2!I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=?;&%S='9E<G-I;VXG72D@/PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=?;&%S='9E<G-I;VXG72`Z(&YU
M;&P[#0H@("`@("`@("`@("`@("`@)'1A<VLM/FEN:70H)')A=RP@)&%T=',L
M("1L87-T=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@)')E<R`]("1T87-K
M+3YS=&%R=%-E<W-I;VXH)'1H:7,L("1A='1S6R=I;G-T86QL961?87,G72D[
M#0H@("`@("`@("`@("`@("`@:68@*"$D<F5S*2![#0H@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.R`O+R!S:VEP('1H:7,@9FEL90T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&%S<VEG;B`]("8D
M=&%S:SL-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-C<FEP='-;72`]("8D
M87-S:6=N.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AC;W5N="@D=&AI<RT^7W-C<FEP=',I*2![#0H@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<G5N4&]S=&EN<W1A;&Q38W)I<'1S*"D-
M"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^:6YI=%!O<W1I;G-T86QL4V-R
M:7!T<R@I*2![#0H@("`@("`@("`@("`D=6D@/2`F4$5!4E]&<F]N=&5N9#HZ
M<VEN9VQE=&]N*"D[#0H@("`@("`@("`@("!I9B`H)'5I*2![#0H@("`@("`@
M("`@("`@("`@)'5I+3YR=6Y0;W-T:6YS=&%L;%-C<FEP=',H)'1H:7,M/E]S
M8W)I<'1S+"`D=&AI<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("!]#0H-"@T*("`@("\J*@T*("`@("`J($-O;G9E<G0@82!R96-U<G-I=F4@
M<V5T(&]F(#QD:7(^(&%N9"`\9FEL93X@=&%G<R!I;G1O(&$@<VEN9VQE(#QD
M:7(^('1A9R!W:71H#0H@("`@("H@/&9I;&4^('1A9W,N#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9FQA='1E;D9I;&5L:7-T*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI('L-
M"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("`D9FEL
M96QI<W0@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V1I<B==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]G971&;&%T=&5N961&:6QE;&ES="@D9FEL96QI
M<W0L("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==*3L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)&9I;&5L:7-T6S%=*2D@>PT*("`@
M("`@("`@("`@("`@("1F:6QE;&ES="`]("1F:6QE;&ES=%LP73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O
M;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT@/2`D9FEL96QI<W0[#0H@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D
M:7(G75LG9&ER)UTI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M+R\@96QS92!A;')E861Y(&9L871T96YE9"!B=70@8VAE8VL@9F]R(&)A<V5I
M;G-T86QL9&ER('!R;W!A9V%T:6]N#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V%T=')I
M8G,G75LG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER
M)UU;)V9I;&4G75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I
M;&4G72!A<R`D:2`]/B`D9FEL92D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1F:6QE6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G
M75LG9FEL92==6R1I75LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/2`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C;VYT96YT<R==6R=D:7(G75LG871T<FEB<R==6R=B87-E:6YS=&%L
M;&1I<B==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==
M6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;
M)V1I<B==6R=F:6QE)UU;)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G70T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#T@)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V%T=')I8G,G75LG8F%S96EN<W1A
M;&QD:7(G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!A<G)A>2!T:&4@9FEN86P@9FQA='1E;F5D
M(&9I;&4@;&ES=`T*("`@("`J($!P87)A;2!A<G)A>2!T:&4@8W5R<F5N="!D
M:7)E8W1O<GD@8F5I;F<@<')O8V5S<V5D#0H@("`@("H@0'!A<F%M('-T<FEN
M9WQF86QS92!A;GD@<F5C=7)S:79E;'D@:6YH97)I=&5D(&)A96EN<W1A;&QD
M:7(@871T<FEB=71E#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<FEV871E(')E
M8W5R<VEO;B!V87)I86)L90T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@
M*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G
M971&;&%T=&5N961&:6QE;&ES="@F)&9I;&5S+"`D9&ER+"`D8F%S96EN<W1A
M;&P@/2!F86QS92P@)'!A=&@@/2`G)RD-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D9&ER6R=A='1R:6)S)UTI("8F(&ES<V5T*"1D:7);)V%T=')I8G,G
M75LG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("1B87-E:6YS
M=&%L;"`]("1D:7);)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G73L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1I<ELG9&ER)UTI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1D:7);)V1I<B==6S!=*2D@>PT*("`@
M("`@("`@("`@("`@("1D:7);)V1I<B==(#T@87)R87DH)&1I<ELG9&ER)UTI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1I<ELG
M9&ER)UT@87,@)'-U8F1I<BD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'-U8F1I<ELG871T<FEB<R==*2!\?"`A:7-S970H)'-U8F1I<ELG871T
M<FEB<R==6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1N86UE
M(#T@)RIU;FMN;W=N*B<[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)&YA;64@/2`D<W5B9&ER6R=A='1R:6)S)UU;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)&YE=W!A=&@@/2!E;7!T>2@D<&%T:"D@/R`D;F%M92`Z#0H@("`@("`@("`@
M("`@("`@("`@("1P871H("X@)R\G("X@)&YA;64[#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971&;&%T=&5N961&:6QE;&ES="@D9FEL97,L("1S=6)D
M:7(L#0H@("`@("`@("`@("`@("`@("`@("1B87-E:6YS=&%L;"P@)&YE=W!A
M=&@I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D9&ER6R=F:6QE)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1D:7);)V9I;&4G75LP72DI('L-"B`@("`@("`@("`@("`@("`D9&ER6R=F
M:6QE)UT@/2!A<G)A>2@D9&ER6R=F:6QE)UTI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@9F]R96%C:"`H)&1I<ELG9FEL92==(&%S("1F:6QE*2![
M#0H@("`@("`@("`@("`@("`@)&%T=')S(#T@)&9I;&5;)V%T=')I8G,G73L-
M"B`@("`@("`@("`@("`@("`D;F%M92`]("1A='1R<ULG;F%M92==.PT*("`@
M("`@("`@("`@("`@(&EF("@D8F%S96EN<W1A;&P@)B8@(6ES<V5T*"1A='1R
M<ULG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&%T=')S6R=B87-E:6YS=&%L;&1I<B==(#T@)&)A<V5I;G-T86QL.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D871T<G-;)VYA;64G
M72`](&5M<'1Y*"1P871H*2`_("1N86UE(#H@)'!A=&@@+B`G+R<@+B`D;F%M
M93L-"B`@("`@("`@("`@("`@("`D871T<G-;)VYA;64G72`]('!R96=?<F5P
M;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A+RLA)RDL(&%R<F%Y*"<O)RP@)R\G
M*2P-"B`@("`@("`@("`@("`@("`@("`@)&%T=')S6R=N86UE)UTI.PT*("`@
M("`@("`@("`@("`@("1F:6QE6R=A='1R:6)S)UT@/2`D871T<G,[#0H@("`@
M("`@("`@("`@("`@)&9I;&5S6UT@/2`D9FEL93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$-O;F9I9R@F
M)&-O;F9I9RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)B1C
M;VYF:6<[#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)&-O;F9I9RT^
M9V5T4F5G:7-T<GDH*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971,;V=G
M97(H)B1L;V=G97(I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V]B:F5C="@D
M;&]G9V5R*2!\?"`A;65T:&]D7V5X:7-T<R@D;&]G9V5R+"`G;&]G)RDI('L-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=,;V=G97(@
M;75S="!B92!C;VUP871I8FQE('=I=&@@4$5!4E]#;VUM;VXZ.FQO9R<I.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?;&]G9V5R(#T@)B1L;V=G97([
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5T%23DE.1R`M(&1O(&YO="!U
M<V4@=&AI<R!F=6YC=&EO;B!D:7)E8W1L>2!U;FQE<W,@>6]U(&MN;W<@=VAA
M="!Y;W4G<F4@9&]I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971$97!S
M*"1D97!S*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M9&5P96YD96YC:65S)UT@/2`D9&5P<SL-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!S971086-K86=E9FEL92@D9FEL92P@)&%R8VAI=F4@/2!F86QS92D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G949I;&4@/2`D9FEL93L-"B`@
M("`@("`@)'1H:7,M/E]A<F-H:79E1FEL92`]("1A<F-H:79E(#\@)&%R8VAI
M=F4@.B`D9FEL93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!7<F%P<&5R
M('1O('M`;&EN:R!014%27T5R<F]R4W1A8VLZ.F=E=$5R<F]R<R@I?0T*("`@
M("`J($!P87)A;2!B;V]L96%N(&1E=&5R;6EN97,@=VAE=&AE<B!T;R!P=7)G
M92!T:&4@97)R;W(@<W1A8VL@869T97(@<F5T<FEE=FEN9PT*("`@("`J($!R
M971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971686QI9&%T
M:6]N5V%R;FEN9W,H)'!U<F=E(#T@=')U92D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7W-T86-K+3YG971%<G)O<G,H)'!U<F=E*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E1FEL92@I#0H@("`@>PT*("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E1FEL93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G971!<F-H:79E1FEL92@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)'1H:7,M/E]A<F-H:79E1FEL93L-"B`@("!]#0H-"@T*("`@("\J
M*@T*("`@("`J($1I<F5C=&QY('-E="!T:&4@87)R87D@=&AA="!D969I;F5S
M('1H:7,@<&%C:V%G969I;&4-"B`@("`@*@T*("`@("`J(%=!4DY)3D<Z(&YO
M('9A;&ED871I;VXN("!4:&ES('-H;W5L9"!O;FQY(&)E('!E<F9O<FUE9"!B
M>2!I;G1E<FYA;"!M971H;V1S#0H@("`@("H@:6YS:61E(%!%05(@;W(@8GD@
M:6YP=71T:6YG(&%N(&%R<F%Y('-A=F5D(&9R;VT@86X@97AI<W1I;F<@4$5!
M4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&9R;VU!<G)A>2@D<&EN9F\I#0H@("`@>PT*("`@
M("`@("!U;G-E="@D<&EN9F];)V]L9"==*3L-"B`@("`@("`@=6YS970H)'!I
M;F9O6R=X<V1V97)S:6]N)UTI.PT*("`@("`@("`D=&AI<RT^7VEN8V]M<&QE
M=&4@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1P
M:6YF;SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<TEN8V]M<&QE=&4H*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6YC;VUP;&5T93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@=&]!<G)A>2@D9F]R<F5G(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H(21T:&ES+3YV86QI9&%T92A014%27U9!3$E$051%
M7TY/4DU!3"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$%R<F%Y*"1F;W)R96<I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$%R<F%Y*"1F;W)296<@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(&EF("@D9F]R4F5G*2![#0H@("`@("`@
M("`@("`D87)R(#T@)'1H:7,M/E]P86-K86=E26YF;SL-"B`@("`@("`@("`@
M("1A<G);)V]L9"==(#T@87)R87DH*3L-"B`@("`@("`@("`@("1A<G);)V]L
M9"==6R=V97)S:6]N)UT@/2`D=&AI<RT^9V5T5F5R<VEO;B@I.PT*("`@("`@
M("`@("`@)&%R<ELG;VQD)UU;)W)E;&5A<V5?9&%T92==(#T@)'1H:7,M/F=E
M=$1A=&4H*3L-"B`@("`@("`@("`@("1A<G);)V]L9"==6R=R96QE87-E7W-T
M871E)UT@/2`D=&AI<RT^9V5T4W1A=&4H*3L-"B`@("`@("`@("`@("1A<G);
M)V]L9"==6R=R96QE87-E7VQI8V5N<V4G72`]("1T:&ES+3YG971,:6-E;G-E
M*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G75LG<F5L96%S95]N;W1E<R==
M(#T@)'1H:7,M/F=E=$YO=&5S*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G
M75LG<F5L96%S95]D97!S)UT@/2`D=&AI<RT^9V5T1&5P<R@I.PT*("`@("`@
M("`@("`@)&%R<ELG;VQD)UU;)VUA:6YT86EN97)S)UT@/2`D=&AI<RT^9V5T
M36%I;G1A:6YE<G,H*3L-"B`@("`@("`@("`@("1A<G);)WAS9'9E<G-I;VXG
M72`]("<R+C`G.PT*("`@("`@("`@("`@<F5T=7)N("1A<G([#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3Y?<&%C:V%G
M94EN9F\[#0H@("`@("`@("`@("!U;G-E="@D:6YF;ULG9&ER=')E92==*3L-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG7VQA<W1V97)S:6]N)UTI
M*2![#0H@("`@("`@("`@("`@("`@=6YS970H)&EN9F];)U]L87-T=F5R<VEO
M;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG(V)I;F%R>7!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("!U
M;G-E="@D:6YF;ULG(V)I;F%R>7!A8VMA9V4G72D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!R971U<FX@)&EN9F\[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!P86-K86=E26YF;R@D9FEE;&0I#0H@("`@>PT*
M("`@("`@("`D87)R(#T@)'1H:7,M/F=E=$%R<F%Y*'1R=64I.PT*("`@("`@
M("!I9B`H)&9I96QD(#T]("=S=&%T92<I('L-"B`@("`@("`@("`@(')E='5R
M;B`D87)R6R=S=&%B:6QI='DG75LG<F5L96%S92==.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D9FEE;&0@/3T@)V%P:2UV97)S:6]N)RD@>PT*("`@("`@
M("`@("`@<F5T=7)N("1A<G);)W9E<G-I;VXG75LG87!I)UT[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1F:65L9"`]/2`G87!I+7-T871E)RD@>PT*("`@
M("`@("`@("`@<F5T=7)N("1A<G);)W-T86)I;&ET>2==6R=A<&DG73L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&%R<ELG;VQD)UU;)&9I96QD
M72DI('L-"B`@("`@("`@("`@(&EF("@A:7-?<W1R:6YG*"1A<G);)V]L9"==
M6R1F:65L9%TI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&%R<ELG;VQD)UU;
M)&9I96QD73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&%R<ELD
M9FEE;&1=*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]S=')I;F<H)&%R<ELD
M9FEE;&1=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1A<G);)&9I96QD73L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@;G5L;#L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G971.86UE*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D
M=&AI<RT^9V5T4&%C:V%G92@I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=%!A8VMA9V4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)VYA;64G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=N86UE)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$-H
M86YN96PH*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W5R:2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("=?7W5R
M:2<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V-H86YN96PG72DI('L-"B`@("`@("`@("`@(')E='5R;B!S
M=')T;VQO=V5R*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN96PG72D[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=%5R:2@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG=7)I)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG=7)I)UT[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&=E=$5X=&5N9',H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V5X=&5N9',G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1E;F1S)UT[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=%-U;6UA<GDH*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W-U;6UA<GDG72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=S=6UM87)Y)UT[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=$1E<V-R:7!T:6]N*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97-C<FEP=&EO;B==*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R
M:7!T:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$UA:6YT86EN97)S*"1R87<@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG;&5A9"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<F%W*2![#0H@("`@("`@("`@
M("`D<F5T(#T@87)R87DH)VQE860G(#T^("1T:&ES+3Y?<&%C:V%G94EN9F];
M)VQE860G72D[#0H@("`@("`@("`@("`H:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG9&5V96QO<&5R)UTI*2`_#0H@("`@("`@("`@("`@("`@)')E=%LG
M9&5V96QO<&5R)UT@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P97(G
M72`Z;G5L;#L-"B`@("`@("`@("`@("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C;VYT<FEB=71O<B==*2D@/PT*("`@("`@("`@("`@("`@("1R971;
M)V-O;G1R:6)U=&]R)UT@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT<FEB
M=71O<B==(#IN=6QL.PT*("`@("`@("`@("`@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)VAE;'!E<B==*2D@/PT*("`@("`@("`@("`@("`@("1R971;
M)VAE;'!E<B==(#T@)'1H:7,M/E]P86-K86=E26YF;ULG:&5L<&5R)UT@.FYU
M;&P[#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("`@("`@
M)&QE861S(#T@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;&5A9"==6S!=
M*2`_("1T:&ES+3Y?<&%C:V%G94EN9F];)VQE860G72`Z#0H@("`@("`@("`@
M("`@("`@87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULG;&5A9"==*3L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1L96%D<R!A<R`D;&5A9"D@>PT*("`@("`@
M("`@("`@("`@("1S(#T@)&QE860[#0H@("`@("`@("`@("`@("`@)'-;)VAA
M;F1L92==(#T@)'-;)W5S97(G73L-"B`@("`@("`@("`@("`@("!U;G-E="@D
M<ULG=7-E<B==*3L-"B`@("`@("`@("`@("`@("`D<ULG<F]L92==(#T@)VQE
M860G.PT*("`@("`@("`@("`@("`@("1R971;72`]("1S.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V1E=F5L;W!E<B==*2D@>PT*("`@("`@("`@("`@("`@("1L96%D<R`]
M(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E=F5L;W!E<B==6S!=*2`_
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M=F5L;W!E<B==(#H-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5V96QO<&5R)UTI.PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1L96%D<R!A<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@
M("`@("`@("`@("`D<R`]("1M86EN=&%I;F5R.PT*("`@("`@("`@("`@("`@
M("`@("`D<ULG:&%N9&QE)UT@/2`D<ULG=7-E<B==.PT*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D<ULG=7-E<B==*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'-;)W)O;&4G72`]("=D979E;&]P97(G.PT*("`@("`@("`@("`@("`@
M("`@("`D<F5T6UT@/2`D<SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N=')I8G5T;W(G72DI('L-"B`@("`@("`@("`@("`@("`D;&5A
M9',@/2!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT<FEB=71O<B==
M6S!=*2`_#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1R:6)U=&]R)UT@.@T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT<FEB=71O<B==*3L-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D;&5A9',@87,@)&UA:6YT86EN97(I('L-
M"B`@("`@("`@("`@("`@("`@("`@)',@/2`D;6%I;G1A:6YE<CL-"B`@("`@
M("`@("`@("`@("`@("`@)'-;)VAA;F1L92==(#T@)'-;)W5S97(G73L-"B`@
M("`@("`@("`@("`@("`@("`@=6YS970H)'-;)W5S97(G72D[#0H@("`@("`@
M("`@("`@("`@("`@("1S6R=R;VQE)UT@/2`G8V]N=')I8G5T;W(G.PT*("`@
M("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D<SL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG:&5L<&5R)UTI*2![#0H@("`@("`@("`@("`@
M("`@)&QE861S(#T@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG:&5L<&5R
M)UU;,%TI(#\-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG:&5L<&5R)UT@.@T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=H96QP97(G72D[#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&QE861S(&%S("1M86EN=&%I;F5R*2![#0H@("`@("`@
M("`@("`@("`@("`@("1S(#T@)&UA:6YT86EN97([#0H@("`@("`@("`@("`@
M("`@("`@("1S6R=H86YD;&4G72`]("1S6R=U<V5R)UT[#0H@("`@("`@("`@
M("`@("`@("`@('5N<V5T*"1S6R=U<V5R)UTI.PT*("`@("`@("`@("`@("`@
M("`@("`D<ULG<F]L92==(#T@)VAE;'!E<B<[#0H@("`@("`@("`@("`@("`@
M("`@("1R971;72`]("1S.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M971,96%D<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG;&5A9"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F];)VQE860G73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&5V
M96QO<&5R<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5V96QO<&5R)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9&5V96QO<&5R)UT[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=$-O;G1R:6)U=&]R<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT<FEB
M=71O<B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!G971(96QP97)S*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=H96QP97(G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=H
M96QP97(G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T1&%T92@D9&%T92D-"B`@("![#0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&%T92==
M*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE(&5X=&5N9',@
M=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R
M92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y
M*"=T:6UE)RP@)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`G<W1A
M8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G8V]M
M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G
M+"`G<')O=FED97-E>'1E;G-I;VXG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG
M+`T*("`@("`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R
M96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V5X=&)I;G)E;&5A<V4G
M+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+"!A<G)A>2@I+"`G9&%T92<I.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1A=&4G
M72`]("1D871E.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=%1I;64H)'1I;64I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)W1I;64G72DI('L-"B`@("`@("`@("`@
M("\O(&5N<W5R92!T:&%T('1H92!T:6UE('1A9R!I<R!S970@=7`@:6X@=&AE
M(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF
M;RP-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)W9E<G-I;VXG+`T*("`@
M("`@("`@("`@("`@("`@("`G<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T
M97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@
M("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G
M<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@("`@("`@("`G
M<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I
M+"`D=&EM92P@)W1I;64G*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=T:6UE)UT@/2`D=&EM93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971$871E*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=D871E)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9&%T92==.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!G9714:6UE*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=T:6UE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E26YF;ULG=&EM92==.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@<&%C:V%G97QA<&D@=F5R<VEO;B!C871E9V]R>2!T;R!R971U<FX-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971697)S:6]N*"1K97D@/2`G<F5L
M96%S92<I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG=F5R<VEO;B==6R1K97E=*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG75LD:V5Y73L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T4W1A8FEL:71Y*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI
M='DG73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T4W1A=&4H)&ME>2`]("=R96QE87-E)RD-
M"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=S=&%B:6QI='DG75LD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG75LD:V5Y73L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T3&EC96YS92@D<F%W(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==*2D@
M>PT*("`@("`@("`@("`@:68@*"1R87<I('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)VQI8V5N<V4G72DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==6R=?8V]N=&5N="==
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971,:6-E;G-E3&]C871I;VXH*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=L:6-E
M;G-E)UTI('Q\("%I<U]A<G)A>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=L:6-E
M;G-E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N
M<V4G75LG871T<FEB<R==.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$YO
M=&5S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=N;W1E<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F];)VYO=&5S)UT[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R
M;B!T:&4@/'5S97-R;VQE/B!T86<@8V]N=&5N=',L(&EF(&%N>0T*("`@("`J
M($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M9715<V5S<F]L92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG=7-E<W)O;&4G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L92==.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!2971U<FX@=&AE(#QU<V5S=&%S:SX@=&%G(&-O;G1E;G1S+"!I
M9B!A;GD-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T57-E<W1A<VLH*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W1A
M<VLG73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!S:&]U;&0@;VYL>2!B92!U<V5D
M('1O(')E=')I979E(&9I;&5N86UE<R!A;F0@:6YS=&%L;"!A='1R:6)U=&5S
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1FEL96QI<W0H)'!R97-E<G9E
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG9FEL96QI<W0G72D@)B8@(21P<F5S97)V92D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T
M)UT[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F9L871T96Y&:6QE;&ES
M="@I.PT*("`@("`@("!I9B`H)&-O;G1E;G1S(#T@)'1H:7,M/F=E=$-O;G1E
M;G1S*"DI('L-"B`@("`@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D8V]N=&5N='-;)V1I<B==6R=F:6QE)UU;,%TI
M*2![#0H@("`@("`@("`@("`@("`@)&-O;G1E;G1S6R=D:7(G75LG9FEL92==
M(#T@87)R87DH)&-O;G1E;G1S6R=D:7(G75LG9FEL92==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT<ULG9&ER)UU;
M)V9I;&4G72!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("1N86UE(#T@
M)&9I;&5;)V%T=')I8G,G75LG;F%M92==.PT*("`@("`@("`@("`@("`@(&EF
M("@A)'!R97-E<G9E*2![#0H@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@
M)&9I;&5;)V%T=')I8G,G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)')E=%LD;F%M95T@/2`D9FEL93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@A)'!R97-E<G9E*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G72`]("1R970[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@4F5T=7)N(&-O;F9I9W5R92!O<'1I;VYS(&%R<F%Y+"!I9B!A
M;GD-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971#;VYF:6=U<F5/<'1I;VYS*"D-"B`@("![
M#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`A/2`G97AT
M<W)C)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@("1R96QE87-E<R`]("1T:&ES+3YG971296QE87-E<R@I.PT*
M("`@("`@("!I9B`H:7-S970H)')E;&5A<V5S6S!=*2D@>PT*("`@("`@("`@
M("`@)')E;&5A<V5S(#T@)')E;&5A<V5;,%T[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1R96QE87-E<ULG8V]N9FEG=7)E;W!T:6]N)UTI*2![
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E<ULG8V]N9FEG=7)E
M;W!T:6]N)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)')E;&5A<V5S6R=C
M;VYF:6=U<F5O<'1I;VXG72`](&%R<F%Y*"1R96QE87-E<ULG8V]N9FEG=7)E
M;W!T:6]N)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@8V]U;G0H)')E;&5A<V5S6R=C;VYF:6=U<F5O<'1I;VXG
M72D[("1I*RLI('L-"B`@("`@("`@("`@("`@("`D<F5L96%S97-;)V-O;F9I
M9W5R96]P=&EO;B==6R1I72`]("1R96QE87-E<ULG8V]N9FEG=7)E;W!T:6]N
M)UU;)&E=6R=A='1R:6)S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!R971U<FX@)')E;&5A<V5S6R=C;VYF:6=U<F5O<'1I;VXG73L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@5&AI<R!I<R!O;FQY('5S960@870@:6YS=&%L;"UT:6UE+"!A
M9G1E<B!A;&P@<V5R:6%L:7IA=&EO;@T*("`@("`J(&ES(&]V97(N#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<F5S971&:6QE;&ES="@I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==(#T@87)R87DH
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971R:65V92!A(&QI<W0@
M;V8@9FEL97,@=&AA="!S:&]U;&0@8F4@:6YS=&%L;&5D(&]N('1H:7,@8V]M
M<'5T97(-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T26YS=&%L;&%T:6]N1FEL96QI<W0H)&9O<F9I;&5C:&5C:R`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/F=E
M=$9I;&5L:7-T*'1R=64I.PT*("`@("`@("!I9B`H:7-S970H)&-O;G1E;G1S
M6R=D:7(G75LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@
M("`@("`@("`@)&)A<V4@/2`D8V]N=&5N='-;)V1I<B==6R=A='1R:6)S)UU;
M)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V)U;F1L92==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@
M("`@)T5X8V5P=&EO;CH@8G5N9&QE<R!S:&]U;&0@8F4@:&%N9&QE9"!I;B!D
M;W=N;&]A9"!C;V1E(&]N;'DG*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5L
M96%S92`]("1T:&ES+3YG971296QE87-E<R@I.PT*("`@("`@("!I9B`H)')E
M;&5A<V4I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)')E;&5A<V5;,%TI
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F5L96%S95LG:6YS
M=&%L;&-O;F1I=&EO;G,G72D@)B8@(6ES<V5T*"1R96QE87-E6R=F:6QE;&ES
M="==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&9O<F9I;&5C:&5C
M:RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG
M971&:6QE;&ES="@I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=',[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@87)R87DH)')E;&5A
M<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E<&-H96-K97(@
M/2`F)'1H:7,M/F=E=%!%05)$97!E;F1E;F-Y,B@D=&AI<RT^7V-O;F9I9RP@
M87)R87DH*2P-"B`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@
M)'1H:7,M/F=E=$-H86YN96PH*2P@)W!A8VMA9V4G(#T^("1T:&ES+3YG9710
M86-K86=E*"DI+`T*("`@("`@("`@("`@("`@(%!%05)?5D%,241!5$5?24Y3
M5$%,3$E.1RD[#0H@("`@("`@("`@("!F;W)E86-H("@D<F5L96%S92!A<R`D
M:6YS=&%N8V4I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN<W1A
M;F-E6R=I;G-T86QL8V]N9&ET:6]N<R==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D:6YS=&%L;&-O;F1I=&EO;G,@/2`D:6YS=&%N8V5;)VEN<W1A;&QC
M;VYD:71I;VYS)UT[#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D:6YS=&%L;&-O;F1I=&EO;G,I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YS=&%L
M;&-O;F1I=&EO;G,@87,@)'1Y<&4@/3X@)&-O;F1I=&EO;G,I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1C;VYD:71I;VYS
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M9&ET:6]N<R`](&%R<F%Y*"1C;VYD:71I;VYS*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&-O;F1I=&EO;G,@87,@)&-O;F1I=&EO;BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)&1E<&-H96-K97(M
M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1C;VYD:71I;VXI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,SL@+R\@<VMI<"!T
M:&ES(')E;&5A<V4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z
M.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`O+R!T:&ES(&ES
M('1H92!R96QE87-E('1O('5S90T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D:6YS=&%N8V5;)V9I;&5L:7-T)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("\O(&EG;F]R92!F:6QE<PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&EN<W1A;F-E6R=F:6QE;&ES="==6R=I9VYO<F4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I9VYO<F4@/2!I<W-E="@D:6YS=&%N
M8V5;)V9I;&5L:7-T)UU;)VEG;F]R92==6S!=*2`_#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN<W1A;F-E6R=F:6QE;&ES="==6R=I9VYO<F4G
M72`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&EN<W1A
M;F-E6R=F:6QE;&ES="==6R=I9VYO<F4G72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D:6=N;W)E(&%S("1I9RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T("@D8V]N=&5N='-;)&EG6R=A='1R
M:6)S)UU;)VYA;64G75TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("\O
M(&EN<W1A;&P@9FEL97,@87,@=&AI<R!N86UE#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D:6YS=&%N8V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;G-T86QL87,@/2!I
M<W-E="@D:6YS=&%N8V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG75LP72D@/PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;G-T86YC95LG9FEL96QI
M<W0G75LG:6YS=&%L;"==(#H-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@D:6YS=&%N8V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YS=&%L;&%S(&%S
M("1A<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M<ULD87-;)V%T=')I8G,G75LG;F%M92==75LG871T<FEB<R==6R=I;G-T86QL
M+6%S)UT@/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87-;
M)V%T=')I8G,G75LG87,G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H)&9O<F9I;&5C:&5C:RD@>PT*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D8V]N=&5N=',@87,@)&9I;&4@/3X@)&%T
M=')S*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N='-;)&9I
M;&5=(#T@)&%T=')S6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1C;VYT96YT<SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L@
M+R\@<VEM<&QE(')E;&5A<V4@+2!N;R!I;G-T86QL8V]N9&ET:6]N<R!O<B!I
M;G-T86QL+6%S#0H@("`@("`@("`@("!I9B`H)&9O<F9I;&5C:&5C:RD@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T1FEL96QI<W0H*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=',[
M#0H@("`@("`@('T-"B`@("`@("`@+R\@;F\@<F5L96%S97,@;6%T8VAE9`T*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@<F5L96%S97,@
M:6X@<&%C:V%G92YX;6P@;6%T8VAE9"!T:&4@97AI<W1I;F<@;W!E<F%T:6YG
M("<@+@T*("`@("`@("`@("`@)W-Y<W1E;2P@97AT96YS:6]N<R!I;G-T86QL
M960L(&]R(&%R8VAI=&5C='5R92P@8V%N;F]T(&EN<W1A;&PG*3L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES(&]N;'D@=7-E9"!A="!I;G-T
M86QL+71I;64L(&%F=&5R(&%L;"!S97)I86QI>F%T:6]N#0H@("`@("H@:7,@
M;W9E<BX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M90T*("`@("`J
M($!P87)A;2!S=')I;F<@:6YS=&%L;&5D('!A=&@-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971);G-T86QL961!<R@D9FEL92P@)'!A=&@I#0H@("`@>PT*
M("`@("`@("!I9B`H)'!A=&@I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L;&5D
M7V%S)UT@/2`D<&%T:#L-"B`@("`@("`@?0T*("`@("`@("!U;G-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L;&5D
M7V%S)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$EN<W1A;&QE9$QO
M8V%T:6]N*"1F:6QE*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=6R=I;G-T86QL961?
M87,G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L;&5D7V%S)UT[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%1H:7,@:7,@;VYL>2!U<V5D(&%T(&EN<W1A;&PM=&EM92P@
M869T97(@86QL('-E<FEA;&EZ871I;VX-"B`@("`@*B!I<R!O=F5R+@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&EN<W1A;&QE9$9I;&4H)&9I;&4L("1A='1S
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V9I;&5L:7-T)UU;)&9I;&5=*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95T@/0T*("`@("`@("`@
M("`@("`@(&%R<F%Y7VUE<F=E*"1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L
M:7-T)UU;)&9I;&5=+"`D871T<ULG871T<FEB<R==*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L
M:7-T)UU;)&9I;&5=(#T@)&%T='-;)V%T=')I8G,G73L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E=')I979E('1H92!C;VYT96YT
M<R!T86<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971#;VYT96YT<R@I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M8V]N=&5N=',G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C;VYT96YT<R==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&9U;&P@<&%T:"!T;R!F:6QE#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!A='1R:6)U=&4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@871T<FEB
M=71E('9A;'5E#0H@("`@("H@0'!A<F%M(&EN="!R:7-K>2!B=70@9F%S="`M
M('5S92!T:&ES('1O(&-H;V]S92!A(&9I;&4@8F%S960@;VX@:71S('!O<VET
M:6]N(&EN('1H92!L:7-T#0H@("`@("H@("`@("`@("`@("!O9B!F:6QE<RX@
M($EN9&5X(&ES('IE<F\M8F%S960@;&EK92!02%`@87)R87ES+@T*("`@("`J
M($!R971U<FX@8F]O;"!S=6-C97-S(&]F(&]P97)A=&EO;@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=$9I;&5!='1R:6)U=&4H)&9I;&5N86UE+"`D871T
M<BP@)'9A;'5E+"`D:6YD97@@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("AI;E]A<G)A>2@D871T
M<BP@87)R87DH)W)O;&4G+"`G;F%M92<L("=B87-E:6YS=&%L;&1I<B<I*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]F:6QE<U9A;&ED(#T@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1I;F1E>"`A/3T@9F%L<V4@)B8-"B`@
M("`@("`@("`@("`@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N
M=',G75LG9&ER)UU;)V9I;&4G75LD:6YD97A=6R=A='1R:6)S)UTI*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D
M:7(G75LG9FEL92==6R1I;F1E>%U;)V%T=')I8G,G75LD871T<ET@/2`D=F%L
M=64[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S
M)UU;)V1I<B==6R=F:6QE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9I;&5S(#T@)'1H:7,M/E]P86-K
M86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G73L-"B`@("`@("`@
M:68@*"%I<W-E="@D9FEL97-;,%TI*2![#0H@("`@("`@("`@("`D9FEL97,@
M/2!A<G)A>2@D9FEL97,I.PT*("`@("`@("`@("`@)&EN9"`](&9A;'-E.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&EN9"`]('1R=64[#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1I(#T^("1F
M:6QE*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&9I;&5;)V%T=')I8G,G
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&9I;&5;)V%T=')I8G,G75LG
M;F%M92==(#T]("1F:6QE;F%M92D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&EN9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LD:5U;)V%T
M=')I8G,G75LD871T<ET@/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6R=A='1R:6)S
M)UU;)&%T=')=(#T@)'9A;'5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T1&ER=')E92@D
M<&%T:"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1I
M<G1R964G75LD<&%T:%T@/2!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&=E=$1I<G1R964H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V1I<G1R964G72D@)B8@8V]U;G0H)'1H:7,M/E]P
M86-K86=E26YF;ULG9&ER=')E92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V1I<G1R964G73L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M<F5S971$:7)T<F5E*"D-"B`@("![#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V1I<G1R964G72D[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@1&5T97)M:6YE<R!W:&5T:&5R('1H:7,@<&%C:V%G92!C;&%I;7,@
M:70@:7,@8V]M<&%T:6)L92!W:71H('1H92!V97)S:6]N(&]F#0H@("`@("H@
M=&AE('!A8VMA9V4@=&AA="!H87,@82!R96-O;6UE;F1E9"!V97)S:6]N(&1E
M<&5N9&5N8WD-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,GQ0
M14%27U!A8VMA9V5&:6QE7W8Q?%!%05)?1&]W;FQO861E<E]086-K86=E#0H@
M("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M:7-#;VUP871I8FQE*"1P9BD-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]M<&%T:6)L92==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1M
M92`]("1P9BT^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D8V]M<&%T:6)L92`]
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;7!A=&EB;&4G73L-"B`@("`@("`@
M:68@*"%I<W-E="@D8V]M<&%T:6)L95LP72DI('L-"B`@("`@("`@("`@("1C
M;VUP871I8FQE(#T@87)R87DH)&-O;7!A=&EB;&4I.PT*("`@("`@("!]#0H@
M("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("@D8V]M
M<&%T:6)L92!A<R`D:6YF;RD@>PT*("`@("`@("`@("`@:68@*'-T<G1O;&]W
M97(H)&EN9F];)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D<&8M/F=E=%!A8VMA
M9V4H*2DI('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF
M;ULG8VAA;FYE;"==*2`]/2!S=')T;VQO=V5R*"1P9BT^9V5T0VAA;FYE;"@I
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D9F]U;F0I
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&EN9F];)V5X8VQU9&4G72DI('L-"B`@("`@("`@
M("`@(&EF("@A:7-S970H)&EN9F];)V5X8VQU9&4G75LP72DI('L-"B`@("`@
M("`@("`@("`@("`D:6YF;ULG97AC;'5D92==(#T@87)R87DH)&EN9F];)V5X
M8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H
M("@D:6YF;ULG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@
M("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D;64L("1E>&-L=61E+"`G/3TG
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)&UE+"`D:6YF;ULG;6EN)UTL("<^
M/2<I("8F('9E<G-I;VY?8V]M<&%R92@D;64L("1I;F9O6R=M87@G72P@)SP]
M)RDI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T0V]M<&%T:6)L92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]M<&%T:6)L92==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;7!A=&EB;&4G73L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T1&5P96YD96YC:65S*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=D97!E;F1E;F-I97,G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-3=6)P86-K86=E3V8H
M)'`I#0H@("`@>PT*("`@("`@("!R971U<FX@)'`M/FES4W5B<&%C:V%G92@D
M=&AI<RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE<R!W
M:&5T:&5R('1H92!P87-S960@:6X@<&%C:V%G92!I<R!A('-U8G!A8VMA9V4@
M;V8@=&AI<R!P86-K86=E+@T*("`@("`J#0H@("`@("H@3F\@=F5R<VEO;B!C
M:&5C:VEN9R!I<R!D;VYE+"!O;FQY(&YA;64@=F5R:69I8V%T:6]N+@T*("`@
M("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I
M;&5?=C(-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!I<U-U8G!A8VMA9V4H)'`I#0H@("`@>PT*("`@("`@("`D<W5B(#T@
M87)R87DH*3L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=S=6)P86-K86=E)UTI
M*2![#0H@("`@("`@("`@("`D<W5B(#T@)'1H:7,M/E]P86-K86=E26YF;ULG
M9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G73L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'-U8ELP72DI('L-"B`@("`@("`@("`@
M("`@("`D<W5B(#T@87)R87DH)'-U8BD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V1E<&5N9&5N8VEE<R==6R=O<'1I;VYA;"==6R=S=6)P86-K86=E)UTI*2![
M#0H@("`@("`@("`@("`D<W5B,2`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M<&5N9&5N8VEE<R==6R=O<'1I;VYA;"==6R=S=6)P86-K86=E)UT[#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1S=6(Q6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("1S=6(Q(#T@87)R87DH)'-U8C$I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'-U8B`](&%R<F%Y7VUE<F=E*"1S=6(L("1S=6(Q*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`D
M9W)O=7`@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG
M9W)O=7`G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&=R;W5P6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("1G<F]U<"`](&%R<F%Y*"1G<F]U<"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9W)O=7`@87,@
M)&1E<',I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W-U
M8G!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'-U8C(@/2`D
M9&5P<ULG<W5B<&%C:V%G92==.PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1S=6(R6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'-U8C(@/2!A<G)A>2@D<W5B,BD[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@)'-U8B`](&%R<F%Y7VUE<F=E*"1S=6(L
M("1S=6(R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'-U8B!A<R`D9&5P*2![#0H@
M("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI(#T]('-T
M<G1O;&]W97(H)'`M/F=E=%!A8VMA9V4H*2DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P6R=C:&%N;F5L)UTI(#T]('-T
M<G1O;&]W97(H)'`M/F=E=$-H86YN96PH*2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1D97!;)W5R:2==(#T]("1P+3YG97154DDH*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&1E<&5N9'-/;B@D<&%C:V%G92P@)&-H86YN96PI#0H@("`@
M>PT*("`@("`@("!I9B`H(2@D9&5P<R`]("1T:&ES+3YG971$97!E;F1E;F-I
M97,H*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("AA<G)A>2@G<&%C:V%G92<L("=S=6)P86-K
M86=E)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M*"=R97%U:7)E9"<L("=O<'1I;VYA;"<I(&%S("1N965D960I('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)&YE961E9%U;)'1Y<&5=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R1N965D
M961=6R1T>7!E75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M97!S6R1N965D961=6R1T>7!E72`](&%R<F%Y*"1D97!S6R1N965D961=6R1T
M>7!E72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&1E<'-;)&YE961E9%U;)'1Y<&5=(&%S("1D97`I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@:7-S
M970H)&1E<%LG8VAA;FYE;"==*2`_("1D97!;)V-H86YN96PG72`Z("=?7W5R
M:2<[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D
M9&5P6R=N86UE)UTI(#T]('-T<G1O;&]W97(H)'!A8VMA9V4I("8F#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P8VAA;FYE;"`]/2`D8VAA
M;FYE;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2`@#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)V=R;W5P)UTI*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG9W)O=7`G75LP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG9W)O=7`G72`](&%R<F%Y
M*"1D97!S6R=G<F]U<"==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&1E<'-;)V=R;W5P)UT@87,@)&=R;W5P*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)'1Y<&5=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M9W)O=7!;)'1Y<&5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1G<F]U<%LD='EP95T@/2!A<G)A>2@D9W)O=7!;)'1Y<&5=*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1G<F]U<%LD='EP95T@87,@)&1E<"D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@:7-S970H)&1E<%LG
M8VAA;FYE;"==*2`_("1D97!;)V-H86YN96PG72`Z("=?7W5R:2<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&1E<%LG
M;F%M92==*2`]/2!S=')T;VQO=V5R*"1P86-K86=E*2`F)@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T]("1C:&%N
M;F5L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@(`T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!'970@=&AE(&-O;G1E;G1S(&]F(&$@9&5P96YD96YC>2!G<F]U<`T*
M("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A
M;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5P96YD96YC>4=R;W5P
M*"1N86UE*0T*("`@('L-"B`@("`@("`@)&YA;64@/2!S=')T;VQO=V5R*"1N
M86UE*3L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=D97!E;F1E;F-I97,G75LG9W)O=7`G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9W)O=7!S(#T@)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UT[#0H@
M("`@("`@(&EF("@A:7-S970H)&=R;W5P<ULP72DI('L-"B`@("`@("`@("`@
M("1G<F]U<',@/2!A<G)A>2@D9W)O=7!S*3L-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H("@D9W)O=7!S(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@
M:68@*'-T<G1O;&]W97(H)&=R;W5P6R=A='1R:6)S)UU;)VYA;64G72D@/3T@
M)&YA;64I('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&=R;W5P.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971R:65V92!A('!A<G1I86P@
M<&%C:V%G92YX;6P@,2XP(')E<')E<V5N=&%T:6]N(&]F(&1E<&5N9&5N8VEE
M<PT*("`@("`J#0H@("`@("H@82!V97)Y(&QI;6ET960@<F5P<F5S96YT871I
M;VX@;V8@9&5P96YD96YC:65S(&ES(')E='5R;F5D(&)Y('1H:7,@;65T:&]D
M+@T*("`@("`J(%1H92`\97AC;'5D93X@=&%G(&9O<B!E>&-L=61I;F<@8V5R
M=&%I;B!V97)S:6]N<R!O9B!A(&1E<&5N9&5N8WD@:7,-"B`@("`@*B!C;VUP
M;&5T96QY(&EG;F]R960N("!);B!A9&1I=&EO;BP@9&5P96YD96YC>2!G<F]U
M<',@87)E(&EG;F]R960L('=I=&@@=&AE#0H@("`@("H@87-S=6UP=&EO;B!T
M:&%T(&%L;"!D97!E;F1E;F-I97,@:6X@9&5P96YD96YC>2!G<F]U<',@87)E
M(&%L<V\@;&ES=&5D(&EN#0H@("`@("H@=&AE(&]P=&EO;F%L(&=R;W5P('1H
M870@=V]R:R!W:71H(&%L;"!D97!E;F1E;F-Y(&=R;W5P<PT*("`@("`J($!P
M87)A;2!B;V]L96%N(')E='5R;B!P86-K86=E+GAM;"`R+C`@/&1E<&5N9&5N
M8VEE<SX@=&%G#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=$1E<',H)')A=R`](&9A;'-E+"`D;F]P96%R
M:6YS=&%L;&5R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UTI*2![#0H@("`@
M("`@("`@("!I9B`H)')A=RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@)&UA<"`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=P:'`G(#T^("=P
M:'`G+`T*("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B`G<&MG)RP-"B`@
M("`@("`@("`@("`@("`G<W5B<&%C:V%G92<@/3X@)W!K9R<L#0H@("`@("`@
M("`@("`@("`@)V5X=&5N<VEO;B<@/3X@)V5X="<L#0H@("`@("`@("`@("`@
M("`@)V]S)R`]/B`G;W,G+`T*("`@("`@("`@("`@("`@("=P96%R:6YS=&%L
M;&5R)R`]/B`G<&MG)RP-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@9F]R96%C:"`H87)R87DH)W)E<75I<F5D)RP@)V]P=&EO;F%L)RD@87,@
M)'1Y<&4I('L-"B`@("`@("`@("`@("`@("`D;W!T:6]N86P@/2`H)'1Y<&4@
M/3T@)V]P=&EO;F%L)RD@/R`G>65S)R`Z("=N;R<[#0H@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I
M97,G75LD='EP95TI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LD='EP95T@
M87,@)&1T>7!E(#T^("1D97!S*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D9'1Y<&4@/3T@)W!E87)I;G-T86QL97(G("8F("1N;W!E87)I;G-T86QL
M97(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&1E<'-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5P<R`](&%R<F%Y*"1D97!S*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9&5P*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1M87!;)&1T
M>7!E72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!N;R!S
M=7!P;W)T(&9O<B!A<F-H('1Y<&4-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D9'1Y<&4@/3T@)W!E87)I;G-T
M86QL97(G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG
M;F%M92==(#T@)U!%05(G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!;)V-H86YN96PG72`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)',@
M/2!A<G)A>2@G='EP92<@/3X@)&UA<%LD9'1Y<&5=*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)V-H86YN96PG72`]("1D
M97!;)V-H86YN96PG73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=U<FDG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG=7)I)UT@/2`D
M9&5P6R=U<FDG73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=N86UE)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)VYA;64G72`]("1D
M97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG<F5L)UT@
M/2`G;F]T)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=M
M:6XG72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A
M:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S6R=R96PG72`]("=H87,G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<ULG;W!T:6]N86PG72`]("1O<'1I;VYA;#L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H
M)&1E<%LG;6EN)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1S6R=R96PG72`]("=G92<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S,2`]("1S.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<S%;)W)E;"==(#T@)VQE)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W9E<G-I;VXG72`]("1D
M97!;)VUI;B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<S%;)W9E<G-I;VXG72`]("1D97!;)VUA>"==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8VAA;FYE;"==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)',Q6R=C
M:&%N;F5L)UT@/2`D9&5P6R=C:&%N;F5L)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1D='EP92`A/2`G<&AP)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-;)VYA;64G72`]("1D97!;)VYA;64G
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S,5LG
M;F%M92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S6R=O<'1I;VYA;"==(#T@)&]P=&EO;F%L.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<S%;)V]P=&EO;F%L)UT@/2`D;W!T:6]N86P[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971;72`]("1S
M,3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S
M970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI("8F#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G
M72`]/2`D9&5P6R=M:6XG72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-;)W)E;"==(#T@)V=T)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S6R=R96PG72`]("=G92<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-;)W9E<G-I;VXG72`]("1D97!;)VUI;B==.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG;W!T:6]N86PG
M72`]("1O<'1I;VYA;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1D='EP92`A/2`G<&AP)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-;)VYA;64G72`]("1D97!;)VYA;64G73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D9&5P6R=M87@G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!;)V5X8VQU9&4G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T]("1D97!;)VUA
M>"==*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<ULG<F5L)UT@/2`G;'0G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-;)W)E;"==(#T@)VQE)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<ULG=F5R<VEO;B==(#T@)&1E<%LG;6%X)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S6R=O<'1I;VYA;"==(#T@)&]P=&EO;F%L
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1T>7!E
M("$]("=P:'`G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<ULG;F%M92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E=%M=(#T@)',[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H8V]U;G0H)')E="DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)')E=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E
M='5R;B!P:'!\97AT<W)C?&5X=&)I;GQB=6YD;&5\9F%L<V4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971086-K86=E5'EP92@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<&AP<F5L96%S92==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("=P:'`G.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1S<F-R
M96QE87-E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)V5X='-R8R<[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V5X=&)I;G)E;&5A<V4G72DI('L-"B`@("`@("`@("`@(')E='5R;B`G
M97AT8FEN)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)V)U;F1L92<[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@87)R87E\9F%L
M<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971296QE87-E<R@I#0H@("`@
M>PT*("`@("`@("`D='EP92`]("1T:&ES+3YG971086-K86=E5'EP92@I.PT*
M("`@("`@("!I9B`H)'1Y<&4@(3T@)V)U;F1L92<I('L-"B`@("`@("`@("`@
M("1T>7!E("X]("=R96QE87-E)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@)B8@:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULD='EP95TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULD='EP95T[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@
M87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971#:&%N9V5L;V<H*0T*
M("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-H86YG96QO9R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-H86YG96QO9R==.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!H87-$97!S
M*"D-"B`@("![#0H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D97!E;F1E;F-I97,G72D[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T4&%C:V%G97AM;%9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("<R+C`G.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@
M87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9713;W5R8V50
M86-K86=E*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=E>'1B:6YR96QE87-E)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH)V-H86YN96PG(#T^("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W-R8V-H86YN96PG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C
M:V%G92<@/3X@)'1H:7,M/E]P86-K86=E26YF;ULG<W)C<&%C:V%G92==*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T0G5N9&QE9%!A8VMA9V5S*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VYT96YT<R==6R=B=6YD;&5D<&%C:V%G92==.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971,
M87-T36]D:69I960H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)U]L87-T;6]D:69I960G72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=?;&%S=&UO9&EF:65D
M)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@8V]N=&5N=',@;V8@82!F:6QE
M(&QI<W1E9"!W:71H:6X@=&AE('!A8VMA9V4N>&UL#0H@("`@("H@0'!A<F%M
M('-T<FEN9PT*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T1FEL94-O;G1E;G1S*"1F:6QE*0T*("`@('L-"B`@("`@
M("`@:68@*"1T:&ES+3Y?87)C:&EV949I;&4@/3T@)'1H:7,M/E]P86-K86=E
M1FEL92D@>R`O+R!U;G!A8VME9`T*("`@("`@("`@("`@)&1I<B`](&1I<FYA
M;64H)'1H:7,M/E]P86-K86=E1FEL92D[#0H@("`@("`@("`@("`D9FEL92`]
M("1D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4[#0H@("`@("`@
M("`@("`D9FEL92`]('-T<E]R97!L86-E*&%R<F%Y*"<O)RP@)UQ<)RDL#0H@
M("`@("`@("`@("`@("`@87)R87DH1$E214-43U)97U-%4$%2051/4BP@1$E2
M14-43U)97U-%4$%2051/4BDL("1F:6QE*3L-"B`@("`@("`@("`@(&EF("AF
M:6QE7V5X:7-T<R@D9FEL92D@)B8@:7-?<F5A9&%B;&4H)&9I;&4I*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(&EM<&QO9&4H)R<L(&9I;&4H)&9I;&4I
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L@+R\@=&=Z#0H@
M("`@("`@("`@("`D=&%R(#T@)FYE=R!!<F-H:79E7U1A<B@D=&AI<RT^7V%R
M8VAI=F5&:6QE*3L-"B`@("`@("`@("`@("1T87(M/G!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@(&EF("@D9FEL
M92`A/2`G<&%C:V%G92YX;6PG("8F("1F:6QE("$]("=P86-K86=E,BYX;6PG
M*2![#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^9V5T4&%C:V%G
M92@I("X@)RTG("X@)'1H:7,M/F=E=%9E<G-I;VXH*2`N("<O)R`N("1F:6QE
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&9I;&4@/2`D=&%R+3YE
M>'1R86-T26Y3=')I;F<H)&9I;&4I.PT*("`@("`@("`@("`@)'1A<BT^<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(D-A;FYO="!L;V-A=&4@9FEL92`G)&9I;&4G(&EN(&%R8VAI
M=F4B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D9FEL
M93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N("9G97125R@I
M#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K
M86=E1FEL95]V,E]R=R<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4O=C(O<G<N<&AP)SL-"B`@("`@("`@?0T*("`@
M("`@("`D82`](&YE=R!014%27U!A8VMA9V5&:6QE7W8R7W)W.PT*("`@("`@
M("!F;W)E86-H("AG971?;V)J96-T7W9A<G,H)'1H:7,I(&%S("1N86UE(#T^
M("1U;G5S960I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/B1N
M86UE*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"1N86UE(#T]("=?8V]N9FEG)R!\?"`D
M;F%M92`]/2`G7VQO9V=E<B=\?"`D;F%M92`]/2`G7W)E9VES=')Y)R!\?`T*
M("`@("`@("`@("`@("`@("`@)&YA;64@/3T@)U]S=&%C:R<I('L-"B`@("`@
M("`@("`@("`@("`D82T^)&YA;64@/2`F)'1H:7,M/B1N86UE.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D82T^)&YA;64@/2`D
M=&AI<RT^)&YA;64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@(&9U;F-T:6]N("9G971$969A
M=6QT1V5N97)A=&]R*"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,B<I*2![#0H@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O1V5N97)A
M=&]R+W8R+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F;F5W(%!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R*"1T:&ES*3L-"B`@("`@("`@
M<F5T=7)N("1A.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&%N86QY>F53;W5R
M8V5#;V1E*"1F:6QE+"`D<W1R:6YG(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?=C)686QI9&%T;W(I('Q\#0H@("`@("`@
M("`@("`@("%I<U]A*"1T:&ES+3Y?=C)686QI9&%T;W(L("=014%27U!A8VMA
M9V5&:6QE7W8R7U9A;&ED871O<B<I*2![#0H@("`@("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@G4$5!4E]086-K86=E1FEL95]V,E]686QI9&%T;W(G*2D@
M>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E
M1FEL92]V,B]686QI9&%T;W(N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1T:&ES+3Y?=C)686QI9&%T;W(@/2!N97<@4$5!4E]086-K86=E
M1FEL95]V,E]686QI9&%T;W([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=C)686QI9&%T;W(M/F%N86QY>F53;W5R8V5#;V1E*"1F:6QE
M+"`D<W1R:6YG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T92@D
M<W1A=&4@/2!014%27U9!3$E$051%7TY/4DU!3"D-"B`@("![#0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;RD@?'P@(6ES7V%R<F%Y
M*"1T:&ES+3Y?<&%C:V%G94EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W8R5F%L:61A=&]R*2!\?`T*("`@("`@("`@("`@("`A:7-?82@D=&AI<RT^
M7W8R5F%L:61A=&]R+"`G4$5!4E]086-K86=E1FEL95]V,E]686QI9&%T;W(G
M*2D@>PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C
M:V%G949I;&5?=C)?5F%L:61A=&]R)RDI('L-"B`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(O5F%L:61A=&]R+G!H
M<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W8R5F%L
M:61A=&]R(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=X<V1V97)S:6]N)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=X<V1V97)S:6]N)UTI.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W8R5F%L:61A=&]R+3YV86QI9&%T92@D
M=&AI<RP@)'-T871E*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971487-K
M<TYS*"D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]T87-K
M<TYS*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R:6)S)UT@87,@)&YA;64@/3X@
M)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=64@/3T@
M)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%S:W-.<R`]('-T<E]R97!L
M86-E*"=X;6QN<SHG+"`G)RP@)&YA;64I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=&%S:W-.<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!$971E<FUI;F4@=VAE=&AE<B!A('1A<VL@;F%M92!I<R!A('9A;&ED
M('1A<VLN("!#=7-T;VT@=&%S:W,@;6%Y(&)E(&1E9FEN960-"B`@("`@*B!U
M<VEN9R!S=6)D:7)E8W1O<FEE<R!B>2!P=71T:6YG(&$@(BTB(&EN('1H92!N
M86UE+"!A<R!I;B`\=&%S:W,Z;7EC=7-T;VTM=&%S:SX-"B`@("`@*@T*("`@
M("`J($YO=&4@=&AA="!T:&ES(&UE=&AO9"!W:6QL(&%U=&\M;&]A9"!T:&4@
M=&%S:R!C;&%S<R!F:6QE(&%N9"!T97-T(&9O<B!T:&4@97AI<W1E;F-E#0H@
M("`@("H@;V8@=&AE(&YA;64@=VET:"`B+2(@<F5P;&%C960@8GD@(E\B(&%S
M(&EN(%!%05(O5&%S:R]M>6-U<W1O;2]T87-K+G!H<"!M86ME<R!C;&%S<PT*
M("`@("`J(%!%05)?5&%S:U]M>6-U<W1O;5]T87-K#0H@("`@("H@0'!A<F%M
M('-T<FEN9PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=%1A<VLH)'1A<VLI#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^9V5T5&%S:W-.<R@I.PT*("`@("`@("`O+R!T<F%N<V9O<FT@86QL("<M
M)R!T;R`G+R<@86YD("=T87-K<SHG('1O("<G('-O('1A<VMS.G)E<&QA8V4@
M8F5C;VUE<R!R97!L86-E#0H@("`@("`@("1T87-K(#T@<W1R7W)E<&QA8V4H
M87)R87DH)'1H:7,M/E]T87-K<TYS("X@)SHG+"`G+2<I+"!A<G)A>2@G)RP@
M)R`G*2P@)'1A<VLI.PT*("`@("`@("`D=&%S:R`]('-T<E]R97!L86-E*"<@
M)RP@)R\G+"!U8W=O<F1S*"1T87-K*2D[#0H@("`@("`@("1P<R`]("AS=')T
M;VQO=V5R*'-U8G-T<BA02%!?3U,L(#`L(#,I*2`]/2`G=VEN)RD@/R`G.R<@
M.B`G.B<[#0H@("`@("`@(&9O<F5A8V@@*&5X<&QO9&4H)'!S+"!I;FE?9V5T
M*"=I;F-L=61E7W!A=&@G*2D@87,@)'!A=&@I('L-"B`@("`@("`@("`@(&EF
M("AF:6QE7V5X:7-T<R@D<&%T:"`N("(O4$5!4B]487-K+R1T87-K+G!H<"(I
M*2![#0H@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E(")014%2+U1A<VLO
M)'1A<VLN<&AP(CL-"B`@("`@("`@("`@("`@("`D=&%S:R`]('-T<E]R97!L
M86-E*"<O)RP@)U\G+"`D=&%S:RD[#0H@("`@("`@("`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@B4$5!4E]487-K7R1T87-K(BDI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(")014%27U1A<VM?)'1A<VLB.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@2V5Y+69R
M:65N9&QY(&%R<F%Y7W-P;&EC90T*("`@("`J($!P87)A;2!T86=N86UE('1O
M('-P;&EC92!A('9A;'5E(&EN(&)E9F]R90T*("`@("`J($!P87)A;2!M:7AE
M9"!T:&4@=F%L=64@=&\@<W!L:6-E(&EN#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!T:&4@;F5W('1A9R!N86UE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VMS
M<&QI8V4H)&%R<F%Y+"`D:V5Y+"`D=F%L=64L("1N97=K97DI#0H@("`@>PT*
M("`@("`@("`D;V9F<V5T(#T@87)R87E?<V5A<F-H*"1K97DL(&%R<F%Y7VME
M>7,H)&%R<F%Y*2D[#0H@("`@("`@("1A9G1E<B`](&%R<F%Y7W-L:6-E*"1A
M<G)A>2P@)&]F9G-E="D[#0H@("`@("`@("1B969O<F4@/2!A<G)A>5]S;&EC
M92@D87)R87DL(#`L("1O9F9S970I.PT*("`@("`@("`D8F5F;W)E6R1N97=K
M97E=(#T@)'9A;'5E.PT*("`@("`@("!R971U<FX@87)R87E?;65R9V4H)&)E
M9F]R92P@)&%F=&5R*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@87)R87D@82!L:7-T(&]F('!O<W-I8FQE(&ME>7,L(&EN('1H92!O<F1E
M<B!T:&5Y(&UA>2!O8V-U<@T*("`@("`J($!P87)A;2!M:7AE9"!C;VYT96YT
M<R!O9B!T:&4@;F5W('!A8VMA9V4N>&UL('1A9PT*("`@("`J($!P87)A;2!S
M=')I;F<@=&%G(&YA;64-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?:6YS97)T0F5F;W)E*"1A<G)A>2P@)&ME>7,L
M("1C;VYT96YT<RP@)&YE=VME>2D-"B`@("![#0H@("`@("`@(&9O<F5A8V@@
M*"1K97ES(&%S("1K97DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D87)R
M87E;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1A<G)A>2`]
M("1T:&ES+3Y?:W-P;&EC92@D87)R87DL("1K97DL("1C;VYT96YT<RP@)&YE
M=VME>2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&%R
M<F%Y6R1N97=K97E=(#T@)&-O;G1E;G1S.PT*("`@("`@("!R971U<FX@)&%R
M<F%Y.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=6)S96-T
M:6]N(&]F('M`;&EN:R`D7W!A8VMA9V5);F9O?0T*("`@("`J($!P87)A;2!A
M<G)A>7QS=')I;F<@=&%G(&-O;G1E;G1S#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(&9O<FUA=#H-"B`@("`@*B`\<')E/@T*("`@("`J(&%R<F%Y*`T*("`@("`J
M("`@=&%G;F%M92`]/B!A<G)A>2AL:7-T(&]F('1A9R!N86UE<R!T:&%T(&9O
M;&QO=R!T:&ES(&]N92DL#0H@("`@("H@("!C:&EL9'1A9VYA;64@/3X@87)R
M87DH;&ES="!O9B!C:&EL9"!T86<@;F%M97,@=&AA="!F;VQL;W<@=&AI<R!O
M;F4I+`T*("`@("`J("D-"B`@("`@*B`\+W!R93X-"B`@("`@*@T*("`@("`J
M(%1H:7,@86QL;W=S(&-O;G-T<G5C=&EO;B!O9B!N97-T960@=&%G<PT*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]M
M97)G951A9R@D;6%N:7`L("1C;VYT96YT<RP@)&]R9&5R*0T*("`@('L-"B`@
M("`@("`@:68@*&-O=6YT*"1O<F1E<BDI('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1O<F1E<B!A<R`D=&%G(#T^("1C=7)O<F1E<BD@>PT*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&UA;FEP6R1T86==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`O+R!E;G-U<F4@=&AA="!T:&4@=&%G(&ES('-E="!U<`T*
M("`@("`@("`@("`@("`@("`@("`D;6%N:7`@/2`D=&AI<RT^7VEN<V5R=$)E
M9F]R92@D;6%N:7`L("1C=7)O<F1E<BP@87)R87DH*2P@)'1A9RD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D;W)D
M97(I(#X@,2D@>PT*("`@("`@("`@("`@("`@("`@("`D;6%N:7!;)'1A9UT@
M/2`D=&AI<RT^7VUE<F=E5&%G*"1M86YI<%LD=&%G72P@)&-O;G1E;G1S+"!A
M<G)A>5]S;&EC92@D;W)D97(L(#$I*3L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1M86YI<#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@)&UA
M;FEP.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<U]A<G)A>2@D;6%N:7!;
M)'1A9UTI("8F("%E;7!T>2@D;6%N:7!;)'1A9UTI("8F(&ES<V5T*"1M86YI
M<%LD=&%G75LP72DI('L-"B`@("`@("`@("`@("1M86YI<%LD=&%G75M=(#T@
M)&-O;G1E;G1S.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@
M*"%C;W5N="@D;6%N:7!;)'1A9UTI*2![#0H@("`@("`@("`@("`@("`@)&UA
M;FEP6R1T86==(#T@)&-O;G1E;G1S.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D;6%N:7!;)'1A9UT@/2!A<G)A>2@D;6%N:7!;
M)'1A9UTI.PT*("`@("`@("`@("`@("`@("1M86YI<%LD=&%G75M=(#T@)&-O
M;G1E;G1S.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D;6%N:7`[#0H@("`@?0T*?0T*/SX-"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]V,2YP:'``````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-#4T-C8`,3`U,34T,S$P-3<`,#(Q
M,S`R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO*BH-"B`J(%!%05)?4&%C:V%G949I;&5?=C$L('!A8VMA9V4N
M>&UL('9E<G-I;VX@,2XP#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z('8Q+G!H<"QV(#$N-CD@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C
M96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!&;W(@97)R
M;W(@:&%N9&QI;F<-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T5R<F]R4W1A
M8VLN<&AP)SL-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E(&EF('!A<G-I;F<@:7,@
M871T96UP=&5D('=I=&@@;F\@>&UL(&5X=&5N<VEO;@T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?6$U,7T585"<L(#,I.PT*#0HO
M*BH-"B`J($5R<F]R(&-O9&4@:68@8W)E871I;F<@=&AE('AM;"!P87)S97(@
M<F5S;W5R8V4@9F%I;',-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%
M7T524D]27T-!3E1?34%+15]005)315(G+"`T*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('5S960@9F]R(&%L;"!S87@@>&UL('!A<G-I;F<@97)R;W)S#0H@
M*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E]005)315)?15)2
M3U(G+"`U*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@=VAE;B!T:&5R
M92!I<R!N;R!N86UE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U].04U%)RP@-BD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N
M(&$@<&%C:V%G92!N86UE(&ES(&YO="!V86QI9`T*("HO#0ID969I;F4H)U!%
M05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%].04U%)RP@-RD[#0H-"B\J
M*@T*("H@17)R;W(@8V]D92!U<V5D('=H96X@;F\@<W5M;6%R>2!I<R!P87)S
M960-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7U-5
M34U!4EDG+"`X*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E(&9O<B!S=6UM87)I
M97,@=&AA="!A<F4@;6]R92!T:&%N(#$@;&EN90T*("HO#0ID969I;F4H)U!%
M05)?4$%#2T%'149)3$5?15)23U)?355,5$E,24Y%7U-534U!4EDG+"`Y*3L-
M"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@=VAE;B!N;R!D97-C<FEP=&EO
M;B!I<R!P<F5S96YT#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U]$15-#4DE05$E/3B<L(#$P*3L-"@T*+RHJ#0H@*B!%<G)O<B!C
M;V1E('5S960@=VAE;B!N;R!L:6-E;G-E(&ES('!R97-E;G0-"B`J+PT*9&5F
M:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7TQ)0T5.4T4G+"`Q,2D[
M#0H-"B\J*@T*("H@17)R;W(@8V]D92!U<V5D('=H96X@82`\=F5R<VEO;CX@
M=F5R<VEO;B!N=6UB97(@:7,@;F]T('!R97-E;G0-"B`J+PT*9&5F:6YE*"=0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7U9%4E-)3TXG+"`Q,BD[#0H-"B\J
M*@T*("H@17)R;W(@8V]D92!U<V5D('=H96X@82`\=F5R<VEO;CX@=F5R<VEO
M;B!N=6UB97(@:7,@:6YV86QI9`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'
M149)3$5?15)23U)?24Y604Q)1%]615)324].)RP@,3,I.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=VAE;B!R96QE87-E('-T871E(&ES(&UI<W-I;F<-"B`J
M+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7U-4051%)RP@
M,30I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!R96QE87-E('-T871E
M(&ES(&EN=F%L:60-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T52
M4D]27TE.5D%,241?4U1!5$4G+"`Q-2D[#0H-"B\J*@T*("H@17)R;W(@8V]D
M92!W:&5N(')E;&5A<V4@<W1A=&4@:7,@;6ES<VEN9PT*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$%412<L(#$V*3L-"@T*+RHJ
M#0H@*B!%<G)O<B!C;V1E('=H96X@<F5L96%S92!S=&%T92!I<R!I;G9A;&ED
M#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$
M7T1!5$4G+"`Q-RD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&YO(')E
M;&5A<V4@;F]T97,@87)E(&9O=6YD#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U].3U1%4R<L(#$X*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('=H96X@;F\@;6%I;G1A:6YE<G,@87)E(&9O=6YD#0H@*B\-"F1E
M9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5$%)3D524R<L
M(#$Y*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!M86EN=&%I;F5R
M(&AA<R!N;R!H86YD;&4-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7TU!24Y42$%.1$Q%)RP@,C`I.PT*#0HO*BH-"B`J($5R<F]R
M(&-O9&4@=VAE;B!A(&UA:6YT86EN97(@:&%S(&YO(&AA;F1L90T*("HO#0ID
M969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E123TQ%)RP@
M,C$I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&UA:6YT86EN97(@
M:&%S(&YO(&YA;64-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T52
M4D]27TY/7TU!24Y43D%-12<L(#(R*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E
M('=H96X@82!M86EN=&%I;F5R(&AA<R!N;R!E;6%I;`T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1%34%)3"<L(#(S*3L-
M"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!M86EN=&%I;F5R(&AA<R!N
M;R!H86YD;&4-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]2
M7TE.5D%,241?34%)3E123TQ%)RP@,C0I.PT*#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=VAE;B!A(&1E<&5N9&5N8WD@:7,@;F]T(&$@4$A0(&1E<&5N9&5N8WDL
M(&)U="!H87,@;F\@;F%M90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?1$503D%-12<L(#(U*3L-"@T*+RHJ#0H@*B!%<G)O<B!C
M;V1E('=H96X@82!D97!E;F1E;F-Y(&AA<R!N;R!T>7!E("AP:V<L('!H<"P@
M971C+BD-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/
M7T1%4%194$4G+"`R-BD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@
M9&5P96YD96YC>2!H87,@;F\@<F5L871I;VX@*&QT+"!G92P@:&%S+"!E=&,N
M*0T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$50
M4D5,)RP@,C<I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N
M9&5N8WD@:7,@;F]T(&$@)VAA<R<@<F5L871I;VXL(&)U="!H87,@;F\@=F5R
M<VEO;@T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?
M1$505D524TE/3B<L(#(X*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M82!D97!E;F1E;F-Y(&AA<R!A;B!I;G9A;&ED(')E;&%T:6]N#0H@*B\-"F1E
M9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7T1%4%)%3"<L
M(#(Y*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y
M(&AA<R!A;B!I;G9A;&ED('1Y<&4-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!
M1T5&24Q%7T524D]27TE.5D%,241?1$505%E012<L(#,P*3L-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y(&AA<R!A;B!I;G9A;&ED
M(&]P=&EO;F%L(&]P=&EO;@T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?24Y604Q)1%]$15!/4%1)3TY!3"<L(#,Q*3L-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y(&ES(&$@<&MG(&1E<&5N
M9&5N8WDL(&%N9"!H87,@86X@:6YV86QI9"!P86-K86=E(&YA;64-"B`J+PT*
M9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?1$503D%-
M12<L(#,R*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E
M;F-Y(&AA<R!A(&-H86YN96P](F9O;R(@871T<FEB=71E+"!A;F0@9F]O(&ES
M(&YO="!A(')E9VES=&5R960@8VAA;FYE;`T*("HO#0ID969I;F4H)U!%05)?
M4$%#2T%'149)3$5?15)23U)?54Y+3D]73E]$15!#2$%.3D5,)RP@,S,I.PT*
M#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!R96P](FAA<R(@86YD('9E<G-I
M;VX@871T<FEB=71E(&ES('!R97-E;G0N#0H@*B\-"F1E9FEN92@G4$5!4E]0
M04-+04=%1DE,15]%4E)/4E]$15!615)324].7TE'3D]2140G+"`S-"D[#0H-
M"B\J*@T*("H@17)R;W(@8V]D92!W:&5N('1Y<&4](G!H<"(@86YD(&1E<&5N
M9&5N8WD@;F%M92!I<R!P<F5S96YT#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E]$15!.04U%7TE'3D]2140G+"`S-2D[#0H-"B\J*@T*
M("H@17)R;W(@8V]D92!W:&5N(&$@8V]N9FEG=7)E(&]P=&EO;B!H87,@;F\@
M;F%M90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?
M0T].1DY!344G+"`S-BD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@
M8V]N9FEG=7)E(&]P=&EO;B!H87,@;F\@;F%M90T*("HO#0ID969I;F4H)U!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?0T].1E!23TU05"<L(#,W*3L-"@T*
M+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!F:6QE(&EN('1H92!F:6QE;&ES
M="!H87,@86X@:6YV86QI9"!R;VQE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E])3E9!3$E$7T9)3$523TQ%)RP@,S@I.PT*#0HO*BH-
M"B`J($5R<F]R(&-O9&4@=VAE;B!A(&9I;&4@:6X@=&AE(&9I;&5L:7-T(&AA
M<R!N;R!R;VQE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]&24Q%4D],12<L(#,Y*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@86YA;'EZ:6YG(&$@<&AP('-O=7)C92!F:6QE('1H870@:&%S('!A<G-E
M(&5R<F]R<PT*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?
M24Y604Q)1%]02%!&24Q%)RP@-#`I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@
M=VAE;B!A;F%L>7II;F<@82!P:'`@<V]U<F-E(&9I;&4@<F5V96%L<R!A('-O
M=7)C92!E;&5M96YT#0H@*B!W:71H;W5T(&$@<&%C:V%G92!N86UE('!R969I
M>`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?4$Y!
M345?4%)%1DE8)RP@-#$I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A
M;B!U;FMN;W=N(&-H86YN96P@:7,@<W!E8VEF:65D#0H@*B\-"F1E9FEN92@G
M4$5!4E]004-+04=%1DE,15]%4E)/4E]53DM.3U=.7T-(04Y.14PG+"`T,BD[
M#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&YO(&9I;&5S(&%R92!F;W5N
M9"!I;B!T:&4@9FEL96QI<W0-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&
M24Q%7T524D]27TY/7T9)3$53)RP@-#,I.PT*#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=VAE;B!A(&9I;&4@:7,@;F]T('9A;&ED('!H<"!A8V-O<F1I;F<@=&\@
M7V%N86QY>F53;W5R8V5#;V1E*"D-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!
M1T5&24Q%7T524D]27TE.5D%,241?1DE,12<L(#0T*3L-"@T*+RHJ#0H@*B!%
M<G)O<B!C;V1E('=H96X@=&AE(&-H86YN96P@=F%L:61A=&]R(')E='5R;G,@
M86X@97)R;W(@;W(@=V%R;FEN9PT*("HO#0ID969I;F4H)U!%05)?4$%#2T%'
M149)3$5?15)23U)?0TA!3DY%3%9!3"<L(#0U*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('=H96X@82!P:'`U('!A8VMA9V4@:7,@<&%C:V%G960@:6X@<&AP
M-"`H86YA;'ES:7,@9&]E<VXG="!W;W)K*0T*("HO#0ID969I;F4H)U!%05)?
M4$%#2T%'149)3$5?15)23U)?4$A0-2<L(#0V*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('=H96X@82!F:6QE(&ES(&QI<W1E9"!I;B!P86-K86=E+GAM;"!B
M=70@9&]E<R!N;W0@97AI<W0-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&
M24Q%7T524D]27T9)3$5?3D]41D]53D0G+"`T-RD[#0H-"B\J*@T*("H@17)R
M;W(@8V]D92!W:&5N(&$@/&1E<"!T>7!E/2)P:'`B(')E;#TB;F]T(BXN+B!I
M<R!E;F-O=6YT97)E9"`H=7-E(')E;#TB;F4B*0T*("HO#0ID969I;F4H)U!%
M05)?4$%#2T%'149)3$5?4$A07TY/7TY/5"<L(#0X*3L-"@T*+RHJ#0H@*B!%
M<G)O<B!C;V1E('=H96X@82!P86-K86=E+GAM;"!C;VYT86EN<R!N;VXM25-/
M+3@X-3DM,2!C:&%R86-T97)S#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3TY?25-/7T-(05)3)RP@-#DI.PT*#0HO*BH-"B`J($5R
M<F]R(&-O9&4@=VAE;B!A(&1E<&5N9&5N8WD@:7,@;F]T(&$@)VAA<R<@<F5L
M871I;VXL(&)U="!H87,@;F\@=F5R<VEO;@T*("HO#0ID969I;F4H)U!%05)?
M4$%#2T%'149)3$5?15)23U)?3D]?1$504$A05D524TE/3B<L(#4P*3L-"@T*
M+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!P86-K86=E(&AA<R!N;R!L96%D
M(&1E=F5L;W!E<@T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)2
M3U)?3D]?3$5!1"<L(#4Q*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M82!F:6QE;F%M92!B96=I;G,@=VET:"`B+B(-"B`J+PT*9&5F:6YE*"=014%2
M7U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?1DE,14Y!344G+"`U,BD[#0HO
M*BH-"B`J('!A8VMA9V4N>&UL(&5N8V%P<W5L871O<@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?=C$-"GL-"B`@("`O*BH-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B!`=F%R(%!%05)?17)R
M;W)3=&%C:PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M('9A<B`D7W-T86-K.PT*#0H@("`@+RHJ#0H@("`@("H@02!R96=I<W1R>2!O
M8FIE8W0L('5S960@=&\@86-C97-S('1H92!P86-K86=E(&YA;64@=F%L:61A
M=&EO;B!R96=E>"!F;W(@;F]N+7-T86YD87)D(&-H86YN96QS#0H@("`@("H@
M0'9A<B!014%27U)E9VES=')Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@=F%R("1?<F5G:7-T<GD[#0H-"B`@("`O*BH-"B`@("`@
M*B!!;B!O8FIE8W0@=&AA="!C;VYT86EN<R!A(&QO9R!M971H;V0@=&AA="!M
M871C:&5S(%!%05)?0V]M;6]N.CIL;V<G<R!S:6=N871U<F4-"B`@("`@*B!`
M=F%R(&]B:F5C=`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@('9A<B`D7VQO9V=E<CL-"@T*("`@("\J*@T*("`@("`J(%!A<G-E9"!P
M86-K86=E(&EN9F]R;6%T:6]N#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5)
M;F9O.PT*#0H@("`@+RHJ#0H@("`@("H@<&%T:"!T;R!P86-K86=E+GAM;`T*
M("`@("`J($!V87(@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@=F%R("1?<&%C:V%G949I;&4[#0H-"B`@("`O*BH-"B`@
M("`@*B!P871H('1O('!A8VMA9V4@+G1G>B!O<B!F86QS92!I9B!T:&ES(&ES
M(&$@;&]C86PO97AT<F%C=&5D('!A8VMA9V4N>&UL#0H@("`@("H@0'9A<B!S
M=')I;F<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V
M87(@)%]A<F-H:79E1FEL93L-"@T*("`@("\J*@T*("`@("`J($!V87(@:6YT
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M:7-686QI9"`](#`[#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H
M971H97(@=&AI<R!P86-K86=E9FEL92!W87,@:6YI=&EA;&EZ960@;VYL>2!W
M:71H('!A<G1I86P@<&%C:V%G92!I;F9O#0H@("`@("H-"B`@("`@*B!)9B!T
M:&ES('!A8VMA9V4@9FEL92!W87,@8V]N<W1R=6-T960@=FEA('!A<G-I;F<@
M4D535"P@:70@=VEL;"!O;FQY(&-O;G1A:6X-"B`@("`@*@T*("`@("`J("T@
M<&%C:V%G92!N86UE#0H@("`@("H@+2!C:&%N;F5L(&YA;64-"B`@("`@*B`M
M(&1E<&5N9&5N8VEE<R`-"B`@("`@*B!`=F%R(&)O;VQE86X-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]I;F-O;7!L971E
M(#T@=')U93L-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!B;V]L(&1E=&5R
M;6EN97,@=VAE=&AE<B!T;R!R971U<FX@82!014%27T5R<F]R(&]B:F5C="P@
M;W(@=7-E('1H92!014%27T5R<F]R4W1A8VL-"B`@("`@*B!`<&%R86T@<W1R
M:6YG($YA;64@;V8@17)R;W(@4W1A8VL@8VQA<W,@=&\@=7-E+@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%!%05)?4&%C:V%G949I;&5?=C$H*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]S=&%C:R`]("9N97<@4$5!4E]%<G)O<E-T86-K
M*"=014%27U!A8VMA9V5&:6QE7W8Q)RD[#0H@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G-E=$5R<F]R365S<V%G951E;7!L871E*"1T:&ES+3Y?9V5T17)R;W)-
M97-S86=E*"DI.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&EN<W1A;&Q":6YA<GDH)&EN<W1A;&QE<BD-
M"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!I<T5X=&5N<VEO;B@D;F%M92D-"B`@("![#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H
M)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("8D
M8V]N9FEG.PT*("`@("`@("`D=&AI<RT^7W)E9VES=')Y(#T@)B1C;VYF:6<M
M/F=E=%)E9VES=')Y*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T4F5Q
M=65S=&5D1W)O=7`H*0T*("`@('L-"B`@("`@("`@+R\@<&QA8V5H;VQD97(-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@<V%V:6YG(&EN('1H92!R
M96=I<W1R>2X-"B`@("`@*@T*("`@("`J(%-E="!T:&4@;&%S="!V97)S:6]N
M('1H870@=V%S(&EN<W1A;&QE9`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!S971,87-T26YS=&%L;&5D5F5R<VEO;B@D
M=F5R<VEO;BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)U]L87-T=F5R<VEO;B==(#T@)'9E<G-I;VX[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971,87-T26YS=&%L;&5D5F5R<VEO;B@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1V97)S
M:6]N)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E
M26YF;ULG7VQA<W1V97)S:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$EN<W1A;&QE
M9$)I;F%R>2@I#0H@("`@>PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@;&ES=%!O<W1I;G-T86QL4V-R:7!T<R@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@:6YI=%!O<W1I;G-T86QL4V-R:7!T<R@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3&]G
M9V5R*"8D;&]G9V5R*0T*("`@('L-"B`@("`@("`@:68@*"1L;V=G97(@)B8@
M*"%I<U]O8FIE8W0H)&QO9V=E<BD@?'P@(6UE=&AO9%]E>&ES=',H)&QO9V=E
M<BP@)VQO9R<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)TQO9V=E<B!M=7-T(&)E(&-O;7!A=&EB;&4@=VET:"!014%27T-O
M;6UO;CHZ;&]G)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]L;V=G
M97(@/2`F)&QO9V=E<CL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971086-K
M86=E9FEL92@D9FEL92P@)&%R8VAI=F4@/2!F86QS92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G949I;&4@/2`D9FEL93L-"B`@("`@("`@)'1H
M:7,M/E]A<F-H:79E1FEL92`]("1A<F-H:79E(#\@)&%R8VAI=F4@.B`D9FEL
M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E1FEL92@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]P86-K86=E1FEL
M92D@/R`D=&AI<RT^7W!A8VMA9V5&:6QE(#H@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T4&%C:V%G951Y<&4H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("=P:'`G.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$%R8VAI
M=F5&:6QE*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V%R8VAI
M=F5&:6QE.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('!A8VMA9V5);F9O*"1F
M:65L9"D-"B`@("![#0H@("`@("`@(&EF("@A:7-?<W1R:6YG*"1F:65L9"D@
M?'P@96UP='DH)&9I96QD*2!\?`T*("`@("`@("`@("`@(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)&9I96QD72DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULD9FEE;&1=.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E
M=$1I<G1R964H)'!A=&@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D:7)T<F5E)UU;)'!A=&A=(#T@=')U93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G971$:7)T<F5E*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UTI("8F(&-O=6YT
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1I<G1R964G72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UT[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(')E<V5T1&ER=')E92@I#0H@("`@>PT*("`@("`@("!U;G-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UTI.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&9R;VU!<G)A>2@D<&EN9F\I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^7VEN8V]M<&QE=&4@/2!F86QS93L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;R`]("1P:6YF;SL-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!I<TEN8V]M<&QE=&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6YC;VUP;&5T93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#:&%N
M;F5L*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G<&5A<BYP:'`N;F5T)SL-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9715<FDH*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%1I
M;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=$5X=&5N9',H*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V5X=&5N9',G72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1E;F1S
M)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!T;T%R<F%Y*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H
M:7,M/G9A;&ED871E*%!%05)?5D%,241!5$5?3D]234%,*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^9V5T07)R87DH*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M971!<G)A>2@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971.86UE*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T4&%C:V%G92@I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V4H*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!A8VMA9V4G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=P
M86-K86=E)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D;VXG="!U<V4@
M=&AI<R!U;FQE<W,@>6]U(&MN;W<@=VAA="!Y;W4@87)E(&1O:6YG#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<V5T4F%W4&%C:V%G92@D<&%C:V%G92D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W!A8VMA9V4G72`]
M("1P86-K86=E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%!A8VMA9V4H
M)'!A8VMA9V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=P86-K86=E)UT@/2`D<&%C:V%G93L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5F5R<VEO
M;B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T5F5R
M<VEO;B@D=F5R<VEO;BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)W9E<G-I;VXG72`]("1V97)S:6]N.PT*("`@("`@("`D=&AI<RT^
M7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!C;&5A
M<DUA:6YT86EN97)S*"D-"B`@("![#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UTI.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=$UA:6YT86EN97)S*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT
M86EN97)S)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($%D9',@82!N97<@;6%I;G1A:6YE
M<B`M(&YO(&-H96-K:6YG(&]F(&1U<&QI8V%T97,@:7,@<&5R9F]R;65D+"!U
M<V4-"B`@("`@*B!U<&1A=&5M86EN=&%I;F5R(&9O<B!T:&%T('!U<G!O<V4N
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D36%I;G1A:6YE<B@D<F]L92P@
M)&AA;F1L92P@)&YA;64L("1E;6%I;"D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UU;72`]#0H@("`@("`@("`@
M("!A<G)A>2@G:&%N9&QE)R`]/B`D:&%N9&QE+"`G<F]L92<@/3X@)')O;&4L
M("=E;6%I;"<@/3X@)&5M86EL+"`G;F%M92<@/3X@)&YA;64I.PT*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!U<&1A=&5-86EN=&%I;F5R*"1R;VQE+"`D:&%N9&QE+"`D;F%M92P@
M)&5M86EL*0T*("`@('L-"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE
M<G,G72D@?'P-"B`@("`@("`@("`@("`@(6ES7V%R<F%Y*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)VUA:6YT86EN97)S)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F%D9$UA:6YT86EN97(H)')O;&4L("1H86YD;&4L("1N86UE
M+"`D96UA:6PI.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UT@87,@)&D@/3X@)&UA:6YT
M86EN97(I('L-"B`@("`@("`@("`@(&EF("@D;6%I;G1A:6YE<ELG:&%N9&QE
M)UT@/3T@)&AA;F1L92D@>PT*("`@("`@("`@("`@("`@("1F;W5N9"`]("1I
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@D9F]U;F0@(3T](&9A;'-E*2![#0H@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R
M<R==6R1F;W5N9%TI.PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG;6%I;G1A:6YE<G,G72`]#0H@("`@("`@("`@("`@("`@87)R87E?=F%L
M=65S*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UTI.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YA9&1-86EN=&%I;F5R*"1R;VQE+"`D
M:&%N9&QE+"`D;F%M92P@)&5M86EL*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!D96QE=&5-86EN=&%I;F5R*"1H86YD;&4I#0H@("`@>PT*("`@("`@("`D
M9F]U;F0@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K
M86=E26YF;ULG;6%I;G1A:6YE<G,G72!A<R`D:2`]/B`D;6%I;G1A:6YE<BD@
M>PT*("`@("`@("`@("`@:68@*"1M86EN=&%I;F5R6R=H86YD;&4G72`]/2`D
M:&%N9&QE*2![#0H@("`@("`@("`@("`@("`@)&9O=6YD(#T@)&D[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1F;W5N9"`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UU;)&9O
M=6YD72D[#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN
M=&%I;F5R<R==(#T-"B`@("`@("`@("`@("`@("!A<G)A>5]V86QU97,H)'1H
M:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G72D[#0H@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4W1A=&4H*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A
M<V5?<W1A=&4G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=R96QE87-E7W-T871E)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%)A
M=U-T871E*"1S=&%T92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)W)E;&5A<V5?<W1A=&4G72`]("1S=&%T93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!S9713=&%T92@D<W1A=&4I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7W-T871E)UT@/2`D<W1A=&4[
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=$1A=&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&%T92==*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A
M<V5?9&%T92==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971$871E*"1D871E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]D871E)UT@
M/2`D9&%T93L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3&EC96YS92@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]L
M:6-E;G-E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;ULG<F5L96%S95]L:6-E;G-E)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$QI
M8V5N<V4H)&1A=&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=R96QE87-E7VQI8V5N<V4G72`]("1D871E.PT*("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M9713=6UM87)Y*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<W5M;6%R>2==.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!S9713=6UM87)Y*"1S=6UM87)Y*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG<W5M;6%R>2==(#T@)'-U;6UA<GD[#0H@("`@("`@
M("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=$1E<V-R:7!T:6]N*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97-C<FEP=&EO;B==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T
M:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=$1E<V-R:7!T:6]N*"1D97-C*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG
M72`]("1D97-C.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971.;W1E<R@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]N
M;W1E<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M94EN9F];)W)E;&5A<V5?;F]T97,G73L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3F]T97,H
M)&YO=&5S*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M<F5L96%S95]N;W1E<R==(#T@)&YO=&5S.PT*("`@("`@("`D=&AI<RT^7VES
M5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$97!S
M*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=R96QE87-E7V1E<',G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E<',G73L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@4F5S970@9&5P96YD96YC:65S('!R:6]R('1O(&%D9&EN9R!N97<@
M;VYE<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-L96%R1&5P<R@I#0H@("`@
M>PT*("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E
M7V1E<',G72D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@861D4&AP1&5P*"1V
M97)S:6]N+"`D<F5L*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A
M<V5?9&5P<R==6UT@/0T*("`@("`@("`@("`@87)R87DH)W1Y<&4G(#T^("=P
M:'`G+`T*("`@("`@("`@("`@("`@("`@)W)E;"<@/3X@)')E;"P-"B`@("`@
M("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D=F5R<VEO;BD[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@861D4&%C:V%G941E<"@D;F%M92P@)'9E<G-I;VXL
M("1R96PL("1O<'1I;VYA;"`]("=N;R<I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@)&1E<"`]#0H@("`@("`@
M("`@("!A<G)A>2@G='EP92<@/3X@)W!K9R<L#0H@("`@("`@("`@("`@("`@
M("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@("`@("`@("`@("`G<F5L)R`]
M/B`D<F5L+`T*("`@("`@("`@("`@("`@("`@)V]P=&EO;F%L)R`]/B`D;W!T
M:6]N86PI.PT*("`@("`@("!I9B`H)')E;"`A/2`G:&%S)R`F)B`D<F5L("$]
M("=N;W0G*2![#0H@("`@("`@("`@("`D9&5P6R=V97)S:6]N)UT@/2`D=F5R
M<VEO;CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=R96QE87-E7V1E<',G75M=(#T@)&1E<#L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!A9&1%>'1E;G-I;VY$97`H)&YA;64L("1V97)S:6]N+"`D<F5L+"`D
M;W!T:6]N86P@/2`G;F\G*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E
M;&5A<V5?9&5P<R==6UT@/0T*("`@("`@("`@("`@87)R87DH)W1Y<&4G(#T^
M("=E>'0G+`T*("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`T*
M("`@("`@("`@("`@("`@("`@)W)E;"<@/3X@)')E;"P-"B`@("`@("`@("`@
M("`@("`@("=V97)S:6]N)R`]/B`D=F5R<VEO;BP-"B`@("`@("`@("`@("`@
M("`@("=O<'1I;VYA;"<@/3X@)&]P=&EO;F%L*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!705).24Y'("T@9&\@;F]T('5S92!T:&ES(&9U;F-T:6]N
M(&1I<F5C=&QY('5N;&5S<R!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$1E<',H)&1E<',I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E<',G72`]
M("1D97!S.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&AA<T1E<',H*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)W)E;&5A<V5?9&5P<R==*2`F)@T*("`@("`@("`@("`@8V]U;G0H)'1H:7,M
M/E]P86-K86=E26YF;ULG<F5L96%S95]D97!S)UTI.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=$1E<&5N9&5N8WE'<F]U<"@D9W)O=7`I#0H@("`@>PT*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M:7-#;VUP871I8FQE*"1P9BD-"B`@("![#0H@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<U-U8G!A8VMA9V5/9B@D<"D-
M"B`@("![#0H@("`@("`@(')E='5R;B`D<"T^:7-3=6)P86-K86=E*"1T:&ES
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<U-U8G!A8VMA9V4H)'`I#0H@
M("`@>PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9&5P96YD<T]N*"1P86-K86=E+"`D8VAA;FYE;"D-"B`@("![#0H@
M("`@("`@(&EF("AS=')T;VQO=V5R*"1C:&%N;F5L*2`A/2`G<&5A<BYP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A*"1D97!S(#T@)'1H:7,M/F=E=$1E<',H*2DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H("@D9&5P<R!A<R`D9&5P*2![#0H@("`@("`@("`@("!I9B`H
M)&1E<%LG='EP92==("$]("=P:V<G*2![#0H@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H<W1R=&]L
M;W=E<B@D9&5P6R=N86UE)UTI(#T]('-T<G1O;&]W97(H)'!A8VMA9V4I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=$-O;F9I9W5R94]P=&EO;G,H*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R
M95]O<'1I;VYS)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G73L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M:&%S0V]N9FEG=7)E3W!T:6]N<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G
M72D@)B8-"B`@("`@("`@("`@(&-O=6YT*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;F9I9W5R95]O<'1I;VYS)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&%D9$-O;F9I9W5R94]P=&EO;B@D;F%M92P@)'!R;VUP="P@)&1E9F%U;'0@
M/2!F86QS92D-"B`@("![#0H@("`@("`@("1O(#T@87)R87DH)VYA;64G(#T^
M("1N86UE+"`G<')O;7!T)R`]/B`D<')O;7!T*3L-"B`@("`@("`@:68@*"1D
M969A=6QT("$]/2!F86QS92D@>PT*("`@("`@("`@("`@)&];)V1E9F%U;'0G
M72`]("1D969A=6QT.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O
M<'1I;VYS)UT@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UU;72`]("1O.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&-L96%R0V]N9FEG=7)E3W!T:6]N<R@I
M#0H@("`@>PT*("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VYF:6=U<F5?;W!T:6]N<R==*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M9710<F]V:61E<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG<')O=FED97,G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!A9&1&:6QE*"1D:7(L("1F:6QE+"`D871T<G,I#0H@("`@>PT*("`@
M("`@("`D9&ER(#T@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@)R$O
M*R$G*2P@87)R87DH)R\G+"`G+R<I+"`D9&ER*3L-"B`@("`@("`@:68@*"1D
M:7(@/3T@)R\G('Q\("1D:7(@/3T@)R<I('L-"B`@("`@("`@("`@("1D:7(@
M/2`G)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D:7(@+CT@
M)R\G.PT*("`@("`@("!]#0H@("`@("`@("1F:6QE(#T@)&1I<B`N("1F:6QE
M.PT*("`@("`@("`D9FEL92`]('!R96=?<F5P;&%C92@G(5M<7"]=*R$G+"`G
M+R<L("1F:6QE*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL
M96QI<W0G75LD9FEL95T@/2`D871T<G,[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T26YS=&%L;&%T:6]N1FEL96QI<W0H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YG971&:6QE;&ES="@I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=$9I;&5L:7-T*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UT[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N('-E=$9I;&5!='1R:6)U=&4H)&9I;&4L("1A='1R+"`D
M=F%L=64I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F
M:6QE;&ES="==6R1F:6QE75LD871T<ET@/2`D=F%L=64[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<F5S971&:6QE;&ES="@I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==(#T@87)R87DH*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!S971);G-T86QL961!<R@D9FEL92P@)'!A
M=&@I#0H@("`@>PT*("`@("`@("!I9B`H)'!A=&@I('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE
M75LG:6YS=&%L;&5D7V%S)UT@/2`D<&%T:#L-"B`@("`@("`@?0T*("`@("`@
M("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE
M75LG:6YS=&%L;&5D7V%S)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&EN
M<W1A;&QE9$9I;&4H)&9I;&4L("1A='1S*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI
M<W0G75LD9FEL95T@/0T*("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=+"`D871T<RD[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72`]("1A='1S.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T0VAA;F=E;&]G*"D-"B`@("![
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=C:&%N9V5L;V<G73L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4&%C:V%G97AM
M;%9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("<Q+C`G.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%=R87!P97(@=&\@>T!L:6YK(%!%05)?
M17)R;W)3=&%C:SHZ9V5T17)R;W)S*"E]#0H@("`@("H@0'!A<F%M(&)O;VQE
M86X@9&5T97)M:6YE<R!W:&5T:&5R('1O('!U<F=E('1H92!E<G)O<B!S=&%C
M:R!A9G1E<B!R971R:65V:6YG#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=%9A;&ED871I;VY787)N:6YG<R@D<'5R
M9V4@/2!T<G5E*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W1A
M8VLM/F=E=$5R<F]R<R@D<'5R9V4I.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\J*@T*("`@("`J(%9A;&ED871I;VX@97)R;W(N("!!;'-O(&UA<FMS
M('1H92!O8FIE8W0@8V]N=&5N=',@87,@:6YV86QI9`T*("`@("`J($!P87)A
M;2!E<G)O<B!C;V1E#0H@("`@("H@0'!A<F%M(&%R<F%Y(&5R<F]R(&EN9F]R
M;6%T:6]N#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@7W9A;&ED871E17)R;W(H)&-O9&4L("1P87)A;7,@/2!A<G)A
M>2@I*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"@D8V]D
M92P@)V5R<F]R)RP@)'!A<F%M<RP@9F%L<V4L(&9A;'-E+"!D96)U9U]B86-K
M=')A8V4H*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%9A;&ED871I;VX@=V%R;FEN9RX@
M($1O97,@;F]T(&UA<FL@=&AE(&]B:F5C="!C;VYT96YT<R!I;G9A;&ED+@T*
M("`@("`J($!P87)A;2!E<G)O<B!C;V1E#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(&5R<F]R(&EN9F]R;6%T:6]N#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7W9A;&ED871E5V%R;FEN9R@D8V]D92P@
M)'!A<F%M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*"1C;V1E+"`G=V%R;FEN9R<L("1P87)A;7,L(&9A;'-E+"!F
M86QS92P@9&5B=6=?8F%C:W1R86-E*"DI.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!I;G1E9V5R(&5R<F]R(&-O9&4-"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971%<G)O
M<DUE<W-A9V4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3D%-12`]
M/@T*("`@("`@("`@("`@("`@("`@("`G36ES<VEN9R!086-K86=E($YA;64G
M+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?
M4U5-34%262`]/@T*("`@("`@("`@("`@("`@("`@("`G3F\@<W5M;6%R>2!F
M;W5N9"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/
M4E]-54Q424Q)3D5?4U5-34%262`]/@T*("`@("`@("`@("`@("`@("`@("`G
M4W5M;6%R>2!S:&]U;&0@8F4@;VX@;VYE(&QI;F4G+`T*("`@("`@("`@("`@
M("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$530U))4%1)3TX@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)TUI<W-I;F<@9&5S8W)I<'1I;VXG+`T*
M("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3$E#
M14Y312`]/@T*("`@("`@("`@("`@("`@("`@("`G36ES<VEN9R!L:6-E;G-E
M)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/
M7U9%4E-)3TX@/3X-"B`@("`@("`@("`@("`@("`@("`@)TYO(')E;&5A<V4@
M=F5R<VEO;B!F;W5N9"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3U]35$%412`]/@T*("`@("`@("`@("`@("`@("`@("`G
M3F\@<F5L96%S92!S=&%T92!F;W5N9"<L#0H@("`@("`@("`@("`@("`@4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U]$051%(#T^#0H@("`@("`@("`@("`@
M("`@("`@("=.;R!R96QE87-E(&1A=&4@9F]U;F0G+`T*("`@("`@("`@("`@
M("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3D]415,@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)TYO(')E;&5A<V4@;F]T97,@9F]U;F0G+`T*("`@
M("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3$5!1"`]
M/@T*("`@("`@("`@("`@("`@("`@("`G4&%C:V%G92!M=7-T(&AA=F4@870@
M;&5A<W0@;VYE(&QE860@;6%I;G1A:6YE<B<L#0H@("`@("`@("`@("`@("`@
M4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5$%)3D524R`]/@T*("`@
M("`@("`@("`@("`@("`@("`G3F\@;6%I;G1A:6YE<G,@9F]U;F0L(&%T(&QE
M87-T(&]N92!M=7-T(&)E(&1E9FEN960G+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1(04Y$3$4@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)TUA:6YT86EN97(@)6EN9&5X)2!H87,@;F\@:&%N
M9&QE("AU<V5R($E$(&%T(&-H86YN96P@<V5R=F5R*2<L#0H@("`@("`@("`@
M("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5%)/3$4@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)TUA:6YT86EN97(@)6EN9&5X)2!H87,@
M;F\@<F]L92<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U]-04E.5$Y!344@/3X-"B`@("`@("`@("`@("`@("`@("`@)TUA
M:6YT86EN97(@)6EN9&5X)2!H87,@;F\@;F%M92<L#0H@("`@("`@("`@("`@
M("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5$5-04E,(#T^#0H@
M("`@("`@("`@("`@("`@("`@("=-86EN=&%I;F5R("5I;F1E>"4@:&%S(&YO
M(&5M86EL)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T52
M4D]27TY/7T1%4$Y!344@/3X-"B`@("`@("`@("`@("`@("`@("`@)T1E<&5N
M9&5N8WD@)6EN9&5X)2!I<R!N;W0@82!P:'`@9&5P96YD96YC>2P@86YD(&AA
M<R!N;R!N86UE)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7T1%4%)%3"`]/@T*("`@("`@("`@("`@("`@("`@("`G1&5P
M96YD96YC>2`E:6YD97@E(&AA<R!N;R!R96QA=&EO;B`H<F5L*2<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15!465!%
M(#T^#0H@("`@("`@("`@("`@("`@("`@("=$97!E;F1E;F-Y("5I;F1E>"4@
M:&%S(&YO('1Y<&4G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)
M3$5?15)23U)?1$503D%-15])1TY/4D5$(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=02%`@1&5P96YD96YC>2`E:6YD97@E(&AA<R!A(&YA;64@871T<FEB
M=71E(&]F("(E;F%M924B('=H:6-H('=I;&P@8F4G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("<@:6=N;W)E9"$G+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?1$505D524TE/3B`]/@T*("`@("`@
M("`@("`@("`@("`@("`G1&5P96YD96YC>2`E:6YD97@E(&ES(&YO="!A(')E
M;#TB:&%S(B!O<B!R96P](FYO="(@9&5P96YD96YC>2P@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G86YD(&AA<R!N;R!V97)S:6]N)RP-"B`@("`@
M("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%!(4%9%
M4E-)3TX@/3X-"B`@("`@("`@("`@("`@("`@("`@)T1E<&5N9&5N8WD@)6EN
M9&5X)2!I<R!A('1Y<&4](G!H<"(@9&5P96YD96YC>2P@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G86YD(&AA<R!N;R!V97)S:6]N)RP-"B`@("`@
M("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27T1%4%9%4E-)3TY?
M24=.3U)%1"`]/@T*("`@("`@("`@("`@("`@("`@("`G1&5P96YD96YC>2`E
M:6YD97@E(&ES(&$@<F5L/2(E<F5L)2(@9&5P96YD96YC>2P@=F5R<VEO;FEN
M9R!I<R!I9VYO<F5D)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&
M24Q%7T524D]27TE.5D%,241?1$503U!424].04P@/3X-"B`@("`@("`@("`@
M("`@("`@("`@)T1E<&5N9&5N8WD@)6EN9&5X)2!H87,@:6YV86QI9"!O<'1I
M;VYA;"!V86QU92`B)6]P="4B+"!S:&]U;&0@8F4@>65S(&]R(&YO)RP-"B`@
M("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7U!(4%].3U].3U0@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)T1E<&5N9&5N8WD@)6EN9&5X)3H@<&AP
M(&1E<&5N9&5N8VEE<R!C86YN;W0@=7-E(")N;W0B(')E;"P@=7-E(")N92(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<@=&\@97AC;'5D92!S<&5C
M:69I8R!V97)S:6]N<R<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3U]#3TY&3D%-12`]/@T*("`@("`@("`@("`@("`@("`@
M("`G0V]N9FEG=7)E($]P=&EO;B`E:6YD97@E(&AA<R!N;R!N86UE)RP-"B`@
M("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7T-/3D90
M4D]-4%0@/3X-"B`@("`@("`@("`@("`@("`@("`@)T-O;F9I9W5R92!/<'1I
M;VX@)6EN9&5X)2!H87,@;F\@<')O;7!T)RP-"B`@("`@("`@("`@("`@("!0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7T9)3$53(#T^#0H@("`@("`@("`@
M("`@("`@("`@("=.;R!F:6QE<R!I;B`\9FEL96QI<W0^('-E8W1I;VX@;V8@
M<&%C:V%G92YX;6PG+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?1DE,15)/3$4@/3X-"B`@("`@("`@("`@("`@("`@("`@
M)T9I;&4@(B5F:6QE)2(@:&%S(&YO(')O;&4L(&5X<&5C=&EN9R!O;F4@;V8@
M(B5R;VQE<R4B)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%
M7T524D]27TE.5D%,241?1DE,15)/3$4@/3X-"B`@("`@("`@("`@("`@("`@
M("`@)T9I;&4@(B5F:6QE)2(@:&%S(&EN=F%L:60@<F]L92`B)7)O;&4E(BP@
M97AP96-T:6YG(&]N92!O9B`B)7)O;&5S)2(G+`T*("`@("`@("`@("`@("`@
M(%!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]&24Q%3D%-12`]/@T*
M("`@("`@("`@("`@("`@("`@("`G1FEL92`B)69I;&4E(B!C86YN;W0@<W1A
M<G0@=VET:"`B+B(L(&-A;FYO="!P86-K86=E(&]R(&EN<W1A;&PG+`T*("`@
M("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]0
M2%!&24Q%(#T^#0H@("`@("`@("`@("`@("`@("`@("=087)S97(@97)R;W(Z
M(&EN=F%L:60@4$A0(&9O=6YD(&EN(&9I;&4@(B5F:6QE)2(G+`T*("`@("`@
M("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?4$Y!345?4%)%
M1DE8(#T^#0H@("`@("`@("`@("`@("`@("`@("=I;B`E9FEL924Z("5T>7!E
M)2`B)6YA;64E(B!N;W0@<')E9FEX960@=VET:"!P86-K86=E(&YA;64@(B5P
M86-K86=E)2(G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?
M15)23U)?24Y604Q)1%]&24Q%(#T^#0H@("`@("`@("`@("`@("`@("`@("=0
M87)S97(@97)R;W(Z(&EN=F%L:60@4$A0(&9I;&4@(B5F:6QE)2(G+`T*("`@
M("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?0TA!3DY%3%9!
M3"`]/@T*("`@("`@("`@("`@("`@("`@("`G0VAA;FYE;"!V86QI9&%T;W(@
M97)R;W(Z(&9I96QD("(E9FEE;&0E(B`M("5R96%S;VXE)RP-"B`@("`@("`@
M("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27U!(4#4@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)T5R<F]R+"!02%`U('1O:V5N(&5N8V]U;G1E<F5D
M(&EN("5F:6QE)2P@86YA;'ES:7,@<VAO=6QD(&)E(&EN(%!(4#4G+`T*("`@
M("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?1DE,15].3U1&
M3U5.1"`]/@T*("`@("`@("`@("`@("`@("`@("`G1FEL92`B)69I;&4E(B!I
M;B!P86-K86=E+GAM;"!D;V5S(&YO="!E>&ES="<L#0H@("`@("`@("`@("`@
M("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3TY?25-/7T-(05)3(#T^#0H@
M("`@("`@("`@("`@("`@("`@("=086-K86=E+GAM;"!C;VYT86EN<R!N;VXM
M25-/+3@X-3DM,2!C:&%R86-T97)S+"!A;F0@;6%Y(&YO="!V86QI9&%T92<L
M#0H@("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%9A
M;&ED871E(%A-3"!P86-K86=E(&1E9FEN:71I;VX@9FEL92X-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0')E='5R;B!B;V]L96%N
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&4H)'-T871E(#T@4$5!
M4E]604Q)1$%415].3U)-04PL("1N;V9I;&5C:&5C:VEN9R`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@:68@*"@D=&AI<RT^7VES5F%L:60@)B`D<W1A=&4I
M(#T]("1S=&%T92D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@=')U93L-"B`@("`@
M("`@)&EN9F\@/2`D=&AI<RT^7W!A8VMA9V5);F9O.PT*("`@("`@("!I9B`H
M96UP='DH)&EN9F];)W!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7TY!
M344I.PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E3F%M92`]("1P;B`]
M("=U;FMN;W=N)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94YA;64@/2`D<&X@/2`D:6YF;ULG<&%C:V%G92==.PT*
M("`@("`@("!]#0H-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=S=6UM87)Y
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U]354U-05)9*3L-"B`@("`@("`@?2!E
M;'-E:68@*'-T<G!O<RAT<FEM*"1I;F9O6R=S=6UM87)Y)UTI+"`B7&XB*2`A
M/3T@9F%L<V4I('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N
M:6YG*%!%05)?4$%#2T%'149)3$5?15)23U)?355,5$E,24Y%7U-534U!4EDL
M#0H@("`@("`@("`@("`@("`@87)R87DH)W-U;6UA<GDG(#T^("1I;F9O6R=S
M=6UM87)Y)UTI*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN
M9F];)V1E<V-R:7!T:6]N)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15-#4DE0
M5$E/3BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=R
M96QE87-E7VQI8V5N<V4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L
M:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7TQ)0T5.4T4I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG=F5R<VEO
M;B==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?5D524TE/3BD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=R96QE87-E7W-T871E)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U]35$%412D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&5M<'1Y*"1I;F9O6R=R96QE87-E7V1A=&4G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T52
M4D]27TY/7T1!5$4I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D
M:6YF;ULG<F5L96%S95]N;W1E<R==*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3D]4
M15,I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG;6%I
M;G1A:6YE<G,G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%
M<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y404E.15)3*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1H87-L96%D(#T@9F%L
M<V4[#0H@("`@("`@("`@("`D:2`](#$[#0H@("`@("`@("`@("!F;W)E86-H
M("@D:6YF;ULG;6%I;G1A:6YE<G,G72!A<R`D;2D@>PT*("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D;5LG:&%N9&QE)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7TU!24Y42$%.1$Q%+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&U;)W)O;&4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?
M4$%#2T%'149)3$5?15)23U)?3D]?34%)3E123TQ%+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2P@)W)O;&5S)R`]/B!0
M14%27T-O;6UO;CHZ9V5T57-E<E)O;&5S*"DI*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)&U;)W)O;&4G72`]/2`G;&5A9"<I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&AA<VQE860@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&U;)VYA;64G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1.04U%+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&U;)V5M
M86EL)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A
M=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y414U!24PL
M#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I
M*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I*RL[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21H87-L96%D*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?
M4$%#2T%'149)3$5?15)23U)?3D]?3$5!1"D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG<F5L96%S95]D
M97!S)UTI*2![#0H@("`@("`@("`@("`D:2`](#$[#0H@("`@("`@("`@("!F
M;W)E86-H("@D:6YF;ULG<F5L96%S95]D97!S)UT@87,@)&0I('L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1D6R=T>7!E)UTI('Q\(&5M<'1Y*"1D
M6R=T>7!E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L
M:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%194$4L
M#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I
M+"`G='EP97,G(#T^(%!%05)?0V]M;6]N.CIG971$97!E;F1E;F-Y5'EP97,H
M*2DI.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9%LG<F5L
M)UTI('Q\(&5M<'1Y*"1D6R=R96PG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)2
M3U)?3D]?1$504D5,+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)VEN9&5X)R`]/B`D:2P@)W)E;',G(#T^(%!%05)?0V]M;6]N.CIG971$97!E
M;F1E;F-Y4F5L871I;VYS*"DI*3L-"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&1;)V]P=&EO;F%L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:6Y?87)R87DH)&1;)V]P=&EO;F%L)UTL(&%R<F%Y*"=Y97,G
M+"`G;F\G*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?
M1$503U!424].04PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VEN9&5X)R`]/B`D:2P@)V]P="<@/3X@)&1;)V]P=&EO;F%L)UTI*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H)&1;)W)E;"==("$]("=H87,G("8F("1D6R=R
M96PG72`A/2`G;F]T)R`F)B!E;7!T>2@D9%LG=F5R<VEO;B==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]0
M04-+04=%1DE,15]%4E)/4E].3U]$15!615)324].+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@
M("`@("`@('T@96QS96EF("@H)&1;)W)E;"==(#T]("=H87,G('Q\("1D6R=R
M96PG72`]/2`G;F]T)RD@)B8@(65M<'1Y*"1D6R=V97)S:6]N)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%
M05)?4$%#2T%'149)3$5?15)23U)?1$505D524TE/3E])1TY/4D5$+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2P@)W)E
M;"<@/3X@)&1;)W)E;"==*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@D9%LG='EP92==(#T]("=P:'`G("8F("%E;7!T>2@D
M9%LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E5V%R;FEN9RA014%27U!!0TM!1T5&24Q%7T524D]27T1%4$Y!345?
M24=.3U)%1"P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I;F1E
M>"<@/3X@)&DL("=N86UE)R`]/B`D9%LG;F%M92==*2D[#0H@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1D6R=T>7!E)UT@(3T@)W!H<"<@)B8@96UP='DH
M)&1;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$503D%-
M12P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@
M)&DI*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"1D6R=T>7!E)UT@/3T@)W!H<"<@)B8@96UP='DH)&1;)W9E<G-I;VXG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R
M*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$504$A05D524TE/3BP-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"@D9%LG
M<F5L)UT@/3T@)VYO="<I("8F("@D9%LG='EP92==(#T]("=P:'`G*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]004-+04=%1DE,15]02%!?3D]?3D]4+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D:2LK.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@A96UP='DH)&EN9F];)V-O;F9I9W5R95]O
M<'1I;VYS)UTI*2![#0H@("`@("`@("`@("`D:2`](#$[#0H@("`@("`@("`@
M("!F;W)E86-H("@D:6YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72!A<R`D8RD@
M>PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D8ULG;F%M92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U]#3TY&3D%-12P-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1C6R=P<F]M
M<'0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?0T].1E!23TU05"P-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&DK*SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH
M)&EN9F];)V9I;&5L:7-T)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]&24Q%4RD[
M#0H@("`@("`@("`@("`D97)R;W)S6UT@/2`G;F\@9FEL97,G.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];)V9I;&5L
M:7-T)UT@87,@)&9I;&4@/3X@)&9A*2![#0H@("`@("`@("`@("`@("`@:68@
M*&5M<'1Y*"1F85LG<F]L92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U]&24Q%4D],12P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F
M:6QE)R`]/B`D9FEL92P@)W)O;&5S)R`]/B!014%27T-O;6UO;CHZ9V5T1FEL
M95)O;&5S*"DI*3L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"%I;E]A<G)A>2@D9F%;)W)O;&4G
M72P@4$5!4E]#;VUM;VXZ.F=E=$9I;&52;VQE<R@I*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%
M1DE,15]%4E)/4E])3E9!3$E$7T9)3$523TQ%+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F:6QE+"`G<F]L92<@/3X@)&9A
M6R=R;VQE)UTL("=R;VQE<R<@/3X@4$5!4E]#;VUM;VXZ.F=E=$9I;&52;VQE
M<R@I*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D9FEL97LP?2`]/2`G+B<@)B8@)&9I;&5[,7T@/3T@)R\G*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!
M0TM!1T5&24Q%7T524D]27TE.5D%,241?1DE,14Y!344L#0H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G9FEL92<@/3X@)&9I;&4I*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<F5G:7-T<GDI("8F("1T:&ES+3Y?:7-6
M86QI9"D@>PT*("`@("`@("`@("`@)&-H86X@/2`D=&AI<RT^7W)E9VES=')Y
M+3YG971#:&%N;F5L*"=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27T-(
M04Y.14Q604PL("1C:&%N+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)'9A;&ED871O<B`]("1C:&%N+3YG971686QI9&%T
M:6]N3V)J96-T*"D[#0H@("`@("`@("`@("`D=F%L:61A=&]R+3YS971086-K
M86=E1FEL92@D=&AI<RD[#0H@("`@("`@("`@("`D=F%L:61A=&]R+3YV86QI
M9&%T92@D<W1A=&4I.PT*("`@("`@("`@("`@)&9A:6QU<F5S(#T@)'9A;&ED
M871O<BT^9V5T1F%I;'5R97,H*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1F
M86EL=7)E<ULG97)R;W)S)UT@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)2
M3U)?0TA!3DY%3%9!3"P@)&5R<F]R*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1F86EL=7)E<ULG=V%R;FEN9W,G72!A<R`D=V%R
M;FEN9RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N
M:6YG*%!%05)?4$%#2T%'149)3$5?15)23U)?0TA!3DY%3%9!3"P@)'=A<FYI
M;F<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D
M=&AI<RT^7VES5F%L:60@)B8@)'-T871E(#T](%!%05)?5D%,241!5$5?4$%#
M2T%'24Y'("8F("$D;F]F:6QE8VAE8VMI;F<I('L-"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V%N86QY>F50:'!&:6QE<R@I*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I<U9A;&ED(#T@)'-T871E.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7VES5F%L:60@/2`P.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]A;F%L>7IE4&AP1FEL97,H*0T*("`@
M('L-"B`@("`@("`@:68@*"$D=&AI<RT^7VES5F%L:60I('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%C:V%G949I;&4I*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&1I<E]P<F5F:7@@/2!D
M:7)N86UE*"1T:&ES+3Y?<&%C:V%G949I;&4I.PT*("`@("`@("`D8V]M;6]N
M(#T@;F5W(%!%05)?0V]M;6]N.PT*("`@("`@("`D;&]G(#T@:7-S970H)'1H
M:7,M/E]L;V=G97(I(#\@87)R87DH)B1T:&ES+3Y?;&]G9V5R+"`G;&]G)RD@
M.@T*("`@("`@("`@("`@87)R87DH)&-O;6UO;BP@)VQO9R<I.PT*("`@("`@
M("`D:6YF;R`]("1T:&ES+3YG971&:6QE;&ES="@I.PT*("`@("`@("!F;W)E
M86-H("@D:6YF;R!A<R`D9FEL92`]/B`D9F$I('L-"B`@("`@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&1I<E]P<F5F:7@@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?1DE,15].3U1&3U5.
M1"P-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G(#T^(')E86QP
M871H*"1D:7)?<')E9FEX*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL
M92DI.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"1F85LG<F]L92==(#T]("=P:'`G("8F("1D
M:7)?<')E9FEX*2![#0H@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?
M87)R87DH)&QO9RP@87)R87DH,2P@(D%N86QY>FEN9R`D9FEL92(I*3L-"B`@
M("`@("`@("`@("`@("`D<W)C:6YF;R`]("1T:&ES+3Y?86YA;'EZ95-O=7)C
M94-O9&4H)&1I<E]P<F5F:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I
M;&4I.PT*("`@("`@("`@("`@("`@(&EF("@D<W)C:6YF;RD@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V)U:6QD4')O=FED97-!<G)A>2@D<W)C
M:6YF;RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94YA;64@/2`D<&X@/2`D
M=&AI<RT^9V5T4&%C:V%G92@I.PT*("`@("`@("`D<&YL(#T@<W1R;&5N*"1P
M;BD[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P
M<F]V:61E<R==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H*&%R<F%Y*2`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==(&%S("1K97D@/3X@)'=H
M870I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'=H871;)V5X<&QI
M8VET)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("\O('-K:7`@8V]N9F]R
M;6%N8V4@8VAE8VMS(&EF('1H92!P<F]V:61E<R!E;G1R>2!I<PT*("`@("`@
M("`@("`@("`@("`@("`O+R!S<&5C:69I960@:6X@=&AE('!A8VMA9V4N>&UL
M(&9I;&4-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&5X=')A8W0H)'=H870I.PT*
M("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G8VQA<W,G*2![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A<W1R;F-A<V5C;7`H)&YA;64L("1P;BP@
M)'!N;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?4$%#2T%'149)3$5?15)23U)?
M3D]?4$Y!345?4%)%1DE8+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V9I;&4G(#T^("1F:6QE+"`G='EP92<@/3X@)'1Y<&4L("=N86UE)R`]
M/B`D;F%M92P@)W!A8VMA9V4G(#T^("1P;BDI.PT*("`@("`@("`@("`@("`@
M('T@96QS96EF("@D='EP92`]/2`G9G5N8W1I;VXG*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AS=')S='(H)&YA;64L("<Z.B<I('Q\("%S=')N8V%S
M96-M<"@D;F%M92P@)'!N+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T95=A<FYI;F<H4$5!4E]0
M04-+04=%1DE,15]%4E)/4E].3U]03D%-15]04D5&25@L#0H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G9FEL92<@/3X@)&9I;&4L("=T>7!E)R`]
M/B`D='EP92P@)VYA;64G(#T^("1N86UE+"`G<&%C:V%G92<@/3X@)'!N*2D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7VES5F%L:60[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T('1H92!D969A=6QT('AM;"!G96YE<F%T;W(@
M;V)J96-T#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I
M;&5?1V5N97)A=&]R7W8Q#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$1E
M9F%U;'1'96YE<F%T;W(H*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8Q)RDI('L-"B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]'96YE
M<F%T;W(O=C$N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@
M4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C$H)'1H:7,I.PT*("`@("`@
M("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H
M92!C;VYT96YT<R!O9B!A(&9I;&4@;&ES=&5D('=I=&AI;B!T:&4@<&%C:V%G
M92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!S
M=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971&:6QE0V]N=&5N=',H
M)&9I;&4I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]A<F-H:79E1FEL
M92`]/2`D=&AI<RT^7W!A8VMA9V5&:6QE*2![("\O('5N<&%C:V5D#0H@("`@
M("`@("`@("`D9&ER(#T@9&ER;F%M92@D=&AI<RT^7W!A8VMA9V5&:6QE*3L-
M"B`@("`@("`@("`@("1F:6QE(#T@)&1I<B`N($1)4D5#5$]265]315!!4D%4
M3U(@+B`D9FEL93L-"B`@("`@("`@("`@("1F:6QE(#T@<W1R7W)E<&QA8V4H
M87)R87DH)R\G+"`G7%PG*2P-"B`@("`@("`@("`@("`@("!A<G)A>2A$25)%
M0U1/4EE?4T5005)!5$]2+"!$25)%0U1/4EE?4T5005)!5$]2*2P@)&9I;&4I
M.PT*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE*2`F)B!I<U]R
M96%D86)L92@D9FEL92DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@:6UP
M;&]D92@G)RP@9FEL92@D9FEL92DI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V4@>R`O+R!T9WH-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=!<F-H:79E7U1A<B<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'1A<B`]("9N97<@07)C:&EV95]487(H)'1H:7,M/E]A<F-H
M:79E1FEL92D[#0H@("`@("`@("`@("`D=&%R+3YP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("!I9B`H)&9I;&4@
M(3T@)W!A8VMA9V4N>&UL)R`F)B`D9FEL92`A/2`G<&%C:V%G93(N>&UL)RD@
M>PT*("`@("`@("`@("`@("`@("1F:6QE(#T@)'1H:7,M/F=E=%!A8VMA9V4H
M*2`N("<M)R`N("1T:&ES+3YG971697)S:6]N*"D@+B`G+R<@+B`D9FEL93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1F:6QE(#T@)'1A<BT^97AT
M<F%C=$EN4W1R:6YG*"1F:6QE*3L-"B`@("`@("`@("`@("1T87(M/G!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*")#86YN;W0@;&]C871E(&9I;&4@)R1F:6QE)R!I;B!A<F-H:79E
M(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&9I;&4[
M#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R![>WL@86YA;'EZ95-O=7)C
M94-O9&4H*0T*("`@("\J*@T*("`@("`J($%N86QY>F4@=&AE('-O=7)C92!C
M;V1E(&]F('1H92!G:79E;B!02%`@9FEL90T*("`@("`J#0H@("`@("H@0'!A
M<F%M("!S=')I;F<@1FEL96YA;64@;V8@=&AE(%!(4"!F:6QE#0H@("`@("H@
M0')E='5R;B!M:7AE9`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]A;F%L>7IE4V]U<F-E0V]D92@D9FEL92D-"B`@
M("![#0H@("`@("`@(&EF("@A9G5N8W1I;VY?97AI<W1S*")T;VME;E]G971?
M86QL(BDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(61E9FEN960H)U1?1$]#7T-/34U%3E0G*2D@>PT*
M("`@("`@("`@("`@9&5F:6YE*"=47T1/0U]#3TU-14Y4)RP@5%]#3TU-14Y4
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(61E9FEN960H)U1?24Y415)&
M04-%)RDI('L-"B`@("`@("`@("`@(&1E9FEN92@G5%])3E1%4D9!0T4G+"`M
M,2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%D969I;F5D*"=47TE-4$Q%
M345.5%,G*2D@>PT*("`@("`@("`@("`@9&5F:6YE*"=47TE-4$Q%345.5%,G
M+"`M,2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D9G`@/2!`9F]P96XH
M)&9I;&4L(")R(BDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E
M=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@
M("`@("`@("`@("1C;VYT96YT<R`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C;VYT96YT<R`]
M($!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F:6QE*2D[#0H@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("`D=&]K96YS(#T@=&]K
M96Y?9V5T7V%L;"@D8V]N=&5N=',I.PT*+RH-"B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@<VEZ96]F*"1T;VME;G,I.R`D:2LK*2![#0H@("`@("`@("`@
M("!`;&ES="@D=&]K96XL("1D871A*2`]("1T;VME;G-;)&E=.PT*("`@("`@
M("`@("`@:68@*&ES7W-T<FEN9R@D=&]K96XI*2![#0H@("`@("`@("`@("`@
M("`@=F%R7V1U;7`H)'1O:V5N*3L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@<')I;G0@=&]K96Y?;F%M92@D=&]K96XI("X@)R`G
M.PT*("`@("`@("`@("`@("`@('9A<E]D=6UP*')T<FEM*"1D871A*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"BHO#0H@("`@("`@("1L;V]K7V9O
M<B`](#`[#0H@("`@("`@("1P87)E;E]L979E;"`](#`[#0H@("`@("`@("1B
M<F%C:V5T7VQE=F5L(#T@,#L-"B`@("`@("`@)&)R86-E7VQE=F5L(#T@,#L-
M"B`@("`@("`@)&QA<W1P:'!D;V,@/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?
M8VQA<W,@/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?:6YT97)F86-E(#T@)R<[
M#0H@("`@("`@("1C=7)R96YT7V-L87-S7VQE=F5L(#T@+3$[#0H@("`@("`@
M("1C=7)R96YT7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V9U
M;F-T:6]N7VQE=F5L(#T@+3$[#0H@("`@("`@("1D96-L87)E9%]C;&%S<V5S
M(#T@87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C97,@/2!A
M<G)A>2@I.PT*("`@("`@("`D9&5C;&%R961?9G5N8W1I;VYS(#T@87)R87DH
M*3L-"B`@("`@("`@)&1E8VQA<F5D7VUE=&AO9',@/2!A<G)A>2@I.PT*("`@
M("`@("`D=7-E9%]C;&%S<V5S(#T@87)R87DH*3L-"B`@("`@("`@)'5S961?
M9G5N8W1I;VYS(#T@87)R87DH*3L-"B`@("`@("`@)&5X=&5N9',@/2!A<G)A
M>2@I.PT*("`@("`@("`D:6UP;&5M96YT<R`](&%R<F%Y*"D[#0H@("`@("`@
M("1N;V1E<',@/2!A<G)A>2@I.PT*("`@("`@("`D:6YQ=6]T92`](&9A;'-E
M.PT*("`@("`@("`D:6YT97)F86-E(#T@9F%L<V4[#0H@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1T;VME;G-;)&E=*2D@>PT*("`@("`@("`@
M("`@("`@(&QI<W0H)'1O:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I73L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1O:V5N(#T@
M)'1O:V5N<ULD:5T[#0H@("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:6YQ=6]T92D@>PT*("`@
M("`@("`@("`@("`@(&EF("@D=&]K96X@(3T@)R(G("8F("1T;VME;B`A/2!4
M7T5.1%](15)%1$]#*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1I;G%U;W1E(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('-W:71C:"`H)'1O:V5N*2![#0H@("`@("`@("`@("`@("`@
M8V%S92!47U=(251%4U!!0T4@.@T*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!C87-E("<[)SH-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1I;G1E<F9A8V4I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]("TQ.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@(&-A<V4@)R(G.@T*("`@("`@("`@("`@("`@
M(&-A<V4@5%]35$%25%](15)%1$]#.@T*("`@("`@("`@("`@("`@("`@("`D
M:6YQ=6]T92`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@(&-A<V4@5%]#55),65]/4$5..@T*("`@("`@("`@
M("`@("`@(&-A<V4@5%]$3TQ,05)?3U!%3E]#55),65]"4D%#15,Z#0H@("`@
M("`@("`@("`@("`@8V%S92`G>R<Z("1B<F%C95]L979E;"LK.R!C;VYT:6YU
M92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@)WTG.@T*("`@("`@("`@("`@
M("`@("`@("`D8G)A8V5?;&5V96PM+3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1C=7)R96YT7V-L87-S7VQE=F5L(#T]("1B<F%C95]L979E;"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W,@/2`G)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S7VQE=F5L
M(#T@+3$[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T]("1B<F%C95]L
M979E;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N
M8W1I;VX@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT
M7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@
M("`@("!C87-E("=;)SH@)&)R86-K971?;&5V96PK*SL@8V]N=&EN=64@,CL-
M"B`@("`@("`@("`@("`@("!C87-E("==)SH@)&)R86-K971?;&5V96PM+3L@
M8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("<H)SH@)'!A<F5N
M7VQE=F5L*RL[("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E
M("<I)SH@)'!A<F5N7VQE=F5L+2T[("`@8V]N=&EN=64@,CL-"B`@("`@("`@
M("`@("`@("!C87-E(%1?24Y415)&04-%.@T*("`@("`@("`@("`@("`@("`@
M("`D:6YT97)F86-E(#T@=')U93L-"B`@("`@("`@("`@("`@("!C87-E(%1?
M0TQ!4U,Z#0H@("`@("`@("`@("`@("`@("`@(&EF("@H)&-U<G)E;G1?8VQA
M<W-?;&5V96P@(3T@+3$I('Q\("@D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`A
M/2`M,2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L
M:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?4$A0
M1DE,12P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEL
M92<@/3X@)&9I;&4I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&-A<V4@5%]&54Y#5$E/3CH-"B`@("`@("`@("`@("`@("!C87-E(%1?
M3D57.@T*("`@("`@("`@("`@("`@(&-A<V4@5%]%6%1%3D13.@T*("`@("`@
M("`@("`@("`@(&-A<V4@5%])35!,14U%3E13.@T*("`@("`@("`@("`@("`@
M("`@("`D;&]O:U]F;W(@/2`D=&]K96X[#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92!47U-44DE.1SH-
M"B`@("`@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AZ96YD
M7W9E<G-I;VXH*2P@)S(N,"<L("<\)RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2AS=')T;VQO=V5R*"1D871A*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<'5B;&EC)RP@)W!R:79A
M=&4G+"`G<')O=&5C=&5D)RP@)V%B<W1R86-T)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:6YT97)F86-E)RP@)VEM<&QE;65N=',G
M+"`G=&AR;W<G*2`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E5V%R;FEN9RA014%27U!!0TM!1T5&24Q%7T524D]27U!(4#4L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1F:6QE*2D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1L;V]K7V9O<B`]/2!4
M7T-,05-3*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C
M;&%S<R`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?8VQA<W-?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5C;&%R961?8VQA<W-E<UM=(#T@)&-U<G)E;G1?8VQA
M<W,[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@
M/3T@5%])3E1%4D9!0T4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C
M=7)R96YT7VEN=&5R9F%C92`]("1D871A.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?:6YT97)F86-E<UM=
M(#T@)&-U<G)E;G1?:6YT97)F86-E.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?24U03$5-14Y44RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EM<&QE;65N='-;)&-U<G)E;G1?8VQA<W-=
M(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O
M:U]F;W(@/3T@5%]%6%1%3D13*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97AT96YD<ULD8W5R<F5N=%]C;&%S<UT@/2`D9&%T83L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47T953D-424].
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&-U<G)E;G1?8VQA
M<W,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F
M=6YC=&EO;B`]("(D8W5R<F5N=%]C;&%S<SHZ)&1A=&$B.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]M971H;V1S6R1C=7)R96YT
M7V-L87-S75M=(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&-U<G)E;G1?:6YT97)F86-E*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`B)&-U<G)E;G1?
M:6YT97)F86-E.CHD9&%T82([#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E8VQA<F5D7VUE=&AO9'-;)&-U<G)E;G1?:6YT97)F86-E75M=(#T@
M)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@
M)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D
M7V9U;F-T:6]N<UM=(#T@)&-U<G)E;G1?9G5N8W1I;VX[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=%]F=6YC=&EO;E]L979E;"`]("1B<F%C95]L979E;#L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1M(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47TY%5RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'5S961?8VQA<W-E<ULD9&%T85T@/2!T<G5E
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1L;V]K7V9O<B`](#`[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M(#([#0H@("`@("`@("`@("`@("`@8V%S92!47U9!4DE!0DQ%.@T*("`@("`@
M("`@("`@("`@("`@("`D;&]O:U]F;W(@/2`P.PT*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]$3T-?
M0T]-345.5#H-"B`@("`@("`@("`@("`@("!C87-E(%1?0T]-345.5#H-"B`@
M("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R%>+UPJ7"I<<R$G
M+"`D9&%T82DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1L87-T<&AP
M9&]C(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<')E
M9U]M871C:%]A;&PH)R]`;F]D97!<<RLH7%,K*2\G+"`D;&%S='!H<&1O8RP@
M)&TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&5P<R`]
M(&%R<F%Y7VUE<F=E*"1N;V1E<',L("1M6S%=*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@
M5%]$3U5"3$5?0T],3TXZ#0H@("`@("`@("`@("`@("`@("`@(&EF("@A*"1T
M;VME;G-;)&D@+2`Q75LP72`]/2!47U=(251%4U!!0T4@?'P@)'1O:V5N<ULD
M:2`M(#%=6S!=(#T](%1?4U1224Y'*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?
M15)23U)?24Y604Q)1%]02%!&24Q%+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92DI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1C;&%S<R`]("1T;VME;G-;)&D@
M+2`Q75LQ73L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)&-L87-S*2`A/2`G<&%R96YT)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'5S961?8VQA<W-E<ULD8VQA<W-=(#T@=')U93L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A
M>2@-"B`@("`@("`@("`@(")S;W5R8V5?9FEL92(@/3X@)&9I;&4L#0H@("`@
M("`@("`@("`B9&5C;&%R961?8VQA<W-E<R(@/3X@)&1E8VQA<F5D7V-L87-S
M97,L#0H@("`@("`@("`@("`B9&5C;&%R961?:6YT97)F86-E<R(@/3X@)&1E
M8VQA<F5D7VEN=&5R9F%C97,L#0H@("`@("`@("`@("`B9&5C;&%R961?;65T
M:&]D<R(@/3X@)&1E8VQA<F5D7VUE=&AO9',L#0H@("`@("`@("`@("`B9&5C
M;&%R961?9G5N8W1I;VYS(B`]/B`D9&5C;&%R961?9G5N8W1I;VYS+`T*("`@
M("`@("`@("`@(G5S961?8VQA<W-E<R(@/3X@87)R87E?9&EF9BAA<G)A>5]K
M97ES*"1U<V5D7V-L87-S97,I+"`D;F]D97!S*2P-"B`@("`@("`@("`@(")I
M;FAE<FET86YC92(@/3X@)&5X=&5N9',L#0H@("`@("`@("`@("`B:6UP;&5M
M96YT<R(@/3X@)&EM<&QE;65N=',L#0H@("`@("`@("`@("`I.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($)U:6QD(&$@(G!R;W9I9&5S(B!A<G)A>2!F
M<F]M(&1A=&$@<F5T=7)N960@8GD-"B`@("`@*B!A;F%L>7IE4V]U<F-E0V]D
M92@I+B`@5&AE(&9O<FUA="!O9B!T:&4@8G5I;'0@87)R87D@:7,@;&EK90T*
M("`@("`J('1H:7,Z#0H@("`@("H-"B`@("`@*B`@87)R87DH#0H@("`@("H@
M("`@)V-L87-S.TUY0VQA<W,G(#T^("=A<G)A>2@G='EP92<@/3X@)V-L87-S
M)RP@)VYA;64G(#T^("=->4-L87-S)RDL#0H@("`@("H@("`@+BXN#0H@("`@
M("H@("D-"B`@("`@*@T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1S
M<F-I;F9O(&%R<F%Y('=I=&@@:6YF;W)M871I;VX@86)O=70@82!S;W5R8V4@
M9FEL90T*("`@("`J(&%S(')E='5R;F5D(&)Y('1H92!A;F%L>7IE4V]U<F-E
M0V]D92@I(&UE=&AO9"X-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?8G5I;&10<F]V:61E<T%R<F%Y*"1S<F-I;F9O
M*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7VES5F%L:60I('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D
M9FEL92`](&)A<V5N86UE*"1S<F-I;F9O6R=S;W5R8V5?9FEL92==*3L-"B`@
M("`@("`@)'!N(#T@)'1H:7,M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@)'!N
M;"`]('-T<FQE;B@D<&XI.PT*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG
M9&5C;&%R961?8VQA<W-E<R==(&%S("1C;&%S<RD@>PT*("`@("`@("`@("`@
M)&ME>2`](")C;&%S<SLD8VQA<W,B.PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K97E=
M(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y
M<&4G(#T^("=C;&%S<R<L("=N86UE)R`]/B`D8VQA<W,I.PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1S<F-I;F9O6R=I;FAE<FET86YC92==6R1C;&%S<UTI
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<')O
M=FED97,G75LD:V5Y75LG97AT96YD<R==(#T-"B`@("`@("`@("`@("`@("`@
M("`@)'-R8VEN9F];)VEN:&5R:71A;F-E)UU;)&-L87-S73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG
M9&5C;&%R961?;65T:&]D<R==(&%S("1C;&%S<R`]/B`D;65T:&]D<RD@>PT*
M("`@("`@("`@("`@9F]R96%C:"`H)&UE=&AO9',@87,@)&UE=&AO9"D@>PT*
M("`@("`@("`@("`@("`@("1F=6YC=&EO;B`]("(D8VQA<W,Z.B1M971H;V0B
M.PT*("`@("`@("`@("`@("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N
M(CL-"B`@("`@("`@("`@("`@("!I9B`H)&UE=&AO9'LP?2`]/2`G7R<@?'P@
M(7-T<F-A<V5C;7`H)&UE=&AO9"P@)&-L87-S*2!\?`T*("`@("`@("`@("`@
M("`@("`@("!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==
M6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG<')O=FED97,G75LD:V5Y72`]#0H@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE+"`G='EP92<@/3X@)V9U;F-T:6]N
M)RP@)VYA;64G(#T^("1F=6YC=&EO;BD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"@T*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R961?
M9G5N8W1I;VYS)UT@87,@)&9U;F-T:6]N*2![#0H@("`@("`@("`@("`D:V5Y
M(#T@(F9U;F-T:6]N.R1F=6YC=&EO;B([#0H@("`@("`@("`@("!I9B`H)&9U
M;F-T:6]N>S!](#T]("=?)R!\?"!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=P<F]V:61E<R==6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%S=')S='(H
M)&9U;F-T:6]N+"`G.CHG*2`F)B!S=')N8V%S96-M<"@D9G5N8W1I;VXL("1P
M;BP@)'!N;"DI('L-"B`@("`@("`@("`@("`@("`D=V%R;FEN9W-;72`](")I
M;C$@(B`N("1F:6QE("X@(CH@9G5N8W1I;VX@7"(D9G5N8W1I;VY<(B!N;W0@
M<')E9FEX960@=VET:"!P86-K86=E(&YA;64@7"(D<&Y<(B([#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V
M:61E<R==6R1K97E=(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]
M/B`D9FEL92P@)W1Y<&4G(#T^("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N
M8W1I;VXI.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H_
M/@T*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+T-H86YN96Q&:6QE+P``````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C`R-#,`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0VAA;FYE;$9I;&4O
M4&%R<V5R+G!H<```````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,C,P`#$P
M-3$U-#,Q,#4W`#`R,C(P-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27T-H86YN96Q&:6QE
M7U!A<G-E<B!F;W(@<&%R<VEN9R!C:&%N;F5L+GAM;`T*("H-"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!087)S97(N<&AP+'8@,2XT(#(P
M,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E
M("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@
M*B\-"@T*+RHJ#0H@*B!B87-E('AM;"!P87)S97(@8VQA<W,-"B`J+PT*<F5Q
M=6ER95]O;F-E("=014%2+UA-3%!A<G-E<BYP:'`G.PT*<F5Q=6ER95]O;F-E
M("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0HO*BH-"B`J(%!A<G-E<B!F;W(@
M8VAA;FYE;"YX;6P-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27T-H
M86YN96Q&:6QE7U!A<G-E<B!E>'1E;F1S(%!%05)?6$U,4&%R<V5R#0I[#0H@
M("`@=F%R("1?8V]N9FEG.PT*("`@('9A<B`D7VQO9V=E<CL-"B`@("!V87(@
M)%]R96=I<W1R>3L-"@T*("`@(&9U;F-T:6]N('-E=$-O;F9I9R@F)&,I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("8D8SL-"B`@("`@("`@
M)'1H:7,M/E]R96=I<W1R>2`]("8D8RT^9V5T4F5G:7-T<GDH*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!S971,;V=G97(H)B1L*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]L;V=G97(@/2`F)&P[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@<&%R<V4H)&1A=&$L("1F:6QE*0T*("`@('L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<B`]('!A<F5N=#HZ<&%R<V4H)&1A=&$L("1F:6QE
M*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@
M("`@("`@("1R970@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@
M)')E="T^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;&]G9V5R*2D@>PT*("`@("`@("`@("`@)')E="T^
M<V5T3&]G9V5R*"1T:&ES+3Y?;&]G9V5R*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<F5T+3YF<F]M07)R87DH)'1H:7,M/E]U;G-E<FEA;&EZ961$871A*3L-
M"B`@("`@("`@+R\@;6%K92!S=7)E('1H92!F:6QE;&ES="!I<R!I;B!T:&4@
M96%S>2!T;R!R96%D(&9O<FUA="!N965D960-"B`@("`@("`@)')E="T^9FQA
M='1E;D9I;&5L:7-T*"D[#0H@("`@("`@("1R970M/G-E=%!A8VMA9V5F:6QE
M*"1F:6QE+"`D87)C:&EV92D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"GT-"C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M1&]W;FQO861E<BYP:'``````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,38V-#$S`#$P-3$U-#,Q,#4W`#`R,#<Q,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%2
M7T1O=VYL;V%D97(L('1H92!014%2($EN<W1A;&QE<B=S(&1O=VYL;V%D('5T
M:6QI='D@8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H
M<"YN970^#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+B!6+B!#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H
M<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U
M<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z
M("1)9#H@1&]W;FQO861E<BYP:'`L=B`Q+CDY(#(P,#8O,#,O,#(@,3@Z,30Z
M,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C,N,`T*("HO#0H-"B\J*@T*("H@3F5E
M9&5D(&9O<B!C;VYS=&%N=',L(&5X=&5N9&EN9PT*("HO#0IR97%U:7)E7V]N
M8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H-"F1E9FEN92@G4$5!4E])3E-404Q,
M15)?3TLG+"`@("`@("`Q*3L-"F1E9FEN92@G4$5!4E])3E-404Q,15)?1D%)
M3$5$)RP@("`P*3L-"F1E9FEN92@G4$5!4E])3E-404Q,15)?4TM)4%!%1"<L
M("TQ*3L-"F1E9FEN92@G4$5!4E])3E-404Q,15)?15)23U)?3D]?4%)%1E]3
M5$%412<L(#(I.PT*#0HO*BH-"B`J($%D;6EN:7-T<F%T:6]N(&-L87-S('5S
M960@=&\@9&]W;FQO860@86YY=&AI;F<@9G)O;2!T:&4@:6YT97)N970@*%!%
M05(@4&%C:V%G97,L#0H@*B!S=&%T:6,@55),<RP@>&UL(&9I;&5S*0T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@(%1O;6%S(%8N(%8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*
M("H@0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XS+C`-"B`J+PT*8VQA<W,@4$5!4E]$;W=N;&]A9&5R(&5X=&5N
M9',@4$5!4E]#;VUM;VX-"GL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?
M4F5G:7-T<GD-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!V87(@)%]R96=I<W1R>3L-"@T*("`@("\J*@T*("`@("`J($!V87(@4$5!
M4E]296UO=&4-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!V87(@)%]R96UO=&4[#0H-"B`@("`O*BH-"B`@("`@*B!0<F5F97)R960@
M26YS=&%L;&%T:6]N(%-T871E("AS;F%P<VAO="P@9&5V96PL(&%L<&AA+"!B
M971A+"!S=&%B;&4I#0H@("`@("H@0'9A<B!S=')I;F=\;G5L;`T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W!R969E<G)E
M9%-T871E.PT*#0H@("`@+RHJ#0H@("`@("H@3W!T:6]N<R!F<F]M(&-O;6UA
M;F0M;&EN92!P87-S960@=&\@26YS=&%L;"X-"B`@("`@*@T*("`@("`J(%)E
M8V]G;FEZ960@;W!T:6]N<SH\8G(@+SX-"B`@("`@*B`@+2!O;FQY<F5Q9&5P
M<R`@(#H@:6YS=&%L;"!A;&P@<F5Q=6ER960@9&5P96YD96YC:65S(&%S('=E
M;&P-"B`@("`@*B`@+2!A;&QD97!S("`@("`@(#H@:6YS=&%L;"!A;&P@9&5P
M96YD96YC:65S+"!I;F-L=61I;F<@;W!T:6]N86P-"B`@("`@*B`@+2!I;G-T
M86QL<F]O="`@(#H@8F%S92!R96QA=&EV92!P871H('1O(&EN<W1A;&P@9FEL
M97,@:6X-"B`@("`@*B`@+2!F;W)C92`@("`@("`@(#H@9F]R8V4@82!D;W=N
M;&]A9"!E=F5N(&EF('=A<FYI;F=S('=O=6QD('!R979E;G0@:70-"B`@("`@
M*B`@+2!N;V-O;7!R97-S("`@(#H@9&]W;FQO860@=6YC;VUP<F5S<V5D('1A
M<F)A;&QS#0H@("`@("H@0'-E92!014%27T-O;6UA;F1?26YS=&%L;`T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!V87(@87)R87D-"B`@("`@
M*B\-"B`@("!V87(@)%]O<'1I;VYS.PT*#0H@("`@+RHJ#0H@("`@("H@1&]W
M;FQO861E9"!086-K86=E<R!A9G1E<B!A(&-A;&P@=&\@9&]W;FQO860H*2X-
M"B`@("`@*@T*("`@("`J($9O<FUA="!O9B!E86-H(&5N=')Y.@T*("`@("`J
M#0H@("`@("H@/&-O9&4^#0H@("`@("H@87)R87DH)W!K9R<@/3X@)W!A8VMA
M9V5?;F%M92<L("=F:6QE)R`]/B`G+W!A=&@O=&\O;&]C86PO9FEL92<L#0H@
M("`@("H@("`@)VEN9F\G(#T^(&%R<F%Y*"D@+R\@<&%R<V5D('!A8VMA9V4N
M>&UL#0H@("`@("H@*3L-"B`@("`@*B`\+V-O9&4^#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J+PT*("`@('9A
M<B`D7V1O=VYL;V%D961086-K86=E<R`](&%R<F%Y*"D[#0H-"B`@("`O*BH-
M"B`@("`@*B!086-K86=E<R!S;&%T960@9F]R(&1O=VYL;V%D+@T*("`@("`J
M#0H@("`@("H@5&AI<R!I<R!U<V5D('1O('!R979E;G0@9&]W;FQO861I;F<@
M82!P86-K86=E(&UO<F4@=&AA;B!O;F-E('-H;W5L9"!I="!B92!A(&1E<&5N
M9&5N8WD-"B`@("`@*B!F;W(@='=O('!A8VMA9V5S('1O(&)E(&EN<W1A;&QE
M9"X-"B`@("`@*B!&;W)M870@;V8@96%C:"!E;G1R>3H-"B`@("`@*@T*("`@
M("`J(#QP<F4^#0H@("`@("H@87)R87DH)W!A8VMA9V5?;F%M93$G(#T^('!A
M<G-E9"!P86-K86=E+GAM;"P@)W!A8VMA9V5?;F%M93(G(#T^('!A<G-E9"!P
M86-K86=E+GAM;"P-"B`@("`@*B`I.PT*("`@("`J(#PO<')E/@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-
M"B`@("!V87(@)%]T;T1O=VYL;V%D(#T@87)R87DH*3L-"@T*("`@("\J*@T*
M("`@("`J($%R<F%Y(&]F(&5V97)Y('!A8VMA9V4@:6YS=&%L;&5D+"!W:71H
M(&YA;65S(&QO=V5R+6-A<V5D+@T*("`@("`J#0H@("`@("H@1F]R;6%T.@T*
M("`@("`J(#QC;V1E/@T*("`@("`J(&%R<F%Y*"=P86-K86=E,2<@/3X@,"P@
M)W!A8VMA9V4R)R`]/B`Q+"`I.PT*("`@("`J(#PO8V]D93X-"B`@("`@*B!`
M=F%R(&%R<F%Y#0H@("`@("HO#0H@("`@=F%R("1?:6YS=&%L;&5D(#T@87)R
M87DH*3L-"@T*("`@("\J*@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]E<G)O<E-T86-K
M(#T@87)R87DH*3L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!`=F%R(&)O;VQE
M86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]I;G1E<FYA;$1O=VYL;V%D(#T@9F%L<V4[#0H-"B`@("`O*BH-"B`@("`@
M*B!496UP;W)A<GD@=F%R:6%B;&4@=7-E9"!I;B!S;W)T:6YG('!A8VMA9V5S
M(&)Y(&1E<&5N9&5N8WD@:6X@>T!L:6YK('-O<G10:V=$97!S*"E]#0H@("`@
M("H@0'9A<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@('9A<B`D7W!A8VMA9V53;W)T5')E93L-"@T*("`@("\J*@T*("`@
M("`J(%1E;7!O<F%R>2!D:7)E8W1O<GDL(&]R(&-O;F9I9W5R871I;VX@=F%L
M=64@=VAE<F4@9&]W;FQO861S('=I;&P@;V-C=7(-"B`@("`@*B!`=F%R('-T
M<FEN9PT*("`@("`J+PT*("`@('9A<B`D7V1O=VYL;V%D1&ER.PT*("`@("\O
M('M[>R!014%27T1O=VYL;V%D97(H*0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M(%!%05)?1G)O;G1E;F1?*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@
M("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%!%05)?1&]W;FQO861E<B@F)'5I+"`D;W!T:6]N<RP@)B1C;VYF:6<I#0H@
M("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6]N*"D[#0H@("`@("`@
M("1T:&ES+3Y?;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@("`@("`D=&AI<RT^
M8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@("`@("1T:&ES+3Y?<')E9F5R<F5D
M4W1A=&4@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I
M.PT*("`@("`@("`D=&AI<RT^=6D@/2`F)'5I.PT*("`@("`@("!I9B`H(21T
M:&ES+3Y?<')E9F5R<F5D4W1A=&4I('L-"B`@("`@("`@("`@("\O(&1O;B=T
M(&EN861V97)T86YT;'D@=7-E(&$@;F]N+7-E="!P<F5F97)R961?<W1A=&4-
M"B`@("`@("`@("`@("1T:&ES+3Y?<')E9F5R<F5D4W1A=&4@/2!N=6QL.PT*
M("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG:6YS=&%L;')O;W0G72DI('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF
M:6<M/G-E=$EN<W1A;&Q2;V]T*"1T:&ES+3Y?;W!T:6]N<ULG:6YS=&%L;')O
M;W0G72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]
M("8D8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D=&AI<RT^7W)E
M;6]T92`]("8D8V]N9FEG+3YG971296UO=&4H*3L-"@T*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=A;&QD97!S)UTI('Q\(&ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG;VYL>7)E<61E<',G72DI('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?:6YS=&%L;&5D(#T@)'1H:7,M/E]R96=I<W1R>2T^;&ES=$%L
M;%!A8VMA9V5S*"D[#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VEN
M<W1A;&QE9"!A<R`D:V5Y(#T^("1U;G5S960I('L-"B`@("`@("`@("`@("`@
M("!I9B`H(6-O=6YT*"1U;G5S960I*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!`87)R87E?=V%L:R@D=&AI<RT^7VEN<W1A;&QE9%LD:V5Y72P@)W-T<G1O
M;&]W97(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($%T=&5M<'0@=&\@9&ES8V]V97(@82!C:&%N;F5L
M)W,@<F5M;W1E(&-A<&%B:6QI=&EE<R!F<F]M#0H@("`@("H@:71S('-E<G9E
M<B!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@
M8F]O;&5A;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&1I<V-O=F5R*"1C:&%N
M;F5L*0T*("`@('L-"B`@("`@("`@)'1H:7,M/FQO9R@Q+"`G071T96UP=&EN
M9R!T;R!D:7-C;W9E<B!C:&%N;F5L("(G("X@)&-H86YN96P@+B`G(BXN+B<I
M.PT*("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD[#0H@("`@("`@("1C86QL8F%C:R`]("1T:&ES+3YU:2`_(&%R
M<F%Y*"8D=&AI<RP@)U]D;W=N;&]A9$-A;&QB86-K)RD@.B!N=6QL.PT*("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@('T-"B`@
M("`@("`@)&$@/2`D=&AI<RT^9&]W;FQO861(='1P*"=H='1P.B\O)R`N("1C
M:&%N;F5L("X@)R]C:&%N;F5L+GAM;"<L("1T:&ES+3YU:2P-"B`@("`@("`@
M("`@(%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*2P@)&-A;&QB86-K+"!F
M86QS92D[#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&$I*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@;&ES="@D82P@)&QA
M<W1M;V1I9FEE9"D@/2`D83L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)U!%05(O0VAA;FYE;$9I;&4N<&AP)RDI('L-"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*("`@("`@("!]#0H@
M("`@("`@("1B(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@("`@(&EF
M("@D8BT^9G)O;5AM;$9I;&4H)&$I*2![#0H@("`@("`@("`@("!`=6YL:6YK
M*"1A*3L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)V%U
M=&]?9&ES8V]V97(G*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G
M:7-T<GDM/F%D9$-H86YN96PH)&(L("1L87-T;6]D:69I960I.PT*("`@("`@
M("`@("`@("`@("1A;&EA<R`]("1B+3YG971.86UE*"D[#0H@("`@("`@("`@
M("`@("`@:68@*"1B+3YG971.86UE*"D@/3T@)'1H:7,M/E]R96=I<W1R>2T^
M8VAA;FYE;$YA;64H)&(M/F=E=$%L:6%S*"DI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1A;&EA<R`]("1B+3YG971!;&EA<R@I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L("=!=71O+61I
M<V-O=F5R960@8VAA;FYE;"`B)R`N("1C:&%N;F5L("X-"B`@("`@("`@("`@
M("`@("`@("`@)R(L(&%L:6%S("(G("X@)&%L:6%S("X@)R(L(&%D9&EN9R!T
M;R!R96=I<W1R>2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@0'5N;&EN:R@D82D[#0H@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!&;W(@<VEM<&QE<B!U;FET+71E<W1I;F<-"B`@("`@*B!`<&%R86T@4$5!
M4E]$;W=N;&]A9&5R#0H@("`@("H@0')E='5R;B!014%27T1O=VYL;V%D97)?
M4&%C:V%G90T*("`@("`J+PT*("`@(&9U;F-T:6]N("9N97=$;W=N;&]A9&5R
M4&%C:V%G92@F)'0I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@G4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4G*2D@>PT*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(O4&%C:V%G92YP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27T1O=VYL;V%D97)?
M4&%C:V%G92@D="D[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!&;W(@<VEM<&QE<B!U;FET+71E<W1I;F<-"B`@("`@
M*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<&%R86T@87)R87D-"B`@
M("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<&%R86T@:6YT#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@)F=E=$1E<&5N9&5N8WDR3V)J96-T*"8D8RP@)&DL
M("1P+"`D<RD-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%2+T1E<&5N9&5N8WDR+G!H<"<I*2![#0H@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@?0T*("`@
M("`@("`D>B`]("9N97<@4$5!4E]$97!E;F1E;F-Y,B@D8RP@)&DL("1P+"`D
M<RD[#0H@("`@("`@(')E='5R;B`D>CL-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B`F9&]W;FQO860H)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("@A8V]U
M;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1A(#T@87)R87DH*3L-"B`@
M("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<F5G:7-T<GDI*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W)E;6]T
M92DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<F5M;W1E(#T@)B1T:&ES+3YC
M;VYF:6<M/F=E=%)E;6]T92@I.PT*("`@("`@("!]#0H@("`@("`@("1C:&%N
M;F5L<V-H96-K960@/2!A<G)A>2@I.PT*("`@("`@("`O+R!C;VYV97)T(&%L
M;"!P87)A;65T97)S(&EN=&\@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4@;V)J
M96-T<PT*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1I(#T^("1P87)A
M;2D@>PT*("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2`F)'1H:7,M/FYE=T1O
M=VYL;V%D97)086-K86=E*"1T:&ES*3L-"B`@("`@("`@("`@(%!%05(Z.G-T
M871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@("`@("1E<G(@/2`D<&%R86US6R1I72T^:6YI=&EA;&EZ92@D<&%R
M86TI.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@:68@*"$D97)R*2![#0H@("`@("`@("`@("`@
M("`@+R\@<VMI<"!P87)A;65T97)S('1H870@=V5R92!M:7-S960@8GD@<')E
M9F5R<F5D7W-T871E#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,"P@)&5R<BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1P87)A;2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M(#T@)'!A<F%M+3YG971#:&%N;F5L*"D@+B`G
M+R<@+B`D<&%R86TM/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<B@G4&%C:V%G92`B
M)R`N("1P87)A;2`N("<B(&ES(&YO="!V86QI9"<L#0H@("`@("`@("`@("`@
M("`@("`@(%!%05)?24Y35$%,3$527U-+25!0140I.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<ULD:5T@)B8@
M(6ES<V5T*"1C:&%N;F5L<V-H96-K961;)'!A<F%M<ULD:5TM/F=E=$-H86YN
M96PH*5TI("8F#0H@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG;V9F;&EN92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D8VAA;FYE;'-C:&5C:V5D6R1P87)A;7-;)&E=+3YG971#:&%N;F5L*"E=
M(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H
M<"<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)&-U<F-H86YN96P@/2`F)'1H:7,M/E]R96=I<W1R>2T^9V5T0VAA;FYE
M;"@D<&%R86US6R1I72T^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-U<F-H86YN96PI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&-U<F-H86YN96PI.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1A(#T@)'1H:7,M/F1O=VYL;V%D
M2'1T<"@G:'1T<#HO+R<@+B`D<&%R86US6R1I72T^9V5T0VAA;FYE;"@I("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("<O8VAA;FYE;"YX;6PG+"`D=&AI
M<RT^=6DL#0H@("`@("`@("`@("`@("`@("`@("`@("!3>7-T96TZ.FUK=&5M
M<"AA<G)A>2@G+60G*2DL(&YU;&PL("1C=7)C:&%N;F5L+3YL87-T36]D:69I
M960H*2D[#0H@("`@("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&$I('Q\("$D82D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`G5T%23DE.1SH@8VAA;FYE;"`B
M)R`N("1P87)A;7-;)&E=+3YG971#:&%N;F5L*"D@+B`G(B!H87,@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E9"!I=',@<')O=&]C;VQS
M+"!U<V4@(F-H86YN96PM=7!D871E("<@+B`D<&%R86US6R1I72T^9V5T0VAA
M;FYE;"@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B('1O('5P9&%T
M92<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M)'!A<F%M<ULD:5T@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO
M861O;FQY)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1C:&5C:V1I<B`]("1T:&ES+3Y?<')E<&5N9%!A
M=&@H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=P:'!?9&ER)RP@;G5L;"P@)'!A<F%M<ULD:5TM/F=E=$-H86YN
M96PH*2DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-H96-K9&ER
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!N=6QL+"`D<&%R86US6R1I72T^9V5T0VAA;FYE
M;"@I*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!W:&EL92`H)&-H96-K9&ER("8F("1C:&5C:V1I<B`A/2`G+R<@)B8@
M(69I;&5?97AI<W1S*"1C:&5C:V1I<BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1C:&5C:V1I<B`](&1I<FYA;64H)&-H96-K9&ER*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&-H
M96-K9&ER(#T]("<N)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-H
M96-K9&ER(#T@)R\G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A0&ES7W=R:71E86)L92@D8VAE8VMD:7(I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G0V%N;F]T(&EN<W1A;&PL('!H<%]D:7(@9F]R(&-H86YN96P@(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7-;)&E=+3YG
M971#:&%N;F5L*"D@+B`G(B!I<R!N;W0@=W)I=&5A8FQE(&)Y('1H92!C=7)R
M96YT('5S97(G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!U
M;G-E="@D8VAA;FYE;'-C:&5C:V5D*3L-"B`@("`@("`@4$5!4E]$;W=N;&]A
M9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T97,H)'!A<F%M<RD[#0H@("`@
M("`@(&EF("@A8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1A(#T@
M87)R87DH*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI
M("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@
M("`@("`@("`@("1R979E<FEF>2`]('1R=64[#0H@("`@("`@("`@("!W:&EL
M92`H)')E=F5R:69Y*2![#0H@("`@("`@("`@("`@("`@)')E=F5R:69Y(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D
M:2`]/B`D<&%R86TI('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`]("1P
M87)A;7-;)&E=+3YD971E8W1$97!E;F1E;F-I97,H)'!A<F%M<RD[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5V97)I9GD@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?1&]W;FQO861E<E]086-K86=E
M.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M("1R970M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3YL
M;V<H,RP@)U-K:7!P:6YG(&1E<&5N9&5N8WD@9&]W;FQO860@8VAE8VLL("TM
M;V9F;&EN92!S<&5C:69I960G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(6-O=6YT*"1P87)A;7,I*2![#0H@("`@("`@("`@("`D82`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@
M=VAI;&4@*%!%05)?1&]W;FQO861E<E]086-K86=E.CIM97)G941E<&5N9&5N
M8VEE<R@D<&%R86US*2D[#0H@("`@("`@(%!%05)?1&]W;FQO861E<E]086-K
M86=E.CIR96UO=F5);G-T86QL960H)'!A<F%M<RD[#0H@("`@("`@(&EF("@A
M8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R
M;W(H)TYO('9A;&ED('!A8VMA9V5S(&9O=6YD)RP@4$5!4E])3E-404Q,15)?
M1D%)3$5$*3L-"B`@("`@("`@("`@("1A(#T@87)R87DH*3L-"B`@("`@("`@
M("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@("!014%2.CIP=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1E
M<G(@/2`D=&AI<RT^86YA;'EZ941E<&5N9&5N8VEE<R@D<&%R86US*3L-"B`@
M("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H
M(6-O=6YT*"1P87)A;7,I*2![#0H@("`@("`@("`@("`D=&AI<RT^<'5S:$5R
M<F]R*"=.;R!V86QI9"!P86-K86=E<R!F;W5N9"<L(%!%05)?24Y35$%,3$52
M7T9!24Q%1"D[#0H@("`@("`@("`@("`D82`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&%R
M<F%Y*"D[#0H@("`@("`@("1N97=P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS6R=P<F5T96YD)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'!A<F%M<SL-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H("@D<&%R86US(&%S("1I(#T^("1P86-K86=E*2![#0H@("`@
M("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD[#0H@("`@("`@("`@("`D<&8@/2`F)'!A<F%M<ULD:5TM
M/F1O=VYL;V%D*"D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O
M<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<&8I*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9R@Q+"`D<&8M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H,"P@)T5R<F]R.B!C86YN;W0@9&]W;FQO860@(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^
M<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%C:V%G92T^9V5T4&%R<V5D
M4&%C:V%G92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&YE=W!A<F%M<UM=(#T@)B1P87)A;7-;)&E=
M.PT*("`@("`@("`@("`@)')E=%M=(#T@87)R87DH)V9I;&4G(#T^("1P9BT^
M9V5T07)C:&EV949I;&4H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VEN9F\G(#T^("8D<&8L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P:V<G(#T^("1P9BT^9V5T4&%C:V%G92@I*3L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V1O=VYL;V%D961086-K86=E
M<R`]("1R970[#0H@("`@("`@(')E='5R;B`D;F5W<&%R86US.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>2!A;&P@<&%C:V%G97,@
M=&\@8F4@:6YS=&%L;&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@86YA;'EZ
M941E<&5N9&5N8VEE<R@F)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1H87-F
M86EL960@/2`D9F%I;&5D(#T@9F%L<V4[#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G-T871I8U!U
M<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@
M)')E9&\@/2!T<G5E.PT*("`@("`@("`D<F5S970@/2!F86QS93L-"B`@("`@
M("`@=VAI;&4@*"1R961O*2![#0H@("`@("`@("`@("`D<F5D;R`](&9A;'-E
M.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%R
M86TI('L-"B`@("`@("`@("`@("`@("`D9&5P<R`]("1P87)A;2T^9V5T1&5P
M<R@I.PT*("`@("`@("`@("`@("`@(&EF("@A)&1E<',I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&1E<&-H96-K97(@/2`F)'1H:7,M/F=E=$1E<&5N9&5N
M8WDR3V)J96-T*"1T:&ES+3YC;VYF:6<L("1T:&ES+3YG971/<'1I;VYS*"DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%!A<G-E9%!A
M8VMA9V4H*2P@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1RD[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D<&%R86TM/F=E=%1Y<&4H*2`]/2`G>&UL<G!C
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-E;F0@/2`D<&%R86TM
M/F=E=$1O=VYL;V%D55),*"D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<V5N9"`]("1P87)A;2T^
M9V5T4&%C:V%G949I;&4H*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D:6YS=&%L;&-H96-K(#T@)&1E<&-H96-K97(M
M/G9A;&ED871E4&%C:V%G92@D<V5N9"P@)'1H:7,L("1P87)A;7,I.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YS=&%L;&-H
M96-K*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1I;G-T86QL8VAE8VLM/F=E=$UE
M<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D:&%S9F%I;&5D(#T@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;7-;)&E=(#T@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S970@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E9&\@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9A:6QE9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T97,H
M)'!A<F%M<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H(21R97-E="`F)B`D<&%R86TM/F%L<F5A9'E686QI9&%T960H*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1D97!S*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D9&5P8VAE8VME<B`]("8D=&AI<RT^9V5T
M1&5P96YD96YC>3)/8FIE8W0H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/F=E=$]P
M=&EO;G,H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2T^9V5T
M4&%R<V5D4&%C:V%G92@I+"!014%27U9!3$E$051%7T1/5TY,3T%$24Y'*3L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1P87)A;2T^9V5T5'EP92@I(#T]
M("=X;6QR<&,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<V5N9"`]
M("1P87)A;2T^9V5T1&]W;FQO86154DPH*3L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S96YD(#T@
M)'!A<F%M+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL8VAE8VL@/2`D9&5P
M8VAE8VME<BT^=F%L:61A=&5086-K86=E*"1S96YD+"`D=&AI<RP@)'!A<F%M
M<RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I
M;G-T86QL8VAE8VLI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)&EN<W1A;&QC:&5C
M:RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1H87-F86EL960@/2!T<G5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F86QS93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-E="`]('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5D;R`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D9F%I;&5D(#T@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M;W9E1'5P
M;&EC871E<R@D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@)&9A:6QE9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG<F5Q=6ER960G72!A<R`D
M='EP92`]/B`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@;F]T93H@1&5P96YD96YC>3(@=VEL;"!N979E<B!R971U<FX@82!014%2
M7T5R<F]R(&EF(&EG;F]R92UE<G)O<G,-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!I<R!S<&5C:69I960L('-O('-O9G0@:7,@;F5E9&5D('1O
M('1U<FX@;V9F(&QO9V=I;F<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1D97!;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)&1E<&-H96-K
M97(M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1D97`L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64L("1P87)A
M;7,I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,"P@)&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D92D@)B8@(21P87)A
M;2T^86QR96%D>59A;&ED871E9"@I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,"P@)&5;,%TI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<"!A<R`D9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<&-H96-K97(M/GLB
M=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1D+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92P@)'!A<F%M<RDI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R
M87DH)&4I("8F("$D<&%R86TM/F%L<F5A9'E686QI9&%T960H*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@
M)&5;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG
M;W!T:6]N86PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9&5P<ULG;W!T:6]N86PG72!A<R`D='EP92`]/B`D9&5P*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&1E<%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R+3Y[(G9A;&ED
M871E>R1T>7!E?41E<&5N9&5N8WDB?2@D9&5P+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L("1P87)A;7,I*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M86EL960@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H,"P@)&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y
M*"1E*2`F)B`A)'!A<F%M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E
M6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5P
M(&%S("1D*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R+3Y[
M(G9A;&ED871E>R1T>7!E?41E<&5N9&5N8WDB?2@D9"P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@)'!A
M<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F86EL960@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T
M365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D92D@)B8@(21P87)A;2T^
M86QR96%D>59A;&ED871E9"@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E6S!=*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1G<F]U<&YA;64@/2`D<&%R86TM/F=E=$=R
M;W5P*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<'-;)V=R;W5P)UTI("8F("1G<F]U<&YA;64I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=G<F]U<"==6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULG9W)O
M=7`G72`](&%R<F%Y*"1D97!S6R=G<F]U<"==*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&1E<'-;)V=R;W5P)UT@87,@)&=R;W5P*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9W)O=7!;)V%T=')I8G,G
M75LG;F%M92==(#T]("1G<F]U<&YA;64I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&9O
M=6YD*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1G<F]U<%LG871T<FEB<R==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&=R;W5P(&%S("1T>7!E(#T^("1D97`I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&1E<%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<&-H96-K
M97(M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1D97`L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L
M<V4L("1P87)A;7,I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9F%I;&5D(#T@=')U93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@
M)&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&4I("8F("$D
M<&%R86TM/F%L<F5A9'E686QI9&%T960H*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D95LP
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97`@87,@)&0I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@
M/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E
M;F-Y(GTH)&0L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9A;'-E+"`D<&%R86US*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL
M960@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O
M9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&4I("8F("$D<&%R86TM
M/F%L<F5A9'E686QI9&%T960H*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E
M6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1D97`I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D92`]("1D97!C:&5C:V5R+3YV86QI9&%T941E<&5N9&5N8WDQ*"1D97`L
M("1P87)A;7,I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F%I;&5D(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,"P@)&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H:7-?87)R87DH)&4I("8F("$D<&%R86TM/F%L<F5A9'E686QI
M9&%T960H*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D
M95LP72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<ULD:5TM/G-E=%9A;&ED871E9"@I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&9A:6QE9"D@>PT*
M("`@("`@("`@("`@("`@("`@("`D:&%S9F%I;&5D(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@)')E<V5T(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@)')E9&\@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`D9F%I;&5D
M(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@(%!%05)?1&]W;FQO861E
M<E]086-K86=E.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!014%2.CIS=&%T
M:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("@D:&%S9F%I;&5D
M("8F("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72D@
M?'P-"B`@("`@("`@("`@("`@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E
M<',G72DI*2![#0H@("`@("`@("`@("`O+R!T:&ES(&ES('!R;V)A8FQY(&YO
M="!N965D960L(&)U="!J=7-T(&EN(&-A<V4-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`G5T%23DE.1SH@9&5P96YD96YC:65S(&9A
M:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@=&AE(&1I<F5C=&]R>2!T:&%T(&1O
M=VYL;V%D<R!W:6QL(&AA<'!E;B!I;@T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T1&]W;FQO861$:7(H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?9&]W;FQO861$:7(I*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]D;W=N;&]A9$1I<CL-"B`@("`@("`@?0T*("`@("`@("`D9&]W
M;FQO861D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1O=VYL;V%D7V1I<B<I
M.PT*("`@("`@("!I9B`H96UP='DH)&1O=VYL;V%D9&ER*2D@>PT*("`@("`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U-Y<W1E;2<I*2![#0H@("`@("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1D;W=N;&]A
M9&1I<B`](%-Y<W1E;3HZ;6MT96UP*"<M9"<I*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D9&]W;FQO861D:7([#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L("<K('1M<"!D:7(@8W)E871E9"!A="`G
M("X@)&1O=VYL;V%D9&ER*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]D;W=N;&]A9$1I<B`]("1D;W=N;&]A9&1I<CL-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!S971$;W=N;&]A9$1I<B@D9&ER*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]D;W=N;&]A9$1I<B`]("1D:7([#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;F9I9U-E="@I#0H@("`@9G5N8W1I
M;VX@8V]N9FEG4V5T*"1K97DL("1V86QU92P@)&QA>65R(#T@)W5S97(G+"`D
M8VAA;FYE;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F-O;F9I
M9RT^<V5T*"1K97DL("1V86QU92P@)&QA>65R+"`D8VAA;FYE;"D[#0H@("`@
M("`@("1T:&ES+3Y?<')E9F5R<F5D4W1A=&4@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)W!R969E<G)E9%]S=&%T92<L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@
M("`@:68@*"$D=&AI<RT^7W!R969E<G)E9%-T871E*2![#0H@("`@("`@("`@
M("`O+R!D;VXG="!I;F%D=F5R=&%N=&QY('5S92!A(&YO;BUS970@<')E9F5R
M<F5D7W-T871E#0H@("`@("`@("`@("`D=&AI<RT^7W!R969E<G)E9%-T871E
M(#T@;G5L;#L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!S971/<'1I;VYS*"D-"B`@("!F=6YC=&EO;B!S971/<'1I;VYS
M*"1O<'1I;VYS*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@
M)&]P=&EO;G,[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-E
M=$]P=&EO;G,H*0T*("`@(&9U;F-T:6]N(&=E=$]P=&EO;G,H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!T:6]N<SL-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"@T*("`@("\J*@T*("`@("`J($9O<B!S:6UP;&5R('5N:70M
M=&5S=&EN9PT*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!P
M87)A;2!I;G0-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@)F=E=%!A8VMA9V5F:6QE3V)J96-T*"8D8RP@)&0L("1T(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]086-K86=E1FEL92<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D
M82`]("9N97<@4$5!4E]086-K86=E1FEL92@D8RP@)&0L("1T*3L-"B`@("`@
M("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\O('M[>R!?9V5T4&%C:V%G
M941O=VYL;V%D57)L*"D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A
M>2!O=71P=70@;V8@>T!L:6YK('!A<G-E4&%C:V%G94YA;64H*7T-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T
M4&%C:V%G941O=VYL;V%D57)L*"1P87)R*0T*("`@('L-"B`@("`@("`@)&-U
M<F-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE
M;"<I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN
M96PG+"`D<&%R<ELG8VAA;FYE;"==*3L-"B`@("`@("`@+R\@9V5T1&]W;FQO
M86154DP@<F5T=7)N<R!A;B!A<G)A>2X@($]N(&5R<F]R+"!I="!O;FQY(&-O
M;G1A:6YS(&EN9F]R;6%T:6]N#0H@("`@("`@("\O(&]N('1H92!L871E<W0@
M<F5L96%S92!A<R!A<G)A>2AV97)S:6]N+"!I;F9O*2X@($]N('-U8V-E<W,@
M:70@8V]N=&%I;G,-"B`@("`@("`@+R\@87)R87DH=F5R<VEO;BP@:6YF;RP@
M9&]W;FQO860@=7)L('-T<FEN9RD-"B`@("`@("`@)'-T871E(#T@:7-S970H
M)'!A<G);)W-T871E)UTI(#\@)'!A<G);)W-T871E)UT@.B`D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I.PT*("`@("`@("!I9B`H(21T
M:&ES+3Y?<F5G:7-T<GDM/F-H86YN96Q%>&ES=',H)'!A<G);)V-H86YN96PG
M72DI('L-"B`@("`@("`@("`@(&1O('L-"B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/F-O;F9I9RT^9V5T*"=A=71O7V1I<V-O=F5R)RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3YD:7-C;W9E<B@D<&%R<ELG8VAA
M;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L
M)RP@)&-U<F-H86YN96PI.PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=5;FMN;W=N(')E;6]T92!C:&%N;F5L.B`G("X@)')E
M;6]T96-H86YN96PI.PT*("`@("`@("`@("`@?2!W:&EL92`H9F%L<V4I.PT*
M("`@("`@("!]#0H@("`@("`@("1C:&%N(#T@)B1T:&ES+3Y?<F5G:7-T<GDM
M/F=E=$-H86YN96PH)'!A<G);)V-H86YN96PG72D[#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1C
M:&%N.PT*("`@("`@("!]#0H@("`@("`@("1V97)S:6]N(#T@)'1H:7,M/E]R
M96=I<W1R>2T^<&%C:V%G94EN9F\H)'!A<G);)W!A8VMA9V4G72P@)W9E<G-I
M;VXG+`T*("`@("`@("`@("`@)'!A<G);)V-H86YN96PG72D[#0H@("`@("`@
M(&EF("@D8VAA;BT^<W5P<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G
M<')E9F5R<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@("`@("`@("`D8F%S92`]
M("1C:&%N+3YG971"87-E55),*"=215-4,2XP)RP@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?;6ER<F]R)RDI*2![#0H@("`@("`@("`@("`D<F5S
M="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C`G+"`D=&AI<RT^7V]P
M=&EO;G,I.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R<ELG=F5R<VEO
M;B==*2`F)B`A:7-S970H)'!A<G);)W-T871E)UTI("8F("1V97)S:6]N#0H@
M("`@("`@("`@("`@("`@("`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=D
M;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@("`@("`@("`D=7)L(#T@)')E
M<W0M/F=E=$1O=VYL;V%D55),*"1B87-E+"`D<&%R<BP@)'-T871E+"`D=F5R
M<VEO;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1U<FP@/2`D<F5S="T^9V5T1&]W;FQO86154DPH)&)A<V4L("1P87)R+"`D
M<W1A=&4L(&9A;'-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1U<FPI*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-U<F-H86YN96PI
M.PT*("`@("`@("`@("`@("`@(')E='5R;B`D=7)L.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"1P87)R6R=C:&%N;F5L)UT@(3T@)&-U<F-H
M86YN96PI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D
M969A=6QT7V-H86YN96PG+"`D8W5R8VAA;FYE;"D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1U<FPI*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D=7)L6R=R87<G72`](&9A;'-E.R`O+R!N;R!C:&5C:VEN9R!I<R!N
M96-E<W-A<GD@9F]R(%)%4U0-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)'5R;%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=);G9A;&ED(')E;6]T92!D97!E;F1E;F-I97,@<F5T
M<FEE=F5D(&9R;VT@4D535"`M("<@+@T*("`@("`@("`@("`@("`@("`@("`G
M=&AI<R!S:&]U;&0@;F5V97(@:&%P<&5N)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'5R;%LG:6YF;R==6R=R97%U:7)E9"==
M*2!\?"`D=7)L6R=C;VUP871I8FQE)UTI('L-"B`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B`@("`@
M("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]086-K86=E1FEL95]V,CL-"B`@
M("`@("`@("`@("`@("`D<&8M/G-E=%)A=T-H86YN96PH)'!A<G);)V-H86YN
M96PG72D[#0H@("`@("`@("`@("`@("`@:68@*"1U<FQ;)V-O;7!A=&EB;&4G
M72D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/G-E=%)A=T-O;7!A=&EB
M;&4H)'5R;%LG8V]M<&%T:6)L92==*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]086-K86=E1FEL92]V,2YP:'`G.PT*("`@("`@("`@("`@
M("`@("1P9B`](&YE=R!014%27U!A8VMA9V5&:6QE7W8Q.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'!F+3YS971287=086-K86=E*"1U<FQ;)W!A
M8VMA9V4G72D[#0H@("`@("`@("`@("`D<&8M/G-E=$1E<',H)'5R;%LG:6YF
M;R==*3L-"B`@("`@("`@("`@("1P9BT^<V5T4F%W4W1A=&4H)'5R;%LG<W1A
M8FEL:71Y)UTI.PT*("`@("`@("`@("`@)'5R;%LG:6YF;R==(#T@)B1P9CL-
M"B`@("`@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@B>FQI8B(I('Q\
M(&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*("`@
M("`@("`@("`@("`@("1E>'0@/2`G+G1A<B<[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'5R;"DI('L-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'5R;%LG=7)L)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1U<FQ;)W5R;"==("X]("1E>'0[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N
M("1U<FP[#0H@("`@("`@('T@96QS96EF("@D8VAA;BT^<W5P<&]R=',H)WAM
M;')P8R<L("=P86-K86=E+F=E=$1O=VYL;V%D55),)RP@9F%L<V4L("<Q+C$G
M*2D@>PT*("`@("`@("`@("`@+R\@9&]N)W0@:6YS=&%L;"!W:71H('1H92!O
M;&0@=F5R<VEO;B!I;F9O<FUA=&EO;B!U;FQE<W,@=V4G<F4@9&]I;F<@82!P
M;&%I;@T*("`@("`@("`@("`@+R\@=F%N:6QL82!S:6UP;&4@:6YS=&%L;&%T
M:6]N+B`@268@=&AE('5S97(@<V%Y<R!T;R!I;G-T86QL(&$@<&%R=&EC=6QA
M<@T*("`@("`@("`@("`@+R\@=F5R<VEO;B!O<B!S=&%T92P@:6=N;W)E('1H
M92!C=7)R96YT(&EN<W1A;&QE9"!V97)S:6]N#0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P87)R6R=V97)S:6]N)UTI("8F("%I<W-E="@D<&%R<ELG<W1A
M=&4G72D@)B8@)'9E<G-I;VX-"B`@("`@("`@("`@("`@("`@("8F("%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@
M("`@("`@("`@("1U<FP@/2`D=&AI<RT^7W)E;6]T92T^8V%L;"@G<&%C:V%G
M92YG971$;W=N;&]A9%523"<L("1P87)R+"`D<W1A=&4L("1V97)S:6]N*3L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'5R;"`]
M("1T:&ES+3Y?<F5M;W1E+3YC86QL*"=P86-K86=E+F=E=$1O=VYL;V%D55),
M)RP@)'!A<G(L("1S=&%T92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D=7)L(#T@)'1H:7,M/E]R96UO=&4M/F-A
M;&PH)W!A8VMA9V4N9V5T1&]W;FQO86154DPG+"`D<&%R<BP@)'-T871E*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=7)L*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1P87)R6R=C:&%N;F5L)UT@(3T@)&-U<F-H86YN96PI('L-"B`@
M("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L
M("1C=7)C:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)'5R;%LG7U]014%27T524D]27T-,05-37U\G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"1U<FQ;)VUE<W-A9V4G72D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D=7)L*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@('T-"B`@("`@("`@)'5R
M;%LG<F%W)UT@/2`D=7)L6R=I;F9O)UT[#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@("`@
M("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G969I;&5/8FIE8W0H)'1H:7,M
M/F-O;F9I9RP@)'1H:7,M/F1E8G5G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5F:6QE3V)J96-T
M*"1T:&ES+3YC;VYF:6<L("1T:&ES+3YD96)U9RP-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^9V5T1&]W;FQO861$:7(H*2D[#0H@("`@("`@('T-"B`@("`@
M("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`D<&EN9F\@/2`F)'!K9RT^9G)O;5AM;%-T<FEN
M9R@D=7)L6R=I;F9O)UTL(%!%05)?5D%,241!5$5?1$]73DQ/041)3D<L("=R
M96UO=&4G*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&EN9F\I*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)'!I;F9O+3YG
M971-97-S86=E*"DI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U)E;6]T92!P86-K86=E+GAM;"!I<R!N
M;W0@=F%L:60@+2!T:&ES('-H;W5L9"!N979E<B!H87!P96XG*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=7)L6R=I;F9O)UT@/2`F)'!I;F9O.PT*("`@("`@
M("!I9B`H(65X=&5N<VEO;E]L;V%D960H(GIL:6(B*2!\?"!I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)VYO8V]M<')E<W,G72DI('L-"B`@("`@("`@("`@("1E
M>'0@/2`G+G1A<B<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M97AT(#T@)RYT9WHG.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<U]A<G)A
M>2@D=7)L*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1U<FQ;)W5R;"==
M*2D@>PT*("`@("`@("`@("`@("`@("1U<FQ;)W5R;"==("X]("1E>'0[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1U<FP[
M#0H@("`@?0T*("`@("\O('U]?0T*("`@("\O('M[>R!G971$97!086-K86=E
M1&]W;FQO8615<FPH*0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(&1E<&5N9&5N8WD@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T1&5P4&%C:V%G941O=VYL;V%D57)L
M*"1D97`L("1P87)R*0T*("`@('L-"B`@("`@("`@)'AS9'9E<G-I;VX@/2!I
M<W-E="@D9&5P6R=R96PG72D@/R`G,2XP)R`Z("<R+C`G.PT*("`@("`@("`D
M8W5R8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N
M;F5L)RD[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L)UTI*2![
M#0H@("`@("`@("`@("`D<F5M;W1E8VAA;FYE;"`]("1D97!;)V-H86YN96PG
M73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R96UO=&5C:&%N
M;F5L(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"$D=&AI<RT^7W)E9VES=')Y+3YC:&%N;F5L17AI<W1S*"1R96UO=&5C:&%N
M;F5L*2D@>PT*("`@("`@("`@("`@9&\@>PT*("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^8V]N9FEG+3YG970H)V%U=&]?9&ES8V]V97(G*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F1I<V-O=F5R*"1R96UO=&5C
M:&%N;F5L*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@
M<F5M;W1E(&-H86YN96PZ("<@+B`D<F5M;W1E8VAA;FYE;"D[#0H@("`@("`@
M("`@("!]('=H:6QE("AF86QS92D[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)')E;6]T96-H86YN
M96PI.PT*("`@("`@("`D<W1A=&4@/2!I<W-E="@D<&%R<ELG<W1A=&4G72D@
M/R`D<&%R<ELG<W1A=&4G72`Z("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R
M<F5D7W-T871E)RD[#0H@("`@("`@(&EF("AI<W-E="@D<&%R<ELG<W1A=&4G
M72D@)B8@:7-S970H)'!A<G);)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@
M('5N<V5T*"1P87)R6R=S=&%T92==*3L-"B`@("`@("`@?0T*("`@("`@("`D
M8VAA;B`]("8D=&AI<RT^7W)E9VES=')Y+3YG971#:&%N;F5L*"1R96UO=&5C
M:&%N;F5L*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![
M#0H@("`@("`@("`@("!R971U<FX@)&-H86X[#0H@("`@("`@('T-"B`@("`@
M("`@)'9E<G-I;VX@/2`D=&AI<RT^7W)E9VES=')Y+3YP86-K86=E26YF;R@D
M9&5P6R=N86UE)UTL("=V97)S:6]N)RP-"B`@("`@("`@("`@("1R96UO=&5C
M:&%N;F5L*3L-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@
M("`@("`@("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G
M+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-
M"B`@("`@("`@("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H
M)S$N,"<L("1T:&ES+3Y?;W!T:6]N<RD[#0H@("`@("`@("`@("`D=7)L(#T@
M)')E<W0M/F=E=$1E<$1O=VYL;V%D55),*"1B87-E+"`D>'-D=F5R<VEO;BP@
M)&1E<"P@)'!A<G(L#0H@("`@("`@("`@("`@("`@("`@("1S=&%T92P@)'9E
M<G-I;VXI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'5R;"DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@D<&%R<ELG8VAA;FYE;"==("$]("1C=7)C
M:&%N;F5L*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G
M9&5F875L=%]C:&%N;F5L)RP@)&-U<F-H86YN96PI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=7)L*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D=7)L.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)'5R;%LG<F%W)UT@/2!F86QS93L@+R\@;F\@8VAE8VMI;F<@:7,@
M;F5C97-S87)Y(&9O<B!215-4#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1U<FQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G26YV86QI9"!R96UO=&4@9&5P96YD96YC:65S(')E
M=')I979E9"!F<F]M(%)%4U0@+2`G("X-"B`@("`@("`@("`@("`@("`@("`@
M)W1H:7,@<VAO=6QD(&YE=F5R(&AA<'!E;B<I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1U<FQ;)VEN9F\G75LG<F5Q=6ER960G
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]086-K86=E1FEL95]V,B<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V,BYP:'`G.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]0
M86-K86=E1FEL95]V,CL-"B`@("`@("`@("`@("`@("`D<&8M/G-E=%)A=T-H
M86YN96PH)')E;6]T96-H86YN96PI.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K
M86=E1FEL95]V,2<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]086-K86=E1FEL92]V,2YP:'`G.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]086-K86=E
M1FEL95]V,3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P9BT^<V5T
M4F%W4&%C:V%G92@D=7)L6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@)'!F
M+3YS971$97!S*"1U<FQ;)VEN9F\G72D[#0H@("`@("`@("`@("`D<&8M/G-E
M=%)A=U-T871E*"1U<FQ;)W-T86)I;&ET>2==*3L-"B`@("`@("`@("`@("1U
M<FQ;)VEN9F\G72`]("8D<&8[#0H@("`@("`@("`@("!I9B`H(65X=&5N<VEO
M;E]L;V%D960H(GIL:6(B*2!\?"!I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO
M8V]M<')E<W,G72DI('L-"B`@("`@("`@("`@("`@("`D97AT(#T@)RYT87(G
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D97AT
M(#T@)RYT9WHG.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1U<FPI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1U
M<FQ;)W5R;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=7)L6R=U<FPG
M72`N/2`D97AT.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(')E='5R;B`D=7)L.PT*("`@("`@("!](&5L<V5I9B`H
M)&-H86XM/G-U<'!O<G1S*"=X;6QR<&,G+"`G<&%C:V%G92YG971$97!$;W=N
M;&]A9%523"<L(&9A;'-E+"`G,2XQ)RDI('L-"B`@("`@("`@("`@(&EF("@D
M=F5R<VEO;BD@>PT*("`@("`@("`@("`@("`@("1U<FP@/2`D=&AI<RT^7W)E
M;6]T92T^8V%L;"@G<&%C:V%G92YG971$97!$;W=N;&]A9%523"<L("1X<V1V
M97)S:6]N+"`D9&5P+"`D<&%R<BP-"B`@("`@("`@("`@("`@("`@("`@)'-T
M871E+"`D=F5R<VEO;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1U<FP@/2`D=&AI<RT^7W)E;6]T92T^8V%L;"@G<&%C:V%G
M92YG971$97!$;W=N;&]A9%523"<L("1X<V1V97)S:6]N+"`D9&5P+"`D<&%R
M<BP-"B`@("`@("`@("`@("`@("`@("`@)'-T871E*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1U<FP@/2`D=&AI
M<RT^7W)E;6]T92T^8V%L;"@G<&%C:V%G92YG971$97!$;W=N;&]A9%523"<L
M("1X<V1V97)S:6]N+"`D9&5P+"`D<&%R<BP@)'-T871E*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)'!A<G);)V-H86YN96PG72`A/2`D8W5R8VAA;FYE
M;"D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C
M:&%N;F5L)RP@)&-U<F-H86YN96PI.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A:7-?87)R87DH)'5R;"DI('L-"B`@("`@("`@("`@(')E='5R;B`D=7)L
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=7)L6R=?7U!%05)?
M15)23U)?0TQ!4U-?7R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)'5R;%LG;65S<V%G92==*3L-"B`@("`@("`@?0T*("`@
M("`@("`D=7)L6R=R87<G72`]("1U<FQ;)VEN9F\G73L-"B`@("`@("`@)'!K
M9R`]("8D=&AI<RT^9V5T4&%C:V%G969I;&5/8FIE8W0H)'1H:7,M/F-O;F9I
M9RP@)'1H:7,M/F1E8G5G*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D<&EN
M9F\@/2`F)'!K9RT^9G)O;5AM;%-T<FEN9R@D=7)L6R=I;F9O)UTL(%!%05)?
M5D%,241!5$5?1$]73DQ/041)3D<L("=R96UO=&4G*3L-"B`@("`@("`@4$5!
M4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<&EN9F\I*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,"P@)'!I;F9O+3YG971-97-S86=E*"DI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U)E;6]T92!P86-K86=E+GAM;"!I<R!N;W0@=F%L:60@+2!T:&ES('-H;W5L
M9"!N979E<B!H87!P96XG*3L-"B`@("`@("`@?0T*("`@("`@("`D=7)L6R=I
M;F9O)UT@/2`F)'!I;F9O.PT*("`@("`@("!I9B`H:7-?87)R87DH)'5R;"DI
M('L-"B`@("`@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@B>FQI8B(I
M('Q\(&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*
M("`@("`@("`@("`@("`@("1E>'0@/2`G+G1A<B<[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'5R;%LG=7)L)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'5R;%LG=7)L)UT@+CT@)&5X=#L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'5R;#L-
M"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=%!A8VMA9V5$;W=N
M;&]A9%5R;"@I#0H-"B`@("`O*BH-"B`@("`@*B!`9&5P<F5C871E9"!I;B!F
M879O<B!O9B!?9V5T4&%C:V%G941O=VYL;V%D57)L#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T4&%C:V%G941O=VYL;V%D57)L*"1P86-K86=E+"`D=F5R
M<VEO;B`](&YU;&PL("1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!I9B`H)'9E<G-I;VXI('L-"B`@("`@("`@("`@("1P86-K86=E("X]("(M
M)'9E<G-I;VXB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<R`]/3T@
M;G5L;"!\?"`D=&AI<RT^7W)E9VES=')Y(#T]/2!N=6QL*2![#0H@("`@("`@
M("`@("`D<&%C:V%G92`](")H='1P.B\O<&5A<BYP:'`N;F5T+V=E="\D<&%C
M:V%G92([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8VAA;B`]
M("1T:&ES+3Y?<F5G:7-T<GDM/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("<G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'!A8VMA9V4@/2`B:'1T<#HO+R(@+B`D8VAA;BT^9V5T4V5R=F5R*"D@
M+B`B+V=E="\D<&%C:V%G92([#0H@("`@("`@('T-"B`@("`@("`@:68@*"%E
M>'1E;G-I;VY?;&]A9&5D*")Z;&EB(BDI('L-"B`@("`@("`@("`@("1P86-K
M86=E("X]("<_=6YC;VUP<F5S<SUY97,G.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D<&%C:V%G93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9V5T1&]W;FQO861E9%!A8VMA9V5S*"D-"@T*("`@("\J*@T*("`@
M("`J(%)E=')I979E(&$@;&ES="!O9B!D;W=N;&]A9&5D('!A8VMA9V5S(&%F
M=&5R(&$@8V%L;"!T;R![0&QI;FL@9&]W;FQO860H*7TN#0H@("`@("H-"B`@
M("`@*B!!;'-O(')E<V5T<R!T:&4@;&ES="!O9B!D;W=N;&]A9&5D('!A8VMA
M9V5S+@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971$;W=N;&]A9&5D4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@
M)')E="`]("1T:&ES+3Y?9&]W;FQO861E9%!A8VMA9V5S.PT*("`@("`@("`D
M=&AI<RT^7V1O=VYL;V%D961086-K86=E<R`](&%R<F%Y*"D[#0H@("`@("`@
M("1T:&ES+3Y?=&]$;W=N;&]A9"`](&%R<F%Y*"D[#0H@("`@("`@(')E='5R
M;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?9&]W
M;FQO861#86QL8F%C:R@I#0H-"B`@("!F=6YC=&EO;B!?9&]W;FQO861#86QL
M8F%C:R@D;7-G+"`D<&%R86US(#T@;G5L;"D-"B`@("![#0H@("`@("`@('-W
M:71C:"`H)&US9RD@>PT*("`@("`@("`@("`@8V%S92`G<V%V96%S)SH-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L(")D;W=N;&]A9&EN9R`D<&%R
M86US("XN+B(I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92`G9&]N92<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q
M+"`G+BXN9&]N93H@)R`N(&YU;6)E<E]F;W)M870H)'!A<F%M<RP@,"P@)R<L
M("<L)RD@+B`G(&)Y=&5S)RD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=B>71E<W)E860G.@T*("`@("`@("`@("`@("`@
M('-T871I8R`D8GET97,[#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1B
M>71E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"$H)&)Y=&5S
M("4@,3`R-#`I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,2P@)RXG+"!F86QS92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1B>71E<R`K/2`D<&%R86US.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G<W1A<G0G.@T*("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H,2P@(E-T87)T:6YG('1O(&1O=VYL;V%D('LD<&%R
M86US6S!=?2`H(BYN=6UB97)?9F]R;6%T*"1P87)A;7-;,5TL(#`L("<G+"`G
M+"<I+B(@8GET97,I(BD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/G5I+"`G
M7V1O=VYL;V%D0V%L;&)A8VLG*2D-"B`@("`@("`@("`@("1T:&ES+3YU:2T^
M7V1O=VYL;V%D0V%L;&)A8VLH)&US9RP@)'!A<F%M<RD[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(%]P<F5P96YD4&%T:"@D<&%T:"P@)'!R
M97!E;F0I#0H-"B`@("!F=6YC=&EO;B!?<')E<&5N9%!A=&@H)'!A=&@L("1P
M<F5P96YD*0T*("`@('L-"B`@("`@("`@:68@*'-T<FQE;B@D<')E<&5N9"D@
M/B`P*2![#0H@("`@("`@("`@("!I9B`H3U-?5TE.1$]74R`F)B!P<F5G7VUA
M=&-H*"<O7EMA+7I=.B]I)RP@)'!A=&@I*2![#0H@("`@("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R]>6V$M>ETZ+VDG+"`D<')E<&5N9"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'!R97!E;F0@/2!S=6)S='(H)'!R97!E;F0L
M(#(I.PT*("`@("`@("`@("`@("`@('T@96QS96EF("@D<')E<&5N9'LP?2`A
M/2`G7%PG*2![#0H@("`@("`@("`@("`@("`@("`@("1P<F5P96YD(#T@(EQ<
M)'!R97!E;F0B.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D<&%T:"`]('-U8G-T<B@D<&%T:"P@,"P@,BD@+B`D<')E<&5N9"`N('-U
M8G-T<B@D<&%T:"P@,BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1P871H(#T@)'!R97!E;F0@+B`D<&%T:#L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'!A=&@[#0H@("`@
M?0T*("`@("\O('U]?0T*("`@("\O('M[>R!P=7-H17)R;W(H)&5R<FUS9RP@
M)&-O9&4I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@
M("H@0'!A<F%M(&EN=&5G97(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P=7-H
M17)R;W(H)&5R<FUS9RP@)&-O9&4@/2`M,2D-"B`@("![#0H@("`@("`@(&%R
M<F%Y7W!U<V@H)'1H:7,M/E]E<G)O<E-T86-K+"!A<G)A>2@D97)R;7-G+"`D
M8V]D92DI.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971%
M<G)O<DUS9W,H*0T*#0H@("`@9G5N8W1I;VX@9V5T17)R;W)-<V=S*"D-"B`@
M("![#0H@("`@("`@("1M<V=S(#T@87)R87DH*3L-"B`@("`@("`@)&5R<G,@
M/2`D=&AI<RT^7V5R<F]R4W1A8VL[#0H@("`@("`@(&9O<F5A8V@@*"1E<G)S
M(&%S("1E<G(I('L-"B`@("`@("`@("`@("1M<V=S6UT@/2`D97)R6S!=.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?97)R;W)3=&%C:R`](&%R<F%Y
M*"D[#0H@("`@("`@(')E='5R;B`D;7-G<SL-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"@T*("`@("\J*@T*("`@("`J(&9O<B!"0PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-O<G10:V=$97!S*"8D<&%C:V%G97,L("1U;FEN<W1A;&P@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1U;FEN<W1A;&P@/R`-"B`@("`@("`@
M("`@("1T:&ES+3YS;W)T4&%C:V%G97-&;W)5;FEN<W1A;&PH)'!A8VMA9V5S
M*2`Z#0H@("`@("`@("`@("`D=&AI<RT^<V]R=%!A8VMA9V5S1F]R26YS=&%L
M;"@D<&%C:V%G97,I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]G971$97!4
M<F5E1%`H)'!A8VMA9V4L("1P86-K86=E<RP@)B1D97!S+"`F)&-H96-K960I
M#0H@("`@>PT*("`@("`@("`D<&8@/2`D<&%C:V%G92T^9V5T4&%C:V%G949I
M;&4H*3L-"B`@("`@("`@)&-H96-K961;<W1R=&]L;W=E<B@D<&%C:V%G92T^
M9V5T0VAA;FYE;"@I*5U;<W1R=&]L;W=E<B@D<&%C:V%G92T^9V5T4&%C:V%G
M92@I*5T-"B`@("`@("`@("`@(#T@=')U93L-"B`@("`@("`@)'!D97!S(#T@
M)'!F+3YG971$97!S*'1R=64I.PT*("`@("`@("!I9B`H(21P9&5P<RD@>PT*
M("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<&8M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1P9&5P<R!A<R`D9&5P*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1D97!;)W1Y<&4G72`A/2`G<&MG)RD@>PT*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&1E<'-;)W!E87(N<&AP+FYE="==6W-T<G1O;&]W97(H
M)&1E<%LG;F%M92==*5T@/2!T<G5E.PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P86-K86=E<R!A<R`D<"D@>PT*("`@("`@("`@("`@("`@("`@("`D
M9&5P6R=C:&%N;F5L)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@
M("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'`M/FES17%U86PH)&1E<"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-H96-K961;<W1R
M=&]L;W=E<B@D<"T^9V5T0VAA;FYE;"@I*5T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%MS=')T;VQO=V5R*"1P+3YG971086-K86=E*"DI72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!A9&0@=&AE(&1E
M<&5N9&5N8WDG<R!D97!E;F1E;F-I97,@=&\@=&AE('1R964-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$1E<%1R965$4"@D<"P@
M)'!A8VMA9V5S+"`D9&5P<RP@)&-H96-K960I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)'1D97!S(#T@87)R87DH*3L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D<&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72DI('L-"B`@("`@
M("`@("`@("`@("`D="`]("1P9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==
M.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1;,%TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T(#T@87)R87DH)'0I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&1E<',@/2!A<G)A>5]M97)G92@D
M=&1E<',L("1T*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D<&1E<'-;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G72DI('L-"B`@
M("`@("`@("`@("`@("`D="`]("1P9&5P<ULG<F5Q=6ER960G75LG<W5B<&%C
M:V%G92==.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T(#T@87)R87DH)'0I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&1E<',@/2!A<G)A>5]M
M97)G92@D=&1E<',L("1T*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D<&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G72DI('L-
M"B`@("`@("`@("`@("`@("`D="`]("1P9&5P<ULG;W!T:6]N86PG75LG<&%C
M:V%G92==.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T(#T@87)R87DH)'0I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&1E<',@/2!A<G)A>5]M
M97)G92@D=&1E<',L("1T*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D<&1E<'-;)V]P=&EO;F%L)UU;)W-U8G!A8VMA9V4G72DI
M('L-"B`@("`@("`@("`@("`@("`D="`]("1P9&5P<ULG;W!T:6]N86PG75LG
M<W5B<&%C:V%G92==.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1;
M,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1T(#T@87)R87DH)'0I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&1E<',@/2!A
M<G)A>5]M97)G92@D=&1E<',L("1T*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D<&1E<'-;)V=R;W5P)UTI*2![#0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<&1E<'-;)V=R;W5P)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1P9&5P<ULG9W)O=7`G72`](&%R<F%Y*"1P
M9&5P<ULG9W)O=7`G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1P9&5P<ULG9W)O=7`G72!A<R`D9W)O=7`I('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LG<&%C:V%G
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'0@/2`D9W)O=7!;
M)W!A8VMA9V4G73L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'1;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'0@
M/2!A<G)A>2@D="D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&1E<',@/2!A<G)A>5]M97)G92@D=&1E
M<',L("1T*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&=R;W5P6R=S=6)P86-K86=E)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D="`]("1G<F]U<%LG<W5B<&%C:V%G
M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=%LP
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D="`](&%R<F%Y
M*"1T*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T9&5P<R`](&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)'1D97!S(&%S
M("1D97`I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;)V-H
M86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@
M/2`G7U]U<FDG.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@)&1E<%LG8VAA;FYE;"==.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D9&5P<ULD9&5P
M8VAA;FYE;%U;<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI72`]('1R=64[#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S("1P*2![#0H@
M("`@("`@("`@("`@("`@("`@("1D97!;)V-H86YN96PG72`]("1D97!C:&%N
M;F5L.PT*("`@("`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D
M9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<"T^:7-%
M<75A;"@D9&5P*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D8VAE8VME9%MS=')T;VQO=V5R*"1P+3YG971#:&%N;F5L*"DI70T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6W-T<G1O;&]W97(H)'`M
M/F=E=%!A8VMA9V4H*2E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(&%D9"!T:&4@9&5P96YD96YC>2=S(&1E<&5N9&5N8VEE<R!T;R!T
M:&4@=')E90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9V5T1&5P5')E9410*"1P+"`D<&%C:V%G97,L("1D97!S+"`D8VAE8VME9"D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3;W)T(&$@;&ES="!O
M9B!A<G)A>7,@;V8@87)R87DH9&]W;FQO861E9"!P86-K86=E9FEL96YA;64I
M(&)Y(&1E<&5N9&5N8WDN#0H@("`@("H-"B`@("`@*B!)="!A;'-O(')E;6]V
M97,@9'5P;&EC871E(&1E<&5N9&5N8VEE<PT*("`@("`J($!P87)A;2!A<G)A
M>2!A;B!A<G)A>2!O9B!D;W=N;&]A9&5D(%!%05)?1&]W;FQO861E<E]086-K
M86=E<PT*("`@("`J($!R971U<FX@87)R87D@87)R87D@;V8@87)R87DH<&%C
M:V%G969I;&5N86UE+"!P86-K86=E+GAM;"!C;VYT96YT<RD-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!S;W)T4&%C:V%G97-&;W));G-T86QL*"8D<&%C:V%G
M97,I#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D<&%C:V%G97,@87,@)&D@
M/3X@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("1C:&5C:V5D(#T@)&1E<',@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@)'1H:7,M/E]G971$97!4<F5E1%`H
M)'!A8VMA9V5S6R1I72P@)'!A8VMA9V5S+"`D9&5P<RP@)&-H96-K960I.PT*
M("`@("`@("`@("`@)'1H:7,M/E]D97!4<F5E6R1P86-K86=E+3YG971#:&%N
M;F5L*"E=6R1P86-K86=E+3YG971086-K86=E*"E=(#T@)&1E<',[#0H@("`@
M("`@('T-"B`@("`@("`@=7-O<G0H)'!A8VMA9V5S+"!A<G)A>2@F)'1H:7,L
M("=?<V]R=$EN<W1A;&PG*2D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1E
M<&5N9'-/;B@D82P@)&(I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M
M/E]C:&5C:T1E<%1R964H<W1R=&]L;W=E<B@D82T^9V5T0VAA;FYE;"@I*2P@
M<W1R=&]L;W=E<B@D82T^9V5T4&%C:V%G92@I*2P-"B`@("`@("`@("`@("1B
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?8VAE8VM$97!4<F5E*"1C:&%N
M;F5L+"`D<&%C:V%G92P@)&(L("1C:&5C:V5D(#T@87)R87DH*2D-"B`@("![
M#0H@("`@("`@("1C:&5C:V5D6R1C:&%N;F5L75LD<&%C:V%G95T@/2!T<G5E
M.PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?9&5P5')E95LD8VAA;FYE
M;%U;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<%1R965;
M)&-H86YN96Q=6R1P86-K86=E75MS=')T;VQO=V5R*"1B+3YG971#:&%N;F5L
M*"DI70T*("`@("`@("`@("`@("!;<W1R=&]L;W=E<B@D8BT^9V5T4&%C:V%G
M92@I*5TI*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1E<%1R965;)&-H86YN96Q=
M6R1P86-K86=E72!A<R`D8V@@/3X@)'!A8VMA9V5S*2![#0H@("`@("`@("`@
M("!F;W)E86-H("@D<&%C:V%G97,@87,@)'!A(#T^("1T<G5E*2![#0H@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?8VAE8VM$97!4<F5E*"1C:"P@)'!A
M+"`D8BP@)&-H96-K960I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7W-O<G1);G-T86QL*"1A+"`D8BD-"B`@("![#0H@("`@("`@
M(&EF("@A)&$M/F=E=$1E<',H*2`F)B`A)&(M/F=E=$1E<',H*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(#`[("\O(&YE:71H97(@<&%C:V%G92!H87,@9&5P
M96YD96YC:65S+"!O<F1E<B!I<R!I;G-I9VYI9FEC86YT#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1A+3YG971$97!S*"D@)B8@(21B+3YG971$97!S*"DI
M('L-"B`@("`@("`@("`@(')E='5R;B`Q.R`O+R`D82!M=7-T(&)E(&EN<W1A
M;&QE9"!A9G1E<B`D8B!B96-A=7-E("1A(&AA<R!D97!E;F1E;F-I97,-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(21A+3YG971$97!S*"D@)B8@)&(M/F=E
M=$1E<',H*2D@>PT*("`@("`@("`@("`@<F5T=7)N("TQ.R`O+R`D8B!M=7-T
M(&)E(&EN<W1A;&QE9"!A9G1E<B`D82!B96-A=7-E("1B(&AA<R!D97!E;F1E
M;F-I97,-"B`@("`@("`@?0T*("`@("`@("`O+R!B;W1H('!A8VMA9V5S(&AA
M=F4@9&5P96YD96YC:65S#0H@("`@("`@(&EF("@D=&AI<RT^7V1E<&5N9'-/
M;B@D82P@)&(I*2![#0H@("`@("`@("`@("!R971U<FX@,3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)'1H:7,M/E]D97!E;F1S3VXH)&(L("1A*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("TQ.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`P.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1O=VYL;V%D(&$@
M9FEL92!T:')O=6=H($A45%`N("!#;VYS:61E<G,@<W5G9V5S=&5D(&9I;&4@
M;F%M92!I;@T*("`@("`J($-O;G1E;G0M9&ES<&]S:71I;VXZ(&AE861E<B!A
M;F0@8V%N(')U;B!A(&-A;&QB86-K(&9U;F-T:6]N(&9O<@T*("`@("`J(&1I
M9F9E<F5N="!E=F5N=',N("!4:&4@8V%L;&)A8VL@=VEL;"!B92!C86QL960@
M=VET:"!T=V\-"B`@("`@*B!P87)A;65T97)S.B!T:&4@8V%L;&)A8VL@='EP
M92P@86YD('!A<F%M971E<G,N("!4:&4@:6UP;&5M96YT960-"B`@("`@*B!C
M86QL8F%C:R!T>7!E<R!A<F4Z#0H@("`@("H-"B`@("`@*B`@)W-E='5P)R`@
M("`@("!C86QL960@870@=&AE('9E<GD@8F5G:6YN:6YG+"!P87)A;65T97(@
M:7,@82!522!O8FIE8W0-"B`@("`@*B`@("`@("`@("`@("`@("!T:&%T('-H
M;W5L9"!B92!U<V5D(&9O<B!A;&P@;W5T<'5T#0H@("`@("H@("=M97-S86=E
M)R`@("`@=&AE('!A<F%M971E<B!I<R!A('-T<FEN9R!W:71H(&%N(&EN9F]R
M;6%T:6]N86P@;65S<V%G90T*("`@("`J("`G<V%V96%S)R`@("`@(&UA>2!B
M92!U<V5D('1O('-A=F4@=VET:"!A(&1I9F9E<F5N="!F:6QE(&YA;64L('1H
M90T*("`@("`J("`@("`@("`@("`@("`@('!A<F%M971E<B!I<R!T:&4@9FEL
M96YA;64@=&AA="!I<R!A8F]U="!T;R!B92!U<V5D+@T*("`@("`J("`@("`@
M("`@("`@("`@($EF(&$@)W-A=F5A<R<@8V%L;&)A8VL@<F5T=7)N<R!A(&YO
M;BUE;7!T>2!S=')I;F<L#0H@("`@("H@("`@("`@("`@("`@("`@=&AA="!F
M:6QE(&YA;64@=VEL;"!B92!U<V5D(&%S('1H92!F:6QE;F%M92!I;G-T96%D
M+@T*("`@("`J("`@("`@("`@("`@("`@($YO=&4@=&AA="`D<V%V95]D:7(@
M=VEL;"!N;W0@8F4@869F96-T960@8GD@=&AI<RP@;VYL>0T*("`@("`J("`@
M("`@("`@("`@("`@('1H92!B87-E;F%M92!O9B!T:&4@9FEL92X-"B`@("`@
M*B`@)W-T87)T)R`@("`@("!D;W=N;&]A9"!I<R!S=&%R=&EN9RP@<&%R86UE
M=&5R(&ES(&YU;6)E<B!O9B!B>71E<PT*("`@("`J("`@("`@("`@("`@("`@
M('1H870@87)E(&5X<&5C=&5D+"!O<B`M,2!I9B!U;FMN;W=N#0H@("`@("H@
M("=B>71E<W)E860G("`@<&%R86UE=&5R(&ES('1H92!N=6UB97(@;V8@8GET
M97,@<F5A9"!S;R!F87(-"B`@("`@*B`@)V1O;F4G("`@("`@("!D;W=N;&]A
M9"!I<R!C;VUP;&5T92P@<&%R86UE=&5R(&ES('1H92!T;W1A;"!N=6UB97(-
M"B`@("`@*B`@("`@("`@("`@("`@("!O9B!B>71E<R!R96%D#0H@("`@("H@
M("=C;VYN9F%I;&5D)R`@:68@=&AE(%1#4"]34TP@8V]N;F5C=&EO;B!F86EL
M<RP@=&AI<R!C86QL8F%C:R!I<R!C86QL960-"B`@("`@*B`@("`@("`@("`@
M("`@("!W:71H(&%R<F%Y*&AO<W0L<&]R="QE<G)N;RQE<G)M<V<I#0H@("`@
M("H@("=W<FET969A:6QE9"<@:68@=W)I=&EN9R!T;R!D:7-K(&9A:6QS+"!T
M:&ES(&-A;&QB86-K(&ES(&-A;&QE9`T*("`@("`J("`@("`@("`@("`@("`@
M('=I=&@@87)R87DH9&5S=&9I;&4L97)R;7-G*0T*("`@("`J#0H@("`@("H@
M268@86X@2%144"!P<F]X>2!H87,@8F5E;B!C;VYF:6=U<F5D("AH='1P7W!R
M;WAY(%!%05)?0V]N9FEG#0H@("`@("H@<V5T=&EN9RDL('1H92!P<F]X>2!W
M:6QL(&)E('5S960N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M=7)L("`@("`@('1H92!54DP@=&\@9&]W;FQO860-"B`@("`@*B!`<&%R86T@
M;V)J96-T("`D=6D@("`@("`@(%!%05)?1G)O;G1E;F1?*B!I;G-T86YC90T*
M("`@("`J($!P87)A;2!O8FIE8W0@("1C;VYF:6<@("`@4$5!4E]#;VYF:6<@
M:6YS=&%N8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V%V95]D:7(@(&1I
M<F5C=&]R>2!T;R!S879E(&9I;&4@:6X-"B`@("`@*B!`<&%R86T@;6EX960@
M("`D8V%L;&)A8VL@(&9U;F-T:6]N+VUE=&AO9"!T;R!C86QL(&9O<B!S=&%T
M=7,-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('5P9&%T97,-
M"B`@("`@*B!`<&%R86T@9F%L<V5\<W1R:6YG?&%R<F%Y("1L87-T;6]D:69I
M960@:&5A9&5R('9A;'5E<R!T;R!C:&5C:R!A9V%I;G-T(&9O<B!C86-H:6YG
M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!U<V4@9F%L<V4@
M=&\@<F5T=7)N('1H92!H96%D97(@=F%L=65S(&9R;VT@=&AI<R!D;W=N;&]A
M9`T*("`@("`J($!P87)A;2!F86QS97QA<G)A>2`D86-C97!T($%C8V5P="!H
M96%D97)S('1O('-E;F0-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQA<G)A>2`@
M4F5T=7)N<R!T:&4@9G5L;"!P871H(&]F('1H92!D;W=N;&]A9&5D(&9I;&4@
M;W(@82!014%2#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5R<F]R
M(&]N(&9A:6QU<F4N("!)9B!T:&4@97)R;W(@:7,@8V%U<V5D(&)Y#0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@('-O8VME="UR96QA=&5D(&5R<F]R
M<RP@=&AE(&5R<F]R(&]B:F5C="!W:6QL#0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&AA=F4@=&AE(&9S;V-K;W!E;B!E<G)O<B!C;V1E(&%V86EL
M86)L92!T:')O=6=H#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&=E
M=$-O9&4H*2X@($EF(&-A8VAI;F<@:7,@<F5Q=65S=&5D+"!T:&5N(')E='5R
M;B!T:&4@:&5A9&5R#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('9A
M;'5E<RX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9&]W;FQO861(='1P*"1U<FPL("8D=6DL("1S879E
M7V1I<B`]("<N)RP@)&-A;&QB86-K(#T@;G5L;"P@)&QA<W1M;V1I9FEE9"`]
M(&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1A8V-E<'0@/2!F
M86QS92D-"B`@("![#0H@("`@("`@('-T871I8R`D<F5D:7)E8W0@/2`P.PT*
M("`@("`@("`O+R!A;&QW87ES(')E<V5T("P@<V\@=V4@87)E(&-L96%N(&-A
M<V4@;V8@97)R;W(-"B`@("`@("`@)'=A<W)E9&ER96-T(#T@)')E9&ER96-T
M.PT*("`@("`@("`D<F5D:7)E8W0@/2`P.PT*("`@("`@("!I9B`H)&-A;&QB
M86-K*2![#0H@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL
M("=S971U<"<L(&%R<F%Y*"8D=6DI*3L-"B`@("`@("`@?0T*("`@("`@("`D
M:6YF;R`]('!A<G-E7W5R;"@D=7)L*3L-"B`@("`@("`@:68@*"%I<W-E="@D
M:6YF;ULG<V-H96UE)UTI('Q\("%I;E]A<G)A>2@D:6YF;ULG<V-H96UE)UTL
M(&%R<F%Y*"=H='1P)RP@)VAT='!S)RDI*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V%N;F]T(&1O=VYL;V%D(&YO;BUH='1P
M(%523"`B)R`N("1U<FP@+B`G(B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A:7-S970H)&EN9F];)VAO<W0G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=#86YN;W0@9&]W;FQO860@9G)O;2!N;VXM
M55),("(G("X@)'5R;"`N("<B)RD[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D:&]S="`]($`D:6YF;ULG:&]S="==.PT*("`@("`@("`@("`@
M)'!O<G0@/2!`)&EN9F];)W!O<G0G73L-"B`@("`@("`@("`@("1P871H(#T@
M0"1I;F9O6R=P871H)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES*2D@>PT*("`@("`@("`@("`@)&-O;F9I9R`]("8D=&AI<RT^8V]N
M9FEG.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-O;F9I9R`]
M("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@('T-"B`@("`@
M("`@)'!R;WAY7VAO<W0@/2`D<')O>'E?<&]R="`]("1P<F]X>5]U<V5R(#T@
M)'!R;WAY7W!A<W,@/2`G)SL-"B`@("`@("`@:68@*"1C;VYF:6<M/F=E="@G
M:'1T<%]P<F]X>2<I)B8@#0H@("`@("`@("`@("`@("1P<F]X>2`]('!A<G-E
M7W5R;"@D8V]N9FEG+3YG970H)VAT='!?<')O>'DG*2DI('L-"B`@("`@("`@
M("`@("1P<F]X>5]H;W-T(#T@0"1P<F]X>5LG:&]S="==.PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1P<F]X>5LG<V-H96UE)UTI("8F("1P<F]X>5LG<V-H
M96UE)UT@/3T@)VAT='!S)RD@>PT*("`@("`@("`@("`@("`@("1P<F]X>5]H
M;W-T(#T@)W-S;#HO+R<@+B`D<')O>'E?:&]S=#L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1P<F]X>5]P;W)T(#T@0"1P<F]X>5LG<&]R="==.PT*
M("`@("`@("`@("`@)'!R;WAY7W5S97(@/2!`)'!R;WAY6R=U<V5R)UT[#0H@
M("`@("`@("`@("`D<')O>'E?<&%S<R`]($`D<')O>'E;)W!A<W,G73L-"@T*
M("`@("`@("`@("`@:68@*"1P<F]X>5]P;W)T(#T]("<G*2![#0H@("`@("`@
M("`@("`@("`@)'!R;WAY7W!O<G0@/2`X,#@P.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@
M(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)VUE<W-A9V4G+"`B57-I;F<@
M2%144"!P<F]X>2`D:&]S=#HD<&]R="(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D<&]R="DI('L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D:6YF;ULG<V-H96UE)UTI("8F("1I;F9O6R=S8VAE
M;64G72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@("`@("`@)'!O<G0@/2`T
M-#,[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1P
M;W)T(#T@.#`[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1P<F]X>5]H;W-T("$]("<G*2![#0H@("`@("`@("`@("`D9G`@/2!`
M9G-O8VMO<&5N*"1P<F]X>5]H;W-T+"`D<')O>'E?<&]R="P@)&5R<FYO+"`D
M97)R<W1R*3L-"B`@("`@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=C;VYN9F%I;&5D)RP@87)R87DH
M)'!R;WAY7VAO<W0L("1P<F]X>5]P;W)T+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5R<FYO+"`D97)R<W1R*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYN96-T
M:6]N('1O(&`D<')O>'E?:&]S=#HD<')O>'E?<&]R="<@9F%I;&5D.B`D97)R
M<W1R(BP@)&5R<FYO*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@D;&%S=&UO9&EF:65D(#T]/2!F86QS92!\?"`D;&%S=&UO9&EF:65D*2![
M#0H@("`@("`@("`@("`@("`@)')E<75E<W0@/2`B1T54("1U<FP@2%144"\Q
M+C%<<EQN(CL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)')E<75E<W0@/2`B1T54("1U<FP@2%144"\Q+C!<<EQN(CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D:6YF;ULG<V-H96UE)UTI("8F("1I;F9O6R=S8VAE;64G72`]/2`G
M:'1T<',G*2![#0H@("`@("`@("`@("`@("`@)&AO<W0@/2`G<W-L.B\O)R`N
M("1H;W-T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&9P(#T@0&9S
M;V-K;W!E;B@D:&]S="P@)'!O<G0L("1E<G)N;RP@)&5R<G-T<BD[#0H@("`@
M("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@(&EF("@D8V%L
M;&)A8VLI('L-"B`@("`@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H
M)&-A;&QB86-K+"`G8V]N;F9A:6QE9"<L(&%R<F%Y*"1H;W-T+"`D<&]R="P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G)N;RP@)&5R<G-T<BDI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B0V]N;F5C=&EO;B!T;R!@)&AO<W0Z)'!O<G0G(&9A:6QE
M9#H@)&5R<G-T<B(L("1E<G)N;RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H)&QA<W1M;V1I9FEE9"`]/3T@9F%L<V4@?'P@)&QA<W1M;V1I
M9FEE9"D@>PT*("`@("`@("`@("`@("`@("1R97%U97-T(#T@(D=%5"`D<&%T
M:"!(5%10+S$N,5QR7&XB.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D<F5Q=65S="`](")'150@)'!A=&@@2%144"\Q+C!<<EQN
M(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D:69M;V1I
M9FEE9'-I;F-E(#T@)R<[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D;&%S=&UO
M9&EF:65D*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1L87-T;6]D:69I
M961;)TQA<W0M36]D:69I960G72DI('L-"B`@("`@("`@("`@("`@("`D:69M
M;V1I9FEE9'-I;F-E(#T@)TEF+4UO9&EF:65D+5-I;F-E.B`G("X@)&QA<W1M
M;V1I9FEE9%LG3&%S="U-;V1I9FEE9"==("X@(EQR7&XB.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1L87-T;6]D:69I961;)T54
M86<G72DI('L-"B`@("`@("`@("`@("`@("`D:69M;V1I9FEE9'-I;F-E("X]
M("))9BU.;VYE+4UA=&-H.B`D;&%S=&UO9&EF:65D6T5486==7')<;B([#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M:69M;V1I9FEE9'-I;F-E(#T@*"1L87-T;6]D:69I960@/R`B268M36]D:69I
M960M4VEN8V4Z("1L87-T;6]D:69I961<<EQN(B`Z("<G*3L-"B`@("`@("`@
M?0T*("`@("`@("`D<F5Q=65S="`N/2`B2&]S=#H@)&AO<W0Z)'!O<G1<<EQN
M(B`N("1I9FUO9&EF:65D<VEN8V4@+@T*("`@("`@("`@("`@(E5S97(M06=E
M;G0Z(%!%05(O,2XT+CDO4$A0+R(@+B!02%!?5D524TE/3B`N(")<<EQN(CL-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2D@>R`O+R!O;FQY('!A<W,@:6X@
M875T:&5N=&EC871I;VX@9F]R(&YO;BUS=&%T:6,@8V%L;',-"B`@("`@("`@
M("`@("1U<V5R;F%M92`]("1C;VYF:6<M/F=E="@G=7-E<FYA;64G*3L-"B`@
M("`@("`@("`@("1P87-S=V]R9"`]("1C;VYF:6<M/F=E="@G<&%S<W=O<F0G
M*3L-"B`@("`@("`@("`@(&EF("@D=7-E<FYA;64@)B8@)'!A<W-W;W)D*2![
M#0H@("`@("`@("`@("`@("`@)'1M<"`](&)A<V4V-%]E;F-O9&4H(B1U<V5R
M;F%M93HD<&%S<W=O<F0B*3L-"B`@("`@("`@("`@("`@("`D<F5Q=65S="`N
M/2`B075T:&]R:7IA=&EO;CH@0F%S:6,@)'1M<%QR7&XB.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D<')O>'E?:&]S="`A/2`G
M)R`F)B`D<')O>'E?=7-E<B`A/2`G)RD@>PT*("`@("`@("`@("`@)')E<75E
M<W0@+CT@)U!R;WAY+4%U=&AO<FEZ871I;VXZ($)A<VEC("<@+@T*("`@("`@
M("`@("`@("`@(&)A<V4V-%]E;F-O9&4H)'!R;WAY7W5S97(@+B`G.B<@+B`D
M<')O>'E?<&%S<RD@+B`B7')<;B([#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1A8V-E<'0I('L-"B`@("`@("`@("`@("1R97%U97-T("X]("=!8V-E<'0Z
M("<@+B!I;7!L;V1E*"<L("<L("1A8V-E<'0I("X@(EQR7&XB.PT*("`@("`@
M("!]#0H@("`@("`@("1R97%U97-T("X](")#;VYN96-T:6]N.B!C;&]S95QR
M7&XB.PT*("`@("`@("`D<F5Q=65S="`N/2`B7')<;B([#0H@("`@("`@(&9W
M<FET92@D9G`L("1R97%U97-T*3L-"B`@("`@("`@)&AE861E<G,@/2!A<G)A
M>2@I.PT*("`@("`@("`D<F5P;'D@/2`P.PT*("`@("`@("!W:&EL92`H=')I
M;2@D;&EN92`](&9G971S*"1F<"P@,3`R-"DI*2![#0H@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@G+UXH6UXZ72LI.EQS*R@N*BE<<RHD+R<L("1L:6YE
M+"`D;6%T8VAE<RDI('L-"B`@("`@("`@("`@("`@("`D:&5A9&5R<UMS=')T
M;VQO=V5R*"1M871C:&5S6S%=*5T@/2!T<FEM*"1M871C:&5S6S)=*3L-"B`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\7DA45%`O,2Y;,#%=
M("A;,"TY77LS?2D@?"<L("1L:6YE+"`D;6%T8VAE<RDI('L-"B`@("`@("`@
M("`@("`@("`D<F5P;'D@/2`H:6YT*2`D;6%T8VAE<ULQ73L-"B`@("`@("`@
M("`@("`@("!I9B`H)')E<&QY(#T](#,P-"`F)B`H)&QA<W1M;V1I9FEE9"!\
M?"`H)&QA<W1M;V1I9FEE9"`]/3T@9F%L<V4I*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("@A(&EN7V%R<F%Y*"1R97!L>2P@87)R87DH,C`P
M+"`S,#$L(#,P,BP@,S`S+"`S,#4L(#,P-RDI*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&:6QE(&AT='`Z+R\D
M:&]S=#HD<&]R="1P871H(&YO="!V86QI9"`H<F5C96EV960Z("1L:6YE*2(I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)')E<&QY("$](#(P,"D@>PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1H96%D97)S6R=L;V-A=&EO;B==*2D@>PT*("`@("`@("`@
M("`@("`@(&EF("@D=V%S<F5D:7)E8W0@/"`U*2![#0H@("`@("`@("`@("`@
M("`@("`@("1R961I<F5C="`]("1W87-R961I<F5C="`K(#$[#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&]W;FQO861(='1P*"1H96%D
M97)S6R=L;V-A=&EO;B==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U:2P@)'-A=F5?9&ER+"`D8V%L;&)A8VLL("1L87-T;6]D:69I960L("1A
M8V-E<'0I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&:6QE(&AT='`Z
M+R\D:&]S=#HD<&]R="1P871H(&YO="!V86QI9"`H<F5D:7)E8W1I;VX@;&]O
M<&5D(&UO<F4@=&AA;B`U('1I;65S*2(I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(D9I;&4@:'1T<#HO+R1H;W-T.B1P;W)T)'!A
M=&@@;F]T('9A;&ED("AR961I<F5C=&5D(&)U="!N;R!L;V-A=&EO;BDB*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&AE861E<G-;)V-O;G1E;G0M9&ES<&]S:71I;VXG72D@)B8-"B`@("`@("`@
M("`@('!R96=?;6%T8V@H)R]<<V9I;&5N86UE/5PB*%M>.UTJ7%,I7")<<RHH
M.WPD*2\G+"`D:&5A9&5R<ULG8V]N=&5N="UD:7-P;W-I=&EO;B==+"`D;6%T
M8VAE<RDI('L-"B`@("`@("`@("`@("1S879E7V%S(#T@8F%S96YA;64H)&UA
M=&-H97-;,5TI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'-A
M=F5?87,@/2!B87-E;F%M92@D=7)L*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@("`D=&UP(#T@8V%L;%]U<V5R
M7V9U;F,H)&-A;&QB86-K+"`G<V%V96%S)RP@)'-A=F5?87,I.PT*("`@("`@
M("`@("`@:68@*"1T;7`I('L-"B`@("`@("`@("`@("`@("`D<V%V95]A<R`]
M("1T;7`[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&1E
M<W1?9FEL92`]("1S879E7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`D
M<V%V95]A<SL-"B`@("`@("`@:68@*"$D=W`@/2!`9F]P96XH)&1E<W1?9FEL
M92P@)W=B)RDI('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@
M("`@("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@(&-A;&Q?
M=7-E<E]F=6YC*"1C86QL8F%C:RP@)W=R:71E9F%I;&5D)RP@87)R87DH)&1E
M<W1?9FEL92P@)'!H<%]E<G)O<FUS9RDI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(F-O=6QD(&YO="!O
M<&5N("1D97-T7V9I;&4@9F]R('=R:71I;F<B*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&AE861E<G-;)V-O;G1E;G0M;&5N9W1H)UTI*2![
M#0H@("`@("`@("`@("`D;&5N9W1H(#T@)&AE861E<G-;)V-O;G1E;G0M;&5N
M9W1H)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;&5N9W1H
M(#T@+3$[#0H@("`@("`@('T-"B`@("`@("`@)&)Y=&5S(#T@,#L-"B`@("`@
M("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@8V%L;%]U<V5R7V9U
M;F,H)&-A;&QB86-K+"`G<W1A<G0G+"!A<G)A>2AB87-E;F%M92@D9&5S=%]F
M:6QE*2P@)&QE;F=T:"DI.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE("@D
M9&%T82`]($!F<F5A9"@D9G`L(#$P,C0I*2![#0H@("`@("`@("`@("`D8GET
M97,@*ST@<W1R;&5N*"1D871A*3L-"B`@("`@("`@("`@(&EF("@D8V%L;&)A
M8VLI('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D8V%L;&)A
M8VLL("=B>71E<W)E860G+"`D8GET97,I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"%`9G=R:71E*"1W<"P@)&1A=&$I*2![#0H@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@:68@*"1C
M86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N
M8R@D8V%L;&)A8VLL("=W<FET969A:6QE9"<L(&%R<F%Y*"1D97-T7V9I;&4L
M("1P:'!?97)R;W)M<V<I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(B1D97-T7V9I;&4Z
M('=R:71E(&9A:6QE9"`H)'!H<%]E<G)O<FUS9RDB*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M9F-L;W-E*"1W<"D[#0H@("`@("`@(&EF("@D8V%L;&)A8VLI('L-"B`@("`@
M("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)V1O;F4G+"`D8GET
M97,I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;&%S=&UO9&EF:65D(#T]
M/2!F86QS92!\?"`D;&%S=&UO9&EF:65D*2![#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&AE861E<G-;)V5T86<G72DI('L-"B`@("`@("`@("`@("`@("`D
M;&%S=&UO9&EF:65D(#T@87)R87DH)T5486<G(#T^("1H96%D97)S6R=E=&%G
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1H
M96%D97)S6R=L87-T+6UO9&EF:65D)UTI*2![#0H@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1L87-T;6]D:69I960I*2![#0H@("`@("`@("`@("`@
M("`@("`@("1L87-T;6]D:69I961;)TQA<W0M36]D:69I960G72`]("1H96%D
M97)S6R=L87-T+6UO9&EF:65D)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9"`]("1H96%D
M97)S6R=L87-T+6UO9&EF:65D)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1D97-T7V9I
M;&4L("1L87-T;6]D:69I960L("1H96%D97)S*3L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)&1E<W1?9FEL93L-"B`@("!]#0I]#0HO+R!]?7T-"@T*
M/SX-"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O17)R;W)3=&%C:RYP:'``````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,3`S-C$S`#$P-3$U-#,Q,#4W`#`R,#8V-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!%<G)O<B!3=&%C:R!);7!L96UE;G1A=&EO;@T*("H@#0H@
M*B!4:&ES(&ES(&%N(&EN8W)E9&EB;'D@<VEM<&QE(&EM<&QE;65N=&%T:6]N
M(&]F(&$@=F5R>2!C;VUP;&5X(&5R<F]R(&AA;F1L:6YG#0H@*B!F86-I;&ET
M>2X@($ET(&-O;G1A:6YS('1H92!A8FEL:71Y#0H@*B!T;R!T<F%C:R!M=6QT
M:7!L92!E<G)O<G,@9G)O;2!M=6QT:7!L92!P86-K86=E<R!S:6UU;'1A;F5O
M=7-L>2X@($EN(&%D9&ET:6]N+`T*("H@:70@8V%N('1R86-K(&5R<F]R<R!O
M9B!M86YY(&QE=F5L<RP@<V%V92!D871A(&%L;VYG('=I=&@@=&AE(&5R<F]R
M+"!C;VYT97AT#0H@*B!I;F9O<FUA=&EO;B!S=6-H(&%S('1H92!E>&%C="!F
M:6QE+"!L:6YE(&YU;6)E<BP@8VQA<W,@86YD(&9U;F-T:6]N('1H870-"B`J
M(&=E;F5R871E9"!T:&4@97)R;W(L(&%N9"!I9B!N96-E<W-A<GDL(&ET(&-A
M;B!R86ES92!A('1R861I=&EO;F%L(%!%05)?17)R;W(N#0H@*B!)="!H87,@
M8G5I;'0M:6X@<W5P<&]R="!F;W(@4$5!4CHZ3&]G+"!T;R!L;V<@97)R;W)S
M(&%S('1H97D@;V-C=7(-"B`J(`T*("H@4VEN8V4@=F5R<VEO;B`P+C)A;'!H
M82P@:70@:7,@86QS;R!P;W-S:6)L92!T;R!S96QE8W1I=F5L>2!I9VYO<F4@
M97)R;W)S+`T*("H@=&AR;W5G:"!T:&4@=7-E(&]F(&%N(&5R<F]R(&-A;&QB
M86-K+"!S964@>T!L:6YK('!U<VA#86QL8F%C:R@I?0T*("H@#0H@*B!3:6YC
M92!V97)S:6]N(#`N,V%L<&AA+"!I="!I<R!P;W-S:6)L92!T;R!S<&5C:69Y
M('1H92!E>&-E<'1I;VX@8VQA<W,-"B`J(')E='5R;F5D(&9R;VT@>T!L:6YK
M('!U<V@H*7T-"B`J#0H@*B!3:6YC92!V97)S:6]N(%!%05(Q+C,N,BP@17)R
M;W)3=&%C:R!N;R!L;VYG97(@:6YS=&%N=&EA=&5S(&%N(&5X8V5P=&EO;B!C
M;&%S<RX@(%1H:7,@8V%N#0H@*B!S=&EL;"!B92!D;VYE('%U:71E(&AA;F1I
M;'D@:6X@86X@97)R;W(@8V%L;&)A8VL@;W(@8GD@;6%N:7!U;&%T:6YG('1H
M92!R971U<FYE9"!A<G)A>0T*("H@0&-A=&5G;W)Y("`@1&5B=6=G:6YG#0H@
M*B!`<&%C:V%G92`@("!014%27T5R<F]R4W1A8VL-"B`J($!A=71H;W(@("`@
M($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@
M(#(P,#0M,C`P-B!'<F5G($)E879E<@T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@17)R;W)3=&%C:RYP:'`L=B`Q
M+C(R(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4E]%<G)O
M<E-T86-K#0H@*B\-"@T*+RHJ#0H@*B!3:6YG;&5T;VX@<W1O<F%G90T*("H@
M#0H@*B!&;W)M870Z#0H@*B`\<')E/@T*("H@87)R87DH#0H@*B`@)W!A8VMA
M9V4Q)R`]/B!014%27T5R<F]R4W1A8VL@;V)J96-T+`T*("H@("=P86-K86=E
M,B<@/3X@4$5!4E]%<G)O<E-T86-K(&]B:F5C="P-"B`J("`N+BX-"B`J("D-
M"B`J(#PO<')E/@T*("H@0&%C8V5S<R!P<FEV871E#0H@*B!`9VQO8F%L(&%R
M<F%Y("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)3D=,151/3B==#0H@
M*B\-"B1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)3D=,151/3B==(#T@
M87)R87DH*3L-"@T*+RHJ#0H@*B!';&]B86P@97)R;W(@8V%L;&)A8VL@*&1E
M9F%U;'0I#0H@*B`-"B`J(%1H:7,@:7,@;VYL>2!U<V5D(&EF('-E="!T;R!N
M;VXM9F%L<V4N("`J(&ES('1H92!D969A=6QT(&-A;&QB86-K(&9O<@T*("H@
M86QL('!A8VMA9V5S+"!W:&5R96%S('-P96-I9FEC('!A8VMA9V5S(&UA>2!S
M970@82!D969A=6QT(&-A;&QB86-K#0H@*B!F;W(@86QL(&EN<W1A;F-E<RP@
M<F5G87)D;&5S<R!O9B!W:&5T:&5R('1H97D@87)E(&$@<VEN9VQE=&]N(&]R
M(&YO="X-"B`J#0H@*B!4;R!E>&-L=61E(&YO;BUS:6YG;&5T;VYS+"!O;FQY
M('-E="!T:&4@;&]C86P@8V%L;&)A8VL@9F]R('1H92!S:6YG;&5T;VX-"B`J
M($!S964@4$5!4E]%<G)O<E-T86-K.CIS971$969A=6QT0V%L;&)A8VLH*0T*
M("H@0&%C8V5S<R!P<FEV871E#0H@*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q3
M6R=?4$5!4E]%4E)/4E-404-+7T1%1D%53%1?0T%,3$)!0TLG70T*("HO#0HD
M1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$149!54Q47T-!3$Q"04-+)UT@
M/2!A<G)A>2@-"B`@("`G*B<@/3X@9F%L<V4L#0HI.PT*#0HO*BH-"B`J($=L
M;V)A;"!,;V<@;V)J96-T("AD969A=6QT*0T*("H@#0H@*B!4:&ES(&ES(&]N
M;'D@=7-E9"!I9B!S970@=&\@;F]N+69A;'-E+B`@57-E('1O('-E="!A(&1E
M9F%U;'0@;&]G(&]B:F5C="!F;W(-"B`J(&%L;"!S=&%C:W,L(')E9V%R9&QE
M<W,@;V8@:6YS=&%N=&EA=&EO;B!O<F1E<B!O<B!L;V-A=&EO;@T*("H@0'-E
M92!014%27T5R<F]R4W1A8VLZ.G-E=$1E9F%U;'1,;V=G97(H*0T*("H@0&%C
M8V5S<R!P<FEV871E#0H@*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q36R=?4$5!
M4E]%4E)/4E-404-+7T1%1D%53%1?3$]'1T52)UT-"B`J+PT*)$=,3T)!3%-;
M)U]014%27T524D]24U1!0TM?1$5&055,5%],3T='15(G72`](&9A;'-E.PT*
M#0HO*BH-"B`J($=L;V)A;"!/=F5R<FED:6YG($-A;&QB86-K#0H@*B`-"B`J
M(%1H:7,@8V%L;&)A8VL@=VEL;"!O=F5R<FED92!A;GD@97)R;W(@8V%L;&)A
M8VMS('1H870@<W!E8VEF:6,@;&]G9V5R<R!H879E('-E="X-"B`J(%5S92!W
M:71H($585%)%344@8V%U=&EO;@T*("H@0'-E92!014%27T5R<F]R4W1A8VLZ
M.G-T871I8U!U<VA#86QL8F%C:R@I#0H@*B!`86-C97-S('!R:79A=&4-"B`J
M($!G;&]B86P@87)R87D@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?1$5&
M055,5%],3T='15(G70T*("HO#0HD1TQ/0D%,4ULG7U!%05)?15)23U)35$%#
M2U]/5D524DE$15]#04Q,0D%#2R==(#T@87)R87DH*3L-"@T*+RHJ(T`K#0H@
M*B!/;F4@;V8@9F]U<B!P;W-S:6)L92!R971U<FX@=F%L=65S(&9R;VT@=&AE
M(&5R<F]R($-A;&QB86-K#0H@*B!`<V5E(%!%05)?17)R;W)3=&%C:SHZ7V5R
M<F]R0V%L;&)A8VLH*0T*("HO#0HO*BH-"B`J($EF('1H:7,@:7,@<F5T=7)N
M960L('1H96X@=&AE(&5R<F]R('=I;&P@8F4@8F]T:"!P=7-H960@;VYT;R!T
M:&4@<W1A8VL-"B`J(&%N9"!L;V=G960N#0H@*B\-"F1E9FEN92@G4$5!4E]%
M4E)/4E-404-+7U!54TA!3D1,3T<G+"`Q*3L-"B\J*@T*("H@268@=&AI<R!I
M<R!R971U<FYE9"P@=&AE;B!T:&4@97)R;W(@=VEL;"!O;FQY(&)E('!U<VAE
M9"!O;G1O('1H92!S=&%C:RP-"B`J(&%N9"!N;W0@;&]G9V5D+@T*("HO#0ID
M969I;F4H)U!%05)?15)23U)35$%#2U]055-()RP@,BD[#0HO*BH-"B`J($EF
M('1H:7,@:7,@<F5T=7)N960L('1H96X@=&AE(&5R<F]R('=I;&P@;VYL>2!B
M92!L;V=G960L(&)U="!N;W0@<'5S:&5D#0H@*B!O;G1O('1H92!E<G)O<B!S
M=&%C:RX-"B`J+PT*9&5F:6YE*"=014%27T524D]24U1!0TM?3$]')RP@,RD[
M#0HO*BH-"B`J($EF('1H:7,@:7,@<F5T=7)N960L('1H96X@=&AE(&5R<F]R
M(&ES(&-O;7!L971E;'D@:6=N;W)E9"X-"B`J+PT*9&5F:6YE*"=014%27T52
M4D]24U1!0TM?24=.3U)%)RP@-"D[#0HO*BH-"B`J($EF('1H:7,@:7,@<F5T
M=7)N960L('1H96X@=&AE(&5R<F]R(&ES(&QO9V=E9"!A;F0@9&EE*"D@:7,@
M8V%L;&5D+@T*("HO#0ID969I;F4H)U!%05)?15)23U)35$%#2U]$244G+"`U
M*3L-"B\J*B-`+2HO#0H-"B\J*@T*("H@17)R;W(@8V]D92!F;W(@86X@871T
M96UP="!T;R!I;G-T86YT:6%T92!A(&YO;BUC;&%S<R!A<R!A(%!%05)?17)R
M;W)3=&%C:R!I;@T*("H@=&AE('-I;F=L971O;B!M971H;V0N#0H@*B\-"F1E
M9FEN92@G4$5!4E]%4E)/4E-404-+7T524E].3TY#3$%34R<L(#$I.PT*#0HO
M*BH-"B`J($5R<F]R(&-O9&4@9F]R(&%N(&%T=&5M<'0@=&\@<&%S<R!A;B!O
M8FIE8W0@:6YT;R![0&QI;FL@4$5!4E]%<G)O<E-T86-K.CIG971-97-S86=E
M*"E]#0H@*B!T:&%T(&AA<R!N;R!?7W1O4W1R:6YG*"D@;65T:&]D#0H@*B\-
M"F1E9FEN92@G4$5!4E]%4E)/4E-404-+7T524E]/0DI43U-44DE.1R<L(#(I
M.PT*+RHJ#0H@*B!%<G)O<B!3=&%C:R!);7!L96UE;G1A=&EO;@T*("H-"B`J
M(%5S86=E.@T*("H@/&-O9&4^#0H@*B`O+R!G;&]B86P@97)R;W(@<W1A8VL-
M"B`J("1G;&]B86Q?<W1A8VL@/2`F4$5!4E]%<G)O<E-T86-K.CIS:6YG;&5T
M;VXH)TUY4&%C:V%G92<I.PT*("H@+R\@;&]C86P@97)R;W(@<W1A8VL-"B`J
M("1L;V-A;%]S=&%C:R`](&YE=R!014%27T5R<F]R4W1A8VLH)TUY4&%C:V%G
M92<I.PT*("H@/"]C;V1E/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0'9E<G-I;VX@("`@,2XT+CD-"B`J($!P
M86-K86=E("`@(%!%05)?17)R;W)3=&%C:PT*("H@0&-A=&5G;W)Y("`@1&5B
M=6=G:6YG#0H@*B!`8V]P>7)I9VAT("`R,#`T+3(P,#8@1W)E9R!"96%V97(-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z($5R<F]R4W1A8VLN<&AP+'8@,2XR,B`R,#`V+S`Q+S`V(#`T.C0W.C,V
M(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05)?17)R;W)3=&%C:PT*("HO#0IC;&%S<R!014%2
M7T5R<F]R4W1A8VL@>PT*("`@("\J*@T*("`@("`J($5R<F]R<R!A<F4@<W1O
M<F5D(&EN('1H92!O<F1E<B!T:&%T('1H97D@87)E('!U<VAE9"!O;B!T:&4@
M<W1A8VLN#0H@("`@("H@0'-I;F-E(#`N-&%L<&AA($5R<F]R<R!A<F4@;F\@
M;&]N9V5R(&]R9V%N:7IE9"!B>2!E<G)O<B!L979E;"X-"B`@("`@*B!4:&ES
M(')E;F1E<G,@<&]P*"D@;F5A<FQY('5N=7-A8FQE+"!A;F0@;&5V96QS(&-O
M=6QD(&)E(&UO<F4@96%S:6QY#0H@("`@("H@:&%N9&QE9"!I;B!A(&-A;&QB
M86-K(&%N>7=A>0T*("`@("`J($!V87(@87)R87D-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]E<G)O<G,@/2!A<G)A>2@I
M.PT*#0H@("`@+RHJ#0H@("`@("H@4W1O<F%G92!O9B!E<G)O<G,@8GD@;&5V
M96PN#0H@("`@("H-"B`@("`@*B!!;&QO=W,@96%S>2!R971R:65V86P@86YD
M(&1E;&5T:6]N(&]F(&]N;'D@97)R;W)S(&9R;VT@82!P87)T:6-U;&%R(&QE
M=F5L#0H@("`@("H@0'-I;F-E(%!%05(@,2XT+C!D978-"B`@("`@*B!`=F%R
M(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M=F%R("1?97)R;W)S0GE,979E;"`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@
M("`@*B!086-K86=E(&YA;64@=&AI<R!E<G)O<B!S=&%C:R!R97!R97-E;G1S
M#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R;W1E8W1E
M9`T*("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V4[#0H@("`@#0H@("`@+RHJ
M#0H@("`@("H@1&5T97)M:6YE<R!W:&5T:&5R(&$@4$5!4E]%<G)O<B!I<R!T
M:')O=VX@=7!O;B!E=F5R>2!E<G)O<B!A9&1I=&EO;@T*("`@("`J($!V87(@
M8F]O;&5A;@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M('9A<B`D7V-O;7!A="`](&9A;'-E.PT*("`@(`T*("`@("\J*@T*("`@("`J
M($EF('-E="!T;R!A('9A;&ED(&-A;&QB86-K+"!T:&ES('=I;&P@8F4@=7-E
M9"!T;R!G96YE<F%T92!T:&4@97)R;W(-"B`@("`@*B!M97-S86=E(&9R;VT@
M=&AE(&5R<F]R(&-O9&4L(&]T:&5R=VES92!T:&4@;65S<V%G92!P87-S960@
M:6X@=VEL;"!B90T*("`@("`J('5S960-"B`@("`@*B!`=F%R(&9A;'-E?'-T
M<FEN9WQA<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@('9A<B`D7VUS9T-A;&QB86-K(#T@9F%L<V4[#0H@("`@#0H@("`@+RHJ
M#0H@("`@("H@268@<V5T('1O(&$@=F%L:60@8V%L;&)A8VLL('1H:7,@=VEL
M;"!B92!U<V5D('1O(&=E;F5R871E('1H92!E<G)O<@T*("`@("`J(&-O;G1E
M>'0@9F]R(&%N(&5R<F]R+B`@1F]R(%!(4"UR96QA=&5D(&5R<F]R<RP@=&AI
M<R!W:6QL(&)E(&$@9FEL90T*("`@("`J(&%N9"!L:6YE(&YU;6)E<B!A<R!R
M971R:65V960@9G)O;2!D96)U9U]B86-K=')A8V4H*2P@8G5T(&-A;B!B90T*
M("`@("`J(&-U<W1O;6EZ960@9F]R(&]T:&5R('!U<G!O<V5S+B`@5&AE(&5R
M<F]R(&UI9VAT(&%C='5A;&QY(&)E(&EN(&$@<V5P87)A=&4-"B`@("`@*B!C
M;VYF:6=U<F%T:6]N(&9I;&4L(&]R(&EN(&$@9&%T86)A<V4@<75E<GDN#0H@
M("`@("H@0'9A<B!F86QS97QS=')I;F=\87)R87D-"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D7V-O;G1E>'1#86QL8F%C
M:R`](&9A;'-E.PT*("`@(`T*("`@("\J*@T*("`@("`J($EF('-E="!T;R!A
M('9A;&ED(&-A;&QB86-K+"!T:&ES('=I;&P@8F4@8V%L;&5D(&5V97)Y('1I
M;64@86X@97)R;W(-"B`@("`@*B!I<R!P=7-H960@;VYT;R!T:&4@<W1A8VLN
M("!4:&4@<F5T=7)N('9A;'5E('=I;&P@8F4@=7-E9"!T;R!D971E<FUI;F4-
M"B`@("`@*B!W:&5T:&5R('1O(&%L;&]W(&%N(&5R<F]R('1O(&)E('!U<VAE
M9"!O<B!L;V=G960N#0H@("`@("H@#0H@("`@("H@5&AE(')E='5R;B!V86QU
M92!M=7-T(&)E(&]N92!A;B!014%27T524D]24U1!0TM?*B!C;VYS=&%N=`T*
M("`@("`J($!S964@4$5!4E]%4E)/4E-404-+7U!54TA!3D1,3T<L(%!%05)?
M15)23U)35$%#2U]055-(+"!014%27T524D]24U1!0TM?3$]'#0H@("`@("H@
M0'9A<B!F86QS97QS=')I;F=\87)R87D-"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`T*("`@("`J+PT*("`@('9A<B`D7V5R<F]R0V%L;&)A8VL@/2!A<G)A
M>2@I.PT*("`@(`T*("`@("\J*@T*("`@("`J(%!%05(Z.DQO9R!O8FIE8W0@
M9F]R(&QO9V=I;F<@97)R;W)S#0H@("`@("H@0'9A<B!F86QS97Q,;V<-"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D7VQO
M9V=E<B`](&9A;'-E.PT*("`@(`T*("`@("\J*@T*("`@("`J($5R<F]R(&UE
M<W-A9V5S("T@9&5S:6=N960@=&\@8F4@;W9E<G)I9&1E;@T*("`@("`J($!V
M87(@87)R87D-"B`@("`@*B!`86)S=')A8W0-"B`@("`@*B\-"B`@("!V87(@
M)%]E<G)O<DUS9W,@/2!A<G)A>2@I.PT*("`@(`T*("`@("\J*@T*("`@("`J
M(%-E="!U<"!A(&YE=R!E<G)O<B!S=&%C:PT*("`@("`J(`T*("`@("`J($!P
M87)A;2!S=')I;F<@("`D<&%C:V%G92!N86UE(&]F('1H92!P86-K86=E('1H
M:7,@97)R;W(@<W1A8VL@<F5P<F5S96YT<PT*("`@("`J($!P87)A;2!C86QL
M8F%C:R`D;7-G0V%L;&)A8VL@8V%L;&)A8VL@=7-E9"!F;W(@97)R;W(@;65S
M<V%G92!G96YE<F%T:6]N#0H@("`@("H@0'!A<F%M(&-A;&QB86-K("1C;VYT
M97AT0V%L;&)A8VL@8V%L;&)A8VL@=7-E9"!F;W(@8V]N=&5X="!G96YE<F%T
M:6]N+`T*("`@("`J("`@("`@("`@("`@("`@("!D969A=6QT<R!T;R![0&QI
M;FL@9V5T1FEL94QI;F4H*7T-"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@)'1H
M<F]W4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?17)R
M;W)3=&%C:R@D<&%C:V%G92P@)&US9T-A;&QB86-K(#T@9F%L<V4L("1C;VYT
M97AT0V%L;&)A8VL@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AR;W=014%27T5R<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V4@/2`D<&%C:V%G93L-"B`@("`@("`@)'1H:7,M/G-E
M=$UE<W-A9V5#86QL8F%C:R@D;7-G0V%L;&)A8VLI.PT*("`@("`@("`D=&AI
M<RT^<V5T0V]N=&5X=$-A;&QB86-K*"1C;VYT97AT0V%L;&)A8VLI.PT*("`@
M("`@("`D=&AI<RT^7V-O;7!A="`]("1T:')O=U!%05)?17)R;W([#0H@("`@
M?0T*("`@(`T*("`@("\J*@T*("`@("`J(%)E='5R;B!A('-I;F=L92!E<G)O
M<B!S=&%C:R!F;W(@=&AI<R!P86-K86=E+@T*("`@("`J(`T*("`@("`J($YO
M=&4@=&AA="!A;&P@<&%R86UE=&5R<R!A<F4@:6=N;W)E9"!I9B!T:&4@<W1A
M8VL@9F]R('!A8VMA9V4@)'!A8VMA9V4-"B`@("`@*B!H87,@86QR96%D>2!B
M965N(&EN<W1A;G1I871E9`T*("`@("`J($!P87)A;2!S=')I;F<@("`D<&%C
M:V%G92!N86UE(&]F('1H92!P86-K86=E('1H:7,@97)R;W(@<W1A8VL@<F5P
M<F5S96YT<PT*("`@("`J($!P87)A;2!C86QL8F%C:R`D;7-G0V%L;&)A8VL@
M8V%L;&)A8VL@=7-E9"!F;W(@97)R;W(@;65S<V%G92!G96YE<F%T:6]N#0H@
M("`@("H@0'!A<F%M(&-A;&QB86-K("1C;VYT97AT0V%L;&)A8VL@8V%L;&)A
M8VL@=7-E9"!F;W(@8V]N=&5X="!G96YE<F%T:6]N+`T*("`@("`J("`@("`@
M("`@("`@("`@("!D969A=6QT<R!T;R![0&QI;FL@9V5T1FEL94QI;F4H*7T-
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@)'1H<F]W4$5!4E]%<G)O<@T*("`@
M("`J($!P87)A;2!S=')I;F<@("`D<W1A8VM#;&%S<R!C;&%S<R!T;R!I;G-T
M86YT:6%T90T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`<F5T=7)N(%!%05)?
M17)R;W)3=&%C:PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH
M)'!A8VMA9V4L("1M<V=#86QL8F%C:R`](&9A;'-E+"`D8V]N=&5X=$-A;&QB
M86-K(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H<F]W
M4$5!4E]%<G)O<B`](&9A;'-E+"`D<W1A8VM#;&%S<R`]("=014%27T5R<F]R
M4W1A8VLG*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=?
M4$5!4E]%4E)/4E-404-+7U-)3D=,151/3B==6R1P86-K86=E72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]3
M24Y'3$543TXG75LD<&%C:V%G95T[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)'-T86-K0VQA<W,I*2![#0H@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B86-K=')A8V4G*2D@>PT*("`@
M("`@("`@("`@("`@("1T<F%C92`](&1E8G5G7V)A8VMT<F%C92@I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@4$5!4E]%<G)O<E-T86-K.CIS=&%T
M:6-0=7-H*"=014%27T5R<F]R4W1A8VLG+"!014%27T524D]24U1!0TM?15)2
M7TY/3D-,05-3+`T*("`@("`@("`@("`@("`@("=E>&-E<'1I;VXG+"!A<G)A
M>2@G<W1A8VMC;&%S<R<@/3X@)'-T86-K0VQA<W,I+`T*("`@("`@("`@("`@
M("`@("=S=&%C:R!C;&%S<R`B)7-T86-K8VQA<W,E(B!I<R!N;W0@82!V86QI
M9"!C;&%S<R!N86UE("AS:&]U;&0@8F4@;&EK92!014%27T5R<F]R4W1A8VLI
M)RP-"B`@("`@("`@("`@("`@("!F86QS92P@)'1R86-E*3L-"B`@("`@("`@
M?0T*("`@("`@("`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]324Y'3$54
M3TXG75LD<&%C:V%G95T@/0T*("`@("`@("`@("`@;F5W("1S=&%C:T-L87-S
M*"1P86-K86=E+"`D;7-G0V%L;&)A8VLL("1C;VYT97AT0V%L;&)A8VLL("1T
M:')O=U!%05)?17)R;W(I.PT*#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG
M7U!%05)?15)23U)35$%#2U]324Y'3$543TXG75LD<&%C:V%G95T[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@26YT97)N86P@97)R;W(@:&%N9&QE<B!F
M;W(@4$5!4E]%<G)O<E-T86-K(&-L87-S#0H@("`@("H@#0H@("`@("H@1&EE
M<R!I9B!T:&4@97)R;W(@:7,@86X@97AC97!T:6]N("AA;F0@=V]U;&0@:&%V
M92!D:65D(&%N>7=A>2D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?:&%N9&QE17)R;W(H)&5R<BD-"B`@("![#0H@
M("`@("`@(&EF("@D97)R6R=L979E;"==(#T]("=E>&-E<'1I;VXG*2![#0H@
M("`@("`@("`@("`D;65S<V%G92`]("1E<G);)VUE<W-A9V4G73L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG4D5154535%]54DDG72DI('L-
M"B`@("`@("`@("`@("`@("!E8VAO("<\8G(@+SXG.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("!E8VAO(")<;B([#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!V87)?9'5M<"@D97)R6R=C;VYT97AT)UTI
M.PT*("`@("`@("`@("`@9&EE*"1M97-S86=E*3L-"B`@("`@("`@?0T*("`@
M('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3970@=7`@82!014%2.CI,;V<@
M;V)J96-T(&9O<B!A;&P@97)R;W(@<W1A8VMS('1H870@9&]N)W0@:&%V92!O
M;F4-"B`@("`@*B!`<&%R86T@3&]G("1L;V<@#0H@("`@("H@0'-T871I8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$1E9F%U;'1,;V=G97(H)B1L;V<I
M#0H@("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1L;V<I("8F(&UE=&AO
M9%]E>&ES=',H)&QO9RP@)VQO9R<I("D@>PT*("`@("`@("`@("`@)$=,3T)!
M3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%],3T='15(G72`]("8D;&]G
M.PT*("`@("`@("!](&5L<V5I9B`H:7-?8V%L;&%B;&4H)&QO9RDI('L-"B`@
M("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T1%1D%53%1?
M3$]'1T52)UT@/2`F)&QO9SL-"@E]#0H@("`@?0T*("`@(`T*("`@("\J*@T*
M("`@("`J(%-E="!U<"!A(%!%05(Z.DQO9R!O8FIE8W0@9F]R('1H:7,@97)R
M;W(@<W1A8VL-"B`@("`@*B!`<&%R86T@3&]G("1L;V<@#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D;&]G*0T*("`@('L-"B`@("`@("`@
M:68@*&ES7V]B:F5C="@D;&]G*2`F)B!M971H;V1?97AI<W1S*"1L;V<L("=L
M;V<G*2`I('L-"B`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R(#T@)B1L;V<[
M#0H@("`@("`@('T@96QS96EF("AI<U]C86QL86)L92@D;&]G*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]L;V=G97(@/2`F)&QO9SL-"B`@("`@("`@?0T*
M("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3970@86X@97)R;W(@8V]D
M92`]/B!E<G)O<B!M97-S86=E(&UA<'!I;F<@8V%L;&)A8VL-"B`@("`@*B`-
M"B`@("`@*B!4:&ES(&UE=&AO9"!S971S('1H92!C86QL8F%C:R!T:&%T(&-A
M;B!B92!U<V5D('1O(&=E;F5R871E(&5R<F]R#0H@("`@("H@;65S<V%G97,@
M9F]R(&%N>2!I;G-T86YC90T*("`@("`J($!P87)A;2!A<G)A>7QS=')I;F<@
M0V%L;&)A8VL@9G5N8W1I;VXO;65T:&]D#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T365S<V%G94-A;&QB86-K*"1M<V=#86QL8F%C:RD-"B`@("![#0H@
M("`@("`@(&EF("@A)&US9T-A;&QB86-K*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7VUS9T-A;&QB86-K(#T@87)R87DH)B1T:&ES+"`G9V5T17)R;W)-97-S
M86=E)RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-?
M8V%L;&%B;&4H)&US9T-A;&QB86-K*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;7-G0V%L;&)A8VL@/2`D;7-G0V%L;&)A8VL[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@
M1V5T(&%N(&5R<F]R(&-O9&4@/3X@97)R;W(@;65S<V%G92!M87!P:6YG(&-A
M;&QB86-K#0H@("`@("H@#0H@("`@("H@5&AI<R!M971H;V0@<F5T=7)N<R!T
M:&4@8W5R<F5N="!C86QL8F%C:R!T:&%T(&-A;B!B92!U<V5D('1O(&=E;F5R
M871E(&5R<F]R#0H@("`@("H@;65S<V%G97,-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y?'-T<FEN9WQF86QS92!#86QL8F%C:R!F=6YC=&EO;B]M971H;V0@;W(@
M9F%L<V4@:68@;F]N90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$UE<W-A
M9V5#86QL8F%C:R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]M
M<V=#86QL8F%C:SL-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4V5T
M<R!A(&1E9F%U;'0@8V%L;&)A8VL@=&\@8F4@=7-E9"!B>2!A;&P@97)R;W(@
M<W1A8VMS#0H@("`@("H@#0H@("`@("H@5&AI<R!M971H;V0@<V5T<R!T:&4@
M8V%L;&)A8VL@=&AA="!C86X@8F4@=7-E9"!T;R!G96YE<F%T92!E<G)O<@T*
M("`@("`J(&UE<W-A9V5S(&9O<B!A('-I;F=L971O;@T*("`@("`J($!P87)A
M;2!A<G)A>7QS=')I;F<@0V%L;&)A8VL@9G5N8W1I;VXO;65T:&]D#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!086-K86=E(&YA;64L(&]R(&9A;'-E(&9O<B!A
M;&P@<&%C:V%G97,-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<V5T1&5F875L=$-A;&QB86-K*"1C86QL8F%C:R`](&9A;'-E+"`D
M<&%C:V%G92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]C86QL
M86)L92@D8V%L;&)A8VLI*2![#0H@("`@("`@("`@("`D8V%L;&)A8VL@/2!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("`D<&%C:V%G92`]("1P86-K86=E
M(#\@)'!A8VMA9V4@.B`G*B<[#0H@("`@("`@("1'3$]"04Q36R=?4$5!4E]%
M4E)/4E-404-+7T1%1D%53%1?0T%,3$)!0TLG75LD<&%C:V%G95T@/2`D8V%L
M;&)A8VL[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E="!A(&-A
M;&QB86-K('1H870@9V5N97)A=&5S(&-O;G1E>'0@:6YF;W)M871I;VX@*&QO
M8V%T:6]N(&]F(&5R<F]R*2!F;W(@86X@97)R;W(@<W1A8VL-"B`@("`@*B`-
M"B`@("`@*B!4:&ES(&UE=&AO9"!S971S('1H92!C86QL8F%C:R!T:&%T(&-A
M;B!B92!U<V5D('1O(&=E;F5R871E(&-O;G1E>'0-"B`@("`@*B!I;F9O<FUA
M=&EO;B!F;W(@86X@97)R;W(N("!087-S:6YG(&EN($Y53$P@=VEL;"!D:7-A
M8FQE(&-O;G1E>'0@9V5N97)A=&EO;@T*("`@("`J(&%N9"!R96UO=F4@=&AE
M(&5X<&5N<VEV92!C86QL('1O(&1E8G5G7V)A8VMT<F%C92@I#0H@("`@("H@
M0'!A<F%M(&%R<F%Y?'-T<FEN9WQN=6QL($-A;&QB86-K(&9U;F-T:6]N+VUE
M=&AO9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$-O;G1E>'1#86QL8F%C
M:R@D8V]N=&5X=$-A;&QB86-K*0T*("`@('L-"B`@("`@("`@:68@*"1C;VYT
M97AT0V%L;&)A8VL@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-O;G1E>'1#86QL8F%C:R`](&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)&-O;G1E>'1#86QL8F%C:RD@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]C;VYT97AT0V%L;&)A8VL@/2!A<G)A>2@F)'1H:7,L("=G971&
M:6QE3&EN92<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@
M*&ES7V-A;&QA8FQE*"1C;VYT97AT0V%L;&)A8VLI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;VYT97AT0V%L;&)A8VL@/2`D8V]N=&5X=$-A;&QB
M86-K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*("`@(`T*
M("`@("\J*@T*("`@("`J(%-E="!A;B!E<G)O<B!#86QL8F%C:PT*("`@("`J
M($EF('-E="!T;R!A('9A;&ED(&-A;&QB86-K+"!T:&ES('=I;&P@8F4@8V%L
M;&5D(&5V97)Y('1I;64@86X@97)R;W(-"B`@("`@*B!I<R!P=7-H960@;VYT
M;R!T:&4@<W1A8VLN("!4:&4@<F5T=7)N('9A;'5E('=I;&P@8F4@=7-E9"!T
M;R!D971E<FUI;F4-"B`@("`@*B!W:&5T:&5R('1O(&%L;&]W(&%N(&5R<F]R
M('1O(&)E('!U<VAE9"!O<B!L;V=G960N#0H@("`@("H@#0H@("`@("H@5&AE
M(')E='5R;B!V86QU92!M=7-T(&)E(&]N92!O9B!T:&4@15)23U)35$%#2U\J
M(&-O;G-T86YT<RX-"B`@("`@*B`-"B`@("`@*B!4:&ES(&9U;F-T:6]N86QI
M='D@8V%N(&)E('5S960@=&\@96UU;&%T92!014%2)W,@<'5S:$5R<F]R2&%N
M9&QI;F<L(&%N9`T*("`@("`J('1H92!014%27T524D]27T-!3$Q"04-+(&UO
M9&4L('=I=&AO=70@869F96-T:6YG('1H92!I;G1E9W)I='D@;V8-"B`@("`@
M*B!T:&4@97)R;W(@<W1A8VL@;W(@;&]G9VEN9PT*("`@("`J($!S964@4$5!
M4E]%4E)/4E-404-+7U!54TA!3D1,3T<L(%!%05)?15)23U)35$%#2U]055-(
M+"!014%27T524D]24U1!0TM?3$]'#0H@("`@("H@0'-E92!P;W!#86QL8F%C
M:R@I#0H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D8V(-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!P=7-H0V%L;&)A8VLH)&-B*0T*("`@('L-"B`@("`@
M("`@87)R87E?<'5S:"@D=&AI<RT^7V5R<F]R0V%L;&)A8VLL("1C8BD[#0H@
M("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%)E;6]V92!A(&-A;&QB86-K
M(&9R;VT@=&AE(&5R<F]R(&-A;&QB86-K('-T86-K#0H@("`@("H@0'-E92!P
M=7-H0V%L;&)A8VLH*0T*("`@("`J($!R971U<FX@87)R87E\<W1R:6YG?&9A
M;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<&]P0V%L;&)A8VLH*0T*("`@
M('L-"B`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7V5R<F]R0V%L;&)A8VLI
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&%R<F%Y7W!O<"@D=&AI<RT^7V5R<F]R0V%L;&)A8VLI
M.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3970@82!T96UP;W)A
M<GD@;W9E<G)I9&EN9R!E<G)O<B!C86QL8F%C:R!F;W(@979E<GD@<&%C:V%G
M92!E<G)O<B!S=&%C:PT*("`@("`J#0H@("`@("H@57-E('1H:7,@=&\@=&5M
M<&]R87)I;'D@9&ES86)L92!A;&P@97AI<W1I;F<@8V%L;&)A8VMS("AC86X@
M8F4@=7-E9`T*("`@("`J('1O(&5M=6QA=&4@=&AE($`@;W!E<F%T;W(L(&9O
M<B!I;G-T86YC92D-"B`@("`@*B!`<V5E(%!%05)?15)23U)35$%#2U]055-(
M04Y$3$]'+"!014%27T524D]24U1!0TM?4%532"P@4$5!4E]%4E)/4E-404-+
M7TQ/1PT*("`@("`J($!S964@<W1A=&EC4&]P0V%L;&)A8VLH*2P@<'5S:$-A
M;&QB86-K*"D-"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y("1C8@T*("`@
M("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&%T:6-0=7-H
M0V%L;&)A8VLH)&-B*0T*("`@('L-"B`@("`@("`@87)R87E?<'5S:"@D1TQ/
M0D%,4ULG7U!%05)?15)23U)35$%#2U]/5D524DE$15]#04Q,0D%#2R==+"`D
M8V(I.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!296UO=F4@82!T
M96UP;W)A<GD@;W9E<G)I9&EN9R!E<G)O<B!C86QL8F%C:PT*("`@("`J($!S
M964@<W1A=&EC4'5S:$-A;&QB86-K*"D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M?'-T<FEN9WQF86QS90T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S=&%T:6-0;W!#86QL8F%C:R@I#0H@("`@>PT*("`@("`@("`D
M<F5T(#T@87)R87E?<&]P*"1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T]6
M15)2241%7T-!3$Q"04-+)UTI.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1'
M3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T]615)2241%7T-!3$Q"04-+)UTI
M*2![#0H@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]/
M5D524DE$15]#04Q,0D%#2R==(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@
M("H@061D(&%N(&5R<F]R('1O('1H92!S=&%C:PT*("`@("`J(`T*("`@("`J
M($EF('1H92!M97-S86=E(&=E;F5R871O<B!E>&ES=',L(&ET(&ES(&-A;&QE
M9"!W:71H(#(@<&%R86UE=&5R<RX-"B`@("`@*B`@+2!T:&4@8W5R<F5N="!%
M<G)O<B!3=&%C:R!O8FIE8W0-"B`@("`@*B`@+2!A;B!A<G)A>2!T:&%T(&ES
M(&EN('1H92!S86UE(&9O<FUA="!A<R!A;B!E<G)O<BX@($%V86EL86)L92!I
M;F1I8V5S#0H@("`@("H@("`@87)E("=C;V1E)RP@)W!A8VMA9V4G+"`G=&EM
M92<L("=P87)A;7,G+"`G;&5V96PG+"!A;F0@)V-O;G1E>'0G#0H@("`@("H@
M#0H@("`@("H@3F5X="P@:68@=&AE(&5R<F]R('-H;W5L9"!C;VYT86EN(&-O
M;G1E>'0@:6YF;W)M871I;VXL('1H:7,@:7,-"B`@("`@*B!H86YD;&5D(&)Y
M('1H92!C;VYT97AT(&=R86)B:6YG(&UE=&AO9"X-"B`@("`@*B!&:6YA;&QY
M+"!T:&4@97)R;W(@:7,@<'5S:&5D(&]N=&\@=&AE('!R;W!E<B!E<G)O<B!S
M=&%C:PT*("`@("`J($!P87)A;2!I;G0@("`@)&-O9&4@("`@("!086-K86=E
M+7-P96-I9FEC(&5R<F]R(&-O9&4-"B`@("`@*B!`<&%R86T@<W1R:6YG("1L
M979E;"`@("`@17)R;W(@;&5V96PN("!4:&ES(&ES($Y/5"!S<&5L;"UC:&5C
M:V5D#0H@("`@("H@0'!A<F%M(&%R<F%Y("`D<&%R86US("`@(&%S<V]C:6%T
M:79E(&%R<F%Y(&]F(&5R<F]R('!A<F%M971E<G,-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1M<V<@("`@("`@17)R;W(@;65S<V%G92P@;W(@82!P;W)T:6]N
M(&]F(&ET(&EF('1H92!M97-S86=E#0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&ES('1O(&)E(&=E;F5R871E9`T*("`@("`J($!P87)A;2!A
M<G)A>2`@)')E<&%C:V%G92!)9B!T:&ES(&5R<F]R(')E+7!A8VMA9V5S(&%N
M(&5R<F]R('!U<VAE9"!B>0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!A;F]T:&5R('!A8VMA9V4L('!L86-E('1H92!A<G)A>2!R971U<FYE
M9"!F<F]M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('M`;&EN
M:R!P;W`H*7T@:6X@=&AI<R!P87)A;65T97(-"B`@("`@*B!`<&%R86T@87)R
M87D@("1B86-K=')A8V4@4')O=&5C=&5D('!A<F%M971E<CH@=7-E('1H:7,@
M=&\@<&%S<R!I;B!T:&4-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@>T!L:6YK(&1E8G5G7V)A8VMT<F%C92@I?2!T:&%T('-H;W5L9"!B92!U
M<V5D#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&9I;F0@
M97)R;W(@8V]N=&5X=`T*("`@("`J($!R971U<FX@4$5!4E]%<G)O<GQA<G)A
M>7Q%>&-E<'1I;VX-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@8V]M<&%T:6)I;&ET>2!M;V1E(&ES(&]N+"!A(%!%05)?17)R;W(@:7,@
M86QS;PT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:')O=VXN
M("!)9B!T:&4@8VQA<W,@17AC97!T:6]N(&5X:7-T<RP@=&AE;B!O;F4-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@<F5T=7)N960@=&\@
M86QL;W<@8V]D92!L:6ME.@T*("`@("`J(#QC;V1E/@T*("`@("`J('1H<F]W
M("@D<W1A8VLM/G!U<V@H35E?15)23U)?0T]$12P@)V5R<F]R)RP@87)R87DH
M)W5S97)N86UE)R`]/B`G9W)O8B<I*2D[#0H@("`@("H@/"]C;V1E/@T*("`@
M("`J(`T*("`@("`J(%1H92!E<G)O<D1A=&$@<')O<&5R='D@;V8@=&AE(&5X
M8V5P=&EO;B!C;&%S<R!W:6QL(&)E('-E="!T;R!T:&4@87)R87D-"B`@("`@
M*B!T:&%T('=O=6QD(&YO<FUA;&QY(&)E(')E='5R;F5D+B`@268@82!014%2
M7T5R<F]R(&ES(')E='5R;F5D+"!T:&4@=7-E<FEN9F\-"B`@("`@*B!P<F]P
M97)T>2!I<R!S970@=&\@=&AE(&%R<F%Y#0H@("`@("H@#0H@("`@("H@3W1H
M97)W:7-E+"!A;B!A<G)A>2!I<R!R971U<FYE9"!I;B!T:&ES(&9O<FUA=#H-
M"B`@("`@*B`\8V]D93X-"B`@("`@*B!A<G)A>2@-"B`@("`@*B`@("`G8V]D
M92<@/3X@)&-O9&4L#0H@("`@("H@("`@)W!A<F%M<R<@/3X@)'!A<F%M<RP-
M"B`@("`@*B`@("`G<&%C:V%G92<@/3X@)'1H:7,M/E]P86-K86=E+`T*("`@
M("`J("`@("=L979E;"<@/3X@)&QE=F5L+`T*("`@("`J("`@("=T:6UE)R`]
M/B!T:6UE*"DL#0H@("`@("H@("`@)V-O;G1E>'0G(#T^("1C;VYT97AT+`T*
M("`@("`J("`@("=M97-S86=E)R`]/B`D;7-G+`T*("`@("`J("\O6R=R97!A
M8VMA9V4G(#T^("1E<G)=(')E<&%C:V%G960@97)R;W(@87)R87DO17AC97!T
M:6]N(&-L87-S#0H@("`@("H@*3L-"B`@("`@*B`\+V-O9&4^#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<'5S:"@D8V]D92P@)&QE=F5L(#T@)V5R<F]R)RP@
M)'!A<F%M<R`](&%R<F%Y*"DL("1M<V<@/2!F86QS92P-"B`@("`@("`@("`@
M("`@("`@("1R97!A8VMA9V4@/2!F86QS92P@)&)A8VMT<F%C92`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@)&-O;G1E>'0@/2!F86QS93L-"B`@("`@("`@
M+R\@9W)A8B!E<G)O<B!C;VYT97AT#0H@("`@("`@(&EF("@D=&AI<RT^7V-O
M;G1E>'1#86QL8F%C:RD@>PT*("`@("`@("`@("`@:68@*"$D8F%C:W1R86-E
M*2![#0H@("`@("`@("`@("`@("`@)&)A8VMT<F%C92`](&1E8G5G7V)A8VMT
M<F%C92@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-O;G1E>'0@
M/2!C86QL7W5S97)?9G5N8R@D=&AI<RT^7V-O;G1E>'1#86QL8F%C:RP@)&-O
M9&4L("1P87)A;7,L("1B86-K=')A8V4I.PT*("`@("`@("!]#0H@("`@("`@
M(`T*("`@("`@("`O+R!S879E(&5R<F]R#0H@("`@("`@("1T:6UE(#T@97AP
M;&]D92@G("<L(&UI8W)O=&EM92@I*3L-"B`@("`@("`@)'1I;64@/2`D=&EM
M95LQ72`K("1T:6UE6S!=.PT*("`@("`@("`D97)R(#T@87)R87DH#0H@("`@
M("`@("`@("`@("`@)V-O9&4G(#T^("1C;V1E+`T*("`@("`@("`@("`@("`@
M("=P87)A;7,G(#T^("1P87)A;7,L#0H@("`@("`@("`@("`@("`@)W!A8VMA
M9V4G(#T^("1T:&ES+3Y?<&%C:V%G92P-"B`@("`@("`@("`@("`@("`G;&5V
M96PG(#T^("1L979E;"P-"B`@("`@("`@("`@("`@("`G=&EM92<@/3X@)'1I
M;64L#0H@("`@("`@("`@("`@("`@)V-O;G1E>'0G(#T^("1C;VYT97AT+`T*
M("`@("`@("`@("`@("`@("=M97-S86=E)R`]/B`D;7-G+`T*("`@("`@("`@
M("`@("`@*3L-"@T*("`@("`@("!I9B`H)')E<&%C:V%G92D@>PT*("`@("`@
M("`@("`@)&5R<ELG<F5P86-K86=E)UT@/2`D<F5P86-K86=E.PT*("`@("`@
M("!]#0H-"B`@("`@("`@+R\@<V5T('5P('1H92!E<G)O<B!M97-S86=E+"!I
M9B!N96-E<W-A<GD-"B`@("`@("`@:68@*"1T:&ES+3Y?;7-G0V%L;&)A8VLI
M('L-"B`@("`@("`@("`@("1M<V<@/2!C86QL7W5S97)?9G5N8U]A<G)A>2@D
M=&AI<RT^7VUS9T-A;&QB86-K+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"8D=&AI<RP@)&5R<BDI.PT*("`@("`@
M("`@("`@)&5R<ELG;65S<V%G92==(#T@)&US9SL-"B`@("`@("`@?2`@("`@
M("`@#0H@("`@("`@("1P=7-H(#T@)&QO9R`]('1R=64[#0H@("`@("`@("1D
M:64@/2!F86QS93L-"B`@("`@("`@+R\@=')Y('1H92!O=F5R<FED:6YG(&-A
M;&QB86-K(&9I<G-T#0H@("`@("`@("1C86QL8F%C:R`]("1T:&ES+3YS=&%T
M:6-0;W!#86QL8F%C:R@I.PT*("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@
M("`@("`@("`@("`D=&AI<RT^<W1A=&EC4'5S:$-A;&QB86-K*"1C86QL8F%C
M:RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<U]C86QL86)L92@D8V%L
M;&)A8VLI*2![#0H@("`@("`@("`@("`O+R!T<GD@=&AE(&QO8V%L(&-A;&QB
M86-K(&YE>'0-"B`@("`@("`@("`@("1C86QL8F%C:R`]("1T:&ES+3YP;W!#
M86QL8F%C:R@I.PT*("`@("`@("`@("`@:68@*&ES7V-A;&QA8FQE*"1C86QL
M8F%C:RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S:$-A;&QB86-K
M*"1C86QL8F%C:RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("\O('1R>2!T:&4@9&5F875L="!C86QL8F%C:PT*("`@("`@("`@
M("`@("`@("1C86QL8F%C:R`](&ES<V5T*"1'3$]"04Q36R=?4$5!4E]%4E)/
M4E-404-+7T1%1D%53%1?0T%,3$)!0TLG75LD=&AI<RT^7W!A8VMA9V5=*2`_
M#0H@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]%4E)/4E-4
M04-+7T1%1D%53%1?0T%,3$)!0TLG75LD=&AI<RT^7W!A8VMA9V5=(#H-"B`@
M("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?
M1$5&055,5%]#04Q,0D%#2R==6R<J)UT[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES7V-A;&QA8FQE*"1C86QL8F%C:RDI('L-
M"B`@("`@("`@("`@('-W:71C:"AC86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL
M("1E<G(I*7L-"B`@("`@("`@("`@(`EC87-E(%!%05)?15)23U)35$%#2U])
M1TY/4D4Z(`T*("`@("`@("`@("`@"0ER971U<FX@)&5R<CL-"B`@("`@("`@
M"0EB<F5A:SL-"B`@("`@("`@("`@(`EC87-E(%!%05)?15)23U)35$%#2U]0
M55-(.B`-"B`@("`@("`@("`@(`D))&QO9R`](&9A;'-E.PT*("`@("`@("`)
M"6)R96%K.PT*("`@("`@("`@("`@"6-A<V4@4$5!4E]%4E)/4E-404-+7TQ/
M1SH@#0H@("`@("`@("`@("`)"21P=7-H(#T@9F%L<V4[#0H@("`@("`@(`D)
M8G)E86L[#0H@("`@("`@("`@("`)8V%S92!014%27T524D]24U1!0TM?1$E%
M.B`-"B`@("`@("`@("`@(`D))&1I92`]('1R=64[#0H@("`@("`@(`D)8G)E
M86L[#0H@("`@("`@("`@("`@("`@+R\@86YY=&AI;F<@96QS92!R971U<FYE
M9"!H87,@=&AE('-A;64@969F96-T(&%S('!U<VAA;F1L;V<-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!U<V@I('L-"B`@("`@
M("`@("`@(&%R<F%Y7W5N<VAI9G0H)'1H:7,M/E]E<G)O<G,L("1E<G(I.PT*
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1E<G);)VQE=F5L
M)UU=6UT@/2`F)'1H:7,M/E]E<G)O<G-;,%T[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1L;V<I('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VQO9V=E
M<B!\?"`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$149!54Q47TQ/1T=%
M4B==*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V<H)&5R<BD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1D:64I('L-
M"B`@("`@("`@("`@(&1I92@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M=&AI<RT^7V-O;7!A="`F)B`D<'5S:"D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1M<V<L("1C;V1E+"!N=6QL+"!N=6QL+"`D
M97)R*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&5R<CL-"B`@("!]
M#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4W1A=&EC('9E<G-I;VX@;V8@>T!L
M:6YK('!U<V@H*7T-"B`@("`@*B`-"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M86-K86=E("`@4&%C:V%G92!N86UE('1H:7,@97)R;W(@8F5L;VYG<R!T;PT*
M("`@("`J($!P87)A;2!I;G0@("`@)&-O9&4@("`@("!086-K86=E+7-P96-I
M9FEC(&5R<F]R(&-O9&4-"B`@("`@*B!`<&%R86T@<W1R:6YG("1L979E;"`@
M("`@17)R;W(@;&5V96PN("!4:&ES(&ES($Y/5"!S<&5L;"UC:&5C:V5D#0H@
M("`@("H@0'!A<F%M(&%R<F%Y("`D<&%R86US("`@(&%S<V]C:6%T:79E(&%R
M<F%Y(&]F(&5R<F]R('!A<F%M971E<G,-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M<V<@("`@("`@17)R;W(@;65S<V%G92P@;W(@82!P;W)T:6]N(&]F(&ET
M(&EF('1H92!M97-S86=E#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&ES('1O(&)E(&=E;F5R871E9`T*("`@("`J($!P87)A;2!A<G)A>2`@
M)')E<&%C:V%G92!)9B!T:&ES(&5R<F]R(')E+7!A8VMA9V5S(&%N(&5R<F]R
M('!U<VAE9"!B>0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A
M;F]T:&5R('!A8VMA9V4L('!L86-E('1H92!A<G)A>2!R971U<FYE9"!F<F]M
M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('M`;&EN:R!P;W`H
M*7T@:6X@=&AI<R!P87)A;65T97(-"B`@("`@*B!`<&%R86T@87)R87D@("1B
M86-K=')A8V4@4')O=&5C=&5D('!A<F%M971E<CH@=7-E('1H:7,@=&\@<&%S
M<R!I;B!T:&4-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@>T!L
M:6YK(&1E8G5G7V)A8VMT<F%C92@I?2!T:&%T('-H;W5L9"!B92!U<V5D#0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&9I;F0@97)R;W(@
M8V]N=&5X=`T*("`@("`J($!R971U<FX@4$5!4E]%<G)O<GQN=6QL?$5X8V5P
M=&EO;@T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I9B!C;VUP
M871I8FEL:71Y(&UO9&4@:7,@;VXL(&$@4$5!4E]%<G)O<B!I<R!A;'-O#0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H<F]W;BX@($EF('1H
M92!C;&%S<R!%>&-E<'1I;VX@97AI<W1S+"!T:&5N(&]N90T*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!I<R!R971U<FYE9"!T;R!A;&QO=R!C
M;V1E(&QI:V4Z#0H@("`@("H@/&-O9&4^#0H@("`@("H@=&AR;W<@*"1S=&%C
M:RT^<'5S:"A-65]%4E)/4E]#3T1%+"`G97)R;W(G+"!A<G)A>2@G=7-E<FYA
M;64G(#T^("=G<F]B)RDI*3L-"B`@("`@*B`\+V-O9&4^#0H@("`@("H@0'-T
M871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-T871I8U!U<V@H)'!A8VMA
M9V4L("1C;V1E+"`D;&5V96P@/2`G97)R;W(G+"`D<&%R86US(#T@87)R87DH
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("1M<V<@/2!F86QS92P@)')E
M<&%C:V%G92`](&9A;'-E+"`D8F%C:W1R86-E(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("`D<R`]("9014%27T5R<F]R4W1A8VLZ.G-I;F=L971O;B@D<&%C
M:V%G92D[#0H@("`@("`@(&EF("@D<RT^7V-O;G1E>'1#86QL8F%C:RD@>PT*
M("`@("`@("`@("`@:68@*"$D8F%C:W1R86-E*2![#0H@("`@("`@("`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9&5B=6=?8F%C:W1R86-E)RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&)A8VMT<F%C92`](&1E8G5G7V)A8VMT
M<F%C92@I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)',M/G!U<V@H)&-O9&4L("1L979E
M;"P@)'!A<F%M<RP@)&US9RP@)')E<&%C:V%G92P@)&)A8VMT<F%C92D[#0H@
M("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($QO9R!A;B!E<G)O<B!U<VEN
M9R!014%2.CI,;V<-"B`@("`@*B!`<&%R86T@87)R87D@)&5R<B!%<G)O<B!A
M<G)A>0T*("`@("`J($!P87)A;2!A<G)A>2`D;&5V96QS($5R<F]R(&QE=F5L
M(#T^($QO9R!C;VYS=&%N="!M87`-"B`@("`@*B!`86-C97-S('!R;W1E8W1E
M9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]L;V<H)&5R<BD-"B`@("![#0H@
M("`@("`@(&EF("@D=&AI<RT^7VQO9V=E<BD@>PT*("`@("`@("`@("`@)&QO
M9V=E<B`]("8D=&AI<RT^7VQO9V=E<CL-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1L;V=G97(@/2`F)$=,3T)!3%-;)U]014%27T524D]24U1!
M0TM?1$5&055,5%],3T='15(G73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-?82@D;&]G9V5R+"`G3&]G)RDI('L-"B`@("`@("`@("`@("1L979E;',@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G97AC97!T:6]N)R`]/B!014%2
M7TQ/1U]#4DE4+`T*("`@("`@("`@("`@("`@("=A;&5R="<@/3X@4$5!4E],
M3T=?04Q%4E0L#0H@("`@("`@("`@("`@("`@)V-R:71I8V%L)R`]/B!014%2
M7TQ/1U]#4DE4+`T*("`@("`@("`@("`@("`@("=E<G)O<B<@/3X@4$5!4E],
M3T=?15)2+`T*("`@("`@("`@("`@("`@("=W87)N:6YG)R`]/B!014%27TQ/
M1U]705).24Y'+`T*("`@("`@("`@("`@("`@("=N;W1I8V4G(#T^(%!%05)?
M3$]'7TY/5$E#12P-"B`@("`@("`@("`@("`@("`G:6YF;R<@/3X@4$5!4E],
M3T=?24Y&3RP-"B`@("`@("`@("`@("`@("`G9&5B=6<G(#T^(%!%05)?3$]'
M7T1%0E5'*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D;&5V96QS6R1E<G);
M)VQE=F5L)UU=*2D@>PT*("`@("`@("`@("`@("`@("1L979E;"`]("1L979E
M;'-;)&5R<ELG;&5V96PG75T[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'7TE.1D\[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D;&]G9V5R+3YL;V<H)&5R<ELG;65S<V%G
M92==+"`D;&5V96PL("1E<G(I.PT*("`@("`@("!](&5L<V4@>R`O+R!S=7!P
M;W)T(&YO;BUS=&%N9&%R9"!L;V=S#0H@("`@("`@("`@("!C86QL7W5S97)?
M9G5N8R@D;&]G9V5R+"`D97)R*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M(`T*("`@("\J*@T*("`@("`J(%!O<"!A;B!E<G)O<B!O9F8@;V8@=&AE(&5R
M<F]R('-T86-K#0H@("`@("H@#0H@("`@("H@0')E='5R;B!F86QS97QA<G)A
M>0T*("`@("`J($!S:6YC92`P+C1A;'!H82!I="!I<R!N;R!L;VYG97(@<&]S
M<VEB;&4@=&\@<W!E8VEF>2!A('-P96-I9FEC(&5R<F]R#0H@("`@("H@;&5V
M96P@=&\@<F5T=7)N("T@=&AE(&QA<W0@97)R;W(@<'5S:&5D('=I;&P@8F4@
M<F5T=7)N960L(&EN<W1E860-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P;W`H
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N($!A<G)A>5]S:&EF="@D=&AI<RT^
M7V5R<F]R<RD[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($1E=&5R
M;6EN92!W:&5T:&5R('1H97)E(&%R92!A;GD@97)R;W)S(&]N('1H92!S=&%C
M:PT*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@3&5V96P@;F%M92X@(%5S
M92!T;R!D971E<FUI;F4@:68@86YY(&5R<F]R<PT*("`@("`J(&]F(&QE=F5L
M("AS=')I;F<I+"!O<B!L979E;',@*&%R<F%Y*2!H879E(&)E96X@<'5S:&5D
M#0H@("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@:&%S17)R;W)S*"1L979E;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"1L979E;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3Y?97)R;W)S0GE,979E;%LD;&5V96Q=*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@8V]U;G0H)'1H:7,M/E]E<G)O<G,I.PT*("`@('T-"B`@("`-
M"B`@("`O*BH-"B`@("`@*B!2971R:65V92!A;&P@97)R;W)S('-I;F-E(&QA
M<W0@<'5R9V4-"B`@("`@*B`-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!S970@
M:6X@;W)D97(@=&\@96UP='D@=&AE(&5R<F]R('-T86-K#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!L979E;"!N86UE+"!T;R!R971U<FX@;VYL>2!E<G)O<G,@
M;V8@82!P87)T:6-U;&%R('-E=F5R:71Y#0H@("`@("H@0')E='5R;B!A<G)A
M>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$5R<F]R<R@D<'5R9V4@/2!F
M86QS92P@)&QE=F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(21P
M=7)G92D@>PT*("`@("`@("`@("`@:68@*"1L979E;"D@>PT*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1L979E
M;%TI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V5R<F]R<T)Y3&5V96Q;)&QE=F5L73L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V5R<F]R<SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&QE=F5L*2![#0H@("`@("`@("`@
M("`D<F5T(#T@)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1L979E;%T[#0H@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5R<F]R<T)Y3&5V96Q;)&QE=F5L
M72!A<R`D:2`]/B`D=6YU<V5D*2![#0H@("`@("`@("`@("`@("`@+R\@96YT
M<FEE<R!A<F4@<F5F97)E;F-E<R!T;R!T:&4@)%]E<G)O<G,@87)R87D-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R<T)Y3&5V96Q;)&QE=F5L75LD
M:5T@/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O(&%R
M<F%Y7V9I;'1E<B!R96UO=F5S(&%L;"!E;G1R:65S(#T]/2!F86QS90T*("`@
M("`@("`@("`@)'1H:7,M/E]E<G)O<G,@/2!A<G)A>5]F:6QT97(H)'1H:7,M
M/E]E<G)O<G,I.PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]E<G)O<G-"
M>4QE=F5L6R1L979E;%TI.PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?97)R;W)S.PT*("`@
M("`@("`D=&AI<RT^7V5R<F]R<R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES
M+3Y?97)R;W)S0GE,979E;"`](&%R<F%Y*"D[#0H@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@
M=VAE=&AE<B!T:&5R92!A<F4@86YY(&5R<F]R<R!O;B!A('-I;F=L92!E<G)O
M<B!S=&%C:RP@;W(@;VX@86YY(&5R<F]R('-T86-K#0H@("`@("H-"B`@("`@
M*B!4:&4@;W!T:6]N86P@<&%R86UE=&5R(&-A;B!B92!U<V5D('1O('1E<W0@
M=&AE(&5X:7-T96YC92!O9B!A;GD@97)R;W)S('=I=&AO=70@=&AE(&YE960@
M;V8-"B`@("`@*B!S:6YG;&5T;VX@:6YS=&%N=&EA=&EO;@T*("`@("`J($!P
M87)A;2!S=')I;F=\9F%L<V4@4&%C:V%G92!N86UE('1O(&-H96-K(&9O<B!E
M<G)O<G,-"B`@("`@*B!`<&%R86T@<W1R:6YG($QE=F5L(&YA;64@=&\@8VAE
M8VL@9F]R(&$@<&%R=&EC=6QA<B!S979E<FET>0T*("`@("`J($!R971U<FX@
M8F]O;&5A;@T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S=&%T:6-(87-%<G)O<G,H)'!A8VMA9V4@/2!F86QS92P@)&QE=F5L(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)'!A8VMA9V4I('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?
M4TE.1TQ%5$].)UU;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R
M;B`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]324Y'3$543TXG75LD<&%C
M:V%G95TM/FAA<T5R<F]R<R@D;&5V96PI.PT*("`@("`@("!]#0H@("`@("`@
M(&9O<F5A8V@@*"1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)3D=,151/
M3B==(&%S("1P86-K86=E(#T^("1O8FHI('L-"B`@("`@("`@("`@(&EF("@D
M;V)J+3YH87-%<G)O<G,H)&QE=F5L*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@
M1V5T(&$@;&ES="!O9B!A;&P@97)R;W)S('-I;F-E(&QA<W0@<'5R9V4L(&]R
M9V%N:7IE9"!B>2!P86-K86=E#0H@("`@("H@0'-I;F-E(%!%05(@,2XT+C!D
M978@0D,@8G)E86LA("1L979E;"!I<R!N;W<@:6X@=&AE('!L86-E("1M97)G
M92!U<V5D('1O(&)E#0H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!U<F=E(%-E
M="!T;R!P=7)G92!T:&4@97)R;W(@<W1A8VL@;V8@97AI<W1I;F<@97)R;W)S
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&QE=F5L(%-E="!T;R!A(&QE=F5L
M(&YA;64@:6X@;W)D97(@=&\@<F5T<FEE=F4@;VYL>2!E<G)O<G,@;V8@82!P
M87)T:6-U;&%R(&QE=F5L#0H@("`@("H@0'!A<F%M(&)O;VQE86X@)&UE<F=E
M(%-E="!T;R!R971U<FX@82!F;&%T(&%R<F%Y+"!N;W0@;W)G86YI>F5D(&)Y
M('!A8VMA9V4-"B`@("`@*B!`<&%R86T@87)R87D@("`D<V]R=&9U;F,@1G5N
M8W1I;VX@=7-E9"!T;R!S;W)T(&$@;65R9V5D(&%R<F%Y("T@9&5F875L=`T*
M("`@("`J("`@("`@("!S;W)T<R!B>2!T:6UE+"!A;F0@<VAO=6QD(&)E(&=O
M;V0@9F]R(&UO<W0@8V%S97,-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0')E
M='5R;B!A<G)A>2`-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&%T:6-'971%
M<G)O<G,H)'!U<F=E(#T@9F%L<V4L("1L979E;"`](&9A;'-E+"`D;65R9V4@
M/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1F
M=6YC(#T@87)R87DH)U!%05)?17)R;W)3=&%C:R<L("=?<V]R=$5R<F]R<R<I
M*0T*("`@('L-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&EF
M("@A:7-?8V%L;&%B;&4H)'-O<G1F=6YC*2D@>PT*("`@("`@("`@("`@)'-O
M<G1F=6YC(#T@87)R87DH)U!%05)?17)R;W)3=&%C:R<L("=?<V]R=$5R<F]R
M<R<I.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1'3$]"04Q36R=?
M4$5!4E]%4E)/4E-404-+7U-)3D=,151/3B==(&%S("1P86-K86=E(#T^("1O
M8FHI('L-"B`@("`@("`@("`@("1T97-T(#T@)$=,3T)!3%-;)U]014%27T52
M4D]24U1!0TM?4TE.1TQ%5$].)UU;)'!A8VMA9V5=+3YG971%<G)O<G,H)'!U
M<F=E+"`D;&5V96PI.PT*("`@("`@("`@("`@:68@*"1T97-T*2![#0H@("`@
M("`@("`@("`@("`@:68@*"1M97)G92D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F5T(#T@87)R87E?;65R9V4H)')E="P@)'1E<W0I.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1R971;)'!A
M8VMA9V5=(#T@)'1E<W0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D;65R9V4I('L-"B`@("`@
M("`@("`@('5S;W)T*"1R970L("1S;W)T9G5N8RD[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@
M("`J($5R<F]R('-O<G1I;F<@9G5N8W1I;VXL('-O<G1S(&)Y('1I;64-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M<V]R=$5R<F]R<R@D82P@)&(I#0H@("`@>PT*("`@("`@("!I9B`H)&%;)W1I
M;64G72`]/2`D8ELG=&EM92==*2![#0H@("`@("`@("`@("!R971U<FX@,#L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&%;)W1I;64G72`\("1B6R=T:6UE
M)UTI('L-"B`@("`@("`@("`@(')E='5R;B`Q.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`M,3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3=&%N
M9&%R9"!F:6QE+VQI;F4@;G5M8F5R+V9U;F-T:6]N+V-L87-S(&-O;G1E>'0@
M8V%L;&)A8VL-"B`@("`@*@T*("`@("`J(%1H:7,@9G5N8W1I;VX@=7-E<R!A
M(&)A8VMT<F%C92!G96YE<F%T960@9G)O;2![0&QI;FL@9&5B=6=?8F%C:W1R
M86-E*"E]#0H@("`@("H@86YD('-O('=I;&P@;F]T('=O<FL@870@86QL(&EN
M(%!(4"`\(#0N,RXP+B`@5&AE(&9R86UE('-H;W5L9`T*("`@("`J(')E9F5R
M96YC92!T:&4@9G)A;64@=&AA="!C;VYT86EN<R!T:&4@<V]U<F-E(&]F('1H
M92!E<G)O<BX-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E(&5I=&AE<B!A
M<G)A>2@G9FEL92<@/3X@9FEL92P@)VQI;F4G(#T^(&QI;F4L#0H@("`@("H@
M("`@("`@("`G9G5N8W1I;VXG(#T^(&9U;F-T:6]N(&YA;64L("=C;&%S<R<@
M/3X@8VQA<W,@;F%M92D@;W(-"B`@("`@*B`@("`@("`@(&EF('1H:7,@9&]E
M<VXG="!W;W)K+"!T:&5N(&9A;'-E#0H@("`@("H@0'!A<F%M('5N=7-E9`T*
M("`@("`J($!P87)A;2!I;G1E9V5R(&)A8VMT<F%C92!F<F%M92X-"B`@("`@
M*B!`<&%R86T@87)R87D@4F5S=6QT<R!O9B!D96)U9U]B86-K=')A8V4H*0T*
M("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971&:6QE
M3&EN92@D8V]D92P@)'!A<F%M<RP@)&)A8VMT<F%C92`](&YU;&PI#0H@("`@
M>PT*("`@("`@("!I9B`H)&)A8VMT<F%C92`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1F<F%M
M92`](#`[#0H@("`@("`@("1F=6YC=&EO;F9R86UE(#T@,3L-"B`@("`@("`@
M:68@*"%I<W-E="@D8F%C:W1R86-E6S%=*2D@>PT*("`@("`@("`@("`@)&9U
M;F-T:6]N9G)A;64@/2`P.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@=VAI;&4@*&ES<V5T*"1B86-K=')A8V5;)&9U;F-T:6]N9G)A;65=6R=F
M=6YC=&EO;B==*2`F)@T*("`@("`@("`@("`@("`@("`@)&)A8VMT<F%C95LD
M9G5N8W1I;VYF<F%M95U;)V9U;F-T:6]N)UT@/3T@)V5V86PG("8F#0H@("`@
M("`@("`@("`@("`@("!I<W-E="@D8F%C:W1R86-E6R1F=6YC=&EO;F9R86UE
M("L@,5TI*2![#0H@("`@("`@("`@("`@("`@)&9U;F-T:6]N9G)A;64K*SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&)A8VMT<F%C95LD9G)A;65=*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E
M="@D8F%C:W1R86-E6R1F<F%M95U;)V9I;&4G72DI('L-"B`@("`@("`@("`@
M("`@("`D9G)A;64K*SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1F
M=6YC8F%C:W1R86-E(#T@)&)A8VMT<F%C95LD9G5N8W1I;VYF<F%M95T[#0H@
M("`@("`@("`@("`D9FEL96)A8VMT<F%C92`]("1B86-K=')A8V5;)&9R86UE
M73L-"B`@("`@("`@("`@("1R970@/2!A<G)A>2@G9FEL92<@/3X@)&9I;&5B
M86-K=')A8V5;)V9I;&4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M;&EN92<@/3X@)&9I;&5B86-K=')A8V5;)VQI;F4G72D[#0H@("`@("`@("`@
M("`O+R!R96%R<F%N9V4@9F]R(&5V86PG9"!C;V1E(&]R(&-R96%T92!F=6YC
M=&EO;B!E<G)O<G,-"B`@("`@("`@("`@(&EF("AS=')P;W,H)&9I;&5B86-K
M=')A8V5;)V9I;&4G72P@)R@G*2`F)B`-"B`@("`@("`@("`@(`D@('!R96=?
M;6%T8V@H)SM>*"XJ/RE<*"A<9"LI7"D@.B`H+BH_*20[)RP@)&9I;&5B86-K
M=')A8V5;)V9I;&4G72P-"B`@("`@("`@("`@("`@("`@("1M871C:&5S*2D@
M>PT*("`@("`@("`@("`@("`@("1R971;)V9I;&4G72`]("1M871C:&5S6S%=
M.PT*("`@("`@("`@("`@("`@("1R971;)VQI;F4G72`]("1M871C:&5S6S)=
M("L@,#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M9G5N8V)A8VMT<F%C95LG9G5N8W1I;VXG72D@)B8@:7-S970H)&)A8VMT<F%C
M95LQ72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&9U;F-B86-K=')A8V5;
M)V9U;F-T:6]N)UT@(3T@)V5V86PG*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D9G5N8V)A8VMT<F%C95LG9G5N8W1I;VXG72`]/2`G7U]L86UB9&%?
M9G5N8R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R971;)V9U;F-T
M:6]N)UT@/2`G8W)E871E7V9U;F-T:6]N*"D@8V]D92<[#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5T6R=F=6YC=&EO;B==(#T@)&9U;F-B86-K=')A8V5;)V9U;F-T:6]N)UT[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&9U;F-B86-K
M=')A8V5;)V-L87-S)UTI("8F(&ES<V5T*"1B86-K=')A8V5;,5TI*2![#0H@
M("`@("`@("`@("`@("`@)')E=%LG8VQA<W,G72`]("1F=6YC8F%C:W1R86-E
M6R=C;&%S<R==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3=&%N9&%R9"!E<G)O<B!M97-S
M86=E(&=E;F5R871I;VX@8V%L;&)A8VL-"B`@("`@*B`-"B`@("`@*B!4:&ES
M(&UE=&AO9"!M87D@86QS;R!B92!C86QL960@8GD@82!C=7-T;VT@97)R;W(@
M;65S<V%G92!G96YE<F%T;W(-"B`@("`@*B!T;R!F:6QL(&EN('1E;7!L871E
M('9A;'5E<R!F<F]M('1H92!P87)A;7,@87)R87DL('-I;7!L>0T*("`@("`J
M('-E="!T:&4@=&AI<F0@<&%R86UE=&5R('1O('1H92!E<G)O<B!M97-S86=E
M('1E;7!L871E('-T<FEN9R!T;R!U<V4-"B`@("`@*B`-"B`@("`@*B!4:&4@
M<W!E8VEA;"!V87)I86)L92`E7U]M<V<E(&ES(')E<V5R=F5D.B!U<V4@:70@
M;VYL>2!T;R!S<&5C:69Y#0H@("`@("H@=VAE<F4@82!M97-S86=E('!A<W-E
M9"!I;B!B>2!T:&4@=7-E<B!S:&]U;&0@8F4@<&QA8V5D(&EN('1H92!T96UP
M;&%T92P-"B`@("`@*B!L:6ME('-O.@T*("`@("`J(`T*("`@("`J($5R<F]R
M(&UE<W-A9V4Z("5M<V<E("T@:6YT97)N86P@97)R;W(-"B`@("`@*B`-"B`@
M("`@*B!)9B!T:&4@;65S<V%G92!P87-S960@;&EK92!S;SH-"B`@("`@*B`-
M"B`@("`@*B`\8V]D93X-"B`@("`@*B`D<W1A8VLM/G!U<V@H15)23U)?0T]$
M12P@)V5R<F]R)RP@87)R87DH*2P@)W-E<G9E<B!E<G)O<B`U,#`G*3L-"B`@
M("`@*B`\+V-O9&4^#0H@("`@("H@#0H@("`@("H@5&AE(')E='5R;F5D(&5R
M<F]R(&UE<W-A9V4@=VEL;"!B92`B17)R;W(@;65S<V%G93H@<V5R=F5R(&5R
M<F]R(#4P,"`M#0H@("`@("H@:6YT97)N86P@97)R;W(B#0H@("`@("H@0'!A
M<F%M(%!%05)?17)R;W)3=&%C:PT*("`@("`J($!P87)A;2!A<G)A>0T*("`@
M("`J($!P87)A;2!S=')I;F=\9F%L<V4@4')E+6=E;F5R871E9"!E<G)O<B!M
M97-S86=E('1E;7!L871E#0H@("`@("H@0'-T871I8PT*("`@("`J($!R971U
M<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T17)R;W)-97-S
M86=E*"8D<W1A8VLL("1E<G(L("1T96UP;&%T92`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@:68@*"1T96UP;&%T92D@>PT*("`@("`@("`@("`@)&UA:6YM
M<V<@/2`D=&5M<&QA=&4[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D;6%I;FUS9R`]("1S=&%C:RT^9V5T17)R;W)-97-S86=E5&5M<&QA=&4H
M)&5R<ELG8V]D92==*3L-"B`@("`@("`@?0T*("`@("`@("`D;6%I;FUS9R`]
M('-T<E]R97!L86-E*"<E7U]M<V<E)RP@)&5R<ELG;65S<V%G92==+"`D;6%I
M;FUS9RD[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D97)R6R=P87)A;7,G72D@
M)B8@8V]U;G0H)&5R<ELG<&%R86US)UTI*2![#0H@("`@("`@("`@("!F;W)E
M86-H("@D97)R6R=P87)A;7,G72!A<R`D;F%M92`]/B`D=F%L*2![#0H@("`@
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86PI*2![#0H@("`@("`@("`@
M("`@("`@("`@("\O($`@:7,@;F5E9&5D(&EN(&-A<V4@)'9A;"!I<R!A(&UU
M;'1I+61I;65N<VEO;F%L(&%R<F%Y#0H@("`@("`@("`@("`@("`@("`@("1V
M86P@/2!`:6UP;&]D92@G+"`G+"`D=F%L*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D=F%L*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=F%L+"`G7U]T
M;U-T<FEN9R<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L(#T@
M)'9A;"T^7U]T;U-T<FEN9R@I.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<E-T86-K
M.CIS=&%T:6-0=7-H*"=014%27T5R<F]R4W1A8VLG+"!014%27T524D]24U1!
M0TM?15)27T]"2E1/4U1224Y'+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=W87)N:6YG)RP@87)R87DH)V]B:B<@/3X@9V5T7V-L87-S*"1V86PI
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;V)J96-T("5O8FHE
M('!A<W-E9"!I;G1O(&=E=$5R<F]R365S<V%G92P@8G5T(&AA<R!N;R!?7W1O
M4W1R:6YG*"D@;65T:&]D)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L(#T@)T]B:F5C="<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&UA:6YM<V<@/2!S=')?
M<F5P;&%C92@G)2<@+B`D;F%M92`N("<E)RP@)'9A;"P@)&UA:6YM<V<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D;6%I
M;FUS9SL-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4W1A;F1A<F0@
M17)R;W(@365S<V%G92!496UP;&%T92!G96YE<F%T;W(@9G)O;2!C;V1E#0H@
M("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971%<G)O<DUE<W-A9V5496UP;&%T92@D8V]D92D-"B`@("![#0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]E<G)O<DUS9W-;)&-O9&5=*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("<E7U]M<V<E)SL-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]E<G)O<DUS9W-;)&-O9&5=.PT*("`@('T-"B`@
M("`-"B`@("`O*BH-"B`@("`@*B!3970@=&AE($5R<F]R($UE<W-A9V4@5&5M
M<&QA=&4@87)R87D-"B`@("`@*B`-"B`@("`@*B!4:&4@87)R87D@9F]R;6%T
M(&UU<W0@8F4Z#0H@("`@("H@/'!R93X-"B`@("`@*B!A<G)A>2AE<G)O<B!C
M;V1E(#T^("=M97-S86=E('1E;7!L871E)RPN+BXI#0H@("`@("H@/"]P<F4^
M#0H@("`@("H@#0H@("`@("H@17)R;W(@;65S<V%G92!P87)A;65T97)S('!A
M<W-E9"!I;G1O('M`;&EN:R!P=7-H*"E]('=I;&P@8F4@=7-E9"!A<R!I;G!U
M=`T*("`@("`J(&9O<B!T:&4@97)R;W(@;65S<V%G92X@($EF('1H92!T96UP
M;&%T92!I<R`G;65S<V%G92`E9F]O)2!W87,@)6)A<B4G+"!A;F0@=&AE#0H@
M("`@("H@<&%R86UE=&5R<R!A<F4@87)R87DH)V9O;R<@/3X@)V]N92<L("=B
M87(G(#T^("=S:7@G*2P@=&AE(&5R<F]R(&UE<W-A9V4@<F5T=7)N960@=VEL
M;`T*("`@("`J(&)E("=M97-S86=E(&]N92!W87,@<VEX)PT*("`@("`J($!R
M971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T17)R;W)-
M97-S86=E5&5M<&QA=&4H)'1E;7!L871E*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]E<G)O<DUS9W,@/2`D=&5M<&QA=&4[#0H@("`@?0T*("`@(`T*("`@
M(`T*("`@("\J*@T*("`@("`J(&5M=6QA=&4@4$5!4CHZ<F%I<V5%<G)O<B@I
M#0H@("`@("H@#0H@("`@("H@0')E='5R;B!014%27T5R<F]R#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@I#0H@("`@>PT*("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"B`@("`@("`@)&%R9W,@/2!F=6YC
M7V=E=%]A<F=S*"D[#0H@("`@("`@(')E='5R;B!C86QL7W5S97)?9G5N8U]A
M<G)A>2AA<G)A>2@G4$5!4B<L("=R86ES945R<F]R)RDL("1A<F=S*3L-"B`@
M("!]#0I]#0HD<W1A8VL@/2`F4$5!4E]%<G)O<E-T86-K.CIS:6YG;&5T;VXH
M)U!%05)?17)R;W)3=&%C:R<I.PT*)'-T86-K+3YP=7-H0V%L;&)A8VLH87)R
M87DH)U!%05)?17)R;W)3=&%C:R<L("=?:&%N9&QE17)R;W(G*2D[#0H_/@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O17AC97!T:6]N+G!H<```````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,Q-C$P`#$P-3$U-#,Q,#4W`#`R,#4T
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@9F]L9&UE=&AO9#UM87)K97(Z("HO#0HO*BH-"B`J(%!%05)?17AC
M97!T:6]N#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC;WA`:61E8VYE
M="YC;VT^#0H@*B!`875T:&]R("`@("!(86YS($QE;&QE;&ED(#QH86YS0'9E
M;'5M+FYE=#X-"B`J($!A=71H;W(@("`@($)E<G1R86YD($UA;G-I;VX@/&)M
M86YS:6]N0&UA;6%S86TN8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z($5X8V5P=&EO;BYP:'`L=B`Q+C(S(#(P,#8O
M,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C,N,PT*("HO#0H-
M"@T*+RHJ#0H@*B!"87-E(%!%05)?17AC97!T:6]N($-L87-S#0H@*@T*("H@
M,2D@1F5A='5R97,Z#0H@*@T*("H@+2!.97-T86)L92!E>&-E<'1I;VYS("AT
M:')O=R!N97<@4$5!4E]%>&-E<'1I;VXH)&US9RP@)'!R979?97AC97!T:6]N
M*2D-"B`J("T@1&5F:6YA8FQE('1R:6=G97)S+"!S:&]T('=H96X@97AC97!T
M:6]N<R!O8V-U<@T*("H@+2!0<F5T='D@86YD(&EN9F]R;6%T:79E(&5R<F]R
M(&UE<W-A9V5S#0H@*B`M($%D9&5D(&UO<F4@8V]N=&5X="!I;F9O(&%V86EL
M86)L92`H;&EK92!C;&%S<RP@;65T:&]D(&]R(&-A=7-E*0T*("H@+2!C875S
M92!C86X@8F4@82!014%27T5X8V5P=&EO;B!O<B!A;B!A<G)A>2!O9B!M:7AE
M9`T*("H@("!014%27T5X8V5P=&EO;G,O4$5!4E]%<G)O<E-T86-K('=A<FYI
M;F=S#0H@*B`M(&-A;&QB86-K<R!F;W(@<W!E8VEF:6,@97AC97!T:6]N(&-L
M87-S97,@86YD('1H96ER(&-H:6QD<F5N#0H@*@T*("H@,BD@261E87,Z#0H@
M*@T*("H@+2!-87EB92!A('=A>2!T;R!D969I;F4@82`G=&5M<&QA=&4G(&9O
M<B!T:&4@;W5T<'5T#0H@*@T*("H@,RD@26YH97)I=&5D('!R;W!E<G1I97,@
M9G)O;2!02%`@17AC97!T:6]N($-L87-S.@T*("H-"B`J('!R;W1E8W1E9"`D
M;65S<V%G90T*("H@<')O=&5C=&5D("1C;V1E#0H@*B!P<F]T96-T960@)&QI
M;F4-"B`J('!R;W1E8W1E9"`D9FEL90T*("H@<')I=F%T92`@("1T<F%C90T*
M("H-"B`J(#0I($EN:&5R:71E9"!M971H;V1S(&9R;VT@4$A0($5X8V5P=&EO
M;B!#;&%S<SH-"B`J#0H@*B!?7V-L;VYE#0H@*B!?7V-O;G-T<G5C=`T*("H@
M9V5T365S<V%G90T*("H@9V5T0V]D90T*("H@9V5T1FEL90T*("H@9V5T3&EN
M90T*("H@9V5T5')A8V53869E#0H@*B!G9714<F%C95-A9F5!<U-T<FEN9PT*
M("H@7U]T;U-T<FEN9PT*("H-"B`J(#4I(%5S86=E(&5X86UP;&4-"B`J#0H@
M*B`\8V]D93X-"B`J("!R97%U:7)E7V]N8V4@)U!%05(O17AC97!T:6]N+G!H
M<"<[#0H@*@T*("H@(&-L87-S(%1E<W0@>PT*("H@("`@(&9U;F-T:6]N(&9O
M;R@I('L-"B`J("`@("`@("`@=&AR;W<@;F5W(%!%05)?17AC97!T:6]N*"=%
M<G)O<B!-97-S86=E)RP@15)23U)?0T]$12D[#0H@*B`@("`@?0T*("H@('T-
M"B`J#0H@*B`@9G5N8W1I;VX@;7E,;V=G97(H)'!E87)?97AC97!T:6]N*2![
M#0H@*B`@("`@96-H;R`D<&5A<E]E>&-E<'1I;VXM/F=E=$UE<W-A9V4H*3L-
M"B`J("!]#0H@*B`@+R\@96%C:"!T:6UE(&$@97AC97!T:6]N(&ES('1H<F]W
M;B!T:&4@)VUY3&]G9V5R)R!W:6QL(&)E(&-A;&QE9`T*("H@("\O("AI=',@
M=7-E(&ES(&-O;7!L971E;'D@;W!T:6]N86PI#0H@*B`@4$5!4E]%>&-E<'1I
M;VXZ.F%D9$]B<V5R=F5R*"=M>4QO9V=E<B<I.PT*("H@("1T97-T(#T@;F5W
M(%1E<W0[#0H@*B`@=')Y('L-"B`J("`@("`D=&5S="T^9F]O*"D[#0H@*B`@
M?2!C871C:"`H4$5!4E]%>&-E<'1I;VX@)&4I('L-"B`J("`@("!P<FEN="`D
M93L-"B`J("!]#0H@*B`\+V-O9&4^#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@5&]M87,@
M5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@2&%N
M<R!,96QL96QI9"`\:&%N<T!V96QU;2YN970^#0H@*B!`875T:&]R("`@("!"
M97)T<F%N9"!-86YS:6]N(#QB;6%N<VEO;D!M86UA<V%M+F-O;3X-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XS+C,-"B`J#0H@*B\-"F-L87-S(%!%05)?17AC97!T:6]N(&5X=&5N
M9',@17AC97!T:6]N#0I[#0H@("`@8V]N<W0@3T)315)615)?4%))3E0@/2`M
M,CL-"B`@("!C;VYS="!/0E-%4E9%4E]44DE'1T52(#T@+30[#0H@("`@8V]N
M<W0@3T)315)615)?1$E%(#T@+3@[#0H@("`@<')O=&5C=&5D("1C875S93L-
M"B`@("!P<FEV871E('-T871I8R`D7V]B<V5R=F5R<R`](&%R<F%Y*"D[#0H@
M("`@<')I=F%T92!S=&%T:6,@)%]U;FEQ=65I9"`](#`[#0H@("`@<')I=F%T
M92`D7W1R86-E.PT*#0H@("`@+RHJ#0H@("`@("H@4W5P<&]R=&5D('-I9VYA
M='5R97,Z#0H@("`@("H@4$5!4E]%>&-E<'1I;VXH<W1R:6YG("1M97-S86=E
M*3L-"B`@("`@*B!014%27T5X8V5P=&EO;BAS=')I;F<@)&UE<W-A9V4L(&EN
M="`D8V]D92D[#0H@("`@("H@4$5!4E]%>&-E<'1I;VXH<W1R:6YG("1M97-S
M86=E+"!%>&-E<'1I;VX@)&-A=7-E*3L-"B`@("`@*B!014%27T5X8V5P=&EO
M;BAS=')I;F<@)&UE<W-A9V4L($5X8V5P=&EO;B`D8V%U<V4L(&EN="`D8V]D
M92D[#0H@("`@("H@4$5!4E]%>&-E<'1I;VXH<W1R:6YG("1M97-S86=E+"!A
M<G)A>2`D8V%U<V5S*3L-"B`@("`@*B!014%27T5X8V5P=&EO;BAS=')I;F<@
M)&UE<W-A9V4L(&%R<F%Y("1C875S97,L(&EN="`D8V]D92D[#0H@("`@("HO
M#0H@("`@<'5B;&EC(&9U;F-T:6]N(%]?8V]N<W1R=6-T*"1M97-S86=E+"`D
M<#(@/2!N=6QL+"`D<#,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*&ES
M7VEN="@D<#(I*2![#0H@("`@("`@("`@("`D8V]D92`]("1P,CL-"B`@("`@
M("`@("`@("1T:&ES+3YC875S92`](&YU;&P[#0H@("`@("`@('T@96QS96EF
M("@D<#(@:6YS=&%N8V5O9B!%>&-E<'1I;VX@?'P@:7-?87)R87DH)'`R*2D@
M>PT*("`@("`@("`@("`@)&-O9&4@/2`D<#,[#0H@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'`R*2`F)B!I<W-E="@D<#);)VUE<W-A9V4G72DI('L-"B`@
M("`@("`@("`@("`@("`O+R!F:7@@<&]T96YT:6%L('!R;V)L96T@;V8@<&%S
M<VEN9R!I;B!A('-I;F=L92!W87)N:6YG#0H@("`@("`@("`@("`@("`@)'`R
M(#T@87)R87DH)'`R*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M:&ES+3YC875S92`]("1P,CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1C;V1E(#T@;G5L;#L-"B`@("`@("`@("`@("1T:&ES+3YC875S92`]
M(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@<&%R96YT.CI?7V-O;G-T<G5C
M="@D;65S<V%G92P@)&-O9&4I.PT*("`@("`@("`D=&AI<RT^<VEG;F%L*"D[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&UI>&5D("1C86QL
M8F%C:R`@+2!!('9A;&ED('!H<"!C86QL8F%C:RP@<V5E('!H<"!F=6YC(&ES
M7V-A;&QA8FQE*"D-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M
M($$@4$5!4E]%>&-E<'1I;VXZ.D]"4T525D527RH@8V]N<W1A;G0-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M($%N(&%R<F%Y*&-O;G-T(%!%
M05)?17AC97!T:6]N.CI/0E-%4E9%4E\J+`T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;6EX960@)&]P=&EO;G,I#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;&%B96P@("`@5&AE(&YA;64@;V8@=&AE(&]B<V5R=F5R+B!5
M<V4@=&AI<R!I9B!Y;W4@=V%N=`T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('1O(')E;6]V92!I="!L871E<B!W:71H(')E;6]V94]B<V5R=F5R
M*"D-"B`@("`@*B\-"B`@("!P=6)L:6,@<W1A=&EC(&9U;F-T:6]N(&%D9$]B
M<V5R=F5R*"1C86QL8F%C:RP@)&QA8F5L(#T@)V1E9F%U;'0G*0T*("`@('L-
M"B`@("`@("`@<V5L9CHZ)%]O8G-E<G9E<G-;)&QA8F5L72`]("1C86QL8F%C
M:SL-"B`@("!]#0H-"B`@("!P=6)L:6,@<W1A=&EC(&9U;F-T:6]N(')E;6]V
M94]B<V5R=F5R*"1L86)E;"`]("=D969A=6QT)RD-"B`@("![#0H@("`@("`@
M('5N<V5T*'-E;&8Z.B1?;V)S97)V97)S6R1L86)E;%TI.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!R971U<FX@:6YT('5N:7%U92!I9&5N=&EF:65R
M(&9O<B!A;B!O8G-E<G9E<@T*("`@("`J+PT*("`@('!U8FQI8R!S=&%T:6,@
M9G5N8W1I;VX@9V5T56YI<75E260H*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M('-E;&8Z.B1?=6YI<75E:60K*SL-"B`@("!]#0H-"B`@("!P<FEV871E(&9U
M;F-T:6]N('-I9VYA;"@I#0H@("`@>PT*("`@("`@("!F;W)E86-H("AS96QF
M.CHD7V]B<V5R=F5R<R!A<R`D9G5N8RD@>PT*("`@("`@("`@("`@:68@*&ES
M7V-A;&QA8FQE*"1F=6YC*2D@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E
M<E]F=6YC*"1F=6YC+"`D=&AI<RD[#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!S971T>7!E*"1F=6YC
M+"`G87)R87DG*3L-"B`@("`@("`@("`@('-W:71C:"`H)&9U;F-;,%TI('L-
M"B`@("`@("`@("`@("`@("!C87-E('-E;&8Z.D]"4T525D527U!224Y4(#H-
M"B`@("`@("`@("`@("`@("`@("`@)&8@/2`H:7-S970H)&9U;F-;,5TI*2`_
M("1F=6YC6S%=(#H@)R5S)SL-"B`@("`@("`@("`@("`@("`@("`@<')I;G1F
M*"1F+"`D=&AI<RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92!S96QF.CI/0E-%4E9%
M4E]44DE'1T52(#H-"B`@("`@("`@("`@("`@("`@("`@)&8@/2`H:7-S970H
M)&9U;F-;,5TI*2`_("1F=6YC6S%=(#H@15]54T527TY/5$E#13L-"B`@("`@
M("`@("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@D=&AI<RT^9V5T365S<V%G
M92@I+"`D9BD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@(&-A<V4@<V5L9CHZ3T)315)615)?1$E%(#H-"B`@("`@("`@
M("`@("`@("`@("`@)&8@/2`H:7-S970H)&9U;F-;,5TI*2`_("1F=6YC6S%=
M(#H@)R5S)SL-"B`@("`@("`@("`@("`@("`@("`@9&EE*'!R:6YT9B@D9BP@
M)'1H:7,M/F=E=$UE<W-A9V4H*2DI.PT*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@
M("`@("`@("!T<FEG9V5R7V5R<F]R*"=I;G9A;&ED(&]B<V5R=F5R('1Y<&4G
M+"!%7U5315)?5T%23DE.1RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@<W!E8VEF:6,@97)R
M;W(@:6YF;W)M871I;VX@=&AA="!C86X@8F4@=7-E9"!F;W(@;6]R92!D971A
M:6QE9`T*("`@("`J(&5R<F]R(&UE<W-A9V5S(&]R('1R86YS;&%T:6]N+@T*
M("`@("`J#0H@("`@("H@5&AI<R!M971H;V0@;6%Y(&)E(&]V97)R:61D96X@
M:6X@8VAI;&0@97AC97!T:6]N(&-L87-S97,@:6X@;W)D97(-"B`@("`@*B!T
M;R!A9&0@9G5N8W1I;VYA;&ET>2!N;W0@<')E<V5N="!I;B!014%27T5X8V5P
M=&EO;B!A;F0@:7,@82!P;&%C96AO;&1E<@T*("`@("`J('1O(&1E9FEN92!!
M4$D-"B`@("`@*@T*("`@("`J(%1H92!R971U<FYE9"!A<G)A>2!M=7-T(&)E
M(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<B`]/B!V86QU92!L
M:6ME('-O.@T*("`@("`J(#QP<F4^#0H@("`@("H@87)R87DH)VYA;64G(#T^
M("1N86UE+"`G8V]N=&5X="<@/3X@87)R87DH+BXN*2D-"B`@("`@*B`\+W!R
M93X-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@<'5B;&EC
M(&9U;F-T:6]N(&=E=$5R<F]R1&%T82@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@87)R87DH*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS
M('1H92!E>&-E<'1I;VX@=&AA="!C875S960@=&AI<R!E>&-E<'1I;VX@=&\@
M8F4@=&AR;W=N#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<F5T
M=7)N($5X8V5P=&EO;GQA<G)A>2!4:&4@8V]N=&5X="!O9B!T:&4@97AC97!T
M:6]N#0H@("`@("HO#0H@("`@<'5B;&EC(&9U;F-T:6]N(&=E=$-A=7-E*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^8V%U<V4[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@1G5N8W1I;VX@;75S="!B92!P=6)L:6,@=&\@
M8V%L;"!O;B!C875S960@97AC97!T:6]N<PT*("`@("`J($!P87)A;2!A<G)A
M>0T*("`@("`J+PT*("`@('!U8FQI8R!F=6YC=&EO;B!G971#875S94UE<W-A
M9V4H)B1C875S97,I#0H@("`@>PT*("`@("`@("`D=')A8V4@/2`D=&AI<RT^
M9V5T5')A8V53869E*"D[#0H@("`@("`@("1C875S92`](&%R<F%Y*"=C;&%S
M<R<@("`]/B!G971?8VQA<W,H)'1H:7,I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`G;65S<V%G92<@/3X@)'1H:7,M/FUE<W-A9V4L#0H@("`@("`@("`@
M("`@("`@("`@("`@("=F:6QE)R`]/B`G=6YK;F]W;B<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("=L:6YE)R`]/B`G=6YK;F]W;B<I.PT*("`@("`@("!I
M9B`H:7-S970H)'1R86-E6S!=*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T<F%C95LP75LG9FEL92==*2D@>PT*("`@("`@("`@("`@("`@("1C875S
M95LG9FEL92==(#T@)'1R86-E6S!=6R=F:6QE)UT[#0H@("`@("`@("`@("`@
M("`@)&-A=7-E6R=L:6YE)UT@/2`D=')A8V5;,%U;)VQI;F4G73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D8V%U<V5S6UT@/2`D8V%U
M<V4[#0H@("`@("`@(&EF("@D=&AI<RT^8V%U<V4@:6YS=&%N8V5O9B!014%2
M7T5X8V5P=&EO;BD@>PT*("`@("`@("`@("`@)'1H:7,M/F-A=7-E+3YG971#
M875S94UE<W-A9V4H)&-A=7-E<RD[#0H@("`@("`@('T@96QS96EF("@D=&AI
M<RT^8V%U<V4@:6YS=&%N8V5O9B!%>&-E<'1I;VXI('L-"B`@("`@("`@("`@
M("1C875S97-;72`](&%R<F%Y*"=C;&%S<R<@("`]/B!G971?8VQA<W,H)&-A
M=7-E*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=M97-S86=E)R`]
M/B`D8V%U<V4M/F=E=$UE<W-A9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=F:6QE)R`]/B`D8V%U<V4M/F=E=$9I;&4H*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=L:6YE)R`]/B`D8V%U<V4M/F=E=$QI;F4H
M*2D[#0H-"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T:&ES+3YC875S
M92DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC875S92!A<R`D
M8V%U<V4I('L-"B`@("`@("`@("`@("`@("!I9B`H)&-A=7-E(&EN<W1A;F-E
M;V8@4$5!4E]%>&-E<'1I;VXI('L-"B`@("`@("`@("`@("`@("`@("`@)&-A
M=7-E+3YG971#875S94UE<W-A9V4H)&-A=7-E<RD[#0H@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"1C875S92!I;G-T86YC96]F($5X8V5P=&EO;BD@>PT*
M("`@("`@("`@("`@("`@("`@("`D8V%U<V5S6UT@/2!A<G)A>2@G8VQA<W,G
M("`@/3X@9V5T7V-L87-S*"1C875S92DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=M97-S86=E)R`]/B`D8V%U<V4M/F=E=$UE<W-A
M9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9I
M;&4G(#T^("1C875S92T^9V5T1FEL92@I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;&EN92<@/3X@)&-A=7-E+3YG971,:6YE*"DI
M.PT*("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D8V%U<V4I
M("8F(&ES<V5T*"1C875S95LG;65S<V%G92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`O+R!014%27T5R<F]R4W1A8VL@=V%R;FEN9PT*("`@("`@("`@
M("`@("`@("`@("`D8V%U<V5S6UT@/2!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("=C;&%S<R<@/3X@)&-A=7-E6R=P86-K86=E)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G;65S<V%G92<@/3X@)&-A=7-E6R=M97-S
M86=E)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`G9FEL92<@/3X@:7-S
M970H)&-A=7-E6R=C;VYT97AT)UU;)V9I;&4G72D@/PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%U<V5;)V-O;G1E
M>'0G75LG9FEL92==(#H-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5N:VYO=VXG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI;F4G(#T^(&ES<V5T*"1C875S95LG8V]N=&5X="==6R=L:6YE
M)UTI(#\-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-A=7-E6R=C;VYT97AT)UU;)VQI;F4G72`Z#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U;FMN;W=N)RP-
M"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!P=6)L:6,@
M9G5N8W1I;VX@9V5T5')A8V53869E*"D-"B`@("![("`@#0H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]T<F%C92DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?=')A8V4@/2`D=&AI<RT^9V5T5')A8V4H*3L-"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^7W1R86-E*2D@>PT*("`@("`@("`@("`@("`@("1B
M86-K=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W1R86-E(#T@87)R87DH)&)A8VMT<F%C95MC;W5N="@D8F%C
M:W1R86-E*2TQ72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=')A8V4[#0H@("`@?0T*#0H@("`@<'5B;&EC
M(&9U;F-T:6]N(&=E=$5R<F]R0VQA<W,H*0T*("`@('L-"B`@("`@("`@)'1R
M86-E(#T@)'1H:7,M/F=E=%1R86-E4V%F92@I.PT*("`@("`@("!R971U<FX@
M)'1R86-E6S!=6R=C;&%S<R==.PT*("`@('T-"@T*("`@('!U8FQI8R!F=6YC
M=&EO;B!G971%<G)O<DUE=&AO9"@I#0H@("`@>PT*("`@("`@("`D=')A8V4@
M/2`D=&AI<RT^9V5T5')A8V53869E*"D[#0H@("`@("`@(')E='5R;B`D=')A
M8V5;,%U;)V9U;F-T:6]N)UT[#0H@("`@?0T*#0H@("`@<'5B;&EC(&9U;F-T
M:6]N(%]?=&]3=')I;F<H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1?
M4T525D526R=215%515-47U5222==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YT;TAT;6PH*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)'1H:7,M/G1O5&5X="@I.PT*("`@('T-"@T*("`@('!U8FQI8R!F=6YC=&EO
M;B!T;TAT;6PH*0T*("`@('L-"B`@("`@("`@)'1R86-E(#T@)'1H:7,M/F=E
M=%1R86-E4V%F92@I.PT*("`@("`@("`D8V%U<V5S(#T@87)R87DH*3L-"B`@
M("`@("`@)'1H:7,M/F=E=$-A=7-E365S<V%G92@D8V%U<V5S*3L-"B`@("`@
M("`@)&AT;6P@/2`@)SQT86)L92!B;W)D97(](C$B(&-E;&QS<&%C:6YG/2(P
M(CXG("X@(EQN(CL-"B`@("`@("`@9F]R96%C:"`H)&-A=7-E<R!A<R`D:2`]
M/B`D8V%U<V4I('L-"B`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O
M;'-P86X](C,B(&)G8V]L;W(](B-F9CDY.3DB/B<-"B`@("`@("`@("`@("`@
M("X@<W1R7W)E<&5A="@G+2<L("1I*2`N("<@/&(^)R`N("1C875S95LG8VQA
M<W,G72`N("<\+V(^.B`G#0H@("`@("`@("`@("`@("`N(&AT;6QS<&5C:6%L
M8VAA<G,H)&-A=7-E6R=M97-S86=E)UTI("X@)R!I;B`\8CXG("X@)&-A=7-E
M6R=F:6QE)UT@+B`G/"]B/B`G#0H@("`@("`@("`@("`@("`N("=O;B!L:6YE
M(#QB/B<@+B`D8V%U<V5;)VQI;F4G72`N("<\+V(^)PT*("`@("`@("`@("`@
M("`@+B`B/"]T9#X\+W1R/EQN(CL-"B`@("`@("`@?0T*("`@("`@("`D:'1M
M;"`N/2`G/'1R/CQT9"!C;VQS<&%N/2(S(B!B9V-O;&]R/2(C86%A86%A(B!A
M;&EG;CTB8V5N=&5R(CX\8CY%>&-E<'1I;VX@=')A8V4\+V(^/"]T9#X\+W1R
M/B<@+B`B7&XB#0H@("`@("`@("`@("`@("`N("<\='(^/'1D(&%L:6=N/2)C
M96YT97(B(&)G8V]L;W(](B-C8V-C8V,B('=I9'1H/2(R,"(^/&(^(SPO8CX\
M+W1D/B<-"B`@("`@("`@("`@("`@("X@)SQT9"!A;&EG;CTB8V5N=&5R(B!B
M9V-O;&]R/2(C8V-C8V-C(CX\8CY&=6YC=&EO;CPO8CX\+W1D/B<-"B`@("`@
M("`@("`@("`@("X@)SQT9"!A;&EG;CTB8V5N=&5R(B!B9V-O;&]R/2(C8V-C
M8V-C(CX\8CY,;V-A=&EO;CPO8CX\+W1D/CPO='(^)R`N(")<;B([#0H-"B`@
M("`@("`@9F]R96%C:"`H)'1R86-E(&%S("1K(#T^("1V*2![#0H@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1R/CQT9"!A;&EG;CTB8V5N=&5R(CXG("X@)&L@
M+B`G/"]T9#XG#0H@("`@("`@("`@("`@("`@("`@+B`G/'1D/B<[#0H@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1V6R=C;&%S<R==*2D@>PT*("`@("`@("`@
M("`@("`@("1H=&UL("X]("1V6R=C;&%S<R==("X@)'9;)W1Y<&4G73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1H=&UL("X]("1V6R=F=6YC=&EO
M;B==.PT*("`@("`@("`@("`@)&%R9W,@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D=ELG87)G<R==*2D@>PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1V6R=A<F=S)UT@87,@)&%R9RD@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D87)G*2D@)&%R9W-;72`]("=N=6QL)SL-
M"B`@("`@("`@("`@("`@("`@("`@96QS96EF("AI<U]A<G)A>2@D87)G*2D@
M)&%R9W-;72`]("=!<G)A>2<[#0H@("`@("`@("`@("`@("`@("`@(&5L<V5I
M9B`H:7-?;V)J96-T*"1A<F<I*2`D87)G<UM=(#T@)T]B:F5C="@G+F=E=%]C
M;&%S<R@D87)G*2XG*2<[#0H@("`@("`@("`@("`@("`@("`@(&5L<V5I9B`H
M:7-?8F]O;"@D87)G*2D@)&%R9W-;72`]("1A<F<@/R`G=')U92<@.B`G9F%L
M<V4G.PT*("`@("`@("`@("`@("`@("`@("!E;'-E:68@*&ES7VEN="@D87)G
M*2!\?"!I<U]D;W5B;&4H)&%R9RDI("1A<F=S6UT@/2`D87)G.PT*("`@("`@
M("`@("`@("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1A<F<@/2`H<W1R:6YG*21A<F<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<W1R(#T@:'1M;'-P96-I86QC:&%R<RAS=6)S='(H)&%R9RP@,"P@,38I
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&%R9RD@
M/B`Q-BD@)'-T<B`N/2`G)FAE;&QI<#LG.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R9W-;72`]("(G(B`N("1S='(@+B`B)R([#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D:'1M;"`N/2`G*"<@+B!I;7!L;V1E*"<L("<L)&%R
M9W,I("X@)RDG#0H@("`@("`@("`@("`@("`@("`@+B`G/"]T9#XG#0H@("`@
M("`@("`@("`@("`@("`@+B`G/'1D/B<@+B`H:7-S970H)'9;)V9I;&4G72D@
M/R`D=ELG9FEL92==(#H@)W5N:VYO=VXG*0T*("`@("`@("`@("`@("`@("`@
M("X@)SHG("X@*&ES<V5T*"1V6R=L:6YE)UTI(#\@)'9;)VQI;F4G72`Z("=U
M;FMN;W=N)RD-"B`@("`@("`@("`@("`@("`@("`N("<\+W1D/CPO='(^)R`N
M(")<;B([#0H@("`@("`@('T-"B`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0@
M86QI9VX](F-E;G1E<B(^)R`N("@D:RLQ*2`N("<\+W1D/B<-"B`@("`@("`@
M("`@("`@("X@)SQT9#Y[;6%I;GT\+W1D/B<-"B`@("`@("`@("`@("`@("X@
M)SQT9#XF;F)S<#L\+W1D/CPO='(^)R`N(")<;B(-"B`@("`@("`@("`@("`@
M("X@)SPO=&%B;&4^)SL-"B`@("`@("`@<F5T=7)N("1H=&UL.PT*("`@('T-
M"@T*("`@('!U8FQI8R!F=6YC=&EO;B!T;U1E>'0H*0T*("`@('L-"B`@("`@
M("`@)&-A=7-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3YG971#875S
M94UE<W-A9V4H)&-A=7-E<RD[#0H@("`@("`@("1C875S94US9R`]("<G.PT*
M("`@("`@("!F;W)E86-H("@D8V%U<V5S(&%S("1I(#T^("1C875S92D@>PT*
M("`@("`@("`@("`@)&-A=7-E37-G("X]('-T<E]R97!E870H)R`G+"`D:2D@
M+B`D8V%U<V5;)V-L87-S)UT@+B`G.B`G#0H@("`@("`@("`@("`@("`@("`@
M+B`D8V%U<V5;)VUE<W-A9V4G72`N("<@:6X@)R`N("1C875S95LG9FEL92==
M#0H@("`@("`@("`@("`@("`@("`@+B`G(&]N(&QI;F4@)R`N("1C875S95LG
M;&EN92==("X@(EQN(CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&-A
M=7-E37-G("X@)'1H:7,M/F=E=%1R86-E07-3=')I;F<H*3L-"B`@("!]#0I]
M#0H-"C\^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O1G)O;G1E;F0N<&AP````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,3<T`#$P-3$U-#,Q
M,#4W`#`R,#,V-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!014%27T9R;VYT96YD+"!T:&4@<VEN
M9VQE=&]N+6)A<V5D(&9R;VYT96YD(&9O<B!U<V5R(&EN<'5T+V]U='!U=`T*
M("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS
M92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B
M+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!&<F]N=&5N
M9"YP:'`L=B`Q+CD@,C`P-B\P,R\P,R`Q,SHQ,SHP-R!P86IO>64@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J(%=H:6-H('5S97(@:6YT97)F
M86-E(&-L87-S(&ES(&)E:6YG('5S960N#0H@*B!`=F%R('-T<FEN9R!C;&%S
M<R!N86UE#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]&4D].5$5.1%]#3$%34R==
M(#T@)U!%05)?1G)O;G1E;F1?0TQ))SL-"@T*+RHJ#0H@*B!);G-T86YC92!O
M9B`D7U!%05)?0V]M;6%N9%]U:6-L87-S+@T*("H@0'9A<B!O8FIE8W0-"B`J
M+PT*)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==(#T@;G5L
M;#L-"@T*+RHJ#0H@*B!3:6YG;&5T;VXM8F%S960@9G)O;G1E;F0@9F]R(%!%
M05(@=7-E<B!I;G!U="]O=71P=70-"B`J#0H@*B!.;W1E('1H870@9G)O;G1E
M;F0@8VQA<W-E<R!M=7-T(&EM<&QE;65N="!U<V5R0V]N9FER;2@I+"!A;F0@
M<VAO=6P@:6UP;&5M96YT#0H@*B!D:7-P;&%Y1F%T86Q%<G)O<B@I(&%N9"!O
M=71P=71$871A*"D-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27T9R
M;VYT96YD(&5X=&5N9',@4$5!4@T*>PT*("`@("\J*@T*("`@("`J(%)E=')I
M979E('1H92!F<F]N=&5N9"!O8FIE8W0-"B`@("`@*B!`<F5T=7)N(%!%05)?
M1G)O;G1E;F1?0TQ)?%!%05)?1G)O;G1E;F1?5V5B?%!%05)?1G)O;G1E;F1?
M1W1K#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9S
M:6YG;&5T;VXH)'1Y<&4@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*"1T
M>7!E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1'3$]"
M04Q36R=?4$5!4E]&4D].5$5.1%]324Y'3$543TXG72DI('L-"B`@("`@("`@
M("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M83L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UT[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D82`](%!%05)?1G)O;G1E;F0Z.G-E=$9R;VYT
M96YD0VQA<W,H)'1Y<&4I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T('1H92!F<F]N
M=&5N9"!C;&%S<R!T:&%T('=I;&P@8F4@=7-E9"!B>2!C86QL<R!T;R![0&QI
M;FL@<VEN9VQE=&]N*"E]#0H@("`@("H-"B`@("`@*B!&<F]N=&5N9',@87)E
M(&5X<&5C=&5D('1O(&-O;F9O<FT@=&\@=&AE(%!%05(@;F%M:6YG('-T86YD
M87)D(&]F#0H@("`@("H@7R`]/B!$25)%0U1/4EE?4T5005)!5$]2("A014%2
M7T9R;VYT96YD7T-,22!I<R!I;B!014%2+T9R;VYT96YD+T-,22YP:'`I#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=6EC;&%S<R!F=6QL(&-L87-S(&YA;64-
M"B`@("`@*B!`<F5T=7)N(%!%05)?1G)O;G1E;F0-"B`@("`@*B!`<W1A=&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)G-E=$9R;VYT96YD0VQA<W,H)'5I
M8VQA<W,I#0H@("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1'3$]"04Q3
M6R=?4$5!4E]&4D].5$5.1%]324Y'3$543TXG72D@)B8-"B`@("`@("`@("`@
M("`@:7-?82@D1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UTL
M("1U:6-L87-S*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?
M4$5!4E]&4D].5$5.1%]324Y'3$543TXG73L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@D=6EC;&%S<RDI('L-"B`@("`@("`@("`@
M("1F:6QE(#T@<W1R7W)E<&QA8V4H)U\G+"`G+R<L("1U:6-L87-S*2`N("<N
M<&AP)SL-"B`@("`@("`@("`@(&EF("A014%27T9R;VYT96YD.CII<TEN8VQU
M9&5A8FQE*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`D9FEL93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H8VQA<W-?97AI<W1S*"1U:6-L87-S*2D@>PT*("`@("`@("`@("`@)&]B
M:B`]("9N97<@)'5I8VQA<W,[#0H@("`@("`@("`@("`O+R!Q=6EC:R!T97-T
M('1O('-E92!I9B!T:&ES(&-L87-S(&EM<&QE;65N=',@82!F97<@;V8@=&AE
M(&UO<W0-"B`@("`@("`@("`@("\O(&EM<&]R=&%N="!F<F]N=&5N9"!M971H
M;V1S#0H@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V)J+"`G=7-E
M<D-O;F9I<FTG*2D@>PT*("`@("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!
M4E]&4D].5$5.1%]324Y'3$543TXG72`]("8D;V)J.PT*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=?4$5!4E]&4D].5$5.1%]#3$%34R==(#T@)'5I8VQA
M<W,[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1O8FH[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1E<G(@/2!014%2.CIR86ES
M945R<F]R*")N;W0@82!F<F]N=&5N9"!C;&%S<SH@)'5I8VQA<W,B*3L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@B;F\@
M<W5C:"!C;&%S<SH@)'5I8VQA<W,B*3L-"B`@("`@("`@<F5T=7)N("1E<G([
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T('1H92!F<F]N=&5N9"!C
M;&%S<R!T:&%T('=I;&P@8F4@=7-E9"!B>2!C86QL<R!T;R![0&QI;FL@<VEN
M9VQE=&]N*"E]#0H@("`@("H-"B`@("`@*B!&<F]N=&5N9',@87)E(&5X<&5C
M=&5D('1O(&)E(&$@9&5S8V5N9&%N="!O9B!014%27T9R;VYT96YD#0H@("`@
M("H@0'!A<F%M(%!%05)?1G)O;G1E;F0-"B`@("`@*B!`<F5T=7)N(%!%05)?
M1G)O;G1E;F0-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@)G-E=$9R;VYT96YD3V)J96-T*"1U:6]B:F5C="D-"B`@("![#0H@("`@
M("`@(&EF("AI<U]O8FIE8W0H)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)
M3D=,151/3B==*2`F)@T*("`@("`@("`@("`@("!I<U]A*"1'3$]"04Q36R=?
M4$5!4E]&4D].5$5.1%]324Y'3$543TXG72P@9V5T7V-L87-S*"1U:6]B:F5C
M="DI*2![#0H@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T92
M3TY414Y$7U-)3D=,151/3B==.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-?82@D=6EO8FIE8W0L("=014%27T9R;VYT96YD)RDI('L-"B`@("`@("`@
M("`@("1E<G(@/2!014%2.CIR86ES945R<F]R*"=N;W0@82!V86QI9"!F<F]N
M=&5N9"!C;&%S<SH@*"<@+@T*("`@("`@("`@("`@("`@(&=E=%]C;&%S<R@D
M=6EO8FIE8W0I("X@)RDG*3L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*
M("`@("`@("!]#0H@("`@("`@("\O('%U:6-K('1E<W0@=&\@<V5E(&EF('1H
M:7,@8VQA<W,@:6UP;&5M96YT<R!A(&9E=R!O9B!T:&4@;6]S=`T*("`@("`@
M("`O+R!I;7!O<G1A;G0@9G)O;G1E;F0@;65T:&]D<PT*("`@("`@("!I9B`H
M;65T:&]D7V5X:7-T<R@D=6EO8FIE8W0L("=U<V5R0V]N9FER;2<I*2![#0H@
M("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].
M)UT@/2`F)'5I;V)J96-T.PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]014%2
M7T923TY414Y$7T-,05-3)UT@/2!G971?8VQA<W,H)'5I;V)J96-T*3L-"B`@
M("`@("`@("`@(')E='5R;B`D=6EO8FIE8W0[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@B;F]T(&$@
M=F%L=64@9G)O;G1E;F0@8VQA<W,Z("@B("X@9V5T7V-L87-S*"1U:6]B:F5C
M="D-"B`@("`@("`@("`@("`@("`N("<I)RD[#0H@("`@("`@("`@("!R971U
M<FX@)&5R<CL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@<F5L871I=F4@;W(@86)S;VQU=&4@:6YC
M;'5D92!P871H#0H@("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("H@0'-T
M871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES26YC;'5D96%B;&4H)'!A
M=&@I#0H@("`@>PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H)'!A=&@I("8F
M(&ES7W)E861A8FQE*"1P871H*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@('T-"B`@("`@("`@)&EP871H(#T@97AP;&]D92A0051(
M7U-%4$%2051/4BP@:6YI7V=E="@G:6YC;'5D95]P871H)RDI.PT*("`@("`@
M("!F;W)E86-H("@D:7!A=&@@87,@)&EN8VQU9&4I('L-"B`@("`@("`@("`@
M("1T97-T(#T@<F5A;'!A=&@H)&EN8VQU9&4@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)'!A=&@I.PT*("`@("`@("`@("`@:68@*"$D=&5S="D@>R`O+R!S
M=7!P;W)T('=R87!P97)S(&QI:V4@<&AA<B`H<F5A;'!A=&@@:G5S="!D;VXG
M="!W;W)K('=I=&@@=&AE;2D-"B`@("`@("`@("`@("`@("`D=&5S="`]("1I
M;F-L=61E("X@1$E214-43U)97U-%4$%2051/4B`N("1P871H.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1T97-T*2`F
M)B!I<U]R96%D86)L92@D=&5S="DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M(%!%05)?0V]N9FEG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG
M*"8D8V]N9FEG*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4
M:&ES(&-A;B!B92!O=F5R<FED9&5N('1O(&%L;&]W('-E<W-I;VXM8F%S960@
M=&5M<&]R87)Y(&9I;&4@;6%N86=E;65N=`T*("`@("`J#0H@("`@("H@0GD@
M9&5F875L="P@86QL(&9I;&5S(&%R92!D96QE=&5D(&%T('1H92!E;F0@;V8@
M82!S97-S:6]N+B`@5&AE('=E8B!I;G-T86QL97(-"B`@("`@*B!N965D<R!T
M;R!B92!A8FQE('1O('-U<W1A:6X@82!L:7-T(&]V97(@;6%N>2!S97-S:6]N
M<R!I;B!O<F1E<B!T;R!S=7!P;W)T#0H@("`@("H@=7-E<B!I;G1E<F%C=&EO
M;B!W:71H(&EN<W1A;&P@<V-R:7!T<PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&%D9%1E;7!&:6QE*"1F:6QE*0T*("`@('L-"B`@("`@("`@)$=,3T)!3%-;
M)U]014%27T-O;6UO;E]T96UP9FEL97,G75M=(#T@)&9I;&4[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@;&]G*"1M<V<L("1A<'!E;F1?8W)L9B`]('1R=64I
M#0H@("`@>PT*("`@('T-"GT-"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A
M;&QE<BYP:'``````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$W
M-C$U,0`Q,#4Q-30S,3`U-P`P,C`U-3$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]);G-T
M86QL97(-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@
M*B!`875T:&]R("`@("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N8V]M
M/@T*("H@0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!)
M;G-T86QL97(N<&AP+'8@,2XR,C@N,BXQ(#(P,#8O,#,O,#4@,C`Z,#<Z-3(@
M8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(%5S960@9F]R
M(&EN<W1A;&QA=&EO;B!G<F]U<',@:6X@<&%C:V%G92YX;6P@,BXP(&%N9"!P
M;&%T9F]R;2!E>&-E<'1I;VYS#0H@*B\-"G)E<75I<F5?;VYC92`G3U,O1W5E
M<W,N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]$;W=N;&]A9&5R+G!H<"<[
M#0H-"F1E9FEN92@G4$5!4E])3E-404Q,15)?3D]"24Y!4EDG+"`M,C0P*3L-
M"B\J*@T*("H@061M:6YI<W1R871I;VX@8VQA<W,@=7-E9"!T;R!I;G-T86QL
M(%!%05(@<&%C:V%G97,@86YD(&UA:6YT86EN('1H90T*("H@:6YS=&%L;&5D
M('!A8VMA9V4@9&%T86)A<V4N#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+B!#
M;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($UA<G1I;B!*
M86YS96X@/&UJ0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!0
M14%27TEN<W1A;&QE<B!E>'1E;F1S(%!%05)?1&]W;FQO861E<@T*>PT*("`@
M("\O('M[>R!P<F]P97)T:65S#0H-"B`@("`O*BH@;F%M92!O9B!T:&4@<&%C
M:V%G92!D:7)E8W1O<GDL(&9O<B!E>&%M<&QE($9O;RTQ+C`-"B`@("`@*B!`
M=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D<&MG9&ER.PT*#0H@("`@
M+RHJ(&1I<F5C=&]R>2!W:&5R92!02%`@8V]D92!F:6QE<R!G;PT*("`@("`J
M($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1P:'!D:7([#0H-"B`@
M("`O*BH@9&ER96-T;W)Y('=H97)E(%!(4"!E>'1E;G-I;VX@9FEL97,@9V\-
M"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D97AT9&ER
M.PT*#0H@("`@+RHJ(&1I<F5C=&]R>2!W:&5R92!D;V-U;65N=&%T:6]N(&=O
M97,-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D9&]C
M9&ER.PT*#0H@("`@+RHJ(&EN<W1A;&QA=&EO;B!R;V]T(&1I<F5C=&]R>2`H
M86QA(%!(4"=S($E.4U1!3$Q?4D]/5"!O<@T*("`@("`J(&%U=&]M86ME)W,@
M1$535$1)4@T*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R
M("1I;G-T86QL<F]O="`]("<G.PT*#0H@("`@+RHJ(&1E8G5G(&QE=F5L#0H@
M("`@("H@0'9A<B!I;G0-"B`@("`@*B\-"B`@("!V87(@)&1E8G5G(#T@,3L-
M"@T*("`@("\J*B!T96UP;W)A<GD@9&ER96-T;W)Y#0H@("`@("H@0'9A<B!S
M=')I;F<-"B`@("`@*B\-"B`@("!V87(@)'1M<&1I<CL-"@T*("`@("\J*@T*
M("`@("`J(%!%05)?4F5G:7-T<GD@;V)J96-T('5S960@8GD@=&AE(&EN<W1A
M;&QE<@T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J+PT*("`@
M('9A<B`D<F5G:7-T<GD[#0H-"B`@("`O*BH-"B`@("`@*B!A<G)A>2!O9B!0
M14%27T1O=VYL;V%D97)?4&%C:V%G97,-"B`@("`@*B!`=F%R(&%R<F%Y#0H@
M("`@("HO#0H@("`@=F%R("1?9&]W;FQO861E9%!A8VMA9V5S.PT*#0H@("`@
M+RHJ($QI<W0@;V8@9FEL92!T<F%N<V%C=&EO;G,@<75E=65D(&9O<B!A;B!I
M;G-T86QL+W5P9W)A9&4O=6YI;G-T86QL+@T*("`@("`J#0H@("`@("H@($9O
M<FUA=#H-"B`@("`@*B`@("!A<G)A>2@-"B`@("`@*B`@("`@(#`@/3X@87)R
M87DH(G)E;F%M92`]/B!A<G)A>2@B9G)O;2UF:6QE(BP@(G1O+69I;&4B*2DL
M#0H@("`@("H@("`@("`Q(#T^(&%R<F%Y*")D96QE=&4B(#T^(&%R<F%Y*")F
M:6QE+71O+61E;&5T92(I*2P-"B`@("`@*B`@("`@("XN+@T*("`@("`J("`@
M("D-"B`@("`@*@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V
M87(@)&9I;&5?;W!E<F%T:6]N<R`](&%R<F%Y*"D[#0H-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@
M4$5!4E]);G-T86QL97(@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@;V)J96-T("1U:2!U<V5R(&EN=&5R9F%C92!O8FIE8W0@*&EN<W1A
M;F-E(&]F(%!%05)?1G)O;G1E;F1?*BD-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]);G-T86QL
M97(H)B1U:2D-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM;VXH
M*3L-"B`@("`@("`@)'1H:7,M/G-E=$9R;VYT96YD3V)J96-T*"1U:2D[#0H@
M("`@("`@("1T:&ES+3YD96)U9R`]("1T:&ES+3YC;VYF:6<M/F=E="@G=F5R
M8F]S92<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H)&]P
M=&EO;G,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V]P=&EO;G,@/2`D;W!T
M:6]N<SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C;VYF
M:6<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^8V]N9FEG(#T@)B1C;VYF:6<[
M#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)&-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@(&9U;F-T:6]N
M(%]R96UO=F5"86-K=7!S*"1F:6QE<RD-"B`@("![#0H@("`@("`@(&9O<F5A
M8V@@*"1F:6QE<R!A<R`D<&%T:"D@>PT*("`@("`@("`@("`@)'1H:7,M/F%D
M9$9I;&5/<&5R871I;VXH)W)E;6]V96)A8VMU<"<L(&%R<F%Y*"1P871H*2D[
M#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R![>WL@7V1E;&5T95!A8VMA
M9V5&:6QE<R@I#0H-"B`@("`O*BH-"B`@("`@*B!$96QE=&4@82!P86-K86=E
M)W,@:6YS=&%L;&5D(&9I;&5S+"!D;V5S(&YO="!R96UO=F4@96UP='D@9&ER
M96-T;W)I97,N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA
M9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@
M("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&AE;B!F:6QE<R!A<F4@8F%C
M:V5D('5P(&9I<G-T#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C
M8V5S<RP@;W(@82!014%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]D96QE=&50
M86-K86=E1FEL97,H)'!A8VMA9V4L("1C:&%N;F5L(#T@9F%L<V4L("1B86-K
M=7`@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A)&-H86YN96PI('L-
M"B`@("`@("`@("`@("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%S=')L96XH)'!A8VMA9V4I*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(DYO('!A8VMA9V4@
M=&\@=6YI;G-T86QL(&=I=F5N(BD[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*'-T<G1O;&]W97(H)'!A8VMA9V4I(#T]("=P96%R)R`F)B`D8VAA;FYE;"`]
M/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@+R\@=&\@879O:60@
M<F%C92!C;VYD:71I;VYS+"!I;F-L=61E(&%L;"!P;W-S:6)L92!N965D960@
M9FEL97,-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]487-K+T-O
M;6UO;BYP:'`G.PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U1A
M<VLO4F5P;&%C92YP:'`G.PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+U1A<VLO56YI>&5O;"YP:'`G.PT*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+U1A<VLO5VEN9&]W<V5O;"YP:'`G.PT*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8Q+G!H<"<[#0H@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP
M)SL-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL
M92]'96YE<F%T;W(O=C$N<&AP)SL-"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G4$5!4B]086-K86=E1FEL92]'96YE<F%T;W(O=C(N<&AP)SL-"B`@("`@
M("`@?0T*("`@("`@("`D9FEL96QI<W0@/2`D=&AI<RT^7W)E9VES=')Y+3YP
M86-K86=E26YF;R@D<&%C:V%G92P@)V9I;&5L:7-T)RP@)&-H86YN96PI.PT*
M("`@("`@("!I9B`H)&9I;&5L:7-T(#T](&YU;&PI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-H86YN96PO)'!A8VMA9V4@
M;F]T(&EN<W1A;&QE9"(I.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2!A
M<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D9FEL96QI<W0@87,@)&9I;&4@
M/3X@)'!R;W!S*2![#0H@("`@("`@("`@("!I9B`H96UP='DH)'!R;W!S6R=I
M;G-T86QL961?87,G72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P871H(#T@)'!R;W!S6R=I
M;G-T86QL961?87,G73L-"B`@("`@("`@("`@(&EF("@D8F%C:W5P*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH)V)A8VMU
M<"<L(&%R<F%Y*"1P871H*2D[#0H@("`@("`@("`@("`@("`@)')E=%M=(#T@
M)'!A=&@[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^861D
M1FEL94]P97)A=&EO;B@G9&5L971E)RP@87)R87DH)'!A=&@I*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)&)A8VMU<"D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]I;G-T86QL1FEL92@I
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&5N86UE#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(&%T=')I8G5T97,@9G)O;2`\9FEL93X@=&%G
M(&EN('!A8VMA9V4N>&UL#0H@("`@("H@0'!A<F%M('-T<FEN9R!P871H('1O
M(&EN<W1A;&P@=&AE(&9I;&4@:6X-"B`@("`@*B!`<&%R86T@87)R87D@;W!T
M:6]N<R!F<F]M(&-O;6UA;F0M;&EN90T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]I;G-T86QL1FEL92@D9FEL92P@
M)&%T=',L("1T;7!?<&%T:"P@)&]P=&EO;G,I#0H@("`@>PT*("`@("`@("`O
M+R![>WL@<F5T=7)N(&EF('1H:7,@9FEL92!I<R!M96%N="!F;W(@86YO=&AE
M<B!P;&%T9F]R;0T*("`@("`@("!S=&%T:6,@)&]S.PT*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<F5G:7-T<GDI*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1A='1S6R=P;&%T9F]R
M;2==*2D@>PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1O<RDI('L-"B`@("`@
M("`@("`@("`@("`D;W,@/2!N97<@3U-?1W5E<W,H*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AS=')L96XH)&%T='-;)W!L871F;W)M)UTI
M("8F("1A='1S6R=P;&%T9F]R;2==>S!](#T]("<A)RD@>PT*("`@("`@("`@
M("`@("`@("1N96=A=&4@/2!T<G5E.PT*("`@("`@("`@("`@("`@("1P;&%T
M9F]R;2`]('-U8G-T<B@D871T<ULG<&QA=&9O<FTG72P@,2D[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1N96=A=&4@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("`D<&QA=&9O<FT@/2`D871T<ULG<&QA=&9O
M<FTG73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@H8F]O;"D@
M)&]S+3YM871C:%-I9VYA='5R92@D<&QA=&9O<FTI(#T]/2`D;F5G871E*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B<VMI<'!E9"`D9FEL
M92`H;65A;G0@9F]R("1A='1S6W!L871F;W)M72P@=V4@87)E("(N)&]S+3YG
M9713:6=N871U<F4H*2XB*2(I.PT*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%27TE.4U1!3$Q%4E]32TE04$5$.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@("\O('U]?0T*#0H@("`@("`@("1C:&%N;F5L(#T@)'1H
M:7,M/G!K9VEN9F\M/F=E=$-H86YN96PH*3L-"B`@("`@("`@+R\@>WM[(&%S
M<V5M8FQE('1H92!D97-T:6YA=&EO;B!P871H<PT*("`@("`@("!S=VET8V@@
M*"1A='1S6R=R;VQE)UTI('L-"B`@("`@("`@("`@(&-A<V4@)V1O8R<Z#0H@
M("`@("`@("`@("!C87-E("=D871A)SH-"B`@("`@("`@("`@(&-A<V4@)W1E
M<W0G.@T*("`@("`@("`@("`@("`@("1D97-T7V1I<B`]("1T:&ES+3YC;VYF
M:6<M/F=E="@D871T<ULG<F]L92==("X@)U]D:7(G+"!N=6QL+"`D8VAA;FYE
M;"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@($1)4D5#5$]265]3
M15!!4D%43U(@+B`D=&AI<RT^<&MG:6YF;RT^9V5T4&%C:V%G92@I.PT*("`@
M("`@("`@("`@("`@('5N<V5T*"1A='1S6R=B87-E:6YS=&%L;&1I<B==*3L-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V5X
M="<Z#0H@("`@("`@("`@("!C87-E("=P:'`G.@T*("`@("`@("`@("`@("`@
M("1D97-T7V1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@D871T<ULG<F]L92==
M("X@)U]D:7(G+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E("=S8W)I<'0G.@T*("`@("`@("`@
M("`@("`@("1D97-T7V1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G8FEN7V1I
M<B<L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)W-R8R<Z#0H@("`@("`@("`@("!C87-E("=E
M>'1S<F,G.@T*("`@("`@("`@("`@("`@("1T:&ES+3YS;W5R8V5?9FEL97,K
M*SL-"B`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("!D969A
M=6QT.@T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B26YV86QI9"!R;VQE(&`D871T<UMR;VQE72<@9F]R(&9I;&4@)&9I;&4B
M*3L-"B`@("`@("`@?0T*("`@("`@("`D<V%V95]D97-T9&ER(#T@)&1E<W1?
M9&ER.PT*("`@("`@("!I9B`H(65M<'1Y*"1A='1S6R=B87-E:6YS=&%L;&1I
M<B==*2D@>PT*("`@("`@("`@("`@)&1E<W1?9&ER("X]($1)4D5#5$]265]3
M15!!4D%43U(@+B`D871T<ULG8F%S96EN<W1A;&QD:7(G73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H9&ER;F%M92@D9FEL92D@(3T@)RXG("8F(&5M<'1Y
M*"1A='1S6R=I;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D9&5S=%]D
M:7(@+CT@1$E214-43U)97U-%4$%2051/4B`N(&1I<FYA;64H)&9I;&4I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D871T<ULG:6YS=&%L;"UA
M<R==*2D@>PT*("`@("`@("`@("`@)&1E<W1?9FEL92`]("1D97-T7V1I<B`N
M($1)4D5#5$]265]315!!4D%43U(@+B!B87-E;F%M92@D9FEL92D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D9&5S=%]F:6QE(#T@)&1E<W1?
M9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1A='1S6R=I;G-T86QL+6%S
M)UT[#0H@("`@("`@('T-"B`@("`@("`@)&]R:6=?9FEL92`]("1T;7!?<&%T
M:"`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL93L-"@T*("`@("`@("`O
M+R!#;&5A;B!U<"!T:&4@1$E214-43U)97U-%4$%2051/4B!M97-S#0H@("`@
M("`@("1D<S(@/2!$25)%0U1/4EE?4T5005)!5$]2("X@1$E214-43U)97U-%
M4$%2051/4CL-"B`@("`@("`@;&ES="@D9&5S=%]F:6QE+"`D;W)I9U]F:6QE
M*2`]('!R96=?<F5P;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A+R$G+"`B(21D
M<S(K(2(I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*$1)4D5#5$]265]315!!4D%43U(L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4BP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!$25)%0U1/4EE?4T5005)!5$]2*2P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D9&5S=%]F
M:6QE+"`D;W)I9U]F:6QE*2D[#0H@("`@("`@("1F:6YA;%]D97-T7V9I;&4@
M/2`D:6YS=&%L;&5D7V%S(#T@)&1E<W1?9FEL93L-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@
M("`@("`@("`@)&EN<W1A;&QE9&%S7V1E<W1?9&ER(#T@9&ER;F%M92@D9FEN
M86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@("`@("1I;G-T86QL961A<U]D97-T
M7V9I;&4@/2`D9&5S=%]D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)RYT
M;7`G("X@8F%S96YA;64H)&9I;F%L7V1E<W1?9FEL92D[#0H@("`@("`@("`@
M("`D9FEN86Q?9&5S=%]F:6QE(#T@)'1H:7,M/E]P<F5P96YD4&%T:"@D9FEN
M86Q?9&5S=%]F:6QE+`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N
M<ULG<&%C:V%G:6YG<F]O="==*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1I;G-T86QL961A<U]D97-T7V1I<B`](&1I<FYA;64H)&9I;F%L
M7V1E<W1?9FEL92D[#0H@("`@("`@("`@("`D:6YS=&%L;&5D87-?9&5S=%]F
M:6QE(#T@)&EN<W1A;&QE9&%S7V1E<W1?9&ER("X@1$E214-43U)97U-%4$%2
M051/4B`N("<N=&UP)R`N(&)A<V5N86UE*"1F:6YA;%]D97-T7V9I;&4I.PT*
M("`@("`@("!]#0H@("`@("`@("1D97-T7V1I<B`](&1I<FYA;64H)&9I;F%L
M7V1E<W1?9FEL92D[#0H@("`@("`@("1D97-T7V9I;&4@/2`D9&5S=%]D:7(@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)RYT;7`G("X@8F%S96YA;64H)&9I
M;F%L7V1E<W1?9FEL92D[#0H@("`@("`@("\O('U]?0T*#0H@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^7V]P=&EO;G-;)W)E9VES=&5R+6]N;'DG72D@)B8@
M(4!I<U]D:7(H)&1E<W1?9&ER*2D@>PT*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^;6M$:7)(:65R*"1D97-T7V1I<BDI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!M:V1I<B`D9&5S
M=%]D:7(B+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!M:V1I<B`D9&5S=%]D:7(B
M*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!P<F5T='D@;75C:"!N;W1H:6YG
M(&AA<'!E;G,@:68@=V4@87)E(&]N;'D@<F5G:7-T97)I;F<@=&AE(&EN<W1A
M;&P-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T
M97(M;VYL>2==*2D@>PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1A='1S6R=R
M97!L86-E;65N=',G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?
M97AI<W1S*"1O<FEG7V9I;&4I*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92`D;W)I9U]F:6QE(&1O97,@
M;F]T(&5X:7-T(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A0&-O<'DH)&]R:6=?
M9FEL92P@)&1E<W1?9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")F86EL960@=&\@=W)I=&4@)&1E<W1?
M9FEL92(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-P("1O
M<FEG7V9I;&4@)&1E<W1?9FEL92(I.PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<ULG;60U<W5M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1M9#5S=6T@/2!M9#5?9FEL92@D9&5S=%]F:6QE*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("\O('M[>R!F:6QE('=I=&@@<F5P;&%C96UE;G1S#0H@("`@("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D;W)I9U]F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@9&]E
M<R!N;W0@97AI<W0B+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D;W)I9U]F:6QE
M*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D9G`@/2!F;W!E;B@D;W)I9U]F:6QE+"`B<B(I.PT*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N=',@/2!`9G)E860H)&9P+"!F:6QE<VEZ92@D
M;W)I9U]F:6QE*2D[#0H@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&-O
M;G1E;G1S(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5N=',@/2`G)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1A='1S6R=M9#5S=6TG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&UD-7-U;2`](&UD-2@D8V]N=&5N=',I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`D<W5B<W1?9G)O;2`]("1S=6)S
M=%]T;R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T
M='-;)W)E<&QA8V5M96YT<R==(&%S("1A*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T;R`]("<G.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&%;)W1Y
M<&4G72`]/2`G<&AP+6-O;G-T)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>6V$M>C`M.5]=*R0O:2<L("1A6R=T;R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5V86PH(EPD=&\@
M/2`D85MT;UT[(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`B:6YV86QI9"!P:'`M8V]N<W0@<F5P;&%C
M96UE;G0Z("1A6W1O72(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1A6R=T>7!E)UT@/3T@)W!E87(M8V]N9FEG)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1A6R=T;R==(#T]("=M87-T97)?
M<V5R=F5R)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C:&%N
M(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&\@/2`D8VAA;BT^9V5T4V5R=F5R*"D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1O(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1A6R=T;R==+"!N=6QL
M+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&\@/2`D=&AI<RT^8V]N9FEG+3YG970H)&%;
M)W1O)UTL(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1T
M;RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YL;V<H,"P@(FEN=F%L:60@<&5A<BUC;VYF:6<@
M<F5P;&%C96UE;G0Z("1A6W1O72(I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1A6R=T>7!E)UT@/3T@)W!A8VMA9V4M:6YF;R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D="`]("1T:&ES+3YP
M:V=I;F9O+3YP86-K86=E26YF;R@D85LG=&\G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&\@/2`D=#L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")I;G9A;&ED('!A
M8VMA9V4M:6YF;R!R97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-?;G5L;"@D=&\I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<W5B
M<W1?9G)O;5M=(#T@)&%;)V9R;VTG73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1S=6)S=%]T;UM=(#T@)'1O.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,RP@(F1O:6YG("(N<VEZ96]F*"1S=6)S=%]F<F]M*2XB('-U8G-T:71U
M=&EO;BAS*2!F;W(@)&9I;F%L7V1E<W1?9FEL92(I.PT*("`@("`@("`@("`@
M("`@(&EF("AS:7IE;V8H)'-U8G-T7V9R;VTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1C;VYT96YT<R`]('-T<E]R97!L86-E*"1S=6)S=%]F<F]M+"`D
M<W5B<W1?=&\L("1C;VYT96YT<RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1W<"`]($!F;W!E;B@D9&5S=%]F:6QE+"`B=V(B*3L-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1W<"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F
M86EL960@=&\@8W)E871E("1D97-T7V9I;&4Z("1P:'!?97)R;W)M<V<B+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&9W<FET92@D=W`L("1C;VYT96YT<RD@/3T]
M(&9A;'-E*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B9F%I;&5D('=R:71I;F<@=&\@)&1E<W1?9FEL93H@)'!H
M<%]E<G)O<FUS9R(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F8VQO<V4H)'=P*3L-"B`@
M("`@("`@("`@("`@("`O+R!]?7T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("\O('M[>R!C:&5C:R!T:&4@;60U#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&UD-7-U;2DI('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E
M<B@D;60U<W5M*2`]/2!S=')T;VQO=V5R*"1A='1S6R=M9#5S=6TG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@R+"`B;60U<W5M(&]K
M.B`D9FEN86Q?9&5S=%]F:6QE(BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=F
M;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@9&5L971E
M('1H92!F:6QE#0H@("`@("`@("`@("`@("`@("`@("`@("!`=6YL:6YK*"1D
M97-T7V9I;&4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8F%D
M(&UD-7-U;2!F;W(@9FEL92`D9FEN86Q?9&5S=%]F:6QE(BP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%2
M7TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(G=A<FYI;F<@.B!B860@;60U
M<W5M(&9O<B!F:6QE("1F:6YA;%]D97-T7V9I;&4B*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B=V%R
M;FEN9R`Z(&)A9"!M9#5S=6T@9F]R(&9I;&4@)&9I;F%L7V1E<W1?9FEL92(I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@+R\@?7U]#0H@("`@("`@("`@("`O+R![>WL@<V5T(&9I;&4@
M<&5R;6ES<VEO;G,-"B`@("`@("`@("`@(&EF("@A3U-?5TE.1$]74RD@>PT*
M("`@("`@("`@("`@("`@(&EF("@D871T<ULG<F]L92==(#T]("=S8W)I<'0G
M*2![#0H@("`@("`@("`@("`@("`@("`@("1M;V1E(#T@,#<W-R`F('XH:6YT
M*6]C=&1E8R@D=&AI<RT^8V]N9FEG+3YG970H)W5M87-K)RDI.PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-H;6]D("MX("1D97-T
M7V9I;&4B*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D;6]D92`](#`V-C8@)B!^*&EN="EO8W1D96,H)'1H:7,M
M/F-O;F9I9RT^9V5T*"=U;6%S:R<I*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH(F-H;6]D
M(BP@87)R87DH)&UO9&4L("1D97-T7V9I;&4I*3L-"B`@("`@("`@("`@("`@
M("!I9B`H(4!C:&UO9"@D9&5S=%]F:6QE+"`D;6]D92DI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B9F%I;&5D
M('1O(&-H86YG92!M;V1E(&]F("1D97-T7V9I;&4B*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("\O('U]?0T*("`@("`@("`@("`@)'1H:7,M/F%D9$9I
M;&5/<&5R871I;VXH(G)E;F%M92(L(&%R<F%Y*"1D97-T7V9I;&4L("1F:6YA
M;%]D97-T7V9I;&4L#0H@("`@("`@("`@("`@("`@)&%T='-;)W)O;&4G72`]
M/2`G97AT)RDI.PT*("`@("`@("!]#0H@("`@("`@("\O(%-T;W)E('1H92!F
M=6QL('!A=&@@=VAE<F4@=&AE(&9I;&4@=V%S(&EN<W1A;&QE9"!F;W(@96%S
M>2!U;FES=&%L;`T*("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@B
M:6YS=&%L;&5D7V%S(BP@87)R87DH)&9I;&4L("1I;G-T86QL961?87,L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S879E7V1E<W1D:7(L
M(&1I<FYA;64H<W5B<W1R*"1I;G-T86QL961A<U]D97-T7V9I;&4L('-T<FQE
M;B@D<V%V95]D97-T9&ER*2DI*2D[#0H-"B`@("`@("`@+R\D=&AI<RT^;&]G
M*#(L(")I;G-T86QL960Z("1D97-T7V9I;&4B*3L-"B`@("`@("`@<F5T=7)N
M(%!%05)?24Y35$%,3$527T]+.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!?:6YS=&%L;$9I;&4R*"D-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&5N86UE#0H@("`@("H@0'!A<F%M
M(&%R<F%Y(&%T=')I8G5T97,@9G)O;2`\9FEL93X@=&%G(&EN('!A8VMA9V4N
M>&UL#0H@("`@("H@0'!A<F%M('-T<FEN9R!P871H('1O(&EN<W1A;&P@=&AE
M(&9I;&4@:6X-"B`@("`@*B!`<&%R86T@87)R87D@;W!T:6]N<R!F<F]M(&-O
M;6UA;F0M;&EN90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]I;G-T86QL1FEL93(H)B1P:V<L("1F:6QE+"`D871T
M<RP@)'1M<%]P871H+"`D;W!T:6]N<RD-"B`@("![#0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]R96=I<W1R>2DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-
M"B`@("`@("`@?0T*#0H@("`@("`@("1C:&%N;F5L(#T@)'!K9RT^9V5T0VAA
M;FYE;"@I.PT*("`@("`@("`O+R![>WL@87-S96UB;&4@=&AE(&1E<W1I;F%T
M:6]N('!A=&AS#0H@("`@("`@(&EF("@A:6Y?87)R87DH)&%T='-;)V%T=')I
M8G,G75LG<F]L92==+`T*("`@("`@("`@("`@("!014%27TEN<W1A;&QE<E]2
M;VQE.CIG971686QI9%)O;&5S*"1P:V<M/F=E=%!A8VMA9V54>7!E*"DI*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=);G9A
M;&ED(')O;&4@8"<@+B`D871T<ULG871T<FEB<R==6R=R;VQE)UT@+@T*("`@
M("`@("`@("`@("`@("`@("`B)R!F;W(@9FEL92`D9FEL92(I.PT*("`@("`@
M("!]#0H@("`@("`@("1R;VQE(#T@)E!%05)?26YS=&%L;&5R7U)O;&4Z.F9A
M8W1O<GDH)'!K9RP@)&%T='-;)V%T=')I8G,G75LG<F]L92==+"`D=&AI<RT^
M8V]N9FEG*3L-"B`@("`@("`@)&5R<B`]("1R;VQE+3YS971U<"@D=&AI<RP@
M)'!K9RP@)&%T='-;)V%T=')I8G,G72P@)&9I;&4I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E
M<G([#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D<F]L92T^:7-);G-T86QL
M86)L92@I*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@
M("`@("`@)&EN9F\@/2`D<F]L92T^<')O8V5S<TEN<W1A;&QA=&EO;B@D<&MG
M+"`D871T<ULG871T<FEB<R==+"`D9FEL92P@)'1M<%]P871H*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R
M971U<FX@)&EN9F\[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!L
M:7-T*"1S879E7V1E<W1D:7(L("1D97-T7V1I<BP@)&1E<W1?9FEL92P@)&]R
M:6=?9FEL92D@/2`D:6YF;SL-"B`@("`@("`@?0T*("`@("`@("`D9FEN86Q?
M9&5S=%]F:6QE(#T@)&EN<W1A;&QE9%]A<R`]("1D97-T7V9I;&4[#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G
M72DI('L-"B`@("`@("`@("`@("1F:6YA;%]D97-T7V9I;&4@/2`D=&AI<RT^
M7W!R97!E;F10871H*"1F:6YA;%]D97-T7V9I;&4L#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI.PT*("`@("`@
M("!]#0H@("`@("`@("1D97-T7V1I<B`](&1I<FYA;64H)&9I;F%L7V1E<W1?
M9FEL92D[#0H@("`@("`@("1D97-T7V9I;&4@/2`D9&5S=%]D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)RYT;7`G("X@8F%S96YA;64H)&9I;F%L7V1E
M<W1?9FEL92D[#0H@("`@("`@("\O('U]?0T*#0H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7V]P=&EO;G-;)W)E9VES=&5R+6]N;'DG72DI('L-"B`@("`@
M("`@("`@(&EF("@A0&ES7V1I<B@D9&5S=%]D:7(I*2![#0H@("`@("`@("`@
M("`@("`@:68@*"$D=&AI<RT^;6M$:7)(:65R*"1D97-T7V1I<BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F
M86EL960@=&\@;6MD:7(@)&1E<W1?9&ER(BP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!
M24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,RP@(BL@;6MD:7(@)&1E<W1?9&ER(BD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)&%T=')I8G,@/2`D871T<ULG871T
M<FEB<R==.PT*("`@("`@("!U;G-E="@D871T<ULG871T<FEB<R==*3L-"B`@
M("`@("`@+R\@<')E='1Y(&UU8V@@;F]T:&EN9R!H87!P96YS(&EF('=E(&%R
M92!O;FQY(')E9VES=&5R:6YG('1H92!I;G-T86QL#0H@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7V]P=&EO;G-;)W)E9VES=&5R+6]N;'DG72DI('L-"B`@
M("`@("`@("`@(&EF("@A8V]U;G0H)&%T=',I*2![("\O(&YO('1A<VMS#0H@
M("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;W)I9U]F:6QE*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(F9I;&4@)&]R:6=?9FEL92!D;V5S(&YO="!E>&ES="(L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TE.
M4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H(4!C;W!Y*"1O<FEG7V9I;&4L("1D97-T7V9I;&4I*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B9F%I;&5D('1O('=R:71E("1D97-T7V9I;&4B+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,
M15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@S+"`B*R!C<"`D;W)I9U]F:6QE("1D97-T7V9I;&4B
M*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')I8G-;)VUD-7-U
M;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;60U<W5M(#T@;60U7V9I
M;&4H)&1E<W1?9FEL92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L@+R\@9FEL92!W:71H('1A<VMS#0H@("`@("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D;W)I9U]F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@)&]R
M:6=?9FEL92!D;V5S(&YO="!E>&ES="(L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,
M140I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1C;VYT96YT<R`](&9I;&5?9V5T7V-O;G1E;G1S
M*"1O<FEG7V9I;&4I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1F<"`](&9O<&5N*"1O<FEG7V9I;&4L(")R(BD[
M#0H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L
M(&9I;&5S:7IE*"1O<FEG7V9I;&4I*3L@+R\@9FEL97-I>F4@8V%N(&)E(#`-
M"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D8V]N=&5N=',@/3T](&9A
M;'-E*2![#0H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`]("<G.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&%T=')I8G-;)VUD-7-U;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M;60U<W5M(#T@;60U*"1C;VYT96YT<RD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A='1S(&%S("1T86<@/3X@)')A
M=RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&%G(#T@<W1R7W)E<&QA8V4H
M)'!K9RT^9V5T5&%S:W-.<R@I("X@)SHG+"`G)RP@)'1A9RD[#0H@("`@("`@
M("`@("`@("`@("`@("1T87-K(#T@(E!%05)?5&%S:U\D=&%G(CL-"B`@("`@
M("`@("`@("`@("`@("`@)'1A<VL@/2`F;F5W("1T87-K*"1T:&ES+3YC;VYF
M:6<L("1T:&ES+"!014%27U1!4TM?24Y35$%,3"D[#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A)'1A<VLM/FES4V-R:7!T*"DI('L@+R\@<V-R:7!T<R!A
M<F4@;VYL>2!H86YD;&5D(&%F=&5R(&EN<W1A;&QA=&EO;@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1A<VLM/FEN:70H)')A=RP@)&%T=')I8G,L("1P
M:V<M/F=E=$QA<W1);G-T86QL961697)S:6]N*"DI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E<R`]("1T87-K+3YS=&%R=%-E<W-I;VXH)'!K9RP@
M)&-O;G1E;G1S+"`D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<F5S(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.R`O+R!S:VEP('1H:7,@9FEL90T*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M<R`]("1R97,[("\O('-A=F4@8VAA;F=E<PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1W<"`]($!F;W!E;B@D9&5S=%]F
M:6QE+"`B=V(B*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]R97-O
M=7)C92@D=W`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!C<F5A=&4@)&1E<W1?9FEL
M93H@)'!H<%]E<G)O<FUS9R(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H9G=R:71E*"1W<"P@)&-O;G1E;G1S*2`]/3T@9F%L<V4I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B9F%I;&5D('=R:71I;F<@=&\@)&1E<W1?9FEL93H@)'!H<%]E<G)O<FUS
M9R(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)'=P*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`O+R![>WL@8VAE8VL@=&AE(&UD-0T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1M9#5S=6TI*2![#0H@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)&UD-7-U;2D@/3T@<W1R=&]L;W=E<B@D871T<FEB<ULG;60U<W5M)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,BP@(FUD-7-U;2!O
M:SH@)&9I;F%L7V1E<W1?9FEL92(I.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG
M9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&1E;&5T
M92!T:&4@9FEL90T*("`@("`@("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D
M9&5S=%]F:6QE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A
M9"!M9#5S=6T@9F]R(&9I;&4@)&9I;F%L7V1E<W1?9FEL92(L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B=V%R;FEN9R`Z(&)A
M9"!M9#5S=6T@9F]R(&9I;&4@)&9I;F%L7V1E<W1?9FEL92(I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M(")W87)N:6YG(#H@8F%D(&UD-7-U;2!F;W(@9FEL92`D9FEN86Q?9&5S=%]F
M:6QE(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`O+R!]?7T-"B`@("`@("`@("`@("\O('M[>R!S970@
M9FEL92!P97)M:7-S:6]N<PT*("`@("`@("`@("`@:68@*"%/4U]724Y$3U=3
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1R;VQE+3YI<T5X96-U=&%B;&4H
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;6]D92`](#`W-S<@)B!^*&EN
M="EO8W1D96,H)'1H:7,M/F-O;F9I9RT^9V5T*"=U;6%S:R<I*3L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!C:&UO9"`K>"`D9&5S
M=%]F:6QE(BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&UO9&4@/2`P-C8V("8@?BAI;G0I;V-T9&5C*"1T:&ES
M+3YC;VYF:6<M/F=E="@G=6UA<VLG*2D[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*")C:&UO
M9"(L(&%R<F%Y*"1M;V1E+"`D9&5S=%]F:6QE*2D[#0H@("`@("`@("`@("`@
M("`@:68@*"%`8VAM;V0H)&1E<W1?9FEL92P@)&UO9&4I*2![#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(F9A:6QE
M9"!T;R!C:&%N9V4@;6]D92!O9B`D9&5S=%]F:6QE(BD[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`O+R!]?7T-"B`@("`@("`@("`@("1T:&ES+3YA9&1&
M:6QE3W!E<F%T:6]N*")R96YA;64B+"!A<G)A>2@D9&5S=%]F:6QE+"`D9FEN
M86Q?9&5S=%]F:6QE+"`D<F]L92T^:7-%>'1E;G-I;VXH*2DI.PT*("`@("`@
M("!]#0H@("`@("`@("\O(%-T;W)E('1H92!F=6QL('!A=&@@=VAE<F4@=&AE
M(&9I;&4@=V%S(&EN<W1A;&QE9"!F;W(@96%S>2!U;FEN<W1A;&P-"B`@("`@
M("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH(FEN<W1A;&QE9%]A<R(L(&%R
M<F%Y*"1F:6QE+"`D:6YS=&%L;&5D7V%S+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S879E7V1E<W1D:7(L(&1I<FYA;64H<W5B<W1R*"1D97-T
M7V9I;&4L('-T<FQE;B@D<V%V95]D97-T9&ER*2DI*2D[#0H-"B`@("`@("`@
M+R\D=&AI<RT^;&]G*#(L(")I;G-T86QL960Z("1D97-T7V9I;&4B*3L-"B`@
M("`@("`@<F5T=7)N(%!%05)?24Y35$%,3$527T]+.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!A9&1&:6QE3W!E<F%T:6]N*"D-"@T*("`@
M("\J*@T*("`@("`J($%D9"!A(&9I;&4@;W!E<F%T:6]N('1O('1H92!C=7)R
M96YT(&9I;&4@=')A;G-A8W1I;VXN#0H@("`@("H-"B`@("`@*B!`<V5E('-T
M87)T1FEL951R86YS86-T:6]N*"D-"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E(%1H:7,@8V%N(&)E(&]N92!O9CH-"B`@("`@*B`@("`M(')E;F%M93H@
M(')E;F%M92!A(&9I;&4@*"1D871A(&AA<R`S('9A;'5E<RD-"B`@("`@*B`@
M("`M(&)A8VMU<#H@(&)A8VMU<"!A;B!E>&ES=&EN9R!F:6QE("@D9&%T82!H
M87,@,2!V86QU92D-"B`@("`@*B`@("`M(')E;6]V96)A8VMU<#H@(&-L96%N
M('5P(&)A8VMU<',@8W)E871E9"!D=7)I;F<@:6YS=&%L;"`H)&1A=&$@:&%S
M(#$@=F%L=64I#0H@("`@("H@("`@+2!C:&UO9#H@("!C:&%N9V4@<&5R;6ES
M<VEO;G,@;VX@82!F:6QE("@D9&%T82!H87,@,B!V86QU97,I#0H@("`@("H@
M("`@+2!D96QE=&4Z("!D96QE=&4@82!F:6QE("@D9&%T82!H87,@,2!V86QU
M92D-"B`@("`@*B`@("`M(')M9&ER.B`@(&1E;&5T92!A(&1I<F5C=&]R>2!I
M9B!E;7!T>2`H)&1A=&$@:&%S(#$@=F%L=64I#0H@("`@("H@("`@+2!I;G-T
M86QL961?87,Z(&UA<FL@82!F:6QE(&%S(&EN<W1A;&QE9"`H)&1A=&$@:&%S
M(#0@=F%L=65S*2X-"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@1F]R(&%L
M;"!F:6QE(&]P97)A=&EO;G,L('1H:7,@87)R87D@;75S="!C;VYT86EN('1H
M90T*("`@("`J("`@(&9U;&P@<&%T:"!T;R!T:&4@9FEL92!O<B!D:7)E8W1O
M<GD@=&AA="!I<R!B96EN9R!O<&5R871E9"!O;BX@($9O<@T*("`@("`J("`@
M('1H92!R96YA;64@8V]M;6%N9"P@=&AE(&9I<G-T('!A<F%M971E<B!M=7-T
M(&)E('1H92!F:6QE('1O(')E;F%M92P-"B`@("`@*B`@("!T:&4@<V5C;VYD
M(&ET<R!N97<@;F%M92P@=&AE('1H:7)D('=H971H97(@=&AI<R!I<R!A(%!(
M4"!E>'1E;G-I;VXN#0H@("`@("H-"B`@("`@*B`@("!4:&4@:6YS=&%L;&5D
M7V%S(&]P97)A=&EO;B!C;VYT86EN<R`T(&5L96UE;G1S(&EN('1H:7,@;W)D
M97(Z#0H@("`@("H@("`@,2X@1FEL96YA;64@87,@;&ES=&5D(&EN('1H92!F
M:6QE;&ES="!E;&5M96YT(&9R;VT@<&%C:V%G92YX;6P-"B`@("`@*B`@("`R
M+B!&=6QL('!A=&@@=&\@=&AE(&EN<W1A;&QE9"!F:6QE#0H@("`@("H@("`@
M,RX@1G5L;"!P871H(&9R;VT@=&AE('!H<%]D:7(@8V]N9FEG=7)A=&EO;B!V
M87)I86)L92!U<V5D(&EN('1H:7,-"B`@("`@*B`@("`@("!I;G-T86QL871I
M;VX-"B`@("`@*B`@("`T+B!296QA=&EV92!P871H(&9R;VT@=&AE('!H<%]D
M:7(@=&AA="!T:&ES(&9I;&4@:7,@:6YS=&%L;&5D(&EN#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@861D1FEL94]P97)A=&EO;B@D='EP92P@)&1A=&$I#0H@
M("`@>PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=);G1E<FYA;"!%<G)O
M<CH@)&1A=&$@:6X@861D1FEL94]P97)A=&EO;B<-"B`@("`@("`@("`@("`@
M("`N("<@;75S="!B92!A;B!A<G)A>2P@=V%S("<@+B!G971T>7!E*"1D871A
M*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T>7!E(#T]("=C:&UO9"<I
M('L-"B`@("`@("`@("`@("1O8W1M;V1E(#T@9&5C;V-T*"1D871A6S!=*3L-
M"B`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(F%D9&EN9R!T;R!T<F%N<V%C
M=&EO;CH@)'1Y<&4@)&]C=&UO9&4@)&1A=&%;,5TB*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(F%D9&EN9R!T;R!T
M<F%N<V%C=&EO;CH@)'1Y<&4@(B`N(&EM<&QO9&4H(B`B+"`D9&%T82DI.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3YF:6QE7V]P97)A=&EO;G-;72`]
M(&%R<F%Y*"1T>7!E+"`D9&%T82D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[('-T87)T1FEL951R86YS86-T:6]N*"D-"@T*("`@(&9U;F-T
M:6]N('-T87)T1FEL951R86YS86-T:6]N*"1R;VQL8F%C:U]I;E]C87-E(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/F9I;&5?
M;W!E<F%T:6]N<RD@)B8@)')O;&QB86-K7VEN7V-A<V4I('L-"B`@("`@("`@
M("`@("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3YF:6QE7V]P97)A=&EO;G,@/2!A<G)A>2@I
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C;VUM:71&:6QE
M5')A;G-A8W1I;VXH*0T*#0H@("`@9G5N8W1I;VX@8V]M;6ET1FEL951R86YS
M86-T:6]N*"D-"B`@("![#0H@("`@("`@("1N(#T@8V]U;G0H)'1H:7,M/F9I
M;&5?;W!E<F%T:6]N<RD[#0H@("`@("`@("1T:&ES+3YL;V<H,BP@(F%B;W5T
M('1O(&-O;6UI="`D;B!F:6QE(&]P97)A=&EO;G,B*3L-"B`@("`@("`@+R\@
M>WM[(&9I<G-T+"!C:&5C:R!P97)M:7-S:6]N<R!A;F0@<W5C:"!M86YU86QL
M>0T*("`@("`@("`D97)R;W)S(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/F9I;&5?;W!E<F%T:6]N<R!A<R`D='(I('L-"B`@("`@("`@
M("`@(&QI<W0H)'1Y<&4L("1D871A*2`]("1T<CL-"B`@("`@("`@("`@('-W
M:71C:"`H)'1Y<&4I('L-"B`@("`@("`@("`@("`@("!C87-E("=R96YA;64G
M.@T*("`@("`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D871A
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@
M(F-A;FYO="!R96YA;64@9FEL92`D9&%T85LP72P@9&]E<VXG="!E>&ES="([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M+R\@8VAE8VL@=&AA="!D97-T(&1I<BX@:7,@=W)I=&%B;&4-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<U]W<FET86)L92AD:7)N86UE*"1D871A6S%=
M*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`](")P
M97)M:7-S:6]N(&1E;FEE9"`H)'1Y<&4I.B`D9&%T85LQ72([#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@8V%S92`G8VAM;V0G.@T*("`@("`@("`@("`@("`@
M("`@("`O+R!C:&5C:R!T:&%T(&9I;&4@:7,@=W)I=&%B;&4-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<U]W<FET86)L92@D9&%T85LQ72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`](")P97)M:7-S:6]N
M(&1E;FEE9"`H)'1Y<&4I.B`D9&%T85LQ72`B("X@9&5C;V-T*"1D871A6S!=
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("=D96QE=&4G.@T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D871A6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@R+"`B=V%R
M;FEN9SH@9FEL92`D9&%T85LP72!D;V5S;B=T(&5X:7-T+"!C86XG="!B92!D
M96QE=&5D(BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@+R\@8VAE8VL@=&AA="!D:7)E8W1O<GD@:7,@=W)I=&%B;&4-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1D871A6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]W<FET86)L
M92AD:7)N86UE*"1D871A6S!=*2DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97)R;W)S6UT@/2`B<&5R;6ES<VEO;B!D96YI960@*"1T>7!E
M*3H@)&1A=&%;,%TB.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!M86ME('-U<F4@
M=&AE(&9I;&4@=&\@8F4@9&5L971E9"!C86X@8F4@;W!E;F5D(&9O<B!W<FET
M:6YG#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9P(#T@9F%L<V4[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]D:7(H)&1A
M=&%;,%TI("8F("$H)&9P(#T@0&9O<&5N*"1D871A6S!=+"`G82<I*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B
M<&5R;6ES<VEO;B!D96YI960@*"1T>7!E*3H@)&1A=&%;,%TB.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D9G`I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@('T-"B`@
M("`@("`@+R\@?7U]#0H@("`@("`@("1M(#T@<VEZ96]F*"1E<G)O<G,I.PT*
M("`@("`@("!I9B`H)&T@/B`P*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M97)R;W)S(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,2P@)&5R<F]R*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^7V1I<G1R964@/2!A<G)A>2@I.PT*("`@("`@
M("`O+R![>WL@<F5A;&QY(&-O;6UI="!T:&4@=')A;G-A8W1I;VX-"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/F9I;&5?;W!E<F%T:6]N<R!A<R`D='(I('L-
M"B`@("`@("`@("`@(&QI<W0H)'1Y<&4L("1D871A*2`]("1T<CL-"B`@("`@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L-"B`@("`@("`@("`@("`@("!C87-E
M("=B86-K=7`G.@T*("`@("`@("`@("`@("`@("`@("!`8V]P>2@D9&%T85LP
M72P@)&1A=&%;,%T@+B`G+F)A:R<I.PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#,L("(K(&)A8VMU<"`D9&%T85LP72!T;R`D9&%T85LP72YB
M86LB*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("`@("`@8V%S92`G<F5M;W9E8F%C:W5P)SH-"B`@("`@("`@("`@("`@("`@
M("`@0'5N;&EN:R@D9&%T85LP72`N("<N8F%K)RD[#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,RP@(BL@<FT@8F%C:W5P(&]F("1D871A6S!=
M("@D9&%T85LP72YB86LI(BD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@(&-A<V4@)W)E;F%M92<Z#0H@("`@("`@("`@
M("`@("`@("`@("1T97-T(#T@0'5N;&EN:R@D9&%T85LQ72D[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A)'1E<W0@)B8@9FEL95]E>&ES=',H)&1A=&%;
M,5TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1A=&%;,ETI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$@/2`G+"!T
M:&ES(&5X=&5N<VEO;B!M=7-T(&)E(&EN<W1A;&QE9"!M86YU86QL>2X@(%)E
M;F%M92!T;R`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)A<V5N86UE*"1D871A6S%=*2`N("<B)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5X=')A(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,2P@)T-O=6QD(&YO="!D96QE=&4@)R`N("1D871A6S%=("X@
M)RP@8V%N;F]T(')E;F%M92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1A=&%;,%T@+B`D97AT<F$I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@0')E;F%M92@D9&%T85LP72P@)&1A=&%;,5TI
M.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&UV("1D
M871A6S!=("1D871A6S%=(BD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@(&-A<V4@)V-H;6]D)SH-"B`@("`@("`@("`@
M("`@("`@("`@0&-H;6]D*"1D871A6S%=+"`D9&%T85LP72D[#0H@("`@("`@
M("`@("`@("`@("`@("1O8W1M;V1E(#T@9&5C;V-T*"1D871A6S!=*3L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!C:&UO9"`D;V-T
M;6]D92`D9&%T85LQ72(I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("!C87-E("=D96QE=&4G.@T*("`@("`@("`@("`@
M("`@("`@("!`=6YL:6YK*"1D871A6S!=*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@S+"`B*R!R;2`D9&%T85LP72(I.PT*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("=R;61I
M<B<Z#0H@("`@("`@("`@("`@("`@("`@($!R;61I<B@D9&%T85LP72D[#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@<FUD:7(@)&1A
M=&%;,%TB*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@8V%S92`G:6YS=&%L;&5D7V%S)SH-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G!K9VEN9F\M/G-E=$EN<W1A;&QE9$%S*"1D871A6S!=
M+"`D9&%T85LQ72D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]D:7)T<F5E6V1I<FYA;64H)&1A=&%;,5TI72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ER=')E95MD:7)N86UE*"1D
M871A6S%=*5T@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G!K9VEN9F\M/G-E=$1I<G1R964H9&ER;F%M92@D9&%T85LQ72DI.PT*
M#0H@("`@("`@("`@("`@("`@("`@("`@("!W:&EL92@A96UP='DH)&1A=&%;
M,UTI("8F("1D871A6S-=("$]("<O)R`F)B`D9&%T85LS72`A/2`G7%PG#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`F)B`D9&%T85LS72`A/2`G
M+B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&MG
M:6YF;RT^<V5T1&ER=')E92@D<'`@/0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!R97!E;F10871H*"1D871A6S-=+"`D9&%T
M85LR72DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&ER=')E95LD<'!=(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%T85LS72`](&1I<FYA;64H)&1A=&%;,UTI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@("\O('U]?0T*("`@("`@("`D=&AI<RT^;&]G*#(L(")S
M=6-C97-S9G5L;'D@8V]M;6ET=&5D("1N(&9I;&4@;W!E<F%T:6]N<R(I.PT*
M("`@("`@("`D=&AI<RT^9FEL95]O<&5R871I;VYS(#T@87)R87DH*3L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(')O;&QB86-K1FEL951R86YS86-T:6]N*"D-"@T*("`@(&9U;F-T
M:6]N(')O;&QB86-K1FEL951R86YS86-T:6]N*"D-"B`@("![#0H@("`@("`@
M("1N(#T@8V]U;G0H)'1H:7,M/F9I;&5?;W!E<F%T:6]N<RD[#0H@("`@("`@
M("1T:&ES+3YL;V<H,BP@(G)O;&QI;F<@8F%C:R`D;B!F:6QE(&]P97)A=&EO
M;G,B*3L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F9I;&5?;W!E<F%T:6]N
M<R!A<R`D='(I('L-"B`@("`@("`@("`@(&QI<W0H)'1Y<&4L("1D871A*2`]
M("1T<CL-"B`@("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L-"B`@("`@("`@
M("`@("`@("!C87-E("=B86-K=7`G.@T*("`@("`@("`@("`@("`@("`@("!I
M9B`H9FEL95]E>&ES=',H)&1A=&%;,%T@+B`G+F)A:R<I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!`=6YL:6YK*"1D871A6S!=*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@($!C;W!Y*"1D871A6S!=("X@)RYB86LG+"`D9&%T
M85LP72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L
M("(K(')E<W1O<F4@)&1A=&%;,%T@9G)O;2`D9&%T85LP72YB86LB*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!C87-E("=R96YA;64G.@T*("`@("`@("`@
M("`@("`@("`@("!`=6YL:6YK*"1D871A6S!=*3L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@S+"`B*R!R;2`D9&%T85LP72(I.PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("=M
M:V1I<B<Z#0H@("`@("`@("`@("`@("`@("`@($!R;61I<B@D9&%T85LP72D[
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@<FUD:7(@
M)&1A=&%;,%TB*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@8V%S92`G8VAM;V0G.@T*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("=D96QE=&4G.@T*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E
M("=I;G-T86QL961?87,G.@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<&MG:6YF;RT^<V5T26YS=&%L;&5D07,H)&1A=&%;,%TL(&9A;'-E*3L-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/G!K9VEN9F\M/G)E<V5T1&ER=')E92@I
M.PT*("`@("`@("`D=&AI<RT^9FEL95]O<&5R871I;VYS(#T@87)R87DH*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;6M$:7)(:65R*"1D
M:7(I#0H-"B`@("!F=6YC=&EO;B!M:T1I<DAI97(H)&1I<BD-"B`@("![#0H@
M("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*"=M:V1I<B<L(&%R<F%Y
M*"1D:7(I*3L-"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ;6M$:7)(:65R*"1D
M:7(I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;W=N;&]A
M9"@I#0H-"B`@("`O*BH-"B`@("`@*B!$;W=N;&]A9"!A;GD@9FEL97,@86YD
M('1H96ER(&1E<&5N9&5N8VEE<RP@:68@;F5C97-S87)Y#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@87)R87D@82!M:7AE9"!L:7-T(&]F('!A8VMA9V4@;F%M
M97,L(&QO8V%L(&9I;&5S+"!O<B!P86-K86=E+GAM;`T*("`@("`J($!P87)A
M;2!014%27T-O;F9I9PT*("`@("`J($!P87)A;2!A<G)A>2!O<'1I;VYS(&9R
M;VT@=&AE(&-O;6UA;F0@;&EN90T*("`@("`J($!P87)A;2!A<G)A>2!T:&ES
M(&ES('1H92!A<G)A>2!T:&%T('=I;&P@8F4@<&]P=6QA=&5D('=I=&@@<&%C
M:V%G97,@=&\-"B`@("`@*B`@("`@("`@("`@("`@:6YS=&%L;"X@($9O<FUA
M="!O9B!E86-H(&5N=')Y.@T*("`@("`J#0H@("`@("H@/&-O9&4^#0H@("`@
M("H@87)R87DH)W!K9R<@/3X@)W!A8VMA9V5?;F%M92<L("=F:6QE)R`]/B`G
M+W!A=&@O=&\O;&]C86PO9FEL92<L#0H@("`@("H@("`@)VEN9F\G(#T^(&%R
M<F%Y*"D@+R\@<&%R<V5D('!A8VMA9V4N>&UL#0H@("`@("H@*3L-"B`@("`@
M*B`\+V-O9&4^#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H:7,@=VEL;"!B92!P
M;W!U;&%T960@=VET:"!A;GD@97)R;W(@;65S<V%G97,-"B`@("`@*B!`<&%R
M86T@9F%L<V4@<')I=F%T92!R96-U<G-I;VX@=F%R:6%B;&4-"B`@("`@*B!`
M<&%R86T@9F%L<V4@<')I=F%T92!R96-U<G-I;VX@=F%R:6%B;&4-"B`@("`@
M*B!`<&%R86T@9F%L<V4@<')I=F%T92!R96-U<G-I;VX@=F%R:6%B;&4-"B`@
M("`@*B!`9&5P<F5C871E9"!I;B!F879O<B!O9B!014%27T1O=VYL;V%D97(-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;W=N;&]A9"@D<&%C:V%G97,L("1O
M<'1I;VYS+"`F)&-O;F9I9RP@)B1I;G-T86QL<&%C:V%G97,L#0H@("`@("`@
M("`@("`@("`@("`@("`@)B1E<G)O<G,L("1I;G-T86QL960@/2!F86QS92P@
M)'=I;&QI;G-T86QL(#T@9F%L<V4L("1S=&%T92`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@+R\@=')I8VMI;F5S<SH@:6YI=&EA;&EZ92!H97)E#0H@("`@
M("`@('!A<F5N=#HZ4$5!4E]$;W=N;&]A9&5R*"1T:&ES+3YU:2P@)&]P=&EO
M;G,L("1C;VYF:6<I.PT*("`@("`@("`D<F5T(#T@<&%R96YT.CID;W=N;&]A
M9"@D<&%C:V%G97,I.PT*("`@("`@("`D97)R;W)S(#T@)'1H:7,M/F=E=$5R
M<F]R37-G<R@I.PT*("`@("`@("`D:6YS=&%L;'!A8VMA9V5S(#T@)'1H:7,M
M/F=E=$1O=VYL;V%D961086-K86=E<R@I.PT*("`@("`@("!T<FEG9V5R7V5R
M<F]R*")014%2(%=A<FYI;F<Z(%!%05)?26YS=&%L;&5R.CID;W=N;&]A9"@I
M(&ES(&1E<')E8V%T960@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@(FEN
M(&9A=F]R(&]F(%!%05)?1&]W;FQO861E<B!C;&%S<R(L($5?55-%4E]705).
M24Y'*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(%]P87)S95!A8VMA9V58;6PH*0T*#0H@("`@9G5N
M8W1I;VX@7W!A<G-E4&%C:V%G95AM;"@F)&1E<V-F:6QE+"`F)'1M<&1I<BD-
M"B`@("![#0H@("`@("`@(&EF("AS=6)S='(H)&1E<V-F:6QE+"`M-"D@/3T@
M)RYX;6PG*2![#0H@("`@("`@("`@("`D=&UP9&ER(#T@9F%L<V4[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`O+R![>WL@1&5C;VUP<F5S<R!P
M86-K(&EN('1M<"!D:7(@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0T*#0H@("`@("`@("`@("`O+R!4;R!A;&QO=R!R96QA=&EV92!P
M86-K86=E(&9I;&4@;F%M97,-"B`@("`@("`@("`@("1D97-C9FEL92`](')E
M86QP871H*"1D97-C9FEL92D[#0H-"B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"@G+60G*2DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1M<&1I<CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@)RL@=&UP(&1I<B!C<F5A=&5D
M(&%T("<@+B`D=&UP9&ER*3L-"B`@("`@("`@("`@("\O('U]?0T*("`@("`@
M("!]#0H@("`@("`@("\O(%!A<G-E('AM;"!F:6QE("TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM#0H@("`@("`@("1P
M:V<@/2!N97<@4$5!4E]086-K86=E1FEL92@D=&AI<RT^8V]N9FEG+"`D=&AI
M<RT^9&5B=6<L("1T;7!D:7(I.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1P
M(#T@)B1P:V<M/F9R;VU!;GE&:6QE*"1D97-C9FEL92P@4$5!4E]604Q)1$%4
M15])3E-404Q,24Y'*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<"DI('L-
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<"T^9V5T57-E<DEN9F\H*2DI
M('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<"T^9V5T57-E<DEN9F\H
M*2!A<R`D97)R*2![#0H@("`@("`@("`@("`@("`@("`@("1L;V=L979E;"`]
M("1E<G);)VQE=F5L)UT@/3T@)V5R<F]R)R`_(#`@.B`Q.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@D;&]G
M;&5V96PL('5C9FER<W0H)&5R<ELG;&5V96PG72D@+B`G.B`G("X@)&5R<ELG
M;65S<V%G92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G26YS=&%L;&%T:6]N(&9A:6QE9#H@:6YV86QI
M9"!P86-K86=E(&9I;&4G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1D97-C9FEL92`]("1P+3YG971086-K86=E1FEL92@I.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D<#L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O*BH-"B`@("`@*B!3970@=&AE(&QI<W0@;V8@4$5!4E]$;W=N;&]A
M9&5R7U!A8VMA9V4@;V)J96-T<R!T;R!A;&QO=R!M;W)E('-A;F4-"B`@("`@
M*B!D97!E;F1E;F-Y('9A;&ED871I;VX-"B`@("`@*B!`<&%R86T@87)R87D-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971$;W=N;&]A9&5D4&%C:V%G97,H
M)B1P:V=S*0T*("`@('L-"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D97)R(#T@)'1H:7,M
M/F%N86QY>F5$97!E;F1E;F-I97,H)'!K9W,I.PT*("`@("`@("!014%2.CIP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G(I*2![#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^7V1O=VYL;V%D961086-K86=E<R`]("8D<&MG
M<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3970@=&AE(&QI<W0@;V8@
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4@;V)J96-T<R!T;R!A;&QO=R!M;W)E
M('-A;F4-"B`@("`@*B!D97!E;F1E;F-Y('9A;&ED871I;VX-"B`@("`@*B!`
M<&%R86T@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S9715;FEN<W1A
M;&Q086-K86=E<R@F)'!K9W,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1O
M=VYL;V%D961086-K86=E<R`]("8D<&MG<SL-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!G971);G-T86QL4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&]W;FQO861E9%!A8VMA9V5S.PT*("`@('T-"@T*("`@
M("\O('M[>R!I;G-T86QL*"D-"@T*("`@("\J*@T*("`@("`J($EN<W1A;&QS
M('1H92!F:6QE<R!W:71H:6X@=&AE('!A8VMA9V4@9FEL92!S<&5C:69I960N
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG?%!%05)?1&]W;FQO861E
M<E]086-K86=E("1P:V=F:6QE('!A=&@@=&\@=&AE('!A8VMA9V4@9FEL92P-
M"B`@("`@*B`@("`@("`@;W(@82!P<F4M:6YI=&EA;&EZ960@<&%C:V%G969I
M;&4@;V)J96-T#0H@("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS#0H@("`@
M("H@<F5C;V=N:7IE9"!O<'1I;VYS.@T*("`@("`J("T@:6YS=&%L;')O;W0@
M("`Z(&]P=&EO;F%L('!R969I>"!D:7)E8W1O<GD@9F]R(&EN<W1A;&QA=&EO
M;@T*("`@("`J("T@9F]R8V4@("`@("`@("`Z(&9O<F-E(&EN<W1A;&QA=&EO
M;@T*("`@("`J("T@<F5G:7-T97(M;VYL>2`Z('5P9&%T92!R96=I<W1R>2!B
M=70@9&]N)W0@:6YS=&%L;"!F:6QE<PT*("`@("`J("T@=7!G<F%D92`@("`@
M("`Z('5P9W)A9&4@97AI<W1I;F<@:6YS=&%L;`T*("`@("`J("T@<V]F="`@
M("`@("`@("`Z(&9A:6P@<VEL96YT;'D-"B`@("`@*B`M(&YO9&5P<R`@("`@
M("`@.B!I9VYO<F4@9&5P96YD96YC>2!C;VYF;&EC=',O;6ES<VEN9R!D97!E
M;F1E;F-I97,-"B`@("`@*B`M(&%L;&1E<',@("`@("`@.B!I;G-T86QL(&%L
M;"!D97!E;F1E;F-I97,-"B`@("`@*B`M(&]N;'ER97%D97!S("`@.B!I;G-T
M86QL(&]N;'D@<F5Q=6ER960@9&5P96YD96YC:65S#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y?%!%05)?17)R;W(@<&%C:V%G92!I;F9O(&EF('-U
M8V-E<W-F=6P-"B`@("`@*B\-"@T*("`@(&9U;F-T:6]N(&EN<W1A;&PH)'!K
M9V9I;&4L("1O<'1I;VYS(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@
M("`@(&EF("AI<U]O8FIE8W0H)'!K9V9I;&4I*2![#0H@("`@("`@("`@("`D
M9&QP:V<@/2`F)'!K9V9I;&4[#0H@("`@("`@("`@("`D<&MG(#T@)'!K9V9I
M;&4M/F=E=%!A8VMA9V5&:6QE*"D[#0H@("`@("`@("`@("`D<&MG9FEL92`]
M("1P:V<M/F=E=$%R8VAI=F5&:6QE*"D[#0H@("`@("`@("`@("`D9&5S8V9I
M;&4@/2`D<&MG+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@)'1M
M<&1I<B`](&1I<FYA;64H)&1E<V-F:6QE*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1D97-C9FEL92`]("1P:V=F:6QE.PT*("`@("`@("`@
M("`@)'1M<&1I<B`]("<G.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'!K9R`]("8D=&AI<RT^7W!A<G-E4&%C:V%G95AM;"@D9&5S8V9I;&4L
M("1T;7!D:7(I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&MG.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*')E86QP
M871H*"1D97-C9FEL92D@(3T@<F5A;'!A=&@H)'!K9V9I;&4I*2![#0H@("`@
M("`@("`@("`D=&%R(#T@;F5W($%R8VAI=F5?5&%R*"1P:V=F:6QE*3L-"B`@
M("`@("`@("`@(&EF("@A0"1T87(M/F5X=')A8W0H)'1M<&1I<BDI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N86)L
M92!T;R!U;G!A8VL@)'!K9V9I;&4B*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*#0H@("`@("`@("1P:V=N86UE(#T@)'!K9RT^9V5T3F%M92@I.PT*
M("`@("`@("`D8VAA;FYE;"`]("1P:V<M/F=E=$-H86YN96PH*3L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==
M*2D@>PT*("`@("`@("`@("`@)'!A8VMR;V]T<&AP7V1I<B`]("1T:&ES+3Y?
M<')E<&5N9%!A=&@H#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P:'!?9&ER)RP@;G5L;"P@)&-H86YN96PI+`T*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*3L-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG:6YS=&%L;')O
M;W0G72DI('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E=$EN<W1A
M;&Q2;V]T*"1O<'1I;VYS6R=I;G-T86QL<F]O="==*3L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T
M<GDH*3L-"B`@("`@("`@("`@("1I;G-T86QL<F5G:7-T<GD@/2`F)'1H:7,M
M/E]R96=I<W1R>3L-"B`@("`@("`@("`@("1T:&ES+3YI;G-T86QL<F]O="`]
M("<G.R`O+R!A;&P@9&]N92!A=71O;6%G:6-A;&QY(&YO=PT*("`@("`@("`@
M("`@)'!H<%]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G+"!N
M=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YS971);G-T86QL4F]O="AF86QS92D[#0H@("`@
M("`@("`@("`D=&AI<RT^7W)E9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E
M=%)E9VES=')Y*"D[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&EN<W1A;&QR96=I<W1R>2`]("9N97<@4$5!4E]296=I<W1R>2@D<&%C:W)O
M;W1P:'!?9&ER*3L-"B`@("`@("`@("`@("`@("`D<&AP7V1I<B`]("1P86-K
M<F]O='!H<%]D:7([#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1I;G-T86QL<F5G:7-T<GD@/2`F)'1H:7,M/E]R96=I<W1R>3L-
M"B`@("`@("`@("`@("`@("`D<&AP7V1I<B`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G<&AP7V1I<B<L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3YI;G-T86QL<F]O="`]("<G.PT*("`@("`@
M("!]#0H-"B`@("`@("`@+R\@>WM[(&-H96-K<R!T;R!D;R!W:&5N(&YO="!I
M;B`B9F]R8V4B(&UO9&4-"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=F
M;W)C92==*2`F)B!`:7-?9&ER*"1T:&ES+3YC;VYF:6<M/F=E="@G<&AP7V1I
M<B<I*2D@>PT*("`@("`@("`@("`@)'1E<W1P(#T@)&-H86YN96P@/3T@)W!E
M87(N<&AP+FYE="<@/R`D<&MG;F%M92`Z(&%R<F%Y*"1C:&%N;F5L+"`D<&MG
M;F%M92D[#0H@("`@("`@("`@("`D:6YS=&9I;&5L:7-T(#T@)'!K9RT^9V5T
M26YS=&%L;&%T:6]N1FEL94QI<W0H=')U92D[#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D:6YS=&9I;&5L:7-T*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D:6YS=&9I;&5L:7-T.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YC:&5C:T9I;&5-
M87`H)&EN<W1F:6QE;&ES="P@)'1E<W1P+"`G,2XQ)RD[#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&5S="DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1E<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H<VEZ96]F*"1T97-T*2D@>PT*("`@("`@("`@("`@("`@("1P:V=S(#T@
M)'1H:7,M/F=E=$EN<W1A;&Q086-K86=E<R@I.PT*("`@("`@("`@("`@("`@
M("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P
M:V=S(&%S("1P87)A;2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'!K
M9RT^:7-3=6)P86-K86=E3V8H)'!A<F%M*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9F]U;F0I('L-"B`@("`@
M("`@("`@("`@("`@("`@+R\@<W5B<&%C:V%G97,@8V%N(&-O;F9L:6-T('=I
M=&@@96%R;&EE<B!V97)S:6]N<R!O9B!P87)E;G0@<&%C:V%G97,-"B`@("`@
M("`@("`@("`@("`@("`@)'!A<F5N=')E9R`]("1I;G-T86QL<F5G:7-T<GDM
M/G!A8VMA9V5);F9O*"1P87)A;2T^9V5T4&%C:V%G92@I+"!N=6QL+"`D<&%R
M86TM/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@("`@("1T;7`@
M/2`D=&5S=#L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1M<"!A
M<R`D9FEL92`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1I;F9O*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')T;VQO=V5R*"1I;F9O6S%=*2`]/2!S=')T;VQO=V5R
M*"1P87)A;2T^9V5T4&%C:V%G92@I*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<G1O;&]W97(H)&EN9F];,%TI(#T]('-T<G1O
M;&]W97(H)'!A<F%M+3YG971#:&%N;F5L*"DI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1T97-T6R1F:6QE72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P87)E;G1R96=;
M)V9I;&5L:7-T)UU;)&9I;&5=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1P87)A
M;2T^9V5T0VAA;FYE;"@I*2`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*'-T<G1O;&]W97(H)&EN9F\I(#T]('-T<G1O;&]W97(H)'!A
M<F%M+3YG971086-K86=E*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('5N<V5T*"1T97-T6R1F:6QE72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1P87)E;G1R96=;)V9I;&5L:7-T
M)UU;)&9I;&5=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@)'!F:R`]("9N97<@4$5!4E]086-K
M86=E1FEL92@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@("`@("`@("`@("`@
M)'!A<F5N='!K9R`]("8D<&9K+3YF<F]M07)R87DH)'!A<F5N=')E9RD[#0H@
M("`@("`@("`@("`@("`@("`@("1I;G-T86QL<F5G:7-T<GDM/G5P9&%T95!A
M8VMA9V4R*"1P87)E;G1P:V<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H)'!A<F%M+3YG971#:&%N;F5L*"D@/3T@)W!E8VPN
M<&AP+FYE="<@)B8@:7-S970H)&]P=&EO;G-;)W5P9W)A9&4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1M<"`]("1T97-T.PT*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=&UP(&%S("1F:6QE(#T^("1I;F9O*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1I;F9O*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('!E87(N<&AP+FYE
M="!P86-K86=E<R!A<F4@86QW87ES('-T;W)E9"!A<R!S=')I;F=S#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&EN9F\I
M(#T]('-T<G1O;&]W97(H)'!A<F%M+3YG971086-K86=E*"DI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('5P9W)A9&EN9R!E>&ES
M=&EN9R!P86-K86=E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1T97-T6R1F:6QE72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AS:7IE;V8H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1M<V<@/2`B)&-H86YN96PO)'!K9VYA;64Z(&-O;F9L:6-T:6YG(&9I;&5S
M(&9O=6YD.EQN(CL-"B`@("`@("`@("`@("`@("`@("`@)&QO;F=E<W0@/2!M
M87@H87)R87E?;6%P*")S=')L96XB+"!A<G)A>5]K97ES*"1T97-T*2DI.PT*
M("`@("`@("`@("`@("`@("`@("`D9FUT(#T@(B4D>VQO;F=E<W1]<R`H)7,I
M7&XB.PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&5S="!A<R`D
M9FEL92`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<U]A<G)A>2@D:6YF;RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;R`](&%R<F%Y*"=P96%R+G!H<"YN970G+"`D:6YF;RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;R`]("1I;F9O6S!=("X@)R\G("X@)&EN9F];,5T[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D;7-G("X]('-P<FEN=&8H)&9M="P@)&9I
M;&4L("1I;F9O*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=I9VYO<F4M97)R;W)S
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&US9RD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FQO9R@P+"`B5T%23DE.1SH@)&US9R(I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("\O('U]?0T*#0H@("`@("`@("1T:&ES+3YS=&%R=$9I;&54<F%N<V%C=&EO
M;B@I.PT*#0H@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG=7!G<F%D92==
M*2`F)B!E;7!T>2@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M+R\@8VAE8VMS('1O(&1O(&]N;'D@=VAE;B!I;G-T86QL:6YG(&YE=R!P86-K
M86=E<PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES
M=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE+"`D8VAA;FYE;"D[#0H@("`@
M("`@("`@("`@("`@:68@*"$D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K
M9VYA;64L("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T97-T(#T@
M)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)&-H
M86YN96PI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1O<'1I;VYS6R=F;W)C92==*2`F)B`D=&5S="D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-H86YN96PO)'!K9VYA
M;64@:7,@86QR96%D>2!I;G-T86QL960B*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1U<V5C:&%N;F5L(#T@)&-H
M86YN96P[#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN<&AP
M+FYE="<I('L-"B`@("`@("`@("`@("`@("`D=&5S="`]("1I;G-T86QL<F5G
M:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L("1C:&%N;F5L*3L-"B`@
M("`@("`@("`@("`@("!I9B`H(21T97-T*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D
M<&MG;F%M92P@)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@("`@
M("`D=7-E8VAA;FYE;"`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E17AI<W1S*"1P:V=N
M86UE+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)'1E<W0I('L-"B`@("`@("`@("`@("`@("`D=C$@/2`D:6YS=&%L;')E
M9VES=')Y+3YP86-K86=E26YF;R@D<&MG;F%M92P@)W9E<G-I;VXG+"`D=7-E
M8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@)'8R(#T@)'!K9RT^9V5T5F5R
M<VEO;B@I.PT*("`@("`@("`@("`@("`@("1C;7`@/2!V97)S:6]N7V-O;7!A
M<F4H(B1V,2(L("(D=C(B+"`G9W0G*3L-"B`@("`@("`@("`@("`@("!I9B`H
M96UP='DH)&]P=&EO;G-;)V9O<F-E)UTI("8F("%V97)S:6]N7V-O;7!A<F4H
M(B1V,B(L("(D=C$B+"`G9W0G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5P9W)A9&4@=&\@82!N97=E<B!V
M97)S:6]N("@D=C(@:7,@;F]T(&YE=V5R('1H86X@)'8Q*2(I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&]P=&EO
M;G-;)W)E9VES=&5R+6]N;'DG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M+R\@=VAE;B!U<&=R861I;F<L(')E;6]V92!O;&0@<F5L96%S92=S(&9I;&5S
M(&9I<G-T.@T*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R(#T@)'1H:7,M/E]D96QE=&5086-K86=E1FEL97,H)'!K9VYA;64L
M("1U<V5C:&%N;F5L+`T*("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E
M*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<BD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@P+"`G5T%23DE.1SH@)R`N("1E<G(M/F=E=$UE<W-A9V4H*2D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&)A8VME9'5P(#T@)&5R<CL-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O('M[>R!#;W!Y(&9I;&5S('1O
M(&1E<W0@9&ER("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0T*#0H@("`@("`@("\O(&EN9F\@9G)O;2!T:&4@<&%C:V%G92!I="!S
M96QF('=E('=A;G0@=&\@86-C97-S(&9R;VT@7VEN<W1A;&Q&:6QE#0H@("`@
M("`@("1T:&ES+3YP:V=I;F9O(#T@)B1P:V<[#0H@("`@("`@("\O('5S960@
M=&\@9&5T97)M:6YE('=H971H97(@=V4@<VAO=6QD(&)U:6QD(&%N>2!#(&-O
M9&4-"B`@("`@("`@)'1H:7,M/G-O=7)C95]F:6QE<R`](#`[#0H-"B`@("`@
M("`@)'-A=F5C:&%N;F5L(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT
M7V-H86YN96PG*3L-"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=R96=I
M<W1E<BUO;FQY)UTI("8F("%I<U]D:7(H)'!H<%]D:7(I*2![#0H@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<BA3>7-T96TZ.FUK9&ER*&%R<F%Y*"<M
M<"<I+"`D<&AP7V1I<BDI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")N;R!I;G-T86QL871I;VX@9&5S=&EN871I;VX@
M9&ER96-T;W)Y("<D<&AP7V1I<B=<;B(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H-"B`@("`@("`@)'1M<%]P871H(#T@9&ER;F%M92@D9&5S8V9I
M;&4I.PT*("`@("`@("!I9B`H<W5B<W1R*"1P:V=F:6QE+"`M-"D@(3T@)RYX
M;6PG*2![#0H@("`@("`@("`@("`D=&UP7W!A=&@@+CT@1$E214-43U)97U-%
M4$%2051/4B`N("1P:V=N86UE("X@)RTG("X@)'!K9RT^9V5T5F5R<VEO;B@I
M.PT*("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F
M875L=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@("`O+R![>WL@:6YS
M=&%L;"!F:6QE<PT*("`@("`@("`-"B`@("`@("`@:68@*"1P:V<M/F=E=%!A
M8VMA9V5X;6Q697)S:6]N*"D@/3T@)S(N,"<I('L-"B`@("`@("`@("`@("1F
M:6QE;&ES="`]("1P:V<M/F=E=$EN<W1A;&QA=&EO;D9I;&5L:7-T*"D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9FEL96QI<W0@/2`D<&MG
M+3YG971&:6QE3&ES="@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1F:6QE;&ES="DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M9FEL96QI<W0[#0H@("`@("`@('T-"B`@("`@("`@)'!K9RT^<F5S971&:6QE
M;&ES="@I.PT*("`@("`@("`D<&MG+3YS971,87-T26YS=&%L;&5D5F5R<VEO
M;B@D:6YS=&%L;')E9VES=')Y+3YP86-K86=E26YF;R@D<&MG+3YG971086-K
M86=E*"DL#0H@("`@("`@("`@("`G=F5R<VEO;B<L("1P:V<M/F=E=$-H86YN
M96PH*2DI.PT*("`@("`@("!F;W)E86-H("@D9FEL96QI<W0@87,@)&9I;&4@
M/3X@)&%T=',I('L-"B`@("`@("`@("`@(&EF("@D<&MG+3YG971086-K86=E
M>&UL5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/F5X<&5C=$5R<F]R*%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@
M("`@("`@("`@("`@)')E<R`]("1T:&ES+3Y?:6YS=&%L;$9I;&4H)&9I;&4L
M("1A='1S+"`D=&UP7W!A=&@L("1O<'1I;VYS*3L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^<&]P17AP96-T*"D[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3YE>'!E8W1%<G)O<BA014%27TE.4U1!
M3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@("1R97,@/2`D=&AI<RT^
M7VEN<W1A;&Q&:6QE,B@D<&MG+"`D9FEL92P@)&%T=',L("1T;7!?<&%T:"P@
M)&]P=&EO;G,I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YP;W!%>'!E8W0H
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1R97,I*2![#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1O<'1I
M;VYS6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)')E<RT^9V5T365S<V%G92@I(#T](")F:6QE(&1O
M97,@;F]T(&5X:7-T(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G)A:7-E17)R;W(H(F9I;&4@)&9I;&4@:6X@<&%C:V%G92YX;6P@9&]E
M<R!N;W0@97AI<W0B*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<RD[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B5V%R;FEN9SH@(B`N("1R
M97,M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)')E<R`]/2!014%27TE.4U1!3$Q%4E]/2RD@>PT*("`@("`@("`@("`@
M("`@("\O(%)E9VES=&5R(&9I;&5S('1H870@=V5R92!I;G-T86QL960-"B`@
M("`@("`@("`@("`@("`D<&MG+3YI;G-T86QL961&:6QE*"1F:6QE+"`D871T
M<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@?7U]
M#0H-"B`@("`@("`@+R\@>WM[(&-O;7!I;&4@86YD(&EN<W1A;&P@<V]U<F-E
M(&9I;&5S#0H@("`@("`@(&EF("@D=&AI<RT^<V]U<F-E7V9I;&5S(#X@,"`F
M)B!E;7!T>2@D;W!T:6]N<ULG;F]B=6EL9"==*2D@>PT*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<B`]#0H@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-O;7!I;&53;W5R8V5&:6QE<R@D<V%V96-H86YN96PL("1P:V<I
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("\O('U]?0T*#0H@("`@("`@(&EF
M("AI<W-E="@D8F%C:V5D=7`I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W)E
M;6]V94)A8VMU<',H)&)A8VME9'5P*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(21T:&ES+3YC;VUM:71&:6QE5')A;G-A8W1I;VXH*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T:6]N*"D[#0H@("`@
M("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D
M<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")C;VUM:70@9F%I;&5D(BP@4$5!4E])3E-404Q,15)?1D%)3$5$
M*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!]?7T-"@T*("`@("`@("`D<F5T
M(#T@9F%L<V4[#0H@("`@("`@("1I;G-T86QL<&AA<V4@/2`G:6YS=&%L;"<[
M#0H@("`@("`@("1O;&1V97)S:6]N(#T@9F%L<V4[#0H@("`@("`@("\O('M[
M>R!296=I<W1E<B!T:&%T('1H92!P86-K86=E(&ES(&EN<W1A;&QE9"`M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0T*("`@("`@("!I9B`H96UP='DH)&]P=&EO
M;G-;)W5P9W)A9&4G72DI('L-"B`@("`@("`@("`@("\O(&EF("=F;W)C92<@
M:7,@=7-E9"P@<F5P;&%C92!T:&4@:6YF;R!I;B!R96=I<W1R>0T*("`@("`@
M("`@("`@)'5S96-H86YN96P@/2`D8VAA;FYE;#L-"B`@("`@("`@("`@(&EF
M("@D8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D
M<&MG;F%M92P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&EF("@A)'1E
M<W0I('L-"B`@("`@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E
M9VES=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE+"`G<&5A<BYP:'`N;F5T
M)RD[#0H@("`@("`@("`@("`@("`@("`@("1U<V5C:&%N;F5L(#T@)W!E87(N
M<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D=&5S="`]("1I;G-T86QL<F5G:7-T
M<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L("1C:&%N;F5L*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A96UP='DH)&]P=&EO;G-;)V9O
M<F-E)UTI("8F("1T97-T*2![#0H@("`@("`@("`@("`@("`@)&]L9'9E<G-I
M;VX@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E26YF;R@D<&MG;F%M92P@
M)W9E<G-I;VXG+"`D=7-E8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@)&EN
M<W1A;&QR96=I<W1R>2T^9&5L971E4&%C:V%G92@D<&MG;F%M92P@)'5S96-H
M86YN96PI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`]("1I
M;G-T86QL<F5G:7-T<GDM/F%D9%!A8VMA9V4R*"1P:V<I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'5S96-H86YN96P@/2`D8VAA;FYE;#L-
M"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RD@
M>PT*("`@("`@("`@("`@("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^
M<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)&-H86YN96PI.PT*("`@("`@("`@
M("`@("`@(&EF("@A)'1E<W0I('L-"B`@("`@("`@("`@("`@("`@("`@)'1E
M<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE
M+"`G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@("`@("`@("`@("`@("1U<V5C
M:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&5S="`]
M("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L("1C
M:&%N;F5L*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O(&YE=SH@
M=7!G<F%D92!I;G-T86QL<R!A('!A8VMA9V4@:68@:70@:7-N)W0@:6YS=&%L
M;&5D#0H@("`@("`@("`@("!I9B`H(21T97-T*2![#0H@("`@("`@("`@("`@
M("`@)')E="`]("1I;G-T86QL<F5G:7-T<GDM/F%D9%!A8VMA9V4R*"1P:V<I
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H
M)'5S96-H86YN96P@(3T@)&-H86YN96PI('L-"B`@("`@("`@("`@("`@("`@
M("`@)&EN<W1A;&QR96=I<W1R>2T^9&5L971E4&%C:V%G92@D<&MG;F%M92P@
M)'5S96-H86YN96PI.PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)&EN
M<W1A;&QR96=I<W1R>2T^861D4&%C:V%G93(H)'!K9RD[#0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`]("1I
M;G-T86QL<F5G:7-T<GDM/G5P9&%T95!A8VMA9V4R*"1P:V<I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D:6YS=&%L;'!H87-E(#T@
M)W5P9W)A9&4G.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@A)')E="D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G
M9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B061D:6YG('!A8VMA9V4@)&-H
M86YN96PO)'!K9VYA;64@=&\@<F5G:7-T<GD@9F%I;&5D(BD[#0H@("`@("`@
M('T-"B`@("`@("`@+R\@?7U]#0H@("`@("`@("1T:&ES+3YC;VYF:6=3970H
M)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@(&EF
M("AC;&%S<U]E>&ES=',H)U!%05)?5&%S:U]#;VUM;VXG*2D@>R`O+R!T:&ES
M(&ES(&%U=&\M:6YC;'5D960@:68@86YY('1A<VMS(&5X:7-T#0H@("`@("`@
M("`@("!I9B`H4$5!4E]487-K7T-O;6UO;CHZ:&%S4&]S=&EN<W1A;&Q487-K
M<R@I*2![#0H@("`@("`@("`@("`@("`@4$5!4E]487-K7T-O;6UO;CHZ<G5N
M4&]S=&EN<W1A;&Q487-K<R@D:6YS=&%L;'!H87-E*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'!K9RT^=&]!<G)A>2AT
M<G5E*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?8V]M
M<&EL95-O=7)C949I;&5S*"D-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C;VUP:6QE
M4V]U<F-E1FEL97,H)'-A=F5C:&%N;F5L+"`F)&9I;&5L:7-T*0T*("`@('L-
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T)U:6QD97(N<&AP)SL-"B`@
M("`@("`@)'1H:7,M/FQO9R@Q+"`B)'1H:7,M/G-O=7)C95]F:6QE<R!S;W5R
M8V4@9FEL97,L(&)U:6QD:6YG(BD[#0H@("`@("`@("1B;V(@/2`F;F5W(%!%
M05)?0G5I;&1E<B@D=&AI<RT^=6DI.PT*("`@("`@("`D8F]B+3YD96)U9R`]
M("1T:&ES+3YD96)U9SL-"B`@("`@("`@)&)U:6QT(#T@)&)O8BT^8G5I;&0H
M)&9I;&5L:7-T+"!A<G)A>2@F)'1H:7,L("=?8G5I;&1#86QL8F%C:R<I*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&)U:6QT*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T:6]N*"D[#0H@("`@
M("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D
M<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N("1B=6EL=#L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^;&]G*#$L(")<;D)U:6QD('!R;V-E
M<W,@8V]M<&QE=&5D('-U8V-E<W-F=6QL>2(I.PT*("`@("`@("!F;W)E86-H
M("@D8G5I;'0@87,@)&5X="D@>PT*("`@("`@("`@("`@)&)N(#T@8F%S96YA
M;64H)&5X=%LG9FEL92==*3L-"B`@("`@("`@("`@(&QI<W0H)%]E>'1?;F%M
M92P@)%]E>'1?<W5F9BD@/2!E>'!L;V1E*"<N)RP@)&)N*3L-"B`@("`@("`@
M("`@(&EF("@D7V5X=%]S=69F(#T]("<N<V\G('Q\("1?97AT7W-U9F8@/3T@
M)RYD;&PG*2![#0H@("`@("`@("`@("`@("`@:68@*&5X=&5N<VEO;E]L;V%D
M960H)%]E>'1?;F%M92DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G)A:7-E17)R;W(H(D5X=&5N<VEO;B`G)%]E>'1?;F%M92<@86QR96%D>2!L
M;V%D960N("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G4&QE87-E('5N;&]A9"!I="!I;B!Y;W5R('!H<"YI;FD@9FEL92`G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!R
M:6]R('1O(&EN<W1A;&P@;W(@=7!G<F%D92<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D<F]L92`]("=E>'0G.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<F]L92`]("=S<F,G.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E<W0@/2`D97AT6R=D97-T
M)UT[#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#$L("));G-T86QL:6YG("<D
M97AT6V9I;&5=)R(I.PT*("`@("`@("`@("`@)'!A8VMA9VEN9W)O;W0@/2`G
M)SL-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)W!A
M8VMA9VEN9W)O;W0G72DI('L-"B`@("`@("`@("`@("`@("`D<&%C:V%G:6YG
M<F]O="`]("1T:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&-O<'ET;R`]("1T:&ES+3Y?<')E
M<&5N9%!A=&@H)&1E<W0L("1P86-K86=I;F=R;V]T*3L-"B`@("`@("`@("`@
M("1C;W!Y9&ER(#T@9&ER;F%M92@D8V]P>71O*3L-"B`@("`@("`@("`@("\O
M('!R971T>2!M=6-H(&YO=&AI;F<@:&%P<&5N<R!I9B!W92!A<F4@;VYL>2!R
M96=I<W1E<FEN9R!T:&4@:6YS=&%L;`T*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A0&ES7V1I<B@D8V]P>61I<BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"$D=&AI<RT^;6M$:7)(:65R*"1C;W!Y9&ER*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")F86EL960@=&\@;6MD:7(@)&-O<'ED:7(B+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9R@S+"`B*R!M:V1I<B`D8V]P>61I<B(I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(4!C;W!Y*"1E>'1;)V9I;&4G
M72P@)&-O<'ET;RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")F86EL960@=&\@=W)I=&4@)&-O<'ET;R(L(%!%
M05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@8W`@)&5X=%MF:6QE72`D
M8V]P>71O(BD[#0H@("`@("`@("`@("`@("`@:68@*"%/4U]724Y$3U=3*2![
M#0H@("`@("`@("`@("`@("`@("`@("1M;V1E(#T@,#8V-B`F('XH:6YT*6]C
M=&1E8R@D=&AI<RT^8V]N9FEG+3YG970H)W5M87-K)RDI.PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@G8VAM;V0G+"!A
M<G)A>2@D;6]D92P@)&-O<'ET;RDI.PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(4!C:&UO9"@D8V]P>71O+"`D;6]D92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YL;V<H,"P@(F9A:6QE9"!T;R!C:&%N9V4@;6]D
M92!O9B`D8V]P>71O(BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9I;&5/
M<&5R871I;VXH)W)E;F%M92<L(&%R<F%Y*"1E>'1;)V9I;&4G72P@)&-O<'ET
M;RDI.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!I9B`H)&9I;&5L
M:7-T+3YG971086-K86=E6&UL5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@
M("`@("`@("`@("`@)&9I;&5L:7-T+3YI;G-T86QL961&:6QE*"1B;BP@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=R;VQE)R`]/B`D<F]L92P-"B`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1B;BP-"B`@("`@("`@("`@
M("`@("`@("`@)VEN<W1A;&QE9%]A<R<@/3X@)&1E<W0L#0H@("`@("`@("`@
M("`@("`@("`@("=P:'!?87!I)R`]/B`D97AT6R=P:'!?87!I)UTL#0H@("`@
M("`@("`@("`@("`@("`@("=Z96YD7VUO9%]A<&DG(#T^("1E>'1;)WIE;F1?
M;6]D7V%P:2==+`T*("`@("`@("`@("`@("`@("`@("`G>F5N9%]E>'1?87!I
M)R`]/B`D97AT6R=Z96YD7V5X=%]A<&DG72P-"B`@("`@("`@("`@("`@("`@
M("`@*2D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1F:6QE;&ES="T^:6YS=&%L;&5D1FEL92@D8FXL(&%R<F%Y*"=A='1R:6)S
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W)O;&4G(#T^("1R
M;VQE+`T*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&)N+`T*("`@
M("`@("`@("`@("`@("`@("`G:6YS=&%L;&5D7V%S)R`]/B`D9&5S="P-"B`@
M("`@("`@("`@("`@("`@("`@)W!H<%]A<&DG(#T^("1E>'1;)W!H<%]A<&DG
M72P-"B`@("`@("`@("`@("`@("`@("`@)WIE;F1?;6]D7V%P:2<@/3X@)&5X
M=%LG>F5N9%]M;V1?87!I)UTL#0H@("`@("`@("`@("`@("`@("`@("=Z96YD
M7V5X=%]A<&DG(#T^("1E>'1;)WIE;F1?97AT7V%P:2==+`T*("`@("`@("`@
M("`@("`@("`@("`I*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("!F=6YC=&EO;B`F9V5T56YI;G-T86QL
M4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W
M;FQO861E9%!A8VMA9V5S.PT*("`@('T-"B`@("`O+R![>WL@=6YI;G-T86QL
M*"D-"@T*("`@("\J*@T*("`@("`J(%5N:6YS=&%L;"!A('!A8VMA9V4-"B`@
M("`@*@T*("`@("`J(%1H:7,@;65T:&]D(')E;6]V97,@86QL(&9I;&5S(&EN
M<W1A;&QE9"!B>2!T:&4@87!P;&EC871I;VXL(&%N9"!T:&5N#0H@("`@("H@
M<F5M;W9E<R!A;GD@96UP='D@9&ER96-T;W)I97,N#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!P86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@87)R87D@0V]M
M;6%N9"UL:6YE(&]P=&EO;G,N("!0;W-S:6)I;&ET:65S(&EN8VQU9&4Z#0H@
M("`@("H-"B`@("`@*B`@("`@("`@("`@("`@+2!I;G-T86QL<F]O=#H@8F%S
M92!I;G-T86QL871I;VX@9&ER+"!I9B!N;W0@=&AE(&1E9F%U;'0-"B`@("`@
M*B`@("`@("`@("`@("`@+2!N;V1E<',Z(&1O(&YO="!P<F]C97-S(&1E<&5N
M9&5N8VEE<R!O9B!O=&AE<B!P86-K86=E<R!T;R!E;G-U<F4-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('5N:6YS=&%L;&%T:6]N(&1O97,@;F]T
M(&)R96%K('1H:6YG<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('5N:6YS=&%L
M;"@D<&%C:V%G92P@)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R=I;G-T86QL<F]O="==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T26YS=&%L;%)O;W0H)&]P=&EO
M;G-;)VEN<W1A;&QR;V]T)UTI.PT*("`@("`@("`@("`@)'1H:7,M/FEN<W1A
M;&QR;V]T(#T@)R<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&AI<RT^8V]N9FEG+3YS971);G-T86QL4F]O="@G)RD[#0H@("`@("`@("`@
M("`D=&AI<RT^:6YS=&%L;')O;W0@/2`G)SL-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7W)E9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)'!A8VMA9V4I*2![#0H@
M("`@("`@("`@("`D8VAA;FYE;"`]("1P86-K86=E+3YG971#:&%N;F5L*"D[
M#0H@("`@("`@("`@("`D<&MG(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`D
M<&%C:V%G92`]("1P:V<M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1P:V<@/2!F86QS93L-"B`@("`@("`@("`@("1I
M;F9O(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5086-K86=E3F%M92@D<&%C
M:V%G92P-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YG970H)V1E
M9F%U;'1?8VAA;FYE;"<I*3L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)&EN
M9F];)V-H86YN96PG73L-"B`@("`@("`@("`@("1P86-K86=E(#T@)&EN9F];
M)W!A8VMA9V4G73L-"B`@("`@("`@?0T*("`@("`@("`D<V%V96-H86YN96P@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@
M("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D8VAA
M;FYE;"D[#0H@("`@("`@(&EF("@A:7-?;V)J96-T*"1P:V<I*2![#0H@("`@
M("`@("`@("`D<&MG(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T4&%C:V%G92@D
M<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)'!K9RD@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L
M=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^7W)E9VES=')Y+3YP87)S9610
M86-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)&-H86YN96PL#0H@
M("`@("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B`D<&%C:V%G90T*("`@
M("`@("`@("`@("`@("DL('1R=64I("X@)R!N;W0@:6YS=&%L;&5D)RD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1P:V<M/F=E=$EN<W1A;&QE9$)I;F%R
M>2@I*2![#0H@("`@("`@("`@("`O+R!T:&ES(&ES(&IU<W0@86X@86QI87,@
M9F]R(&$@8FEN87)Y('!A8VMA9V4-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)E9VES=')Y+3YD96QE=&5086-K86=E*"1P86-K86=E+"`D8VAA;FYE
M;"D[#0H@("`@("`@('T-"B`@("`@("`@)&9I;&5L:7-T(#T@)'!K9RT^9V5T
M1FEL96QI<W0H*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@
M?0T*("`@("`@("`D9&5P8VAE8VME<B`]("9N97<@4$5!4E]$97!E;F1E;F-Y
M,B@D=&AI<RT^8V]N9FEG+"`D;W!T:6]N<RP@#0H@("`@("`@("`@("!A<G)A
M>2@G8VAA;FYE;"<@/3X@)&-H86YN96PL("=P86-K86=E)R`]/B`D<&%C:V%G
M92DL#0H@("`@("`@("`@("!014%27U9!3$E$051%7U5.24Y35$%,3$E.1RD[
M#0H@("`@("`@("1E(#T@)&1E<&-H96-K97(M/G9A;&ED871E4&%C:V%G955N
M:6YS=&%L;"@D=&AI<RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4I*2![
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=I9VYO<F4M97)R
M;W)S)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1E*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).24Y'.B`G("X@)&4M
M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&4I*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D95LP72D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@>WM[($1E;&5T92!T:&4@9FEL
M97,-"B`@("`@("`@)'1H:7,M/G-T87)T1FEL951R86YS86-T:6]N*"D[#0H@
M("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<B`]("1T:&ES
M+3Y?9&5L971E4&%C:V%G949I;&5S*"1P86-K86=E+"`D8VAA;FYE;"DI*2![
M#0H@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*3L-"B`@
M("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L
M("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G(I.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S
M;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@
M)U=!4DY)3D<Z("<@+B`D97)R+3YG971-97-S86=E*"DI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(21T:&ES+3YC;VUM:71&:6QE5')A;G-A8W1I;VXH
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T
M:6]N*"D[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=I9VYO
M<F4M97)R;W)S)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")U;FEN<W1A;&P@9F%I;&5D(BD[#0H@("`@("`@("`@
M("!](&5L<V5I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`G5T%23DE.1SH@=6YI;G-T86QL
M(&9A:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)'1H:7,M/G-T87)T1FEL951R86YS86-T:6]N*"D[#0H@
M("`@("`@("`@("!I9B`H)&1I<G1R964@/2`D<&MG+3YG971$:7)4<F5E*"DI
M('L-"B`@("`@("`@("`@("`@("`O+R!A='1E;7!T('1O(&1E;&5T92!E;7!T
M>2!D:7)E8W1O<FEE<PT*("`@("`@("`@("`@("`@('5K<V]R="@D9&ER=')E
M92P@87)R87DH)'1H:7,L("=?<V]R=$1I<G,G*2D[#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"@D9&ER=')E92!A<R`D9&ER(#T^("1N;W1U<V5D*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*"=R
M;61I<B<L(&%R<F%Y*"1D:7(I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF
M:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T<GDM/F1E;&5T95!A
M8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@A)'1H:7,M/F-O;6UI=$9I;&54<F%N<V%C=&EO;B@I
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS
M86-T:6]N*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M+R\@?7U]#0H-"B`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C
M:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@+R\@4F5G:7-T97(@
M=&AA="!T:&4@<&%C:V%G92!I<R!N;R!L;VYG97(@:6YS=&%L;&5D#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)E9VES=')Y+3YD96QE=&5086-K86=E*"1P
M86-K86=E+"`D8VAA;FYE;"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4V]R="!A(&QI<W0@;V8@87)R87ES(&]F(&%R<F%Y*&1O=VYL;V%D960@<&%C
M:V%G969I;&5N86UE*2!B>2!D97!E;F1E;F-Y+@T*("`@("`J#0H@("`@("H@
M270@86QS;R!R96UO=F5S(&1U<&QI8V%T92!D97!E;F1E;F-I97,-"B`@("`@
M*B!`<&%R86T@87)R87D@86X@87)R87D@;V8@4$5!4E]086-K86=E1FEL95]V
M6S$O,ET@;V)J96-T<PT*("`@("`J($!R971U<FX@87)R87E\4$5!4E]%<G)O
M<B!A<G)A>2!O9B!A<G)A>2AP86-K86=E9FEL96YA;64L('!A8VMA9V4N>&UL
M(&-O;G1E;G1S*0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-O<G1086-K86=E
M<T9O<E5N:6YS=&%L;"@F)'!A8VMA9V5S*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]D97!E;F1E;F-Y1$(@/2`F4$5!4E]$97!E;F1E;F-Y1$(Z.G-I;F=L
M971O;B@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'1H:7,M/E]D97!E;F1E;F-Y1$(I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D97!E;F1E;F-Y1$([#0H@("`@("`@('T-"B`@("`@("`@
M=7-O<G0H)'!A8VMA9V5S+"!A<G)A>2@F)'1H:7,L("=?<V]R=%5N:6YS=&%L
M;"<I*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?<V]R=%5N:6YS=&%L;"@D
M82P@)&(I#0H@("`@>PT*("`@("`@("!I9B`H(21A+3YG971$97!S*"D@)B8@
M(21B+3YG971$97!S*"DI('L-"B`@("`@("`@("`@(')E='5R;B`P.R`O+R!N
M96ET:&5R('!A8VMA9V4@:&%S(&1E<&5N9&5N8VEE<RP@;W)D97(@:7,@:6YS
M:6=N:69I8V%N=`T*("`@("`@("!]#0H@("`@("`@(&EF("@D82T^9V5T1&5P
M<R@I("8F("$D8BT^9V5T1&5P<R@I*2![#0H@("`@("`@("`@("!R971U<FX@
M+3$[("\O("1A(&UU<W0@8F4@:6YS=&%L;&5D(&%F=&5R("1B(&)E8V%U<V4@
M)&$@:&%S(&1E<&5N9&5N8VEE<PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)&$M/F=E=$1E<',H*2`F)B`D8BT^9V5T1&5P<R@I*2![#0H@("`@("`@("`@
M("!R971U<FX@,3L@+R\@)&(@;75S="!B92!I;G-T86QL960@869T97(@)&$@
M8F5C875S92`D8B!H87,@9&5P96YD96YC:65S#0H@("`@("`@('T-"B`@("`@
M("`@+R\@8F]T:"!P86-K86=E<R!H879E(&1E<&5N9&5N8VEE<PT*("`@("`@
M("!I9B`H)'1H:7,M/E]D97!E;F1E;F-Y1$(M/F1E<&5N9'-/;B@D82P@)&(I
M*2![#0H@("`@("`@("`@("!R971U<FX@+3$[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1T:&ES+3Y?9&5P96YD96YC>41"+3YD97!E;F1S3VXH)&(L("1A
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(#$[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(#`[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(%]S;W)T1&ER<R@I#0H@("`@9G5N8W1I;VX@7W-O<G1$:7)S*"1A+"`D8BD-
M"B`@("![#0H@("`@("`@(&EF("AS=')N871C;7`H)&$L("1B*2`]/2`M,2D@
M<F5T=7)N(#$[#0H@("`@("`@(&EF("AS=')N871C;7`H)&$L("1B*2`]/2`Q
M*2!R971U<FX@+3$[#0H@("`@("`@(')E='5R;B`P.PT*("`@('T-"@T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(%]B=6EL9$-A;&QB86-K*"D-"@T*("`@
M(&9U;F-T:6]N(%]B=6EL9$-A;&QB86-K*"1W:&%T+"`D9&%T82D-"B`@("![
M#0H@("`@("`@(&EF("@H)'=H870@/3T@)V-M9&]U='!U="<@)B8@)'1H:7,M
M/F1E8G5G(#X@,2D@?'P-"B`@("`@("`@("`@("@D=VAA="`]/2`G;W5T<'5T
M)R`F)B`D=&AI<RT^9&5B=6<@/B`P*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*')T<FEM*"1D871A*2P@)V)U:6QD)RD[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*+R\@>WM[(&UD-5]F
M:6QE*"D@=71I;&ET>2!F=6YC=&EO;@T*:68@*"%F=6YC=&EO;E]E>&ES=',H
M(FUD-5]F:6QE(BDI('L-"B`@("!F=6YC=&EO;B!M9#5?9FEL92@D9FEL96YA
M;64I('L-"B`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5N86UE+"`B<B(I.PT*
M("`@("`@("!I9B`H(21F<"D@<F5T=7)N(&YU;&P[#0H@("`@("`@(&EF("AF
M=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@
M("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M9FEL95]G971?8V]N=&5N=',H)&9I;&5N86UE*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1C;VYT96YT<R`](&9R96%D*"1F<"P@9FEL97-I
M>F4H)&9I;&5N86UE*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@;60U*"1C;VYT96YT<RD[#0H@("`@
M?0T*?0T*+R\@?7U]#0H-"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]296UO=&4N<&AP````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-#4S-C,`,3`U,34T,S$P-3<`,#(P,#0W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(%!%05)?4F5M;W1E#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T
M(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T
M:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S
M8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(%)E;6]T92YP:'`L=B`Q+C<V(#(P,#8O,#,O,#(@,3@Z,30Z
M,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(&YE961E
M9"!F;W(@4$5!4E]%<G)O<@T*("HO#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP
M)SL-"G)E<75I<F5?;VYC92`G4$5!4B]#;VYF:6<N<&AP)SL-"@T*+RHJ#0H@
M*B!4:&ES(&ES(&$@8VQA<W,@9F]R(&1O:6YG(')E;6]T92!O<&5R871I;VYS
M(&%G86EN<W0@=&AE(&-E;G1R86P-"B`J(%!%05(@9&%T86)A<V4N#0H@*@T*
M("H@0&YO9&5P(%A-3%]24$-?5F%L=64-"B`J($!N;V1E<"!834Q?4E!#7TUE
M<W-A9V4-"B`J($!N;V1E<"!834Q?4E!#7T-L:65N=`T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E
M9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*
M8VQA<W,@4$5!4E]296UO=&4@97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[
M('!R;W!E<G1I97,-"@T*("`@('9A<B`D8V]N9FEG(#T@;G5L;#L-"B`@("!V
M87(@)&-A8VAE("`](&YU;&P[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%2
M7U)E9VES=')Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@=F%R("1?<F5G:7-T<GD[#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!014%27U)E;6]T92AC;VYF:6=?;V)J96-T*0T*#0H@("`@9G5N8W1I;VX@
M4$5!4E]296UO=&4H)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M4$5!4B@I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG(#T@)B1C;VYF:6<[#0H@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4F5G:7-T<GDH*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M<V5T4F5G:7-T<GDH*0T*("`@(`T*("`@(&9U;F-T:6]N('-E=%)E9VES=')Y
M*"8D<F5G*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D
M<F5G.PT*("`@('T-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T0V%C:&4H
M*0T*#0H-"B`@("!F=6YC=&EO;B!G971#86-H92@D87)G<RD-"B`@("![#0H@
M("`@("`@("1I9"`@("`@("`](&UD-2AS97)I86QI>F4H)&%R9W,I*3L-"B`@
M("`@("`@)&-A8VAE9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H95]D
M:7(G*3L-"B`@("`@("`@)&9I;&5N86UE(#T@)&-A8VAE9&ER("X@1$E214-4
M3U)97U-%4$%2051/4B`N("=X;6QR<&-?8V%C:&5?)R`N("1I9#L-"B`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL96YA;64I*2![#0H@("`@("`@("`@
M("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*#0H@("`@("`@("1F<"`](&9O
M<&5N*"1F:6QE;F%M92P@)W)B)RD[#0H@("`@("`@(&EF("@A)&9P*2![#0H@
M("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1C;VYT96YT
M(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&5N86UE*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1C;VYT96YT("`](&9R96%D*"1F<"P@9FEL
M97-I>F4H)&9I;&5N86UE*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5S=6QT("`@/2!A<G)A>2@-"B`@("`@
M("`@("`@("=A9V4G("`@("`@("`]/B!T:6UE*"D@+2!F:6QE;71I;64H)&9I
M;&5N86UE*2P-"B`@("`@("`@("`@("=L87-T0VAA;F=E)R`]/B!F:6QE;71I
M;64H)&9I;&5N86UE*2P-"B`@("`@("`@("`@("=C;VYT96YT)R`@("`]/B!U
M;G-E<FEA;&EZ92@D8V]N=&5N="DL#0H@("`@("`@("`@("`I.PT*("`@("`@
M("!R971U<FX@)')E<W5L=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@
M("\O('M[>R!S879E0V%C:&4H*0T*#0H@("`@9G5N8W1I;VX@<V%V94-A8VAE
M*"1A<F=S+"`D9&%T82D-"B`@("![#0H@("`@("`@("1I9"`@("`@("`](&UD
M-2AS97)I86QI>F4H)&%R9W,I*3L-"B`@("`@("`@)&-A8VAE9&ER(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=C86-H95]D:7(G*3L-"B`@("`@("`@:68@*"%F
M:6QE7V5X:7-T<R@D8V%C:&5D:7(I*2![#0H@("`@("`@("`@("!3>7-T96TZ
M.FUK9&ER*&%R<F%Y*"<M<"<L("1C86-H961I<BDI.PT*("`@("`@("!]#0H@
M("`@("`@("1F:6QE;F%M92`]("1C86-H961I<BXG+WAM;')P8U]C86-H95\G
M+B1I9#L-"@T*("`@("`@("`D9G`@/2!`9F]P96XH)&9I;&5N86UE+"`B=V(B
M*3L-"B`@("`@("`@:68@*"1F<"D@>PT*("`@("`@("`@("`@9G=R:71E*"1F
M<"P@<V5R:6%L:7IE*"1D871A*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(&-L96%R0V%C:&4H*0T*#0H@("`@9G5N8W1I;VX@8VQE87)#86-H92@D
M;65T:&]D+"`D87)G<RD-"B`@("![#0H@("`@("`@(&%R<F%Y7W5N<VAI9G0H
M)&%R9W,L("1M971H;V0I.PT*("`@("`@("!A<G)A>5]U;G-H:69T*"1A<F=S
M+"`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I*3L@+R\@
M8V%C:&4@8GD@8VAA;FYE;`T*("`@("`@("`D:60@("`@("`@/2!M9#4H<V5R
M:6%L:7IE*"1A<F=S*2D[#0H@("`@("`@("1C86-H961I<B`]("1T:&ES+3YC
M;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD[#0H@("`@("`@("1F:6QE;F%M92`]
M("1C86-H961I<BXG+WAM;')P8U]C86-H95\G+B1I9#L-"B`@("`@("`@:68@
M*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('L-"B`@("`@("`@("`@($!U;FQI
M;FLH)&9I;&5N86UE*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!C86QL*&UE=&AO9"P@6V%R9W,N+BY=*0T*#0H@("`@
M9G5N8W1I;VX@8V%L;"@D;65T:&]D*0T*("`@('L-"B`@("`@("`@)%]A<F=S
M(#T@)&%R9W,@/2!F=6YC7V=E=%]A<F=S*"D[#0H-"B`@("`@("`@)'-E<G9E
M<E]C:&%N;F5L(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN
M96PG*3L-"B`@("`@("`@)&-H86YN96P@/2`D=&AI<RT^7W)E9VES=')Y+3YG
M971#:&%N;F5L*"1S97)V97)?8VAA;FYE;"D[#0H@("`@("`@(&EF("@A4$5!
M4CHZ:7-%<G)O<B@D8VAA;FYE;"DI('L-"B`@("`@("`@("`@("1M:7)R;W(@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*3L-"B`@
M("`@("`@("`@(&EF("@D8VAA;FYE;"T^9V5T36ER<F]R*"1M:7)R;W(I*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N;F5L+3YS=7!P;W)T<R@G>&UL
M<G!C)RP@)&UE=&AO9"P@)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'-E<G9E<E]C:&%N;F5L(#T@)'-E<G9E<E]H;W-T(#T@)&UI<G)O<CL@
M+R\@=7-E('1H92!P<F5F97)R960@;6ER<F]R#0H@("`@("`@("`@("`@("`@
M("`@("1S97)V97)?<&]R="`]("1C:&%N;F5L+3YG9710;W)T*"1M:7)R;W(I
M.PT*("`@("`@("`@("`@("`@('T@96QS96EF("@A)&-H86YN96PM/G-U<'!O
M<G1S*"=X;6QR<&,G+"`D;65T:&]D*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN96P@)'-E<G9E<E]C
M:&%N;F5L(&1O97,@;F]T("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M(G-U<'!O<G0@>&UL+7)P8R!M971H;V0@)&UE=&AO9"(I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'-E<G9E<E]H;W-T*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A)&-H
M86YN96PM/G-U<'!O<G1S*"=X;6QR<&,G+"`D;65T:&]D*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN
M96P@)'-E<G9E<E]C:&%N;F5L(&1O97,@;F]T('-U<'!O<G0@(B`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`B>&UL+7)P8R!M971H;V0@)&UE=&AO9"(I
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1S97)V97)?:&]S="`]("1S97)V97)?8VAA;FYE;#L-"B`@("`@("`@
M("`@("`@("`@("`@)'-E<G9E<E]P;W)T(#T@)&-H86YN96PM/F=E=%!O<G0H
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(E5N:VYO=VX@8VAA;FYE;"`G)'-E<G9E<E]C:&%N;F5L)R(I.PT*("`@
M("`@("!]#0H-"B`@("`@("`@87)R87E?=6YS:&EF="@D7V%R9W,L("1S97)V
M97)?8VAA;FYE;"D[("\O(&-A8VAE(&)Y(&-H86YN96P-"B`@("`@("`@)'1H
M:7,M/F-A8VAE(#T@)'1H:7,M/F=E=$-A8VAE*"1?87)G<RD[#0H@("`@("`@
M("1C86-H971T;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?='1L)RD[
M#0H@("`@("`@("\O($EF(&-A8VAE(&ES(&YE=V5R('1H86X@)&-A8VAE='1L
M('-E8V]N9',L('=E('5S92!T:&4@8V%C:&4A#0H@("`@("`@(&EF("@D=&AI
M<RT^8V%C:&4@(3T](&YU;&P@)B8@)'1H:7,M/F-A8VAE6R=A9V4G72`\("1C
M86-H971T;"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC86-H95LG
M8V]N=&5N="==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE>'1E;G-I;VY?
M;&]A9&5D*")X;6QR<&,B*2D@>PT*("`@("`@("`@("`@)')E<W5L="`](&-A
M;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D=&AI<RP@)V-A;&Q?97!I)RDL
M("1A<F=S*3L-"B`@("`@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YS879E0V%C:&4H)%]A
M<F=S+"`D<F5S=6QT*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PT*("`@("`@("!](&5L<V5I9B`H(4!I;F-L=61E7V]N
M8V4@)UA-3"]24$,N<&AP)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")&;W(@=&AI<R!R96UO=&4@4$5!4B!O<&5R871I;VX@
M>6]U(&YE960@=&\@;&]A9"!T:&4@>&UL<G!C(&5X=&5N<VEO;B!O<B!I;G-T
M86QL(%A-3%]24$,B*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&%R<F%Y7W-H
M:69T*"1A<F=S*3L-"B`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=U<V5R;F%M92<I.PT*("`@("`@("`D<&%S<W=O<F0@/2`D=&AI
M<RT^8V]N9FEG+3YG970H)W!A<W-W;W)D)RD[#0H@("`@("`@("1E87)G<R`]
M(&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@H)&%R9W,@87,@)&%R9RD@>PT*
M("`@("`@("`@("`@)&5A<F=S6UT@/2`D=&AI<RT^7V5N8V]D92@D87)G*3L-
M"B`@("`@("`@?0T*("`@("`@("`D9B`](&YE=R!834Q?4E!#7TUE<W-A9V4H
M)&UE=&AO9"P@)&5A<F=S*3L-"B`@("`@("`@:68@*"1T:&ES+3YC86-H92`A
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&UA>$%G92`]("<_;6%X06=E/2<N
M)'1H:7,M/F-A8VAE6R=L87-T0VAA;F=E)UT[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D;6%X06=E(#T@)R<[#0H@("`@("`@('T-"B`@("`@
M("`@)'!R;WAY7VAO<W0@/2`D<')O>'E?<&]R="`]("1P<F]X>5]U<V5R(#T@
M)'!R;WAY7W!A<W,@/2`G)SL-"B`@("`@("`@:68@*"1P<F]X>2`]('!A<G-E
M7W5R;"@D=&AI<RT^8V]N9FEG+3YG970H)VAT='!?<')O>'DG*2DI('L-"B`@
M("`@("`@("`@("1P<F]X>5]H;W-T(#T@0"1P<F]X>5LG:&]S="==.PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LG<V-H96UE)UTI("8F("1P<F]X
M>5LG<V-H96UE)UT@/3T@)VAT='!S)RD@>PT*("`@("`@("`@("`@("`@("1P
M<F]X>5]H;W-T(#T@)VAT='!S.B\O)R`N("1P<F]X>5]H;W-T.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2!`)'!R;WAY6R=P
M;W)T)UT[#0H@("`@("`@("`@("`D<')O>'E?=7-E<B`]($!U<FQD96-O9&4H
M0"1P<F]X>5LG=7-E<B==*3L-"B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@
M0'5R;&1E8V]D92A`)'!R;WAY6R=P87-S)UTI.PT*("`@("`@("!]#0H@("`@
M("`@("1S:&]S="`]("1S97)V97)?:&]S=#L-"B`@("`@("`@:68@*"1C:&%N
M;F5L+3YG97134TPH*2D@>PT*("`@("`@("`@("`@)'-H;W-T(#T@(FAT='!S
M.B\O)'-H;W-T(CL-"B`@("`@("`@?0T*("`@("`@("`D8R`](&YE=R!834Q?
M4E!#7T-L:65N="@G+R<@+B`D8VAA;FYE;"T^9V5T4&%T:"@G>&UL<G!C)RD-
M"B`@("`@("`@("`@("X@)&UA>$%G92P@)'-H;W-T+"`D<V5R=F5R7W!O<G0L
M("1P<F]X>5]H;W-T+"`D<')O>'E?<&]R="P-"B`@("`@("`@("`@("1P<F]X
M>5]U<V5R+"`D<')O>'E?<&%S<RD[#0H@("`@("`@(&EF("@D=7-E<FYA;64@
M)B8@)'!A<W-W;W)D*2![#0H@("`@("`@("`@("`D8RT^<V5T0W)E9&5N=&EA
M;',H)'5S97)N86UE+"`D<&%S<W=O<F0I.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^/2`S*2![#0H@
M("`@("`@("`@("`D8RT^<V5T1&5B=6<H,2D[#0H@("`@("`@('T-"B`@("`@
M("`@)'(@/2`D8RT^<V5N9"@D9BD[#0H@("`@("`@(&EF("@A)'(I('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B6$U,7U)00R!S
M96YD(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@("1V(#T@)'(M/G9A
M;'5E*"D[#0H@("`@("`@(&EF("@D92`]("1R+3YF875L=$-O9&4H*2D@>PT*
M("`@("`@("`@("`@:68@*"1E(#T]("1'3$]"04Q36R=834Q?4E!#7V5R<B==
M6R=H='1P7V5R<F]R)UT@)B8@<W1R<W1R*"1R+3YF875L=%-T<FEN9R@I+"`G
M,S`T($YO="!-;V1I9FEE9"<I("$]/2!F86QS92D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^8V%C:&5;)V-O;G1E;G0G73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M<BT^9F%U;'13=')I;F<H*2P@)&4I.PT*("`@("`@("!]#0H-"B`@("`@("`@
M)')E<W5L="`](%A-3%]24$-?9&5C;V1E*"1V*3L-"B`@("`@("`@)'1H:7,M
M/G-A=F5#86-H92@D7V%R9W,L("1R97-U;'0I.PT*("`@("`@("!R971U<FX@
M)')E<W5L=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C
M86QL7V5P:2AM971H;V0L(%MA<F=S+BXN72D-"@T*("`@(&9U;F-T:6]N(&-A
M;&Q?97!I*"1M971H;V0I#0H@("`@>PT*("`@("`@("!D;R![#0H@("`@("`@
M("`@("!I9B`H97AT96YS:6]N7VQO861E9"@B>&UL<G!C(BDI('L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("A/4U]724Y$3U=3*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("=D
M;&PG.PT*("`@("`@("`@("`@?2!E;'-E:68@*%!(4%]/4R`]/2`G2%`M55@G
M*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("=S;"<[#0H@("`@("`@("`@
M("!](&5L<V5I9B`H4$A07T]3(#T]("=!25@G*2![#0H@("`@("`@("`@("`@
M("`@)&5X="`]("=A)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&5X="`]("=S;R<[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D97AT(#T@3U-?5TE.1$]74R`_("=D;&PG(#H@)W-O)SL-"B`@("`@
M("`@("`@($!D;"@B>&UL<G!C+65P:2XD97AT(BD[#0H@("`@("`@("`@("!I
M9B`H97AT96YS:6]N7VQO861E9"@B>&UL<G!C(BDI('L-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@($!D;"@B
M>&UL<G!C+B1E>'0B*3L-"B`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A
M9&5D*")X;6QR<&,B*2D@>PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")U;F%B;&4@=&\@;&]A9"!X;6QR<&,@97AT96YS:6]N(BD[#0H@("`@
M("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@("`@("`@)'-E<G9E<E]C:&%N;F5L
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@
M("`@("`@)&-H86YN96P@/2`D=&AI<RT^7W)E9VES=')Y+3YG971#:&%N;F5L
M*"1S97)V97)?8VAA;FYE;"D[#0H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O
M<B@D8VAA;FYE;"DI('L-"B`@("`@("`@("`@("1M:7)R;W(@/2`D=&AI<RT^
M8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*3L-"B`@("`@("`@("`@
M(&EF("@D8VAA;FYE;"T^9V5T36ER<F]R*"1M:7)R;W(I*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1C:&%N;F5L+3YS=7!P;W)T<R@G>&UL<G!C)RP@)&UE
M=&AO9"P@)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E
M<E]C:&%N;F5L(#T@)'-E<G9E<E]H;W-T(#T@)&UI<G)O<CL@+R\@=7-E('1H
M92!P<F5F97)R960@;6ER<F]R#0H@("`@("`@("`@("`@("`@("`@("1S97)V
M97)?<&]R="`]("1C:&%N;F5L+3YG9710;W)T*"1M:7)R;W(I.PT*("`@("`@
M("`@("`@("`@('T@96QS96EF("@A)&-H86YN96PM/G-U<'!O<G1S*"=X;6QR
M<&,G+"`D;65T:&]D*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN96P@)'-E<G9E<E]C:&%N;F5L(&1O
M97,@;F]T("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@(G-U<'!O<G0@
M>&UL+7)P8R!M971H;V0@)&UE=&AO9"(I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'-E<G9E
M<E]H;W-T*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A)&-H86YN96PM/G-U
M<'!O<G1S*"=X;6QR<&,G+"`D;65T:&]D*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN96P@)'-E<G9E
M<E]C:&%N;F5L(&1O97,@;F]T('-U<'!O<G0@(B`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`B>&UL+7)P8R!M971H;V0@)&UE=&AO9"(I.PT*("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1S97)V
M97)?:&]S="`]("1S97)V97)?8VAA;FYE;#L-"B`@("`@("`@("`@("`@("`@
M("`@)'-E<G9E<E]P;W)T(#T@)&-H86YN96PM/F=E=%!O<G0H*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E5N:VYO
M=VX@8VAA;FYE;"`G)'-E<G9E<E]C:&%N;F5L)R(I.PT*("`@("`@("!]#0H@
M("`@("`@("1P87)A;7,@/2!F=6YC7V=E=%]A<F=S*"D[#0H@("`@("`@(&%R
M<F%Y7W-H:69T*"1P87)A;7,I.PT*("`@("`@("`D;65T:&]D(#T@<W1R7W)E
M<&QA8V4H(E\B+"`B+B(L("1M971H;V0I.PT*("`@("`@("`D<F5Q=65S="`]
M('AM;')P8U]E;F-O9&5?<F5Q=65S="@D;65T:&]D+"`D<&%R86US*3L-"B`@
M("`@("`@:68@*"1H='1P7W!R;WAY(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=H
M='1P7W!R;WAY)RDI('L-"B`@("`@("`@("`@("1P<F]X>2`]('!A<G-E7W5R
M;"@D:'1T<%]P<F]X>2D[#0H@("`@("`@("`@("`D<')O>'E?:&]S="`]("1P
M<F]X>5]P;W)T(#T@)'!R;WAY7W5S97(@/2`D<')O>'E?<&%S<R`]("<G.PT*
M("`@("`@("`@("`@)'!R;WAY7VAO<W0@/2!`)'!R;WAY6R=H;W-T)UT[#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'!R;WAY6R=S8VAE;64G72D@)B8@)'!R
M;WAY6R=S8VAE;64G72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@("`@("`@
M)'!R;WAY7VAO<W0@/2`G<W-L.B\O)R`N("1P<F]X>5]H;W-T.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2!`)'!R;WAY6R=P
M;W)T)UT[#0H@("`@("`@("`@("`D<')O>'E?=7-E<B`]($!U<FQD96-O9&4H
M0"1P<F]X>5LG=7-E<B==*3L-"B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@
M0'5R;&1E8V]D92A`)'!R;WAY6R=P87-S)UTI.PT*("`@("`@("`@("`@)&9P
M(#T@0&9S;V-K;W!E;B@D<')O>'E?:&]S="P@)'!R;WAY7W!O<G0I.PT*("`@
M("`@("`@("`@)'5S95]P<F]X>2`]('1R=64[#0H@("`@("`@("`@("!I9B`H
M)&-H86YN96PM/F=E=%-33"@I*2![#0H@("`@("`@("`@("`@("`@)'-E<G9E
M<E]H;W-T(#T@(FAT='!S.B\O)'-E<G9E<E]H;W-T(CL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1U<V5?<')O>'D@
M/2!F86QS93L-"B`@("`@("`@("`@("1S<VP@/2`D8VAA;FYE;"T^9V5T4U-,
M*"D[#0H@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"@D<W-L(#\@)W-S
M;#HO+R<@.B`G)RD@+B`D<V5R=F5R7VAO<W0L("1S97)V97)?<&]R="D[#0H@
M("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@("1S97)V
M97)?:&]S="`]("(D<W-L)'-E<G9E<E]H;W-T(CL@+R\@9F]R(&5R<F]R+7)E
M<&]R=&EN9PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("@A)&9P("8F("1H='1P7W!R;WAY*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?4F5M;W1E.CIC86QL.B!F<V]C:V]P
M96XH8"1P<F]X>5]H;W-T)RP@)'!R;WAY7W!O<G0I(&9A:6QE9"(I.PT*("`@
M("`@("!](&5L<V5I9B`H(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")014%27U)E;6]T93HZ8V%L;#H@9G-O8VMO<&5N
M*&`D<V5R=F5R7VAO<W0G+"`D<V5R=F5R7W!O<G0I(&9A:6QE9"(I.PT*("`@
M("`@("!]#0H@("`@("`@("1L96X@/2!S=')L96XH)')E<75E<W0I.PT*("`@
M("`@("`D<F5Q7VAE861E<G,@/2`B2&]S=#H@)'-E<G9E<E]H;W-T.B1S97)V
M97)?<&]R=%QR7&XB("X-"B`@("`@("`@("`@("`B0V]N=&5N="UT>7!E.B!T
M97AT+WAM;%QR7&XB("X-"B`@("`@("`@("`@("`B0V]N=&5N="UL96YG=&@Z
M("1L96Y<<EQN(CL-"B`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=U<V5R;F%M92<I.PT*("`@("`@("`D<&%S<W=O<F0@/2`D=&AI
M<RT^8V]N9FEG+3YG970H)W!A<W-W;W)D)RD[#0H@("`@("`@(&EF("@D=7-E
M<FYA;64@)B8@)'!A<W-W;W)D*2![#0H@("`@("`@("`@("`D<F5Q7VAE861E
M<G,@+CT@(D-O;VMI93H@4$5!4E]54T52/21U<V5R;F%M93L@4$5!4E]05STD
M<&%S<W=O<F1<<EQN(CL-"B`@("`@("`@("`@("1T;7`@/2!B87-E-C1?96YC
M;V1E*"(D=7-E<FYA;64Z)'!A<W-W;W)D(BD[#0H@("`@("`@("`@("`D<F5Q
M7VAE861E<G,@+CT@(D%U=&AO<FEZ871I;VXZ($)A<VEC("1T;7!<<EQN(CL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/F-A8VAE("$]/2!N=6QL
M*2![#0H@("`@("`@("`@("`D;6%X06=E(#T@)S]M87A!9V4])RXD=&AI<RT^
M8V%C:&5;)VQA<W1#:&%N9V4G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1M87A!9V4@/2`G)SL-"B`@("`@("`@?0T*#0H@("`@("`@(&EF
M("@D=7-E7W!R;WAY("8F("1P<F]X>5]H;W-T("$]("<G("8F("1P<F]X>5]U
M<V5R("$]("<G*2![#0H@("`@("`@("`@("`D<F5Q7VAE861E<G,@+CT@)U!R
M;WAY+4%U=&AO<FEZ871I;VXZ($)A<VEC("<-"B`@("`@("`@("`@("`@("`N
M8F%S938T7V5N8V]D92@D<')O>'E?=7-E<BXG.B<N)'!R;WAY7W!A<W,I#0H@
M("`@("`@("`@("`@("`@+B)<<EQN(CL-"B`@("`@("`@?0T*#0H@("`@("`@
M(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#,I('L-"B`@
M("`@("`@("`@('!R:6YT(")834Q24$,@4D5154535"!(14%$15)3.EQN(CL-
M"B`@("`@("`@("`@('9A<E]D=6UP*"1R97%?:&5A9&5R<RD[#0H@("`@("`@
M("`@("!P<FEN="`B6$U,4E!#(%)%455%4U0@0D]$63I<;B([#0H@("`@("`@
M("`@("!V87)?9'5M<"@D<F5Q=65S="D[#0H@("`@("`@('T-"@T*("`@("`@
M("!I9B`H)'5S95]P<F]X>2`F)B`D<')O>'E?:&]S="`A/2`G)RD@>PT*("`@
M("`@("`@("`@)'!O<W1?<W1R:6YG(#T@(E!/4U0@:'1T<#HO+R(N)'-E<G9E
M<E]H;W-T.PT*("`@("`@("`@("`@:68@*"1P<F]X>5]P;W)T(#X@)R<I('L-
M"B`@("`@("`@("`@("`@("`D<&]S=%]S=')I;F<@+CT@)SHG+B1S97)V97)?
M<&]R=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1P;W-T7W-T<FEN9R`](")03U-4("([#0H@("`@("`@('T-"@T*
M("`@("`@("`D<&%T:"`]("<O)R`N("1C:&%N;F5L+3YG9710871H*"=X;6QR
M<&,G*3L-"B`@("`@("`@9G=R:71E*"1F<"P@*"1P;W-T7W-T<FEN9R`N("1P
M871H("X@(B1M87A!9V4@2%144"\Q+C!<<EQN)')E<5]H96%D97)S7')<;B1R
M97%U97-T(BDI.PT*("`@("`@("`D<F5S<&]N<V4@/2`G)SL-"B`@("`@("`@
M)&QI;F4Q(#T@9F=E=',H)&9P+"`R,#0X*3L-"B`@("`@("`@:68@*"%P<F5G
M7VUA=&-H*"<A7DA45%`O6S`M.5PN72L@*%QD*RD@*"XJ*2$G+"`D;&EN93$L
M("1M871C:&5S*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")014%27U)E;6]T93H@:6YV86QI9"!(5%10(')E<W!O;G-E(&9R
M;VT@6$U,+5)00R!S97)V97(B*3L-"B`@("`@("`@?0T*("`@("`@("!S=VET
M8V@@*"1M871C:&5S6S%=*2![#0H@("`@("`@("`@("!C87-E("(R,#`B.B`O
M+R!/2PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`B,S`T(CH@+R\@3F]T($UO9&EF:65D#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YC86-H95LG8V]N=&5N="==.PT*("`@("`@("`@("`@8V%S
M92`B-#`Q(CH@+R\@56YA=71H;W)I>F5D#0H@("`@("`@("`@("`@("`@:68@
M*"1U<V5R;F%M92`F)B`D<&%S<W=O<F0I('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")014%27U)E;6]T92`H)'-E
M<G9E<E]H;W-T.B1S97)V97)?<&]R="D@(B`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`B.B!A=71H;W)I>F%T:6]N(&9A:6QE9"(L(#0P,2D[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")014%27U)E;6]T92`H)'-E<G9E<E]H
M;W-T.B1S97)V97)?<&]R="D@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`B.B!A=71H;W)I>F%T:6]N(')E<75I<F5D+"!P;&5A<V4@;&]G(&EN(&9I
M<G-T(BP@-#`Q*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!D
M969A=6QT.@T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B4$5!4E]296UO=&4@*"1S97)V97)?:&]S=#HD<V5R=F5R7W!O<G0I
M(#H@(B`N#0H@("`@("`@("`@("`@("`@("`@(")U;F5X<&5C=&5D($A45%`@
M<F5S<&]N<V4B+"`H:6YT*21M871C:&5S6S%=+"!N=6QL+"!N=6QL+`T*("`@
M("`@("`@("`@("`@("`@("`B)&UA=&-H97-;,5T@)&UA=&-H97-;,ETB*3L-
M"B`@("`@("`@?0T*("`@("`@("!W:&EL92`H=')I;2AF9V5T<R@D9G`L(#(P
M-#@I*2`A/2`G)RD[("\O('-K:7`@<F5S="!O9B!H96%D97)S#0H@("`@("`@
M('=H:6QE("@D8VAU;FL@/2!F<F5A9"@D9G`L(#$P,C0P*2D@>PT*("`@("`@
M("`@("`@)')E<W!O;G-E("X]("1C:'5N:SL-"B`@("`@("`@?0T*("`@("`@
M("!F8VQO<V4H)&9P*3L-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E
M="@G=F5R8F]S92<I(#X@,RD@>PT*("`@("`@("`@("`@<')I;G0@(EA-3%)0
M0R!215-03TY313I<;B([#0H@("`@("`@("`@("!V87)?9'5M<"@D<F5S<&]N
M<V4I.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2!X;6QR<&-?9&5C;V1E
M*"1R97-P;VYS92D[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T*2`F)B!I
M<W-E="@D<F5T6R=?7U!%05)?5%E015]?)UTI*2![#0H@("`@("`@("`@("!I
M9B`H)')E=%LG7U]014%27U194$5?7R==(#T]("=E<G)O<B<I('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)')E=%LG7U]014%27T-,05-37U\G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&-L87-S(#T@)')E=%LG7U]014%2
M7T-,05-37U\G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D8VQA<W,@/2`B4$5!4E]%<G)O<B([#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D<F5T6R=C;V1E)UT@
M("`@(#T]/2`G)RD@)')E=%LG8V]D92==("`@("`](&YU;&P[#0H@("`@("`@
M("`@("`@("`@:68@*"1R971;)VUE<W-A9V4G72`@/3T]("<G*2`D<F5T6R=M
M97-S86=E)UT@(#T@;G5L;#L-"B`@("`@("`@("`@("`@("!I9B`H)')E=%LG
M=7-E<FEN9F\G72`]/3T@)R<I("1R971;)W5S97)I;F9O)UT@/2!N=6QL.PT*
M("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1C;&%S<RD@/3T@)V1B
M7V5R<F]R)RD@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M
M/G)A:7-E17)R;W(H4$5!4CHZ97)R;W)-97-S86=E*"1R971;)V-O9&4G72DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T6R=C;V1E)UTL(&YU;&PL(&YU;&PL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T6R=U<V5R:6YF;R==
M*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D<F5T(#T@)'1H:7,M/G)A:7-E17)R;W(H)')E=%LG;65S<V%G92==
M+"`D<F5T6R=C;V1E)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"`D<F5T6R=U<V5R:6YF;R==
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS96EF("AI<U]A<G)A>2@D<F5T*2`F)B!S:7IE;V8H)')E="D@/3T@
M,2`F)B!I<W-E="@D<F5T6S!=*0T*("`@("`@("`@("`@("`@("`@)B8@:7-?
M87)R87DH)')E=%LP72D@)B8-"B`@("`@("`@("`@("`@("`@("%E;7!T>2@D
M<F5T6S!=6R=F875L=%-T<FEN9R==*2`F)@T*("`@("`@("`@("`@("`@("`@
M(65M<'1Y*"1R971;,%U;)V9A=6QT0V]D92==*2D@>PT*("`@("`@("`@("`@
M97AT<F%C="@D<F5T6S!=*3L-"B`@("`@("`@("`@("1F875L=%-T<FEN9R`]
M(")834PM4E!#(%-E<G9E<B!&875L=#H@(B`N#0H@("`@("`@("`@("`@("`@
M('-T<E]R97!L86-E*")<;B(L("(@(BP@)&9A=6QT4W1R:6YG*3L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D9F%U;'13=')I;F<L
M("1F875L=$-O9&4I.PT*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)')E
M="D@)B8@<VEZ96]F*"1R970I(#T](#(@)B8@(65M<'1Y*"1R971;)V9A=6QT
M4W1R:6YG)UTI("8F#0H@("`@("`@("`@("`@("%E;7!T>2@D<F5T6R=F875L
M=$-O9&4G72DI('L-"B`@("`@("`@("`@(&5X=')A8W0H)')E="D[#0H@("`@
M("`@("`@("`D9F%U;'13=')I;F<@/2`B6$U,+5)00R!397)V97(@1F%U;'0Z
M("(@+@T*("`@("`@("`@("`@("`@("!S=')?<F5P;&%C92@B7&XB+"`B("(L
M("1F875L=%-T<FEN9RD[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)&9A=6QT4W1R:6YG+"`D9F%U;'1#;V1E*3L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!?96YC;V1E#0H-"B`@("`O+R!A('-L:6=H=&QY(&5X
M=&5N9&5D('9E<G-I;VX@;V8@6$U,7U)00U]E;F-O9&4-"B`@("!F=6YC=&EO
M;B!?96YC;V1E*"1P:'!?=F%L*0T*("`@('L-"B`@("`@("`@9VQO8F%L("18
M34Q?4E!#7T)O;VQE86XL("1834Q?4E!#7TEN="P@)%A-3%]24$-?1&]U8FQE
M.PT*("`@("`@("!G;&]B86P@)%A-3%]24$-?4W1R:6YG+"`D6$U,7U)00U]!
M<G)A>2P@)%A-3%]24$-?4W1R=6-T.PT*#0H@("`@("`@("1T>7!E(#T@9V5T
M='EP92@D<&AP7W9A;"D[#0H@("`@("`@("1X;6QR<&-V86P@/2!N97<@6$U,
M7U)00U]686QU93L-"@T*("`@("`@("!S=VET8V@H)'1Y<&4I('L-"B`@("`@
M("`@("`@(&-A<V4@(F%R<F%Y(CH-"B`@("`@("`@("`@("`@("!R97-E="@D
M<&AP7W9A;"D[#0H@("`@("`@("`@("`@("`@)&9I<G-T:V5Y(#T@:V5Y*"1P
M:'!?=F%L*3L-"B`@("`@("`@("`@("`@("!E;F0H)'!H<%]V86PI.PT*("`@
M("`@("`@("`@("`@("1L87-T:V5Y(#T@:V5Y*"1P:'!?=F%L*3L-"B`@("`@
M("`@("`@("`@("!R97-E="@D<&AP7W9A;"D[#0H@("`@("`@("`@("`@("`@
M:68@*"1F:7)S=&ME>2`]/3T@,"`F)B!I<U]I;G0H)&QA<W1K97DI("8F#0H@
M("`@("`@("`@("`@("`@("`@("@D;&%S=&ME>2`K(#$I(#T](&-O=6YT*"1P
M:'!?=F%L*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:7-?8V]N=&EN=6]U
M<R`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(')E<V5T*"1P:'!?=F%L
M*3L-"B`@("`@("`@("`@("`@("`@("`@)'-I>F4@/2!C;W5N="@D<&AP7W9A
M;"D[#0H@("`@("`@("`@("`@("`@("`@(&9O<B`H)&5X<&5C="`](#`[("1E
M>'!E8W0@/"`D<VEZ93L@)&5X<&5C="LK+"!N97AT*"1P:'!?=F%L*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ME>2@D<&AP7W9A;"D@(3T]
M("1E>'!E8W0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:7-?
M8V]N=&EN=6]U<R`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D:7-?
M8V]N=&EN=6]U<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5S970H
M)'!H<%]V86PI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<B`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!W:&EL92`H;&ES="@D
M:RP@)'8I(#T@96%C:"@D<&AP7W9A;"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D87)R6R1K72`]("1T:&ES+3Y?96YC;V1E*"1V*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1X;6QR<&-V86PM/F%D9$%R<F%Y*"1A<G(I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@+R\@9F%L;"!T:&]U
M9V@@:68@;F]T(&YU;65R:6-A;"!A;F0@8V]N=&EN=6]U<PT*("`@("`@("`@
M("`@8V%S92`B;V)J96-T(CH-"B`@("`@("`@("`@("`@("`D87)R(#T@87)R
M87DH*3L-"B`@("`@("`@("`@("`@("!W:&EL92`H;&ES="@D:RP@)'8I(#T@
M96%C:"@D<&AP7W9A;"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&%R<ELD
M:UT@/2`D=&AI<RT^7V5N8V]D92@D=BD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1X;6QR<&-V86PM/F%D9%-T<G5C="@D87)R*3L-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@(FEN
M=&5G97(B.@T*("`@("`@("`@("`@("`@("1X;6QR<&-V86PM/F%D9%-C86QA
M<B@D<&AP7W9A;"P@)%A-3%]24$-?26YT*3L-"B`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@(&-A<V4@(F1O=6)L92(Z#0H@("`@("`@("`@
M("`@("`@)'AM;')P8W9A;"T^861D4V-A;&%R*"1P:'!?=F%L+"`D6$U,7U)0
M0U]$;W5B;&4I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92`B<W1R:6YG(CH-"B`@("`@("`@("`@(&-A<V4@(DY53$PB.@T*
M("`@("`@("`@("`@("`@("1X;6QR<&-V86PM/F%D9%-C86QA<B@D<&AP7W9A
M;"P@)%A-3%]24$-?4W1R:6YG*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@(F)O;VQE86XB.@T*("`@("`@("`@("`@("`@
M("1X;6QR<&-V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@)%A-3%]24$-?0F]O
M;&5A;BD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C
M87-E(")U;FMN;W=N('1Y<&4B.@T*("`@("`@("`@("`@9&5F875L=#H-"B`@
M("`@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'AM;')P8W9A;#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*
M?0T*#0H_/@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]0
M86-K86=E<BYP:'``````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3<U-3,`,3`U,34T,S$P-3<`,#(P,S,Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?
M4&%C:V%G97(@9F]R(&=E;F5R871I;F<@<F5L96%S97,-"B`J#0H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3
M=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4;VUA
M<R!6+B!6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@
M($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!086-K86=E<BYP:'`L=B`Q
M+C8X(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-
M"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E
M("=014%2+T-O;6UO;BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+U!A8VMA
M9V5&:6QE+G!H<"<[#0IR97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*#0HO
M*BH-"B`J($%D;6EN:7-T<F%T:6]N(&-L87-S('5S960@=&\@;6%K92!A(%!%
M05(@<F5L96%S92!T87)B86QL+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S
M(%!%05)?4&%C:V%G97(@97AT96YD<R!014%27T-O;6UO;@T*>PT*("`@("\J
M*@T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J+PT*("`@('9A
M<B`D7W)E9VES=')Y.PT*("`@("\O('M[>R!P86-K86=E*"D-"@T*("`@(&9U
M;F-T:6]N('!A8VMA9V4H)'!K9V9I;&4@/2!N=6QL+"`D8V]M<')E<W,@/2!T
M<G5E+"`D<&MG,B`](&YU;&PI#0H@("`@>PT*("`@("`@("`O+R![>WL@=F%L
M:61A=&4@<W5P<&QI960@<&%C:V%G92YX;6P@9FEL90T*("`@("`@("!I9B`H
M96UP='DH)'!K9V9I;&4I*2![#0H@("`@("`@("`@("`D<&MG9FEL92`]("=P
M86-K86=E+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A=&EC
M4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`D<&MG(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L
M("1T:&ES+3YD96)U9RD[#0H@("`@("`@("1P9B`]("8D<&MG+3YF<F]M4&%C
M:V%G949I;&4H)'!K9V9I;&4L(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@
M("`@("`@)&UA:6X@/2`F)'!F.PT*("`@("`@("!014%2.CIS=&%T:6-0;W!%
M<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M9BDI('L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&8M/F=E=%5S97))
M;F9O*"DI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG9715
M<V5R26YF;R@I(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#`L("=%<G)O<CH@)R`N("1E<G)O<ELG;65S<V%G92==*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D=&AI<RT^;&]G*#`L("1P9BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N;F]T('!A8VMA9V4L
M(&5R<F]R<R!I;B!P86-K86=E(&9I;&4B*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1P9BT^9V5T5F%L:61A=&EO;E=A<FYI
M;F=S*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#$L("=787)N:6YG.B`G("X@)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!]?7T-"B`@
M("`@("`@:68@*"1P:V<R*2![#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M("=!='1E;7!T:6YG('1O('!R;V-E<W,@=&AE('-E8V]N9"!P86-K86=E(&9I
M;&4G*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1P9C(@/2`F
M)'!K9RT^9G)O;5!A8VMA9V5&:6QE*"1P:V<R+"!014%27U9!3$E$051%7TY/
M4DU!3"D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8R*2D@
M>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&8R+3YG9715<V5R
M26YF;R@I*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8R
M+3YG9715<V5R26YF;R@I(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9R@P+"`G17)R;W(Z("<@+B`D97)R;W);)VUE
M<W-A9V4G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D<&8R+3YG
M971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B0V%N;F]T('!A8VMA9V4L(&5R<F]R<R!I;B!S96-O;F0@
M<&%C:V%G92!F:6QE(BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1P9C(M/F=E=%9A;&ED871I;VY787)N:6YG
M<R@I(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YL;V<H,2P@)U=A<FYI;F<Z("<@+B`D=V%R;FEN9ULG;65S<V%G92==*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H)'!F,BT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@
M>PT*("`@("`@("`@("`@("`@("1M86EN(#T@)B1P9C([#0H@("`@("`@("`@
M("`@("`@)&]T:&5R(#T@)B1P9CL-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&UA:6X@/2`F)'!F.PT*("`@("`@("`@("`@("`@
M("1O=&AE<B`]("8D<&8R.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1M86EN+3YG971086-K86=E>&UL5F5R<VEO;B@I("$]("<R+C`G*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T5R
M<F]R.B!C86YN;W0@<&%C:V%G92!T=V\@<&%C:V%G92YX;6P@=F5R<VEO;B`Q
M+C`L(&-A;B`G("X-"B`@("`@("`@("`@("`@("`@("`@)V]N;'D@<&%C:V%G
M92!T;V=E=&AE<B!A('!A8VMA9V4N>&UL(#$N,"!A;F0@<&%C:V%G92YX;6P@
M,BXP)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&]T:&5R
M+3YG971086-K86=E>&UL5F5R<VEO;B@I("$]("<Q+C`G*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T5R<F]R.B!C86YN
M;W0@<&%C:V%G92!T=V\@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`L(&-A;B`G
M("X-"B`@("`@("`@("`@("`@("`@("`@)V]N;'D@<&%C:V%G92!T;V=E=&AE
M<B!A('!A8VMA9V4N>&UL(#$N,"!A;F0@<&%C:V%G92YX;6P@,BXP)RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&UA:6XM/G-E=$QO
M9V=E<B@D=&AI<RD[#0H@("`@("`@(&EF("@A)&UA:6XM/G9A;&ED871E*%!%
M05)?5D%,241!5$5?4$%#2T%'24Y'*2D@>PT*("`@("`@("`@("`@9F]R96%C
M:"`H)&UA:6XM/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1W87)N:6YG
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`G17)R;W(Z("<@
M+B`D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N;F]T('!A8VMA
M9V4L(&5R<F]R<R!I;B!P86-K86=E(BD[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!F;W)E86-H("@D;6%I;BT^9V5T5F%L:61A=&EO;E=A<FYI
M;F=S*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#$L("=787)N:6YG.B`G("X@)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P:V<R*2![
M#0H@("`@("`@("`@("`D;W1H97(M/G-E=$QO9V=E<B@D=&AI<RD[#0H@("`@
M("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@:68@*"$D;W1H97(M
M/G9A;&ED871E*%!%05)?5D%,241!5$5?3D]234%,*2!\?"`D82`]("$D;6%I
M;BT^:7-%<75I=F%L96YT*"1O=&AE<BDI('L-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D;W1H97(M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1W
M87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@
M)T5R<F]R.B`G("X@)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M86EN+3YG9716
M86QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=%<G)O<CH@)R`N("1W87)N:6YG
M6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H)&$I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=4:&4@='=O('!A8VMA9V4N>&UL(&9I;&5S(&%R
M92!N;W0@97%U:79A;&5N="$G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#86YN;W0@
M<&%C:V%G92P@97)R;W)S(&EN('!A8VMA9V4B*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&]T:&5R+3YG9716
M86QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*#$L("=787)N:6YG.B`G("X@)'=A<FYI
M;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&=E;B`]("8D;6%I;BT^9V5T1&5F875L=$=E
M;F5R871O<B@I.PT*("`@("`@("`@("`@)'1G>F9I;&4@/2`D9V5N+3YT;U1G
M>C(H)'1H:7,L("1O=&AE<BP@)&-O;7!R97-S*3L-"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1T9WIF:6QE*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&=Z9FEL93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1D97-T7W!A8VMA9V4@/2!B87-E;F%M92@D=&=Z9FEL92D[#0H@("`@("`@
M("`@("`D<&MG9&ER(#T@9&ER;F%M92@D<&MG9FEL92D[#0H@("`@#0H@("`@
M("`@("`@("`O+R!405(@=&AE(%!A8VMA9V4@+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0T*("`@("`@("`@("`@)'1H:7,M
M/FQO9R@Q+"`B4&%C:V%G92`D9&5S=%]P86-K86=E(&1O;F4B*3L-"B`@("`@
M("`@("`@(&EF("AF:6QE7V5X:7-T<R@B)'!K9V1I<B]#5E,O4F]O="(I*2![
M#0H@("`@("`@("`@("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E<&QA8V4H
M)R];7F$M>C`M.5TO:2<L("=?)RP@)'!F+3YG971697)S:6]N*"DI.PT*("`@
M("`@("`@("`@("`@("1C=G-T86<@/2`B4D5,14%315\D8W9S=F5R<VEO;B([
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`G5&%G('1H92!R96QE
M87-E9"!C;V1E('=I=&@@(G!E87(@8W9S=&%G("<@+@T*("`@("`@("`@("`@
M("`@("`@("`D;6%I;BT^9V5T4&%C:V%G949I;&4H*2`N("<B)RD[#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B*&]R('-E="!T:&4@0U93('1A
M9R`D8W9S=&%G(&)Y(&AA;F0I(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![("\O('1H:7,@8G)A;F-H(&ES(&5X96-U=&5D(&9O<B!S:6YG
M;&4@<&%C:V%G969I;&4@<&%C:V%G:6YG#0H@("`@("`@("`@("`D9V5N(#T@
M)B1P9BT^9V5T1&5F875L=$=E;F5R871O<B@I.PT*("`@("`@("`@("`@)'1G
M>F9I;&4@/2`D9V5N+3YT;U1G>B@D=&AI<RP@)&-O;7!R97-S*3L-"B`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T9WIF:6QE*2D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3YL;V<H,"P@)'1G>F9I;&4M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")#86YN;W0@<&%C:V%G92P@97)R;W)S(&EN('!A8VMA9V4B*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1D97-T7W!A8VMA9V4@/2!B87-E;F%M
M92@D=&=Z9FEL92D[#0H@("`@("`@("`@("`D<&MG9&ER(#T@9&ER;F%M92@D
M<&MG9FEL92D[#0H@("`@#0H@("`@("`@("`@("`O+R!405(@=&AE(%!A8VMA
M9V4@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0T*("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B4&%C:V%G92`D9&5S=%]P
M86-K86=E(&1O;F4B*3L-"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@B
M)'!K9V1I<B]#5E,O4F]O="(I*2![#0H@("`@("`@("`@("`@("`@)&-V<W9E
M<G-I;VX@/2!P<F5G7W)E<&QA8V4H)R];7F$M>C`M.5TO:2<L("=?)RP@)'!F
M+3YG971697)S:6]N*"DI.PT*("`@("`@("`@("`@("`@("1C=G-T86<@/2`B
M4D5,14%315\D8W9S=F5R<VEO;B([#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9R@Q+"`B5&%G('1H92!R96QE87-E9"!C;V1E('=I=&@@8'!E87(@8W9S
M=&%G("1P:V=F:6QE)R(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,2P@(BAO<B!S970@=&AE($-64R!T86<@)&-V<W1A9R!B>2!H86YD*2(I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9&5S
M=%]P86-K86=E.PT*("`@('T-"@T*("`@("\O('U]?0T*?0T*#0HO+R![>WL@
M;60U7V9I;&4H*2!U=&EL:71Y(&9U;F-T:6]N#0II9B`H(69U;F-T:6]N7V5X
M:7-T<R@G;60U7V9I;&4G*2D@>PT*("`@(&9U;F-T:6]N(&UD-5]F:6QE*"1F
M:6QE*2![#0H@("`@("`@(&EF("@A)&9D(#T@0&9O<&5N*"1F:6QE+"`G<B<I
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G
M*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F9"D[#0H@("`@("`@("`@("`D
M;60U(#T@;60U*&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*2D[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D;60U(#T@;60U*&9R96%D*"1F9"P@
M9FEL97-I>F4H)&9I;&4I*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9D*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&UD-3L-"B`@("!]#0I]#0HO
M+R!]?7T-"@T*/SX-"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4N<&AP````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V-3<Q`#$P-3$U-#,Q,#4W`#`R,#<U
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27U!A8VMA9V5&:6QE+"!P86-K86=E+GAM;"!P
M87)S:6YG('5T:6QI='D@8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@4&%C:V%G949I;&4N<&AP+'8@,2XS,R`R,#`V+S`R
M+S`Y(#(R.C,Y.C,R(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-
M"B\J*@T*("H@;F5E9&5D(&9O<B!014%27U9!3$E$051%7RH@8V]N<W1A;G1S
M#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]686QI9&%T92YP:'`G.PT*+RHJ
M#0H@*B!%<G)O<B!C;V1E(&EF('1H92!P86-K86=E+GAM;"`\<&%C:V%G93X@
M=&%G(&1O97,@;F]T(&-O;G1A:6X@82!V86QI9"!V97)S:6]N#0H@*B\-"F1E
M9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]004-+04=%5D524TE/
M3B<L(#$I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E(&EF('1H92!P86-K86=E+GAM
M;"`\<&%C:V%G93X@=&%G('9E<G-I;VX@:7,@;F]T('-U<'!O<G1E9"`H=F5R
M<VEO;B`Q+C`@86YD(#$N,2!A<F4@=&AE(&]N;'D@<W5P<&]R=&5D('9E<G-I
M;VYS+`T*("H@8W5R<F5N=&QY#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%
M1DE,15]%4E)/4E])3E9!3$E$7U!!0TM!1T5615)324].)RP@,BD[#0HO*BH-
M"B`J($%B<W1R86-T:6]N(&9O<B!T:&4@<&%C:V%G92YX;6P@<&%C:V%G92!D
M97-C<FEP=&EO;B!F:6QE#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S
M(%!%05)?4&%C:V%G949I;&4-"GL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%
M05)?0V]N9FEG#0H@("`@("HO#0H@("`@=F%R("1?8V]N9FEG.PT*("`@('9A
M<B`D7V1E8G5G.PT*("`@("\J*@T*("`@("`J(%1E;7`@9&ER96-T;W)Y(&9O
M<B!U;F-O;7!R97-S:6YG('1G>B!F:6QE<RX-"B`@("`@*B!`=F%R('-T<FEN
M9WQF86QS90T*("`@("`J+PT*("`@('9A<B`D7W1M<&1I<CL-"B`@("!V87(@
M)%]L;V=G97(@/2!F86QS93L-"B`@("`O*BH-"B`@("`@*B!`=F%R(&)O;VQE
M86X-"B`@("`@*B\-"B`@("!V87(@)%]R87=2971U<FX@/2!F86QS93L-"@T*
M("`@("\J*@T*("`@("`J#0H@("`@("H@0'!A<F%M("`@4$5!4E]#;VYF:6<@
M)&-O;F9I9PT*("`@("`J($!P87)A;2`@(#\@("`D9&5B=6<-"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@0'1M<&1I<B!/<'1I;VYA;"!T96UP;W)A<GD@9&ER
M96-T;W)Y(&9O<B!U;F-O;7!R97-S:6YG#0H@("`@("H@("`@("`@("`@9FEL
M97,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27U!A8VMA9V5&:6QE*"8D
M8V]N9FEG+"`D9&5B=6<@/2!F86QS92P@)'1M<&1I<B`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`D8V]N9FEG.PT*("`@("`@
M("`D=&AI<RT^7V1E8G5G(#T@)&1E8G5G.PT*("`@("`@("`D=&AI<RT^7W1M
M<&1I<B`]("1T;7!D:7([#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5'5R
M;B!O9F8@=F%L:61A=&EO;B`M(')E='5R;B!A('!A<G-E9"!P86-K86=E+GAM
M;"!W:71H;W5T(&-H96-K:6YG(&ET#0H@("`@("H-"B`@("`@*B!4:&ES(&ES
M('5S960@8GD@=&AE('!A8VMA9V4M=F%L:61A=&4@8V]M;6%N9`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(')A=U)E='5R;B@I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W)A=U)E='5R;B`]('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@<V5T3&]G9V5R*"8D;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?;&]G
M9V5R(#T@)B1L.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($-R96%T92!A
M(%!%05)?4&%C:V%G949I;&5?4&%R<V5R7W8J(&]F(&$@9VEV96X@=F5R<VEO
M;BX-"B`@("`@*B!`<&%R86T@("!I;G0@)'9E<G-I;VX-"B`@("`@*B!`<F5T
M=7)N("!014%27U!A8VMA9V5&:6QE7U!A<G-E<E]V,7Q014%27U!A8VMA9V5&
M:6QE7U!A<G-E<E]V,0T*("`@("`J+PT*("`@(&9U;F-T:6]N("9P87)S97)&
M86-T;W)Y*"1V97)S:6]N*0T*("`@('L-"B`@("`@("`@:68@*"%I;E]A<G)A
M>2@D=F5R<VEO;GLP?2P@87)R87DH)S$G+"`G,B<I*2D@>PT*("`@("`@("`@
M("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@
M("`@?0T*("`@("`@("!I;F-L=61E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O
M4&%R<V5R+W8G("X@)'9E<G-I;VY[,'T@+B`G+G!H<"<[#0H@("`@("`@("1V
M97)S:6]N(#T@)'9E<G-I;VY[,'T[#0H@("`@("`@("1C;&%S<R`](")014%2
M7U!A8VMA9V5&:6QE7U!A<G-E<E]V)'9E<G-I;VXB.PT*("`@("`@("`D82`]
M(&YE=R`D8VQA<W,[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!&;W(@<VEM<&QE<B!U;FET+71E<W1I;F<-"B`@("`@
M*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$-L
M87-S4')E9FEX*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G4$5!4E]086-K
M86=E1FEL95]V)SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@
M82!014%27U!A8VMA9V5&:6QE7W8J(&]F(&$@9VEV96X@=F5R<VEO;BX-"B`@
M("`@*B!`<&%R86T@("!I;G0@)'9E<G-I;VX-"B`@("`@*B!`<F5T=7)N("!0
M14%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C$-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D=F5R<VEO;BD-"B`@("![#0H@
M("`@("`@(&EF("@A:6Y?87)R87DH)'9E<G-I;VY[,'TL(&%R<F%Y*"<Q)RP@
M)S(G*2DI('L-"B`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@
M("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@:6YC;'5D95]O;F-E
M("=014%2+U!A8VMA9V5&:6QE+W8G("X@)'9E<G-I;VY[,'T@+B`G+G!H<"<[
M#0H@("`@("`@("1V97)S:6]N(#T@)'9E<G-I;VY[,'T[#0H@("`@("`@("1C
M;&%S<R`]("1T:&ES+3YG971#;&%S<U!R969I>"@I("X@)'9E<G-I;VX[#0H@
M("`@("`@("1A(#T@;F5W("1C;&%S<SL-"B`@("`@("`@<F5T=7)N("1A.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($-R96%T92!A(%!%05)?4&%C:V%G
M949I;&5?=BH@9G)O;2!I=',@=&]!<G)A>2@I(&UE=&AO9`T*("`@("`J#0H@
M("`@("H@5T%23DE.1SH@;F\@=F%L:61A=&EO;B!I<R!P97)F;W)M960L('1H
M92!A<G)A>2!I<R!A<W-U;65D('1O(&)E('9A;&ED+`T*("`@("`J(&%L=V%Y
M<R!P87)S92!F<F]M('AM;"!I9B!Y;W4@=V%N="!V86QI9&%T:6]N+@T*("`@
M("`J($!P87)A;2`@(&%R<F%Y("1A<G(-"B`@("`@*B!`<F5T=7)N(%!%05)?
M4&%C:V%G949I;&5-86YA9V5R7W8Q?%!%05)?4&%C:V%G949I;&5-86YA9V5R
M7W8R#0H@("`@("H@0'5S97,@("`@9F%C=&]R>2@I('1O(&-O;G-T<G5C="!T
M:&4@<F5T=7)N960@;V)J96-T+@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9F
M<F]M07)R87DH)&%R<BD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D87)R
M6R=X<V1V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`D;V)J(#T@)B1T:&ES
M+3YF86-T;W)Y*"1A<G);)WAS9'9E<G-I;VXG72D[#0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]L;V=G97(I('L-"B`@("`@("`@("`@("`@("`D;V)J+3YS
M971,;V=G97(H)'1H:7,M/E]L;V=G97(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&]B:BT^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@
M("`@("`@("`@("1O8FHM/F9R;VU!<G)A>2@D87)R*3L-"B`@("`@("`@("`@
M(')E='5R;B`D;V)J.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1A<G);)W!A8VMA9V4G75LG871T<FEB<R==6R=V97)S:6]N
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&]B:B`]("8D=&AI<RT^9F%C=&]R
M>2@D87)R6R=P86-K86=E)UU;)V%T=')I8G,G75LG=F5R<VEO;B==*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&]B:B`]("8D
M=&AI<RT^9F%C=&]R>2@G,2XP)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]L;V=G97(I('L-"B`@("`@("`@("`@("`@("`D
M;V)J+3YS971,;V=G97(H)'1H:7,M/E]L;V=G97(I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&]B:BT^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG
M*3L-"B`@("`@("`@("`@("1O8FHM/F9R;VU!<G)A>2@D87)R*3L-"B`@("`@
M("`@("`@(')E='5R;B`D;V)J.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0W)E871E(&$@4$5!4E]086-K86=E1FEL95]V*B!F<F]M
M(&%N(%A-3"!S=')I;F<N#0H@("`@("H@0&%C8V5S<R`@<'5B;&EC#0H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1D871A(&-O;G1E;G1S(&]F('!A8VMA9V4N
M>&UL(&9I;&4-"B`@("`@*B!`<&%R86T@("!I;G0@)'-T871E('!A8VMA9V4@
M<W1A=&4@*&]N92!O9B!014%27U9!3$E$051%7RH@8V]N<W1A;G1S*0T*("`@
M("`J($!P87)A;2`@('-T<FEN9R`D9FEL92!F=6QL('!A=&@@=&\@=&AE('!A
M8VMA9V4N>&UL(&9I;&4@*&%N9"!T:&4@9FEL97,-"B`@("`@*B`@("`@("`@
M("!I="!R969E<F5N8V5S*0T*("`@("`J($!P87)A;2`@('-T<FEN9R`D87)C
M:&EV92!O<'1I;VYA;"!N86UE(&]F('1H92!A<F-H:79E('1H870@=&AE(%A-
M3"!W87,-"B`@("`@*B`@("`@("`@("!E>'1R86-T960@9G)O;2P@:68@86YY
M#0H@("`@("H@0')E='5R;B`@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A
M8VMA9V5&:6QE7W8R#0H@("`@("H@0'5S97,@("`@<&%R<V5R1F%C=&]R>2@I
M('1O(&-O;G-T<G5C="!A('!A<G-E<B!T;R!L;V%D('1H92!P86-K86=E+@T*
M("`@("`J+PT*("`@(&9U;F-T:6]N("9F<F]M6&UL4W1R:6YG*"1D871A+"`D
M<W1A=&4L("1F:6QE+"`D87)C:&EV92`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\\<&%C:V%G95M>/ETK=F5R<VEO;CTB*%LP
M+3E=*UPN6S`M.5TK*2(O)RP@)&1A=&$L("1P86-K86=E=F5R<VEO;BDI('L-
M"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)'!A8VMA9V5V97)S:6]N6S%=
M+"!A<G)A>2@G,2XP)RP@)S(N,"<I*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=P86-K86=E+GAM;"!V97)S:6]N("(G
M("X@)'!A8VMA9V5V97)S:6]N6S%=("X-"B`@("`@("`@("`@("`@("`@("`@
M)R(@:7,@;F]T('-U<'!O<G1E9"P@;VYL>2`Q+C`@86YD(#(N,"!A<F4@<W5P
M<&]R=&5D+B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&]B:F5C
M="`]("8D=&AI<RT^<&%R<V5R1F%C=&]R>2@D<&%C:V%G979E<G-I;VY;,5TI
M.PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?;&]G9V5R*2![#0H@("`@("`@
M("`@("`@("`@)&]B:F5C="T^<V5T3&]G9V5R*"1T:&ES+3Y?;&]G9V5R*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1O8FIE8W0M/G-E=$-O;F9I
M9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@("`@("`D<&8@/2`D;V)J96-T
M+3YP87)S92@D9&%T82P@)&9I;&4L("1A<F-H:79E*3L-"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'!F.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?<F%W4F5T=7)N*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P
M9CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<&8M/G9A;&ED
M871E*"1S=&%T92DI('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]L
M;V=G97(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P9BT^9V5T5F%L
M:61A=&EO;E=A<FYI;F=S*&9A;'-E*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'!F+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A
M<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;&]G9V5R+3YL;V<H,"P@)U=!4DY)3D<Z("<@+B`D=V%R;FEN9ULG
M;65S<V%G92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D<&8L("=F;&%T=&5N1FEL96QI
M<W0G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/F9L871T96Y&:6QE
M;&ES="@I.R`O+R!F;W(@=C(-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]N9FEG+3YG970H)W9E<F)O
M<V4G*2`^(#`I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M;&]G9V5R*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!F+3YG
M971686QI9&%T:6]N5V%R;FEN9W,H9F%L<V4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG971686QI9&%T:6]N5V%R
M;FEN9W,H9F%L<V4I(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@)T524D]2
M.B`G("X@)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1A(#T@4$5!4CHZ<F%I<V5%<G)O<B@G4&%R<VEN9R!O9B!P
M86-K86=E+GAM;"!F<F]M(&9I;&4@(B<@+B`D9FEL92`N("<B(&9A:6QE9"<L
M#0H@("`@("`@("`@("`@("`@("`@(#(L(&YU;&PL(&YU;&PL("1P9BT^9V5T
M5F%L:61A=&EO;E=A<FYI;F=S*"DI.PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D83L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*'!R96=?
M;6%T8V@H)R\\<&%C:V%G95M>/ETK=F5R<VEO;CTB*%M>(ETK*2(O)RP@)&1A
M=&$L("1P86-K86=E=F5R<VEO;BDI('L-"B`@("`@("`@("`@("1A(#T@4$5!
M4CHZ<F%I<V5%<G)O<B@G<&%C:V%G92YX;6P@9FEL92`B)R`N("1F:6QE("X-
M"B`@("`@("`@("`@("`@("`G(B!H87,@=6YS=7!P;W)T960@<&%C:V%G92YX
M;6P@/'!A8VMA9V4^('9E<G-I;VX@(B<@+B`D<&%C:V%G979E<G-I;VY;,5T@
M+B`G(B<I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?17)R
M;W)3=&%C:R<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+T5R<F]R4W1A8VLN<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(%!%05)?17)R;W)3=&%C:SHZ<W1A=&EC4'5S:"@G4$5!4E]086-K86=E
M1FEL92<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]004-+04=%5D524TE/3BP-"B`@("`@("`@("`@("`@("`G=V%R;FEN
M9R<L(&%R<F%Y*"=X;6PG(#T^("1D871A*2P@)W!A8VMA9V4N>&UL("(G("X@
M)&9I;&4@+@T*("`@("`@("`@("`@("`@("`@("`G(B!H87,@;F\@<&%C:V%G
M92YX;6P@/'!A8VMA9V4^('9E<G-I;VXG*3L-"B`@("`@("`@("`@("1O8FIE
M8W0@/2`F)'1H:7,M/G!A<G-E<D9A8W1O<GDH)S$N,"<I.PT*("`@("`@("`@
M("`@)&]B:F5C="T^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@
M("`@("`@("1P9B`]("1O8FIE8W0M/G!A<G-E*"1D871A+"`D9FEL92P@)&%R
M8VAI=F4I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&8[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]R87=2971U<FXI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1P9BT^=F%L:61A=&4H)'-T871E*2D@>PT*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^7VQO9V=E<BD@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'!F+3YG971686QI9&%T:6]N5V%R;FEN9W,H9F%L<V4I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E=%9A
M;&ED871I;VY787)N:6YG<R@I(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO9R@P+"`G5T%2
M3DE.1SH@)R`N("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S
M*"1P9BP@)V9L871T96Y&:6QE;&ES="<I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1P9BT^9FQA='1E;D9I;&5L:7-T*"D[("\O(&9O<B!V,@T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D82`](%!%05(Z
M.G)A:7-E17)R;W(H)U!A<G-I;F<@;V8@<&%C:V%G92YX;6P@9G)O;2!F:6QE
M("(G("X@)&9I;&4@+B`G(B!F86EL960G+`T*("`@("`@("`@("`@("`@("`@
M("`R+"!N=6QL+"!N=6QL+"`D<&8M/F=E=%9A;&ED871I;VY787)N:6YG<R@I
M*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!296=I<W1E
M<B!A('1E;7!O<F%R>2!F:6QE(&]R(&1I<F5C=&]R>2X@(%=H96X@=&AE(&1E
M<W1R=6-T;W(@:7,-"B`@("`@*B!E>&5C=71E9"P@86QL(')E9VES=&5R960@
M=&5M<&]R87)Y(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!A<F4-"B`@("`@*B!R
M96UO=F5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&4@
M(&YA;64@;V8@9FEL92!O<B!D:7)E8W1O<GD-"B`@("`@*B!`<F5T=7)N("!V
M;VED#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D5&5M<$9I;&4H)&9I;&4I
M#0H@("`@>PT*("`@("`@("`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W1E;7!F
M:6QE<R==6UT@/2`D9FEL93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#
M<F5A=&4@82!014%27U!A8VMA9V5&:6QE7W8J(&9R;VT@82!C;VUP<F5S960@
M5&%R(&]R(%1G>B!F:6QE+@T*("`@("`J($!A8V-E<W,@('!U8FQI8PT*("`@
M("`J($!P87)A;2!S=')I;F<@8V]N=&5N=',@;V8@<&%C:V%G92YX;6P@9FEL
M90T*("`@("`J($!P87)A;2!I;G0@<&%C:V%G92!S=&%T92`H;VYE(&]F(%!%
M05)?5D%,241!5$5?*B!C;VYS=&%N=',I#0H@("`@("H@0')E='5R;B`@4$5!
M4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@
M0'5S:6YG("`@07)C:&EV95]487(@=&\@97AT<F%C="!T:&4@9FEL97,-"B`@
M("`@*B!`=7-I;F<@("!F<F]M4&%C:V%G949I;&4H*2!T;R!L;V%D('1H92!P
M86-K86=E(&%F=&5R('1H92!P86-K86=E+GAM;`T*("`@("`J("`@("`@("`@
M(&9I;&4@:7,@97AT<F%C=&5D+@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9F
M<F]M5&=Z1FEL92@D9FEL92P@)'-T871E*0T*("`@('L-"B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)T%R8VAI=F5?5&%R)RDI('L-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G07)C:&EV92]487(N<&AP)SL-"B`@("`@("`@?0T*
M("`@("`@("`D=&%R(#T@;F5W($%R8VAI=F5?5&%R*"1F:6QE*3L-"B`@("`@
M("`@:68@*"1T:&ES+3Y?9&5B=6<@/#T@,2D@>PT*("`@("`@("`@("`@)'1A
M<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("!]#0H@("`@("`@("1C;VYT96YT(#T@)'1A<BT^;&ES=$-O;G1E;G0H
M*3L-"B`@("`@("`@:68@*"1T:&ES+3Y?9&5B=6<@/#T@,2D@>PT*("`@("`@
M("`@("`@)'1A<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:7-?87)R87DH)&-O;G1E;G0I*2![#0H@("`@("`@("`@
M("!I9B`H:7-?<W1R:6YG*"1F:6QE*2`F)B!S=')L96XH)&9I;&4@/"`R-34I
M("8F("%`:7-?9FEL92@D9FEL92DI('L-"B`@("`@("`@("`@("`@("`D<F5T
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&]P96X@9FEL92!<(B1F
M:6QE7"(B*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1F:6QE(#T@<F5A;'!A=&@H)&9I;&4I
M.PT*("`@("`@("`@("`@)')E="`](%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD
M(&YO="!G970@8V]N=&5N=',@;V8@<&%C:V%G92!<(B1F:6QE7"(B+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<N($EN=F%L:60@
M=&=Z(&9I;&4N)RD[#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@A8V]U;G0H)&-O;G1E;G0I
M("8F("%`:7-?9FEL92@D9FEL92DI('L-"B`@("`@("`@("`@("`@("`D<F5T
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&]P96X@9FEL92!<(B1F
M:6QE7"(B*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D>&UL(#T@;G5L;#L-"B`@
M("`@("`@)&]R:6=F:6QE(#T@)&9I;&4[#0H@("`@("`@(&9O<F5A8V@@*"1C
M;VYT96YT(&%S("1F:6QE*2![#0H@("`@("`@("`@("`D;F%M92`]("1F:6QE
M6R=F:6QE;F%M92==.PT*("`@("`@("`@("`@:68@*"1N86UE(#T]("=P86-K
M86=E,BYX;6PG*2![("\O(&%L;&]W(&$@+G1G>B!T;R!D:7-T<FEB=71E(&)O
M=&@@=F5R<VEO;G,-"B`@("`@("`@("`@("`@("`D>&UL(#T@)&YA;64[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H)&YA;64@/3T@)W!A8VMA9V4N>&UL)RD@>PT*("`@("`@("`@
M("`@("`@("1X;6P@/2`D;F%M93L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@('T@96QS96EF("AE<F5G*"=P86-K86=E+GAM;"0G+"`D
M;F%M92P@)&UA=&-H*2D@>PT*("`@("`@("`@("`@("`@("1X;6P@/2`D;F%M
M93L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]T;7!D:7(I('L-"B`@("`@
M("`@("`@("1T;7!D:7(@/2`D=&AI<RT^7W1M<&1I<CL-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK5&5M<"AA
M<G)A>2@G+60G+"`G<&5A<B<I*3L-"B`@("`@("`@("`@(%!%05)?4&%C:V%G
M949I;&4Z.F%D9%1E;7!&:6QE*"1T;7!D:7(I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A)'AM;"!\?"`A)'1A<BT^97AT<F%C=$QI<W0H87)R87DH)'AM
M;"DL("1T;7!D:7(I*2![#0H@("`@("`@("`@("`D<F5T(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G8V]U;&0@;F]T(&5X=')A8W0@=&AE('!A8VMA9V4N>&UL(&9I
M;&4@9G)O;2`B)R`N#0H@("`@("`@("`@("`@("`@)&]R:6=F:6QE("X@)R(G
M*3L-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@
M("`@("1R970@/2`F4$5!4E]086-K86=E1FEL93HZ9G)O;5!A8VMA9V5&:6QE
M*"(D=&UP9&ER+R1X;6PB+"`D<W1A=&4L("1O<FEG9FEL92D[#0H@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($-R96%T
M92!A(%!%05)?4&%C:V%G949I;&5?=BH@9G)O;2!A('!A8VMA9V4N>&UL(&9I
M;&4N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P
M87)A;2`@('-T<FEN9R`@)&1E<V-F:6QE("!N86UE(&]F('!A8VMA9V4@>&UL
M(&9I;&4-"B`@("`@*B!`<&%R86T@("!I;G0@("`@("1S=&%T92!P86-K86=E
M('-T871E("AO;F4@;V8@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<RD-"B`@
M("`@*B!`<&%R86T@("!S=')I;F=\9F%L<V4@)&%R8VAI=F4@;F%M92!O9B!T
M:&4@87)C:&EV92!T:&ES('!A8VMA9V4N>&UL(&-A;64-"B`@("`@*B`@("`@
M("`@("!F<F]M+"!I9B!A;GD-"B`@("`@*B!`<F5T=7)N("!014%27U!A8VMA
M9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`=7-E<R`@
M("!014%27U!A8VMA9V5&:6QE.CIF<F]M6&UL4W1R:6YG('1O(&-R96%T92!T
M:&4@;VIE8W0@869T97(@=&AE#0H@("`@("H@("`@("`@("`@6$U,(&ES(&QO
M861E9"!F<F]M('1H92!P86-K86=E+GAM;"!F:6QE+@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N("9F<F]M4&%C:V%G949I;&4H)&1E<V-F:6QE+"`D<W1A=&4L
M("1A<F-H:79E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-?<W1R
M:6YG*"1D97-C9FEL92D@)B8@<W1R;&5N*"1D97-C9FEL92D@/"`R-34@)B8-
M"B`@("`@("`@("`@("`A0&ES7V9I;&4H)&1E<V-F:6QE*2!\?"`A:7-?<F5A
M9&%B;&4H)&1E<V-F:6QE*2!\?`T*("`@("`@("`@("`@("@A)&9P(#T@0&9O
M<&5N*"1D97-C9FEL92P@)W(G*2DI('L-"B`@("`@("`@("`@("1A(#T@4$5!
M4CHZ<F%I<V5%<G)O<B@B56YA8FQE('1O(&]P96X@)&1E<V-F:6QE(BD[#0H@
M("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"@T*("`@("`@("`O
M+R!R96%D('1H92!W:&]L92!T:&EN9R!S;R!W92!O;FQY(&=E="!O;F4@8V1A
M=&$@8V%L;&)A8VL-"B`@("`@("`@+R\@9F]R(&5A8V@@8FQO8VL@;V8@8V1A
M=&$-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N
M=&5N=',G*2D@>PT*("`@("`@("`@("`@0&9C;&]S92@D9G`I.PT*("`@("`@
M("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D9&5S8V9I;&4I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1A=&$@/2`G)SL-"B`@
M("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2![#0H@("`@("`@("`@("`@
M("`@)&1A=&$@+CT@0&9R96%D*"1F<"P@.#$Y,BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<F5T(#T@)E!%05)?4&%C:V%G949I;&4Z.F9R;VU8;6Q3=')I;F<H)&1A
M=&$L("1S=&%T92P@)&1E<V-F:6QE+"`D87)C:&EV92D[#0H@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@('T-"@T*#0H@("`@+RHJ#0H@("`@("H@0W)E871E
M(&$@4$5!4E]086-K86=E1FEL95]V*B!F<F]M(&$@+G1G>B!A<F-H:79E(&]R
M('!A8VMA9V4N>&UL(&9I;&4N#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO
M9"!I<R!A8FQE('1O(&5X=')A8W0@:6YF;W)M871I;VX@86)O=70@82!P86-K
M86=E(&9R;VT@82`N=&=Z#0H@("`@("H@87)C:&EV92!O<B!F<F]M(&$@6$U,
M('!A8VMA9V4@9&5F:6YI=&EO;B!F:6QE+@T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1I;F9O(&9I
M;&4@;F%M90T*("`@("`J($!P87)A;2`@(&EN="`@("`@)'-T871E('!A8VMA
M9V4@<W1A=&4@*&]N92!O9B!014%27U9!3$E$051%7RH@8V]N<W1A;G1S*0T*
M("`@("`J($!R971U<FX@(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K
M86=E1FEL95]V,@T*("`@("`J($!U<V5S("`@(&9R;VU086-K86=E1FEL92@I
M(&EF('1H92!F:6QE(&%P<&5A<G,@=&\@8F4@6$U,#0H@("`@("H@0'5S97,@
M("`@9G)O;51G>D9I;&4H*2!T;R!L;V%D(&%L;"!N;VXM6$U,(&9I;&5S#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@)F9R;VU!;GE&:6QE*"1I;F9O+"`D<W1A
M=&4I#0H@("`@>PT*("`@("`@("`D9G`@/2!F86QS93L-"B`@("`@("`@:68@
M*&ES7W-T<FEN9R@D:6YF;RD@)B8@<W1R;&5N*"1I;F9O*2`\(#(U-2`F)@T*
M("`@("`@("`@("`@("AF:6QE7V5X:7-T<R@D:6YF;RD@?'P@*"1F<"`]($!F
M;W!E;B@D:6YF;RP@)W(G*2DI*2![#0H@("`@("`@("`@("!I9B`H)&9P*2![
M#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D=&UP(#T@<W5B<W1R*"1I;F9O+"`M-"D[#0H@("`@
M("`@("`@("!I9B`H)'1M<"`]/2`G+GAM;"<I('L-"B`@("`@("`@("`@("`@
M("`D:6YF;R`]("9014%27U!A8VMA9V5&:6QE.CIF<F]M4&%C:V%G949I;&4H
M)&EN9F\L("1S=&%T92D[#0H@("`@("`@("`@("!](&5L<V5I9B`H)'1M<"`]
M/2`G+G1A<B<@?'P@)'1M<"`]/2`G+G1G>B<I('L-"B`@("`@("`@("`@("`@
M("`D:6YF;R`]("9014%27U!A8VMA9V5&:6QE.CIF<F]M5&=Z1FEL92@D:6YF
M;RP@)'-T871E*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@)&9P(#T@9F]P96XH)&EN9F\L(")R(BD[#0H@("`@("`@("`@("`@
M("`@)'1E<W0@/2!F<F5A9"@D9G`L(#4I.PT*("`@("`@("`@("`@("`@(&9C
M;&]S92@D9G`I.PT*("`@("`@("`@("`@("`@(&EF("@D=&5S="`]/2`B/#]X
M;6PB*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@)E!%05)?4&%C
M:V%G949I;&4Z.F9R;VU086-K86=E1FEL92@D:6YF;RP@)'-T871E*3L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M:6YF;R`]("9014%27U!A8VMA9V5&:6QE.CIF<F]M5&=Z1FEL92@D:6YF;RP@
M)'-T871E*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D:6YF;R`](%!%05(Z.G)A
M:7-E17)R;W(H(D-A;FYO="!O<&5N("<D:6YF;R<@9F]R('!A<G-I;F<B*3L-
M"B`@("`@("`@("`@(')E='5R;B`D:6YF;SL-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)&EN9F\[#0H@("`@?0T*?0T*#0H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+U)E9VES=')Y+G!H<```````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(Q-C(R,``Q,#4Q-30S,3`U-P`P
M,C`T,30`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\J*@T*("H@4$5!4E]296=I<W1R>0T*("H-"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S
M(%8N(%8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)E9VES=')Y+G!H<"QV(#$N
M,34P+C(N,B`R,#`V+S`S+S$Q(#`T.C$V.C0X(&-E;&QO9R!%>'`@)`T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,"XQ#0H@*B\-"@T*+RHJ#0H@*B!F;W(@4$5!4E]%<G)O<@T*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]$97!E
M;F1E;F-Y1$(N<&AP)SL-"@T*9&5F:6YE*"=014%27U)%1TE35%)97T524D]2
M7TQ/0TLG+"`@("TR*3L-"F1E9FEN92@G4$5!4E]214=)4U1265]%4E)/4E]&
M3U)-050G+"`M,RD[#0ID969I;F4H)U!%05)?4D5'25-44EE?15)23U)?1DE,
M12<L("`@+30I.PT*9&5F:6YE*"=014%27U)%1TE35%)97T524D]27T-/3D9,
M24-4)RP@+34I.PT*9&5F:6YE*"=014%27U)%1TE35%)97T524D]27T-(04Y.
M14Q?1DE,12<L("TV*3L-"@T*+RHJ#0H@*B!!9&UI;FES=')A=&EO;B!C;&%S
M<R!U<V5D('1O(&UA:6YT86EN('1H92!I;G-T86QL960@<&%C:V%G92!D871A
M8F%S92X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%
M05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-
M"B`J($!A=71H;W(@("`@(%1O;6%S(%8N(%8N($-O>"`\8V]X0&ED96-N970N
M8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?4F5G:7-T
M<GD@97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*
M("`@("\J*@T*("`@("`J($9I;&4@8V]N=&%I;FEN9R!A;&P@8VAA;FYE;"!I
M;F9O<FUA=&EO;BX-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@
M('9A<B`D8VAA;FYE;',@/2`G)SL-"@T*("`@("\J*B!$:7)E8W1O<GD@=VAE
M<F4@<F5G:7-T<GD@9FEL97,@87)E('-T;W)E9"X-"B`@("`@*B!`=F%R('-T
M<FEN9PT*("`@("`J+PT*("`@('9A<B`D<W1A=&5D:7(@/2`G)SL-"@T*("`@
M("\J*B!&:6QE('=H97)E('1H92!F:6QE(&UA<"!I<R!S=&]R960-"B`@("`@
M*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D9FEL96UA<"`]("<G
M.PT*#0H@("`@+RHJ($1I<F5C=&]R>2!W:&5R92!R96=I<W1R>2!F:6QE<R!F
M;W(@8VAA;FYE;',@87)E('-T;W)E9"X-"B`@("`@*B!`=F%R('-T<FEN9PT*
M("`@("`J+PT*("`@('9A<B`D8VAA;FYE;'-D:7(@/2`G)SL-"@T*("`@("\J
M*B!.86UE(&]F(&9I;&4@=7-E9"!F;W(@;&]C:VEN9R!T:&4@<F5G:7-T<GD-
M"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D;&]C:V9I
M;&4@/2`G)SL-"@T*("`@("\J*B!&:6QE(&1E<V-R:7!T;W(@=7-E9"!D=7)I
M;F<@;&]C:VEN9PT*("`@("`J($!V87(@<F5S;W5R8V4-"B`@("`@*B\-"B`@
M("!V87(@)&QO8VM?9G`@/2!N=6QL.PT*#0H@("`@+RHJ($UO9&4@=7-E9"!D
M=7)I;F<@;&]C:VEN9PT*("`@("`J($!V87(@:6YT#0H@("`@("HO#0H@("`@
M=F%R("1L;V-K7VUO9&4@/2`P.R`O+R!86%@@54Y54T5$#0H-"B`@("`O*BH@
M0V%C:&4@;V8@<&%C:V%G92!I;F9O<FUA=&EO;BX@(%-T<G5C='5R93H-"B`@
M("`@*B!A<G)A>2@-"B`@("`@*B`@("=P86-K86=E)R`]/B!A<G)A>2@G:60G
M(#T^("XN+B`I+`T*("`@("`J("`@+BXN("D-"B`@("`@*B!`=F%R(&%R<F%Y
M#0H@("`@("HO#0H@("`@=F%R("1P:V=I;F9O7V-A8VAE(#T@87)R87DH*3L-
M"@T*("`@("\J*B!#86-H92!O9B!F:6QE(&UA<"X@(%-T<G5C='5R93H-"B`@
M("`@*B!A<G)A>2@@)R]P871H+W1O+V9I;&4G(#T^("=P86-K86=E)RP@+BXN
M("D-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO#0H@("`@=F%R("1F:6QE
M;6%P7V-A8VAE(#T@87)R87DH*3L-"@T*("`@("\J*@T*("`@("`J($!V87(@
M9F%L<V5\4$5!4E]#:&%N;F5L1FEL90T*("`@("`J+PT*("`@('9A<B`D7W!E
M87)#:&%N;F5L.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A<B!F86QS97Q014%2
M7T-H86YN96Q&:6QE#0H@("`@("HO#0H@("`@=F%R("1?<&5C;$-H86YN96P[
M#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?1&5P96YD96YC>41"#0H@
M("`@("HO#0H@("`@=F%R("1?9&5P96YD96YC>41".PT*#0H@("`@+RHJ#0H@
M("`@("H@0'9A<B!014%27T-O;F9I9PT*("`@("`J+PT*("`@('9A<B`D7V-O
M;F9I9SL-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*
M#0H@("`@+RHJ#0H@("`@("H@4$5!4E]296=I<W1R>2!C;VYS=')U8W1O<BX-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@*&]P=&EO;F%L*2!014%2
M(&EN<W1A;&P@9&ER96-T;W)Y("AF;W(@+G!H<"!F:6QE<RD-"B`@("`@*B!`
M<&%R86T@4$5!4E]#:&%N;F5L1FEL92!014%27T-H86YN96Q&:6QE(&]B:F5C
M="!R97!R97-E;G1I;F<@=&AE(%!%05(@8VAA;FYE;"P@:68-"B`@("`@*B`@
M("`@("`@9&5F875L="!V86QU97,@87)E(&YO="!D97-I<F5D+B`@3VYL>2!U
M<V5D('1H92!V97)Y(&9I<G-T('1I;64@82!014%2#0H@("`@("H@("`@("`@
M(')E<&]S:71O<GD@:7,@:6YI=&EA;&EZ960-"B`@("`@*B!`<&%R86T@4$5!
M4E]#:&%N;F5L1FEL92!014%27T-H86YN96Q&:6QE(&]B:F5C="!R97!R97-E
M;G1I;F<@=&AE(%!%0TP@8VAA;FYE;"P@:68-"B`@("`@*B`@("`@("`@9&5F
M875L="!V86QU97,@87)E(&YO="!D97-I<F5D+B`@3VYL>2!U<V5D('1H92!V
M97)Y(&9I<G-T('1I;64@82!014%2#0H@("`@("H@("`@("`@(')E<&]S:71O
M<GD@:7,@:6YI=&EA;&EZ960-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]296=I<W1R>2@D<&5A
M<E]I;G-T86QL7V1I<B`](%!%05)?24Y35$%,3%]$25(L("1P96%R7V-H86YN
M96P@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1P96-L
M7V-H86YN96P@/2!F86QS92D-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!
M4B@I.PT*("`@("`@("`D9',@/2!$25)%0U1/4EE?4T5005)!5$]2.PT*("`@
M("`@("`D=&AI<RT^:6YS=&%L;%]D:7(@/2`D<&5A<E]I;G-T86QL7V1I<CL-
M"B`@("`@("`@)'1H:7,M/F-H86YN96QS9&ER(#T@)'!E87)?:6YS=&%L;%]D
M:7(N)&1S+B<N8VAA;FYE;',G.PT*("`@("`@("`D=&AI<RT^<W1A=&5D:7(@
M/2`D<&5A<E]I;G-T86QL7V1I<BXD9',N)RYR96=I<W1R>2<[#0H@("`@("`@
M("1T:&ES+3YF:6QE;6%P("`]("1P96%R7VEN<W1A;&Q?9&ER+B1D<RXG+F9I
M;&5M87`G.PT*("`@("`@("`D=&AI<RT^;&]C:V9I;&4@/2`D<&5A<E]I;G-T
M86QL7V1I<BXD9',N)RYL;V-K)SL-"B`@("`@("`@)'1H:7,M/E]P96%R0VAA
M;FYE;"`]("1P96%R7V-H86YN96P[#0H@("`@("`@("1T:&ES+3Y?<&5C;$-H
M86YN96P@/2`D<&5C;%]C:&%N;F5L.PT*("`@("`@("`D=&AI<RT^7V-O;F9I
M9R`](&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&AA<U=R:71E06-C
M97-S*"D-"B`@("![#0H@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1T:&ES
M+3YI;G-T86QL7V1I<BDI('L-"B`@("`@("`@("`@("1D:7(@/2`D=&AI<RT^
M:6YS=&%L;%]D:7([#0H@("`@("`@("`@("!W:&EL92`H)&1I<B`F)B`D9&ER
M("$]("<N)RD@>PT*("`@("`@("`@("`@("`@("1D:7(@/2!D:7)N86UE*"1D
M:7(I.R`O+R!C9"`N+@T*("`@("`@("`@("`@("`@(&EF("@D9&ER("$]("<N
M)R`F)B!`9FEL95]E>&ES=',H)&1I<BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*$!I<U]W<FET96%B;&4H)&1I<BDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!`:7-?=W)I=&5A8FQE*"1T:&ES+3YI
M;G-T86QL7V1I<BD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG
M*"8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F
M)&-O;F9I9SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?:6YI=&EA;&EZ94-H
M86YN96Q$:7)S*"D-"B`@("![#0H@("`@("`@('-T871I8R`D<G5N;FEN9R`]
M(&9A;'-E.PT*("`@("`@("!I9B`H(21R=6YN:6YG*2![#0H@("`@("`@("`@
M("`D<G5N;FEN9R`]('1R=64[#0H@("`@("`@("`@("`D9',@/2!$25)%0U1/
M4EE?4T5005)!5$]2.PT*("`@("`@("`@("`@:68@*"%I<U]D:7(H)'1H:7,M
M/F-H86YN96QS9&ER*2!\?`T*("`@("`@("`@("`@("`@("`@(69I;&5?97AI
M<W1S*"1T:&ES+3YC:&%N;F5L<V1I<B`N("1D<R`N("=P96%R+G!H<"YN970N
M<F5G)RD@?'P-"B`@("`@("`@("`@("`@("`@("%F:6QE7V5X:7-T<R@D=&AI
M<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5C;"YP:'`N;F5T+G)E9R<I('Q\
M#0H@("`@("`@("`@("`@("`@("`A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN
M96QS9&ER("X@)&1S("X@)U]?=7)I+G)E9R<I*2![#0H@("`@("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@
M+B`G<&5A<BYP:'`N;F5T+G)E9R<I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1P96%R7V-H86YN96P@/2`D=&AI<RT^7W!E87)#:&%N;F5L.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES7V$H)'!E87)?8VAA;FYE;"P@)U!%05)?
M0VAA;FYE;$9I;&4G*2!\?"`A)'!E87)?8VAA;FYE;"T^=F%L:61A=&4H*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!E87)?8VAA;FYE;"`](&YE=R!014%27T-H86YN96Q&:6QE.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T3F%M
M92@G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&5A<E]C:&%N;F5L+3YS971!;&EA<R@G<&5A<B<I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T4V5R=F5R*"=P96%R+G!H
M<"YN970G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P96%R7V-H86YN
M96PM/G-E=%-U;6UA<GDH)U!(4"!%>'1E;G-I;VX@86YD($%P<&QI8V%T:6]N
M(%)E<&]S:71O<GDG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P96%R
M7V-H86YN96PM/G-E=$1E9F%U;'1014%24')O=&]C;VQS*"D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E55),*"=2
M15-4,2XP)RP@)VAT='`Z+R]P96%R+G!H<"YN970O<F5S="\G*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$)A<V554DPH
M)U)%4U0Q+C$G+"`G:'1T<#HO+W!E87(N<&AP+FYE="]R97-T+R<I.PT*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!E87)?8VAA;FYE;"T^<V5T3F%M92@G<&5A<BYP:'`N;F5T)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971!
M;&EA<R@G<&5A<B<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("1P96%R7V-H86YN96PM/G9A;&ED871E*"D[#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D0VAA;FYE;"@D<&5A<E]C:&%N
M;F5L*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"%F:6QE7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5C
M;"YP:'`N;F5T+G)E9R<I*2![#0H@("`@("`@("`@("`@("`@("`@("1P96-L
M7V-H86YN96P@/2`D=&AI<RT^7W!E8VQ#:&%N;F5L.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES7V$H)'!E8VQ?8VAA;FYE;"P@)U!%05)?0VAA;FYE
M;$9I;&4G*2!\?"`A)'!E8VQ?8VAA;FYE;"T^=F%L:61A=&4H*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?
M0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!E8VQ?8VAA;FYE;"`](&YE=R!014%27T-H86YN96Q&:6QE.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!E8VQ?8VAA;FYE;"T^<V5T3F%M92@G<&5C
M;"YP:'`N;F5T)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5C;%]C
M:&%N;F5L+3YS971!;&EA<R@G<&5C;"<I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!E8VQ?8VAA;FYE;"T^<V5T4V5R=F5R*"=P96-L+G!H<"YN970G
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P96-L7V-H86YN96PM/G-E
M=%-U;6UA<GDH)U!(4"!%>'1E;G-I;VX@0V]M;75N:71Y($QI8G)A<GDG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P96-L7V-H86YN96PM/G-E=$1E
M9F%U;'1014%24')O=&]C;VQS*"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<&5C;%]C:&%N;F5L+3YS971"87-E55),*"=215-4,2XP)RP@)VAT='`Z
M+R]P96-L+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P96-L7V-H86YN96PM/G-E=$)A<V554DPH)U)%4U0Q+C$G+"`G:'1T
M<#HO+W!E8VPN<&AP+FYE="]R97-T+R<I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!E8VQ?8VAA;FYE;"T^<V5T5F%L:61A=&EO;E!A8VMA9V4H)U!%
M05)?5F%L:61A=&]R7U!%0TPG+"`G,2XP)RD[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5C;%]C
M:&%N;F5L+3YS971.86UE*"=P96-L+G!H<"YN970G*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P96-L7V-H86YN96PM/G-E=$%L:6%S*"=P96-L)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)'!E8VQ?8VAA;FYE;"T^=F%L:61A=&4H*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A9&1#:&%N;F5L*"1P96-L7V-H86YN96PI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S
M*"1T:&ES+3YC:&%N;F5L<V1I<B`N("1D<R`N("=?7W5R:2YR96<G*2D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#
M:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<')I=F%T92`](&YE
M=R!014%27T-H86YN96Q&:6QE.PT*("`@("`@("`@("`@("`@("`@("`D<')I
M=F%T92T^<V5T3F%M92@G7U]U<FDG*3L-"B`@("`@("`@("`@("`@("`@("`@
M)'!R:79A=&4M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@)RHJ*BHG
M*3L-"B`@("`@("`@("`@("`@("`@("`@)'!R:79A=&4M/G-E=%-U;6UA<GDH
M)U!S975D;RUC:&%N;F5L(&9O<B!S=&%T:6,@<&%C:V%G97,G*3L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1#:&%N;F5L*"1P<FEV871E*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R
M96)U:6QD1FEL94UA<"@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)')U;FYI;F<@/2!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]I;FET:6%L:7IE1&ER<R@I#0H@("`@>PT*("`@("`@("`D9',@
M/2!$25)%0U1/4EE?4T5005)!5$]2.PT*("`@("`@("`O+R!86%@@0V]M<&%T
M:6)I;&ET>2!C;V1E('-H;W5L9"!B92!R96UO=F5D(&EN('1H92!F=71U<F4-
M"B`@("`@("`@+R\@<F5N86UE(&%L;"!R96=I<W1R>2!F:6QE<R!I9B!A;GD@
M=&\@;&]W97)C87-E#0H@("`@("`@(&EF("@A3U-?5TE.1$]74R`F)B`D:&%N
M9&QE(#T@0&]P96YD:7(H)'1H:7,M/G-T871E9&ER*2D@>PT*("`@("`@("`@
M("`@)&1E<W0@/2`D=&AI<RT^<W1A=&5D:7(@+B`D9',[#0H@("`@("`@("`@
M("!W:&EL92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H)&AA;F1L92DI
M*2![#0H@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>+BI;02U:
M72XJ7"YR96<D+R<L("1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("!R
M96YA;64H)&1E<W0@+B`D9FEL92P@)&1E<W0@+B!S=')T;VQO=V5R*"1F:6QE
M*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@8VQO<V5D:7(H)&AA;F1L92D[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]I;FET:6%L:7IE0VAA;FYE;$1I<G,H*3L-"B`@("`@("`@:68@
M*"%F:6QE7V5X:7-T<R@D=&AI<RT^9FEL96UA<"DI('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<F5B=6EL9$9I;&5-87`H*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7VEN:71I86QI>F5$97!$0B@I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]I;FET:6%L:7IE1&5P1$(H*0T*("`@('L-"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V1E<&5N9&5N8WE$0BDI('L-"B`@("`@("`@("`@
M('-T871I8R`D:6YI=&EA;&EZ:6YG(#T@9F%L<V4[#0H@("`@("`@("`@("!I
M9B`H(21I;FET:6%L:7II;F<I('L-"B`@("`@("`@("`@("`@("`D:6YI=&EA
M;&EZ:6YG(#T@=')U93L-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M8V]N9FEG*2![("\O(&YE=F5R('5S960_#0H@("`@("`@("`@("`@("`@("`@
M(&EF("A/4U]724Y$3U=3*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9FEL92`]("=P96%R+FEN:2<[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9FEL92`]("<N<&5A<G)C
M)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-O;F9I9R`]("9N97<@4$5!4E]#;VYF:6<H)'1H:7,M/G-T
M871E9&ER("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9FEL92D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8V]N9FEG+3YS971296=I<W1R>2@D=&AI<RD[#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V]N9FEG+3YS970H)W!H<%]D:7(G+"`D=&AI<RT^
M:6YS=&%L;%]D:7(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$0B`]("9014%27T1E<&5N9&5N8WE$
M0CHZ<VEN9VQE=&]N*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7V1E<&5N9&5N8WE$0BDI('L-
M"B`@("`@("`@("`@("`@("`@("`@+R\@871T96UP="!T;R!R96-O=F5R(&)Y
M(')E;6]V:6YG('1H92!D97`@9&(-"B`@("`@("`@("`@("`@("`@("`@0'5N
M;&EN:R@D=&AI<RT^7V-O;F9I9RT^9V5T*"=P:'!?9&ER)RP@;G5L;"P@)W!E
M87(N<&AP+FYE="<I("X-"B`@("`@("`@("`@("`@("`@("`@("`@($1)4D5#
M5$]265]315!!4D%43U(@+B`G+F1E<&1B)RD[#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&5P96YD96YC>41"(#T@)E!%05)?1&5P96YD96YC>41"
M.CIS:6YG;&5T;VXH)'1H:7,M/E]C;VYF:6<I.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7V1E<&5N9&5N8WE$0BDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)'1H:7,M/E]D97!E
M;F1E;F-Y1$(M/F=E=$UE<W-A9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&1I92@G56YR96-O=F5R86)L92!E<G)O<B<I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1I;FET:6%L:7II;F<@/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@('T-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&5S=')U8W1O
M<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]296=I<W1R>2!D97-T<G5C=&]R
M+B`@36%K97,@<W5R92!N;R!L;V-K<R!A<F4@9F]R9V]T=&5N+@T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7U!%05)?4F5G:7-T<GDH*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI?
M4$5!4B@I.PT*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/FQO8VM?
M9G`I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V%S<V5R
M=%-T871E1&ER*"D-"@T*("`@("\J*@T*("`@("`J($UA:V4@<W5R92!T:&4@
M9&ER96-T;W)Y('=H97)E('=E(&ME97`@<F5G:7-T<GD@9FEL97,@97AI<W1S
M+@T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@:68@9&ER96-T
M;W)Y(&5X:7-T<RP@1D%,4T4@:68@:70@8V]U;&0@;F]T(&)E#0H@("`@("H@
M8W)E871E9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@7V%S<V5R=%-T871E1&ER*"1C:&%N;F5L(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)&-H86YN96P@)B8@)'1H:7,M
M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L*2`A/2`G<&5A<BYP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?87-S97)T0VAA
M;FYE;%-T871E1&ER*"1C:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("!S
M=&%T:6,@)&EN:70@/2!F86QS93L-"B`@("`@("`@:68@*"%`:7-?9&ER*"1T
M:&ES+3YS=&%T961I<BDI('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/FAA
M<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@:68@*"%3>7-T96TZ.FUK9&ER
M*&%R<F%Y*"<M<"<L("1T:&ES+3YS=&%T961I<BDI*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@8W)E
M871E(&1I<F5C=&]R>2`G>R1T:&ES+3YS=&%T961I<GTG(BD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D:6YI="`]('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@)&1S(#T@1$E214-43U)97U-%4$%2051/4CL-"B`@("`@("`@
M:68@*"%`:7-?9&ER*"1T:&ES+3YC:&%N;F5L<V1I<BD@?'P-"B`@("`@("`@
M("`@("`@(69I;&5?97AI<W1S*"1T:&ES+3YC:&%N;F5L<V1I<B`N("1D<R`N
M("=P96%R+G!H<"YN970N<F5G)RD@?'P-"B`@("`@("`@("`@("`@(69I;&5?
M97AI<W1S*"1T:&ES+3YC:&%N;F5L<V1I<B`N("1D<R`N("=P96-L+G!H<"YN
M970N<F5G)RD@?'P-"B`@("`@("`@("`@("`@(69I;&5?97AI<W1S*"1T:&ES
M+3YC:&%N;F5L<V1I<B`N("1D<R`N("=?7W5R:2YR96<G*2D@>PT*("`@("`@
M("`@("`@)&EN:70@/2!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M:6YI="D@>PT*("`@("`@("`@("`@<W1A=&EC("1R=6YN:6YG(#T@9F%L<V4[
M#0H@("`@("`@("`@("!I9B`H(21R=6YN:6YG*2![#0H@("`@("`@("`@("`@
M("`@)')U;FYI;F<@/2!T<G5E.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:6YI=&EA;&EZ941I<G,H*3L-"B`@("`@("`@("`@("`@("`D<G5N;FEN9R`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("1I;FET(#T@9F%L<V4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI
M<RT^7VEN:71I86QI>F5$97!$0B@I.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?
M87-S97)T0VAA;FYE;%-T871E1&ER*"D-"@T*("`@("\J*@T*("`@("`J($UA
M:V4@<W5R92!T:&4@9&ER96-T;W)Y('=H97)E('=E(&ME97`@<F5G:7-T<GD@
M9FEL97,@97AI<W1S(&9O<B!A(&YO;BUS=&%N9&%R9"!C:&%N;F5L+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@("`@
M*B!`<F5T=7)N(&)O;VP@5%)512!I9B!D:7)E8W1O<GD@97AI<W1S+"!&04Q3
M12!I9B!I="!C;W5L9"!N;W0@8F4-"B`@("`@*B!C<F5A=&5D#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?87-S97)T0VAA;FYE;%-T871E1&ER*"1C:&%N;F5L*0T*("`@('L-"B`@
M("`@("`@)&1S(#T@1$E214-43U)97U-%4$%2051/4CL-"B`@("`@("`@:68@
M*"$D8VAA;FYE;"!\?"`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H
M86YN96PI(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!I9B`H
M(69I;&5?97AI<W1S*"1T:&ES+3YC:&%N;F5L<V1I<B`N("1D<R`N("=P96%R
M+G!H<"YN970N<F5G)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN
M:71I86QI>F5#:&%N;F5L1&ER<R@I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?87-S97)T4W1A=&5$:7(H)&-H86YN96PI
M.PT*("`@("`@("!]#0H@("`@("`@("1C:&%N;F5L1&ER(#T@)'1H:7,M/E]C
M:&%N;F5L1&ER96-T;W)Y3F%M92@D8VAA;FYE;"D[#0H@("`@("`@(&EF("@A
M:7-?9&ER*"1T:&ES+3YC:&%N;F5L<V1I<BD@?'P-"B`@("`@("`@("`@("`@
M(69I;&5?97AI<W1S*"1T:&ES+3YC:&%N;F5L<V1I<B`N("1D<R`N("=P96%R
M+G!H<"YN970N<F5G)RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?:6YI=&EA
M;&EZ94-H86YN96Q$:7)S*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%`
M:7-?9&ER*"1C:&%N;F5L1&ER*2D@>PT*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@("`@("!I9B`H(5-Y<W1E;3HZ
M;6MD:7(H87)R87DH)RUP)RP@)&-H86YN96Q$:7(I*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-R
M96%T92!D:7)E8W1O<GD@)R(@+B`D8VAA;FYE;$1I<B`N#0H@("`@("`@("`@
M("`@("`@("`@("(G(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(%]A<W-E<G1#:&%N;F5L1&ER*"D-"@T*("`@("\J*@T*("`@("`J
M($UA:V4@<W5R92!T:&4@9&ER96-T;W)Y('=H97)E('=E(&ME97`@<F5G:7-T
M<GD@9FEL97,@9F]R(&-H86YN96QS(&5X:7-T<PT*("`@("`J#0H@("`@("H@
M0')E='5R;B!B;V]L(%12544@:68@9&ER96-T;W)Y(&5X:7-T<RP@1D%,4T4@
M:68@:70@8V]U;&0@;F]T(&)E#0H@("`@("H@8W)E871E9`T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7V%S<V5R=$-H86YN96Q$:7(H*0T*("`@('L-"B`@("`@("`@:68@*"%`:7-?
M9&ER*"1T:&ES+3YC:&%N;F5L<V1I<BDI('L-"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@:68@*"%3>7-T
M96TZ.FUK9&ER*&%R<F%Y*"<M<"<L("1T:&ES+3YC:&%N;F5L<V1I<BDI*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C
M;W5L9"!N;W0@8W)E871E(&1I<F5C=&]R>2`G>R1T:&ES+3YC:&%N;F5L<V1I
M<GTG(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%`:7-?9&ER*"1T:&ES+3YC:&%N;F5L<V1I<B`N($1)4D5#5$]265]315!!
M4D%43U(@+B`G+F%L:6%S)RDI('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@:68@*"%3>7-T96TZ.FUK
M9&ER*&%R<F%Y*"<M<"<L("1T:&ES+3YC:&%N;F5L<V1I<B`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`G+F%L:6%S)RDI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@8W)E871E(&1I
M<F5C=&]R>2`G>R1T:&ES+3YC:&%N;F5L<V1I<GTO+F%L:6%S)R(I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?<&%C:V%G949I;&5.
M86UE*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;F%M92!O9B!T:&4@
M9FEL92!W:&5R92!D871A(&9O<B!A(&=I=F5N('!A8VMA9V4@:7,@<W1O<F5D
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64L
M(&]R(&9A;'-E(&EF('1H:7,@:7,@82!014%2('!A8VMA9V4-"B`@("`@*B!`
M<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J#0H@("`@("H@0')E
M='5R;B!S=')I;F<@<F5G:7-T<GD@9FEL92!N86UE#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%]P86-K
M86=E1FEL94YA;64H)'!A8VMA9V4L("1C:&%N;F5L(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H)&-H86YN96P@)B8@)'1H:7,M/E]G971#:&%N;F5L
M1G)O;4%L:6%S*"1C:&%N;F5L*2`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE;$1I<F5C=&]R>4YA;64H
M)&-H86YN96PI("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@
M("`@("`@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G+G)E9R<[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3YS=&%T961I<B`N($1)4D5#5$]2
M65]315!!4D%43U(@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<N<F5G)SL-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V-H86YN96Q&:6QE
M3F%M92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YA;64@;V8@=&AE
M(&9I;&4@=VAE<F4@9&%T82!F;W(@82!G:79E;B!C:&%N;F5L(&ES('-T;W)E
M9"X-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M90T*("`@("`J
M($!R971U<FX@<W1R:6YG(')E9VES=')Y(&9I;&4@;F%M90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]C:&%N;F5L1FEL94YA;64H)&-H86YN96PL("1N;V%L
M:6%S97,@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A)&YO86QI87-E
M<RD@>PT*("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D=&AI<RT^7V=E
M=$-H86YN96Q!;&EA<T9I;&5.86UE*"1C:&%N;F5L*2DI('L-"B`@("`@("`@
M("`@("`@("`D8VAA;FYE;"`](&EM<&QO9&4H)R<L(&9I;&4H)'1H:7,M/E]G
M971#:&%N;F5L06QI87-&:6QE3F%M92@D8VAA;FYE;"DI*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/F-H86YN
M96QS9&ER("X@1$E214-43U)97U-%4$%2051/4B`N('-T<E]R97!L86-E*"<O
M)RP@)U\G+`T*("`@("`@("`@("`@<W1R=&]L;W=E<B@D8VAA;FYE;"DI("X@
M)RYR96<G.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971#
M:&%N;F5L06QI87-&:6QE3F%M92@I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)&%L:6%S*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC:&%N;F5L<V1I<B`N($1)
M4D5#5$]265]315!!4D%43U(@+B`G+F%L:6%S)R`N#0H@("`@("`@("`@("`@
M($1)4D5#5$]265]315!!4D%43U(@+B!S=')?<F5P;&%C92@G+R<L("=?)RP@
M<W1R=&]L;W=E<B@D86QI87,I*2`N("<N='AT)SL-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@7V=E=$-H86YN96Q&<F]M06QI87,H*0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T('1H92!N86UE(&]F(&$@8VAA;FYE;"!F<F]M
M(&ET<R!A;&EA<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971#:&%N;F5L
M1G)O;4%L:6%S*"1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI
M<RT^7V-H86YN96Q%>&ES=',H)&-H86YN96PI*2![#0H@("`@("`@("`@("!I
M9B`H)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN<&AP+FYE="<I('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)W!E8VPN<&AP+FYE="<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)U]?=7)I
M)RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`G7U]U<FDG.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D8VAA;FYE;"D[#0H@
M("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&AI<RT^7V=E=$-H86YN96Q!;&EA
M<T9I;&5.86UE*"1C:&%N;F5L*2DI('L-"B`@("`@("`@("`@("\O('1R86YS
M;&%T92!A;B!A;&EA<R!T;R!A;B!A8W1U86P@8VAA;FYE;`T*("`@("`@("`@
M("`@<F5T=7)N(&EM<&QO9&4H)R<L(&9I;&4H)'1H:7,M/E]G971#:&%N;F5L
M06QI87-&:6QE3F%M92@D8VAA;FYE;"DI*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(')E='5R;B`D8VAA;FYE;#L-"B`@("`@("`@?0T*("`@
M('T@("`@#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]G971#:&%N;F5L1G)O
M;4%L:6%S*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@86QI87,@;V8@
M82!C:&%N;F5L(&9R;VT@:71S(&%L:6%S(&]R(&ET<R!N86UE#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V=E=$%L:6%S*"1C:&%N;F5L*0T*("`@('L-"B`@
M("`@("`@:68@*"$D=&AI<RT^7V-H86YN96Q%>&ES=',H)&-H86YN96PI*2![
M#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)W!E87(G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("=P96-L)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3Y?9V5T0VAA;FYE;"@D8VAA
M;FYE;"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N;F5L*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1C:&%N;F5L.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D8VAA;FYE;"T^9V5T06QI87,H*3L-"B`@("!]("`@
M(`T*("`@("\O('U]?0T*("`@("\O('M[>R!?8VAA;FYE;$1I<F5C=&]R>4YA
M;64H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!N86UE(&]F('1H92!F
M:6QE('=H97)E(&1A=&$@9F]R(&$@9VEV96X@<&%C:V%G92!I<R!S=&]R960N
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M92P@
M;W(@9F%L<V4@:68@=&AI<R!I<R!A(%!%05(@<&%C:V%G90T*("`@("`J($!P
M87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H-"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!R96=I<W1R>2!F:6QE(&YA;64-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V-H86YN
M96Q$:7)E8W1O<GE.86UE*"1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@
M*"$D8VAA;FYE;"!\?"`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H
M86YN96PI(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G-T871E9&ER.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&-H(#T@)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N
M;F5L*3L-"B`@("`@("`@("`@(&EF("@A)&-H*2![#0H@("`@("`@("`@("`@
M("`@)&-H(#T@)&-H86YN96P[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-T871E9&ER("X@1$E214-43U)97U-%4$%2051/
M4B`N('-T<G1O;&]W97(H)RYC:&%N;F5L+B<@+@T*("`@("`@("`@("`@("`@
M('-T<E]R97!L86-E*"<O)RP@)U\G+"`D8V@I*3L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?;W!E;E!A8VMA9V5&:6QE
M*"D-"@T*("`@(&9U;F-T:6]N(%]O<&5N4&%C:V%G949I;&4H)'!A8VMA9V4L
M("1M;V1E+"`D8VAA;FYE;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*"$D=&AI<RT^7V%S<V5R=%-T871E1&ER*"1C:&%N;F5L*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I
M;E]A<G)A>2@D;6]D92P@87)R87DH)W(G+"`G<F(G*2D@)B8@(21T:&ES+3YH
M87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-
M"B`@("`@("`@?0T*("`@("`@("`D9FEL92`]("1T:&ES+3Y?<&%C:V%G949I
M;&5.86UE*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@("`@("`@("1F<"`]($!F
M;W!E;B@D9FEL92P@)&UO9&4I.PT*("`@("`@("!I9B`H(21F<"D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1F<#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V-L
M;W-E4&%C:V%G949I;&4H*0T*#0H@("`@9G5N8W1I;VX@7V-L;W-E4&%C:V%G
M949I;&4H)&9P*0T*("`@('L-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]O<&5N4&%C:V%G949I;&4H
M*0T*#0H@("`@9G5N8W1I;VX@7V]P96Y#:&%N;F5L1FEL92@D8VAA;FYE;"P@
M)&UO9&4I#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?87-S97)T0VAA
M;FYE;$1I<B@I*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1M;V1E+"!A<G)A>2@G<B<L
M("=R8B<I*2`F)B`A)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@
M("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@("1F:6QE
M(#T@)'1H:7,M/E]C:&%N;F5L1FEL94YA;64H)&-H86YN96PI.PT*("`@("`@
M("`D9G`@/2!`9F]P96XH)&9I;&4L("1M;V1E*3L-"B`@("`@("`@:68@*"$D
M9G`I('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D9G`[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(%]C;&]S95!A8VMA9V5&:6QE*"D-"@T*("`@(&9U;F-T:6]N(%]C
M;&]S94-H86YN96Q&:6QE*"1F<"D-"B`@("![#0H@("`@("`@(&9C;&]S92@D
M9G`I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?<F5B=6EL
M9$9I;&5-87`H*0T*#0H@("`@9G5N8W1I;VX@7W)E8G5I;&1&:6QE36%P*"D-
M"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27TEN<W1A
M;&QE<E]2;VQE)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]);G-T86QL97(O4F]L92YP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1C
M:&%N;F5L<R`]("1T:&ES+3Y?;&ES=$%L;%!A8VMA9V5S*"D[#0H@("`@("`@
M("1F:6QE<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1C:&%N;F5L
M<R!A<R`D8VAA;FYE;"`]/B`D<&%C:V%G97,I('L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1P86-K86=E<R!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@
M("`@("1V97)S:6]N(#T@)'1H:7,M/E]P86-K86=E26YF;R@D<&%C:V%G92P@
M)W9E<G-I;VXG+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@)&9I;&5L
M:7-T(#T@)'1H:7,M/E]P86-K86=E26YF;R@D<&%C:V%G92P@)V9I;&5L:7-T
M)RP@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)&9I;&5L:7-T*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&9I;&5L:7-T(&%S("1N86UE(#T^("1A='1R<RD@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&%T=')S6R=A='1R:6)S)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D871T<G,@/2`D871T<G-;)V%T=')I8G,G
M73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`O+R!I="!I<R!P;W-S:6)L92!F;W(@8V]N9FQI8W1I;F<@<&%C:V%G97,@
M:6X@9&EF9F5R96YT(&-H86YN96QS('1O#0H@("`@("`@("`@("`@("`@("`@
M("\O(&-O;F9L:6-T('=I=&@@9&%T82!F:6QE<R]D;V,@9FEL97,-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1N86UE(#T]("=D:7)T<F5E)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R
M<ULG<F]L92==*2`F)B`A:6Y?87)R87DH)&%T=')S6R=R;VQE)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E
M=$EN<W1A;&QA8FQE4F]L97,H*2DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O('1H97-E(&%R92!N;W0@:6YS=&%L;&5D#0H@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')S6R=R;VQE)UTI
M("8F("%I;E]A<G)A>2@D871T<G-;)W)O;&4G72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4E]);G-T86QL97)?4F]L93HZ9V5T0F%S96EN<W1A
M;&Q2;VQE<R@I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')S
M6R=B87-E:6YS=&%L;&1I<B==(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R
M<ULG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1F:6QE(#T@)&%T=')S6R=B87-E:6YS=&%L;&1I<B==+D1)4D5#5$]2
M65]315!!4D%43U(N)&YA;64[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1N86UE.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@<')E9U]R97!L86-E*"<L7B\K+"<L("<G+"`D9FEL92D[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@D8VAA;FYE;"`A/2`G<&5A<BYP:'`N;F5T
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5S6R1A='1R<ULG
M<F]L92==75LD9FEL95T@/2!A<G)A>2AS=')T;VQO=V5R*"1C:&%N;F5L*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1P86-K
M86=E*2D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEL97-;)&%T=')S6R=R;VQE)UU=6R1F:6QE
M72`]('-T<G1O;&]W97(H)'!A8VMA9V4I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?87-S97)T4W1A=&5$:7(H*3L-"B`@("`@
M("`@:68@*"$D=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1F<"`]($!F
M;W!E;B@D=&AI<RT^9FEL96UA<"P@)W=B)RD[#0H@("`@("`@(&EF("@A)&9P
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/F9I;&5M87!?8V%C:&4@/2`D9FEL97,[#0H@("`@("`@
M(&9W<FET92@D9G`L('-E<FEA;&EZ92@D9FEL97,I*3L-"B`@("`@("`@9F-L
M;W-E*"1F<"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!?<F5A9$9I;&5-87`H*0T*#0H@("`@9G5N
M8W1I;VX@7W)E861&:6QE36%P*"D-"B`@("![#0H@("`@("`@("1F<"`]($!F
M;W!E;B@D=&AI<RT^9FEL96UA<"P@)W(G*3L-"B`@("`@("`@:68@*"$D9G`I
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G4$5!
M4E]296=I<W1R>3H@8V]U;&0@;F]T(&]P96X@9FEL96UA<"`B)R`N("1T:&ES
M+3YF:6QE;6%P("X@)R(G+"!014%27U)%1TE35%)97T524D]27T9)3$4L(&YU
M;&PL(&YU;&PL("1P:'!?97)R;W)M<V<I.PT*("`@("`@("!]#0H@("`@("`@
M(&-L96%R<W1A=&-A8VAE*"D[#0H@("`@("`@("1R="`](&=E=%]M86=I8U]Q
M=6]T97-?<G5N=&EM92@I.PT*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U
M;G1I;64H,"D[#0H@("`@("`@("1F<VEZ92`](&9I;&5S:7IE*"1T:&ES+3YF
M:6QE;6%P*3L-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G
M971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@
M("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1T:&ES+3YF
M:6QE;6%P*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D871A
M(#T@9G)E860H)&9P+"`D9G-I>F4I.PT*("`@("`@("`@("`@9F-L;W-E*"1F
M<"D[#0H@("`@("`@('T-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT
M:6UE*"1R="D[#0H@("`@("`@("1T;7`@/2!U;G-E<FEA;&EZ92@D9&%T82D[
M#0H@("`@("`@(&EF("@A)'1M<"`F)B`D9G-I>F4@/B`W*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U!%05)?4F5G:7-T<GDZ
M(&EN=F%L:60@9FEL96UA<"!D871A)RP@4$5!4E]214=)4U1265]%4E)/4E]&
M3U)-050L(&YU;&PL(&YU;&PL("1D871A*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^9FEL96UA<%]C86-H92`]("1T;7`[#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?;&]C
M:R@I#0H-"B`@("`O*BH-"B`@("`@*B!,;V-K('1H92!R96=I<W1R>2X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!I;G1E9V5R(&QO8VL@;6]D92P@;VYE(&]F
M($Q/0TM?15@L($Q/0TM?4T@@;W(@3$]#2U]53BX-"B`@("`@*B`@("`@("`@
M("`@("`@("!3964@9FQO8VL@;6%N=6%L(&9O<B!M;W)E(&EN9F]R;6%T:6]N
M+@T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S
M<RP@1D%,4T4@:68@;&]C:VEN9R!F86EL960L(&]R(&$-"B`@("`@*B`@("`@
M("`@("`@("`@4$5!4B!E<G)O<B!I9B!S;VUE(&]T:&5R(&5R<F]R(&]C8W5R
M<R`H<W5C:"!A<R!T:&4-"B`@("`@*B`@("`@("`@("`@("`@;&]C:R!F:6QE
M(&YO="!B96EN9R!W<FET86)L92DN#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;&]C:R@D;6]D92`]
M($Q/0TM?15@I#0H@("`@>PT*("`@("`@("!I9B`H(65R96=I*"=7:6YD;W=S
M(#DG+"!P:'!?=6YA;64H*2DI('L-"B`@("`@("`@("`@(&EF("@D;6]D92`A
M/2!,3T-+7U5.("8F(&ES7W)E<V]U<F-E*"1T:&ES+3YL;V-K7V9P*2D@>PT*
M("`@("`@("`@("`@("`@("\O(%A86"!D;V5S(&YO="!C:&5C:R!T>7!E(&]F
M(&QO8VL@*$Q/0TM?4T@O3$]#2U]%6"D-"B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/E]A<W-E<G13=&%T941I<B@I*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1M;V1E(#T]($Q/0TM?15@I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=296=I<W1R>2!D:7)E8W1O<GD@:7,@
M;F]T('=R:71E86)L92!B>2!T:&4@8W5R<F5N="!U<V5R)RD[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&]P96Y?;6]D92`]("=W)SL-"B`@("`@("`@("`@("\O(%A8
M6"!096]P;&4@<F5P;W)T960@<')O8FQE;7,@=VET:"!,3T-+7U-((&%N9"`G
M=R<-"B`@("`@("`@("`@(&EF("@D;6]D92`]/3T@3$]#2U]32"!\?"`D;6]D
M92`]/3T@3$]#2U]53BD@>PT*("`@("`@("`@("`@("`@(&EF("A`(6ES7V9I
M;&4H)'1H:7,M/FQO8VMF:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("!T
M;W5C:"@D=&AI<RT^;&]C:V9I;&4I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D;W!E;E]M;V1E(#T@)W(G.PT*("`@("`@("`@("`@
M?0T*#0H@("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YL;V-K
M7V9P*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YL;V-K7V9P(#T@0&9O
M<&5N*"1T:&ES+3YL;V-K9FEL92P@)&]P96Y?;6]D92D[#0H@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/FQO
M8VM?9G`I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")C;W5L9"!N;W0@8W)E871E(&QO8VL@9FEL92(@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:7-S970H)'!H
M<%]E<G)O<FUS9RD@/R`B.B`B("X@)'!H<%]E<G)O<FUS9R`Z("(B*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(2AI;G0I9FQO8VLH)'1H
M:7,M/FQO8VM?9G`L("1M;V1E*2D@>PT*("`@("`@("`@("`@("`@('-W:71C
M:"`H)&UO9&4I('L-"B`@("`@("`@("`@("`@("`@("`@8V%S92!,3T-+7U-(
M.B`D<W1R(#T@)W-H87)E9"<[("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M("`@("!C87-E($Q/0TM?15@Z("1S='(@/2`G97AC;'5S:79E)SL@8G)E86L[
M#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@3$]#2U]53CH@)'-T<B`]("=U
M;FQO8VLG.R`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@9&5F875L
M=#H@("`@("`D<W1R(#T@)W5N:VYO=VXG.R`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F-O=6QD(&YO="!A8W%U:7)E("1S='(@;&]C:R`H)'1H:7,M/FQO
M8VMF:6QE*2(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05)?4D5'25-44EE?15)23U)?3$]#2RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]U;FQO8VLH*0T*#0H@("`@9G5N
M8W1I;VX@7W5N;&]C:R@I#0H@("`@>PT*("`@("`@("`D<F5T(#T@)'1H:7,M
M/E]L;V-K*$Q/0TM?54XI.PT*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H
M:7,M/FQO8VM?9G`I*2![#0H@("`@("`@("`@("!F8VQO<V4H)'1H:7,M/FQO
M8VM?9G`I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YL;V-K7V9P(#T@
M;G5L;#L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(%]P86-K86=E17AI<W1S*"D-"@T*("`@(&9U;F-T
M:6]N(%]P86-K86=E17AI<W1S*"1P86-K86=E+"`D8VAA;FYE;"`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&9I;&5?97AI<W1S*"1T:&ES+3Y?
M<&%C:V%G949I;&5.86UE*"1P86-K86=E+"`D8VAA;FYE;"DI.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?8VAA;FYE;$5X:7-T<R@I#0H-
M"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B!A(&-H86YN96P@
M97AI<W1S(&EN('1H92!R96=I<W1R>0T*("`@("`J($!P87)A;2!S=')I;F<@
M0VAA;FYE;"!N86UE#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&AE
M;B!A;&EA<V5S('=I;&P@8F4@:6=N;W)E9`T*("`@("`J($!R971U<FX@8F]O
M;&5A;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C:&%N;F5L17AI<W1S*"1C
M:&%N;F5L+"`D;F]A;&EA<V5S(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D
M82`](&9I;&5?97AI<W1S*"1T:&ES+3Y?8VAA;FYE;$9I;&5.86UE*"1C:&%N
M;F5L+"`D;F]A;&EA<V5S*2D[#0H@("`@("`@(&EF("@A)&$@)B8@)&-H86YN
M96P@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)&$@)B8@)&-H86YN96P@
M/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7V%D9$-H86YN96PH*0T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M(%!%05)?0VAA;FYE;$9I;&4@0VAA;FYE;"!O8FIE
M8W0-"B`@("`@*B!`<&%R86T@9&]N;W1U<V4-"B`@("`@*B!`<&%R86T@<W1R
M:6YG($QA<W0M36]D:69I960@2%144"!T86<@9G)O;2!R96UO=&4@<F5Q=65S
M=`T*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R(%1R=64@;VX@
M8W)E871I;VXL(&9A;'-E(&EF(&ET(&%L<F5A9'D@97AI<W1S#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V%D9$-H86YN96PH)&-H86YN96PL("1U<&1A=&4@
M/2!F86QS92P@)&QA<W1M;V1I9FEE9"`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@:68@*"%I<U]A*"1C:&%N;F5L+"`G4$5!4E]#:&%N;F5L1FEL92<I*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D8VAA;FYE;"T^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AF:6QE7V5X
M:7-T<R@D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D8VAA;FYE;"T^9V5T3F%M
M92@I*2DI('L-"B`@("`@("`@("`@(&EF("@A)'5P9&%T92D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1C:&5C:V5R(#T@)'1H:7,M/E]G971#:&%N;F5L*"1C:&%N;F5L
M+3YG971.86UE*"DI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&-H96-K97(I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1C:&5C:V5R
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L+3YG
M971!;&EA<R@I("$]("1C:&5C:V5R+3YG971!;&EA<R@I*2![#0H@("`@("`@
M("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7V=E=$-H86YN96Q!;&EA<T9I;&5.
M86UE*"1C:&5C:V5R+3YG971!;&EA<R@I*2D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H)'5P9&%T92`F)B`A
M:6Y?87)R87DH)&-H86YN96PM/F=E=$YA;64H*2P@87)R87DH)W!E87(N<&AP
M+FYE="<L("=P96-L+G!H<"YN970G*2DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)')E="`]("1T:&ES+3Y?87-S97)T0VAA;FYE;$1I<B@I.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?
M87-S97)T0VAA;FYE;%-T871E1&ER*"1C:&%N;F5L+3YG971.86UE*"DI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N
M;F5L+3YG971!;&EA<R@I("$]("1C:&%N;F5L+3YG971.86UE*"DI('L-"B`@
M("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&AI<RT^7V=E=$-H86YN96Q!
M;&EA<T9I;&5.86UE*"1C:&%N;F5L+3YG971!;&EA<R@I*2D@)B8-"B`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA
M;FYE;"T^9V5T06QI87,H*2D@(3T@)&-H86YN96PM/F=E=$YA;64H*2D@>PT*
M("`@("`@("`@("`@("`@("1C:&%N;F5L+3YS971!;&EA<R@D8VAA;FYE;"T^
M9V5T3F%M92@I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9G`@
M/2!`9F]P96XH)'1H:7,M/E]G971#:&%N;F5L06QI87-&:6QE3F%M92@D8VAA
M;FYE;"T^9V5T06QI87,H*2DL("=W)RD[#0H@("`@("`@("`@("!I9B`H(21F
M<"D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9W<FET92@D9G`L("1C:&%N;F5L+3YG971.
M86UE*"DI.PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1F
M<"`]($!F;W!E;B@D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D8VAA;FYE;"T^
M9V5T3F%M92@I*2P@)W=B)RD[#0H@("`@("`@(&EF("@A)&9P*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&EN
M9F\@/2`D8VAA;FYE;"T^=&]!<G)A>2@I.PT*("`@("`@("!I9B`H)&QA<W1M
M;V1I9FEE9"D@>PT*("`@("`@("`@("`@)&EN9F];)U]L87-T;6]D:69I960G
M72`]("1L87-T;6]D:69I960[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D:6YF;ULG7VQA<W1M;V1I9FEE9"==(#T@9&%T92@G<B<I.PT*("`@
M("`@("!]#0H@("`@("`@(&9W<FET92@D9G`L('-E<FEA;&EZ92@D:6YF;RDI
M.PT*("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]D96QE=&5#:&%N
M;F5L*"D-"@T*("`@("\J*@T*("`@("`J($1E;&5T:6]N(&9A:6QS(&EF('1H
M97)E(&%R92!A;GD@<&%C:V%G97,@:6YS=&%L;&5D(&9R;VT@=&AE(&-H86YN
M96P-"B`@("`@*B!`<&%R86T@<W1R:6YG?%!%05)?0VAA;FYE;$9I;&4@8VAA
M;FYE;"!N86UE#0H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@
M5')U92!O;B!D96QE=&EO;BP@9F%L<V4@:68@:70@9&]E<VXG="!E>&ES=`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]D96QE=&5#:&%N;F5L*"1C:&%N;F5L
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]S=')I;F<H)&-H86YN96PI*2![
M#0H@("`@("`@("`@("!I9B`H:7-?82@D8VAA;FYE;"P@)U!%05)?0VAA;FYE
M;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A)&-H86YN96PM/G9A
M;&ED871E*"DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D8VAA;FYE
M;"`]("1C:&%N;F5L+3YG971.86UE*"D[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]G971#:&%N;F5L
M1G)O;4%L:6%S*"1C:&%N;F5L*2`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES
M+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@)W!E8VPN<&AP
M+FYE="<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(21T:&ES+3Y?8VAA;FYE;$5X:7-T<R@D8VAA;FYE
M;"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(21C:&%N;F5L('Q\("1T:&ES+3Y?9V5T0VAA;FYE;$9R
M;VU!;&EA<R@D8VAA;FYE;"D@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D8VAA
M;FYE;"`]("1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D[
M#0H@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M("1T97-T(#T@)'1H:7,M/E]L:7-T0VAA;FYE;%!A8VMA9V5S*"1C:&%N;F5L
M*3L-"B`@("`@("`@:68@*&-O=6YT*"1T97-T*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T97-T(#T@0')M
M9&ER*"1T:&ES+3Y?8VAA;FYE;$1I<F5C=&]R>4YA;64H)&-H86YN96PI*3L-
M"B`@("`@("`@:68@*"$D=&5S="D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1F:6QE(#T@)'1H:7,M/E]G971#
M:&%N;F5L06QI87-&:6QE3F%M92@D=&AI<RT^7V=E=$%L:6%S*"1C:&%N;F5L
M*2D[#0H@("`@("`@(&EF("A`9FEL95]E>&ES=',H)&9I;&4I*2![#0H@("`@
M("`@("`@("`D=&5S="`]($!U;FQI;FLH)&9I;&4I.PT*("`@("`@("`@("`@
M:68@*"$D=&5S="D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D9FEL92`]("1T
M:&ES+3Y?8VAA;FYE;$9I;&5.86UE*"1C:&%N;F5L*3L-"B`@("`@("`@)')E
M="`]($!U;FQI;FLH)&9I;&4I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7VES0VAA;FYE;$%L:6%S
M*"D-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W:&5T:&5R(&$@8VAA
M;FYE;"!E>&ES=',@:6X@=&AE(')E9VES=')Y#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!#:&%N;F5L($%L:6%S#0H@("`@("H@0')E='5R;B!B;V]L96%N#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7VES0VAA;FYE;$%L:6%S*"1A;&EA<RD-
M"B`@("![#0H@("`@("`@(')E='5R;B!F:6QE7V5X:7-T<R@D=&AI<RT^7V=E
M=$-H86YN96Q!;&EA<T9I;&5.86UE*"1A;&EA<RDI.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!?<&%C:V%G94EN9F\H*0T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('-T<FEN9WQN=6QL#0H@("`@("H@0'!A<F%M('-T
M<FEN9WQN=6QL#0H@("`@("H@0'!A<F%M('-T<FEN9WQN=6QL#0H@("`@("H@
M0')E='5R;B!A<G)A>7QN=6QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7W!A8VMA9V5);F9O*"1P86-K86=E(#T@
M;G5L;"P@)&ME>2`](&YU;&PL("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<I
M#0H@("`@>PT*("`@("`@("!I9B`H)'!A8VMA9V4@/3T](&YU;&PI('L-"B`@
M("`@("`@("`@(&EF("@D8VAA;FYE;"`]/3T@;G5L;"D@>PT*("`@("`@("`@
M("`@("`@("1C:&%N;F5L<R`]("1T:&ES+3Y?;&ES=$-H86YN96QS*"D[#0H@
M("`@("`@("`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&-H86YN96QS(&%S("1C:&%N;F5L*2![#0H@("`@("`@
M("`@("`@("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D8VAA;FYE;"D[
M#0H@("`@("`@("`@("`@("`@("`@("1R971;)&-H86YN96Q=(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5S(#T@)'1H:7,M/E]L
M:7-T4&%C:V%G97,H)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<&%C:V%G97,@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R971;)&-H86YN96Q=6UT@/2`D=&AI<RT^7W!A8VMA
M9V5);F9O*"1P86-K86=E+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M<',@/2`D=&AI<RT^7VQI<W1086-K86=E<R@D8VAA;FYE;"D[#0H@("`@("`@
M("`@("!I9B`H(6-O=6YT*"1P<RDI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@87)R87DH*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R
M;B!A<G)A>5]M87`H87)R87DH)B1T:&ES+"`G7W!A8VMA9V5);F9O)RDL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<RP@87)R87E?9FEL;"@P
M+"!C;W5N="@D<',I+"!N=6QL*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87E?9FEL;"@P+"!C;W5N="@D<',I+"`D8VAA;FYE;"DI.PT*
M("`@("`@("!]#0H@("`@("`@("1F<"`]("1T:&ES+3Y?;W!E;E!A8VMA9V5&
M:6QE*"1P86-K86=E+"`G<B<L("1C:&%N;F5L*3L-"B`@("`@("`@:68@*"1F
M<"`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@
M("`@('T-"B`@("`@("`@)')T(#T@9V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE
M*"D[#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@P*3L-"B`@
M("`@("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]C;&]S95!A8VMA9V5&:6QE*"1F<"D[#0H@("`@("`@("`@("`D
M9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1T:&ES+3Y?<&%C:V%G949I;&5.
M86UE*"1P86-K86=E+"`D8VAA;FYE;"DI.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1T:&ES
M+3Y?<&%C:V%G949I;&5.86UE*"1P86-K86=E+"`D8VAA;FYE;"DI*3L-"B`@
M("`@("`@("`@("1T:&ES+3Y?8VQO<V5086-K86=E1FEL92@D9G`I.PT*("`@
M("`@("!]#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@D<G0I
M.PT*("`@("`@("`D9&%T82`]('5N<V5R:6%L:7IE*"1D871A*3L-"B`@("`@
M("`@:68@*"1K97D@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B`D
M9&%T83L-"B`@("`@("`@?0T*("`@("`@("`O+R!C;VUP871I8FEL:71Y(&9O
M<B!P86-K86=E+GAM;"!V97)S:6]N(#(N,`T*("`@("`@("!I9B`H:7-S970H
M)&1A=&%;)V]L9"==6R1K97E=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1D
M871A6R=O;&0G75LD:V5Y73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&1A=&%;)&ME>5TI*2![#0H@("`@("`@("`@("!R971U<FX@)&1A=&%;
M)&ME>5T[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]C:&%N;F5L26YF;R@I#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG($-H86YN96P@;F%M90T*
M("`@("`J($!P87)A;2!B;V]L('=H971H97(@=&\@<W1R:6-T;'D@<F5T<FEE
M=F4@:6YF;R!O9B!C:&%N;F5L<RP@;F]T(&IU<W0@86QI87-E<PT*("`@("`J
M($!R971U<FX@87)R87E\;G5L;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C
M:&%N;F5L26YF;R@D8VAA;FYE;"P@)&YO86QI87-E<R`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@:68@*"$D=&AI<RT^7V-H86YN96Q%>&ES=',H)&-H86YN
M96PL("1N;V%L:6%S97,I*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-
M"B`@("`@("`@?0T*("`@("`@("`D9G`@/2`D=&AI<RT^7V]P96Y#:&%N;F5L
M1FEL92@D8VAA;FYE;"P@)W(G*3L-"B`@("`@("`@:68@*"1F<"`]/3T@;G5L
M;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@
M("`@("`@)')T(#T@9V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"D[#0H@("`@
M("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@P*3L-"B`@("`@("`@8VQE
M87)S=&%T8V%C:&4H*3L-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G
M9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]C
M;&]S94-H86YN96Q&:6QE*"1F<"D[#0H@("`@("`@("`@("`D9&%T82`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1T:&ES+3Y?8VAA;FYE;$9I;&5.86UE*"1C:&%N
M;F5L*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9&%T82`]
M(&9R96%D*"1F<"P@9FEL97-I>F4H)'1H:7,M/E]C:&%N;F5L1FEL94YA;64H
M)&-H86YN96PI*2D[#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E0VAA;FYE
M;$9I;&4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("!S971?;6%G:6-?<75O
M=&5S7W)U;G1I;64H)')T*3L-"B`@("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ
M92@D9&%T82D[#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7VQI<W1#:&%N;F5L<R@I#0H-"B`@("!F
M=6YC=&EO;B!?;&ES=$-H86YN96QS*"D-"B`@("![#0H@("`@("`@("1C:&%N
M;F5L;&ES="`](&%R<F%Y*"D[#0H@("`@("`@("1D<"`]($!O<&5N9&ER*"1T
M:&ES+3YC:&%N;F5L<V1I<BD[#0H@("`@("`@(&EF("@A)&1P("!\?"`A0&ES
M7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(I*2![#0H@("`@("`@("`@("!R971U
M<FX@87)R87DH)W!E87(N<&AP+FYE="<L("=P96-L+G!H<"YN970G+"`G7U]U
M<FDG*3L-"B`@("`@("`@?0T*("`@("`@("!W:&EL92`H)&5N="`](')E861D
M:7(H)&1P*2D@>PT*("`@("`@("`@("`@:68@*"1E;G1[,'T@/3T@)RXG('Q\
M('-U8G-T<B@D96YT+"`M-"D@(3T@)RYR96<G*2![#0H@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M)&5N="`]/2`G7U]U<FDN<F5G)RD@>PT*("`@("`@("`@("`@("`@("1C:&%N
M;F5L;&ES=%M=(#T@)U]?=7)I)SL-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C:&%N;F5L;&ES=%M=
M(#T@<W1R7W)E<&QA8V4H)U\G+"`G+R<L('-U8G-T<B@D96YT+"`P+"`M-"DI
M.PT*("`@("`@("!]#0H@("`@("`@(&-L;W-E9&ER*"1D<"D[#0H@("`@("`@
M(&EF("@A:6Y?87)R87DH)W!E87(N<&AP+FYE="<L("1C:&%N;F5L;&ES="DI
M('L-"B`@("`@("`@("`@("1C:&%N;F5L;&ES=%M=(#T@)W!E87(N<&AP+FYE
M="<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I;E]A<G)A>2@G<&5C;"YP
M:'`N;F5T)RP@)&-H86YN96QL:7-T*2D@>PT*("`@("`@("`@("`@)&-H86YN
M96QL:7-T6UT@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6EN7V%R<F%Y*"=?7W5R:2<L("1C:&%N;F5L;&ES="DI('L-"B`@
M("`@("`@("`@("1C:&%N;F5L;&ES=%M=(#T@)U]?=7)I)SL-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)&-H86YN96QL:7-T.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!?;&ES=%!A8VMA9V5S*"D-"@T*("`@(&9U
M;F-T:6]N(%]L:7-T4&%C:V%G97,H)&-H86YN96P@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@D8VAA;FYE;"`F)B`D=&AI<RT^7V=E=$-H86YN96Q&
M<F]M06QI87,H)&-H86YN96PI("$]("=P96%R+G!H<"YN970G*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]L:7-T0VAA;FYE;%!A8VMA9V5S*"1C
M:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("`D<&MG;&ES="`](&%R<F%Y
M*"D[#0H@("`@("`@("1D<"`]($!O<&5N9&ER*"1T:&ES+3YS=&%T961I<BD[
M#0H@("`@("`@(&EF("@A)&1P*2![#0H@("`@("`@("`@("!R971U<FX@)'!K
M9VQI<W0[#0H@("`@("`@('T-"B`@("`@("`@=VAI;&4@*"1E;G0@/2!R96%D
M9&ER*"1D<"DI('L-"B`@("`@("`@("`@(&EF("@D96YT>S!](#T]("<N)R!\
M?"!S=6)S='(H)&5N="P@+30I("$]("<N<F5G)RD@>PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!K
M9VQI<W1;72`]('-U8G-T<B@D96YT+"`P+"`M-"D[#0H@("`@("`@('T-"B`@
M("`@("`@8VQO<V5D:7(H)&1P*3L-"B`@("`@("`@<F5T=7)N("1P:V=L:7-T
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?;&ES=$-H86YN
M96Q086-K86=E<R@I#0H-"B`@("!F=6YC=&EO;B!?;&ES=$-H86YN96Q086-K
M86=E<R@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@("1P:V=L:7-T(#T@87)R
M87DH*3L-"B`@("`@("`@)&1P(#T@0&]P96YD:7(H)'1H:7,M/E]C:&%N;F5L
M1&ER96-T;W)Y3F%M92@D8VAA;FYE;"DI.PT*("`@("`@("!I9B`H(21D<"D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1P:V=L:7-T.PT*("`@("`@("!]#0H@
M("`@("`@('=H:6QE("@D96YT(#T@<F5A9&1I<B@D9'`I*2![#0H@("`@("`@
M("`@("!I9B`H)&5N='LP?2`]/2`G+B<@?'P@<W5B<W1R*"1E;G0L("TT*2`A
M/2`G+G)E9R<I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1P:V=L:7-T6UT@/2!S=6)S='(H)&5N
M="P@,"P@+30I.PT*("`@("`@("!]#0H@("`@("`@(&-L;W-E9&ER*"1D<"D[
M#0H@("`@("`@(')E='5R;B`D<&MG;&ES=#L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`-"B`@("!F=6YC=&EO;B!?;&ES=$%L;%!A8VMA9V5S*"D-"B`@
M("![#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7VQI<W1#:&%N;F5L<R@I(&%S("1C:&%N;F5L*2![#0H@("`@
M("`@("`@("`D<F5T6R1C:&%N;F5L72`]("1T:&ES+3Y?;&ES=%!A8VMA9V5S
M*"1C:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@86X@:6YS=&%L;&5D('!A
M8VMA9V4@=&\@=&AE(')E9VES=')Y#0H@("`@("H@0'!A<F%M('-T<FEN9R!P
M86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@87)R87D@<&%C:V%G92!I;F9O
M("AP87)S960@8GD@4$5!4E]#;VUM;VXZ.FEN9F]&<F]M*B@I(&UE=&AO9',I
M#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@<V%V:6YG#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V%D
M9%!A8VMA9V4H)'!A8VMA9V4L("1I;F9O*0T*("`@('L-"B`@("`@("`@:68@
M*"1T:&ES+3Y?<&%C:V%G945X:7-T<R@D<&%C:V%G92DI('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9G`@/2`D
M=&AI<RT^7V]P96Y086-K86=E1FEL92@D<&%C:V%G92P@)W=B)RD[#0H@("`@
M("`@(&EF("@D9G`@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;ULG7VQA<W1M;V1I9FEE
M9"==(#T@=&EM92@I.PT*("`@("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H
M)&EN9F\I*3L-"B`@("`@("`@)'1H:7,M/E]C;&]S95!A8VMA9V5&:6QE*"1F
M<"D[#0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG9FEL96QI<W0G72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?<F5B=6EL9$9I;&5-87`H*3L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA
M9V5&:6QE7W8R#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V%D9%!A8VMA9V4R
M*"1I;F9O*0T*("`@('L-"B`@("`@("`@:68@*"$D:6YF;RT^=F%L:61A=&4H
M*2D@>PT*("`@("`@("`@("`@:68@*&-L87-S7V5X:7-T<R@G4$5!4E]#;VUM
M;VXG*2D@>PT*("`@("`@("`@("`@("`@("1U:2`](%!%05)?1G)O;G1E;F0Z
M.G-I;F=L971O;B@I.PT*("`@("`@("`@("`@("`@(&EF("@D=6DI('L-"B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN9F\M/F=E=%9A;&ED871I
M;VY787)N:6YG<R@I(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1U:2T^;&]G*#(L("1E<G);)VUE<W-A9V4G72D[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@)&-H86YN96P@/2`D:6YF;RT^9V5T0VAA;FYE;"@I.PT*("`@("`@("`D
M<&%C:V%G92`]("1I;F9O+3YG971086-K86=E*"D[#0H@("`@("`@("1S879E
M(#T@)&EN9F\[#0H@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5%>&ES=',H
M)'!A8VMA9V4L("1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/E]C:&%N;F5L
M17AI<W1S*"1C:&%N;F5L+"!T<G5E*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O(#T@)&EN9F\M/G1O
M07)R87DH=')U92D[#0H@("`@("`@(&EF("@A)&EN9F\I('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9G`@/2`D
M=&AI<RT^7V]P96Y086-K86=E1FEL92@D<&%C:V%G92P@)W=B)RP@)&-H86YN
M96PI.PT*("`@("`@("!I9B`H)&9P(#T]/2!N=6QL*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)U]L
M87-T;6]D:69I960G72`]('1I;64H*3L-"B`@("`@("`@9G=R:71E*"1F<"P@
M<V5R:6%L:7IE*"1I;F9O*2D[#0H@("`@("`@("1T:&ES+3Y?8VQO<V5086-K
M86=E1FEL92@D9G`I.PT*("`@("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P
M*"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!S=')I;F<@4&%C:V%G92!N86UE#0H@("`@("H@0'!A
M<F%M(&%R<F%Y('!A<G-E9"!P86-K86=E+GAM;"`Q+C`-"B`@("`@*B!`<&%R
M86T@8F]O;"!T:&ES('!A<F%M971E<B!I<R!O;FQY(&AE<F4@9F]R($)#+B`@
M1&]N)W0@=7-E(&ET+@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]U<&1A=&5086-K86=E*"1P86-K86=E+"`D:6YF
M;RP@)&UE<F=E(#T@=')U92D-"B`@("![#0H@("`@("`@("1O;&1I;F9O(#T@
M)'1H:7,M/E]P86-K86=E26YF;R@D<&%C:V%G92D[#0H@("`@("`@(&EF("AE
M;7!T>2@D;VQD:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D9G`@/2`D=&AI<RT^7V]P96Y086-K86=E
M1FEL92@D<&%C:V%G92P@)W<G*3L-"B`@("`@("`@:68@*"1F<"`]/3T@;G5L
M;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<U]O8FIE8W0H)&EN9F\I*2![#0H@("`@("`@("`@("`D
M:6YF;R`]("1I;F9O+3YT;T%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@
M)&EN9F];)U]L87-T;6]D:69I960G72`]('1I;64H*3L-"B`@("`@("`@)&YE
M=VEN9F\@/2`D:6YF;SL-"B`@("`@("`@:68@*"1M97)G92D@>PT*("`@("`@
M("`@("`@)&EN9F\@/2!A<G)A>5]M97)G92@D;VQD:6YF;RP@)&EN9F\I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1I9F8@/2`D:6YF;SL-
M"B`@("`@("`@?0T*("`@("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&EN
M9F\I*3L-"B`@("`@("`@)'1H:7,M/E]C;&]S95!A8VMA9V5&:6QE*"1F<"D[
M#0H@("`@("`@(&EF("AI<W-E="@D;F5W:6YF;ULG9FEL96QI<W0G72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?<F5B=6EL9$9I;&5-87`H*3L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA
M9V5&:6QE7W8R#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5P9&%T95!A8VMA
M9V4R*"1I;F9O*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7W!A8VMA
M9V5%>&ES=',H)&EN9F\M/F=E=%!A8VMA9V4H*2P@)&EN9F\M/F=E=$-H86YN
M96PH*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D9G`@/2`D=&AI<RT^7V]P96Y086-K86=E1FEL92@D:6YF
M;RT^9V5T4&%C:V%G92@I+"`G=R<L("1I;F9O+3YG971#:&%N;F5L*"DI.PT*
M("`@("`@("!I9B`H)&9P(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'-A=F4@/2`D:6YF;SL-
M"B`@("`@("`@)&EN9F\@/2`D<V%V92T^9V5T07)R87DH=')U92D[#0H@("`@
M("`@("1I;F9O6R=?;&%S=&UO9&EF:65D)UT@/2!T:6UE*"D[#0H@("`@("`@
M(&9W<FET92@D9G`L('-E<FEA;&EZ92@D:6YF;RDI.PT*("`@("`@("`D=&AI
M<RT^7V-L;W-E4&%C:V%G949I;&4H)&9P*3L-"B`@("`@("`@)'1H:7,M/E]R
M96)U:6QD1FEL94UA<"@I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(%!A8VMA9V4@;F%M
M90T*("`@("`J($!P87)A;2!S=')I;F<@0VAA;FYE;"!N86UE#0H@("`@("H@
M0')E='5R;B!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?
M=C)\;G5L;`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N("9?9V5T4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96P@/2`G
M<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@("`@("1I;F9O(#T@)'1H:7,M
M/E]P86-K86=E26YF;R@D<&%C:V%G92P@;G5L;"P@)&-H86YN96PI.PT*("`@
M("`@("!I9B`H)&EN9F\@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R
M;B`D:6YF;SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("1T:&ES+3Y?8V]N
M9FEG.PT*("`@("`@("!I9B`H(21A*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7V-O;F9I9R`]("9N97<@4$5!4E]#;VYF:6<[#0H@("`@("`@("`@("`D=&AI
M<RT^7V-O;F9I9RT^<V5T*"=P:'!?9&ER)RP@)'1H:7,M/G-T871E9&ER*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]0
M86-K86=E1FEL92<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D<&MG
M(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES+3Y?8V]N9FEG*3L-"B`@
M("`@("`@)'!F(#T@)B1P:V<M/F9R;VU!<G)A>2@D:6YF;RD[#0H@("`@("`@
M(')E='5R;B`D<&8[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T
M:&5R('1O('-T<FEC=&QY(')E=')I979E(&-H86YN96P@;F%M97,-"B`@("`@
M*B!`<F5T=7)N(%!%05)?0VAA;FYE;$9I;&5\4$5!4E]%<G)O<@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N("9?9V5T
M0VAA;FYE;"@D8VAA;FYE;"P@)&YO86QI87-E<R`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)&-H(#T@9F%L<V4[#0H@("`@("`@(&EF("@D=&AI<RT^7V-H
M86YN96Q%>&ES=',H)&-H86YN96PL("1N;V%L:6%S97,I*2![#0H@("`@("`@
M("`@("`D8VAI;F9O(#T@)'1H:7,M/E]C:&%N;F5L26YF;R@D8VAA;FYE;"P@
M)&YO86QI87-E<RD[#0H@("`@("`@("`@("!I9B`H)&-H:6YF;RD@>PT*("`@
M("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&
M:6QE)RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1C:"`]("9014%27T-H86YN96Q&:6QE.CIF<F]M07)R
M87E7:71H17)R;W)S*"1C:&EN9F\I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("@D8V@I('L-"B`@("`@("`@("`@(&EF("@D8V@M
M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&-H.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&-H+3YG971%
M<G)O<G,H=')U92D@87,@)&5R<BD@>PT*("`@("`@("`@("`@("`@("1M97-S
M86=E(#T@)&5R<ELG;65S<V%G92==("X@(EQN(CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1C:"`](%!%05(Z.G)A:7-E17)R;W(H)&UE<W-A9V4I
M.PT*("`@("`@("`@("`@<F5T=7)N("1C:#L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L*2`]
M/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@+R\@=&AE(')E9VES
M=')Y(&ES(&YO="!P<F]P97)L>2!S970@=7`L('-O('5S92!D969A=6QT<PT*
M("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I
M;&4G*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#
M:&%N;F5L1FEL92YP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'!E87)?8VAA;FYE;"`](&YE=R!014%27T-H86YN96Q&:6QE.PT*("`@("`@
M("`@("`@)'!E87)?8VAA;FYE;"T^<V5T3F%M92@G<&5A<BYP:'`N;F5T)RD[
M#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971!;&EA<R@G<&5A<B<I
M.PT*("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T4W5M;6%R>2@G4$A0
M($5X=&5N<VEO;B!A;F0@07!P;&EC871I;VX@4F5P;W-I=&]R>2<I.PT*("`@
M("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T1&5F875L=%!%05)0<F]T;V-O
M;',H*3L-"B`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$)A<V554DPH
M)U)%4U0Q+C`G+"`G:'1T<#HO+W!E87(N<&AP+FYE="]R97-T+R<I.PT*("`@
M("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T0F%S95523"@G4D535#$N,2<L
M("=H='1P.B\O<&5A<BYP:'`N;F5T+W)E<W0O)RD[#0H@("`@("`@("`@("!R
M971U<FX@)'!E87)?8VAA;FYE;#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L*2`]/2`G<&5C
M;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@+R\@=&AE(')E9VES=')Y(&ES
M(&YO="!P<F]P97)L>2!S970@=7`L('-O('5S92!D969A=6QT<PT*("`@("`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@
M>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L
M1FEL92YP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!E87)?
M8VAA;FYE;"`](&YE=R!014%27T-H86YN96Q&:6QE.PT*("`@("`@("`@("`@
M)'!E87)?8VAA;FYE;"T^<V5T3F%M92@G<&5C;"YP:'`N;F5T)RD[#0H@("`@
M("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971!;&EA<R@G<&5C;"<I.PT*("`@
M("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T4W5M;6%R>2@G4$A0($5X=&5N
M<VEO;B!#;VUM=6YI='D@3&EB<F%R>2<I.PT*("`@("`@("`@("`@)'!E87)?
M8VAA;FYE;"T^<V5T1&5F875L=%!%05)0<F]T;V-O;',H*3L-"B`@("`@("`@
M("`@("1P96%R7V-H86YN96PM/G-E=$)A<V554DPH)U)%4U0Q+C`G+"`G:'1T
M<#HO+W!E8VPN<&AP+FYE="]R97-T+R<I.PT*("`@("`@("`@("`@)'!E87)?
M8VAA;FYE;"T^<V5T0F%S95523"@G4D535#$N,2<L("=H='1P.B\O<&5C;"YP
M:'`N;F5T+W)E<W0O)RD[#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS
M971686QI9&%T:6]N4&%C:V%G92@G4$5!4E]686QI9&%T;W)?4$5#3"<L("<Q
M+C`G*3L-"B`@("`@("`@("`@(')E='5R;B`D<&5A<E]C:&%N;F5L.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI
M87,H)&-H86YN96PI(#T]("=?7W5R:2<I('L-"B`@("`@("`@("`@("\O('1H
M92!R96=I<W1R>2!I<R!N;W0@<')O<&5R;'D@<V5T('5P+"!S;R!U<V4@9&5F
M875L=',-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H
M86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1P<FEV871E(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@
M("`@("`@("`D<')I=F%T92T^<V5T3F%M92@G7U]U<FDG*3L-"B`@("`@("`@
M("`@("1P<FEV871E+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("<J
M*BHJ)RD[#0H@("`@("`@("`@("`D<')I=F%T92T^<V5T4W5M;6%R>2@G4'-E
M=61O+6-H86YN96P@9F]R('-T871I8R!P86-K86=E<R<I.PT*("`@("`@("`@
M("`@<F5T=7)N("1P<FEV871E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D8V@[#0H@("`@?0T*#0H@("`@+R\@>WM[('!A8VMA9V5%>&ES=',H*0T*
M#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!086-K86=E(&YA;64-
M"B`@("`@*B!`<&%R86T@<W1R:6YG($-H86YN96P@;F%M90T*("`@("`J($!R
M971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N('!A8VMA9V5%>&ES
M=',H)'!A8VMA9V4L("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<I#0H@("`@
M>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C
M:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@
M("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]P86-K86=E17AI<W1S*"1P
M86-K86=E+"`D8VAA;FYE;"D[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&-H86YN96Q%>&ES=',H*0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@("`@*B!`<&%R86T@
M8F]O;"!I9B!T<G5E+"!T:&5N(&%L:6%S97,@=VEL;"!B92!I9VYO<F5D#0H@
M("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAA
M;FYE;$5X:7-T<R@D8VAA;FYE;"P@)&YO86QI87-E<R`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO
M8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@
M("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?8VAA;FYE;$5X:7-T<R@D
M8VAA;FYE;"P@)&YO86QI87-E<RD[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K
M*"D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(&ES06QI87,H*0T*#0H@("`@+RHJ#0H@("`@("H@
M1&5T97)M:6YE<R!W:&5T:&5R('1H92!P87)A;65T97(@:7,@86X@86QI87,@
M;V8@82!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R
M971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES06QI87,H)&%L
M:6%S*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D
M=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R971U<FX@
M)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?:7-#:&%N
M;F5L06QI87,H)&%L:6%S*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-
M"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[('!A8VMA9V5);F9O*"D-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F=\;G5L;`T*("`@("`J($!P87)A;2!S=')I;F=\;G5L;`T*
M("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&YU
M;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P86-K86=E26YF;R@D<&%C:V%G
M92`](&YU;&PL("1K97D@/2!N=6QL+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN
M970G*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D
M=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R971U<FX@
M)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?<&%C:V%G
M94EN9F\H)'!A8VMA9V4L("1K97DL("1C:&%N;F5L*3L-"B`@("`@("`@)'1H
M:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-H86YN96Q);F9O*"D-"@T*("`@
M("\J*@T*("`@("`J(%)E=')I979E(&$@<F%W(&%R<F%Y(&]F(&-H86YN96P@
M9&%T82X-"B`@("`@*@T*("`@("`J($1O(&YO="!U<V4@=&AI<RP@:6YS=&5A
M9"!U<V4@>T!L:6YK(&=E=$-H86YN96PH*7T@9F]R(&YO<FUA;`T*("`@("`J
M(&]P97)A=&EO;G,N("!!<G)A>2!S=')U8W1U<F4@:7,@=6YD969I;F5D(&EN
M('1H:7,@;65T:&]D#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA
M;64-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T:&5R('1O('-T<FEC=&QY(')E
M=')I979E(&EN9F]R;6%T:6]N(&]N;'D@;VX@;F]N+6%L:6%S97,-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y?&YU;&Q\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&-H86YN96Q);F9O*"1C:&%N;F5L(#T@;G5L;"P@)&YO86QI
M87-E<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@
M("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES
M+3Y?8VAA;FYE;$EN9F\H)&-H86YN96PL("1N;V%L:6%S97,I.PT*("`@("`@
M("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S
M=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C:&%N;F5L3F%M92@D8VAA
M;FYE;"D-"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@
M)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7V=E=$-H
M86YN96Q&<F]M06QI87,H)&-H86YN96PI.PT*("`@("`@("`D=&AI<RT^7W5N
M;&]C:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@8VAA;FYE;$%L:6%S*"1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![
M#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@
M)')E="`]("1T:&ES+3Y?9V5T06QI87,H)&-H86YN96PI.PT*("`@("`@("`D
M=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]
M#0H@("`@+R\@>WM[(&QI<W1086-K86=E<R@I#0H-"B`@("!F=6YC=&EO;B!L
M:7-T4&%C:V%G97,H)&-H86YN96P@/2!F86QS92D-"B`@("![#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@
M("`@("1R970@/2`D=&AI<RT^7VQI<W1086-K86=E<R@D8VAA;FYE;"D[#0H@
M("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@(')E='5R;B`D<F5T
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!L:7-T06QL4&%C
M:V%G97,H*0T*#0H@("`@9G5N8W1I;VX@;&ES=$%L;%!A8VMA9V5S*"D-"B`@
M("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L
M;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@
M("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7VQI<W1!;&Q086-K86=E
M<R@I.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;&ES
M=$-H86YN96PH*0T*#0H@("`@9G5N8W1I;VX@;&ES=$-H86YN96QS*"D-"B`@
M("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L
M;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@
M("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7VQI<W1#:&%N;F5L<R@I
M.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@
M)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@861D4&%C
M:V%G92@I#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@86X@:6YS=&%L;&5D('!A
M8VMA9V4@=&\@=&AE(')E9VES=')Y#0H@("`@("H@0'!A<F%M('-T<FEN9WQ0
M14%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(@<&%C:V%G
M92!N86UE(&]R(&]B:F5C=`T*("`@("`J("`@("`@("`@("`@("`@=&AA="!W
M:6QL(&)E('!A<W-E9"!T;R![0&QI;FL@861D4&%C:V%G93(H*7T-"B`@("`@
M*B!`<&%R86T@87)R87D@<&%C:V%G92!I;F9O("AP87)S960@8GD@4$5!4E]#
M;VUM;VXZ.FEN9F]&<F]M*B@I(&UE=&AO9',I#0H@("`@("H@0')E='5R;B!B
M;V]L('-U8V-E<W,@;V8@<V%V:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D4&%C:V%G92@D<&%C:V%G92P@)&EN9F\I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1I;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YA9&1086-K86=E,B@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]%6"DI
M*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@
M("`@)')E="`]("1T:&ES+3Y?861D4&%C:V%G92@D<&%C:V%G92P@)&EN9F\I
M.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!I9B`H)')E
M="D@>PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C
M:V%G949I;&5?=C$G*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G4$5!4B]086-K86=E1FEL92]V,2YP:'`G.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C$[#0H@
M("`@("`@("`@("`D<&8M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@
M("`@("`@("`@("`D<&8M/F9R;VU!<G)A>2@D:6YF;RD[#0H@("`@("`@("`@
M("`D=&AI<RT^7V1E<&5N9&5N8WE$0BT^=6YI;G-T86QL4&%C:V%G92@D<&8I
M.PT*("`@("`@("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y1$(M/FEN<W1A;&Q0
M86-K86=E*"1P9BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9%!A8VMA9V4R
M*"D-"@T*("`@(&9U;F-T:6]N(&%D9%!A8VMA9V4R*"1I;F9O*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)&EN9F\I*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F%D9%!A8VMA9V4H)&EN9F];)W!A8VMA9V4G72P@
M)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?15@I*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^
M7V%D9%!A8VMA9V4R*"1I;F9O*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH
M*3L-"B`@("`@("`@:68@*"1R970I('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M9&5P96YD96YC>41"+3YU;FEN<W1A;&Q086-K86=E*"1I;F9O*3L-"B`@("`@
M("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YI;G-T86QL4&%C:V%G92@D
M:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('5P9&%T94-H86YN96PH*0T*
M#0H@("`@+RHJ#0H@("`@("H@1F]R(&9U='5R92!E>'!A;F1I8FEL:71Y('!U
M<G!O<V5S+"!S97!A<F%T92!T:&ES#0H@("`@("H@0'!A<F%M(%!%05)?0VAA
M;FYE;$9I;&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!U<&1A=&5#:&%N;F5L
M*"1C:&%N;F5L+"`D;&%S=&UO9&EF:65D(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("@D8VAA;FYE;"T^9V5T3F%M92@I(#T]("=?7W5R:2<I('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)'1H:7,M/F%D9$-H86YN96PH)&-H86YN96PL("1L87-T;6]D:69I
M960L('1R=64I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D
M96QE=&5#:&%N;F5L*"D-"@T*("`@("\J*@T*("`@("`J($1E;&5T:6]N(&9A
M:6QS(&EF('1H97)E(&%R92!A;GD@<&%C:V%G97,@:6YS=&%L;&5D(&9R;VT@
M=&AE(&-H86YN96P-"B`@("`@*B!`<&%R86T@<W1R:6YG?%!%05)?0VAA;FYE
M;$9I;&4@8VAA;FYE;"!N86UE#0H@("`@("H@0')E='5R;B!B;V]L96%N?%!%
M05)?17)R;W(@5')U92!O;B!D96QE=&EO;BP@9F%L<V4@:68@:70@9&]E<VXG
M="!E>&ES=`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&1E;&5T94-H86YN96PH
M)&-H86YN96PI#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]D
M96QE=&5#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO
M8VLH*3L-"B`@("`@("`@:68@*"1R970@)B8@:7-?82@D=&AI<RT^7V-O;F9I
M9RP@)U!%05)?0V]N9FEG)RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M9FEG+3YS971#:&%N;F5L<R@D=&AI<RT^;&ES=$-H86YN96QS*"DI.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!A9&1#:&%N;F5L*"D-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!014%27T-H86YN96Q&:6QE($-H86YN96P@;V)J96-T#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!,87-T+4UO9&EF:65D(&AE861E<B!F<F]M
M($A45%`@9F]R(&-A8VAI;F<-"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!
M4E]%<G)O<B!4<G5E(&]N(&-R96%T:6]N+"!F86QS92!I9B!I="!A;')E861Y
M(&5X:7-T<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-H86YN96PH)&-H
M86YN96PL("1L87-T;6]D:69I960@/2!F86QS92P@)'5P9&%T92`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]A*"1C:&%N;F5L+"`G4$5!4E]#
M:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"$D8VAA;FYE;"T^=F%L:61A=&4H*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?
M15@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@
M("`@("`@("1R970@/2`D=&AI<RT^7V%D9$-H86YN96PH)&-H86YN96PL("1U
M<&1A=&4L("1L87-T;6]D:69I960I.PT*("`@("`@("`D=&AI<RT^7W5N;&]C
M:R@I.PT*("`@("`@("!I9B`H(21U<&1A=&4@)B8@)')E="`F)B!I<U]A*"1T
M:&ES+3Y?8V]N9FEG+"`G4$5!4E]#;VYF:6<G*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]C;VYF:6<M/G-E=$-H86YN96QS*"1T:&ES+3YL:7-T0VAA;FYE
M;',H*2D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1E;&5T95!A8VMA9V4H*0T*
M#0H@("`@9G5N8W1I;VX@9&5L971E4&%C:V%G92@D<&%C:V%G92P@)&-H86YN
M96P@/2`G<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?15@I*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1F:6QE
M(#T@)'1H:7,M/E]P86-K86=E1FEL94YA;64H)'!A8VMA9V4L("1C:&%N;F5L
M*3L-"B`@("`@("`@)')E="`]($!U;FQI;FLH)&9I;&4I.PT*("`@("`@("`D
M=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@("`@("`@("1T:&ES+3Y?=6YL
M;V-K*"D[#0H@("`@("`@("1P(#T@87)R87DH)V-H86YN96PG(#T^("1C:&%N
M;F5L+"`G<&%C:V%G92<@/3X@)'!A8VMA9V4I.PT*("`@("`@("`D=&AI<RT^
M7V1E<&5N9&5N8WE$0BT^=6YI;G-T86QL4&%C:V%G92@D<"D[#0H@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!U<&1A=&5086-K86=E*"D-"@T*("`@(&9U;F-T:6]N('5P9&%T95!A8VMA
M9V4H)'!A8VMA9V4L("1I;F9O+"`D;65R9V4@/2!T<G5E*0T*("`@('L-"B`@
M("`@("`@:68@*&ES7V]B:F5C="@D:6YF;RDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^=7!D871E4&%C:V%G93(H)&EN9F\L("1M97)G92D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI
M<RT^7VQO8VLH3$]#2U]%6"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[
M#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?=7!D871E4&%C
M:V%G92@D<&%C:V%G92P@)&EN9F\L("1M97)G92D[#0H@("`@("`@("1T:&ES
M+3Y?=6YL;V-K*"D[#0H@("`@("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E1FEL95]V,2<I*2![
M#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&
M:6QE+W8Q+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&8@
M/2!N97<@4$5!4E]086-K86=E1FEL95]V,3L-"B`@("`@("`@("`@("1P9BT^
M<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@("1P9BT^
M9G)O;4%R<F%Y*"1T:&ES+3YP86-K86=E26YF;R@D<&%C:V%G92DI.PT*("`@
M("`@("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y1$(M/G5N:6YS=&%L;%!A8VMA
M9V4H)'!F*3L-"B`@("`@("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YI
M;G-T86QL4&%C:V%G92@D<&8I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!U<&1A
M=&5086-K86=E,B@I#0H-"B`@("!F=6YC=&EO;B!U<&1A=&5086-K86=E,B@D
M:6YF;RD-"B`@("![#0H@("`@("`@(&EF("@A:7-?;V)J96-T*"1I;F9O*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YU<&1A=&5086-K86=E*"1I
M;F9O6R=P86-K86=E)UTL("1I;F9O+"`D;65R9V4I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)&EN9F\M/G9A;&ED871E*%!%05)?5D%,241!5$5?1$]7
M3DQ/041)3D<I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^
M7VQO8VLH3$]#2U]%6"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@
M("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?=7!D871E4&%C:V%G
M93(H)&EN9F\I.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@
M("!I9B`H)')E="D@>PT*("`@("`@("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y
M1$(M/G5N:6YS=&%L;%!A8VMA9V4H)&EN9F\I.PT*("`@("`@("`@("`@)'1H
M:7,M/E]D97!E;F1E;F-Y1$(M/FEN<W1A;&Q086-K86=E*"1I;F9O*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@9V5T0VAA;FYE;"@I#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@("`@*B!`<&%R86T@
M8F]O;"!W:&5T:&5R('1O('-T<FEC=&QY(')E='5R;B!R87<@8VAA;FYE;',@
M*&YO(&%L:6%S97,I#0H@("`@("H@0')E='5R;B!014%27T-H86YN96Q&:6QE
M?%!%05)?17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T0VAA;FYE
M;"@D8VAA;FYE;"P@)&YO86QI87-E<R`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]3
M2"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@
M("`@("`@)')E="`]("8D=&AI<RT^7V=E=$-H86YN96PH)&-H86YN96PL("1N
M;V%L:6%S97,I.PT*("`@("`@("!I9B`H(21R970I('L-"B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N(&-H86YN96PZ("<@
M+B`D8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]U;FQO
M8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=%!A8VMA9V4H*0T*("`@("\J*@T*("`@("`J
M($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!C:&%N;F5L(&YA;64-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G
M949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V,GQN=6QL#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@)F=E=%!A8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L(#T@
M)W!E87(N<&AP+FYE="<I#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<&8@/2`F)'1H
M:7,M/E]G971086-K86=E*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@("`@("`@
M("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@(')E='5R;B`D<&8[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!'970@4$5!4E]0
M86-K86=E1FEL95]V6S$O,ET@;V)J96-T<R!R97!R97-E;G1I;F<@=&AE(&-O
M;G1E;G1S(&]F#0H@("`@("H@82!D97!E;F1E;F-Y(&=R;W5P('1H870@87)E
M(&EN<W1A;&QE9"X-"B`@("`@*@T*("`@("`J(%1H:7,@:7,@=7-E9"!A="!U
M;FEN<W1A;&PM=&EM90T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!R
M971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971)
M;G-T86QL961'<F]U<"@D9W)O=7`I#0H@("`@>PT*("`@("`@("`D<F5T(#T@
M87)R87DH*3L-"B`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LG<&%C:V%G92==
M*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9W)O=7!;)W!A8VMA9V4G
M75LP72DI('L-"B`@("`@("`@("`@("`@("`D9W)O=7!;)W!A8VMA9V4G72`]
M(&%R<F%Y*"1G<F]U<%LG<&%C:V%G92==*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<%LG<&%C:V%G92==(&%S("1P86-K
M86=E*2![#0H@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@/2!I<W-E="@D
M<&%C:V%G95LG8VAA;FYE;"==*2`_("1P86-K86=E6R=C:&%N;F5L)UT@.B`G
M7U]U<FDG.PT*("`@("`@("`@("`@("`@("1P(#T@)B1T:&ES+3YG971086-K
M86=E*"1P86-K86=E6R=N86UE)UTL("1D97!C:&%N;F5L*3L-"B`@("`@("`@
M("`@("`@("!I9B`H)'`I('L-"B`@("`@("`@("`@("`@("`@("`@)'-A=F4@
M/2`F)'`[#0H@("`@("`@("`@("`@("`@("`@("1R971;72`]("8D<V%V93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LG<W5B<&%C:V%G92==*2D@>PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D9W)O=7!;)W-U8G!A8VMA9V4G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`D9W)O=7!;)W-U8G!A8VMA9V4G72`]
M(&%R<F%Y*"1G<F]U<%LG<W5B<&%C:V%G92==*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<%LG<W5B<&%C:V%G92==(&%S
M("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@/2!I
M<W-E="@D<&%C:V%G95LG8VAA;FYE;"==*2`_("1P86-K86=E6R=C:&%N;F5L
M)UT@.B`G7U]U<FDG.PT*("`@("`@("`@("`@("`@("1P(#T@)B1T:&ES+3YG
M971086-K86=E*"1P86-K86=E6R=N86UE)UTL("1D97!C:&%N;F5L*3L-"B`@
M("`@("`@("`@("`@("!I9B`H)'`I('L-"B`@("`@("`@("`@("`@("`@("`@
M)'-A=F4@/2`F)'`[#0H@("`@("`@("`@("`@("`@("`@("1R971;72`]("8D
M<V%V93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%C;W5N="@D<F5T*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@('T-"@T*("`@("\O('M[>R!G971#:&%N;F5L5F%L:61A=&]R
M*"D-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M
M90T*("`@("`J($!R971U<FX@4$5!4E]686QI9&%T97QF86QS90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N("9G971#:&%N;F5L5F%L:61A=&]R*"1C:&%N;F5L
M*0T*("`@('L-"B`@("`@("`@)&-H86X@/2`D=&AI<RT^9V5T0VAA;FYE;"@D
M8VAA;FYE;"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1C:&%N.PT*("`@("`@("!]#0H@("`@
M("`@("1V86P@/2`D8VAA;BT^9V5T5F%L:61A=&EO;D]B:F5C="@I.PT*("`@
M("`@("!R971U<FX@)'9A;#L-"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$-H86YN96QS*"D-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&-H86YN96P@;F%M90T*("`@("`J($!R971U<FX@87)R87D@86X@87)R
M87D@;V8@4$5!4E]#:&%N;F5L1FEL92!O8FIE8W1S(')E<')E<V5N=&EN9R!E
M=F5R>2!I;G-T86QL960@8VAA;FYE;`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M("9G971#:&%N;F5L<R@I#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH
M*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO
M8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@
M("`@('T-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]L:7-T0VAA;FYE;',H
M*2!A<R`D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)&4@/2`F)'1H:7,M/E]G
M971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("@A)&4@?'P@
M4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R971;72`]("1E.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!C:&5C:T9I;&5-87`H*0T*#0H@("`@+RHJ#0H@("`@("H@5&5S="!W:&5T
M:&5R(&$@9FEL92!O<B!S970@;V8@9FEL97,@8F5L;VYG<R!T;R!A('!A8VMA
M9V4N#0H@("`@("H-"B`@("`@*B!)9B!A;B!A<G)A>2!I<R!P87-S960@:6X-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y(&9I;&4@<&%T:"P@86)S;VQU
M=&4@;W(@<F5L871I=F4@=&\@=&AE('!E87(-"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@(&EN<W1A;&P@9&ER#0H@("`@("H@0'!A<F%M('-T<FEN9WQA
M<G)A>2!N86UE(&]F(%!%05(@<&%C:V%G92!O<B!A<G)A>2@G<&%C:V%G92<@
M/3X@;F%M92P@)V-H86YN96PG(#T^#0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!C:&%N;F5L*2!O9B!A('!A8VMA9V4@=&AA="!W:6QL(&)E(&EG;F]R
M960-"B`@("`@*B!`<&%R86T@<W1R:6YG($%022!V97)S:6]N("T@,2XQ('=I
M;&P@97AC;'5D92!A;GD@9FEL97,@8F5L;VYG:6YG('1O(&$@<&%C:V%G90T*
M("`@("`J($!P87)A;2!A<G)A>2!P<FEV871E(')E8W5R<VEO;B!V87)I86)L
M90T*("`@("`J($!R971U<FX@87)R87E\9F%L<V4@=VAI8V@@<&%C:V%G92!A
M;F0@8VAA;FYE;"!T:&4@9FEL92!B96QO;F=S('1O+"!O<B!A;B!E;7!T>0T*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(&EF('1H92!F:6QE
M(&1O97,@;F]T(&)E;&]N9R!T;R!A;B!I;G-T86QL960@<&%C:V%G92P-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(&]R(&)E;&]N9W,@=&\@=&AE('-E
M8V]N9"!P87)A;65T97(G<R!P86-K86=E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@8VAE8VM&:6QE36%P*"1P871H+"`D<&%C:V%G92`](&9A;'-E+"`D87!I
M(#T@)S$N,"<L("1A='1R<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1P871H*2D@>PT*("`@("`@("`@("`@<W1A=&EC("1N;W1E
M;7!T>3L-"B`@("`@("`@("`@(&EF("AE;7!T>2@D;F]T96UP='DI*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?26YS=&%L
M;&5R7U)O;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(O26YS=&%L;&5R+U)O;&4N<&AP)SL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)&YO=&5M<'1Y(#T@8W)E871E7V9U;F-T
M:6]N*"<D82<L)W)E='5R;B`A96UP='DH)&$I.R<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)'!A8VMA9V4@/2!I<U]A<G)A>2@D<&%C:V%G92D@
M/R!A<G)A>2AS=')T;VQO=V5R*"1P86-K86=E6S!=*2P@<W1R=&]L;W=E<B@D
M<&%C:V%G95LQ72DI#0H@("`@("`@("`@("`@("`@.B!S=')T;VQO=V5R*"1P
M86-K86=E*3L-"B`@("`@("`@("`@("1P:V=S(#T@87)R87DH*3L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1P871H(&%S("1N86UE(#T^("1A='1R<RD@>PT*
M("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D871T<G,I*2![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<G-;)VEN<W1A;&PM87,G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)&%T=')S
M6R=I;G-T86QL+6%S)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D871T<G-;)W)O;&4G72P@
M4$5!4E]);G-T86QL97)?4F]L93HZ9V5T26YS=&%L;&%B;&52;VQE<R@I*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AE<V4@87)E(&YO="!I
M;G-T86QL960-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:6Y?87)R87DH)&%T=')S6R=R;VQE)UTL(%!%05)?26YS=&%L;&5R7U)O
M;&4Z.F=E=$)A<V5I;G-T86QL4F]L97,H*2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1A='1R<ULG8F%S96EN<W1A;&QD:7(G72`](&ES7V%R<F%Y
M*"1P86-K86=E*2`_("1P86-K86=E6S%=(#H@)'!A8VMA9V4[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A='1R<ULG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE(#T@)&%T=')S6R=B87-E:6YS=&%L;&1I<B==("X@
M1$E214-43U)97U-%4$%2051/4B`N("1N86UE.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P
M:V=S6R1N86UE72`]("1T:&ES+3YC:&5C:T9I;&5-87`H)&YA;64L("1P86-K
M86=E+"`D87!I+"`D871T<G,I.PT*("`@("`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1P:V=S6R1N86UE72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1P:V=S6R1N86UE73L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@87)R87E?9FEL=&5R
M*"1P:V=S+"`D;F]T96UP='DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^9FEL96UA<%]C86-H92DI('L-"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1E<G(@/2`D=&AI<RT^7W)E861&:6QE36%P*"D[#0H@
M("`@("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(21A='1R<RD@>PT*("`@("`@("`@("`@)&%T=')S(#T@87)R87DH)W)O
M;&4G(#T^("=P:'`G*3L@+R\@86YY(&]L9"!C86QL('=O=6QD(&)E(&9O<B!0
M2%`@<F]L92!O;FQY#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YF:6QE;6%P7V-A8VAE6R1A='1R<ULG<F]L92==75LD<&%T:%TI*2![
M#0H@("`@("`@("`@("!I9B`H)&%P:2`^/2`G,2XQ)R`F)B`D=&AI<RT^9FEL
M96UA<%]C86-H95LD871T<G-;)W)O;&4G75U;)'!A=&A=(#T]("1P86-K86=E
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF:6QE;6%P7V-A8VAE
M6R1A='1R<ULG<F]L92==75LD<&%T:%T[#0H@("`@("`@('T-"B`@("`@("`@
M)&P@/2!S=')L96XH)'1H:7,M/FEN<W1A;&Q?9&ER*3L-"B`@("`@("`@:68@
M*'-U8G-T<B@D<&%T:"P@,"P@)&PI(#T]("1T:&ES+3YI;G-T86QL7V1I<BD@
M>PT*("`@("`@("`@("`@)'!A=&@@/2!P<F5G7W)E<&QA8V4H)R%>)RY$25)%
M0U1/4EE?4T5005)!5$]2+B<K(2<L("<G+"!S=6)S='(H)'!A=&@L("1L*2D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YF:6QE;6%P
M7V-A8VAE6R1A='1R<ULG<F]L92==75LD<&%T:%TI*2![#0H@("`@("`@("`@
M("!I9B`H)&%P:2`^/2`G,2XQ)R`F)B`D=&AI<RT^9FEL96UA<%]C86-H95LD
M871T<G-;)W)O;&4G75U;)'!A=&A=(#T]("1P86-K86=E*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YF:6QE;6%P7V-A8VAE6R1A='1R<ULG<F]L
M92==75LD<&%T:%T[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A<&E697)S:6]N
M*"D-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&5X<&5C=&5D($%022!V97)S
M:6]N+B`@0VAA;FYE;',@05!)(&ES('9E<G-I;VX@,2XQ+"!A<R!I="!I<R!B
M86-K=V%R9',-"B`@("`@*B!C;VUP871I8FQE('=I=&@@,2XP#0H@("`@("H@
M0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A<&E697)S
M:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G,2XQ)SL-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"@T*("`@("\J*@T*("`@("`J(%!A<G-E(&$@<&%C:V%G
M92!N86UE+"!O<B!V86QI9&%T92!A('!A<G-E9"!P86-K86=E(&YA;64@87)R
M87D-"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y('!A<W,@:6X@86X@87)R
M87D@;V8@9F]R;6%T#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@
M)W!N86UE)RP-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(%LG8VAA;FYE
M;"<@/3X@)V-H86YN86UE)RQ=#0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("!;)W9E<G-I;VXG(#T^("=V97)S:6]N)RQ=#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!;)W-T871E)R`]/B`G<W1A=&4G+%T-"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@(%LG9W)O=7`G(#T^("=G<F]U<&YA;64G72D-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(&]R(&$@<W1R:6YG(&]F(&9O<FUA
M=`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@6V-H86YN96PZ+R]=6V-H
M86YN86UE+UUP;F%M95LM=F5R<VEO;GPM<W1A=&5=6R]G<F]U<#UG<F]U<&YA
M;65=#0H@("`@("H@0')E='5R;B!A<G)A>7Q014%27T5R<F]R#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<&%R<V5086-K86=E3F%M92@D<&%R86TL("1D969A
M=6QT8VAA;FYE;"`]("=P96%R+G!H<"YN970G*0T*("`@('L-"B`@("`@("`@
M)'-A=F5P87)A;2`]("1P87)A;3L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1P
M87)A;2DI('L-"B`@("`@("`@("`@("\O(&-O;G9E<G0@=&\@<W1R:6YG(&9O
M<B!E<G)O<B!M97-S86=E<PT*("`@("`@("`@("`@)'-A=F5P87)A;2`]("1T
M:&ES+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P87)A;2D[#0H@("`@
M("`@("`@("`O+R!P<F]C97-S('1H92!A<G)A>0T*("`@("`@("`@("`@:68@
M*"%I<W-E="@D<&%R86U;)W!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K86=E3F%M92@I
M.B!A<G)A>2`D<&%R86T@)R`N#0H@("`@("`@("`@("`@("`@("`@("=M=7-T
M(&-O;G1A:6X@82!V86QI9"!P86-K86=E(&YA;64@:6X@:6YD97@@(G!A<F%M
M(B<L#0H@("`@("`@("`@("`@("`@("`@("=P86-K86=E)RP@;G5L;"P@;G5L
M;"P@)'!A<F%M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)'!A<F%M6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P87)A;5LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<&%R86U;)V-H86YN96PG72`]("1D969A=6QT8VAA;FYE;#L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1P87)A;5LG8VAA;FYE;"==(#T@)U]?=7)I)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C;VUP
M;VYE;G1S(#T@0'!A<G-E7W5R;"@D<&%R86TI.PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1C;VUP;VYE;G1S6R=S8VAE;64G72DI('L-"B`@("`@("`@("`@
M("`@("!I9B`H)&-O;7!O;F5N='-;)W-C:&5M92==(#T]("=H='1P)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`O+R!U<FD@<&%C:V%G90T*("`@("`@("`@
M("`@("`@("`@("`D<&%R86T@/2!A<G)A>2@G=7)I)R`]/B`D<&%R86TL("=C
M:&%N;F5L)R`]/B`G7U]U<FDG*3L-"B`@("`@("`@("`@("`@("!](&5L<V5I
M9B@D8V]M<&]N96YT<ULG<V-H96UE)UT@(3T@)V-H86YN96PG*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P87)S
M95!A8VMA9V5.86UE*"DZ(&]N;'D@8VAA;FYE;#HO+R!U<FES(&UA>2`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=B92!D;W=N;&]A9&5D+"!N;W0@
M(B<@+B`D<&%R86T@+B`G(B<L("=I;G9A;&ED)RP@;G5L;"P@;G5L;"P@)'!A
M<F%M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1C;VUP;VYE;G1S6R=P871H)UTI*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E
M4&%C:V%G94YA;64H*3H@87)R87D@)'!A<F%M("<@+@T*("`@("`@("`@("`@
M("`@("`@("`G;75S="!C;VYT86EN(&$@=F%L:60@<&%C:V%G92!N86UE(&EN
M("(G("X@)'!A<F%M("X@)R(G+`T*("`@("`@("`@("`@("`@("`@("`G<&%C
M:V%G92<L(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&-O;7!O;F5N='-;)VAO<W0G72DI('L-
M"B`@("`@("`@("`@("`@("`O+R!R96UO=F4@=&AE(&QE861I;F<@(B\B#0H@
M("`@("`@("`@("`@("`@)&-O;7!O;F5N='-;)W!A=&@G72`]('-U8G-T<B@D
M8V]M<&]N96YT<ULG<&%T:"==+"`Q*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&-O;7!O;F5N='-;)W-C:&5M92==*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&-O;7!O;F5N='-;)W!A=&@G
M72P@)R\G*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1C;VUP;VYE;G1S6R=P871H)UU[,'T@/3T@)R\G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V50
M86-K86=E3F%M92@I.B!T:&ES(&ES(&YO="`G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G82!P86-K86=E(&YA;64L(&ET(&)E9VEN<R!W:71H
M("(O(B!I;B`B)R`N("1P87)A;2`N("<B)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:6YV86QI9"<L(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!A
M<G1S(#T@97AP;&]D92@G+R<L("1C;VUP;VYE;G1S6R=P871H)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`D8V]M<&]N96YT<ULG:&]S="==(#T@87)R87E?
M<VAI9G0H)'!A<G1S*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT
M*"1P87)T<RD@/B`Q*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8V]M
M<&]N96YT<ULG<&%T:"==(#T@87)R87E?<&]P*"1P87)T<RD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D8V]M<&]N96YT<ULG:&]S="==("X]("<O)R`N
M(&EM<&QO9&4H)R\G+"`D<&%R=',I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;7!O;F5N='-;
M)W!A=&@G72`](&EM<&QO9&4H)R\G+"`D<&%R=',I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&-O;7!O;F5N='-;)VAO<W0G72`]("1D969A=6QT8VAA
M;FYE;#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&-O;7!O;F5N='-;)W!A
M=&@G72P@)R\G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%R=',@/2!E
M>'!L;V1E*"<O)RP@)&-O;7!O;F5N='-;)W!A=&@G72D[#0H@("`@("`@("`@
M("`@("`@("`@("1C;VUP;VYE;G1S6R=P871H)UT@/2!A<G)A>5]P;W`H)'!A
M<G1S*3L-"B`@("`@("`@("`@("`@("`@("`@)&-O;7!O;F5N='-;)VAO<W0G
M72`N/2`G+R<@+B!I;7!L;V1E*"<O)RP@)'!A<G1S*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=P86-K
M86=E)UT@/2`D8V]M<&]N96YT<ULG<&%T:"==.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D<&%R86T@/2!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1C;VUP;VYE;G1S6R=P871H
M)UT-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&-O;7!O;F5N='-;)VAO<W0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M6R=C:&%N;F5L)UT@/2`D8V]M<&]N96YT<ULG:&]S
M="==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D8V]M<&]N96YT<ULG9G)A9VUE;G0G72DI('L-
M"B`@("`@("`@("`@("`@("`D<&%R86U;)V=R;W5P)UT@/2`D8V]M<&]N96YT
M<ULG9G)A9VUE;G0G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D8V]M<&]N96YT<ULG=7-E<B==*2D@>PT*("`@("`@("`@("`@
M("`@("1P87)A;5LG=7-E<B==(#T@)&-O;7!O;F5N='-;)W5S97(G73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D8V]M<&]N96YT
M<ULG<&%S<R==*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG<&%S<R==
M(#T@)&-O;7!O;F5N='-;)W!A<W,G73L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D8V]M<&]N96YT<ULG<75E<GDG72DI('L-"B`@
M("`@("`@("`@("`@("!P87)S95]S='(H)&-O;7!O;F5N='-;)W%U97)Y)UTL
M("1P87)A;5LG;W!T<R==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("\O(&-H96-K(&9O<B!E>'1E;G-I;VX-"B`@("`@("`@("`@("1P871H:6YF
M;R`]('!A=&AI;F9O*"1P87)A;5LG<&%C:V%G92==*3L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%T:&EN9F];)V5X=&5N<VEO;B==*2`F)@T*("`@("`@
M("`@("`@("`@("`@:6Y?87)R87DH<W1R=&]L;W=E<B@D<&%T:&EN9F];)V5X
M=&5N<VEO;B==*2P@87)R87DH)W1G>B<L("=T87(G*2DI('L-"B`@("`@("`@
M("`@("`@("`D<&%R86U;)V5X=&5N<VEO;B==(#T@)'!A=&AI;F9O6R=E>'1E
M;G-I;VXG73L-"B`@("`@("`@("`@("`@("`D<&%R86U;)W!A8VMA9V4G72`]
M('-U8G-T<B@D<&%T:&EN9F];)V)A<V5N86UE)UTL(#`L#0H@("`@("`@("`@
M("`@("`@("`@('-T<FQE;B@D<&%T:&EN9F];)V)A<V5N86UE)UTI("T@-"D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!C:&5C:R!F;W(@=F5R
M<VEO;@T*("`@("`@("`@("`@:68@*'-T<G!O<R@D<&%R86U;)W!A8VMA9V4G
M72P@)RTG*2D@>PT*("`@("`@("`@("`@("`@("1T97-T(#T@97AP;&]D92@G
M+2<L("1P87)A;5LG<&%C:V%G92==*3L-"B`@("`@("`@("`@("`@("!I9B`H
M8V]U;G0H)'1E<W0I("$](#(I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA;64H*3H@;VYL
M>2!O;F4@=F5R<VEO;B]S=&%T92`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("=D96QI;6ET97(@(BTB(&ES(&%L;&]W960@:6X@(B<@+B`D<V%V97!A
M<F%M("X@)R(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG
M+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!L:7-T*"1P87)A;5LG<&%C:V%G92==+"`D<&%R86U;
M)W9E<G-I;VXG72D@/2`D=&5S=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`O+R!V86QI9&%T:6]N#0H@("`@("`@("1I;F9O(#T@)'1H
M:7,M/F-H86YN96Q%>&ES=',H)'!A<F%M6R=C:&%N;F5L)UTI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D:6YF;SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21I;F9O*2![
M#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YK;F]W
M;B!C:&%N;F5L("(G("X@)'!A<F%M6R=C:&%N;F5L)UT@+@T*("`@("`@("`@
M("`@("`@("<B(&EN("(G("X@)'-A=F5P87)A;2`N("<B)RP@)V-H86YN96PG
M+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("!]#0H@("`@("`@("1C
M:&%N(#T@)'1H:7,M/F=E=$-H86YN96PH)'!A<F%M6R=C:&%N;F5L)UTI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D8VAA;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21C
M:&%N*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M17AC97!T:6]N.B!C;W)R=7!T(')E9VES=')Y+"!C;W5L9"!N;W0@(B`N#0H@
M("`@("`@("`@("`@("`@(G)E=')I979E(&-H86YN96P@(B`N("1P87)A;5LG
M8VAA;FYE;"==("X@(B!I;F9O<FUA=&EO;B(L#0H@("`@("`@("`@("`@("`@
M)W)E9VES=')Y)RP@;G5L;"P@;G5L;"P@)'!A<F%M*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<&%R86U;)V-H86YN96PG72`]("1C:&%N+3YG971.86UE*"D[
M#0H@("`@("`@("1V86QI9&%T92`]("1C:&%N+3YG971686QI9&%T:6]N3V)J
M96-T*"D[#0H@("`@("`@("1V<&%C:V%G92`]("1C:&%N+3YG971686QI9&%T
M:6]N4&%C:V%G92@I.PT*("`@("`@("`O+R!V86QI9&%T92!P86-K86=E(&YA
M;64-"B`@("`@("`@:68@*"$D=F%L:61A=&4M/G9A;&ED4&%C:V%G94YA;64H
M)'!A<F%M6R=P86-K86=E)UTL("1V<&%C:V%G95LG7V-O;G1E;G0G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P87)S95!A
M8VMA9V5.86UE*"DZ(&EN=F%L:60@<&%C:V%G92!N86UE("(G("X-"B`@("`@
M("`@("`@("`@("`D<&%R86U;)W!A8VMA9V4G72`N("<B(&EN("(G("X@)'-A
M=F5P87)A;2`N("<B)RP-"B`@("`@("`@("`@("`@("`G<&%C:V%G92<L(&YU
M;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1P87)A;5LG9W)O=7`G72DI('L-"B`@("`@("`@("`@(&EF("@A4$5!
M4E]686QI9&%T93HZ=F%L:61'<F]U<$YA;64H)'!A<F%M6R=G<F]U<"==*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P
M87)S95!A8VMA9V5.86UE*"DZ(&1E<&5N9&5N8WD@9W)O=7`@(B<@+B`D<&%R
M86U;)V=R;W5P)UT@+@T*("`@("`@("`@("`@("`@("`@("`G(B!I<R!N;W0@
M82!V86QI9"!G<F]U<"!N86UE(&EN("(G("X@)'-A=F5P87)A;2`N("<B)RP@
M)V=R;W5P)RP@;G5L;"P@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)'!A<F%M6R=S=&%T92==*2D@>PT*("`@("`@("`@("`@:68@*"%I
M;E]A<G)A>2AS=')T;VQO=V5R*"1P87)A;5LG<W1A=&4G72DL("1V86QI9&%T
M92T^9V5T5F%L:613=&%T97,H*2DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K86=E3F%M92@I.B!S=&%T
M92`B)R`N("1P87)A;5LG<W1A=&4G70T*("`@("`@("`@("`@("`@("`@("`N
M("<B(&ES(&YO="!A('9A;&ED('-T871E(&EN("(G("X@)'-A=F5P87)A;2`N
M("<B)RP-"B`@("`@("`@("`@("`@("`@("`@)W-T871E)RP@;G5L;"P@;G5L
M;"P@)'!A<F%M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)'!A<F%M6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'!A<F%M6R=S=&%T92==*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P87)S95!A8VMA9V5.86UE
M*"DZ(&-A;FYO="!C;VYT86EN(&)O=&@@)R`N#0H@("`@("`@("`@("`@("`@
M("`@("=A('9E<G-I;VX@86YD(&$@<W1A8FEL:71Y("AS=&%T92D@:6X@(B<@
M+B`D<V%V97!A<F%M("X@)R(G+`T*("`@("`@("`@("`@("`@("`@("`G=F5R
M<VEO;B]S=&%T92<L(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`O+R!C:&5C:R!W:&5T:&5R('9E<G-I;VX@:7,@
M86-T=6%L;'D@82!S=&%T90T*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*'-T
M<G1O;&]W97(H)'!A<F%M6R=V97)S:6]N)UTI+"`D=F%L:61A=&4M/F=E=%9A
M;&ED4W1A=&5S*"DI*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=S=&%T
M92==(#T@<W1R=&]L;W=E<B@D<&%R86U;)W9E<G-I;VXG72D[#0H@("`@("`@
M("`@("`@("`@=6YS970H)'!A<F%M6R=V97)S:6]N)UTI.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H(21V86QI9&%T92T^
M=F%L:61697)S:6]N*"1P87)A;5LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K
M86=E3F%M92@I.B`B)R`N("1P87)A;5LG=F5R<VEO;B==("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("<B(&ES(&YE:71H97(@82!V86QI9"!V97)S:6]N
M(&YO<B!A('9A;&ED('-T871E(&EN("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S879E<&%R86T@+B`G(B<L("=V97)S:6]N+W-T871E)RP@;G5L
M;"P@;G5L;"P@)'!A<F%M*3L-"B`@("`@("`@("`@("`@("!]("`@("`@("`@
M("`@("`@("`@("`-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'!A<F%M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!A<G)A>0T*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%R<V5D
M+"`D8G)I968@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("AI<U]S=')I
M;F<H)'!A<G-E9"DI('L-"B`@("`@("`@("`@(')E='5R;B`D<&%R<V5D.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)'!A<G-E9"DI('L-
M"B`@("`@("`@("`@("1P(#T@)'!A<G-E9#L-"B`@("`@("`@("`@("1P87)S
M960@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)'`M
M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@
M)'`M/F=E=$-H86YN96PH*2P-"B`@("`@("`@("`@("`@("`G=F5R<VEO;B<@
M/3X@)'`M/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@("D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)W5R:2==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1P87)S961;)W5R:2==.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D8G)I968I('L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE
M;"`]("1T:&ES+3YC:&%N;F5L06QI87,H)'!A<G-E9%LG8VAA;FYE;"==*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D8VAA;FYE;"`N("<O)R`N("1P
M87)S961;)W!A8VMA9V4G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D=7!A<W,@/2`G)SL-"B`@("`@("`@:68@*&ES<V5T*"1P87)S
M961;)W5S97(G72DI('L-"B`@("`@("`@("`@("1U<&%S<R`]("1P87)S961;
M)W5S97(G73L-"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=P87-S
M)UTI*2![#0H@("`@("`@("`@("`@("`@)'5P87-S("X]("<Z)R`N("1P87)S
M961;)W!A<W,G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1U<&%S
M<R`]("(D=7!A<W-`(CL-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)V-H
M86YN96PZ+R\G("X@)'5P87-S("X@)'!A<G-E9%LG8VAA;FYE;"==("X@)R\G
M("X@)'!A<G-E9%LG<&%C:V%G92==.PT*("`@("`@("!I9B`H:7-S970H)'!A
M<G-E9%LG=F5R<VEO;B==*2!\?"!I<W-E="@D<&%R<V5D6R=S=&%T92==*2D@
M>PT*("`@("`@("`@("`@)')E="`N/2`G+2<@+B!`)'!A<G-E9%LG=F5R<VEO
M;B==("X@0"1P87)S961;)W-T871E)UT[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1P87)S961;)V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@
M("`@)')E="`N/2`G+B<@+B`D<&%R<V5D6R=E>'1E;G-I;VXG73L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG;W!T<R==*2D@>PT*
M("`@("`@("`@("`@)')E="`N/2`G/R<[#0H@("`@("`@("`@("!F;W)E86-H
M("@D<&%R<V5D6R=O<'1S)UT@87,@)&YA;64@/3X@)'9A;'5E*2![#0H@("`@
M("`@("`@("`@("`@)'!A<G-E9%LG;W!T<R==6R1N86UE72`]("(D;F%M93TD
M=F%L=64B.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`N/2!I
M;7!L;V1E*"<F)RP@)'!A<G-E9%LG;W!T<R==*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)'!A<G-E9%LG9W)O=7`G72DI('L-"B`@("`@("`@
M("`@("1R970@+CT@)R,G("X@)'!A<G-E9%LG9W)O=7`G73L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0I]#0H-"C\^#0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U)%4U0N
M<&AP````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S
M-30V,0`Q,#4Q-30S,3`U-P`P,3<S-C<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]215-4
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)%4U0N
M<&AP+'8@,2XR,"`R,#`V+S`S+S`R(#`S.C`Y.C,Q('!A:F]Y92!%>'`@)`T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@1F]R(&1O=VYL;V%D:6YG('AM
M;"!F:6QE<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I
M<F5?;VYC92`G4$5!4B]834Q087)S97(N<&AP)SL-"@T*+RHJ#0H@*B!);G1E
M;&QI9V5N=&QY(')E=')I979E(&1A=&$L(&9O;&QO=VEN9R!H>7!E<FQI;FMS
M(&EF(&YE8V5S<V%R>2P@86YD(')E+61I<F5C=&EN9PT*("H@87,@=V5L;`T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?4D535`T*>PT*("`@('9A
M<B`D8V]N9FEG.PT*("`@('9A<B`D7V]P=&EO;G,[#0H@("`@9G5N8W1I;VX@
M4$5!4E]215-4*"8D8V]N9FEG+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@("`@
M("1T:&ES+3Y?;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%)E=')I979E(%)%4U0@9&%T82P@8G5T(&%L=V%Y<R!R971R
M:65V92!T:&4@;&]C86P@8V%C:&4@:68@:70@:7,@879A:6QA8FQE+@T*("`@
M("`J#0H@("`@("H@5&AI<R!I<R!U<V5F=6P@9F]R(&5L96UE;G1S('1H870@
M<VAO=6QD(&YE=F5R(&-H86YG92P@<W5C:"!A<R!I;F9O<FUA=&EO;B!O;B!A
M('!A<G1I8W5L87(-"B`@("`@*B!R96QE87-E#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!F=6QL(%523"!T;R!T:&ES(')E<V]U<F-E#0H@("`@("H@0'!A<F%M
M(&%R<F%Y?&9A;'-E(&-O;G1E;G1S(&]F('1H92!A8V-E<'0M96YC;V1I;F<@
M:&5A9&5R#0H@("`@("H@0'!A<F%M(&)O;VQE86X@("`@(&EF('1R=64L('AM
M;"!W:6QL(&)E(')E='5R;F5D(&%S(&$@<W1R:6YG+"!O=&AE<G=I<V4L('AM
M;"!W:6QL(&)E#0H@("`@("H@("`@("`@("`@("`@("`@("`@('!A<G-E9"!U
M<VEN9R!014%27UA-3%!A<G-E<@T*("`@("`J($!R971U<FX@<W1R:6YG?&%R
M<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5T<FEE=F5#86-H949I<G-T
M*"1U<FPL("1A8V-E<'0@/2!F86QS92P@)&9O<F-E<W1R:6YG(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("`D8V%C:&5F:6QE(#T@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=C86-H95]D:7(G*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@
M("`@("`@("`@;60U*"1U<FPI("X@)W)E<W0N8V%C:&5F:6QE)SL-"B`@("`@
M("`@:68@*$!F:6QE7V5X:7-T<R@D8V%C:&5F:6QE*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N('5N<V5R:6%L:7IE*&EM<&QO9&4H)R<L(&9I;&4H)&-A8VAE
M9FEL92DI*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/G)E
M=')I979E1&%T82@D=7)L+"`D86-C97!T+"`D9F]R8V5S=')I;F<I.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%)E=')I979E(&$@<F5M;W1E(%)%4U0@
M<F5S;W5R8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9U;&P@55),('1O('1H
M:7,@<F5S;W5R8V4-"B`@("`@*B!`<&%R86T@87)R87E\9F%L<V4@8V]N=&5N
M=',@;V8@=&AE(&%C8V5P="UE;F-O9&EN9R!H96%D97(-"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`@("`@:68@=')U92P@>&UL('=I;&P@8F4@<F5T=7)N960@
M87,@82!S=')I;F<L(&]T:&5R=VES92P@>&UL('=I;&P@8F4-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@<&%R<V5D('5S:6YG(%!%05)?6$U,4&%R<V5R
M#0H@("`@("H@0')E='5R;B!S=')I;F=\87)R87D-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!R971R:65V941A=&$H)'5R;"P@)&%C8V5P="`](&9A;'-E+"`D
M9F]R8V5S=')I;F<@/2!F86QS92D-"B`@("![#0H@("`@("`@("1C86-H94ED
M(#T@)'1H:7,M/F=E=$-A8VAE260H)'5R;"D[#0H@("`@("`@(&EF("@D<F5T
M(#T@)'1H:7,M/G5S94QO8V%L0V%C:&4H)'5R;"P@)&-A8VAE260I*2![#0H@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;V9F;&EN92==*2D@>PT*("`@
M("`@("`@("`@)'1R:65D9&]W;FQO860@/2!T<G5E.PT*("`@("`@("`@("`@
M)&9I;&4@/2`D=&AI<RT^9&]W;FQO861(='1P*"1U<FPL("1C86-H94ED(#\@
M)&-A8VAE261;)VQA<W1#:&%N9V4G72`Z(&9A;'-E+"`D86-C97!T*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T<FEE9&1O=VYL;V%D(#T@
M9F%L<V4[#0H@("`@("`@("`@("`D9FEL92`](&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F:6QE*2D@>PT*("`@("`@
M("`@("`@:68@*"1F:6QE+3YG971#;V1E*"D@/3T@+3DR-S8I('L-"B`@("`@
M("`@("`@("`@("`D=')I961D;W=N;&]A9"`](&9A;'-E.PT*("`@("`@("`@
M("`@("`@("1F:6QE(#T@9F%L<V4[("\O('5S92!L;V-A;"!C;W!Y(&EF(&%V
M86EL86)L92!O;B!S;V-K970@8V]N;F5C="!E<G)O<@T*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&9I;&4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D9FEL92D@>PT*
M("`@("`@("`@("`@)')E="`]("1T:&ES+3YG971#86-H92@D=7)L*3L-"B`@
M("`@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D<F5T*2`F)B`D=')I961D
M;W=N;&]A9"D@>PT*("`@("`@("`@("`@("`@("\O(')E<V5T('1H92!A9V4@
M;V8@=&AE(&-A8VAE(&EF('1H92!S97)V97(@<V%Y<R!I="!W87,@=6YM;V1I
M9FEE9`T*("`@("`@("`@("`@("`@("1T:&ES+3YS879E0V%C:&4H)'5R;"P@
M)')E="P@;G5L;"P@=')U92P@)&-A8VAE260I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1F:6QE*2D@>PT*("`@("`@("`@("`@)&AE861E<G,@
M/2`D9FEL95LR73L-"B`@("`@("`@("`@("1L87-T;6]D:69I960@/2`D9FEL
M95LQ73L-"B`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&5;,%T[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE.PT*
M("`@("`@("`@("`@)&QA<W1M;V1I9FEE9"`](&9A;'-E.PT*("`@("`@("`@
M("`@)&AE861E<G,@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D9F]R8V5S=')I;F<I('L-"B`@("`@("`@("`@("1T:&ES+3YS879E0V%C
M:&4H)'5R;"P@)&-O;G1E;G0L("1L87-T;6]D:69I960L(&9A;'-E+"`D8V%C
M:&5)9"D[#0H@("`@("`@("`@("!R971U<FX@)&-O;G1E;G0[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1H96%D97)S6R=C;VYT96YT+71Y<&4G
M72DI('L-"B`@("`@("`@("`@('-W:71C:"`H)&AE861E<G-;)V-O;G1E;G0M
M='EP92==*2![#0H@("`@("`@("`@("`@("`@8V%S92`G=&5X="]X;6PG(#H-
M"B`@("`@("`@("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]X;6PG(#H-"B`@
M("`@("`@("`@("`@("`@("`@)'!A<G-E<B`](&YE=R!014%27UA-3%!A<G-E
M<CL-"B`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@("`@("`D
M97)R(#T@)'!A<G-E<BT^<&%R<V4H)&-O;G1E;G0I.PT*("`@("`@("`@("`@
M("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV
M86QI9"!X;6P@9&]W;FQO861E9"!F<F]M("(G("X@)'5R;"`N("<B.B`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@)'!A<G-E<BT^9V5T1&%T82@I.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)W1E>'0O:'1M;"<@.@T*("`@("`@("`@("`@("`@(&1E
M9F%U;'0@.@T*("`@("`@("`@("`@("`@("`@("`O+R!U<V4@:70@87,@82!S
M=')I;F<-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("\O(&%S<W5M92!834P-"B`@("`@("`@("`@("1P87)S97(@/2!N
M97<@4$5!4E]834Q087)S97([#0H@("`@("`@("`@("`D<&%R<V5R+3YP87)S
M92@D8V]N=&5N="D[#0H@("`@("`@("`@("`D8V]N=&5N="`]("1P87)S97(M
M/F=E=$1A=&$H*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^<V%V94-A
M8VAE*"1U<FPL("1C;VYT96YT+"`D;&%S=&UO9&EF:65D+"!F86QS92P@)&-A
M8VAE260I.PT*("`@("`@("!R971U<FX@)&-O;G1E;G0[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@=7-E3&]C86Q#86-H92@D=7)L+"`D8V%C:&5I9"`](&YU
M;&PI#0H@("`@>PT*("`@("`@("!I9B`H)&-A8VAE:60@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@("1C86-H96ED9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G8V%C:&5?9&ER)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@
M("`@("`@("`@("!M9#4H)'5R;"D@+B`G<F5S="YC86-H96ED)SL-"B`@("`@
M("`@("`@(&EF("A`9FEL95]E>&ES=',H)&-A8VAE:61F:6QE*2D@>PT*("`@
M("`@("`@("`@("`@("1C86-H96ED(#T@=6YS97)I86QI>F4H:6UP;&]D92@G
M)RP@9FEL92@D8V%C:&5I9&9I;&4I*2D[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D8V%C:&5T=&P@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)V-A8VAE7W1T;"<I.PT*("`@("`@("`O+R!)9B!C86-H92!I
M<R!N97=E<B!T:&%N("1C86-H971T;"!S96-O;F1S+"!W92!U<V4@=&AE(&-A
M8VAE(0T*("`@("`@("!I9B`H=&EM92@I("T@)&-A8VAE:61;)V%G92==(#P@
M)&-A8VAE='1L*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$-A
M8VAE*"1U<FPI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#86-H94ED*"1U<FPI#0H@("`@
M>PT*("`@("`@("`D8V%C:&5I9&9I;&4@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)V-A8VAE7V1I<B<I("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@
M("`@("!M9#4H)'5R;"D@+B`G<F5S="YC86-H96ED)SL-"B`@("`@("`@:68@
M*$!F:6QE7V5X:7-T<R@D8V%C:&5I9&9I;&4I*2![#0H@("`@("`@("`@("`D
M<F5T(#T@=6YS97)I86QI>F4H:6UP;&]D92@G)RP@9FEL92@D8V%C:&5I9&9I
M;&4I*2D[#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$-A8VAE*"1U<FPI#0H@("`@>PT*
M("`@("`@("`D8V%C:&5F:6QE(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H
M95]D:7(G*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@
M;60U*"1U<FPI("X@)W)E<W0N8V%C:&5F:6QE)SL-"B`@("`@("`@:68@*$!F
M:6QE7V5X:7-T<R@D8V%C:&5F:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M('5N<V5R:6%L:7IE*&EM<&QO9&4H)R<L(&9I;&4H)&-A8VAE9FEL92DI*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=.;R!C86-H960@8V]N=&5N="!A=F%I;&%B;&4@9F]R("(G
M("X@)'5R;"`N("<B)RD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&9U;&P@55),('1O(%)%4U0@<F5S;W5R
M8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG(&]R:6=I;F%L(&-O;G1E;G1S(&]F
M('1H92!215-4(')E<V]U<F-E#0H@("`@("H@0'!A<F%M(&%R<F%Y("!(5%10
M($QA<W0M36]D:69I960@86YD($5486<@:&5A9&5R<PT*("`@("`J($!P87)A
M;2!B;V]L("`@:68@=')U92P@=&AE;B!T:&4@8V%C:&4@:60@9FEL92!S:&]U
M;&0@8F4@<F5G96YE<F%T960@=&\-"B`@("`@*B`@("`@("`@("`@("`@('1R
M:6=G97(@82!N97<@=&EM92UT;RUL:79E('9A;'5E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<V%V94-A8VAE*"1U<FPL("1C;VYT96YT<RP@)&QA<W1M;V1I
M9FEE9"P@)&YO8VAA;F=E(#T@9F%L<V4L("1C86-H96ED(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@("1C86-H96ED9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G8V%C:&5?9&ER)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@
M("`@("`@(&UD-2@D=7)L*2`N("=R97-T+F-A8VAE:60G.PT*("`@("`@("`D
M8V%C:&5F:6QE(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H95]D:7(G*2`N
M($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@;60U*"1U<FPI
M("X@)W)E<W0N8V%C:&5F:6QE)SL-"B`@("`@("`@:68@*"1C86-H96ED(#T]
M/2!N=6QL("8F("1N;V-H86YG92D@>PT*("`@("`@("`@("`@)&-A8VAE:60@
M/2!U;G-E<FEA;&EZ92AI;7!L;V1E*"<G+"!F:6QE*"1C86-H96ED9FEL92DI
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@("1F<"`]($!F;W!E;B@D8V%C:&5I
M9&9I;&4L("=W8B<I.PT*("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@
M("`@)&-A8VAE7V1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER
M)RD[#0H@("`@("`@("`@("!I9B`H(6ES7V1I<B@D8V%C:&5?9&ER*2D@>PT*
M("`@("`@("`@("`@("`@(%-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@)&-A
M8VAE7V1I<BDI.PT*("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D8V%C
M:&5I9&9I;&4L("=W8B<I.PT*("`@("`@("`@("`@("`@(&EF("@A)&9P*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M#0H@("`@("`@(&EF("@D;F]C:&%N9V4I('L-"B`@("`@("`@("`@(&9W<FET
M92@D9G`L('-E<FEA;&EZ92AA<G)A>2@-"B`@("`@("`@("`@("`@("`G86=E
M)R`@("`@("`@/3X@=&EM92@I+`T*("`@("`@("`@("`@("`@("=L87-T0VAA
M;F=E)R`]/B`D8V%C:&5I9%LG;&%S=$-H86YG92==+`T*("`@("`@("`@("`@
M("`@("DI*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!F=W)I=&4H)&9P+"!S97)I86QI>F4H87)R87DH#0H@("`@("`@("`@("`@
M("`@)V%G92<@("`@("`@(#T^('1I;64H*2P-"B`@("`@("`@("`@("`@("`G
M;&%S=$-H86YG92<@/3X@)&QA<W1M;V1I9FEE9"P-"B`@("`@("`@("`@("`@
M("`I*2D[#0H@("`@("`@('T-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@
M("`@("1F<"`]($!F;W!E;B@D8V%C:&5F:6QE+"`G=V(G*3L-"B`@("`@("`@
M:68@*"$D9G`I('L-"B`@("`@("`@("`@($!U;FQI;FLH)&-A8VAE:61F:6QE
M*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&-O;G1E;G1S*2D[#0H@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!%9F9I8VEE;G1L>2!$;W=N;&]A9"!A(&9I
M;&4@=&AR;W5G:"!(5%10+B`@4F5T=7)N<R!D;W=N;&]A9&5D(&9I;&4@87,@
M82!S=')I;F<@:6XM;65M;W)Y#0H@("`@("H@5&AI<R!I<R!B97-T('5S960@
M9F]R('-M86QL(&9I;&5S#0H@("`@("H-"B`@("`@*B!)9B!A;B!(5%10('!R
M;WAY(&AA<R!B965N(&-O;F9I9W5R960@*&AT='!?<')O>'D@4$5!4E]#;VYF
M:6<-"B`@("`@*B!S971T:6YG*2P@=&AE('!R;WAY('=I;&P@8F4@=7-E9"X-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@("1U<FP@("`@("`@=&AE
M(%523"!T;R!D;W=N;&]A9`T*("`@("`J($!P87)A;2!S=')I;F<@("1S879E
M7V1I<B`@9&ER96-T;W)Y('1O('-A=F4@9FEL92!I;@T*("`@("`J($!P87)A
M;2!F86QS97QS=')I;F=\87)R87D@)&QA<W1M;V1I9FEE9"!H96%D97(@=F%L
M=65S('1O(&-H96-K(&%G86EN<W0@9F]R(&-A8VAI;F<-"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('5S92!F86QS92!T;R!R971U<FX@=&AE
M(&AE861E<B!V86QU97,@9G)O;2!T:&ES(&1O=VYL;V%D#0H@("`@("H@0'!A
M<F%M(&9A;'-E?&%R<F%Y("1A8V-E<'0@06-C97!T(&AE861E<G,@=&\@<V5N
M9`T*("`@("`J($!R971U<FX@<W1R:6YG?&%R<F%Y("!2971U<FYS('1H92!C
M;VYT96YT<R!O9B!T:&4@9&]W;FQO861E9"!F:6QE(&]R(&$@4$5!4@T*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!E<G)O<B!O;B!F86EL=7)E+B`@
M268@=&AE(&5R<F]R(&ES(&-A=7-E9"!B>0T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!S;V-K970M<F5L871E9"!E<G)O<G,L('1H92!E<G)O<B!O
M8FIE8W0@=VEL;`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!H879E
M('1H92!F<V]C:V]P96X@97)R;W(@8V]D92!A=F%I;&%B;&4@=&AR;W5G:`T*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!G971#;V1E*"DN("!)9B!C
M86-H:6YG(&ES(')E<75E<W1E9"P@=&AE;B!R971U<FX@=&AE(&AE861E<@T*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!V86QU97,N#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&1O=VYL;V%D2'1T<"@D=7)L+"`D;&%S=&UO9&EF:65D(#T@;G5L;"P@)&%C
M8V5P="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)&EN9F\@/2!P87)S95]U
M<FPH)'5R;"D[#0H@("`@("`@(&EF("@A:7-S970H)&EN9F];)W-C:&5M92==
M*2!\?"`A:6Y?87)R87DH)&EN9F];)W-C:&5M92==+"!A<G)A>2@G:'1T<"<L
M("=H='1P<R<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T-A;FYO="!D;W=N;&]A9"!N;VXM:'1T<"!54DP@(B<@+B`D=7)L
M("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1I;F9O
M6R=H;W-T)UTI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G0V%N;F]T(&1O=VYL;V%D(&9R;VT@;F]N+5523"`B)R`N("1U<FP@
M+B`G(B<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&AO<W0@
M/2`D:6YF;ULG:&]S="==.PT*("`@("`@("`@("`@:68@*"%A<G)A>5]K97E?
M97AI<W1S*"=P;W)T)RP@)&EN9F\I*2![#0H@("`@("`@("`@("`@("`@)&EN
M9F];)W!O<G0G72`](&YU;&P[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)W!A=&@G+"`D:6YF;RDI('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULG<&%T:"==(#T@;G5L;#L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1P;W)T(#T@)&EN9F];)W!O<G0G73L-"B`@
M("`@("`@("`@("1P871H(#T@)&EN9F];)W!A=&@G73L-"B`@("`@("`@?0T*
M("`@("`@("`D<')O>'E?:&]S="`]("1P<F]X>5]P;W)T(#T@)'!R;WAY7W5S
M97(@/2`D<')O>'E?<&%S<R`]("<G.PT*("`@("`@("!I9B`H)'1H:7,M/F-O
M;F9I9RT^9V5T*"=H='1P7W!R;WAY)RDF)B`-"B`@("`@("`@("`@("`@)'!R
M;WAY(#T@<&%R<V5?=7)L*"1T:&ES+3YC;VYF:6<M/F=E="@G:'1T<%]P<F]X
M>2<I*2D@>PT*("`@("`@("`@("`@)'!R;WAY7VAO<W0@/2!`)'!R;WAY6R=H
M;W-T)UT[#0H@("`@("`@("`@("!I9B`H:7-S970H)'!R;WAY6R=S8VAE;64G
M72D@)B8@)'!R;WAY6R=S8VAE;64G72`]/2`G:'1T<',G*2![#0H@("`@("`@
M("`@("`@("`@)'!R;WAY7VAO<W0@/2`G<W-L.B\O)R`N("1P<F]X>5]H;W-T
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2!`
M)'!R;WAY6R=P;W)T)UT[#0H@("`@("`@("`@("`D<')O>'E?=7-E<B`]($`D
M<')O>'E;)W5S97(G73L-"B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@0"1P
M<F]X>5LG<&%S<R==.PT*#0H@("`@("`@("`@("!I9B`H)'!R;WAY7W!O<G0@
M/3T@)R<I('L-"B`@("`@("`@("`@("`@("`D<')O>'E?<&]R="`](#@P.#`[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y
M*"1P;W)T*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S8VAE
M;64G72D@)B8@)&EN9F];)W-C:&5M92==(#T]("=H='1P<R<I('L-"B`@("`@
M("`@("`@("`@("`D<&]R="`](#0T,SL-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'!O<G0@/2`X,#L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!)9B`H:7-S970H)'!R;WAY6R=H;W-T)UTI
M*2![#0H@("`@("`@("`@("`D<F5Q=65S="`](")'150@)'5R;"!(5%10+S$N
M,5QR7&XB.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)')E<75E
M<W0@/2`B1T54("1P871H($A45%`O,2XQ7')<;B([#0H@("`@("`@('T-"@T*
M("`@("`@("`D:69M;V1I9FEE9'-I;F-E(#T@)R<[#0H@("`@("`@(&EF("AI
M<U]A<G)A>2@D;&%S=&UO9&EF:65D*2D@>PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1L87-T;6]D:69I961;)TQA<W0M36]D:69I960G72DI('L-"B`@("`@
M("`@("`@("`@("`D:69M;V1I9FEE9'-I;F-E(#T@)TEF+4UO9&EF:65D+5-I
M;F-E.B`G("X@)&QA<W1M;V1I9FEE9%LG3&%S="U-;V1I9FEE9"==("X@(EQR
M7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1L
M87-T;6]D:69I961;)T5486<G72DI('L-"B`@("`@("`@("`@("`@("`D:69M
M;V1I9FEE9'-I;F-E("X]("))9BU.;VYE+4UA=&-H.B`D;&%S=&UO9&EF:65D
M6T5486==7')<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D:69M;V1I9FEE9'-I;F-E(#T@*"1L87-T;6]D:69I
M960@/R`B268M36]D:69I960M4VEN8V4Z("1L87-T;6]D:69I961<<EQN(B`Z
M("<G*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5Q=65S="`N/2`B2&]S=#H@
M)&AO<W0Z)'!O<G1<<EQN(B`N("1I9FUO9&EF:65D<VEN8V4@+@T*("`@("`@
M("`@("`@(E5S97(M06=E;G0Z(%!%05(O,2XT+CDO4$A0+R(@+B!02%!?5D52
M4TE/3B`N(")<<EQN(CL-"B`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=U<V5R;F%M92<I.PT*("`@("`@("`D<&%S<W=O<F0@/2`D
M=&AI<RT^8V]N9FEG+3YG970H)W!A<W-W;W)D)RD[#0H@("`@("`@(&EF("@D
M=7-E<FYA;64@)B8@)'!A<W-W;W)D*2![#0H@("`@("`@("`@("`D=&UP(#T@
M8F%S938T7V5N8V]D92@B)'5S97)N86UE.B1P87-S=V]R9"(I.PT*("`@("`@
M("`@("`@)')E<75E<W0@+CT@(D%U=&AO<FEZ871I;VXZ($)A<VEC("1T;7!<
M<EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!R;WAY7VAO<W0@(3T@
M)R<@)B8@)'!R;WAY7W5S97(@(3T@)R<I('L-"B`@("`@("`@("`@("1R97%U
M97-T("X]("=0<F]X>2U!=71H;W)I>F%T:6]N.B!"87-I8R`G("X-"B`@("`@
M("`@("`@("`@("!B87-E-C1?96YC;V1E*"1P<F]X>5]U<V5R("X@)SHG("X@
M)'!R;WAY7W!A<W,I("X@(EQR7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D86-C97!T*2![#0H@("`@("`@("`@("`D<F5Q=65S="`N/2`G06-C97!T
M.B`G("X@:6UP;&]D92@G+"`G+"`D86-C97!T*2`N(")<<EQN(CL-"B`@("`@
M("`@?0T*("`@("`@("`D<F5Q=65S="`N/2`B0V]N;F5C=&EO;CH@8VQO<V5<
M<EQN(CL-"B`@("`@("`@)')E<75E<W0@+CT@(EQR7&XB.PT*("`@("`@("!I
M9B`H)'!R;WAY7VAO<W0@(3T@)R<I('L-"B`@("`@("`@("`@("1F<"`]($!F
M<V]C:V]P96XH)'!R;WAY7VAO<W0L("1P<F]X>5]P;W)T+"`D97)R;F\L("1E
M<G)S='(L(#$U*3L-"B`@("`@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O;FYE8W1I;VX@
M=&\@8"1P<F]X>5]H;W-T.B1P<F]X>5]P;W)T)R!F86EL960Z("1E<G)S='(B
M+`T*("`@("`@("`@("`@("`@("`@("`M.3(W-BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-S970H)&EN
M9F];)W-C:&5M92==*2`F)B`D:6YF;ULG<V-H96UE)UT@/3T@)VAT='!S)RD@
M>PT*("`@("`@("`@("`@("`@("1H;W-T(#T@)W-S;#HO+R<@+B`D:&]S=#L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH
M)&AO<W0L("1P;W)T+"`D97)R;F\L("1E<G)S='(I.PT*("`@("`@("`@("`@
M:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@B0V]N;F5C=&EO;B!T;R!@)&AO<W0Z)'!O<G0G(&9A:6QE9#H@
M)&5R<G-T<B(L("1E<G)N;RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@9G=R:71E*"1F<"P@)')E<75E<W0I.PT*("`@("`@("`D:&5A
M9&5R<R`](&%R<F%Y*"D[#0H@("`@("`@('=H:6QE("AT<FEM*"1L:6YE(#T@
M9F=E=',H)&9P+"`Q,#(T*2DI('L-"B`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O7BA;7CI=*RDZ7',K*"XJ*5QS*B0O)RP@)&QI;F4L("1M871C:&5S
M*2D@>PT*("`@("`@("`@("`@("`@("1H96%D97)S6W-T<G1O;&]W97(H)&UA
M=&-H97-;,5TI72`]('1R:6TH)&UA=&-H97-;,ETI.PT*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ>2%144"\Q+ELP,5T@*%LP+3E=>S-]
M*2!\)RP@)&QI;F4L("1M871C:&5S*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("@D;6%T8VAE<ULQ72`]/2`S,#0@)B8@*"1L87-T;6]D:69I960@?'P@*"1L
M87-T;6]D:69I960@/3T](&9A;'-E*2DI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H)&UA=&-H97-;,5T@(3T@,C`P*2![#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&:6QE(&AT='`Z
M+R\D:&]S=#HD<&]R="1P871H(&YO="!V86QI9"`H<F5C96EV960Z("1L:6YE
M*2(L("AI;G0I("1M871C:&5S6S%=*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1H
M96%D97)S6R=C;VYT96YT+6QE;F=T:"==*2D@>PT*("`@("`@("`@("`@)&QE
M;F=T:"`]("1H96%D97)S6R=C;VYT96YT+6QE;F=T:"==.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&QE;F=T:"`]("TQ.PT*("`@("`@("!]
M#0H@("`@("`@("1D871A(#T@)R<[#0H@("`@("`@('=H:6QE("@D8VAU;FL@
M/2!`9G)E860H)&9P+"`X,3DR*2D@>PT*("`@("`@("`@("`@)&1A=&$@+CT@
M)&-H=6YK.PT*("`@("`@("!]#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@
M("`@("!I9B`H)&QA<W1M;V1I9FEE9"`]/3T@9F%L<V4@?'P@)&QA<W1M;V1I
M9FEE9"D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1H96%D97)S6R=E=&%G
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9"`](&%R<F%Y
M*"=%5&%G)R`]/B`D:&5A9&5R<ULG971A9R==*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG;&%S="UM;V1I9FEE
M9"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;&%S=&UO
M9&EF:65D*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;&%S=&UO9&EF:65D
M6R=,87-T+4UO9&EF:65D)UT@/2`D:&5A9&5R<ULG;&%S="UM;V1I9FEE9"==
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1L87-T;6]D:69I960@/2`D:&5A9&5R<ULG;&%S="UM;V1I9FEE9"==
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@D9&%T82P@)&QA<W1M;V1I9FEE9"P@)&AE861E
M<G,I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]
M#0I]#0H_/@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4G5N5&5S="YP:'``````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,T-38P`#$P-3$U-#,Q
M,#4W`#`R,#(Q-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!014%27U)U;E1E<W0-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4G5N5&5S="YP:'`L
M=B`Q+C(P(#(P,#8O,#(O,#,@,#(Z,#@Z,3$@8V5L;&]G($5X<"`D#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C,N,PT*("HO#0H-"B\J*@T*("H@9F]R(&5R<F]R(&AA;F1L:6YG#0H@*B\-
M"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2
M+T-O;F9I9RYP:'`G.PT*#0ID969I;F4H)T1%5$%)3$5$)RP@,2D[#0IP=71E
M;G8H(E!(4%]014%27U)53E1%4U13/3$B*3L-"@T*+RHJ#0H@*B!3:6UP;&EF
M:65D('9E<G-I;VX@;V8@4$A0)W,@=&5S="!S=6ET90T*("H-"B`J(%1R>2!I
M="!W:71H.@T*("H-"B`J("0@<&AP("UR("=I;F-L=61E("(N+B]014%2+U)U
M;E1E<W0N<&AP(CL@)'0];F5W(%!%05)?4G5N5&5S=#L@)&\])'0M/G)U;B@B
M+B]P96%R7W-Y<W1E;2YP:'!T(BD[<')I;G1?<B@D;RD[)PT*("H-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N,RXS#0H@*B\-"F-L87-S(%!%05)?4G5N5&5S=`T*>PT*("`@
M('9A<B`D7VQO9V=E<CL-"B`@("!V87(@)%]O<'1I;VYS.PT*#0H@("`@+RHJ
M#0H@("`@("H@06X@;V)J96-T('1H870@<W5P<&]R=',@=&AE(%!%05)?0V]M
M;6]N+3YL;V<H*2!S:6=N871U<F4L(&]R(&YU;&P-"B`@("`@*B!`<&%R86T@
M4$5!4E]#;VUM;VY\;G5L;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?
M4G5N5&5S="@D;&]G9V5R(#T@;G5L;"P@)&]P=&EO;G,@/2!A<G)A>2@I*0T*
M("`@('L-"B`@("`@("`@:68@*&ES7VYU;&PH)&QO9V=E<BDI('L-"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"B`@("`@
M("`@("`@("1L;V=G97(@/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/E]L;V=G97(@/2`D;&]G9V5R.PT*("`@("`@("`D
M=&AI<RT^7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("!]#0H-"B`@("`O+PT*
M("`@("\O("!2=6X@86X@:6YD:79I9'5A;"!T97-T(&-A<V4N#0H@("`@+R\-
M"@T*("`@(&9U;F-T:6]N(')U;B@D9FEL92P@)&EN:5]S971T:6YG<R`]("<G
M*0T*("`@('L-"B`@("`@("`@)&-W9"`](&=E=&-W9"@I.PT*("`@("`@("`D
M8V]N9B`]("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("1P
M:'`@/2`D8V]N9BT^9V5T*"=P:'!?8FEN)RD[#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)W!H<'5N:70G72DI('L-"B`@("`@("`@("`@
M("1C;60@/2`B)'!H<"1I;FE?<V5T=&EN9W,@+68@)&9I;&4B.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;&]G9V5R*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H,BP@)U)U;FYI;F<@8V]M;6%N
M9"`B)R`N("1C;60@+B`G(B<I.PT*("`@("`@("`@("`@?0T*("`@(`T*("`@
M("`@("`@("`@)'-A=F5D:7(@/2!G971C=V0H*3L@+R\@:6X@8V%S92!T:&4@
M=&5S="!M;W9E<R!U<R!A<F]U;F0-"B`@("`@("`@("`@(&-H9&ER*&1I<FYA
M;64H)&9I;&4I*3L-"B`@("`@("`@("`@(&5C:&\@8"1C;61@.PT*("`@("`@
M("`@("`@8VAD:7(H)'-A=F5D:7(I.PT*("`@("`@("`@("`@<F5T=7)N("=0
M05-3140G.R`O+R!W92!H879E(&YO('=A>2!O9B!K;F]W:6YG('1H:7,@:6YF
M;W)M871I;VX@<V\@87-S=6UE('!A<W-I;F<-"B`@("`@("`@?0T*("`@("`@
M("`O+W9A<E]D=6UP*"1P:'`I.V5X:70[#0H@("`@("`@(&=L;V)A;"`D;&]G
M7V9O<FUA="P@)&EN9F]?<&%R86US+"`D:6YI7V]V97)W<FET97,[#0H-"B`@
M("`@("`@)&EN9F]?<&%R86US(#T@)R<[#0H@("`@("`@("1L;V=?9F]R;6%T
M(#T@)TQ%3T0G.PT*#0H@("`@("`@("\O($QO860@=&AE('-E8W1I;VYS(&]F
M('1H92!T97-T(&9I;&4N#0H@("`@("`@("1S96-T:6]N7W1E>'0@/2!A<G)A
M>2@-"B`@("`@("`@("`@("=415-4)R`@("`]/B`G*'5N;F%M960@=&5S="DG
M+`T*("`@("`@("`@("`@)U-+25!)1B<@(#T^("<G+`T*("`@("`@("`@("`@
M)T=%5"<@("`@(#T^("<G+`T*("`@("`@("`@("`@)T%21U,G("`@(#T^("<G
M+`T*("`@("`@("`@("`@)T-,14%.)R`@(#T^("<G+`T*("`@("`@("`I.PT*
M#0H@("`@("`@("1F:6QE(#T@<F5A;'!A=&@H)&9I;&4I.PT*("`@("`@("!I
M9B`H(6ES7V9I;&4H)&9I;&4I('Q\("$D9G`@/2!F;W!E;B@D9FEL92P@(G(B
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A
M;FYO="!O<&5N('1E<W0@9FEL93H@)&9I;&4B*3L-"B`@("`@("`@?0T*#0H@
M("`@("`@("1S96-T:6]N(#T@)R<[#0H@("`@("`@('=H:6QE("@A9F5O9B@D
M9G`I*2![#0H@("`@("`@("`@("`D;&EN92`](&9G971S*"1F<"D[#0H-"B`@
M("`@("`@("`@("\O($UA=&-H('1H92!B96=I;FYI;F<@;V8@82!S96-T:6]N
M+@T*("`@("`@("`@("`@:68@*&5R96<H)UXM+2A;02U:72LI+2TG+"1L:6YE
M+"1R*2D@>PT*("`@("`@("`@("`@("`@("1S96-T:6]N(#T@)');,5T[#0H@
M("`@("`@("`@("`@("`@)'-E8W1I;VY?=&5X=%LD<V5C=&EO;ET@/2`G)SL-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T@96QS
M96EF("AE;7!T>2@D<V5C=&EO;BDI('L-"B`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@B26YV86QI9"!S96-T:6]N<R!F;W)M871S(&EN('1E<W0@9FEL93H@
M)&9I;&4B*3L-"@D)"7T-"@T*("`@("`@("`@("`@+R\@061D('1O('1H92!S
M96-T:6]N('1E>'0N#0H@("`@("`@("`@("`D<V5C=&EO;E]T97AT6R1S96-T
M:6]N72`N/2`D;&EN93L-"B`@("`@("`@?0T*("`@("`@("!F8VQO<V4H)&9P
M*3L-"@T*("`@("`@("`D<VAO<G1N86UE(#T@<W1R7W)E<&QA8V4H)&-W9"`N
M($1)4D5#5$]265]315!!4D%43U(L("<G+"`D9FEL92D[#0H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S:6UP;&4G72DI('L-"B`@("`@
M("`@("`@("1T97-T960@/2!T<FEM*"1S96-T:6]N7W1E>'1;)U1%4U0G72D@
M+B`B6R1S:&]R=&YA;65=(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T97-T960@/2!T<FEM*"1S96-T:6]N7W1E>'1;)U1%4U0G72D@+B`G
M("<[#0H@("`@("`@('T-"@T*("`@("`@("`D=&UP(#T@<F5A;'!A=&@H9&ER
M;F%M92@D9FEL92DI.PT*("`@("`@("`D=&UP7W-K:7!I9B`]("1T;7`@+B!U
M;FEQ:60H)R]P:'!T+B<I.PT*("`@("`@("`D=&UP7V9I;&4@("`](&5R96=?
M<F5P;&%C92@G7"YP:'!T)"<L)RYP:'`G+"1F:6QE*3L-"B`@("`@("`@)'1M
M<%]P;W-T("`@/2`D=&UP("X@=6YI<6ED*"<O<&AP="XG*3L-"@T*("`@("`@
M("!`=6YL:6YK*"1T;7!?<VMI<&EF*3L-"B`@("`@("`@0'5N;&EN:R@D=&UP
M7V9I;&4I.PT*("`@("`@("!`=6YL:6YK*"1T;7!?<&]S="D[#0H-"B`@("`@
M("`@+R\@=6YL:6YK(&]L9"!T97-T(')E<W5L=',-"B`@("`@("`@0'5N;&EN
M:RAE<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N9&EF9B<L)&9I;&4I*3L-"B`@
M("`@("`@0'5N;&EN:RAE<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N;&]G)RPD
M9FEL92DI.PT*("`@("`@("!`=6YL:6YK*&5R96=?<F5P;&%C92@G7"YP:'!T
M)"<L)RYE>'`G+"1F:6QE*2D[#0H@("`@("`@($!U;FQI;FLH97)E9U]R97!L
M86-E*"=<+G!H<'0D)RPG+F]U="<L)&9I;&4I*3L-"@T*("`@("`@("`O+R!#
M:&5C:R!I9B!T97-T('-H;W5L9"!B92!S:VEP<&5D+@T*("`@("`@("`D:6YF
M;R`]("<G.PT*("`@("`@("`D=V%R;B`](&9A;'-E.PT*("`@("`@("!I9B`H
M87)R87E?:V5Y7V5X:7-T<R@G4TM)4$E&)RP@)'-E8W1I;VY?=&5X="DI('L-
M"B`@("`@("`@("`@(&EF("AT<FEM*"1S96-T:6]N7W1E>'1;)U-+25!)1B==
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YS879E7W1E>'0H)'1M<%]S
M:VEP:68L("1S96-T:6]N7W1E>'1;)U-+25!)1B==*3L-"B`@("`@("`@("`@
M("`@("`O+R1E>'1R82`]('-U8G-T<BA02%!?3U,L(#`L(#,I("$]/2`B5TE.
M(B`_#0H@("`@("`@("`@("`@("`@+R\@("`@(G5N<V5T(%)%455%4U1?3454
M2$]$.R(Z("(B.PT*#0H@("`@("`@("`@("`@("`@+R\D;W5T<'5T(#T@8"1E
M>'1R82`D<&AP("1I;F9O7W!A<F%M<R`M9B`D=&UP7W-K:7!I9F`[#0H@("`@
M("`@("`@("`@("`@)&]U='!U="`](&`D<&AP("1I;F9O7W!A<F%M<R`M9B`D
M=&UP7W-K:7!I9F`[#0H@("`@("`@("`@("`@("`@=6YL:6YK*"1T;7!?<VMI
M<&EF*3L-"B`@("`@("`@("`@("`@("!I9B`H97)E9VDH(EYS:VEP(BP@=')I
M;2@D;W5T<'5T*2DI('L-"B`@("`@("`@("`@("`@("`@("`@)'-K:7!R96%S
M;VX@/2`B4TM)4"`D=&5S=&5D(CL-"B`@("`@("`@("`@("`@("`@("`@)')E
M87-O;B`]("AE<F5G:2@B7G-K:7!;6SIS<&%C93I=72HH+BLI7"0B+"!T<FEM
M*"1O=71P=70I*2D@/R!E<F5G:5]R97!L86-E*")><VMI<%M;.G-P86-E.EU=
M*B@N*RE<)"(L(")<7#$B+"!T<FEM*"1O=71P=70I*2`Z($9!3%-%.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E87-O;BD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-K:7!R96%S;VX@+CT@(B`H<F5A<V]N.B`D<F5A<V]N
M*2([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W%U:65T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQO9V=E<BT^;&]G*#`L
M("1S:VEP<F5A<V]N*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&]L9%]P:'`I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<&AP(#T@)&]L9%]P:'`[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("=32TE0
M4$5$)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&5R96=I*")>:6YF;R(L('1R:6TH)&]U='!U="DI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1R96%S;VX@/2`H97)E9R@B7FEN9F];6SIS<&%C93I=72HH
M+BLI7"0B+"!T<FEM*"1O=71P=70I*2D@/R!E<F5G7W)E<&QA8V4H(EYI;F9O
M6ULZ<W!A8V4Z75TJ*"XK*5PD(BP@(EQ<,2(L('1R:6TH)&]U='!U="DI(#H@
M1D%,4T4[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<F5A<V]N*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("(@*&EN9F\Z("1R96%S
M;VXI(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H97)E9VDH(EYW87)N(BP@=')I;2@D
M;W5T<'5T*2DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E87-O;B`]("AE
M<F5G*")>=V%R;EM;.G-P86-E.EU=*B@N*RE<)"(L('1R:6TH)&]U='!U="DI
M*2`_(&5R96=?<F5P;&%C92@B7G=A<FY;6SIS<&%C93I=72HH+BLI7"0B+"`B
M7%PQ(BP@=')I;2@D;W5T<'5T*2D@.B!&04Q313L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1R96%S;VXI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1W87)N(#T@=')U93L@+RH@;VYL>2!I9B!T:&5R92!I<R!A(')E87-O;B`J
M+PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F\@/2`B("AW87)N.B`D
M<F5A<V]N*2([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O
M+R!792=V92!S871I<V9I960@=&AE('!R96-O;F1I=&EO;G,@+2!R=6X@=&AE
M('1E<W0A#0H@("`@("`@("1T:&ES+3YS879E7W1E>'0H)'1M<%]F:6QE+"1S
M96-T:6]N7W1E>'1;)T9)3$4G72D[#0H-"B`@("`@("`@)&%R9W,@/2`D<V5C
M=&EO;E]T97AT6R=!4D=3)UT@/R`G("TM("<N)'-E8W1I;VY?=&5X=%LG05)'
M4R==(#H@)R<[#0H-"B`@("`@("`@)&-M9"`]("(D<&AP)&EN:5]S971T:6YG
M<R`M9B`D=&UP7V9I;&4D87)G<R`R/B8Q(CL-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?;&]G9V5R*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]L;V=G
M97(M/FQO9R@R+"`G4G5N;FEN9R!C;VUM86YD("(G("X@)&-M9"`N("<B)RD[
M#0H@("`@("`@('T-"@T*("`@("`@("`D<V%V961I<B`](&=E=&-W9"@I.R`O
M+R!I;B!C87-E('1H92!T97-T(&UO=F5S('5S(&%R;W5N9`T*("`@("`@("!I
M9B`H:7-S970H)'-E8W1I;VY?=&5X=%LG4D5455).4R==*2D@>PT*("`@("`@
M("`@("`@;V)?<W1A<G0H*3L-"B`@("`@("`@("`@('-Y<W1E;2@D8VUD+"`D
M<F5T=7)N7W9A;'5E*3L-"B`@("`@("`@("`@("1O=70@/2!O8E]G971?8V]N
M=&5N=',H*3L-"B`@("`@("`@("`@(&]B7V5N9%]C;&5A;B@I.PT*("`@("`@
M("`@("`@0'5N;&EN:R@D=&UP7W!O<W0I.PT*("`@("`@("`@("`@)'-E8W1I
M;VY?=&5X=%LG4D5455).4R==(#T@*&EN="D@=')I;2@D<V5C=&EO;E]T97AT
M6R=215154DY3)UTI.PT*("`@("`@("`@("`@)')E='5R;F9A:6P@/2`H)')E
M='5R;E]V86QU92`A/2`D<V5C=&EO;E]T97AT6R=215154DY3)UTI.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&]U="`](&`D8VUD8#L-"B`@
M("`@("`@("`@("1R971U<FYF86EL(#T@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@8VAD:7(H)'-A=F5D:7(I.PT*#0H@("`@("`@(&EF("@D<V5C=&EO
M;E]T97AT6R=#3$5!3B==*2![#0H@("`@("`@("`@("`O+R!P97)F;W)M('1E
M<W0@8VQE86YU<`T*("`@("`@("`@("`@)'1H:7,M/G-A=F5?=&5X="@D8VQE
M86X@/2`D=&UP("X@=6YI<6ED*"<O<&AP="XG*2P@)'-E8W1I;VY?=&5X=%LG
M0TQ%04XG72D[#0H@("`@("`@("`@("!@)'!H<"`D8VQE86Y@.PT*("`@("`@
M("`@("`@0'5N;&EN:R@D8VQE86XI.PT*("`@("`@("!]#0H@("`@("`@("\O
M($1O97,@=&AE(&]U='!U="!M871C:"!W:&%T(&ES(&5X<&5C=&5D/PT*("`@
M("`@("`D;W5T<'5T(#T@=')I;2@D;W5T*3L-"B`@("`@("`@)&]U='!U="`]
M('!R96=?<F5P;&%C92@G+UQR7&XO)RP@(EQN(BP@)&]U='!U="D[#0H-"B`@
M("`@("`@:68@*&ES<V5T*"1S96-T:6]N7W1E>'1;)T584$5#5$8G72D@?'P@
M:7-S970H)'-E8W1I;VY?=&5X=%LG15A014-44D5'15@G72DI('L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D<V5C=&EO;E]T97AT6R=%6%!%0U1&)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'=A;G1E9"`]('1R:6TH)'-E8W1I;VY?=&5X
M=%LG15A014-41B==*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)'=A;G1E9"`]('1R:6TH)'-E8W1I;VY?=&5X=%LG15A014-4
M4D5'15@G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=V%N=&5D
M7W)E(#T@<')E9U]R97!L86-E*"<O7')<;B\G+")<;B(L)'=A;G1E9"D[#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'-E8W1I;VY?=&5X=%LG15A014-41B==
M*2D@>PT*("`@("`@("`@("`@("`@("1W86YT961?<F4@/2!P<F5G7W%U;W1E
M*"1W86YT961?<F4L("<O)RD[#0H@("`@("`@("`@("`@("`@+R\@4W1I8VL@
M=&\@8F%S:6-S#0H@("`@("`@("`@("`@("`@)'=A;G1E9%]R92`]('-T<E]R
M97!L86-E*"(E<R(L("(N*S\B+"`D=V%N=&5D7W)E*3L@+R]N;W0@9W)E961Y
M#0H@("`@("`@("`@("`@("`@)'=A;G1E9%]R92`]('-T<E]R97!L86-E*"(E
M:2(L(");*UPM73];,"TY72LB+"`D=V%N=&5D7W)E*3L-"B`@("`@("`@("`@
M("`@("`D=V%N=&5D7W)E(#T@<W1R7W)E<&QA8V4H(B5D(BP@(ELP+3E=*R(L
M("1W86YT961?<F4I.PT*("`@("`@("`@("`@("`@("1W86YT961?<F4@/2!S
M=')?<F5P;&%C92@B)7@B+"`B6S`M.6$M9D$M1ETK(BP@)'=A;G1E9%]R92D[
M#0H@("`@("`@("`@("`@("`@)'=A;G1E9%]R92`]('-T<E]R97!L86-E*"(E
M9B(L(");*UPM73]<+C];,"TY72M<+C];,"TY72HH12T_6S`M.5TK*3\B+"`D
M=V%N=&5D7W)E*3L-"B`@("`@("`@("`@("`@("`D=V%N=&5D7W)E(#T@<W1R
M7W)E<&QA8V4H(B5C(BP@(BXB+"`D=V%N=&5D7W)E*3L-"B`@("`@("`@("`@
M("`@("`O+R`E9B!A;&QO=W,@='=O('!O:6YT<R`B+2XP+C`B(&)U="!T:&%T
M(&ES('1H92!B97-T("IS:6UP;&4J(&5X<')E<W-I;VX-"B`@("`@("`@("`@
M('T-"B`@("`O*B!$14)51R!93U52(%)%1T58($A%4D4-"B`@("`@("`@("`@
M('9A<E]D=6UP*"1W86YT961?<F4I.PT*("`@("`@("`@("`@<')I;G0H<W1R
M7W)E<&5A="@G/2<L(#@P*2`N(")<;B(I.PT*("`@("`@("`@("`@=F%R7V1U
M;7`H)&]U='!U="D[#0H@("`@*B\-"B`@("`@("`@("`@(&EF("@A)')E='5R
M;F9A:6P@)B8@<')E9U]M871C:"@B+UXD=V%N=&5D7W)E7"0O<R(L("1O=71P
M=70I*2![#0H@("`@("`@("`@("`@("`@0'5N;&EN:R@D=&UP7V9I;&4I.PT*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=Q
M=6EE="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQO9V=E
M<BT^;&]G*#`L(")005-3("1T97-T960D:6YF;R(I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]L9%]P:'`I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1P:'`@/2`D;VQD7W!H<#L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("=005-3140G
M.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D=V%N=&5D(#T@=')I;2@D<V5C=&EO;E]T97AT6R=%6%!%0U0G72D[
M#0H@("`@("`@("`@("`D=V%N=&5D(#T@<')E9U]R97!L86-E*"<O7')<;B\G
M+")<;B(L)'=A;G1E9"D[#0H@("`@("`@("\O(&-O;7!A<F4@86YD(&QE879E
M(&]N('-U8V-E<W,-"B`@("`@("`@("`@("1O:R`]("@P(#T]('-T<F-M<"@D
M;W5T<'5T+"1W86YT960I*3L-"B`@("`@("`@("`@(&EF("@A)')E='5R;F9A
M:6P@)B8@)&]K*2![#0H@("`@("`@("`@("`@("`@0'5N;&EN:R@D=&UP7V9I
M;&4I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=Q=6EE="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQO9V=E<BT^;&]G*#`L(")005-3("1T97-T960D:6YF;R(I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]L9%]P
M:'`I*2![#0H@("`@("`@("`@("`@("`@("`@("1P:'`@/2`D;VQD7W!H<#L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("=0
M05-3140G.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@
M+R\@5&5S="!F86EL960@<V\@=V4@;F5E9"!T;R!R97!O<G0@9&5T86EL<RX-
M"B`@("`@("`@:68@*"1W87)N*2![#0H@("`@("`@("`@("`D=&AI<RT^7VQO
M9V=E<BT^;&]G*#`L(")705).("1T97-T960D:6YF;R(I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO9R@P+"`B
M1D%)3"`D=&5S=&5D)&EN9F\B*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF
M("AI<W-E="@D<V5C=&EO;E]T97AT6R=215154DY3)UTI*2![#0H@("`@("`@
M("`@("`D1TQ/0D%,4ULG7U]02%!?1D%)3$5$7U1%4U137U\G75M=(#T@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1F
M:6QE+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T97-T7VYA;64G
M(#T^("1T97-T960L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]U
M='!U="<@/3X@97)E9U]R97!L86-E*"=<+G!H<'0D)RPG+FQO9R<L("1F:6QE
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&EF9B<@("`]/B!E
M<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N9&EF9B<L("1F:6QE*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:6YF;R<@("`]/B`D:6YF;RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5T=7)N)R`]/B`D<F5T=7)N
M7W9A;'5E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?7U!(4%]&04E,
M141?5$535%-?7R==6UT@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1E<W1?;F%M92<@/3X@)'1E<W1E9"P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;W5T<'5T)R`]/B!E<F5G7W)E<&QA8V4H)UPN
M<&AP="0G+"<N;&]G)RP@)&9I;&4I+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D:69F)R`@(#T^(&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYD
M:69F)RP@)&9I;&4I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I
M;F9O)R`@(#T^("1I;F9O+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!W<FET92`N97AP#0H@("`@
M("`@(&EF("AS=')P;W,H)&QO9U]F;W)M870L)T4G*2`A/3T@1D%,4T4I('L-
M"B`@("`@("`@("`@("1L;V=N86UE(#T@97)E9U]R97!L86-E*"=<+G!H<'0D
M)RPG+F5X<"<L)&9I;&4I.PT*("`@("`@("`@("`@:68@*"$D;&]G(#T@9F]P
M96XH)&QO9VYA;64L)W<G*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*")#86YN;W0@8W)E871E('1E<W0@;&]G("T@)&QO
M9VYA;64B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9W<FET92@D
M;&]G+"1W86YT960I.PT*("`@("`@("`@("`@9F-L;W-E*"1L;V<I.PT*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@=W)I=&4@+F]U=`T*("`@("`@("!I9B`H
M<W1R<&]S*"1L;V=?9F]R;6%T+"=/)RD@(3T]($9!3%-%*2![#0H@("`@("`@
M("`@("`D;&]G;F%M92`](&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYO=70G
M+"1F:6QE*3L-"B`@("`@("`@("`@(&EF("@A)&QO9R`](&9O<&5N*"1L;V=N
M86UE+"=W)RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@B0V%N;F]T(&-R96%T92!T97-T(&QO9R`M("1L;V=N86UE(BD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F=W)I=&4H)&QO9RPD;W5T
M<'5T*3L-"B`@("`@("`@("`@(&9C;&]S92@D;&]G*3L-"B`@("`@("`@?0T*
M#0H@("`@("`@("\O('=R:71E("YD:69F#0H@("`@("`@(&EF("AS=')P;W,H
M)&QO9U]F;W)M870L)T0G*2`A/3T@1D%,4T4I('L-"B`@("`@("`@("`@("1L
M;V=N86UE(#T@97)E9U]R97!L86-E*"=<+G!H<'0D)RPG+F1I9F8G+"1F:6QE
M*3L-"B`@("`@("`@("`@(&EF("@A)&QO9R`](&9O<&5N*"1L;V=N86UE+"=W
M)RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B0V%N;F]T(&-R96%T92!T97-T(&QO9R`M("1L;V=N86UE(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!F=W)I=&4H)&QO9RP@)'1H:7,M/F=E
M;F5R871E7V1I9F8H)'=A;G1E9"P@)&]U='!U="P-"B`@("`@("`@("`@("`@
M("!I<W-E="@D<V5C=&EO;E]T97AT6R=215154DY3)UTI(#\@87)R87DH=')I
M;2@D<V5C=&EO;E]T97AT6R=215154DY3)UTI+`T*("`@("`@("`@("`@("`@
M("`@("`D<F5T=7)N7W9A;'5E*2`Z(&YU;&PI*3L-"B`@("`@("`@("`@(&9C
M;&]S92@D;&]G*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O('=R:71E("YL
M;V<-"B`@("`@("`@:68@*'-T<G!O<R@D;&]G7V9O<FUA="PG3"<I("$]/2!&
M04Q312D@>PT*("`@("`@("`@("`@)&QO9VYA;64@/2!E<F5G7W)E<&QA8V4H
M)UPN<&AP="0G+"<N;&]G)RPD9FEL92D[#0H@("`@("`@("`@("!I9B`H(21L
M;V<@/2!F;W!E;B@D;&]G;F%M92PG=R<I*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!C<F5A=&4@=&5S="!L
M;V<@+2`D;&]G;F%M92(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9G=R:71E*"1L;V<L(@T*+2TM+2!%6%!%0U1%1"!/5510550-"B1W86YT960-
M"BTM+2T@04-454%,($]55%!55`T*)&]U='!U=`T*+2TM+2!&04E,140-"B(I
M.PT*("`@("`@("`@("`@:68@*"1R971U<FYF86EL*2![#0H@("`@("`@("`@
M("`@("`@9G=R:71E*"1L;V<L(@T*+2TM+2!%6%!%0U1%1"!215154DX-"B1S
M96-T:6]N7W1E>'1;4D5455).4UT-"BTM+2T@04-454%,(%)%5%523@T*)')E
M='5R;E]V86QU90T*(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M8VQO<V4H)&QO9RD[#0H@("`@("`@("`@("`O+V5R<F]R7W)E<&]R="@D9FEL
M92PD;&]G;F%M92PD=&5S=&5D*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF
M("AI<W-E="@D;VQD7W!H<"DI('L-"B`@("`@("`@("`@("1P:'`@/2`D;VQD
M7W!H<#L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D=V%R;B`_("=7
M05).140G(#H@)T9!24Q%1"<[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5N
M97)A=&5?9&EF9B@D=V%N=&5D+"`D;W5T<'5T+"`D<F5T=7)N7W9A;'5E*0T*
M("`@('L-"B`@("`@("`@)'<@/2!E>'!L;V1E*")<;B(L("1W86YT960I.PT*
M("`@("`@("`D;R`](&5X<&QO9&4H(EQN(BP@)&]U='!U="D[#0H@("`@("`@
M("1W,2`](&%R<F%Y7V1I9F9?87-S;V,H)'<L)&\I.PT*("`@("`@("`D;S$@
M/2!A<G)A>5]D:69F7V%S<V]C*"1O+"1W*3L-"B`@("`@("`@)'<R(#T@87)R
M87DH*3L-"B`@("`@("`@)&\R(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C
M:"@D=S$@87,@)&ED>"`]/B`D=F%L*2`D=S);<W!R:6YT9B@B)3`S9#PB+"1I
M9'@I72`]('-P<FEN=&8H(B4P,V0M("(L("1I9'@K,2DN)'9A;#L-"B`@("`@
M("`@9F]R96%C:"@D;S$@87,@)&ED>"`]/B`D=F%L*2`D;S);<W!R:6YT9B@B
M)3`S9#XB+"1I9'@I72`]('-P<FEN=&8H(B4P,V0K("(L("1I9'@K,2DN)'9A
M;#L-"B`@("`@("`@)&1I9F8@/2!A<G)A>5]M97)G92@D=S(L("1O,BD[#0H@
M("`@("`@(&MS;W)T*"1D:69F*3L-"B`@("`@("`@:68@*"1R971U<FY?=F%L
M=64I('L-"B`@("`@("`@("`@("1E>'1R82`]("(C(T584$5#5$5$.B`D<F5T
M=7)N7W9A;'5E6S!=7')<;B,C4D5455).140Z("1R971U<FY?=F%L=65;,5TB
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&5X=')A(#T@)R<[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H(EQR7&XB+"`D
M9&EF9BD@+B`D97AT<F$[#0H@("`@?0T*#0H@("`@+R\-"B`@("`O+R`@5W)I
M=&4@=&AE(&=I=F5N('1E>'0@=&\@82!T96UP;W)A<GD@9FEL92P@86YD(')E
M='5R;B!T:&4@9FEL96YA;64N#0H@("`@+R\-"@T*("`@(&9U;F-T:6]N('-A
M=F5?=&5X="@D9FEL96YA;64L("1T97AT*0T*("`@('L-"B`@("`@("`@:68@
M*"$D9G`@/2!F;W!E;B@D9FEL96YA;64L("=W)RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@;W!E;B!F:6QE("<B
M("X@)&9I;&5N86UE("X@(B<@*'-A=F5?=&5X="DB*3L-"B`@("`@("`@?0T*
M("`@("`@("!F=W)I=&4H)&9P+"1T97AT*3L-"B`@("`@("`@9F-L;W-E*"1F
M<"D[#0H@("`@:68@*#$@/"!$151!24Q%1"D@96-H;R`B#0I&24Q%("1F:6QE
M;F%M92![>WL-"B1T97AT#0I]?7T-"B([#0H@("`@?0T*#0I]#0H_/@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5F%L
M:61A=&4N<&AP````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#4T-C$P`#$P-3$U-#,Q,#4W`#`R,#,T,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27U9A
M;&ED871E#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z
M(%9A;&ED871E+G!H<"QV(#$N-#8@,C`P-B\P,2\R,R`Q-SHQ-CHS-2!C96QL
M;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ(T`K#0H@*B!#;VYS=&%N
M=',@9F]R(&EN<W1A;&P@<W1A9V4-"B`J+PT*9&5F:6YE*"=014%27U9!3$E$
M051%7TE.4U1!3$Q)3D<G+"`Q*3L-"F1E9FEN92@G4$5!4E]604Q)1$%415]5
M3DE.4U1!3$Q)3D<G+"`R*3L@+R\@=&AI<R!I<R!N;W0@8FET+6UA<'!E9"!L
M:6ME('1H92!O=&AE<G,-"F1E9FEN92@G4$5!4E]604Q)1$%415].3U)-04PG
M+"`S*3L-"F1E9FEN92@G4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1R<L(#0I
M.R`O+R!T:&ES(&ES(&YO="!B:70M;6%P<&5D(&QI:V4@=&AE(&]T:&5R<PT*
M9&5F:6YE*"=014%27U9!3$E$051%7U!!0TM!1TE.1R<L(#<I.PT*+RHJ(T`M
M*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"G)E<75I<F5?
M;VYC92`G4$5!4B]686QI9&%T;W(O4$5#3"YP:'`G.PT*#0HO*BH-"B`J(%9A
M;&ED871I;VX@8VQA<W,@9F]R('!A8VMA9V4N>&UL("T@8VAA;FYE;"UL979E
M;"!A9'9A;F-E9"!V86QI9&%T:6]N#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA
M<W,@4$5!4E]686QI9&%T90T*>PT*("`@('9A<B`D<&%C:V%G97)E9V5X(#T@
M7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5'.PT*("`@("\J*@T*("`@
M("`J($!V87(@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE
M7W8R#0H@("`@("HO#0H@("`@=F%R("1?<&%C:V%G97AM;#L-"B`@("`O*BH-
M"B`@("`@*B!`=F%R(&EN="!O;F4@;V8@=&AE(%!%05)?5D%,241!5$5?*B!C
M;VYS=&%N=',-"B`@("`@*B\-"B`@("!V87(@)%]S=&%T92`](%!%05)?5D%,
M241!5$5?3D]234%,.PT*("`@("\J*@T*("`@("`J($9O<FUA=#H@*"=E<G)O
M<B<@/3X@87)R87DH)V9I96QD)R`]/B!N86UE+"`G<F5A<V]N)R`]/B!R96%S
M;VXI+"`G=V%R;FEN9R<@/3X@<V%M92D-"B`@("`@*B!`=F%R(&%R<F%Y#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?9F%I
M;'5R97,@/2!A<G)A>2@G97)R;W(G(#T^(&%R<F%Y*"DL("=W87)N:6YG)R`]
M/B!A<G)A>2@I*3L-"@T*("`@("\J*@T*("`@("`J($]V97)R:61E('1H:7,@
M;65T:&]D('1O(&AA;F1L92!V86QI9&%T:6]N(&]F(&YO<FUA;"!P86-K86=E
M(&YA;65S#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@
M8F]O;`T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@7W9A;&ED4&%C:V%G94YA;64H)&YA;64I#0H@("`@>PT*("`@
M("`@("!R971U<FX@*&)O;VPI('!R96=?;6%T8V@H)R]>)R`N("1T:&ES+3YP
M86-K86=E<F5G97@@+B`G)"\G+"`D;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&YA;64@=&\@=F%L:61A
M=&4-"B`@("`@*B!`<&%R86T@<W1R:6YG(&YA;64@;V8@8VAA;FYE;"US<&5C
M:69I8R!V86QI9&%T:6]N('!A8VMA9V4-"B`@("`@*B!`9FEN86P-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!V86QI9%!A8VMA9V5.86UE*"1N86UE+"`D=F%L
M:61A=&5P86-K86=E;F%M92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*"1V86QI9&%T97!A8VMA9V5N86UE*2![#0H@("`@("`@("`@("!I9B`H<W1R
M=&]L;W=E<B@D;F%M92D@/3T@<W1R=&]L;W=E<B@D=F%L:61A=&5P86-K86=E
M;F%M92DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@*&)O;VPI('!R96=?
M;6%T8V@H)R]>6V$M>D$M6C`M.5]=*R@_.EPN6V$M>D$M6C`M.5]=*RDJ)"\G
M+"`D;F%M92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=F%L:61086-K86=E3F%M92@D;F%M92D[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!V86QI9&%T97,@82!B=6YD;&4@
M;F%M92P@86YD(&)U;F1L92!N86UE<R!M=7-T(&-O;F9O<FT-"B`@("`@*B!T
M;R!T:&4@4$5!4B!N86UI;F<@8V]N=F5N=&EO;BP@<V\@=&AE(&UE=&AO9"!I
M<R!F:6YA;"!A;F0@<W1A=&EC+@T*("`@("`J($!P87)A;2!S=')I;F<-"B`@
M("`@*B!`9FEN86P-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=F%L:61'<F]U<$YA;64H)&YA;64I#0H@("`@>PT*("`@("`@("!R
M971U<FX@*&)O;VPI('!R96=?;6%T8V@H)R]>)R`N(%]014%27T-/34U/3E]0
M04-+04=%7TY!345?4%)%1R`N("<D+R<L("1N86UE*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B`D<W1A=&4@<F5P<F5S
M96YT<R!A('9A;&ED('-T86)I;&ET>2!L979E;`T*("`@("`J($!P87)A;2!S
M=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("H@0&9I;F%L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:613=&%T
M92@D<W1A=&4I#0H@("`@>PT*("`@("`@("!R971U<FX@:6Y?87)R87DH)'-T
M871E+"!A<G)A>2@G<VYA<'-H;W0G+"`G9&5V96PG+"`G86QP:&$G+"`G8F5T
M82<L("=S=&%B;&4G*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M(&$@;&ES="!O9B!V86QI9"!S=&%B:6QI='D@;&5V96QS#0H@("`@("H@0')E
M='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`9FEN86P-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G971686QI9%-T871E<R@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@87)R87DH)W-N87!S:&]T)RP@)V1E=F5L)RP@)V%L
M<&AA)RP@)V)E=&$G+"`G<W1A8FQE)RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@1&5T97)M:6YE('=H971H97(@82!V97)S:6]N(&ES(&$@<')O<&5R
M;'D@9F]R;6%T=&5D('9E<G-I;VX@;G5M8F5R('1H870@8V%N(&)E('5S960-
M"B`@("`@*B!B>2!V97)S:6]N7V-O;7!A<F4-"B`@("`@*B!`<&%R86T@<W1R
M:6YG#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H@0'-T871I8PT*("`@
M("`J($!F:6YA;`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED5F5R<VEO
M;B@D=F5R*0T*("`@('L-"B`@("`@("`@<F5T=7)N("AB;V]L*2!P<F5G7VUA
M=&-H*%!%05)?0T]-34].7U!!0TM!1T5?5D524TE/3E]04D5'+"`D=F5R*3L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E
M1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<V5T4&%C:V%G949I;&4H)B1P9BD-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G97AM;"`]("8D<&8[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7V%D9$9A:6QU<F4H)&9I96QD+"`D<F5A<V]N*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]F86EL=7)E<ULG97)R;W)S)UU;72`](&%R<F%Y*"=F:65L9"<@
M/3X@)&9I96QD+"`G<F5A<V]N)R`]/B`D<F5A<V]N*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?861D5V%R;FEN9R@D9FEE;&0L("1R96%S;VXI#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7V9A:6QU<F5S6R=W87)N:6YG<R==6UT@/2!A<G)A
M>2@G9FEE;&0G(#T^("1F:65L9"P@)W)E87-O;B<@/3X@)')E87-O;BD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1F%I;'5R97,H*0T*("`@('L-"B`@
M("`@("`@)&9A:6QU<F5S(#T@)'1H:7,M/E]F86EL=7)E<SL-"B`@("`@("`@
M)'1H:7,M/E]F86EL=7)E<R`](&%R<F%Y*"=W87)N:6YG<R<@/3X@87)R87DH
M*2P@)V5R<F]R<R<@/3X@87)R87DH*2D[#0H@("`@("`@(')E='5R;B`D9F%I
M;'5R97,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&EN="!O
M;F4@;V8@=&AE(%!%05)?5D%,241!5$5?*B!C;VYS=&%N=',-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!V86QI9&%T92@D<W1A=&4@/2!N=6QL*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5X;6PI*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1S=&%T92`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'1H:7,M/E]S
M=&%T92`]("1S=&%T93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V9A
M:6QU<F5S(#T@87)R87DH)W=A<FYI;F=S)R`]/B!A<G)A>2@I+"`G97)R;W)S
M)R`]/B!A<G)A>2@I*3L-"B`@("`@("`@)'1H:7,M/G9A;&ED871E4&%C:V%G
M94YA;64H*3L-"B`@("`@("`@)'1H:7,M/G9A;&ED871E5F5R<VEO;B@I.PT*
M("`@("`@("`D=&AI<RT^=F%L:61A=&5-86EN=&%I;F5R<R@I.PT*("`@("`@
M("`D=&AI<RT^=F%L:61A=&5$871E*"D[#0H@("`@("`@("1T:&ES+3YV86QI
M9&%T95-U;6UA<GDH*3L-"B`@("`@("`@)'1H:7,M/G9A;&ED871E1&5S8W)I
M<'1I;VXH*3L-"B`@("`@("`@)'1H:7,M/G9A;&ED871E3&EC96YS92@I.PT*
M("`@("`@("`D=&AI<RT^=F%L:61A=&5.;W1E<R@I.PT*("`@("`@("!I9B`H
M)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]
M("<Q+C`G*2![#0H@("`@("`@("`@("`D=&AI<RT^=F%L:61A=&53=&%T92@I
M.PT*("`@("`@("`@("`@)'1H:7,M/G9A;&ED871E1FEL96QI<W0H*3L-"B`@
M("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G
M97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@>PT*("`@("`@("`@("`@)'1H:7,M
M/G9A;&ED871E5&EM92@I.PT*("`@("`@("`@("`@)'1H:7,M/G9A;&ED871E
M4W1A8FEL:71Y*"D[#0H@("`@("`@("`@("`D=&AI<RT^=F%L:61A=&5$97!S
M*"D[#0H@("`@("`@("`@("`D=&AI<RT^=F%L:61A=&5-86EN1FEL96QI<W0H
M*3L-"B`@("`@("`@("`@("1T:&ES+3YV86QI9&%T95)E;&5A<V5&:6QE;&ES
M="@I.PT*("`@("`@("`@("`@+R\D=&AI<RT^=F%L:61A=&5';&]B86Q487-K
M<R@I.PT*("`@("`@("`@("`@)'1H:7,M/G9A;&ED871E0VAA;F=E;&]G*"D[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("$H*&)O;VPI(&-O=6YT*"1T
M:&ES+3Y?9F%I;'5R97-;)V5R<F]R<R==*2D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!V86QI9&%T95!A8VMA9V5.86UE*"D-"B`@("![#0H@("`@("`@(&EF
M("@D=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'('Q\
M#0H@("`@("`@("`@("`@("1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)1$%4
M15].3U)-04PI('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5X
M;6PM/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S(N,"<@)B8-"B`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD<R@I
M*2![#0H@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7W!A8VMA
M9V5X;6PM/F=E=%9E<G-I;VXH*2`N("<G.PT*("`@("`@("`@("`@("`@("1N
M86UE(#T@)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E*"D[#0H@("`@
M("`@("`@("`@("`@)'1E<W0@/2!A<G)A>5]S:&EF="@D82`](&5X<&QO9&4H
M)RXG+"`D=F5R<VEO;BDI.PT*("`@("`@("`@("`@("`@(&EF("@D=&5S="`]
M/2`G,"<I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1V;&5N(#T@<W1R
M;&5N*"1T97-T*3L-"B`@("`@("`@("`@("`@("`D;6%J=F5R(#T@<W5B<W1R
M*"1N86UE+"!S=')L96XH)&YA;64I("T@)'9L96XI.PT*("`@("`@("`@("`@
M("`@('=H:6QE("@D;6%J=F5R("8F("%I<U]N=6UE<FEC*"1M86IV97)[,'TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1M86IV97(@/2!S=6)S='(H)&UA
M:G9E<BP@,2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@D;6%J=F5R("$]("1T97-T*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?861D5V%R;FEN9R@G<&%C:V%G92<L(")P86-K86=E("1N86UE
M(&5X=&5N9',@<&%C:V%G92`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD<R@I("X@)R!A;F0@<V\@
M=&AE(&YA;64@<VAO=6QD("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M)VAA=F4@82!P;W-T9FEX(&5Q=6%L('1O('1H92!M86IO<B!V97)S:6]N(&QI
M:V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E>&UL+3YG971%>'1E;F1S*"D@+B`D=&5S="`N("<B)RD[#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@('T@
M96QS96EF("AS=6)S='(H)&YA;64L(#`L('-T<FQE;B@D;F%M92D@+2`D=FQE
M;BD@(3T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5X;6PM/F=E=$5X=&5N9',H*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9%=A<FYI;F<H)W!A8VMA9V4G+"`B<&%C:V%G92`D;F%M
M92!E>'1E;F1S('!A8VMA9V4@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$5X=&5N9',H*2`N("<@86YD('-O
M('1H92!N86UE(&UU<W0@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M8F4@86X@97AT96YS:6]N(&QI:V4@(B<@+B`D=&AI<RT^7W!A8VMA9V5X;6PM
M/F=E=$5X=&5N9',H*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&5S
M="`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(21T:&ES+3YV86QI9%!A8VMA9V5.86UE*"1T:&ES+3Y?
M<&%C:V%G97AM;"T^9V5T4&%C:V%G92@I*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]A9&1&86EL=7)E*"=N86UE)RP@)W!A8VMA9V4@;F%M92`B)R`N#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E
M*"D@+B`G(B!I<R!I;G9A;&ED)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E
M5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`A
M/2!014%27U9!3$E$051%7U!!0TM!1TE.1RD@>PT*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^=F%L:61697)S:6]N*"1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T
M5F5R<VEO;B@I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D1F%I
M;'5R92@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("=);G9A;&ED
M('9E<G-I;VX@;G5M8F5R("(G("X@)'1H:7,M/E]P86-K86=E>&UL+3YG9716
M97)S:6]N*"D@+B`G(B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1V97)S:6]N(#T@
M)'1H:7,M/E]P86-K86=E>&UL+3YG971697)S:6]N*"D[#0H@("`@("`@("1V
M97)S:6]N8V]M<&]N96YT<R`](&5X<&QO9&4H)RXG+"`D=F5R<VEO;BD[#0H@
M("`@("`@(&EF("AC;W5N="@D=F5R<VEO;F-O;7!O;F5N=',I("$](#,I('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L#0H@
M("`@("`@("`@("`@("`@)T$@=F5R<VEO;B!N=6UB97(@<VAO=6QD(&AA=F4@
M,R!D96-I;6%L<R`H>"YY+GHI)RD[#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@?0T*("`@("`@("`D;F%M92`]("1T:&ES+3Y?<&%C:V%G
M97AM;"T^9V5T4&%C:V%G92@I.PT*("`@("`@("`O+R!V97)S:6]N(&UU<W0@
M8F4@8F%S960@=7!O;B!S=&%T90T*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?
M<&%C:V%G97AM;"T^9V5T4W1A=&4H*2D@>PT*("`@("`@("`@("`@8V%S92`G
M<VYA<'-H;W0G(#H-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@("`@(&-A<V4@)V1E=F5L)R`Z#0H@("`@("`@("`@("`@("`@:68@
M*"1V97)S:6]N8V]M<&]N96YT<ULP72`N("=A)R`]/2`G,&$G*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=
M(#T](#`I('L-"B`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VYC;VUP;VYE
M;G1S6S!=(#T@)S`G.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)W9E<G-I;VX@(B<@+B`D=F5R<VEO;B`N("<B('-H;W5L9"!B92`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<N)R`L)'9E<G-I;VYC
M;VUP;VYE;G1S*2`N("<B)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S
M:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=P86-K86=E<R!W:71H
M(&1E=F5L('-T86)I;&ET>2!M=7-T(&)E(#P@=F5R<VEO;B`Q+C`N,"<I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G86QP
M:&$G(#H-"B`@("`@("`@("`@(&-A<V4@)V)E=&$G(#H-"B`@("`@("`@("`@
M("`@("`O+R!C:&5C:R!F;W(@82!P86-K86=E('1H870@97AT96YD<R!A('!A
M8VMA9V4L#0H@("`@("`@("`@("`@("`@+R\@;&EK92!&;V\@86YD($9O;S(-
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`]/2!014%27U9!
M3$E$051%7U!!0TM!1TE.1RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M<W5B<W1R*"1V97)S:6]N8V]M<&]N96YT<ULR72P@,2P@,BD@/3T@)W)C)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1&86EL=7)E
M*"=V97)S:6]N)RP@)U)E;&5A<V4@0V%N9&ED871E('9E<G-I;VYS("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M=7-T(&AA=F4@8V%P:71A
M;"!20RP@;F]T(&QO=V5R+6-A<V4@<F,G*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES
M+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD<R@I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D=F5R<VEO;F-O;7!O;F5N='-;,%T@/3T@)S$G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S
M6S)=>S!](#T]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D=F5R<VEO;F-O;7!O;F5N='-;,ET@/3T@)S`G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O('9E<G-I;VX@,2XJ+C`P,#`-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&17
M87)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=V97)S:6]N(#$N)R`N("1V97)S:6]N8V]M<&]N96YT<ULQ
M72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)RXP('!R;V)A8FQY('-H;W5L9"!N;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H<W1R;&5N
M*"1V97)S:6]N8V]M<&]N96YT<ULR72D@/B`Q*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O('9E<G-I;VX@,2XJ+C!20S$@;W(@,2XJ
M+C!B971A,C0@971C+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!V
M97)S:6]N(#$N*BXP#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B`Q+B<@+B`D=F5R<VEO
M;F-O;7!O;F5N='-;,5T@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<N,"!P<F]B86)L>2!S:&]U;&0@;F]T(&)E(&%L<&AA
M(&]R(&)E=&$G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8G5G9FEX('9E
M<G-I;VYS("@Q+C,N>"!W:&5R92!X(#X@,"D@<')O8F%B;'D@<VAO=6QD("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]T(&)E(&%L
M<&AA(&]R(&)E=&$G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V97)S:6]N8V]M<&]N96YT<ULP
M72`A/2`G,"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D5V%R;FEN9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VUA:F]R('9E<G-I;VYS(&=R96%T97(@=&AA;B`Q(&%R92!N;W0@
M86QL;W=E9"!F;W(@<&%C:V%G97,@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W=I=&AO=70@86X@/&5X=&5N9',^('1A9R!O<B!A;B!I9&5N
M=&EC86P@<&]S=&9I>"`H9F]O,B!V,BXP+C`I)RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S
M6S!=("X@)V$G(#T]("<P82<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D=F5R<VEO;F-O;7!O;F5N='-;,%T@/3T@,"D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VYC;VUP;VYE;G1S
M6S!=(#T@)S`G.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M9&1787)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=F5R<VEO;B`B)R`N("1V97)S:6]N("X@)R(@<VAO=6QD(&)E("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<N)R`L
M)'9E<G-I;VYC;VUP;VYE;G1S*2`N("<B)RD[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D=FQE;B`]('-T<FQE;B@D=F5R<VEO;F-O;7!O;F5N='-;,%T@
M+B`G)RD[#0H@("`@("`@("`@("`@("`@("`@("1M86IV97(@/2!S=6)S='(H
M)&YA;64L('-T<FQE;B@D;F%M92D@+2`D=FQE;BD[#0H@("`@("`@("`@("`@
M("`@("`@('=H:6QE("@D;6%J=F5R("8F("%I<U]N=6UE<FEC*"1M86IV97)[
M,'TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;6%J=F5R(#T@<W5B
M<W1R*"1M86IV97(L(#$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@H)'9E<G-I;VYC;VUP;VYE;G1S6S!=("$]
M(#`I("8F("1M86IV97(@(3T@)'9E<G-I;VYC;VUP;VYE;G1S6S!=*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E
M<G-I;VXG+"`G9FER<W0@=F5R<VEO;B!N=6UB97(@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V97)S:6]N8V]M<&]N96YT<ULP72`N("<B
M(&UU<W0@;6%T8V@@=&AE('!O<W1F:7@@;V8@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!A8VMA9V4@;F%M92`B)R`N("1N86UE("X@)R(@
M*"<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M86IV97(@+B`G
M*2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1V97)S:6]N8V]M<&]N96YT<ULP72`]/2`D;6%J=F5R*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S)=>S!]
M(#T]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F5R<VEO;F-O;7!O;F5N='-;,ET@/3T@)S`G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O('9E<G-I;VX@,BXJ+C`P,#`-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG
M*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")V97)S:6]N("1M86IV97(N(B`N("1V97)S:6]N8V]M<&]N96YT<ULQ
M72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)RXP('!R;V)A8FQY('-H;W5L9"!N;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T<FQE
M;B@D=F5R<VEO;F-O;7!O;F5N='-;,ETI(#X@,2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!V97)S:6]N(#(N*BXP4D,Q(&]R(#(N
M*BXP8F5T83(T(&5T8RX-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M=F5R<VEO;B`R+BHN,`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(G9E<G-I;VX@)&UA:G9E<BXB("X@
M)'9E<G-I;VYC;VUP;VYE;G1S6S%=("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G+C`@8V%N;F]T(&)E(&%L<&AA(&]R(&)E
M=&$G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B8G5G9FEX('9E<G-I;VYS
M("@D;6%J=F5R+G@N>2!W:&5R92!Y(#X@,"D@<VAO=6QD("(@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]T(&)E(&%L<&AA(&]R(&)E
M=&$G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1V97)S:6]N8V]M<&]N96YT<ULP72`A/2`G,"<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN
M9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(F]N
M;'D@=F5R<VEO;G,@,"YX+GD@86YD("1M86IV97(N>"YY(&%R92!A;&QO=V5D
M(&9O<B!A;'!H82]B971A(')E;&5A<V5S(BD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=
M("X@)V$G(#T]("<P82<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D=F5R<VEO;F-O;7!O;F5N='-;,%T@/3T@,"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VYC;VUP;VYE;G1S6S!=
M(#T@)S`G.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&17
M87)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=F5R<VEO;B`B)R`N("1V97)S:6]N("X@)R(@<VAO=6QD(&)E("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<N)R`L)'9E
M<G-I;VYC;VUP;VYE;G1S*2`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@
M)W-T86)L92<@.@T*("`@("`@("`@("`@("`@(&EF("@D=F5R<VEO;F-O;7!O
M;F5N='-;,%T@/3T@)S`G*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L("=V97)S:6]N<R!L97-S('1H86X@
M,2XP+C`@8V%N;F]T("<@+@T*("`@("`@("`@("`@("`@("`@("`G8F4@<W1A
M8FQE)RD[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES7VYU;65R
M:6,H)'9E<G-I;VYC;VUP;VYE;G1S6S)=*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+UQD*RAR8WQA?&%L<&AA?&)\8F5T82E<
M9"HO:2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N8V]M
M<&]N96YT<ULR72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L("=V97)S:6]N("(G("X@)'9E<G-I
M;VX@+B`G(B!O<B!A;GD@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)U)#+V)E=&$O86QP:&$@=F5R<VEO;B!C86YN;W0@8F4@<W1A8FQE)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`O+R!C:&5C:R!F;W(@82!P86-K86=E('1H870@97AT96YD<R!A
M('!A8VMA9V4L#0H@("`@("`@("`@("`@("`@+R\@;&EK92!&;V\@86YD($9O
M;S(-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]P86-K86=E>&UL+3YG
M971%>'1E;F1S*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'9L96X@/2!S
M=')L96XH)'9E<G-I;VYC;VUP;VYE;G1S6S!=("X@)R<I.PT*("`@("`@("`@
M("`@("`@("`@("`D;6%J=F5R(#T@<W5B<W1R*"1N86UE+"!S=')L96XH)&YA
M;64I("T@)'9L96XI.PT*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&UA
M:G9E<B`F)B`A:7-?;G5M97)I8R@D;6%J=F5R>S!]*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&UA:G9E<B`]('-U8G-T<B@D;6%J=F5R+"`Q*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H*"1V97)S:6]N8V]M<&]N96YT<ULP72`A/2`P*2`F)B`D;6%J=F5R("$]
M("1V97)S:6]N8V]M<&]N96YT<ULP72D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP@)V9I<G-T('9E
M<G-I;VX@;G5M8F5R("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F5R<VEO;F-O;7!O;F5N='-;,%T@+B`G(B!M=7-T(&UA=&-H('1H92!P
M;W-T9FEX(&]F("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P
M86-K86=E(&YA;64@(B<@+B`D;F%M92`N("<B("@G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;6%J=F5R("X@)RDG*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V97)S:6]N8V]M<&]N
M96YT<ULP72`^(#$I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M9&1787)N:6YG*"=V97)S:6]N)RP@)VUA:F]R('9E<G-I;VX@>"!I;B!X+GDN
M>B!M87D@;F]T(&)E(&=R96%T97(@=&AA;B`G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("<Q(&9O<B!A;GD@<&%C:V%G92!T:&%T(&1O97,@;F]T(&AA
M=F4@86X@/&5X=&5N9',^('1A9R<I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@9&5F875L="`Z#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E36%I;G1A:6YE<G,H*0T*("`@
M('L-"B`@("`@("`@+R\@;6%I;G1A:6YE<G,@8V%N(&]N;'D@8F4@=')U;'D@
M=F%L:61A=&5D('-E<G9E<BUS:61E(&9O<B!M;W-T(&-H86YN96QS#0H@("`@
M("`@("\O(&)U="!A;&QO=R!T:&ES(&-U<W1O;6EZ871I;VX@9F]R('1H;W-E
M('=H;R!W:7-H(&ET#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@=F%L:61A=&5$871E*"D-"B`@("![#0H@("`@("`@(&EF
M("@D=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?3D]234%,('Q\#0H@
M("`@("`@("`@("`@("1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)1$%415]0
M04-+04=)3D<I('L-"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UQD
M7&1<9%QD7"U<9%QD7"U<9%QD+R<L#0H@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5X;6PM/F=E=$1A=&4H*2DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9$9A:6QU<F4H)V1A=&4G+"`G:6YV86QI9"!R96QE87-E
M(&1A=&4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5X;6PM/F=E=$1A=&4H*2`N("<B)RD[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-T
M<G1O=&EM92@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$1A=&4H*2D@/3T@+3$I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)V1A=&4G
M+"`G:6YV86QI9"!R96QE87-E(&1A=&4@(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$1A=&4H*2`N("<B)RD[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)1$%4
M15]004-+04=)3D<@)B8-"B`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G97AM;"T^9V5T1&%T92@I("$](&1A=&4H)UDM;2UD)RDI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)V1A=&4G+"`G4F5L96%S
M92!$871E("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E>&UL+3YG971$871E*"D@+B`G(B!I<R!N;W0@=&]D87DG*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E5&EM92@I#0H@("`@>PT*("`@
M("`@("!I9B`H(21T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5&EM92@I*2![#0H@
M("`@("`@("`@("`O+R!D969A=6QT(&]F(&YO('1I;64@=F%L=64@<V5T#0H@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`O
M+R!P86-K86=E<B!A=71O;6%T:6-A;&QY('-E=',@=&EM92P@<V\@;VYL>2!V
M86QI9&%T92!I9@T*("`@("`@("`O+R!P96%R('9A;&ED871E(&ES(&-A;&QE
M9`T*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`](%!%05)?5D%,241!5$5?
M3D]234%,*2![#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]<9%QD
M.EQD7&0Z7&1<9"\G+`T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E>&UL+3YG9714:6UE*"DI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A9&1&86EL=7)E*"=T:6UE)RP@)VEN=F%L:60@<F5L96%S92!T:6UE("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG
M9714:6UE*"D@+B`G(B<I.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AS=')T;W1I;64H
M)'1H:7,M/E]P86-K86=E>&UL+3YG9714:6UE*"DI(#T]("TQ*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1&86EL=7)E*"=T:6UE)RP@)VEN=F%L
M:60@<F5L96%S92!T:6UE("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E>&UL+3YG9714:6UE*"D@+B`G(B<I.PT*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('9A;&ED871E4W1A=&4H*0T*("`@('L-"B`@("`@("`@+R\@=&AI<R!I<R!T
M:&4@8VQO<V5S="!T;R`B9FEN86PB('!H<#0@8V%N(&=E=`T*("`@("`@("!I
M9B`H(5!%05)?5F%L:61A=&4Z.G9A;&ED4W1A=&4H)'1H:7,M/E]P86-K86=E
M>&UL+3YG9713=&%T92@I*2D@>PT*("`@("`@("`@("`@:68@*'-T<G1O;&]W
M97(H)'1H:7,M/E]P86-K86=E>&UL+3YG9713=&%T92@I(#T]("=R8R<I*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1&86EL=7)E*"=S=&%T92<L
M("=20R!I<R!N;W0@82!S=&%T92P@:70@:7,@82!V97)S:6]N("<@+@T*("`@
M("`@("`@("`@("`@("`@("`G<&]S=&9I>"P@=7-E("<@+B`D=&AI<RT^7W!A
M8VMA9V5X;6PM/F=E=%9E<G-I;VXH*2`N("=20S$L('-T871E(&)E=&$G*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?861D1F%I;'5R
M92@G<W1A=&4G+"`G:6YV86QI9"!R96QE87-E('-T871E("(G("X-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"D@+B`G
M(BP@;75S="!B92!O;F4@;V8Z("<@+@T*("`@("`@("`@("`@("`@(&EM<&QO
M9&4H)RP@)RP@4$5!4E]686QI9&%T93HZ9V5T5F%L:613=&%T97,H*2DI.PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E
M<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&53
M=&%B:6QI='DH*0T*("`@('L-"B`@("`@("`@)')E="`]('1R=64[#0H@("`@
M("`@("1P86-K86=E<W1A8FEL:71Y(#T@)'1H:7,M/E]P86-K86=E>&UL+3YG
M9713=&%T92@I.PT*("`@("`@("`D87!I<W1A8FEL:71Y(#T@)'1H:7,M/E]P
M86-K86=E>&UL+3YG9713=&%T92@G87!I)RD[#0H@("`@("`@(&EF("@A4$5!
M4E]686QI9&%T93HZ=F%L:613=&%T92@D<&%C:V%G97-T86)I;&ET>2DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?861D1F%I;'5R92@G<W1A=&4G+"`G:6YV
M86QI9"!R96QE87-E('-T86)I;&ET>2`B)R`N#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E>&UL+3YG9713=&%T92@I("X@)R(L(&UU<W0@8F4@
M;VYE(&]F.B`G("X-"B`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L(%!%
M05)?5F%L:61A=&4Z.F=E=%9A;&ED4W1A=&5S*"DI*3L-"B`@("`@("`@("`@
M("1R970@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D87!I<W1A=&5S
M(#T@4$5!4E]686QI9&%T93HZ9V5T5F%L:613=&%T97,H*3L-"B`@("`@("`@
M87)R87E?<VAI9G0H)&%P:7-T871E<RD[("\O('-N87!S:&]T(&ES(&YO="!A
M;&QO=V5D#0H@("`@("`@(&EF("@A:6Y?87)R87DH)&%P:7-T86)I;&ET>2P@
M)&%P:7-T871E<RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?861D1F%I;'5R
M92@G<W1A=&4G+"`G:6YV86QI9"!!4$D@<W1A8FEL:71Y("(G("X-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"=A<&DG
M*2`N("<B+"!M=7-T(&)E(&]N92!O9CH@)R`N#0H@("`@("`@("`@("`@("`@
M:6UP;&]D92@G+"`G+"`D87!I<W1A=&5S*2D[#0H@("`@("`@("`@("`D<F5T
M(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T95-U;6UA<GDH*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V
M86QI9&%T941E<V-R:7!T:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C
M=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5,:6-E;G-E*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=F%L:61A=&5.;W1E<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!F;W(@<&%C:V%G92YX
M;6P@,BXP(&]N;'D@+2!C:&%N;F5L<R!C86XG="!U<V4@<&%C:V%G92YX;6P@
M,2XP#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!V86QI9&%T941E<&5N9&5N8VEE<R@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!F;W(@
M<&%C:V%G92YX;6P@,2XP(&]N;'D-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5&:6QE;&ES="@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@=')U93L@+R\@<&QA8V5H;VQD97(@9F]R
M(&YO=PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(&9O<B!P86-K86=E+GAM
M;"`R+C`@;VYL>0T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@=F%L:61A=&5-86EN1FEL96QI<W0H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N('1R=64[("\O('!L86-E:&]L9&5R(&9O<B!N;W<-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!F;W(@<&%C:V%G92YX;6P@,BXP
M(&]N;'D-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('9A;&ED871E4F5L96%S949I;&5L:7-T*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B!T<G5E.R`O+R!P;&%C96AO;&1E<B!F;W(@;F]W#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T94-H86YG96QO9R@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('9A;&ED871E1FEL96QI<W0H*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T941E<',H*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*?0T*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]834Q087)S97(N<&AP````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3<T-S$`,3`U,34T,S$P-3<`,#(P-#,P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(%!%05)?1E10#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T
M(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T
M:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@4W1E<&AA;B!38VAM:61T
M("AO<FEG:6YA;"!834Q?56YS97)I86QI>F5R(&-O9&4I#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@6$U,4&%R<V5R+G!H
M<"QV(#$N,3$@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J(%!A<G-E<B!F;W(@86YY('AM;"!F
M:6QE#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`875T:&]R("`@("!3=&5P:&%N(%-C:&UI9'0@*&]R:6=I;F%L(%A-
M3%]5;G-E<FEA;&EZ97(@8V]D92D-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC
M;&%S<R!014%27UA-3%!A<G-E<@T*>PT*("`@("\J*@T*("`@("`J('5N<V5R
M:6QI86QI>F5D(&1A=&$-"B`@("`@*B!`=F%R('-T<FEN9R`D7W-E<FEA;&EZ
M961$871A#0H@("`@("HO#0H@("`@=F%R("1?=6YS97)I86QI>F5D1&%T82`]
M(&YU;&P[#0H-"B`@("`O*BH-"B`@("`@*B!N86UE(&]F('1H92!R;V]T('1A
M9PT*("`@("`J($!V87(@<W1R:6YG("1?<F]O=`T*("`@("`J+PT*("`@('9A
M<B`D7W)O;W0@/2!N=6QL.PT*#0H@("`@+RHJ#0H@("`@("H@<W1A8VL@9F]R
M(&%L;"!D871A('1H870@:7,@9F]U;F0-"B`@("`@*B!`=F%R(&%R<F%Y("`@
M("1?9&%T85-T86-K#0H@("`@("HO#0H@("`@=F%R("1?9&%T85-T86-K("`]
M("`@87)R87DH*3L-"@T*("`@("\J*@T*("`@("`J('-T86-K(&9O<B!A;&P@
M=F%L=65S('1H870@87)E(&=E;F5R871E9`T*("`@("`J($!V87(@87)R87D@
M("`@)%]V86Q3=&%C:PT*("`@("`J+PT*("`@('9A<B`D7W9A;%-T86-K("`]
M("`@87)R87DH*3L-"@T*("`@("\J*@T*("`@("`J(&-U<G)E;G0@=&%G(&1E
M<'1H#0H@("`@("H@0'9A<B!I;G0@("`@)%]D97!T:`T*("`@("`J+PT*("`@
M('9A<B`D7V1E<'1H(#T@,#L-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@
M87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971$871A*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W5N<V5R:6%L:7IE9$1A=&$[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!X;6P@8V]N
M=&5N=`T*("`@("`J($!R971U<FX@=')U97Q014%27T5R<F]R#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<&%R<V4H)&1A=&$I#0H@("`@>PT*("`@("`@("!I
M9B`H(65X=&5N<VEO;E]L;V%D960H)WAM;"<I*2![#0H@("`@("`@("`@("!I
M;F-L=61E7V]N8V4@)U!%05(N<&AP)SL-"B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*")834P@17AT96YS:6]N(&YO="!F;W5N9"(L(#$I
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?=F%L4W1A8VL@/2!A<G)A
M>2@I.PT*("`@("`@("`D=&AI<RT^7V1A=&%3=&%C:R`](&%R<F%Y*"D[#0H@
M("`@("`@("1T:&ES+3Y?9&5P=&@@/2`P.PT*#0H@("`@("`@(&EF("AV97)S
M:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-2XP+C`G+"`G;'0G*2D@>PT*
M("`@("`@("`@("`@:68@*'-T<G!O<R@D9&%T82P@)V5N8V]D:6YG/2)55$8M
M."(G*2D@>PT*("`@("`@("`@("`@("`@("1D871A(#T@=71F.%]D96-O9&4H
M)&1A=&$I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'AP(#T@0'AM
M;%]P87)S97)?8W)E871E*"=)4T\M.#@U.2TQ)RD[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1D871A+"`G96YC;V1I;F<]
M(E541BTX(B<I*2![#0H@("`@("`@("`@("`@("`@)'AP(#T@0'AM;%]P87)S
M97)?8W)E871E*"=55$8M."<I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D>'`@/2!`>&UL7W!A<G-E<E]C<F5A=&4H)TE33RTX
M.#4Y+3$G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!X
M;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'AP+"!834Q?3U!424].7T-!4T5?1D],
M1$E.1RP@,"D[#0H@("`@("`@('AM;%]S971?;V)J96-T*"1X<"P@)'1H:7,I
M.PT*("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D>'`L("=S=&%R
M=$AA;F1L97(G+"`G96YD2&%N9&QE<B<I.PT*("`@("`@("!X;6Q?<V5T7V-H
M87)A8W1E<E]D871A7VAA;F1L97(H)'AP+"`G8V1A=&%(86YD;&5R)RD[#0H@
M("`@("`@(&EF("@A>&UL7W!A<G-E*"1X<"P@)&1A=&$I*2![#0H@("`@("`@
M("`@("`D;7-G(#T@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O
M9&4H)'AP*2D[#0H@("`@("`@("`@("`D;&EN92`]('AM;%]G971?8W5R<F5N
M=%]L:6YE7VYU;6)E<B@D>'`I.PT*("`@("`@("`@("`@>&UL7W!A<G-E<E]F
M<F5E*"1X<"D[#0H@("`@("`@("`@("!I;F-L=61E7V]N8V4@)U!%05(N<&AP
M)SL-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")834P@
M17)R;W(Z("<D;7-G)R!O;B!L:6YE("<D;&EN92<B+"`R*3L-"B`@("`@("`@
M?0T*("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'AP*3L-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4W1A<G0@96QE
M;65N="!H86YD;&5R(&9O<B!834P@<&%R<V5R#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B!`<&%R86T@(&]B:F5C="`D<&%R<V5R
M("!834P@<&%R<V5R(&]B:F5C=`T*("`@("`J($!P87)A;2`@<W1R:6YG("1E
M;&5M96YT(%A-3"!E;&5M96YT#0H@("`@("H@0'!A<F%M("!A<G)A>2`@)&%T
M=')I8G,@871T<FEB=71E<R!O9B!834P@=&%G#0H@("`@("H@0')E='5R;B!V
M;VED#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A<G1(86YD;&5R*"1P87)S
M97(L("1E;&5M96YT+"`D871T<FEB<RD-"B`@("![#0H@("`@("`@("1T>7!E
M(#T@)W-T<FEN9R<[#0H-"B`@("`@("`@)'1H:7,M/E]D97!T:"LK.PT*("`@
M("`@("`D=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^7V1E<'1H72`](&YU;&P[
M#0H-"B`@("`@("`@)'9A;"`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`@)VYA;64G("`@("`@("`@/3X@)&5L96UE;G0L#0H@("`@("`@("`@("`@
M("`@("`@("`G=F%L=64G("`@("`@("`]/B!N=6QL+`T*("`@("`@("`@("`@
M("`@("`@("`@)W1Y<&4G("`@("`@("`@/3X@)'1Y<&4L#0H@("`@("`@("`@
M("`@("`@("`@("`G8VAI;&1R96Y+97ES)R`]/B!A<G)A>2@I+`T*("`@("`@
M("`@("`@("`@("`@("`@)V%G9W)E9TME>7,G("`@/3X@87)R87DH*0T*("`@
M("`@("`@("`@("`@("`@("`I.PT*#0H@("`@("`@(&EF("AC;W5N="@D871T
M<FEB<RD@/B`P*2![#0H@("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==(#T@
M87)R87DH*3L-"B`@("`@("`@("`@("1V86Q;)W1Y<&4G72`]("=A<G)A>2<[
M#0H-"B`@("`@("`@("`@("1V86Q;)V-H:6QD<F5N)UU;)V%T=')I8G,G72`]
M("1A='1R:6)S.PT*#0H@("`@("`@('T-"@T*("`@("`@("!A<G)A>5]P=7-H
M*"1T:&ES+3Y?=F%L4W1A8VLL("1V86PI.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J('!O<W0M<')O8V5S<R!D871A#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A#0H@("`@("H@0'!A<F%M('-T<FEN9R`D96QE;65N
M="!E;&5M96YT(&YA;64-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P;W-T4')O
M8V5S<R@D9&%T82P@)&5L96UE;G0I#0H@("`@>PT*("`@("`@("!R971U<FX@
M=')I;2@D9&%T82D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@16YD(&5L
M96UE;G0@:&%N9&QE<B!F;W(@6$U,('!A<G-E<@T*("`@("`J#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'!A<F%M("!O8FIE8W0@6$U,('!A
M<G-E<B!O8FIE8W0-"B`@("`@*B!`<&%R86T@('-T<FEN9PT*("`@("`J($!R
M971U<FX@=F]I9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H
M)'!A<G-E<BP@)&5L96UE;G0I#0H@("`@>PT*("`@("`@("`D=F%L=64@/2!A
M<G)A>5]P;W`H)'1H:7,M/E]V86Q3=&%C:RD[#0H@("`@("`@("1D871A("`]
M("1T:&ES+3YP;W-T4')O8V5S<R@D=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^
M7V1E<'1H72P@)&5L96UE;G0I.PT*#0H@("`@("`@("\O(&%D:G5S="!T>7!E
M(&]F('1H92!V86QU90T*("`@("`@("!S=VET8V@H<W1R=&]L;W=E<B@D=F%L
M=65;)W1Y<&4G72DI('L-"@T*("`@("`@("`@("`@+RH-"B`@("`@("`@("`@
M("`J('5N<V5R:6%L:7IE(&%N(&%R<F%Y#0H@("`@("`@("`@("`@*B\-"B`@
M("`@("`@("`@(&-A<V4@)V%R<F%Y)SH-"B`@("`@("`@("`@("`@("!I9B`H
M)&1A=&$@(3T]("<G*2![#0H@("`@("`@("`@("`@("`@("`@("1V86QU95LG
M8VAI;&1R96XG75LG7V-O;G1E;G0G72`]("1D871A.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=C:&EL
M9')E;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E
M)UT@/2`D=F%L=65;)V-H:6QD<F5N)UT[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@
M87)R87DH*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H-"B`@("`@("`@("`@("\J#0H@("`@("`@("`@("`@*B!U;G-E
M<FEA;&EZ92!A(&YU;&P@=F%L=64-"B`@("`@("`@("`@("`J+PT*("`@("`@
M("`@("`@8V%S92`G;G5L;"<Z#0H@("`@("`@("`@("`@("`@)&1A=&$@/2!N
M=6QL.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("`O
M*@T*("`@("`@("`@("`@("H@=6YS97)I86QI>F4@86YY('-C86QA<B!V86QU
M90T*("`@("`@("`@("`@("HO#0H@("`@("`@("`@("!D969A=6QT.@T*("`@
M("`@("`@("`@("`@('-E='1Y<&4H)&1A=&$L("1V86QU95LG='EP92==*3L-
M"B`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E)UT@/2`D9&%T83L-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*("`@("`@("`D<&%R
M96YT(#T@87)R87E?<&]P*"1T:&ES+3Y?=F%L4W1A8VLI.PT*("`@("`@("!I
M9B`H)'!A<F5N="`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'1H:7,M/E]U
M;G-E<FEA;&EZ961$871A(#T@)B1V86QU95LG=F%L=64G73L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<F]O="`]("8D=F%L=65;)VYA;64G73L-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@+R\@<&%R96YT(&AA<R!T;R!B92!A;B!A<G)A>0T*("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&%R96YT6R=C:&EL9')E;B==*2!\?"`A:7-?87)R87DH
M)'!A<F5N=%LG8VAI;&1R96XG72DI('L-"B`@("`@("`@("`@("`@("`D<&%R
M96YT6R=C:&EL9')E;B==(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!I
M9B`H)'!A<F5N=%LG='EP92==("$]("=A<G)A>2<I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'!A<F5N=%LG='EP92==(#T@)V%R<F%Y)SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@A
M96UP='DH)'9A;'5E6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@+R\@
M=&AE<F4@86QR96%D>2!H87,@8F5E;B!A('1A9R!W:71H('1H:7,@;F%M90T*
M("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D=F%L=65;)VYA;64G72P@
M)'!A<F5N=%LG8VAI;&1R96Y+97ES)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("\O(&YO(&%G9W)E9V%T92!H87,@8F5E;B!C<F5A=&5D(&9O<B!T:&ES
M('1A9PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1V86QU
M95LG;F%M92==+"`D<&%R96YT6R=A9V=R96=+97ES)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F5N=%LG8VAI;&1R96XG
M75LD=F%L=65;)VYA;64G75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75T@/2!A
M<G)A>2@D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)E;G1;)V-H:6QD<F5N)UU;)'9A;'5E6R=N
M86UE)UU=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG
M86=G<F5G2V5Y<R==+"`D=F%L=65;)VYA;64G72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D<&%R
M96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72P@)'9A;'5E6R=V86QU
M92==*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72`]
M("8D=F%L=65;)W9A;'5E)UT[#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7W!U<V@H)'!A<F5N=%LG8VAI;&1R96Y+97ES)UTL("1V86QU95LG;F%M92==
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG8VAI;&1R96XG
M72PD=F%L=65;)W9A;'5E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@87)R87E?<'5S:"@D=&AI<RT^7W9A;%-T86-K+"`D<&%R96YT*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@("1T:&ES+3Y?9&5P=&@M+3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!(86YD;&5R(&9O<B!C:&%R86-T97(@9&%T80T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'!A<F%M
M("!O8FIE8W0@6$U,('!A<G-E<B!O8FIE8W0-"B`@("`@*B!`<&%R86T@('-T
M<FEN9R!#1$%400T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&-D871A2&%N9&QE<B@D<&%R<V5R+"`D8V1A=&$I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^7V1E<'1H72`N
M/2`D8V1A=&$[#0H@("`@?0T*?0T*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0G5I;&1E<BYP:'``
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,C<W`#$P
M-3$U-#,Q,#4W`#`R,#(P-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27T)U:6QD97(@9F]R
M(&)U:6QD:6YG(%!(4"!E>'1E;G-I;VYS("A014-,('!A8VMA9V5S*0T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!"=6EL9&5R+G!H<"QV
M(#$N,C<@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N
M,0T*("HO#0H-"B\J*@T*("H@3F5E9&5D(&9O<B!E>'1E;F1I;F<@4$5!4E]"
M=6EL9&5R#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-
M"G)E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*+RHJ#0H@
M*B!#;&%S<R!T;R!H86YD;&4@8G5I;&1I;F<@*&-O;7!I;&EN9RD@97AT96YS
M:6]N<RX-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!02%`@-"XP+C(-"B`J($!S964@("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+V-O<F4N<'!M+G!E87(M8G5I;&1E<BYP:'`-"B`J
M+PT*8VQA<W,@4$5!4E]"=6EL9&5R(&5X=&5N9',@4$5!4E]#;VUM;VX-"GL-
M"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@=F%R("1P:'!?87!I7W9E
M<G-I;VX@/2`P.PT*("`@('9A<B`D>F5N9%]M;V1U;&5?87!I7VYO(#T@,#L-
M"B`@("!V87(@)'IE;F1?97AT96YS:6]N7V%P:5]N;R`](#`[#0H-"B`@("!V
M87(@)&5X=&5N<VEO;G-?8G5I;'0@/2!A<G)A>2@I.PT*#0H@("`@=F%R("1C
M=7)R96YT7V-A;&QB86-K(#T@;G5L;#L-"@T*("`@("\O('5S960@9F]R(&US
M9&5V(&)U:6QD<PT*("`@('9A<B`D7VQA<W1L:6YE(#T@;G5L;#L-"B`@("!V
M87(@)%]F:7)S=&QI;F4@/2!N=6QL.PT*("`@("\O('U]?0T*("`@("\O('M[
M>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]"=6EL9&5R
M(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&]B:F5C="`D
M=6D@=7-E<B!I;G1E<F9A8V4@;V)J96-T("AI;G-T86YC92!O9B!014%27T9R
M;VYT96YD7RHI#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0G5I;&1E<B@F)'5I*0T*("`@('L-
M"B`@("`@("`@<&%R96YT.CI014%27T-O;6UO;B@I.PT*("`@("`@("`D=&AI
M<RT^<V5T1G)O;G1E;F1/8FIE8W0H)'5I*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"@T*("`@("\O('M[>R!?8G5I;&1?=VEN,S(H*0T*#0H@("`@+RHJ#0H@
M("`@("H@0G5I;&0@86X@97AT96YS:6]N(&9R;VT@<V]U<F-E(&]N('=I;F1O
M=W,N#0H@("`@("H@<F5Q=6ER97,@;7-D978-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?8G5I;&1?=VEN,S(H)&1E<V-F:6QE+"`D8V%L;&)A8VL@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D9&5S8V9I;&4I*2![
M#0H@("`@("`@("`@("`D<&MG(#T@)&1E<V-F:6QE.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)'!F(#T@)FYE=R!014%27U!A8VMA9V5&:6QE
M*"1T:&ES+3YC;VYF:6<L("1T:&ES+3YD96)U9RD[#0H@("`@("`@("`@("`D
M<&MG(#T@)B1P9BT^9G)O;5!A8VMA9V5&:6QE*"1D97-C9FEL92P@4$5!4E]6
M04Q)1$%415].3U)-04PI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'!K9RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'!K9SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D9&ER(#T@9&ER;F%M
M92@D<&MG+3YG971!<F-H:79E1FEL92@I*3L-"B`@("`@("`@)&]L9%]C=V0@
M/2!G971C=V0H*3L-"@T*("`@("`@("!I9B`H(4!C:&1I<B@D9&ER*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N
M;W0@8VAD:7(@=&\@)&1I<B(I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YL;V<H,BP@(F)U:6QD:6YG(&EN("1D:7(B*3L-"@T*("`@("`@("`D9'-P
M(#T@)'!K9RT^9V5T4&%C:V%G92@I+B<N9'-P)SL-"B`@("`@("`@:68@*"%`
M:7-?9FEL92@B)&1I<B\D9'-P(BDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B5&AE($134"`D9'-P(&1O97,@;F]T(&5X:7-T
M+B(I.PT*("`@("`@("!]#0H@("`@("`@("\O(%A86"!43T1/.B!M86ME(')E
M;&5A<V4@8G5I;&0@='EP92!C;VYF:6=U<F%B;&4-"B`@("`@("`@)&-O;6UA
M;F0@/2`G;7-D978@)RXD9'-P+B<@+TU!2T4@(B<N)&EN9F];)W!A8VMA9V4G
M72X@)R`M(%)E;&5A<V4B)SL-"@T*("`@("`@("`D=&AI<RT^8W5R<F5N=%]C
M86QL8F%C:R`]("1C86QL8F%C:SL-"B`@("`@("`@)&5R<B`]("1T:&ES+3Y?
M<G5N0V]M;6%N9"@D8V]M;6%N9"P@87)R87DH)B1T:&ES+"`G;7-D979#86QL
M8F%C:R<I*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H-"B`@("`@
M("`@+R\@9FEG=7)E(&]U="!T:&4@8G5I;&0@<&QA=&9O<FT@86YD('1Y<&4-
M"B`@("`@("`@)'!L871F;W)M(#T@)U=I;C,R)SL-"B`@("`@("`@)&)U:6QD
M='EP92`]("=296QE87-E)SL-"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\N
M*C\G+B1P:V<M/F=E=%!A8VMA9V4H*2XG7',M7',H7'<K*5QS*"XJ/RDM*R]I
M)RPD=&AI<RT^7V9I<G-T;&EN92PD;6%T8VAE<RDI('L-"B`@("`@("`@("`@
M("1P;&%T9F]R;2`]("1M871C:&5S6S%=.PT*("`@("`@("`@("`@)&)U:6QD
M='EP92`]("1M871C:&5S6S)=.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R\H+BHI/UQS+5QS*%QD*RDN*C\H7&0K*2\G+"1T:&ES
M+3Y?;&%S=&QI;F4L)&UA=&-H97,I*2![#0H@("`@("`@("`@("!I9B`H)&UA
M=&-H97-;,ETI('L-"B`@("`@("`@("`@("`@("`O+R!T:&5R92!W97)E(&5R
M<F]R<R!I;B!T:&4@8G5I;&0-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(E1H97)E('=E<F4@97)R;W)S(&1U<FEN9R!C;VUP
M:6QA=&EO;BXB*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1O=70@
M/2`D;6%T8VAE<ULQ73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1&ED(&YO="!U;F1E<G-T86YD
M('1H92!C;VUP;&5T:6]N('-T871U<R!R971U<FYE9"!F<F]M(&US9&5V+F5X
M92XB*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O(&US9&5V(&1O97-N)W0@
M=&5L;"!U<R!T:&4@;W5T<'5T(&1I<F5C=&]R>2`Z+PT*("`@("`@("`O+R!O
M<&5N('1H92!D<W`L(&9I;F0@+V]U="!A;F0@=7-E('1H870@9&ER96-T;W)Y
M#0H@("`@("`@("1D<W!T97AT(#T@:F]I;BAF:6QE*"1D<W`I+"<G*3L-"@T*
M("`@("`@("`O+R!T:&ES(')E9V5X(&1E<&5N9',@;VX@=&AE(&)U:6QD('!L
M871F;W)M(&%N9"!T>7!E(&AA=FEN9R!B965N#0H@("`@("`@("\O(&-O<G)E
M8W1L>2!I9&5N=&EF:65D(&%B;W9E+@T*("`@("`@("`D<F5G97@@/2<O+BH_
M(4E&7',K(EPD7"A#1D=<*2)<<RL]/5QS*R@B)RX-"B`@("`@("`@("`@("`@
M("`@("`@)'!K9RT^9V5T4&%C:V%G92@I+B=<<RU<<R<N#0H@("`@("`@("`@
M("`@("`@("`@("1P;&%T9F]R;2XG7',G+@T*("`@("`@("`@("`@("`@("`@
M("`D8G5I;&1T>7!E+B<B*2XJ/R<N#0H@("`@("`@("`@("`@("`@("`@("=<
M+V]U=#HB*"XJ/RDB+VES)SL-"@T*("`@("`@("!I9B`H)&1S<'1E>'0@)B8@
M<')E9U]M871C:"@D<F5G97@L)&1S<'1E>'0L)&UA=&-H97,I*2![#0H@("`@
M("`@("`@("`O+R!W:&%T('=E(&=E="!B86-K(&ES(&$@<F5L871I=F4@<&%T
M:"!T;R!T:&4@;W5T<'5T(&9I;&4@:71S96QF+@T*("`@("`@("`@("`@)&]U
M=&9I;&4@/2!R96%L<&%T:"@D;6%T8VAE<ULR72D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O
M=6QD(&YO="!R971R:65V92!O=71P=70@:6YF;W)M871I;VX@9G)O;2`D9'-P
M+B(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A`8V]P>2@D;W5T9FEL92P@
M(B1D:7(O)&]U="(I*2![#0H@("`@("`@("`@("`D;W5T9FEL92`]("(D9&ER
M+R1O=70B.PT*("`@("`@("!]#0H-"B`@("`@("`@)&)U:6QT7V9I;&5S6UT@
M/2!A<G)A>2@-"B`@("`@("`@("`@("=F:6QE)R`]/B`B)&]U=&9I;&4B+`T*
M("`@("`@("`@("`@)W!H<%]A<&DG(#T^("1T:&ES+3YP:'!?87!I7W9E<G-I
M;VXL#0H@("`@("`@("`@("`G>F5N9%]M;V1?87!I)R`]/B`D=&AI<RT^>F5N
M9%]M;V1U;&5?87!I7VYO+`T*("`@("`@("`@("`@)WIE;F1?97AT7V%P:2<@
M/3X@)'1H:7,M/GIE;F1?97AT96YS:6]N7V%P:5]N;RP-"B`@("`@("`@("`@
M("D[#0H-"B`@("`@("`@<F5T=7)N("1B=6EL=%]F:6QE<SL-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@;7-D979#86QL8F%C:R@I#0H@("`@
M9G5N8W1I;VX@;7-D979#86QL8F%C:R@D=VAA="P@)&1A=&$I#0H@("`@>PT*
M("`@("`@("!I9B`H(21T:&ES+3Y?9FER<W1L:6YE*0T*("`@("`@("`@("`@
M)'1H:7,M/E]F:7)S=&QI;F4@/2`D9&%T83L-"B`@("`@("`@)'1H:7,M/E]L
M87-T;&EN92`]("1D871A.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?:&%R=F5N=$EN<W1$:7(-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!A
M<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]H87)V97-T26YS=$1I<B@D9&5S=%]P<F5F:7@L("1D:7)N86UE
M+"`F)&)U:6QT7V9I;&5S*0T*("`@('L-"B`@("`@("`@)&0@/2!O<&5N9&ER
M*"1D:7)N86UE*3L-"B`@("`@("`@:68@*"$D9"D-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"@T*("`@("`@("`D<F5T(#T@=')U93L-"B`@("`@("`@
M=VAI;&4@*"@D96YT(#T@<F5A9&1I<B@D9"DI("$]/2!F86QS92D@>PT*("`@
M("`@("`@("`@:68@*"1E;G1[,'T@/3T@)RXG*0T*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*#0H@("`@("`@("`@("`D9G5L;"`]("1D:7)N86UE("X@
M1$E214-43U)97U-%4$%2051/4B`N("1E;G0[#0H@("`@("`@("`@("!I9B`H
M:7-?9&ER*"1F=6QL*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]H87)V97-T26YS=$1I<B@-"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M97-T7W!R969I>"`N($1)4D5#5$]265]315!!4D%43U(@+B`D96YT+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9U;&PL("1B=6EL=%]F:6QE<RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E="`](&9A;'-E.PT*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1D97-T(#T@)&1E<W1?
M<')E9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1E;G0[#0H@("`@("`@
M("`@("`@("`@)&)U:6QT7V9I;&5S6UT@/2!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=F:6QE)R`]/B`D9G5L;"P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-T)R`]/B`D9&5S="P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=P:'!?87!I)R`]/B`D=&AI<RT^<&AP7V%P:5]V97)S:6]N+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@)WIE;F1?;6]D7V%P:2<@/3X@)'1H
M:7,M/GIE;F1?;6]D=6QE7V%P:5]N;RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("=Z96YD7V5X=%]A<&DG(#T^("1T:&ES+3YZ96YD7V5X=&5N<VEO;E]A
M<&E?;F\L#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&-L;W-E9&ER*"1D*3L-"B`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O
M+R![>WL@8G5I;&0H*0T*#0H@("`@+RHJ#0H@("`@("H@0G5I;&0@86X@97AT
M96YS:6]N(&9R;VT@<V]U<F-E+B`@4G5N<R`B<&AP:7IE(B!I;B!T:&4@<V]U
M<F-E#0H@("`@("H@9&ER96-T;W)Y+"!B=70@8V]M<&EL97,@:6X@82!T96UP
M;W)A<GD@9&ER96-T;W)Y#0H@("`@("H@*"]V87(O=&UP+W!E87(M8G5I;&0M
M55-%4B]004-+04=%+59%4E-)3TXI+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9WQ014%27U!A8VMA9V5&:6QE7W8J("1D97-C9FEL92!P871H('1O
M(%A-3"!P86-K86=E(&1E<V-R:7!T:6]N(&9I;&4L(&]R#0H@("`@("H@("`@
M("`@("`@("`@("!A(%!%05)?4&%C:V%G949I;&4@;V)J96-T#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@;6EX960@)&-A;&QB86-K(&-A;&QB86-K(&9U;F-T
M:6]N('5S960@=&\@<F5P;W)T(&]U='!U="P-"B`@("`@*B!S964@4$5!4E]"
M=6EL9&5R.CI?<G5N0V]M;6%N9"!F;W(@9&5T86EL<PT*("`@("`J#0H@("`@
M("H@0')E='5R;B!A<G)A>2!A;B!A<G)A>2!O9B!A<W-O8VEA=&EV92!A<G)A
M>7,@=VET:"!B=6EL="!F:6QE<RP-"B`@("`@*B!F;W)M870Z#0H@("`@("H@
M87)R87DH(&%R<F%Y*"`G9FEL92<@/3X@)R]P871H+W1O+V5X="YS;R<L#0H@
M("`@("H@("`@("`@("`@("`@("`G<&AP7V%P:2<@/3X@65E964U-1$0L#0H@
M("`@("H@("`@("`@("`@("`@("`G>F5N9%]M;V1?87!I)R`]/B!965E934U$
M1"P-"B`@("`@*B`@("`@("`@("`@("`@("=Z96YD7V5X=%]A<&DG(#T^(%E9
M65E-341$("DL#0H@("`@("H@("`@("`@("XN+B`I#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("H@0'-E92!014%27T)U
M:6QD97(Z.E]R=6Y#;VUM86YD#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8G5I
M;&0H)&1E<V-F:6QE+"`D8V%L;&)A8VL@/2!N=6QL*0T*("`@('L-"B`@("`@
M("`@:68@*%!%05)?3U,@/3T@(E=I;F1O=W,B*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]B=6EL9%]W:6XS,B@D9&5S8V9I;&4L)&-A;&QB86-K
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4E]/4R`A/2`G56YI>"<I
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8G5I
M;&1I;F<@97AT96YS:6]N<R!N;W0@<W5P<&]R=&5D(&]N('1H:7,@<&QA=&9O
M<FTB*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?;V)J96-T*"1D97-C
M9FEL92DI('L-"B`@("`@("`@("`@("1P:V<@/2`D9&5S8V9I;&4[#0H@("`@
M("`@("`@("`D9&5S8V9I;&4@/2`D<&MG+3YG971086-K86=E1FEL92@I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'!F(#T@)FYE=R!014%2
M7U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@("`@)'!K
M9R`]("8D<&8M/F9R;VU086-K86=E1FEL92@D9&5S8V9I;&4L(%!%05)?5D%,
M241!5$5?3D]234%,*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1P:V<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P:V<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&1I<B`](&1I<FYA;64H
M)&1E<V-F:6QE*3L-"B`@("`@("`@)&]L9%]C=V0@/2!G971C=V0H*3L-"B`@
M("`@("`@:68@*"%`8VAD:7(H)&1I<BDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-H9&ER('1O("1D:7(B
M*3L-"B`@("`@("`@?0T*("`@("`@("`D=F1I<B`]("1P:V<M/F=E=%!A8VMA
M9V4H*2`N("<M)R`N("1P:V<M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@:68@
M*&ES7V1I<B@D=F1I<BDI('L-"B`@("`@("`@("`@(&-H9&ER*"1V9&ER*3L-
M"B`@("`@("`@?0T*("`@("`@("`D9&ER(#T@9V5T8W=D*"D[#0H@("`@("`@
M("1T:&ES+3YL;V<H,BP@(F)U:6QD:6YG(&EN("1D:7(B*3L-"B`@("`@("`@
M)'1H:7,M/F-U<G)E;G1?8V%L;&)A8VL@/2`D8V%L;&)A8VL[#0H@("`@("`@
M('!U=&5N=B@G4$%42#TG("X@)'1H:7,M/F-O;F9I9RT^9V5T*"=B:6Y?9&ER
M)RD@+B`G.B<@+B!G971E;G8H)U!!5$@G*2D[#0H@("`@("`@("1E<G(@/2`D
M=&AI<RT^7W)U;D-O;6UA;F0H(G!H<&EZ92(L(&%R<F%Y*"8D=&AI<RP@)W!H
M<&EZ94-A;&QB86-K)RDI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D97)R*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(F!P:'!I>F4G(&9A:6QE9"(I.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@>WM[('-T87)T(&]F(&EN=&5R86-T:79E('!A<G0-
M"B`@("`@("`@)&-O;F9I9W5R95]C;VUM86YD(#T@(B1D:7(O8V]N9FEG=7)E
M(CL-"B`@("`@("`@)&-O;F9I9W5R95]O<'1I;VYS(#T@)'!K9RT^9V5T0V]N
M9FEG=7)E3W!T:6]N<R@I.PT*("`@("`@("!I9B`H)&-O;F9I9W5R95]O<'1I
M;VYS*2![#0H@("`@("`@("`@("!F;W)E86-H("@D8V]N9FEG=7)E7V]P=&EO
M;G,@87,@)&\I('L-"B`@("`@("`@("`@("`@("!L:7-T*"1R*2`]("1T:&ES
M+3YU:2T^=7-E<D1I86QO9R@G8G5I;&0G+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1O6R=P<F]M
M<'0G72DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W1E>'0G*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A`)&];)V1E
M9F%U;'0G72DI.PT*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)&];)VYA
M;64G72P@,"P@-2D@/3T@)W=I=&@M)R`F)@T*("`@("`@("`@("`@("`@("`@
M("`H)'(@/3T@)WEE<R<@?'P@)'(@/3T@)V%U=&]D971E8W0G*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0@+CT@(B`M+21O
M6VYA;65=(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0@+CT@(B`M+21O6VYA;65=
M/2(N=')I;2@D<BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@("\O('U]?2!E;F0@;V8@:6YT97)A8W1I
M=F4@<&%R=`T*#0H@("`@("`@("\O($9)6$U%(&UA:V4@8V]N9FEG=7)A8FQE
M#0H@("`@("`@(&EF*"$D=7-E<CUG971E;G8H)U5315(G*2E[#0H@("`@("`@
M("`@("`D=7-E<CTG9&5F875L='5S97(G.PT*("`@("`@("!]#0H@("`@("`@
M("1B=6EL9%]B87-E9&ER(#T@(B]V87(O=&UP+W!E87(M8G5I;&0M)'5S97(B
M.PT*("`@("`@("`D8G5I;&1?9&ER(#T@(B1B=6EL9%]B87-E9&ER+R1V9&ER
M(CL-"B`@("`@("`@)&EN<W1?9&ER(#T@(B1B=6EL9%]B87-E9&ER+VEN<W1A
M;&PM)'9D:7(B.PT*("`@("`@("`D=&AI<RT^;&]G*#$L(")B=6EL9&EN9R!I
M;B`D8G5I;&1?9&ER(BD[#0H@("`@("`@(&EF("AI<U]D:7(H)&)U:6QD7V1I
M<BDI('L-"B`@("`@("`@("`@(%-Y<W1E;3HZ<FTH87)R87DH)RUR9B<L("1B
M=6EL9%]D:7(I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(5-Y<W1E;3HZ
M;6M$:7(H87)R87DH)RUP)RP@)&)U:6QD7V1I<BDI*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@
M8G5I;&0@9&ER.B`D8G5I;&1?9&ER(BD[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/F%D9%1E;7!&:6QE*"1B=6EL9%]D:7(I.PT*("`@("`@("!I9B`H
M(5-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@)&EN<W1?9&ER*2DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T
M(&-R96%T92!T96UP;W)A<GD@:6YS=&%L;"!D:7(Z("1I;G-T7V1I<B(I.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3YA9&1496UP1FEL92@D:6YS=%]D
M:7(I.PT*#0H@("`@("`@(&EF("AG971E;G8H)TU!2T4G*2D@>PT*("`@("`@
M("`@("`@)&UA:V5?8V]M;6%N9"`](&=E=&5N=B@G34%+12<I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)&UA:V5?8V]M;6%N9"`]("=M86ME
M)SL-"B`@("`@("`@?0T*("`@("`@("`D=&]?<G5N(#T@87)R87DH#0H@("`@
M("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0L#0H@("`@("`@("`@("`D;6%K
M95]C;VUM86YD+`T*("`@("`@("`@("`@(B1M86ME7V-O;6UA;F0@24Y35$%,
M3%]23T]4/5PB)&EN<W1?9&ER7"(@:6YS=&%L;"(L#0H@("`@("`@("`@("`B
M9FEN9"!<(B1I;G-T7V1I<EPB("UL<R(-"B`@("`@("`@("`@("D[#0H@("`@
M("`@(&EF("@A0&-H9&ER*"1B=6EL9%]D:7(I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C:&1I<B!T;R`D
M8G5I;&1?9&ER(BD[#0H@("`@("`@('T-"B`@("`@("`@<'5T96YV*"=02%!?
M4$5!4E]615)324]./3$N-"XY)RD[#0H@("`@("`@(&9O<F5A8V@@*"1T;U]R
M=6X@87,@)&-M9"D@>PT*("`@("`@("`@("`@)&5R<B`]("1T:&ES+3Y?<G5N
M0V]M;6%N9"@D8VUD+"`D8V%L;&)A8VLI.PT*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@("`@("!C:&1I<B@D
M;VQD7V-W9"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21E<G(I('L-"B`@("`@("`@
M("`@("`@("!C:&1I<B@D;VQD7V-W9"D[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")@)&-M9"<@9F%I;&5D(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$H)&1P(#T@;W!E
M;F1I<B@B;6]D=6QE<R(I*2D@>PT*("`@("`@("`@("`@8VAD:7(H)&]L9%]C
M=V0I.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")N
M;R!@;6]D=6QE<R<@9&ER96-T;W)Y(&9O=6YD(BD[#0H@("`@("`@('T-"B`@
M("`@("`@)&)U:6QT7V9I;&5S(#T@87)R87DH*3L-"B`@("`@("`@)'!R969I
M>"`](&5X96,H(G!H<"UC;VYF:6<@+2UP<F5F:7@B*3L-"B`@("`@("`@)'1H
M:7,M/E]H87)V97-T26YS=$1I<B@D<')E9FEX+"`D:6YS=%]D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)'!R969I>"P@)&)U:6QT7V9I;&5S*3L-"B`@
M("`@("`@8VAD:7(H)&]L9%]C=V0I.PT*("`@("`@("!R971U<FX@)&)U:6QT
M7V9I;&5S.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!P:'!I
M>F5#86QL8F%C:R@I#0H-"B`@("`O*BH-"B`@("`@*B!-97-S86=E(&-A;&QB
M86-K(&9U;F-T:6]N('5S960@=VAE;B!R=6YN:6YG('1H92`B<&AP:7IE(@T*
M("`@("`J('!R;V=R86TN("!%>'1R86-T<R!T:&4@05!)(&YU;6)E<G,@=7-E
M9"X@($EG;F]R97,@;W1H97(@;65S<V%G90T*("`@("`J('1Y<&5S('1H86X@
M(F-M9&]U='!U="(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1W
M:&%T('1H92!T>7!E(&]F(&UE<W-A9V4-"B`@("`@*B!`<&%R86T@;6EX960@
M)&1A=&$@=&AE(&UE<W-A9V4-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I
M9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!P:'!I>F5#86QL8F%C:R@D=VAA="P@)&1A=&$I#0H@("`@
M>PT*("`@("`@("!I9B`H)'=H870@(3T@)V-M9&]U='!U="<I('L-"B`@("`@
M("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;&]G
M*#$L(')T<FEM*"1D871A*2D[#0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M66]U('-H;W5L9"!U<&1A=&4@>6]U<B`N86-L;V-A;"YM-"\G+"`D9&%T82DI
M('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("`D
M;6%T8VAE<R`](&%R<F%Y*"D[#0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7EQS*RA<4UM>.ETK*3I<<RLH7&1[.'TI+R<L("1D871A+"`D;6%T8VAE<RDI
M('L-"B`@("`@("`@("`@("1M96UB97(@/2!P<F5G7W)E<&QA8V4H)R];7F$M
M>ETO)RP@)U\G+"!S=')T;VQO=V5R*"1M871C:&5S6S%=*2D[#0H@("`@("`@
M("`@("`D87!I;F\@/2`H:6YT*21M871C:&5S6S)=.PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3XD;65M8F5R*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3XD;65M8F5R(#T@)&%P:6YO.PT*("`@("`@("`@("`@("`@("\O
M)&US9R`]('-P<FEN=&8H(B4M,C)S(#H@)60B+"`D;6%T8VAE<ULQ72P@)&%P
M:6YO*3L-"B`@("`@("`@("`@("`@("`O+R1T:&ES+3YL;V<H,2P@)&US9RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@7W)U;D-O;6UA;F0H*0T*#0H@("`@+RHJ#0H@("`@
M("H@4G5N(&%N(&5X=&5R;F%L(&-O;6UA;F0L('5S:6YG(&$@;65S<V%G92!C
M86QL8F%C:R!T;R!R97!O<G0-"B`@("`@*B!O=71P=70N("!4:&4@8V]M;6%N
M9"!W:6QL(&)E(')U;B!T:')O=6=H('!O<&5N(&%N9"!O=71P=70@:7,-"B`@
M("`@*B!R97!O<G1E9"!F;W(@979E<GD@;&EN92!W:71H(&$@(F-M9&]U='!U
M="(@;65S<V%G92!W:71H('1H90T*("`@("`J(&QI;F4@<W1R:6YG+"!I;F-L
M=61I;F<@;F5W;&EN97,L(&%S('!A>6QO860N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VUM86YD('1H92!C;VUM86YD('1O(')U;@T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1C86QL8F%C:R`H;W!T:6]N86PI
M(&9U;F-T:6]N('1O('5S92!A<R!M97-S86=E#0H@("`@("H@8V%L;&)A8VL-
M"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!W:&5T:&5R('1H92!C;VUM
M86YD('=A<R!S=6-C97-S9G5L("AE>&ET(&-O9&4@,`T*("`@("`J(&UE86YS
M('-U8V-E<W,L(&%N>2!O=&AE<B!M96%N<R!F86EL=7)E*0T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7W)U;D-O;6UA;F0H)&-O;6UA;F0L("1C86QL8F%C:R`](&YU;&PI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^;&]G*#$L(")R=6YN:6YG.B`D8V]M;6%N9"(I
M.PT*("`@("`@("`D<'`@/2!`<&]P96XH(B1C;VUM86YD(#(^)C$B+"`B<B(I
M.PT*("`@("`@("!I9B`H(21P<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")F86EL960@=&\@<G5N(&`D8V]M;6%N9"<B*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-A;&QB86-K("8F("1C86QL8F%C
M:ULP72T^9&5B=6<@/3T@,2D@>PT*("`@("`@("`@("`@)&]L9&1B9R`]("1C
M86QL8F%C:ULP72T^9&5B=6<[#0H@("`@("`@("`@("`D8V%L;&)A8VM;,%TM
M/F1E8G5G(#T@,CL-"B`@("`@("`@?0T*#0H@("`@("`@('=H:6QE("@D;&EN
M92`](&9G971S*"1P<"P@,3`R-"DI('L-"B`@("`@("`@("`@(&EF("@D8V%L
M;&)A8VLI('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D8V%L
M;&)A8VLL("=C;61O=71P=70G+"`D;&EN92D[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,BP@<G1R:6TH)&QI
M;F4I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&-A;&QB86-K("8F(&ES<V5T*"1O;&1D8F<I*2![#0H@("`@("`@("`@("`D
M8V%L;&)A8VM;,%TM/F1E8G5G(#T@)&]L9&1B9SL-"B`@("`@("`@?0T*("`@
M("`@("`D97AI=&-O9&4@/2!`<&-L;W-E*"1P<"D[#0H@("`@("`@(')E='5R
M;B`H)&5X:71C;V1E(#T](#`I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!L;V<H*0T*#0H@("`@9G5N8W1I;VX@;&]G*"1L979E;"P@)&US
M9RD-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^8W5R<F5N=%]C86QL8F%C
M:RD@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3YD96)U9R`^/2`D;&5V96PI
M('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D=&AI<RT^8W5R
M<F5N=%]C86QL8F%C:RP@)V]U='!U="<L("1M<V<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!014%27T-O;6UO;CHZ;&]G*"1L979E;"P@)&US9RD[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]!=71O;&]A9&5R+G!H<```````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34W-#$`,3`U,34T,S$P-3<`,#(P
M-S$P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO*BH-"B`J($-L87-S(&%U=&\M;&]A9&5R#0H@*@T*("H@4$A0
M('9E<G-I;VYS(#0-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"
M86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z($%U=&]L;V%D97(N<&AP+'8@,2XQ,R`R,#`V
M+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO8V]R92YP<&TN<&AP(V-O
M<F4N<'!M+G!E87(M875T;VQO861E<@T*("H@0'-I;F-E("`@("`@1FEL92!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J($!D97!R96-A=&5D($9I
M;&4@9&5P<F5C871E9"!I;B!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO+R`O
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@
M*B\-"@T*:68@*"%E>'1E;G-I;VY?;&]A9&5D*")O=F5R;&]A9"(I*2![#0H@
M("`@+R\@9&EE(&AA<F0@=VET:&]U="!E>'0O;W9E<FQO860-"B`@("!D:64H
M(E)E8G5I;&0@4$A0('=I=&@@=&AE(&!O=F5R;&]A9"<@97AT96YS:6]N('1O
M('5S92!014%27T%U=&]L;V%D97(B*3L-"GT-"@T*+RHJ#0H@*B!);F-L=61E
M(&9O<B!014%27T5R<F]R(&%N9"!014%2(&-L87-S97,-"B`J+PT*<F5Q=6ER
M95]O;F-E(")014%2+G!H<"([#0H-"B\J*@T*("H@5&AI<R!C;&%S<R!I<R!F
M;W(@;V)J96-T<R!W:&5R92!Y;W4@=V%N="!T;R!S97!A<F%T92!T:&4@8V]D
M92!F;W(-"B`J('-O;64@;65T:&]D<R!I;G1O('-E<&%R871E(&-L87-S97,N
M("!4:&ES(&ES('5S969U;"!I9B!Y;W4@:&%V92!A#0H@*B!C;&%S<R!W:71H
M(&YO="UF<F5Q=65N=&QY+75S960@;65T:&]D<R!T:&%T(&-O;G1A:6X@;&]T
M<R!O9B!C;V1E#0H@*B!T:&%T('EO=2!W;W5L9"!L:6ME('1O(&%V;VED(&%L
M=V%Y<R!P87)S:6YG+@T*("H-"B`J(%1H92!014%27T%U=&]L;V%D97(@8VQA
M<W,@<')O=FED97,@875T;VQO861I;F<@86YD(&%G9W)E9V%T:6]N+@T*("H@
M5&AE(&%U=&]L;V%D:6YG(&QE=',@>6]U('-E="!U<"!I;B!W:&EC:"!C;&%S
M<V5S('1H92!S97!A<F%T960-"B`J(&UE=&AO9',@87)E(&9O=6YD+B`@06=G
M<F5G871I;VX@:7,@=&AE('1E8VAN:7%U92!U<V5D('1O(&EM<&]R="!N97<-
M"B`J(&UE=&AO9',L(&%N(&EN<W1A;F-E(&]F(&5A8V@@8VQA<W,@<')O=FED
M:6YG('-E<&%R871E9"!M971H;V1S(&ES#0H@*B!S=&]R960@86YD(&-A;&QE
M9"!E=F5R>2!T:6UE('1H92!A9V=R96=A=&5D(&UE=&AO9"!I<R!C86QL960N
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M8V]R92YP<&TN<&AP(V-O<F4N<'!M+G!E87(M875T;VQO861E<@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M($!D97!R96-A=&5D($9I;&4@9&5P<F5C871E9"!I;B!296QE87-E(#$N-"XP
M83$-"B`J+PT*8VQA<W,@4$5!4E]!=71O;&]A9&5R(&5X=&5N9',@4$5!4@T*
M>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("`O*BH-"B`@("`@*B!-
M87`@;V8@;65T:&]D<R!A;F0@8VQA<W-E<R!W:&5R92!T:&5Y(&%R92!D969I
M;F5D#0H@("`@("H-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]A=71O;&]A
M9%]M87`@/2!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@36%P(&]F(&UE
M=&AO9',@86YD(&%G9W)E9V%T92!O8FIE8W1S#0H@("`@("H-"B`@("`@*B!`
M=F%R(&%R<F%Y#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]M971H;V1?;6%P(#T@87)R87DH*3L-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!A9&1!=71O;&]A9"@I#0H-"B`@("`O*BH-
M"B`@("`@*B!!9&0@;VYE(&]R(&UO<F4@875T;VQO860@96YT<FEE<RX-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@("`@=VAI8V@@
M;65T:&]D('1O(&%U=&]L;V%D#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;&%S<VYA;64@("AO<'1I;VYA;"D@=VAI8V@@8VQA<W,@=&\@9FEN
M9"!T:&4@;65T:&]D(&EN+@T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@268@=&AE("1M971H;V0@<&%R86UE=&5R(&ES(&%N(&%R<F%Y+"!T
M:&ES#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T
M97(@;6%Y(&)E(&]M:71T960@*&%N9"!W:6QL(&)E(&EG;F]R960-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF(&YO="DL(&%N9"!T:&4@
M)&UE=&AO9"!P87)A;65T97(@=VEL;"!B90T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=')E871E9"!A<R!A;B!A<W-O8VEA=&EV92!A<G)A
M>2!W:71H(&UE=&AO9`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;F%M97,@87,@:V5Y<R!A;F0@8VQA<W,@;F%M97,@87,@=F%L=65S+@T*
M("`@("`J#0H@("`@("H@0')E='5R;B!V;VED#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$%U=&]L
M;V%D*"1M971H;V0L("1C;&%S<VYA;64@/2!N=6QL*0T*("`@('L-"B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1M971H;V0I*2![#0H@("`@("`@("`@("!A<G)A
M>5]W86QK*"1M971H;V0L(&-R96%T95]F=6YC=&EO;B@G)&$L)B1B)RP@)R1B
M(#T@<W1R=&]L;W=E<B@D8BD[)RDI.PT*("`@("`@("`@("`@)'1H:7,M/E]A
M=71O;&]A9%]M87`@/2!A<G)A>5]M97)G92@D=&AI<RT^7V%U=&]L;V%D7VUA
M<"P@)&UE=&AO9"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&AI<RT^7V%U=&]L;V%D7VUA<%MS=')T;VQO=V5R*"1M971H;V0I72`]("1C
M;&%S<VYA;64[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@<F5M;W9E075T;VQO860H*0T*#0H@("`@+RHJ#0H@("`@("H@
M4F5M;W9E(&%N(&%U=&]L;V%D(&5N=')Y+@T*("`@("`J#0H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;65T:&]D("!W:&EC:"!M971H;V0@=&\@<F5M;W9E('1H
M92!A=71O;&]A9"!E;G1R>2!F;W(-"B`@("`@*@T*("`@("`J($!R971U<FX@
M8F]O;"!44E5%(&EF(&%N(&5N=')Y('=A<R!R96UO=F5D+"!&04Q312!I9B!N
M;W0-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@<F5M;W9E075T;VQO860H)&UE=&AO9"D-"B`@("![#0H@
M("`@("`@("1M971H;V0@/2!S=')T;VQO=V5R*"1M971H;V0I.PT*("`@("`@
M("`D;VL@/2!I<W-E="@D=&AI<RT^7V%U=&]L;V%D7VUA<%LD;65T:&]D72D[
M#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?875T;VQO861?;6%P6R1M971H;V1=
M*3L-"B`@("`@("`@<F5T=7)N("1O:SL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@861D06=G<F5G871E3V)J96-T*"D-"@T*("`@("\J*@T*
M("`@("`J($%D9"!A;B!A9V=R96=A=&4@;V)J96-T('1O('1H:7,@;V)J96-T
M+B`@268@=&AE('-P96-I9FEE9"!C;&%S<PT*("`@("`J(&ES(&YO="!D969I
M;F5D+"!L;V%D:6YG(&ET('=I;&P@8F4@871T96UP=&5D(&9O;&QO=VEN9R!0
M14%2)W,-"B`@("`@*B!F:6QE(&YA;6EN9R!S8VAE;64N("!!;&P@=&AE(&UE
M=&AO9',@:6X@=&AE(&-L87-S('=I;&P@8F4-"B`@("`@*B!A9V=R96=A=&5D
M+"!E>&-E<'0@<')I=F%T92!O;F5S("AN86UE('-T87)T:6YG('=I=&@@86X-
M"B`@("`@*B!U;F1E<G-C;W)E*2!A;F0@8V]N<W1R=6-T;W)S+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W-N86UE("!W:&%T(&-L87-S
M('1O(&EN<W1A;G1I871E(&9O<B!T:&4@;V)J96-T+@T*("`@("`J#0H@("`@
M("H@0')E='5R;B!V;VED#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$%G9W)E9V%T94]B:F5C="@D
M8VQA<W-N86UE*0T*("`@('L-"B`@("`@("`@)&-L87-S;F%M92`]('-T<G1O
M;&]W97(H)&-L87-S;F%M92D[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"1C;&%S<VYA;64I*2![#0H@("`@("`@("`@("`D:6YC;'5D95]F:6QE(#T@
M<')E9U]R97!L86-E*"<O6UYA+7HP+3E=+VDG+"`G7R<L("1C;&%S<VYA;64I
M.PT*("`@("`@("`@("`@:6YC;'5D95]O;F-E("1I;F-L=61E7V9I;&4[#0H@
M("`@("`@('T-"B`@("`@("`@)&]B:B`])B!N97<@)&-L87-S;F%M93L-"B`@
M("`@("`@)&UE=&AO9',@/2!G971?8VQA<W-?;65T:&]D<R@D8VQA<W-N86UE
M*3L-"B`@("`@("`@9F]R96%C:"`H)&UE=&AO9',@87,@)&UE=&AO9"D@>PT*
M("`@("`@("`@("`@+R\@9&]N)W0@:6UP;W)T('!R:79I871E(&UE=&AO9',@
M86YD(&-O;G-T<G5C=&]R<PT*("`@("`@("`@("`@:68@*"1M971H;V1[,'T@
M(3T@)U\G("8F("1M971H;V0@(3T@)&-L87-S;F%M92D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;65T:&]D7VUA<%LD;65T:&]D72`]("1O8FH[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@<F5M;W9E06=G<F5G871E3V)J96-T*"D-"@T*("`@("\J
M*@T*("`@("`J(%)E;6]V92!A;B!A9V=R96=A=&4@;V)J96-T+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W-N86UE("!T:&4@8VQA<W,@
M;V8@=&AE(&]B:F5C="!T;R!R96UO=F4-"B`@("`@*@T*("`@("`J($!R971U
M<FX@8F]O;"`@5%)512!I9B!A;B!O8FIE8W0@=V%S(')E;6]V960L($9!3%-%
M(&EF(&YO=`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!R96UO=F5!9V=R96=A=&5/8FIE8W0H)&-L87-S
M;F%M92D-"B`@("![#0H@("`@("`@("1O:R`](&9A;'-E.PT*("`@("`@("`D
M8VQA<W-N86UE(#T@<W1R=&]L;W=E<B@D8VQA<W-N86UE*3L-"B`@("`@("`@
M<F5S970H)'1H:7,M/E]M971H;V1?;6%P*3L-"B`@("`@("`@=VAI;&4@*&QI
M<W0H)&UE=&AO9"P@)&]B:BD@/2!E86-H*"1T:&ES+3Y?;65T:&]D7VUA<"DI
M('L-"B`@("`@("`@("`@(&EF("AI<U]A*"1O8FHL("1C;&%S<VYA;64I*2![
M#0H@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]M971H;V1?;6%P6R1M
M971H;V1=*3L-"B`@("`@("`@("`@("`@("`D;VL@/2!T<G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D;VL[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]?8V%L;"@I#0H-"B`@("`O
M*BH-"B`@("`@*B!/=F5R;&]A9&5D(&]B:F5C="!C86QL(&AA;F1L97(L(&-A
M;&QE9"!E86-H('1I;64@86X-"B`@("`@*B!U;F1E9FEN960O86=G<F5G871E
M9"!M971H;V0@:7,@:6YV;VME9"X@(%1H:7,@;65T:&]D(')E<&5A=',-"B`@
M("`@*B!T:&4@8V%L;"!I;B!T:&4@<FEG:'0@86=G<F5G871E(&]B:F5C="!A
M;F0@<&%S<V5S(&]N('1H92!R971U<FX-"B`@("`@*B!V86QU92X-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@=VAI8V@@;65T:&]D
M('1H870@=V%S(&-A;&QE9`T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87)G<R`@("!!;B!A<G)A>2!O9B!T:&4@<&%R86UE=&5R<R!P87-S960@
M:6X@=&AE#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!O<FEG:6YA
M;"!C86QL#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5T
M=7)N('9A;'5E(&9R;VT@=&AE(&%G9W)E9V%T960@;65T:&]D+"!O<B!A(%!%
M05(-"B`@("`@*B`@("`@("`@("`@("`@("!E<G)O<B!I9B!T:&4@8V%L;&5D
M(&UE=&AO9"!W87,@=6YK;F]W;BX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M7V-A;&PH)&UE=&AO9"P@)&%R9W,L("8D<F5T=F%L*0T*("`@('L-"B`@("`@
M("`@)&UE=&AO9"`]('-T<G1O;&]W97(H)&UE=&AO9"D[#0H@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^7VUE=&AO9%]M87!;)&UE=&AO9%TI("8F(&ES<V5T
M*"1T:&ES+3Y?875T;VQO861?;6%P6R1M971H;V1=*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/F%D9$%G9W)E9V%T94]B:F5C="@D=&AI<RT^7V%U=&]L;V%D
M7VUA<%LD;65T:&]D72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?;65T:&]D7VUA<%LD;65T:&]D72DI('L-"B`@("`@("`@("`@
M("1R971V86P@/2!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D=&AI<RT^
M7VUE=&AO9%]M87!;)&UE=&AO9%TL("1M971H;V0I+"`D87)G<RD[#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"F]V97)L;V%D
M*")014%27T%U=&]L;V%D97(B*3L-"@T*/SX-"@``````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$5!4B]#:&%N;F5L1FEL92YP:'``````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`Q-C$W-S,`,3`U,34T,S$P-3<`,#(P-S<P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP#0HO*BH-"B`J
M(%!%05)?0VAA;FYE;$9I;&4L('1H92!C:&%N;F5L(&AA;F1L:6YG(&-L87-S
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($-H86YN
M96Q&:6QE+G!H<"QV(#$N-S4@,C`P-B\P,R\P,B`Q.#HQ-#HQ,B!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J($YE961E9"!F;W(@
M97)R;W(@:&%N9&QI;F<-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T5R<F]R
M4W1A8VLN<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]834Q087)S97(N<&AP
M)SL-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E(&EF('1H92!C:&%N;F5L+GAM;"`\8VAA;FYE;#X@=&%G
M(&1O97,@;F]T(&-O;G1A:6X@82!V86QI9"!V97)S:6]N#0H@*B\-"F1E9FEN
M92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]615)324].)RP@,2D[#0HO
M*BH-"B`J($5R<F]R(&-O9&4@:68@=&AE(&-H86YN96PN>&UL(#QC:&%N;F5L
M/B!T86<@=F5R<VEO;B!I<R!N;W0@<W5P<&]R=&5D("AV97)S:6]N(#$N,"!I
M<R!T:&4@;VYL>2!S=7!P;W)T960@=F5R<VEO;BP-"B`J(&-U<G)E;G1L>0T*
M("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]6
M15)324].)RP@,BD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!I9B!P87)S:6YG
M(&ES(&%T=&5M<'1E9"!W:71H(&YO('AM;"!E>'1E;G-I;VX-"B`J+PT*9&5F
M:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/7UA-3%]%6%0G+"`S*3L-
M"@T*+RHJ#0H@*B!%<G)O<B!C;V1E(&EF(&-R96%T:6YG('1H92!X;6P@<&%R
M<V5R(')E<V]U<F-E(&9A:6QS#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,
M1DE,15]%4E)/4E]#04Y47TU!2T5?4$%24T52)RP@-"D[#0H-"B\J*@T*("H@
M17)R;W(@8V]D92!U<V5D(&9O<B!A;&P@<V%X('AM;"!P87)S:6YG(&5R<F]R
M<PT*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?4$%24T52
M7T524D]2)RP@-2D[#0H-"B\J*B-`*PT*("H@5F%L:61A=&EO;B!E<G)O<G,-
M"B`J+PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@8VAA;FYE;"!N86UE(&ES
M(&UI<W-I;F<-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]2
M7TY/7TY!344G+"`V*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&-H86YN
M96P@;F%M92!I<R!I;G9A;&ED#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,
M1DE,15]%4E)/4E])3E9!3$E$7TY!344G+"`W*3L-"B\J*@T*("H@17)R;W(@
M8V]D92!W:&5N(&-H86YN96P@<W5M;6%R>2!I<R!M:7-S:6YG#0H@*B\-"F1E
M9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]354U-05)9)RP@."D[
M#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!C:&%N;F5L('-U;6UA<GD@:7,@
M;75L=&DM;&EN90T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?355,5$E,24Y%7U-534U!4EDG+"`Y*3L-"B\J*@T*("H@17)R;W(@8V]D
M92!W:&5N(&-H86YN96P@<V5R=F5R(&ES(&UI<W-I;F<@9F]R('AM;')P8R!O
M<B!S;V%P('!R;W1O8V]L#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E].3U](3U-4)RP@,3`I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@8VAA;FYE;"!S97)V97(@:7,@:6YV86QI9"!F;W(@>&UL<G!C(&]R('-O
M87`@<')O=&]C;VP-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T52
M4D]27TE.5D%,241?2$]35"<L(#$Q*3L-"B\J*@T*("H@17)R;W(@8V]D92!W
M:&5N(&$@;6ER<F]R(&YA;64@:7,@:6YV86QI9`T*("HO#0ID969I;F4H)U!%
M05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]-25)23U(G+"`R,2D[#0HO
M*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&UI<G)O<B!T>7!E(&ES(&EN=F%L
M:60-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,
M241?34E24D]25%E012<L(#(R*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N
M(&%N(&%T=&5M<'0@:7,@;6%D92!T;R!G96YE<F%T92!X;6PL(&)U="!T:&4@
M<&%R<V5D(&-O;G1E;G0@:7,@:6YV86QI9`T*("HO#0ID969I;F4H)U!%05)?
M0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1"<L(#(S*3L-"B\J*@T*("H@17)R
M;W(@8V]D92!W:&5N(&%N(&5M<'1Y('!A8VMA9V4@;F%M92!V86QI9&%T92!R
M96=E>"!I<R!P87-S960@:6X-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&
M24Q%7T524D]27T5-4%197U)%1T58)RP@,C0I.PT*+RHJ#0H@*B!%<G)O<B!C
M;V1E('=H96X@82`\9G5N8W1I;VX^('1A9R!H87,@;F\@=F5R<VEO;@T*("HO
M#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?1E5.0U1)3TY6
M15)324].)RP@,C4I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82`\9G5N
M8W1I;VX^('1A9R!H87,@;F\@;F%M90T*("HO#0ID969I;F4H)U!%05)?0TA!
M3DY%3$9)3$5?15)23U)?3D]?1E5.0U1)3TY.04U%)RP@,C8I.PT*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82`\=F%L:61A=&5P86-K86=E/B!T86<@:&%S
M(&YO(&YA;64-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]2
M7TY/5D%,241!5$5?3D%-12<L(#(W*3L-"B\J*@T*("H@17)R;W(@8V]D92!W
M:&5N(&$@/'9A;&ED871E<&%C:V%G93X@=&%G(&AA<R!N;R!V97)S:6]N(&%T
M=')I8G5T90T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?
M3D]604Q)1$%415]615)324].)RP@,C@I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E
M('=H96X@82!M:7)R;W(@9&]E<R!N;W0@97AI<W0@8G5T(&ES(&-A;&QE9"!F
M;W(@:6X@;VYE(&]F('1H92!S970J#0H@*B!M971H;V1S+@T*("HO#0ID969I
M;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?34E24D]27TY/5%]&3U5.1"<L
M(#,R*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@<V5R=F5R('!O<G0@
M:7,@;F]T(&YU;65R:6,-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%
M7T524D]27TE.5D%,241?4$]25"<L(#,S*3L-"B\J*@T*("H@17)R;W(@8V]D
M92!W:&5N(#QS=&%T:6,^(&-O;G1A:6YS(&YO('9E<G-I;VX@871T<FEB=71E
M#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]35$%4
M24-615)324].)RP@,S0I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@/&)A
M<V5U<FP^(&-O;G1A:6YS(&YO('1Y<&4@871T<FEB=71E(&EN(&$@/')E<W0^
M('!R;W1O8V]L(&1E9FEN:71I;VX-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.
M14Q&24Q%7T524D]27TY/0D%315523%194$4G+"`S-2D[#0HO*BH@#0H@*B!%
M<G)O<B!C;V1E('=H96X@82!M:7)R;W(@:7,@9&5F:6YE9"!A;F0@=&AE(&-H
M86YN96PN>&UL(')E<')E<V5N=',@=&AE(%]?=7)I('!S975D;RUC:&%N;F5L
M#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]54DE?0T%.5%]-25)2
M3U(G+"`S-BD[#0HO*BH@#0H@*B!%<G)O<B!C;V1E('=H96X@<W-L(&%T=')I
M8G5T92!I<R!P<F5S96YT(&%N9"!I<R!N;W0@(GEE<R(-"B`J+PT*9&5F:6YE
M*"=014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?4U-,)RP@,S<I.PT*
M+RHJ(T`M*B\-"@T*+RHJ#0H@*B!-:7)R;W(@='EP97,@86QL;W=E9"X@($-U
M<G)E;G1L>2!O;FQY(&EN=&5R;F5T('-E<G9E<G,@87)E(')E8V]G;FEZ960N
M#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]#2$%.3D5,4U]-25)23U)?5%E015,G
M72`]("!A<G)A>2@G<V5R=F5R)RD[#0H-"@T*+RHJ#0H@*B!4:&4@0VAA;FYE
M;"!H86YD;&EN9R!C;&%S<PT*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA
M<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S
M<R!014%27T-H86YN96Q&:6QE('L-"B`@("`O*BH-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B!`=F%R(%!%05)?17)R;W)3=&%C:PT*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W-T86-K.PT*
M("`@(`T*("`@("\J*@T*("`@("`J(%-U<'!O<G1E9"!C:&%N;F5L+GAM;"!V
M97)S:6]N<RP@9F]R('!A<G-I;F<-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<W5P<&]R
M=&5D5F5R<VEO;G,@/2!A<G)A>2@G,2XP)RD[#0H-"B`@("`O*BH-"B`@("`@
M*B!087)S960@8VAA;FYE;"!I;F9O<FUA=&EO;@T*("`@("`J($!V87(@87)R
M87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]C:&%N;F5L26YF;SL-"@T*("`@("\J*@T*("`@("`J(&EN9&5X(&EN=&\@
M=&AE('-U8F-H86YN96QS(&%R<F%Y+"!U<V5D(&9O<B!P87)S:6YG('AM;`T*
M("`@("`J($!V87(@:6YT#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@=F%R("1?<W5B8VAA;FYE;$EN9&5X.PT*#0H@("`@+RHJ#0H@
M("`@("H@:6YD97@@:6YT;R!T:&4@;6ER<F]R<R!A<G)A>2P@=7-E9"!F;W(@
M<&%R<VEN9R!X;6P-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VUI<G)O<DEN9&5X.PT*("`@
M(`T*("`@("\J*@T*("`@("`J($9L86<@=7-E9"!T;R!D971E<FUI;F4@=&AE
M('9A;&ED:71Y(&]F('!A<G-E9"!C;VYT96YT#0H@("`@("H@0'9A<B!B;V]L
M96%N#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?:7-686QI9"`](&9A;'-E.PT*#0H@("`@9G5N8W1I;VX@4$5!4E]#:&%N
M;F5L1FEL92@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K(#T@)FYE
M=R!014%27T5R<F]R4W1A8VLH)U!%05)?0VAA;FYE;$9I;&4G*3L-"B`@("`@
M("`@)'1H:7,M/E]S=&%C:RT^<V5T17)R;W)-97-S86=E5&5M<&QA=&4H)'1H
M:7,M/E]G971%<G)O<DUE<W-A9V4H*2D[#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](&9A;'-E.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?9V5T17)R;W)-97-S86=E*"D-"B`@("![#0H@
M("`@("`@(')E='5R;@T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U9%4E-)3TX@
M/3X-"B`@("`@("`@("`@("`@("`@("`@)U=H:6QE('!A<G-I;F<@8VAA;FYE
M;"YX;6PL(&%N(&EN=F%L:60@=F5R<VEO;B!N=6UB97(@(B5V97)S:6]N)2!W
M87,@<&%S<V5D(&EN+"!E>'!E8W1I;F<@;VYE(&]F("5V97)S:6]N<R4G+`T*
M("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?5D52
M4TE/3B`]/@T*("`@("`@("`@("`@("`@("`@("`G3F\@=F5R<VEO;B!N=6UB
M97(@9F]U;F0@:6X@/&-H86YN96P^('1A9R<L#0H@("`@("`@("`@("`@("`@
M4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]834Q?15A4(#T^#0H@("`@("`@
M("`@("`@("`@("`@("<E97)R;W(E)RP-"B`@("`@("`@("`@("`@("!014%2
M7T-(04Y.14Q&24Q%7T524D]27T-!3E1?34%+15]005)315(@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)U5N86)L92!T;R!C<F5A=&4@6$U,('!A<G-E<B<L
M#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]005)3
M15)?15)23U(@/3X-"B`@("`@("`@("`@("`@("`@("`@)R5E<G)O<B4G+`T*
M("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?3D%-
M12`]/@T*("`@("`@("`@("`@("`@("`@("`G36ES<VEN9R!C:&%N;F5L(&YA
M;64G+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?
M24Y604Q)1%].04U%(#T^#0H@("`@("`@("`@("`@("`@("`@("=);G9A;&ED
M(&-H86YN96P@)71A9R4@(B5N86UE)2(G+`T*("`@("`@("`@("`@("`@(%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4U5-34%262`]/@T*("`@("`@("`@
M("`@("`@("`@("`G36ES<VEN9R!C:&%N;F5L('-U;6UA<GDG+`T*("`@("`@
M("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?355,5$E,24Y%7U-5
M34U!4ED@/3X-"B`@("`@("`@("`@("`@("`@("`@)T-H86YN96P@<W5M;6%R
M>2!S:&]U;&0@8F4@;VX@;VYE(&QI;F4L(&)U="!I<R!M=6QT:2UL:6YE)RP-
M"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TY/7TA/
M4U0@/3X-"B`@("`@("`@("`@("`@("`@("`@)TUI<W-I;F<@8VAA;FYE;"!S
M97)V97(@9F]R("5T>7!E)2!S97)V97(G+`T*("`@("`@("`@("`@("`@(%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%](3U-4(#T^#0H@("`@("`@
M("`@("`@("`@("`@("=397)V97(@;F%M92`B)7-E<G9E<B4B(&ES(&EN=F%L
M:60@9F]R("5T>7!E)2!S97)V97(G+`T*("`@("`@("`@("`@("`@(%!%05)?
M0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]-25)23U(@/3X-"B`@("`@("`@
M("`@("`@("`@("`@)TEN=F%L:60@;6ER<F]R(&YA;64@(B5N86UE)2(L(&UI
M<G)O<B!T>7!E("5T>7!E)2<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E])3E9!3$E$7TU)4E)/4E194$4@/3X-"B`@("`@("`@
M("`@("`@("`@("`@)TEN=F%L:60@;6ER<F]R('1Y<&4@(B5T>7!E)2(G+`T*
M("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)
M1"`]/@T*("`@("`@("`@("`@("`@("`@("`G0V%N;F]T(&=E;F5R871E('AM
M;"P@8V]N=&5N=',@87)E(&EN=F%L:60G+`T*("`@("`@("`@("`@("`@(%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?14U05%E?4D5'15@@/3X-"B`@("`@("`@
M("`@("`@("`@("`@)W!A8VMA9V5N86UE<F5G97@@8V%N;F]T(&)E(&5M<'1Y
M)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TY/
M7T953D-424].5D524TE/3B`]/@T*("`@("`@("`@("`@("`@("`@("`G)7!A
M<F5N="4@)7!R;W1O8V]L)2!F=6YC=&EO;B!H87,@;F\@=F5R<VEO;B<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]&54Y#
M5$E/3DY!344@/3X-"B`@("`@("`@("`@("`@("`@("`@)R5P87)E;G0E("5P
M<F]T;V-O;"4@9G5N8W1I;VX@:&%S(&YO(&YA;64G+`T*("`@("`@("`@("`@
M("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]"05-%55),5%E012`]/@T*
M("`@("`@("`@("`@("`@("`@("`G)7!A<F5N="4@<F5S="!B87-E=7)L(&AA
M<R!N;R!T>7!E)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%
M7T524D]27TY/5D%,241!5$5?3D%-12`]/@T*("`@("`@("`@("`@("`@("`@
M("`G5F%L:61A=&EO;B!P86-K86=E(&AA<R!N;R!N86UE(&EN(#QV86QI9&%T
M97!A8VMA9V4^('1A9R<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,
M1DE,15]%4E)/4E].3U9!3$E$051%7U9%4E-)3TX@/3X-"B`@("`@("`@("`@
M("`@("`@("`@)U9A;&ED871I;VX@<&%C:V%G92`B)7!A8VMA9V4E(B!H87,@
M;F\@=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E]-25)23U)?3D]47T9/54Y$(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=-:7)R;W(@(B5M:7)R;W(E(B!D;V5S(&YO="!E>&ES="<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U!/
M4E0@/3X-"B`@("`@("`@("`@("`@("`@("`@)U!O<G0@(B5P;W)T)2(@;75S
M="!B92!N=6UE<FEC)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&
M24Q%7T524D]27TY/7U-4051)0U9%4E-)3TX@/3X-"B`@("`@("`@("`@("`@
M("`@("`@)SQS=&%T:6,^('1A9R!M=7-T(&-O;G1A:6X@=F5R<VEO;B!A='1R
M:6)U=&4G+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?55))
M7T-!3E1?34E24D]2(#T^#0H@("`@("`@("`@("`@("`@("`@("=4:&4@7U]U
M<FD@<'-E=61O+6-H86YN96P@8V%N;F]T(&AA=F4@;6ER<F]R<R<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U-3
M3"`]/@T*("`@("`@("`@("`@("`@("`@("`G)7-E<G9E<B4@:&%S(&EN=F%L
M:60@<W-L(&%T=')I8G5T92`B)7-S;"4B(&-A;B!O;FQY(&)E('EE<R!O<B!N
M;W0@<')E<V5N="<L#0H@("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!S=')I;F<@8V]N=&5N=',@;V8@<&%C:V%G92YX
M;6P@9FEL90T*("`@("`J($!R971U<FX@8F]O;"!S=6-C97-S(&]F('!A<G-I
M;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!F<F]M6&UL4W1R:6YG*"1D871A
M*0T*("`@('L-"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\\8VAA;FYE;%QS
M*W9E<G-I;VX](BA;,"TY72M<+ELP+3E=*RDB+R<L("1D871A+"`D8VAA;FYE
M;'9E<G-I;VXI*2![#0H@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1C:&%N
M;F5L=F5R<VEO;ELQ72P@)'1H:7,M/E]S=7!P;W)T961697)S:6]N<RDI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%!%05)?0TA!
M3DY%3$9)3$5?15)23U)?24Y604Q)1%]615)324].+"`G97)R;W(G+`T*("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G=F5R<VEO;B<@/3X@)&-H86YN96QV
M97)S:6]N6S%=*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!A<G-E<B`](&YE=R!014%2
M7UA-3%!A<G-E<CL-"B`@("`@("`@("`@("1R97-U;'0@/2`D<&%R<V5R+3YP
M87)S92@D9&%T82D[#0H@("`@("`@("`@("!I9B`H)')E<W5L="`A/3T@=')U
M92D@>PT*("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT+3YG971#;V1E*"D@
M/3T@,2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP
M=7-H*%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?6$U,7T585"P@)V5R<F]R
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=E<G)O<B<@/3X@
M)&5R<F]R*2D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A014%27T-(04Y.14Q&
M24Q%7T524D]27T-!3E1?34%+15]005)315(L("=E<G)O<B<I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O
M(#T@)'!A<G-E<BT^9V5T1&%T82@I.PT*("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?5D524TE/3BP@
M)V5R<F]R)RP@87)R87DH)WAM;"<@/3X@)&1A=&$I*3L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"B`@("`-"B`@("`O
M*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@=&]!<G)A>2@I#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?:7-6
M86QI9"`F)B`A)'1H:7,M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M
M/E]C:&%N;F5L26YF;SL-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J($!R971U<FX@
M4$5!4E]#:&%N;F5L1FEL97QF86QS92!F86QS92!I9B!I;G9A;&ED#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@)F9R;VU!<G)A>2@D9&%T82P@)&-O;7!A=&EB
M:6QI='D@/2!F86QS92P@)'-T86-K0VQA<W,@/2`G4$5!4E]%<G)O<E-T86-K
M)RD-"B`@("![#0H@("`@("`@("1A(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4H
M)&-O;7!A=&EB:6QI='DL("1S=&%C:T-L87-S*3L-"B`@("`@("`@)&$M/E]F
M<F]M07)R87DH)&1A=&$I.PT*("`@("`@("!I9B`H(21A+3YV86QI9&%T92@I
M*2![#0H@("`@("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@<F5T
M=7)N("1A.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!5;FQI:V4@>T!L:6YK(&9R;VU!<G)A>2@I
M?2!T:&ES(&1O97,@;F]T(&1O(&%N>2!V86QI9&%T:6]N#0H@("`@("H@0'!A
M<F%M(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J($!R971U<FX@4$5!
M4E]#:&%N;F5L1FEL90T*("`@("`J+PT*("`@(&9U;F-T:6]N("9F<F]M07)R
M87E7:71H17)R;W)S*"1D871A+"`D8V]M<&%T:6)I;&ET>2`](&9A;'-E+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%C:T-L87-S
M(#T@)U!%05)?17)R;W)3=&%C:R<I#0H@("`@>PT*("`@("`@("`D82`](&YE
M=R!014%27T-H86YN96Q&:6QE*"1C;VUP871I8FEL:71Y+"`D<W1A8VM#;&%S
M<RD[#0H@("`@("`@("1A+3Y?9G)O;4%R<F%Y*"1D871A*3L-"B`@("`@("`@
M<F5T=7)N("1A.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?9G)O;4%R<F%Y*"1D871A*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]C:&%N;F5L26YF;R`]("1D871A.PT*("`@('T-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!7<F%P<&5R('1O('M`;&EN:R!014%27T5R<F]R4W1A
M8VLZ.F=E=$5R<F]R<R@I?0T*("`@("`J($!P87)A;2!B;V]L96%N(&1E=&5R
M;6EN97,@=VAE=&AE<B!T;R!P=7)G92!T:&4@97)R;W(@<W1A8VL@869T97(@
M<F5T<FEE=FEN9PT*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!G971%<G)O<G,H)'!U<F=E(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)'1H:7,M/E]S=&%C:RT^9V5T17)R;W)S*"1P=7)G
M92D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@56YI;F1E;G0@9VEV96X@
M<W1R:6YG("@_*0T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R
M(%1H92!S=')I;F<@=&AA="!H87,@=&\@8F4@=6YI;F1E;G1E9"X-"B`@("`@
M*B!`<F5T=7)N('-T<FEN9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]U;DEN9&5N="@D<W1R*0T*("`@('L-"B`@
M("`@("`@+R\@<F5M;W9E(&QE861I;F<@;F5W;&EN97,-"B`@("`@("`@)'-T
M<B`]('!R96=?<F5P;&%C92@G+UY;7')<;ETK+R<L("<G+"`D<W1R*3L-"B`@
M("`@("`@+R\@9FEN9"!W:&ET97-P86-E(&%T('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I<G-T(&QI;F4-"B`@("`@("`@)&EN9&5N=%]L96X@/2!S=')S<&XH
M)'-T<BP@(B!<="(I.PT*("`@("`@("`D:6YD96YT(#T@<W5B<W1R*"1S='(L
M(#`L("1I;F1E;G1?;&5N*3L-"B`@("`@("`@)&1A=&$@/2`G)SL-"B`@("`@
M("`@+R\@<F5M;W9E('1H92!S86UE(&%M;W5N="!O9B!W:&ET97-P86-E(&9R
M;VT@9F]L;&]W:6YG(&QI;F5S#0H@("`@("`@(&9O<F5A8V@@*&5X<&QO9&4H
M(EQN(BP@)'-T<BD@87,@)&QI;F4I('L-"B`@("`@("`@("`@(&EF("AS=6)S
M='(H)&QI;F4L(#`L("1I;F1E;G1?;&5N*2`]/2`D:6YD96YT*2![#0H@("`@
M("`@("`@("`@("`@)&1A=&$@+CT@<W5B<W1R*"1L:6YE+"`D:6YD96YT7VQE
M;BD@+B`B7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D9&%T83L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!087)S
M92!A(&-H86YN96PN>&UL(&9I;&4N("!%>'!E8W1S('1H92!N86UE(&]F#0H@
M("`@("H@82!C:&%N;F5L('AM;"!F:6QE(&%S(&EN<'5T+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&1E<V-F:6QE("!N86UE(&]F(&-H86YN
M96P@>&UL(&9I;&4-"B`@("`@*B!`<F5T=7)N(&)O;VP@<W5C8V5S<R!O9B!P
M87)S:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9G)O;5AM;$9I;&4H)&1E
M<V-F:6QE*0T*("`@('L-"B`@("`@("`@:68@*"%`:7-?9FEL92@D9&5S8V9I
M;&4I('Q\("%I<U]R96%D86)L92@D9&5S8V9I;&4I('Q\#0H@("`@("`@("`@
M("`@*"$D9G`@/2!`9F]P96XH)&1E<V-F:6QE+"`G<B<I*2D@>PT*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0H@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B56YA8FQE('1O(&]P96X@)&1E<V-F
M:6QE(BD[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!R96%D('1H92!W:&]L
M92!T:&EN9R!S;R!W92!O;FQY(&=E="!O;F4@8V1A=&$@8V%L;&)A8VL-"B`@
M("`@("`@+R\@9F]R(&5A8V@@8FQO8VL@;V8@8V1A=&$-"B`@("`@("`@:68@
M*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@
M("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`D9&%T82`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1D97-C9FEL92D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@9FEL97-I>F4H)&1E
M<V-F:6QE*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)'1H:7,M/F9R;VU8;6Q3=')I;F<H)&1A=&$I
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%!A<G-E(&-H86YN96P@:6YF
M;W)M871I;VX@9G)O;2!D:69F97)E;G0@<V]U<F-E<PT*("`@("`J#0H@("`@
M("H@5&AI<R!M971H;V0@:7,@86)L92!T;R!E>'1R86-T(&EN9F]R;6%T:6]N
M(&%B;W5T(&$@8VAA;FYE;`T*("`@("`J(&9R;VT@86X@+GAM;"!F:6QE(&]R
M(&$@<W1R:6YG#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J($!P87)A;2`@<W1R:6YG($9I;&5N86UE(&]F('1H92!S;W5R8V4@;W(@
M=&AE('-O=7)C92!I='-E;&8-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!F<F]M06YY*"1I;F9O*0T*("`@('L-"B`@("`@
M("`@:68@*&ES7W-T<FEN9R@D:6YF;RD@)B8@9FEL95]E>&ES=',H)&EN9F\I
M("8F('-T<FQE;B@D:6YF;RD@/"`R-34I('L-"B`@("`@("`@("`@("1T;7`@
M/2!S=6)S='(H)&EN9F\L("TT*3L-"B`@("`@("`@("`@(&EF("@D=&UP(#T]
M("<N>&UL)RD@>PT*("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/F9R
M;VU8;6Q&:6QE*"1I;F9O*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)&9P(#T@9F]P96XH)&EN9F\L(")R(BD[#0H@("`@("`@
M("`@("`@("`@)'1E<W0@/2!F<F5A9"@D9G`L(#4I.PT*("`@("`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@("`@(&EF("@D=&5S="`]
M/2`B/#]X;6PB*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H
M:7,M/F9R;VU8;6Q&:6QE*"1I;F9O*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M:6YF;RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@D:6YF;RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES7W-T<FEN9R@D:6YF;RDI('L-"B`@("`@("`@("`@("1I;F9O(#T@
M)'1H:7,M/F9R;VU8;6Q3=')I;F<H)&EN9F\I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D:6YF;SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2
M971U<FX@86X@6$U,(&1O8W5M96YT(&)A<V5D(&]N('!R979I;W5S('!A<G-I
M;F<@86YD(&UO9&EF:6-A=&EO;G,-"B`@("`@*@T*("`@("`J($!R971U<FX@
M<W1R:6YG(%A-3"!D871A#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('1O6&UL*"D-"B`@("![#0H@("`@
M("`@(&EF("@A)'1H:7,M/E]I<U9A;&ED("8F("$D=&AI<RT^=F%L:61A=&4H
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?
M0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1"D[#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V-H86YN96Q);F9O6R=A='1R:6)S)UU;)W9E<G-I;VXG72DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)V%T=')I8G,G75LG=F5R
M<VEO;B==(#T@)S$N,"<[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN96Q)
M;F9O(#T@)'1H:7,M/E]C:&%N;F5L26YF;SL-"B`@("`@("`@)')E="`]("(\
M/WAM;"!V97)S:6]N/5PB,2XP7"(@96YC;V1I;F<]7"))4T\M.#@U.2TQ7"(@
M/SY<;B([#0H@("`@("`@("1R970@+CT@(CQC:&%N;F5L('9E<G-I;VX]7"(B
M("X-"B`@("`@("`@("`@("1C:&%N;F5L26YF;ULG871T<FEB<R==6R=V97)S
M:6]N)UT@+B`B7"(@>&UL;G,]7")H='1P.B\O<&5A<BYP:'`N;F5T+V-H86YN
M96PM,2XP7"(-"B`@>&UL;G,Z>'-I/5PB:'1T<#HO+W=W=RYW,RYO<F<O,C`P
M,2]834Q38VAE;6$M:6YS=&%N8V5<(@T*("!X<VDZ<V-H96UA3&]C871I;VX]
M7")H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]C:&%N;F5L+2(-"B`@("`@("`@
M("`@("X@)&-H86YN96Q);F9O6R=A='1R:6)S)UU;)W9E<G-I;VXG72`N("(@
M:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O8VAA;FYE;"TB("X-"B`@("`@("`@
M("`@("1C:&%N;F5L26YF;ULG871T<FEB<R==6R=V97)S:6]N)UT@+B`B+GAS
M9%PB/@T*(#QN86UE/B1C:&%N;F5L26YF;UMN86UE73PO;F%M93X-"B`\<W5M
M;6%R>3XB("X@:'1M;'-P96-I86QC:&%R<R@D8VAA;FYE;$EN9F];)W-U;6UA
M<GDG72DN(CPO<W5M;6%R>3X-"B([#0H@("`@("`@(&EF("AI<W-E="@D8VAA
M;FYE;$EN9F];)W-U9V=E<W1E9&%L:6%S)UTI*2![#0H@("`@("`@("`@("`D
M<F5T("X]("<@/'-U9V=E<W1E9&%L:6%S/B<@+B`D8VAA;FYE;$EN9F];)W-U
M9V=E<W1E9&%L:6%S)UT@+B`B/"]S=6=G97-T961A;&EA<SY<;B([#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1C:&%N;F5L26YF;ULG=F%L:61A
M=&5P86-K86=E)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<@/'9A;&ED
M871E<&%C:V%G92!V97)S:6]N/2(G("X-"B`@("`@("`@("`@("`@("`D8VAA
M;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==6R=A='1R:6)S)UU;)W9E<G-I
M;VXG72X@)R(^)R`N#0H@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R
M<R@D8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==6R=?8V]N=&5N="==
M*2`N#0H@("`@("`@("`@("`@("`@(CPO=F%L:61A=&5P86-K86=E/EQN(CL-
M"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]("(@/'-E<G9E<G,^7&XB.PT*
M("`@("`@("`D<F5T("X]("<@(#QP<FEM87)Y)SL-"B`@("`@("`@:68@*&ES
M<V5T*"1C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I
M8G,G75LG<W-L)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<@<W-L/2(G
M("X@)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB
M<R==6R=S<VPG72`N("<B)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB
M<R==6R=P;W)T)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<@<&]R=#TB
M)R`N("1C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I
M8G,G75LG<&]R="==("X@)R(G.PT*("`@("`@("!]#0H@("`@("`@("1R970@
M+CT@(CY<;B([#0H@("`@("`@(&EF("AI<W-E="@D8VAA;FYE;$EN9F];)W-E
M<G9E<G,G75LG<')I;6%R>2==6R=X;6QR<&,G72DI('L-"B`@("`@("`@("`@
M("1R970@+CT@)'1H:7,M/E]M86ME6&UL<G!C6&UL*"1C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=P<FEM87)Y)UU;)WAM;')P8R==+"`G("`@)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1C:&%N;F5L26YF;ULG<V5R=F5R
M<R==6R=P<FEM87)Y)UU;)W)E<W0G72DI('L-"B`@("`@("`@("`@("1R970@
M+CT@)'1H:7,M/E]M86ME4F5S=%AM;"@D8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG<')I;6%R>2==6R=R97-T)UTL("<@("`G*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA
M<GDG75LG<V]A<"==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`D=&AI<RT^
M7VUA:V53;V%P6&UL*"1C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y
M)UU;)W-O87`G72P@)R`@("<I.PT*("`@("`@("!]#0H@("`@("`@("1R970@
M+CT@(B`@/"]P<FEM87)Y/EQN(CL-"B`@("`@("`@:68@*&ES<V5T*"1C:&%N
M;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72DI('L-"B`@("`@("`@("`@
M("1R970@+CT@)'1H:7,M/E]M86ME36ER<F]R<UAM;"@D8VAA;FYE;$EN9F\I
M.PT*("`@("`@("!]#0H@("`@("`@("1R970@+CT@(B`\+W-E<G9E<G,^7&XB
M.PT*("`@("`@("`D<F5T("X]("(\+V-H86YN96P^(CL-"B`@("`@("`@<F5T
M=7)N('-T<E]R97!L86-E*")<<B(L(")<;B(L('-T<E]R97!L86-E*")<<EQN
M(BP@(EQN(BP@)')E="DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E
M;F5R871E('1H92`\>&UL<G!C/B!T86<-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;6%K95AM;')P8UAM;"@D:6YF
M;RP@)&EN9&5N="D-"B`@("![#0H@("`@("`@("1R970@/2`D:6YD96YT("X@
M(CQX;6QR<&,B.PT*("`@("`@("!I9B`H:7-S970H)&EN9F];)V%T=')I8G,G
M75LG<&%T:"==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`G('!A=&@](B<@
M+B!H=&UL<W!E8VEA;&-H87)S*"1I;F9O6R=A='1R:6)S)UU;)W!A=&@G72D@
M+B`G(B<[#0H@("`@("`@('T-"B`@("`@("`@)')E="`N/2`B/EQN(CL-"B`@
M("`@("`@)')E="`N/2`D=&AI<RT^7VUA:V5&=6YC=&EO;G-8;6PH)&EN9F];
M)V9U;F-T:6]N)UTL("(D:6YD96YT("(I.PT*("`@("`@("`D<F5T("X]("1I
M;F1E;G0@+B`B/"]X;6QR<&,^7&XB.PT*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'96YE<F%T92!T:&4@/'-O87`^
M('1A9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]M86ME4V]A<%AM;"@D:6YF;RP@)&EN9&5N="D-"B`@("![#0H@
M("`@("`@("1R970@/2`D:6YD96YT("X@(CQS;V%P(CL-"B`@("`@("`@:68@
M*&ES<V5T*"1I;F9O6R=A='1R:6)S)UU;)W!A=&@G72DI('L-"B`@("`@("`@
M("`@("1R970@+CT@)R!P871H/2(G("X@:'1M;'-P96-I86QC:&%R<R@D:6YF
M;ULG871T<FEB<R==6R=P871H)UTI("X@)R(G.PT*("`@("`@("!]#0H@("`@
M("`@("1R970@+CT@(CY<;B([#0H@("`@("`@("1R970@+CT@)'1H:7,M/E]M
M86ME1G5N8W1I;VYS6&UL*"1I;F9O6R=F=6YC=&EO;B==+"`B)&EN9&5N="`B
M*3L-"B`@("`@("`@)')E="`N/2`D:6YD96YT("X@(CPO<V]A<#Y<;B([#0H@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($=E;F5R871E('1H92`\<F5S=#X@=&%G#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VUA:V5297-T6&UL*"1I;F9O
M+"`D:6YD96YT*0T*("`@('L-"B`@("`@("`@)')E="`]("1I;F1E;G0@+B`B
M/')E<W0^7&XB.PT*("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=B87-E=7)L
M)UU;,%TI*2![#0H@("`@("`@("`@("`D:6YF;ULG8F%S975R;"==(#T@87)R
M87DH)&EN9F];)V)A<V5U<FPG72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)&EN9F];)V)A<V5U<FPG72!A<R`D=7)L*2![#0H@("`@("`@("`@
M("`D<F5T("X]("(D:6YD96YT(#QB87-E=7)L('1Y<&4]7"(B("X@)'5R;%LG
M871T<FEB<R==6R=T>7!E)UT@+B`B7"(B.PT*("`@("`@("`@("`@)')E="`N
M/2`B/B(@+B`D=7)L6R=?8V]N=&5N="==("X@(CPO8F%S975R;#Y<;B([#0H@
M("`@("`@('T-"B`@("`@("`@)')E="`N/2`D:6YD96YT("X@(CPO<F5S=#Y<
M;B([#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($=E;F5R871E('1H92`\;6ER<F]R<SX@=&%G#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VUA:V5-:7)R
M;W)S6&UL*"1C:&%N;F5L26YF;RD-"B`@("![#0H@("`@("`@("1R970@/2`B
M(CL-"B`@("`@("`@:68@*"%I<W-E="@D8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG;6ER<F]R)UU;,%TI*2![#0H@("`@("`@("`@("`D8VAA;FYE;$EN9F];
M)W-E<G9E<G,G75LG;6ER<F]R)UT@/2!A<G)A>2@D8VAA;FYE;$EN9F];)W-E
M<G9E<G,G75LG;6ER<F]R)UTI.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A
M8V@@*"1C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72!A<R`D;6ER
M<F]R*2![#0H@("`@("`@("`@("`D<F5T("X]("<@(#QM:7)R;W(@:&]S=#TB
M)R`N("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==("X@)R(G.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1M:7)R;W);)V%T=')I8G,G75LG<&]R="==*2D@
M>PT*("`@("`@("`@("`@("`@("1R970@+CT@)R!P;W)T/2(G("X@)&UI<G)O
M<ELG871T<FEB<R==6R=P;W)T)UT@+B`G(B<[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&UI<G)O<ELG871T<FEB<R==6R=S<VPG
M72DI('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("<@<W-L/2(G("X@)&UI
M<G)O<ELG871T<FEB<R==6R=S<VPG72`N("<B)SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1R970@+CT@(CY<;B([#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&UI<G)O<ELG>&UL<G!C)UTI('Q\(&ES<V5T*"1M:7)R;W);)W-O
M87`G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&UI<G)O<ELG
M>&UL<G!C)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@)'1H
M:7,M/E]M86ME6&UL<G!C6&UL*"1M:7)R;W);)WAM;')P8R==+"`G("`@)RD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;6ER<F]R6R=R97-T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R
M970@+CT@)'1H:7,M/E]M86ME4F5S=%AM;"@D;6ER<F]R6R=R97-T)UTL("<@
M("`G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1M:7)R;W);)W-O87`G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)')E="`N/2`D=&AI<RT^7VUA:V53;V%P6&UL*"1M:7)R;W);)W-O87`G
M72P@)R`@("<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D<F5T("X]("(@(#PO;6ER<F]R/EQN(CL-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)')E="`N/2`B+SY<;B([#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@1V5N97)A=&4@=&AE(#QF=6YC=&EO;G,^
M('1A9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]M86ME1G5N8W1I;VYS6&UL*"1F=6YC=&EO;G,L("1I;F1E;G0L
M("1R97-T(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D<F5T(#T@)R<[#0H@
M("`@("`@(&EF("@A:7-S970H)&9U;F-T:6]N<ULP72DI('L-"B`@("`@("`@
M("`@("1F=6YC=&EO;G,@/2!A<G)A>2@D9G5N8W1I;VYS*3L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D9G5N8W1I;VYS(&%S("1F=6YC=&EO;BD@
M>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N=#QF=6YC=&EO;B!V97)S
M:6]N/5PB(B`N("1F=6YC=&EO;ELG871T<FEB<R==6R=V97)S:6]N)UT@+B`B
M7"(B.PT*("`@("`@("`@("`@:68@*"1R97-T*2![#0H@("`@("`@("`@("`@
M("`@)')E="`N/2`G('5R:3TB)R`N("1F=6YC=&EO;ELG871T<FEB<R==6R=U
M<FDG72`N("<B)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@
M+CT@(CXB("X@)&9U;F-T:6]N6R=?8V]N=&5N="==("X@(CPO9G5N8W1I;VX^
M7&XB.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J(%9A;&ED871I;VX@97)R;W(N("!!;'-O(&UA
M<FMS('1H92!O8FIE8W0@8V]N=&5N=',@87,@:6YV86QI9`T*("`@("`J($!P
M87)A;2!E<G)O<B!C;V1E#0H@("`@("H@0'!A<F%M(&%R<F%Y(&5R<F]R(&EN
M9F]R;6%T:6]N#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7W9A;&ED871E17)R;W(H)&-O9&4L("1P87)A;7,@/2!A
M<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"@D
M8V]D92P@)V5R<F]R)RP@)'!A<F%M<RD[#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%9A;&ED
M871I;VX@=V%R;FEN9RX@($1O97,@;F]T(&UA<FL@=&AE(&]B:F5C="!C;VYT
M96YT<R!I;G9A;&ED+@T*("`@("`J($!P87)A;2!E<G)O<B!C;V1E#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&5R<F]R(&EN9F]R;6%T:6]N#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W9A;&ED871E
M5V%R;FEN9R@D8V]D92P@)'!A<F%M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*"1C;V1E+"`G=V%R;FEN9R<L("1P
M87)A;7,I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%9A;&ED871E('!A
M<G-E9"!F:6QE+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V
M86QI9&%T92@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!T
M<G5E.PT*("`@("`@("`D:6YF;R`]("1T:&ES+3Y?8VAA;FYE;$EN9F\[#0H@
M("`@("`@(&EF("AE;7!T>2@D:6YF;ULG;F%M92==*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?3D]?3D%-12D[#0H@("`@("`@('T@96QS96EF("@A)'1H:7,M/G9A;&ED
M0VAA;FYE;%-E<G9E<B@D:6YF;ULG;F%M92==*2D@>PT*("`@("`@("`@("`@
M:68@*"1I;F9O6R=N86UE)UT@(3T@)U]?=7)I)RD@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T52
M4D]27TE.5D%,241?3D%-12P@87)R87DH)W1A9R<@/3X@)VYA;64G+`T*("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&EN9F];)VYA;64G72DI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D
M:6YF;ULG<W5M;6%R>2==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4U5-34%262D[
M#0H@("`@("`@('T@96QS96EF("AS=')P;W,H=')I;2@D:6YF;ULG<W5M;6%R
M>2==*2P@(EQN(BD@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E5V%R;FEN9RA014%27T-(04Y.14Q&24Q%7T524D]27TU53%1)
M3$E.15]354U-05)9+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=S=6UM87)Y
M)R`]/B`D:6YF;ULG<W5M;6%R>2==*2D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1I;F9O6R=S=6=G97-T961A;&EA<R==*2D@>PT*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^=F%L:61#:&%N;F5L4V5R=F5R*"1I;F9O6R=S
M=6=G97-T961A;&EA<R==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?
M3D%-12P-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)W1A9R<@/3X@)W-U
M9V=E<W1E9&%L:6%S)RP@)VYA;64G(#T^)&EN9F];)W-U9V=E<W1E9&%L:6%S
M)UTI*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)&EN9F];)VQO8V%L86QI87,G72DI('L-"B`@("`@("`@("`@(&EF
M("@A)'1H:7,M/G9A;&ED0VAA;FYE;%-E<G9E<B@D:6YF;ULG;&]C86QA;&EA
M<R==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O
M<BA014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?3D%-12P-"B`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W1A9R<@/3X@)VQO8V%L86QI87,G+"`G
M;F%M92<@/3XD:6YF;ULG;&]C86QA;&EA<R==*2D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=V86QI9&%T
M97!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];
M)W9A;&ED871E<&%C:V%G92==6R=?8V]N=&5N="==*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%
M7T524D]27TY/5D%,241!5$5?3D%-12D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=V86QI9&%T97!A8VMA9V4G75LG
M871T<FEB<R==6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]6
M04Q)1$%415]615)324].+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M<&%C:V%G92<@/3X@0"1I;F9O6R=V86QI9&%T97!A8VMA9V4G75LG7V-O;G1E
M;G0G72DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G
M75LG<&]R="==*2`F)@T*("`@("`@("`@("`@("`A:7-?;G5M97)I8R@D:6YF
M;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG<&]R="==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!
M3DY%3$9)3$5?15)23U)?24Y604Q)1%]03U)4+`T*("`@("`@("`@("`@("`@
M(&%R<F%Y*"=P;W)T)R`]/B`D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;
M)V%T=')I8G,G75LG<&]R="==*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==
M6R=S<VPG72D@)B8-"B`@("`@("`@("`@("`@)&EN9F];)W-E<G9E<G,G75LG
M<')I;6%R>2==6R=A='1R:6)S)UU;)W-S;"==("$]("=Y97,G*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E])3E9!3$E$7U-33"P-"B`@("`@("`@("`@("`@("!A<G)A>2@G
M<W-L)R`]/B`D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G
M75LG<W-L)UTL#0H@("`@("`@("`@("`@("`@("`@("=S97)V97(G(#T^("1I
M;F9O6R=N86UE)UTI*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("AI<W-E
M="@D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)WAM;')P8R==*2`F)@T*
M("`@("`@("`@("`@("!I<W-E="@D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y
M)UU;)WAM;')P8R==6R=F=6YC=&EO;B==*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]V86QI9&%T949U;F-T:6]N<R@G>&UL<G!C)RP@)&EN9F];)W-E<G9E
M<G,G75LG<')I;6%R>2==6R=X;6QR<&,G75LG9G5N8W1I;VXG72D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R
M:6UA<GDG75LG<V]A<"==*2`F)@T*("`@("`@("`@("`@("!I<W-E="@D:6YF
M;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)W-O87`G75LG9G5N8W1I;VXG72DI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5&=6YC=&EO;G,H)W-O
M87`G+"`D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)W-O87`G75LG9G5N
M8W1I;VXG72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O
M6R=S97)V97)S)UU;)W!R:6UA<GDG75LG<F5S="==*2`F)@T*("`@("`@("`@
M("`@("!I<W-E="@D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)W)E<W0G
M75LG8F%S975R;"==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M949U;F-T:6]N<R@G<F5S="<L("1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG
M75LG<F5S="==6R=B87-E=7)L)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D:6YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72DI('L-"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UT@/3T@)U]?
M=7)I)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O
M<BA014%27T-(04Y.14Q&24Q%7U5225]#04Y47TU)4E)/4BD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=S97)V97)S
M)UU;)VUI<G)O<B==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=S
M97)V97)S)UU;)VUI<G)O<B==(#T@87)R87DH)&EN9F];)W-E<G9E<G,G75LG
M;6ER<F]R)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&D@/2`P
M.PT*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];)W-E<G9E<G,G75LG;6ER
M<F]R)UT@87,@)&UI<G)O<BD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&
M24Q%7T524D]27TY/7TA/4U0L#0H@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)W1Y<&4G(#T^("=M:7)R;W(G*2D[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"$D=&AI<RT^=F%L:61#:&%N;F5L4V5R=F5R*"1M:7)R;W);)V%T
M=')I8G,G75LG:&]S="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!
M3$E$7TA/4U0L#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<V5R
M=F5R)R`]/B`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72P@)W1Y<&4G(#T^
M("=M:7)R;W(G*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D;6ER<F]R6R=A='1R:6)S)UU;)W-S;"==*2`F)B`D
M;6ER<F]R6R=A='1R:6)S)UU;)W-S;"==("$]("=Y97,G*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.
M14Q&24Q%7T524D]27TE.5D%,241?4U-,+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W-S;"<@/3X@)&EN9F];)W-S;"==+"`G<V5R=F5R)R`]
M/B`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72DI.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&UI<G)O<ELG>&UL
M<G!C)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A
M=&5&=6YC=&EO;G,H)WAM;')P8R<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D;6ER<F]R6R=X;6QR<&,G75LG9G5N8W1I;VXG72P@)&UI<G)O<ELG871T
M<FEB<R==6R=H;W-T)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&UI<G)O<ELG<V]A<"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1G5N8W1I;VYS*"=S;V%P
M)RP@)&UI<G)O<ELG<V]A<"==6R=F=6YC=&EO;B==+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&UI
M<G)O<ELG<F5S="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E1G5N8W1I;VYS*"=R97-T)RP@)&UI<G)O<ELG<F5S="==6R=B
M87-E=7)L)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`D;6ER<F]R6R=A
M='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7VES
M5F%L:60[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!X;6QR<&,@;W(@<V]A<"`M('!R;W1O8V]L(&YA;64@=&AI<R!F=6YC=&EO
M;B!A<'!L:65S('1O#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H92!F=6YC=&EO
M;G,-"B`@("`@*B!`<&%R86T@<W1R:6YG('1H92!N86UE(&]F('1H92!P87)E
M;G0@96QE;65N="`H;6ER<F]R(&YA;64L(&9O<B!I;G-T86YC92D-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5&=6YC=&EO;G,H)'!R;W1O8V]L
M+"`D9G5N8W1I;VYS+"`D<&%R96YT(#T@)R<I#0H@("`@>PT*("`@("`@("!I
M9B`H(6ES<V5T*"1F=6YC=&EO;G-;,%TI*2![#0H@("`@("`@("`@("`D9G5N
M8W1I;VYS(#T@87)R87DH)&9U;F-T:6]N<RD[#0H@("`@("`@('T-"B`@("`@
M("`@9F]R96%C:"`H)&9U;F-T:6]N<R!A<R`D9G5N8W1I;VXI('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&9U;F-T:6]N6R=?8V]N=&5N="==*2!\?"!E
M;7!T>2@D9G5N8W1I;VY;)U]C;VYT96YT)UTI*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?3D]?1E5.0U1)3TY.04U%+`T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G<&%R96YT)R`]/B`D<&%R96YT+"`G<')O=&]C;VPG(#T^("1P<F]T;V-O
M;"DI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1P<F]T;V-O
M;"`]/2`G<F5S="<I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F
M=6YC=&EO;ELG871T<FEB<R==6R=T>7!E)UTI('Q\#0H@("`@("`@("`@("`@
M("`@("`@("`@96UP='DH)&9U;F-T:6]N6R=A='1R:6)S)UU;)W1Y<&4G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R
M*%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?0D%315523%194$4L#0H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%R96YT)R`]/B`D<&%R96YT
M+"`G<')O=&]C;VPG(#T^("1P<F]T;V-O;"DI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D9G5N8W1I;VY;)V%T=')I8G,G75LG=F5R<VEO;B==*2!\?`T*
M("`@("`@("`@("`@("`@("`@("`@(&5M<'1Y*"1F=6YC=&EO;ELG871T<FEB
M<R==6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TY/7T95
M3D-424].5D524TE/3BP-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=P87)E;G0G(#T^("1P87)E;G0L("=P<F]T;V-O;"<@/3X@)'!R;W1O8V]L
M*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&5S="!W:&5T:&5R(&$@
M<W1R:6YG(&-O;G1A:6YS(&$@=F%L:60@8VAA;FYE;"!S97)V97(N#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F5R('1H92!P86-K86=E('9E<G-I;VX@=&\@
M=&5S=`T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('9A;&ED0VAA;FYE;%-E<G9E<B@D<V5R=F5R*0T*("`@('L-"B`@("`@
M("`@:68@*"1S97)V97(@/3T@)U]?=7)I)RD@>PT*("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("AB;V]L*2!P
M<F5G7VUA=&-H*%!%05)?0TA!3DY%3%-?4T525D527U!214<L("1S97)V97(I
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@<W1R:6YG?&9A
M;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T3F%M92@I#0H@("`@>PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG;F%M92==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE;$EN9F];
M)VYA;64G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T4V5R=F5R*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V-H86YN96Q);F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG;F%M92==.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!I;G1\.#`@<&]R="!N=6UB
M97(@=&\@8V]N;F5C="!T;PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%!O
M<G0H)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1M:7)R
M;W(I('L-"B`@("`@("`@("`@(&EF("@D;6ER(#T@)'1H:7,M/F=E=$UI<G)O
M<B@D;6ER<F]R*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;6ER
M6R=A='1R:6)S)UU;)W!O<G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1M:7);)V%T=')I8G,G75LG<&]R="==.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M9V5T4U-,*"1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@-#0S.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`X,#L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E
M<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W!O<G0G72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S
M)UU;)W!R:6UA<GDG75LG871T<FEB<R==6R=P;W)T)UT[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1T:&ES+3YG97134TPH*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(#0T,SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@.#`[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!B;V]L($1E=&5R;6EN
M97,@=VAE=&AE<B!S96-U<F4@<V]C:V5T<R!L87EE<B`H4U-,*2!I<R!U<V5D
M('1O(&-O;FYE8W0@=&\@=&AI<R!C:&%N;F5L#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T4U-,*"1M:7)R;W(@/2!F86QS92D-"B`@("![#0H@("`@("`@
M(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H)&UI<B`]("1T:&ES
M+3YG971-:7)R;W(H)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&UI<ELG871T<FEB<R==6R=S<VPG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G
M75LG<W-L)UTI*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G9713=6UM87)Y*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7V-H86YN96Q);F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]C:&%N;F5L26YF;ULG<W5M;6%R>2==.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!X;6QR<&,@;W(@<V]A<`T*("`@("`J($!P87)A;2!S=')I;F=\9F%L
M<V4@;6ER<F]R(&YA;64@;W(@9F%L<V4@9F]R('!R:6UA<GD@<V5R=F5R#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4&%T:"@D<')O=&]C;VPL("1M:7)R
M;W(@/2!F86QS92D-"B`@("![("`@#0H@("`@("`@(&EF("@A:6Y?87)R87DH
M)'!R;W1O8V]L+"!A<G)A>2@G>&UL<G!C)RP@)W-O87`G*2DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"$H)&UI<B`]("1T:&ES+3YG
M971-:7)R;W(H)&UI<G)O<BDI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1M:7);)'!R;W1O8V]L75LG871T<FEB<R==6R=P871H)UTI*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1M:7);)'!R;W1O8V]L75LG871T<FEB<R==
M6R=P871H)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D<')O=&]C;VP@+B`G+G!H<"<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O
M6R=S97)V97)S)UU;)W!R:6UA<GDG75LD<')O=&]C;VQ=6R=A='1R:6)S)UU;
M)W!A=&@G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN
M96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD<')O=&]C;VQ=6R=A='1R
M:6)S)UU;)W!A=&@G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'!R
M;W1O8V]L("X@)RYP:'`G.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F<@<')O=&]C;VP@='EP92`H>&UL<G!C+"!S;V%P*0T*("`@
M("`J($!P87)A;2!S=')I;F<@36ER<F]R(&YA;64-"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1G5N8W1I
M;VYS*"1P<F]T;V-O;"P@)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@:68@*"1T:&ES+3YG971.86UE*"D@/3T@)U]?=7)I)RD@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<')O=&]C;VP@/3T@)W)E<W0G*2![#0H@("`@("`@("`@("`D9G5N8W1I;VX@
M/2`G8F%S975R;"<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M9G5N8W1I;VX@/2`G9G5N8W1I;VXG.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H)&UI<B`]("1T:&ES+3YG
M971-:7)R;W(H)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&UI<ELD<')O=&]C;VQ=6R1F=6YC=&EO;ETI*2![#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D;6ER6R1P<F]T;V-O;%U;)&9U;F-T:6]N73L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1P
M<F]T;V-O;%U;)&9U;F-T:6]N72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD<')O
M=&]C;VQ=6R1F=6YC=&EO;ET[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(%!R;W1O8V]L('1Y<&4-"B`@("`@
M*B!`<&%R86T@<W1R:6YG($9U;F-T:6]N(&YA;64@*&YU;&P@=&\@<F5T=7)N
M('1H90T*("`@("`J("`@("`@("`@("`@("`@9FER<W0@<')O=&]C;VP@;V8@
M=&AE('1Y<&4@<F5Q=65S=&5D*0T*("`@("`J($!P87)A;2!S=')I;F<@36ER
M<F]R(&YA;64L(&EF(&%N>0T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@
M*B\-"B`@("`@9G5N8W1I;VX@9V5T1G5N8W1I;VXH)'1Y<&4L("1N86UE(#T@
M;G5L;"P@)&UI<G)O<B`](&9A;'-E*0T*("`@("![#0H@("`@("`@("1P<F]T
M;V-O;',@/2`D=&AI<RT^9V5T1G5N8W1I;VYS*"1T>7!E+"`D;6ER<F]R*3L-
M"B`@("`@("`@:68@*"$D<')O=&]C;VQS*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'!R;W1O
M8V]L<R!A<R`D<')O=&]C;VPI('L-"B`@("`@("`@("`@(&EF("@D;F%M92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<')O=&]C;VP[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'!R;W1O8V]L6R=?
M8V]N=&5N="==("$]("1N86UE*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'!R;W1O
M8V]L.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O;"!T
M>7!E#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O;"!N86UE#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!M:7)R;W(@;F%M90T*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N('-U<'!O<G1S*"1T>7!E+"`D;F%M92`](&YU;&PL
M("1M:7)R;W(@/2!F86QS92P@)'9E<G-I;VX@/2`G,2XP)RD-"B`@("![#0H@
M("`@("`@("1P<F]T;V-O;',@/2`D=&AI<RT^9V5T1G5N8W1I;VYS*"1T>7!E
M+"`D;6ER<F]R*3L-"B`@("`@("`@:68@*"$D<')O=&]C;VQS*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)'!R;W1O8V]L<R!A<R`D<')O=&]C;VPI('L-"B`@("`@("`@("`@
M(&EF("@D<')O=&]C;VQ;)V%T=')I8G,G75LG=F5R<VEO;B==("$]("1V97)S
M:6]N*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H)&YA;64@/3T](&YU;&PI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D<')O=&]C;VQ;)U]C;VYT96YT)UT@(3T@)&YA;64I('L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI
M;F5S('=H971H97(@82!C:&%N;F5L('-U<'!O<G1S(%)E<')E<V5N=&%T:6]N
M86P@4W1A=&4@5')A;G-F97(@*%)%4U0I('!R;W1O8V]L<PT*("`@("`J(&9O
M<B!R971R:65V:6YG(&-H86YN96P@:6YF;W)M871I;VX-"B`@("`@*B!`<&%R
M86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<W5P<&]R='-215-4*"1M:7)R;W(@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@D;6ER<F]R(#T]("1T:&ES+3Y?8VAA;FYE;$EN9F];
M)VYA;64G72D@>PT*("`@("`@("`@("`@)&UI<G)O<B`](&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I
M9B`H)&UI<B`]("1T:&ES+3YG971-:7)R;W(H)&UI<G)O<BDI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@:7-S970H)&UI<ELG<F5S="==*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=P<FEM87)Y)UU;)W)E<W0G72D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5T('1H92!54DP@=&\@86-C97-S(&$@8F%S92!R97-O
M=7)C92X-"B`@("`@*@T*("`@("`J($AY<&5R;&EN:W,@:6X@=&AE(')E='5R
M;F5D('AM;"!W:6QL(&)E('5S960@=&\@<F5T<FEE=F4@=&AE('!R;W!E<B!I
M;F9O<FUA=&EO;@T*("`@("`J(&YE961E9"X@(%1H:7,@86QL;W=S(&5X=')E
M;64@97AT96YS:6)I;&ET>2!A;F0@9FQE>&EB:6QI='D@:6X@:6UP;&5M96YT
M871I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(%)E<V]U<F-E(%1Y<&4@=&\@
M<F5T<FEE=F4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971"87-E55),*"1R
M97-O=7)C951Y<&4L("1M:7)R;W(@/2!F86QS92D-"B`@("![#0H@("`@("`@
M(&EF("@D;6ER<F]R(#T]("1T:&ES+3Y?8VAA;FYE;$EN9F];)VYA;64G72D@
M>PT*("`@("`@("`@("`@)&UI<G)O<B`](&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H)&UI<B`]
M("1T:&ES+3YG971-:7)R;W(H)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@
M("`D<F5S="`]("1M:7);)W)E<W0G73L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)'-E<G9E<B`]("1M:7)R;W([#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D<F5S="`]("1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=R97-T)UT[#0H@("`@("`@("`@
M("`D<V5R=F5R(#T@)'1H:7,M/F=E=%-E<G9E<B@I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:7-S970H)')E<W1;)V)A<V5U<FPG75LP72DI('L-"B`@
M("`@("`@("`@("1R97-T6R=B87-E=7)L)UT@/2!A<G)A>2@D<F5S=%LG8F%S
M975R;"==*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D<F5S=%LG
M8F%S975R;"==(&%S("1B87-E=7)L*2![#0H@("`@("`@("`@("!I9B`H<W1R
M=&]L;W=E<B@D8F%S975R;%LG871T<FEB<R==6R=T>7!E)UTI(#T]('-T<G1O
M;&]W97(H)')E<V]U<F-E5'EP92DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)&)A<V5U<FQ;)U]C;VYT96YT)UT[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%-I;F-E(%)%4U0@9&]E<R!N;W0@:6UP;&5M96YT(%)00RP@
M<')O=FED92!T:&ES(&%S(&$@;&]G:6-A;"!W<F%P<&5R(&%R;W5N9`T*("`@
M("`J(')E<V5T1G5N8W1I;VYS(&9O<B!215-4#0H@("`@("H@0'!A<F%M('-T
M<FEN9WQF86QS92!M:7)R;W(@;F%M92P@:68@86YY#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<F5S971215-4*"1M:7)R;W(@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^<F5S971&=6YC=&EO;G,H)W)E<W0G+"`D
M;6ER<F]R*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!%;7!T>2!A;&P@
M<')O=&]C;VP@9&5F:6YI=&EO;G,-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R
M;W1O8V]L('1Y<&4@*'AM;')P8RP@<V]A<"D-"B`@("`@*B!`<&%R86T@<W1R
M:6YG?&9A;'-E(&UI<G)O<B!N86UE+"!I9B!A;GD-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!R97-E=$9U;F-T:6]N<R@D='EP92P@)&UI<G)O<B`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==*2D@>PT*("`@("`@("`@("`@("`@("1M:7)R;W)S(#T@)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G73L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1M:7)R;W)S6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D;6ER<F]R<R`](&%R<F%Y*"1M:7)R;W)S*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UI<G)O
M<G,@87,@)&D@/3X@)&UI<BD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&UI<ELG871T<FEB<R==6R=H;W-T)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=6R1T>7!E72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R1I75LD='EP95TI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=P<FEM87)Y)UU;)'1Y<&5=*2D@>PT*("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1T
M>7!E72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E="!A
M(&-H86YN96PG<R!P<F]T;V-O;',@=&\@=&AE('!R;W1O8V]L<R!S=7!P;W)T
M960@8GD@<&5A<G=E8@T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$1E9F%U
M;'1014%24')O=&]C;VQS*"1V97)S:6]N(#T@)S$N,"<L("1M:7)R;W(@/2!F
M86QS92D-"B`@("![#0H@("`@("`@('-W:71C:"`H)'9E<G-I;VXI('L-"B`@
M("`@("`@("`@(&-A<V4@)S$N,"<@.@T*("`@("`@("`@("`@("`@("1T:&ES
M+3YR97-E=$9U;F-T:6]N<R@G>&UL<G!C)RP@)&UI<G)O<BD[#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/G)E<V5T1G5N8W1I;VYS*"=S;V%P)RP@)&UI<G)O
M<BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/G)E<V5T4D535"@D;6ER<F]R
M*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1G5N8W1I;VXH)WAM;')P
M8R<L("<Q+C`G+"`G;&]G:6YT97-T)RP@)&UI<G)O<BD[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@)W!A
M8VMA9V4N;&ES=$QA=&5S=%)E;&5A<V5S)RP@)&UI<G)O<BD[#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@
M)W!A8VMA9V4N;&ES=$%L;"<L("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("=P86-K86=E
M+FEN9F\G+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D
M1G5N8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G<&%C:V%G92YG971$;W=N;&]A
M9%523"<L("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&
M=6YC=&EO;B@G>&UL<G!C)RP@)S$N,2<L("=P86-K86=E+F=E=$1O=VYL;V%D
M55),)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9U
M;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@)W!A8VMA9V4N9V5T1&5P1&]W;FQO
M86154DPG+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D
M1G5N8W1I;VXH)WAM;')P8R<L("<Q+C$G+"`G<&%C:V%G92YG971$97!$;W=N
M;&]A9%523"<L("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA
M9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("=P86-K86=E+G-E87)C:"<L
M("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&=6YC=&EO
M;B@G>&UL<G!C)RP@)S$N,"<L("=C:&%N;F5L+FQI<W1!;&PG+"`D;6ER<F]R
M*3L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@9&5F875L="`Z#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M('T-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!A<G)A
M>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$UI<G)O<G,H*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E
M<G,G75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@("`D;6ER<F]R<R`]("1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT[#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1M:7)R;W)S6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("1M:7)R;W)S(#T@87)R87DH)&UI<G)O<G,I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N("1M:7)R;W)S.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE('5N<V5R:6%L
M:7IE9"!834P@<F5P<F5S96YT:6YG(&$@;6ER<F]R#0H@("`@("H@0')E='5R
M;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$UI<G)O
M<B@D<V5R=F5R*0T*("`@('L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E
M=$UI<G)O<G,H*2!A<R`D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H)&UI
M<G)O<ELG871T<FEB<R==6R=H;W-T)UT@/3T@)'-E<G9E<BD@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D;6ER<F]R.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!S=')I
M;F=\9F%L<V4-"B`@("`@*B!`97)R;W(@4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U].04U%#0H@("`@("H@0&5R<F]R(%!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?24Y604Q)1%].04U%#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T3F%M
M92@D;F%M92D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^<V5T4V5R
M=F5R*"1N86UE*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3970@=&AE
M('-O8VME="!N=6UB97(@*'!O<G0I('1H870@:7,@=7-E9"!T;R!C;VYN96-T
M('1O('1H:7,@8VAA;FYE;`T*("`@("`J($!P87)A;2!I;G1E9V5R#0H@("`@
M("H@0'!A<F%M('-T<FEN9WQF86QS92!N86UE(&]F('1H92!M:7)R;W(@<V5R
M=F5R+"!O<B!F86QS92!F;W(@=&AE('!R:6UA<GD-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S9710;W)T*"1P;W)T+"`D;6ER<F]R(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA0
M14%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<V5T;6ER<F]R(#T@9F%L<V4[#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G75LP72DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==(&%S("1I(#T^
M("1M:7(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1M:7)R;W(@/3T@
M)&UI<ELG871T<FEB<R==6R=H;W-T)UTI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R
M)UU;)&E=6R=A='1R:6)S)UU;)W!O<G0G72`]("1P;W)T.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG:&]S
M="==(#T]("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H
M86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)W!O
M<G0G72`]("1P;W)T.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI
M9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W!O<G0G
M72`]("1P;W)T.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@4V5T('1H92!S;V-K970@;G5M8F5R("AP;W)T*2!T:&%T(&ES('5S960@
M=&\@8V]N;F5C="!T;R!T:&ES(&-H86YN96P-"B`@("`@*B!`<&%R86T@8F]O
M;"!$971E<FUI;F5S('=H971H97(@=&\@='5R;B!O;B!34TP@<W5P<&]R="!O
M<B!T=7)N(&ET(&]F9@T*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@;F%M
M92!O9B!T:&4@;6ER<F]R('-E<G9E<BP@;W(@9F%L<V4@9F]R('1H92!P<FEM
M87)Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4U-,*"1S<VP@/2!T<G5E
M+"`D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)&UI<G)O
M<BD@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]2
M7TU)4E)/4E].3U1?1D]53D0L#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-"B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<V5T;6ER
M<F]R(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LP72DI('L-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V
M97)S)UU;)VUI<G)O<B==(&%S("1I(#T^("1M:7(I('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1M:7)R;W(@/3T@)&UI<ELG871T<FEB<R==6R=H;W-T
M)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A)'-S;"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R1I70T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LG871T<FEB<R==6R=S<VPG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LD:5U;
M)V%T=')I8G,G75LG<W-L)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=M:7)R;W(G75LD:5U;)V%T=')I8G,G75LG<W-L)UT@/2`G
M>65S)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7V-H86YN
M96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)VAO<W0G
M72`]/2`D;6ER<F]R*2![#0H@("`@("`@("`@("`@("`@:68@*"$D<W-L*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN
M96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)W-S;"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=S
M<VPG72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YN
M96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)W-S;"==
M(#T@)WEE<R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@D<W-L*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O
M6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==6R=S<VPG72`]("=Y
M97,G.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A
M='1R:6)S)UU;)W-S;"==*2D@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R
M:6)S)UU;)W-S;"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T('1H92!S;V-K
M970@;G5M8F5R("AP;W)T*2!T:&%T(&ES('5S960@=&\@8V]N;F5C="!T;R!T
M:&ES(&-H86YN96P-"B`@("`@*B!`<&%R86T@:6YT96=E<@T*("`@("`J($!P
M87)A;2!S=')I;F=\9F%L<V4@;F%M92!O9B!T:&4@;6ER<F]R('-E<G9E<BP@
M;W(@9F%L<V4@9F]R('1H92!P<FEM87)Y#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T4&%T:"@D<')O=&]C;VPL("1P871H+"`D;6ER<F]R(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1P<F]T;V-O;"P@87)R
M87DH)WAM;')P8R<L("=S;V%P)RDI*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=M:7)R;W(G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-25)23U)?
M3D]47T9/54Y$+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;6ER<F]R
M)R`]/B`D;6ER<F]R*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'-E=&UI<G)O<B`](&9A
M;'-E.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;,%TI*2![#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G72!A<R`D:2`]/B`D;6ER*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D;6ER<F]R(#T]("1M:7);)V%T=')I8G,G75LG:&]S="==*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=S
M97)V97)S)UU;)VUI<G)O<B==6R1I75LD<')O=&]C;VQ=6R=A='1R:6)S)UU;
M)W!A=&@G72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A=&@[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E]-25)23U)?3D]47T9/54Y$+`T*("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G;6ER<F]R)R`]/B`D;6ER<F]R*2D[#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G
M75LG:&]S="==(#T]("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R1P<F]T;V-O
M;%U;)V%T=')I8G,G75LG<&%T:"==(#T@)'!A=&@[#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;
M)'!R;W1O8V]L75LG871T<FEB<R==6R=P871H)UT@/2`D<&%T:#L-"B`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<-
M"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS90T*("`@("`J($!E<G)O<B!0
M14%27T-(04Y.14Q&24Q%7T524D]27TY/7U-%4E9%4@T*("`@("`J($!E<G)O
M<B!014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?4T525D52#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<V5T4V5R=F5R*"1S97)V97(L("1M:7)R;W(@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D<V5R=F5R*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!
M3DY%3$9)3$5?15)23U)?3D]?4T525D52*3L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?2!E;'-E:68@*"$D=&AI<RT^=F%L:61#:&%N
M;F5L4V5R=F5R*"1S97)V97(I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TY!
M344L#0H@("`@("`@("`@("`@("`@87)R87DH)W1A9R<@/3X@)VYA;64G+"`G
M;F%M92<@/3X@)'-E<G9E<BDI.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@
M("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT@87,@)&D@
M/3X@)&UI<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D;6ER<F]R(#T]("1M
M:7);)V%T=')I8G,G75LG:&]S="==*2![#0H@("`@("`@("`@("`@("`@("`@
M("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@A)&9O=6YD*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?34E24D]27TY/5%]&
M3U5.1"P-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)VUI<G)O<B<@/3X@
M)&UI<G)O<BDI.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];
M)VUI<G)O<B==6R1I75LG871T<FEB<R==6R=H;W-T)UT@/2`D<V5R=F5R.PT*
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG;F%M92==(#T@)'-E<G9E<CL-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@8F]O;&5A;B!S=6-C97-S#0H@
M("`@("H@0&5R<F]R(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4U5-34%2
M60T*("`@("`J($!W87)N:6YG(%!%05)?0TA!3DY%3$9)3$5?15)23U)?355,
M5$E,24Y%7U-534U!4ED-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S9713=6UM
M87)Y*"1S=6UM87)Y*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y*"1S=6UM
M87)Y*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4U5-34%262D[#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T@96QS96EF("AS=')P;W,H=')I
M;2@D<W5M;6%R>2DL(")<;B(I("$]/2!F86QS92D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]V86QI9&%T95=A<FYI;F<H4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E]-54Q424Q)3D5?4U5-34%262P-"B`@("`@("`@("`@("`@("!A<G)A>2@G
M<W5M;6%R>2<@/3X@)'-U;6UA<GDI*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7V-H86YN96Q);F9O6R=S=6UM87)Y)UT@/2`D<W5M;6%R>3L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!B;V]L96%N(&1E=&5R;6EN
M97,@=VAE=&AE<B!T:&4@86QI87,@:7,@:6X@8VAA;FYE;"YX;6P@;W(@;&]C
M86P-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@<W5C8V5S<PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=$%L:6%S*"1A;&EA<RP@)&QO8V%L(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3YV86QI9$-H86YN96Q397)V
M97(H)&%L:6%S*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R
M<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%].04U%+`T*("`@
M("`@("`@("`@("`@(&%R<F%Y*"=T86<G(#T^("=S=6=G97-T961A;&EA<R<L
M("=N86UE)R`]/B`D86QI87,I*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&QO8V%L*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=L;V-A;&%L:6%S)UT@/2`D86QI
M87,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7V-H
M86YN96Q);F9O6R=S=6=G97-T961A;&EA<R==(#T@)&%L:6%S.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T06QI87,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M8VAA;FYE;$EN9F];)VQO8V%L86QI87,G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-H86YN96Q);F9O6R=L;V-A;&%L:6%S)UT[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W-U9V=E<W1E9&%L:6%S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<W5G9V5S=&5D86QI87,G73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG;F%M
M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE;$EN
M9F];)VYA;64G73L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%-E="!T:&4@<&%C:V%G92!V86QI9&%T:6]N(&]B:F5C="!I9B!I="!D
M:69F97)S(&9R;VT@4$5!4B=S(&1E9F%U;'0-"B`@("`@*B!4:&4@8VQA<W,@
M;75S="!B92!I;F-L=61E86)L92!V:6$@8VAA;F=I;F<@7R!I;B!T:&4@8VQA
M<W-N86UE('1O('!A=&@@<V5P87)A=&]R+`T*("`@("`J(&)U="!N;R!C:&5C
M:VEN9R!O9B!T:&ES(&ES(&UA9&4N#0H@("`@("H@0'!A<F%M('-T<FEN9WQF
M86QS92!P87-S(&EN(&9A;'-E('1O(')E<V5T('1O('1H92!D969A=6QT('!A
M8VMA9V5N86UE(')E9V5X#0H@("`@("H@0')E='5R;B!B;V]L96%N('-U8V-E
M<W,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971686QI9&%T:6]N4&%C:V%G
M92@D=F%L:61A=&5C;&%S<RP@)'9E<G-I;VXI#0H@("`@>PT*("`@("`@("!I
M9B`H96UP='DH)'9A;&ED871E8VQA<W,I*2![#0H@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G72D[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A
M=&5P86-K86=E)UT@/2!A<G)A>2@G7V-O;G1E;G0G(#T^("1V86QI9&%T96-L
M87-S*3L-"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P
M86-K86=E)UU;)V%T=')I8G,G72`](&%R<F%Y*"=V97)S:6]N)R`]/B`D=F5R
M<VEO;BD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@061D(&$@<')O=&]C
M;VP@=&\@=&AE('!R;W9I9&5S('-E8W1I;VX-"B`@("`@*B!`<&%R86T@<W1R
M:6YG('!R;W1O8V]L('1Y<&4-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R;W1O
M8V]L('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R;W1O8V]L(&YA
M;64L(&EF(&%N>0T*("`@("`J($!P87)A;2!S=')I;F<@;6ER<F]R(&YA;64L
M(&EF('1H:7,@:7,@82!M:7)R;W(G<R!P<F]T;V-O;`T*("`@("`J($!R971U
M<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$9U;F-T:6]N*"1T
M>7!E+"`D=F5R<VEO;BP@)&YA;64@/2`G)RP@)&UI<G)O<B`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^861D36ER<F]R1G5N8W1I;VXH)&UI<G)O<BP@)'1Y<&4L
M("1V97)S:6]N+"`D;F%M92D[#0H@("`@("`@('T-"B`@("`@("`@)'-E="`]
M(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G=F5R<VEO;B<@/3X@)'9E<G-I
M;VXI+"`G7V-O;G1E;G0G(#T^("1N86UE*3L-"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD
M='EP95U;)V9U;F-T:6]N)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-H
M86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD='EP95U;)V9U;F-T
M:6]N)UT@/2`D<V5T.PT*("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@
M9F%L<V4[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E
M;'-E:68@*"%I<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;
M)W!R:6UA<GDG75LD='EP95U;)V9U;F-T:6]N)UU;,%TI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG
M75LD='EP95U;)V9U;F-T:6]N)UT@/2!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD
M='EP95U;)V9U;F-T:6]N)UTI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1T>7!E75LG
M9G5N8W1I;VXG75M=(#T@)'-E=#L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*("`@("\J*@T*("`@("`J($%D9"!A('!R;W1O8V]L('1O(&$@;6ER
M<F]R)W,@<')O=FED97,@<V5C=&EO;@T*("`@("`J($!P87)A;2!S=')I;F<@
M;6ER<F]R(&YA;64@*'-E<G9E<BD-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R
M;W1O8V]L('1Y<&4-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R;W1O8V]L('9E
M<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R;W1O8V]L(&YA;64L(&EF
M(&%N>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$UI<G)O<D9U;F-T:6]N
M*"1M:7)R;W(L("1T>7!E+"`D=F5R<VEO;BP@)&YA;64@/2`G)RD-"B`@("![
M#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E]-25)23U)?3D]47T9/54Y$+`T*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D<V5T;6ER<F]R
M(#T@9F%L<V4[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==6S!=*2D@>PT*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R
M;W(G72!A<R`D:2`]/B`D;6ER*2![#0H@("`@("`@("`@("`@("`@:68@*"1M
M:7)R;W(@/3T@)&UI<ELG871T<FEB<R==6R=H;W-T)UTI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'-E=&UI<G)O<B`]("8D=&AI<RT^7V-H86YN96Q);F9O
M6R=S97)V97)S)UU;)VUI<G)O<B==6R1I73L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG:&]S
M="==(#T]("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@("`D<V5T;6ER<F]R
M(#T@)B1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D<V5T
M;6ER<F]R*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H
M4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-25)23U)?3D]47T9/54Y$+`T*("`@
M("`@("`@("`@("`@(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D
M<V5T(#T@87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=V97)S:6]N)R`]/B`D
M=F5R<VEO;BDL("=?8V]N=&5N="<@/3X@)&YA;64I.PT*("`@("`@("!I9B`H
M(6ES<V5T*"1S971M:7)R;W);)'1Y<&5=6R=F=6YC=&EO;B==*2D@>PT*("`@
M("`@("`@("`@)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T:6]N)UT@/2`D<V5T
M.PT*("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E:68@*"%I<W-E
M="@D<V5T;6ER<F]R6R1T>7!E75LG9G5N8W1I;VXG75LP72DI('L-"B`@("`@
M("`@("`@("1S971M:7)R;W);)'1Y<&5=6R=F=6YC=&EO;B==(#T@87)R87DH
M)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T:6]N)UTI.PT*("`@("`@("!]#0H@
M("`@("`@("1S971M:7)R;W);)'1Y<&5=6R=F=6YC=&EO;B==6UT@/2`D<V5T
M.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!297-O=7)C92!4>7!E('1H:7,@=7)L(&QI;FMS('1O#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!54DP-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A
M;'-E(&UI<G)O<B!N86UE+"!I9B!T:&ES(&ES(&YO="!A('!R:6UA<GD@<V5R
M=F5R(%)%4U0@8F%S92!54DP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971"
M87-E55),*"1R97-O=7)C951Y<&4L("1U<FPL("1M:7)R;W(@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("`D
M9F]U;F0@/2!F86QS93L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72DI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,
M1DE,15]%4E)/4E]-25)23U)?3D]47T9/54Y$+`T*("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G;6ER<F]R)R`]/B`D;6ER<F]R*2D[#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'-E=&UI<G)O<B`](&9A;'-E.PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;,%TI
M*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&%N;F5L
M26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72!A<R`D:2`]/B`D;6ER*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@D;6ER<F]R(#T]("1M:7);)V%T=')I
M8G,G75LG:&]S="==*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<V5T
M;6ER<F]R(#T@)B1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER
M<F]R)UU;)&E=.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;
M)VAO<W0G72`]/2`D;6ER<F]R*2![#0H@("`@("`@("`@("`@("`@("`@("1S
M971M:7)R;W(@/2`F)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<V5T;6ER<F]R(#T@)B1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==.PT*("`@
M("`@("!]#0H@("`@("`@("1S970@/2!A<G)A>2@G871T<FEB<R<@/3X@87)R
M87DH)W1Y<&4G(#T^("1R97-O=7)C951Y<&4I+"`G7V-O;G1E;G0G(#T^("1U
M<FPI.PT*("`@("`@("!I9B`H(6ES<V5T*"1S971M:7)R;W);)W)E<W0G75LG
M8F%S975R;"==*2D@>PT*("`@("`@("`@("`@)'-E=&UI<G)O<ELG<F5S="==
M6R=B87-E=7)L)UT@/2`D<V5T.PT*("`@("`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@?2!E;'-E:68@*"%I<W-E="@D<V5T;6ER<F]R6R=R97-T)UU;)V)A<V5U
M<FPG75LP72DI('L-"B`@("`@("`@("`@("1S971M:7)R;W);)W)E<W0G75LG
M8F%S975R;"==(#T@87)R87DH)'-E=&UI<G)O<ELG<F5S="==6R=B87-E=7)L
M)UTI.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1S971M:7)R;W);
M)W)E<W0G75LG8F%S975R;"==(&%S("1I(#T^("1U<FPI('L-"B`@("`@("`@
M("`@(&EF("@D=7)L6R=A='1R:6)S)UU;)W1Y<&4G72`]/2`D<F5S;W5R8V54
M>7!E*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@)'-E=&UI<G)O<ELG<F5S="==6R=B87-E
M=7)L)UU;)&E=(#T@)'-E=#L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<V5T;6ER
M<F]R6R=R97-T)UU;)V)A<V5U<FPG75M=(#T@)'-E=#L-"B`@("`@("`@)'1H
M:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@;6ER<F]R
M('-E<G9E<@T*("`@("`J($!P87)A;2!I;G0@;6ER<F]R(&AT='`@<&]R=`T*
M("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&%D9$UI<G)O<B@D<V5R=F5R+"`D<&]R="`](&YU;&PI#0H@("`@>PT*("`@
M("`@("!I9B`H)'1H:7,M/E]C:&%N;F5L26YF;ULG;F%M92==(#T]("=?7W5R
M:2<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L@+R\@=&AE(%]?=7)I
M(&-H86YN96P@8V%N;F]T(&AA=F4@;6ER<F]R<R!B>2!D969I;FET:6]N#0H@
M("`@("`@('T-"B`@("`@("`@)'-E="`](&%R<F%Y*"=A='1R:6)S)R`]/B!A
M<G)A>2@G:&]S="<@/3X@)'-E<G9E<BDI.PT*("`@("`@("!I9B`H:7-?;G5M
M97)I8R@D<&]R="DI('L-"B`@("`@("`@("`@("1S971;)V%T=')I8G,G75LG
M<&]R="==(#T@)'!O<G0[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=M:7)R;W(G72`]("1S970[#0H@("`@("`@("`@("!R971U<FX@=')U93L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LP72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S
M)UU;)VUI<G)O<B==(#T-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75M=(#T@)'-E=#L-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE
M=F4@=&AE(&YA;64@;V8@=&AE('9A;&ED871I;VX@<&%C:V%G92!F;W(@=&AI
M<R!C:&%N;F5L#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971686QI9&%T:6]N4&%C:V%G92@I#0H@("`@
M>PT*("`@("`@("!I9B`H(21T:&ES+3Y?:7-686QI9"`F)B`A)'1H:7,M/G9A
M;&ED871E*"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W9A;&ED871E<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G=F5R<VEO;B<@/3X@)V1E9F%U;'0G
M*2P-"B`@("`@("`@("`@("`@("`G7V-O;G1E;G0G(#T^("=014%27U9A;&ED
M871E)RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%)E=')I979E('1H92!O8FIE8W0@=&AA="!C86X@8F4@=7-E
M9"!F;W(@8W5S=&]M('9A;&ED871I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG
M?&9A;'-E('1H92!N86UE(&]F('1H92!P86-K86=E('1O('9A;&ED871E+B`@
M268@=&AE('!A8VMA9V4@:7,-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M('1H92!C:&%N;F5L('9A;&ED871I;VX@<&%C:V%G92P@4$5!4E]686QI9&%T
M92!I<R!R971U<FYE9`T*("`@("`J($!R971U<FX@4$5!4E]686QI9&%T97QF
M86QS92!F86QS92!I<R!R971U<FYE9"!I9B!T:&4@=F%L:61A=&EO;B!P86-K
M86=E#0H@("`@("H@("`@("`@("!C86YN;W0@8F4@;&]C871E9`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N("9G971686QI9&%T:6]N3V)J96-T*"1P86-K86=E
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]686QI9&%T92<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O5F%L:61A=&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(21T:&ES+3Y?:7-686QI9"D@>PT*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O
M6R=V86QI9&%T97!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(&EF("@D<&%C
M:V%G92`]/2`D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G
M72D@>PT*("`@("`@("`@("`@("`@("\O(&-H86YN96P@=F%L:61A=&EO;B!P
M86-K86=E<R!A<F4@86QW87ES('9A;&ED871E9"!B>2!014%27U9A;&ED871E
M#0H@("`@("`@("`@("`@("`@)'9A;"`]("9N97<@4$5!4E]686QI9&%T93L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'9A;#L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*'-T<E]R97!L86-E*"<N
M)RP@)U\G+`T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF
M;ULG=F%L:61A=&5P86-K86=E)UU;)U]C;VYT96YT)UTI*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^:7-);F-L=61E86)L92AS=')?<F5P;&%C
M92@G7R<L("<O)RP-"B`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H
M86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G72D@+B`G
M+G!H<"<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92!S
M=')?<F5P;&%C92@G7R<L("<O)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==6R=?8V]N
M=&5N="==*2`N("<N<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@)'9C;&%S
M<R`]('-T<E]R97!L86-E*"<N)RP@)U\G+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UU;
M)U]C;VYT96YT)UTI.PT*("`@("`@("`@("`@("`@("`@("`D=F%L(#T@)FYE
M=R`D=F-L87-S.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1V8VQA<W,@/2!S=')?<F5P;&%C
M92@G+B<L("=?)RP-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UU;)U]C;VYT96YT)UTI.PT*("`@
M("`@("`@("`@("`@("1V86P@/2`F;F5W("1V8VQA<W,[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=F%L(#T@)FYE
M=R!014%27U9A;&ED871E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M=F%L.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES26YC;'5D96%B;&4H)'!A
M=&@I#0H@("`@>PT*("`@("`@("`D<&]S<VEB:6QI=&EE<R`](&5X<&QO9&4H
M4$%42%]315!!4D%43U(L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I*3L-"B`@
M("`@("`@9F]R96%C:"`H)'!O<W-I8FEL:71I97,@87,@)&1I<BD@>PT*("`@
M("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1D:7(@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)'!A=&@I#0H@("`@("`@("`@("`@("`@("`F)B!I<U]R96%D
M86)L92@D9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1P871H*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!4:&ES(&9U;F-T:6]N(&ES('5S960@8GD@=&AE(&-H
M86YN96P@=7!D871E<B!A;F0@<F5T<FEE=F5S(&$@=F%L=64@<V5T(&)Y#0H@
M("`@("H@=&AE(')E9VES=')Y+"!O<B!T:&4@8W5R<F5N="!T:6UE(&EF(&ET
M(&AA<R!N;W0@8F5E;B!S970-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&QA<W1-;V1I9FEE9"@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG7VQA<W1M;V1I
M9FEE9"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE
M;$EN9F];)U]L87-T;6]D:69I960G73L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=&EM92@I.PT*("`@('T-"GT-"C\^#0H``````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0N<&AP````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,38S,0`Q,#4Q-30S,3`U
M-P`P,C`Q-C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD+"!C;VUM86YD('!A
M='1E<FX@8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@0V]M;6%N9"YP:'`L=B`Q+C,V(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L
M;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J($YE961E9"!F;W(@
M97)R;W(@:&%N9&QI;F<-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M#0IR97%U:7)E7V]N8V4@)U!%05(O1G)O;G1E;F0N<&AP)SL-"G)E<75I<F5?
M;VYC92`G4$5!4B]834Q087)S97(N<&AP)SL-"@T*+RHJ#0H@*B!,:7-T(&]F
M(&-O;6UA;F1S(&%N9"!W:&%T(&-L87-S97,@=&AE>2!A<F4@:6UP;&5M96YT
M960@:6XN#0H@*B!`=F%R(&%R<F%Y(&-O;6UA;F0@/3X@:6UP;&5M96YT:6YG
M(&-L87-S#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L
M:7-T)UT@/2!A<G)A>2@I.PT*#0HO*BH-"B`J($QI<W0@;V8@<VAO<G1C=71S
M('1O(&-O;6UO;B!C;VUM86YD<RX-"B`J($!V87(@87)R87D@<VAO<G1C=70@
M/3X@8V]M;6%N9`T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R
M=&-U=',G72`](&%R<F%Y*"D[#0H-"B\J*@T*("H@07)R87D@;V8@8V]M;6%N
M9"!O8FIE8W1S#0H@*B!`=F%R(&%R<F%Y(&-L87-S(#T^(&]B:F5C=`T*("HO
M#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]O8FIE8W1S)UT@/2!A<G)A>2@I
M.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9"!C;&%S<RP@82!S:6UP;&4@9F%C
M=&]R>2!C;&%S<R!F;W(@861M:6YI<W1R871I=F4-"B`J(&-O;6UA;F1S+@T*
M("H-"B`J($AO=R!T;R!I;7!L96UE;G0@8V]M;6%N9"!C;&%S<V5S.@T*("H-
M"B`J("T@5&AE(&-L87-S(&UU<W0@8F4@8V%L;&5D(%!%05)?0V]M;6%N9%].
M;FXL(&EN<W1A;&QE9"!I;B!T:&4-"B`J("`@(E!%05(O0V]M;6]N(B!S=6)D
M:7(L('=I=&@@82!M971H;V0@8V%L;&5D(&=E=$-O;6UA;F1S*"D@=&AA=`T*
M("H@("!R971U<FYS(&%N(&%R<F%Y(&]F('1H92!C;VUM86YD<R!I;7!L96UE
M;G1E9"!B>2!T:&4@8VQA<W,@*'-E90T*("H@("!014%2+T-O;6UA;F0O26YS
M=&%L;"YP:'`@9F]R(&%N(&5X86UP;&4I+@T*("H-"B`J("T@5&AE(&-L87-S
M(&UU<W0@:6UP;&5M96YT(&$@<G5N*"D@9G5N8W1I;VX@=&AA="!I<R!C86QL
M960@=VET:"!T:')E90T*("H@("!P87)A;7,Z#0H@*@T*("H@("`@*'-T<FEN
M9RD@8V]M;6%N9"!N86UE#0H@*B`@("`H87)R87DI("!A<W-O8R!A<G)A>2!W
M:71H(&]P=&EO;G,L(&9R965L>2!D969I;F5D(&)Y(&5A8V@-"B`J("`@("`@
M("`@("`@(&-O;6UA;F0L(&9O<B!E>&%M<&QE.@T*("H@("`@("`@("`@("`@
M87)R87DH)V9O<F-E)R`]/B!T<G5E*0T*("H@("`@*&%R<F%Y*2`@;&ES="!O
M9B!T:&4@;W1H97(@<&%R86UE=&5R<PT*("H-"B`J("`@5&AE(')U;B@I(&9U
M;F-T:6]N(')E='5R;G,@82!014%27T-O;6UA;F1297-P;VYS92!O8FIE8W0N
M("!5<V4-"B`J("`@=&AE<V4@;65T:&]D<R!T;R!G970@:6YF;W)M871I;VXZ
M#0H@*@T*("H@("`@:6YT(&=E=%-T871U<R@I("`@4F5T=7)N<R!014%27T-/
M34U!3D1?*%-50T-%4U-\1D%)3%5217Q005)424%,*0T*("H@("`@("`@("`@
M("`@("`@("`@("`@*E]005)424%,(&UE86YS('1H870@>6]U(&YE960@=&\@
M:7-S=64@870@;&5A<W0-"B`J("`@("`@("`@("`@("`@("`@("`@(&]N92!M
M;W)E(&-O;6UA;F0@=&\@8V]M<&QE=&4@=&AE(&]P97)A=&EO;@T*("H@("`@
M("`@("`@("`@("`@("`@("`@*'5S960@9F]R(&5X86UP;&4@9F]R('9A;&ED
M871I;VX@<W1E<',I+@T*("H-"B`J("`@('-T<FEN9R!G971-97-S86=E*"D@
M(%)E='5R;G,@82!M97-S86=E(&9O<B!T:&4@=7-E<BX@(%)E;65M8F5R+`T*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@;F\@2%1-3"!O<B!O=&AE<B!I
M;G1E<F9A8V4M<W!E8VEF:6,@;6%R:W5P+@T*("H-"B`J("`@268@<V]M971H
M:6YG('5N97AP96-T960@:&%P<&5N<RP@<G5N*"D@<F5T=7)N<R!A(%!%05(@
M97)R;W(N#0H@*@T*("H@+2!$3TXG5"!/5510550@04Y95$A)3D<A(%)E='5R
M;B!T97AT(&9O<B!O=71P=70@:6YS=&5A9"X-"B`J#0H@*B`M($1/3B=4(%53
M12!(5$U,(2!4:&4@=&5X="!Y;W4@<F5T=7)N('=I;&P@8F4@=7-E9"!F<F]M
M(&)O=&@@1W1K+`T*("H@("!W96(@86YD(&-O;6UA;F0M;&EN92!I;G1E<F9A
M8V5S+"!S;R!F;W(@;F]W+"!K965P(&5V97)Y=&AI;F<@=&\-"B`J("`@<&QA
M:6X@=&5X="X-"B`J#0H@*B`M($1/3B=4(%5312!%6$E4($]2($1)12$@06QW
M87ES('5S92!P96%R(&5R<F]R<RX@($9R;VT@<W1A=&EC#0H@*B`@(&-L87-S
M97,@9&\@4$5!4CHZ<F%I<V5%<G)O<B@I+"!F<F]M(&]T:&5R(&-L87-S97,@
M9&\-"B`J("`@)'1H:7,M/G)A:7-E17)R;W(H*2X-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L
M87-S(%!%05)?0V]M;6%N9`T*>PT*("`@("\O('M[>R!F86-T;W)Y*"D-"@T*
M("`@("\J*@T*("`@("`J($=E="!T:&4@<FEG:'0@;V)J96-T(&9O<B!E>&5C
M=71I;F<@82!C;VUM86YD+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]M;6%N9"!4:&4@;F%M92!O9B!T:&4@8V]M;6%N9`T*("`@("`J($!P
M87)A;2!O8FIE8W0@)&-O;F9I9R`@26YS=&%N8V4@;V8@4$5!4E]#;VYF:6<@
M;V)J96-T#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&]B:F5C="!T:&4@8V]M
M;6%N9"!O8FIE8W0@;W(@82!014%2(&5R<F]R#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@D8V]M;6%N9"P@)B1C;VYF:6<I#0H@("`@>PT*
M("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M
M;6%N9&QI<W0G72DI('L-"B`@("`@("`@("`@(%!%05)?0V]M;6%N9#HZ<F5G
M:7-T97)#;VUM86YD<R@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G75LD8V]M;6%N
M9%TI*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`]("1'3$]"04Q36R=?4$5!
M4E]#;VUM86YD7W-H;W)T8W5T<R==6R1C;VUM86YD73L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O
M;6UA;F1L:7-T)UU;)&-O;6UA;F1=*2D@>PT*("`@("`@("`@("`@)&$@/2!0
M14%2.CIR86ES945R<F]R*")U;FMN;W=N(&-O;6UA;F0@8"1C;VUM86YD)R(I
M.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@("`@
M("1C;&%S<R`]("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T
M)UU;)&-O;6UA;F1=.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA
M<W,I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?;V)J96-T<R==6R1C;&%S<UT[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PT*("`@("`@("`@
M("`@)&$@/2!014%2.CIR86ES945R<F]R*")U;FMN;W=N(&-O;6UA;F0@8"1C
M;VUM86YD)R(I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]
M#0H@("`@("`@("1U:2`])B!014%27T-O;6UA;F0Z.F=E=$9R;VYT96YD3V)J
M96-T*"D[#0H@("`@("`@("1O8FH@/2`F;F5W("1C;&%S<R@D=6DL("1C;VYF
M:6<I.PT*("`@("`@("!R971U<FX@)&]B:CL-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@)B!G971/8FIE8W0H*0T*("`@(&9U;F-T:6]N("9G
M971/8FIE8W0H)&-O;6UA;F0I#0H@("`@>PT*("`@("`@("`D8VQA<W,@/2`D
M1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==6R1C;VUM86YD
M73L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PT*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=?4$5!4E]#;VUM86YD
M7V]B:F5C=',G75LD8VQA<W-=.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L-"B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*")U;FMN;W=N(&-O;6UA;F0@8"1C;VUM86YD)R(I
M.PT*("`@("`@("!]#0H@("`@("`@("1U:2`])B!014%27T-O;6UA;F0Z.F=E
M=$9R;VYT96YD3V)J96-T*"D[#0H@("`@("`@("1C;VYF:6<@/2`F4$5!4E]#
M;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("`D;V)J(#T@)FYE=R`D8VQA
M<W,H)'5I+"`D8V]N9FEG*3L-"B`@("`@("`@<F5T=7)N("1O8FH[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[("8@9V5T1G)O;G1E;F1/8FIE
M8W0H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(&EN<W1A;F-E(&]F(&9R;VYT
M96YD(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!R971U<FX@;V)J96-T?%!%
M05)?17)R;W(-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@)F=E=$9R;VYT96YD3V)J96-T*"D-"B`@("![#0H@("`@("`@("1A(#T@
M)E!%05)?1G)O;G1E;F0Z.G-I;F=L971O;B@I.PT*("`@("`@("!R971U<FX@
M)&$[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[("8@<V5T1G)O
M;G1E;F1#;&%S<R@I#0H-"B`@("`O*BH-"B`@("`@*B!,;V%D(&-U<G)E;G0@
M9G)O;G1E;F0@8VQA<W,N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U:6-L87-S($YA;64@;V8@8VQA<W,@:6UP;&5M96YT:6YG('1H92!F<F]N
M=&5N9`T*("`@("`J#0H@("`@("H@0')E='5R;B!O8FIE8W0@=&AE(&9R;VYT
M96YD(&]B:F5C="P@;W(@82!014%2(&5R<F]R#0H@("`@("H@0'-T871I8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N("9S971&<F]N=&5N9$-L87-S*"1U:6-L
M87-S*0T*("`@('L-"B`@("`@("`@)&$@/2`F4$5!4E]&<F]N=&5N9#HZ<V5T
M1G)O;G1E;F1#;&%S<R@D=6EC;&%S<RD[#0H@("`@("`@(')E='5R;B`D83L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<V5T1G)O;G1E;F14
M>7!E*"D-"@T*("`@("\J*@T*("`@("`J(%-E="!C=7)R96YT(&9R;VYT96YD
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=6ET>7!E($YA;64@
M;V8@=&AE(&9R;VYT96YD('1Y<&4@*&9O<B!E>&%M<&QE(")#3$DB*0T*("`@
M("`J#0H@("`@("H@0')E='5R;B!O8FIE8W0@=&AE(&9R;VYT96YD(&]B:F5C
M="P@;W(@82!014%2(&5R<F]R#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=$9R;VYT96YD5'EP92@D=6ET>7!E*0T*("`@('L-
M"B`@("`@("`@)'5I8VQA<W,@/2`G4$5!4E]&<F]N=&5N9%\G("X@)'5I='EP
M93L-"B`@("`@("`@<F5T=7)N(%!%05)?0V]M;6%N9#HZ<V5T1G)O;G1E;F1#
M;&%S<R@D=6EC;&%S<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(')E9VES=&5R0V]M;6%N9',H*0T*#0H@("`@+RHJ#0H@("`@("H@4V-A
M;B!T:')O=6=H('1H92!#;VUM86YD(&1I<F5C=&]R>2!L;V]K:6YG(&9O<B!C
M;&%S<V5S#0H@("`@("H@86YD('-E92!W:&%T(&-O;6UA;F1S('1H97D@:6UP
M;&5M96YT+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&)O;VP@("`H;W!T:6]N
M86PI(&EF($9!3%-%("AD969A=6QT*2P@=&AE(&YE=R!L:7-T(&]F#0H@("`@
M("H@("`@("`@("`@("`@("!C;VUM86YD<R!S:&]U;&0@<F5P;&%C92!T:&4@
M8W5R<F5N="!O;F4N("!)9B!44E5%+`T*("`@("`J("`@("`@("`@("`@("`@
M;F5W(&5N=')I97,@=VEL;"!B92!M97)G960@=VET:"!O;&0N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@=VAE<F4@*'=H870@
M9&ER96-T;W)Y*2!T;R!L;V]K(&9O<@T*("`@("`J("`@("`@("`@("`@("`@
M8VQA<W-E<RP@9&5F875L=',@=&\@=&AE($-O;6UA;F0@<W5B9&ER96-T;W)Y
M(&]F#0H@("`@("H@("`@("`@("`@("`@("!T:&4@9&ER96-T;W)Y(&9R;VT@
M=VAE<F4@=&AI<R!F:6QE("A?7T9)3$5?7RD@:7,-"B`@("`@*B`@("`@("`@
M("`@("`@(&EN8VQU9&5D+@T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L
M(%12544@;VX@<W5C8V5S<RP@82!014%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-T871I8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N(')E9VES=&5R0V]M;6%N9',H)&UE<F=E
M(#T@9F%L<V4L("1D:7(@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)'!A<G-E
M<B`](&YE=R!014%27UA-3%!A<G-E<CL-"B`@("`@("`@:68@*"1D:7(@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@("1D:7(@/2!D:7)N86UE*%]?1DE,15]?
M*2`N("<O0V]M;6%N9"<[#0H@("`@("`@('T-"B`@("`@("`@)&1P(#T@0&]P
M96YD:7(H)&1I<BD[#0H@("`@("`@(&EF("AE;7!T>2@D9'`I*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B<F5G:7-T97)#;VUM
M86YD<SH@;W!E;F1I<B@D9&ER*2!F86EL960B*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(21M97)G92D@>PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?8V]M;6%N9&QI<W0G72`](&%R<F%Y*"D[#0H@("`@("`@
M('T-"B`@("`@("`@=VAI;&4@*"1E;G1R>2`](')E861D:7(H)&1P*2D@>PT*
M("`@("`@("`@("`@:68@*"1E;G1R>7LP?2`]/2`G+B<@?'P@<W5B<W1R*"1E
M;G1R>2P@+30I("$]("<N>&UL)RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-L87-S(#T@(E!%
M05)?0V]M;6%N9%\B+G-U8G-T<B@D96YT<GDL(#`L("TT*3L-"B`@("`@("`@
M("`@("1F:6QE(#T@(B1D:7(O)&5N=')Y(CL-"B`@("`@("`@("`@("1P87)S
M97(M/G!A<G-E*&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*2D[#0H@("`@("`@
M("`@("`D:6UP;&5M96YT<R`]("1P87)S97(M/F=E=$1A=&$H*3L-"B`@("`@
M("`@("`@("\O($QI<W0@;V8@8V]M;6%N9',-"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]O8FIE8W1S)UU;)&-L87-S
M72DI('L-"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N
M9%]O8FIE8W1S)UU;)&-L87-S72`]("(D9&ER+R(@+B!S=6)S='(H)&5N=')Y
M+"`P+"`M-"D@+@T*("`@("`@("`@("`@("`@("`@("`G+G!H<"<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D:6UP;&5M96YT<R!A
M<R`D8V]M;6%N9"`]/B`D9&5S8RD@>PT*("`@("`@("`@("`@("`@(&EF("@D
M8V]M;6%N9"`]/2`G871T<FEB<R<I('L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES
M="==6R1C;VUM86YD72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)T-O;6UA;F0@(B<@+B`D8V]M;6%N9"`N("<B
M(&%L<F5A9'D@<F5G:7-T97)E9"!I;B`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=C;&%S<R`B)R`N("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O
M;6UA;F1L:7-T)UU;)&-O;6UA;F1=("X@)R(G*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?
M8V]M;6%N9&QI<W0G75LD8V]M;6%N9%T@/2`D8VQA<W,[#0H@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&1E<V,G75LD
M8V]M;6%N9%T@/2`D9&5S8ULG<W5M;6%R>2==.PT*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5S8ULG<VAO<G1C=70G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'-H;W)T8W5T(#T@)&1E<V-;)W-H;W)T8W5T)UT[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M
M;6%N9%]S:&]R=&-U=',G75LD<VAO<G1C=71=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O;6UA;F0@
M<VAO<G1C=70@(B<@+B`D<VAO<G1C=70@+B`G(B!A;')E861Y("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R96=I<W1E<F5D('1O(&-O;6UA
M;F0@(B<@+B`D8V]M;6%N9"`N("<B(&EN(&-L87-S("(G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C
M;VUM86YD;&ES="==6R1C;VUM86YD72`N("<B)RD[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%2
M7T-O;6UA;F1?<VAO<G1C=71S)UU;)'-H;W)T8W5T72`]("1C;VUM86YD.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&1E<V-;)V]P=&EO;G,G72D@)B8@)&1E<V-;)V]P=&EO;G,G72D@>PT*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5S8ULG;W!T:6]N<R==(&%S
M("1O;F%M92`]/B`D;W!T:6]N*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;ELG<VAO<G1O<'0G72D@)B8@<W1R;&5N*"1O
M<'1I;VY;)W-H;W)T;W!T)UTI(#X@,2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=/<'1I;VX@(B<@
M+B`D;VYA;64@+B`G(B!S:&]R="!O<'1I;VX@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;W!T:6]N6R=S:&]R=&]P="==("X@)R(@
M;75S="!B92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V]N;'D@,2!C:&%R86-T97(@:6X@0V]M;6%N9"`B)R`N("1C;VUM86YD("X@
M)R(@:6X@8VQA<W,@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8VQA<W,@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&MS;W)T*"1'3$]"
M04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==*3L-"B`@("`@("`@:W-O
M<G0H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G72D[#0H@
M("`@("`@($!C;&]S961I<B@D9'`I.PT*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T0V]M;6%N9',H
M*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!L:7-T(&]F(&-U<G)E;G1L
M>2!S=7!P;W)T960@8V]M;6%N9',L(&%N9"!W:&%T#0H@("`@("H@8VQA<W-E
M<R!I;7!L96UE;G0@=&AE;2X-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R
M87D@8V]M;6%N9"`]/B!I;7!L96UE;G1I;F<@8VQA<W,-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=$-O;6UA;F1S*"D-"B`@("![#0H@("`@("`@(&EF
M("AE;7!T>2@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==
M*2D@>PT*("`@("`@("`@("`@4$5!4E]#;VUM86YD.CIR96=I<W1E<D-O;6UA
M;F1S*"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?
M4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UT[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=%-H;W)T8W5T<R@I#0H-"B`@("`O*BH-"B`@
M("`@*B!'970@=&AE(&QI<W0@;V8@8V]M;6%N9"!S:&]R=&-U=',N#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y('-H;W)T8W5T(#T^(&-O;6UA;F0-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-T871I
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%-H;W)T8W5T<R@I#0H@("`@
M>PT*("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)U]014%27T-O;6UA;F1?
M<VAO<G1C=71S)UTI*2![#0H@("`@("`@("`@("!014%27T-O;6UA;F0Z.G)E
M9VES=&5R0V]M;6%N9',H*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UT[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$=E=&]P=$%R9W,H*0T*#0H@
M("`@+RHJ#0H@("`@("H@0V]M<&EL97,@87)G=6UE;G1S(&9O<B!G971O<'0N
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VUM86YD("`@("!C
M;VUM86YD('1O(&=E="!O<'1S=')I;F<@9F]R#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<VAO<G1?87)G<R`@*')E9F5R96YC92D@<VAO<G0@9V5T;W!T(&9O
M<FUA=`T*("`@("`J($!P87)A;2!A<G)A>2`@)&QO;F=?87)G<R`@("AR969E
M<F5N8V4I(&QO;F<@9V5T;W!T(&9O<FUA=`T*("`@("`J#0H@("`@("H@0')E
M='5R;B!V;VED#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971'971O<'1!
M<F=S*"1C;VUM86YD+"`F)'-H;W)T7V%R9W,L("8D;&]N9U]A<F=S*0T*("`@
M('L-"B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD
M7V-O;6UA;F1L:7-T)UTI*2![#0H@("`@("`@("`@("!014%27T-O;6UA;F0Z
M.G)E9VES=&5R0V]M;6%N9',H*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UU;)&-O
M;6UA;F1=*2D@>PT*("`@("`@("`@("`@)&-O;6UA;F0@/2`D1TQ/0D%,4ULG
M7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G75LD8V]M;6%N9%T[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N
M9%]C;VUM86YD;&ES="==6R1C;VUM86YD72DI('L-"B`@("`@("`@("`@(')E
M='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F4$5!4E]#
M;VUM86YD.CIG971/8FIE8W0H)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@
M)&]B:BT^9V5T1V5T;W!T07)G<R@D8V]M;6%N9"P@)'-H;W)T7V%R9W,L("1L
M;VYG7V%R9W,I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G
M971$97-C<FEP=&EO;B@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@9&5S8W)I
M<'1I;VX@9F]R(&$@8V]M;6%N9"X-"B`@("`@*@T*("`@("`J($!P87)A;2`@
M<W1R:6YG("1C;VUM86YD($YA;64@;V8@=&AE(&-O;6UA;F0-"B`@("`@*@T*
M("`@("`J($!R971U<FX@<W1R:6YG(&-O;6UA;F0@9&5S8W)I<'1I;VX-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-T871I8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E<V-R:7!T:6]N*"1C;VUM86YD
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?
M0V]M;6%N9%]C;VUM86YD9&5S8R==6R1C;VUM86YD72DI('L-"B`@("`@("`@
M("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD9&5S8R==6R1C;VUM86YD
M73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T2&5L<"@I
M#0H-"B`@("`O*BH-"B`@("`@*B!'970@:&5L<"!F;W(@8V]M;6%N9"X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UA;F0@3F%M92!O9B!T
M:&4@8V]M;6%N9"!T;R!R971U<FX@:&5L<"!F;W(-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$AE;'`H)&-O;6UA;F0I#0H@("`@>PT*("`@("`@("`D
M8VUD<R`](%!%05)?0V]M;6%N9#HZ9V5T0V]M;6%N9',H*3L-"B`@("`@("`@
M:68@*&ES<V5T*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==
M6R1C;VUM86YD72DI('L-"B`@("`@("`@("`@("1C;VUM86YD(#T@)$=,3T)!
M3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UU;)&-O;6UA;F1=.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D8VUD<ULD8V]M;6%N9%TI*2![
M#0H@("`@("`@("`@("`D;V)J(#T@)E!%05)?0V]M;6%N9#HZ9V5T3V)J96-T
M*"1C;VUM86YD*3L-"B`@("`@("`@("`@(')E='5R;B`D;V)J+3YG971(96QP
M*"1C;VUM86YD*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*("`@("\O('U]?0T*?0T*#0H_/@T*````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UO;BYP:'``
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P-S<S-``Q
M,#4Q-30S,3`U-P`P,C`P-#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM;VXL('1H
M92!B87-E(&-L87-S(&9O<B!T:&4@4$5!4B!);G-T86QL97(-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4
M;VUA<R!6+B!6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#;VUM;VXN<&AP+'8@
M,2XQ-34@,C`P-B\P,R\P,B`Q.#HQ-#HQ,B!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N
M,2XP#0H@*B!`9&5P<F5C871E9"!&:6QE(&1E<')E8V%T960@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!);F-L=61E(&5R<F]R(&AA
M;F1L:6YG#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*#0HO+R![
M>WL@8V]N<W1A;G1S(&%N9"!G;&]B86QS#0H-"B\J*@T*("H@4$5!4E]#;VUM
M;VX@97)R;W(@=VAE;B!A;B!I;G9A;&ED(%!(4"!F:6QE(&ES('!A<W-E9"!T
M;R!014%27T-O;6UO;CHZ86YA;'EZ95-O=7)C94-O9&4H*0T*("HO#0ID969I
M;F4H)U!%05)?0T]-34].7T524D]27TE.5D%,24102%`G+"`Q*3L-"F1E9FEN
M92@G7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5')RP@)UM!+5IA+7I=
M6V$M>D$M6C`M.5]=*R<I.PT*9&5F:6YE*"=014%27T-/34U/3E]004-+04=%
M7TY!345?4%)%1R<L("<O7B<@+B!?4$5!4E]#3TU-3TY?4$%#2T%'15].04U%
M7U!214<@+B`G)"\G*3L-"@T*+R\@=&AI<R!S:&]U;&0@86QL;W<Z(#$L(#$N
M,"P@,2XP4D,Q+"`Q+C!D978L(#$N,&1E=C$R,S(S-#(S-#(S-"P@,2XP83$L
M(#$N,&(Q+"`Q+C!P;#$-"F1E9FEN92@G7U!%05)?0T]-34].7U!!0TM!1T5?
M5D524TE/3E]04D5')RP@)UQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI
M/R<I.PT*9&5F:6YE*"=014%27T-/34U/3E]004-+04=%7U9%4E-)3TY?4%)%
M1R<L("<O7B<@+B!?4$5!4E]#3TU-3TY?4$%#2T%'15]615)324].7U!214<@
M+B`G)"]I)RD[#0H-"B\O(%A86"!F87(@9G)O;2!P97)F96-T(#HM*0T*9&5F
M:6YE*"=?4$5!4E]#3TU-3TY?4$%#2T%'15]$3U=.3$]!1%]04D5')RP@)R@G
M("X@7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5'("X-"B`@("`G*2@M
M*%LN,"TY82UZ02U:72LI*3\G*3L-"F1E9FEN92@G4$5!4E]#3TU-3TY?4$%#
M2T%'15]$3U=.3$]!1%]04D5')RP@)R]>)R`N(%]014%27T-/34U/3E]004-+
M04=%7T1/5TY,3T%$7U!214<@+@T*("`@("<D+R<I.PT*#0ID969I;F4H)U]0
M14%27T-(04Y.14Q37TY!345?4%)%1R<L("=;02U:82UZ75MA+7I!+5HP+3E<
M+ETK)RD[#0ID969I;F4H)U!%05)?0TA!3DY%3%-?3D%-15]04D5')RP@)R]>
M)R`N(%]014%27T-(04Y.14Q37TY!345?4%)%1R`N("<D+R<I.PT*#0HO+R!T
M:&ES('-H;W5L9"!A;&QO=R!A;GD@9&YS(&]R($E0(&%D9')E<W,L('!L=7,@
M82!P871H("T@3D\@54Y$15)30T]215,@04Q,3U=%1`T*9&5F:6YE*"=?4$5!
M4E]#2$%.3D5,4U]315)615)?4%)%1R<L("=;82UZ02U:,"TY7"U=*R@_.EPN
M6V$M>D$M6C`M.5PM72LI*BA<+UMA+7I!+5HP+3E<+5TK*2HG*3L-"F1E9FEN
M92@G4$5!4E]#2$%.3D5,4U]315)615)?4%)%1R<L("<O7B<@+B!?4$5!4E]#
M2$%.3D5,4U]315)615)?4%)%1R`N("<D+VDG*3L-"@T*9&5F:6YE*"=?4$5!
M4E]#2$%.3D5,4U]004-+04=%7U!214<G+"`@)R@G("Y?4$5!4E]#2$%.3D5,
M4U]315)615)?4%)%1R`N("<I7"\H)PT*("`@("`@("`@+B!?4$5!4E]#3TU-
M3TY?4$%#2T%'15].04U%7U!214<@+B`G*2<I.PT*9&5F:6YE*"=014%27T-(
M04Y.14Q37U!!0TM!1T5?4%)%1R<L("<O7B<@+B!?4$5!4E]#2$%.3D5,4U]0
M04-+04=%7U!214<@+B`G)"]I)RD[#0H-"F1E9FEN92@G7U!%05)?0T]-34].
M7T-(04Y.14Q?1$]73DQ/041?4%)%1R<L("<H)R`N(%]014%27T-(04Y.14Q3
M7TY!345?4%)%1R`N("<I.CHH)PT*("`@("X@7U!%05)?0T]-34].7U!!0TM!
M1T5?3D%-15]04D5'("X@)RDH+2A;+C`M.6$M>D$M6ETK*2D_)RD[#0ID969I
M;F4H)U!%05)?0T]-34].7T-(04Y.14Q?1$]73DQ/041?4%)%1R<L("<O7B<@
M+B!?4$5!4E]#3TU-3TY?0TA!3DY%3%]$3U=.3$]!1%]04D5'("X@)R0O)RD[
M#0H-"B\J*@T*("H@3&ES="!O9B!T96UP;W)A<GD@9FEL97,@86YD(&1I<F5C
M=&]R:65S(')E9VES=&5R960@8GD-"B`J(%!%05)?0V]M;6]N.CIA9&1496UP
M1FEL92@I+@T*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?
M0V]M;6]N7W1E;7!F:6QE<R==(#T@87)R87DH*3L-"@T*+RHJ#0H@*B!686QI
M9"!M86EN=&%I;F5R(')O;&5S#0H@*B!`=F%R(&%R<F%Y#0H@*B\-"B1'3$]"
M04Q36R=?4$5!4E]#;VUM;VY?;6%I;G1A:6YE<E]R;VQE<R==(#T@87)R87DH
M)VQE860G+"=D979E;&]P97(G+"=C;VYT<FEB=71O<B<L)VAE;'!E<B<I.PT*
M#0HO*BH-"B`J(%9A;&ED(')E;&5A<V4@<W1A=&5S#0H@*B!`=F%R(&%R<F%Y
M#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]#;VUM;VY?<F5L96%S95]S=&%T97,G
M72`](&%R<F%Y*"=A;'!H82<L)V)E=&$G+"=S=&%B;&4G+"=S;F%P<VAO="<L
M)V1E=F5L)RD[#0H-"B\J*@T*("H@5F%L:60@9&5P96YD96YC>2!T>7!E<PT*
M("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6]N7V1E
M<&5N9&5N8WE?='EP97,G72`](&%R<F%Y*"=P:V<G+"=E>'0G+"=P:'`G+"=P
M<F]G)RPG;&1L:6(G+"=R=&QI8B<L)V]S)RPG=V5B<W)V)RPG<V%P:2<I.PT*
M#0HO*BH-"B`J(%9A;&ED(&1E<&5N9&5N8WD@<F5L871I;VYS#0H@*B!`=F%R
M(&%R<F%Y#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]#;VUM;VY?9&5P96YD96YC
M>5]R96QA=&EO;G,G72`](&%R<F%Y*"=H87,G+"=E<2<L)VQT)RPG;&4G+"=G
M="<L)V=E)RPG;F]T)RP@)VYE)RD[#0H-"B\J*@T*("H@5F%L:60@9FEL92!R
M;VQE<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M
M;6]N7V9I;&5?<F]L97,G72`](&%R<F%Y*"=P:'`G+"=E>'0G+"=T97-T)RPG
M9&]C)RPG9&%T82<L)W-R8R<L)W-C<FEP="<I.PT*#0HO*BH-"B`J(%9A;&ED
M(')E<&QA8V5M96YT('1Y<&5S#0H@*B!`=F%R(&%R<F%Y#0H@*B\-"B1'3$]"
M04Q36R=?4$5!4E]#;VUM;VY?<F5P;&%C96UE;G1?='EP97,G72`](&%R<F%Y
M*"=P:'`M8V]N<W0G+"`G<&5A<BUC;VYF:6<G+"`G<&%C:V%G92UI;F9O)RD[
M#0H-"B\J*@T*("H@5F%L:60@(G!R;W9I9&4B('1Y<&5S#0H@*B!`=F%R(&%R
M<F%Y#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]#;VUM;VY?<')O=FED95]T>7!E
M<R==(#T@87)R87DH)V5X="<L("=P<F]G)RP@)V-L87-S)RP@)V9U;F-T:6]N
M)RP@)V9E871U<F4G+"`G87!I)RD[#0H-"B\J*@T*("H@5F%L:60@(G!R;W9I
M9&4B('1Y<&5S#0H@*B!`=F%R(&%R<F%Y#0H@*B\-"B1'3$]"04Q36R=?4$5!
M4E]#;VUM;VY?<V-R:7!T7W!H87-E<R==(#T@87)R87DH)W!R92UI;G-T86QL
M)RP@)W!O<W0M:6YS=&%L;"<L("=P<F4M=6YI;G-T86QL)RP@)W!O<W0M=6YI
M;G-T86QL)RP@)W!R92UB=6EL9"<L("=P;W-T+6)U:6QD)RP@)W!R92UC;VYF
M:6=U<F4G+"`G<&]S="UC;VYF:6=U<F4G+"`G<')E+7-E='5P)RP@)W!O<W0M
M<V5T=7`G*3L-"@T*+R\@?7U]#0H-"B\J*@T*("H@0VQA<W,@<')O=FED:6YG
M(&-O;6UO;B!F=6YC=&EO;F%L:71Y(&9O<B!014%2(&%D;6EN:7-T<F%T:6]N
M(&-L87-S97,N#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+B!6+B!#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("H@0&1E<')E8V%T960@5&AI
M<R!C;&%S<R!W:6QL(&1I<V%P<&5A<BP@86YD(&ET<R!C;VUP;VYE;G1S('=I
M;&P@8F4@<W!R96%D#0H@*B`@("`@("`@("`@("!I;G1O('-M86QL97(@8VQA
M<W-E<RP@;&EK92!T:&4@050F5"!B<F5A:W5P+"!A<R!O9B!296QE87-E(#$N
M-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]#;VUM;VX@97AT96YD<R!014%2#0I[
M#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*B!S=&%C:R!O9B!E
M;&5M96YT<RP@9VEV97,@<V]M92!S;W)T(&]F(%A-3"!C;VYT97AT("HO#0H@
M("`@=F%R("1E;&5M96YT7W-T86-K(#T@87)R87DH*3L-"@T*("`@("\J*B!N
M86UE(&]F(&-U<G)E;G1L>2!P87)S960@6$U,(&5L96UE;G0@*B\-"B`@("!V
M87(@)&-U<G)E;G1?96QE;65N=#L-"@T*("`@("\J*B!A<G)A>2!O9B!A='1R
M:6)U=&5S(&]F('1H92!C=7)R96YT;'D@<&%R<V5D(%A-3"!E;&5M96YT("HO
M#0H@("`@=F%R("1C=7)R96YT7V%T=')I8G5T97,@/2!A<G)A>2@I.PT*#0H@
M("`@+RHJ(&%S<V]C('=I=&@@:6YF;W)M871I;VX@86)O=70@82!P86-K86=E
M("HO#0H@("`@=F%R("1P:V=I;F9O(#T@87)R87DH*3L-"@T*("`@("\J*@T*
M("`@("`J(%5S97(@26YT97)F86-E(&]B:F5C="`H4$5!4E]&<F]N=&5N9%\J
M(&-L87-S*2X@($EF(&YU;&PL#0H@("`@("H@=&AE(&QO9R@I(&UE=&AO9"!U
M<V5S('!R:6YT+@T*("`@("`J($!V87(@;V)J96-T#0H@("`@("HO#0H@("`@
M=F%R("1U:2`](&YU;&P[#0H-"B`@("`O*BH-"B`@("`@*B!#;VYF:6=U<F%T
M:6]N(&]B:F5C="`H4$5!4E]#;VYF:6<I+@T*("`@("`J($!V87(@;V)J96-T
M#0H@("`@("HO#0H@("`@=F%R("1C;VYF:6<@/2!N=6QL.PT*#0H@("`@=F%R
M("1C=7)R96YT7W!A=&@@/2!N=6QL.PT*#0H@("`@+RHJ#0H@("`@("H@4$5!
M4E]3;W5R8V5!;F%L>7IE<B!I;G-T86YC90T*("`@("`J($!V87(@;V)J96-T
M#0H@("`@("HO#0H@("`@=F%R("1S;W5R8V5?86YA;'EZ97(@/2!N=6QL.PT*
M("`@("\J*@T*("`@("`J($9L86<@=F%R:6%B;&4@=7-E9"!T;R!M87)K(&$@
M=F%L:60@<&%C:V%G92!F:6QE#0H@("`@("H@0'9A<B!B;V]L96%N#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?=F%L:610
M86-K86=E1FEL93L-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T
M<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27T-O;6UO;B!C;VYS=')U
M8W1O<@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!014%27T-O;6UO;B@I#0H@("`@>PT*("`@("`@("!P
M87)E;G0Z.E!%05(H*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9R`]("9014%2
M7T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("1T:&ES+3YD96)U9R`]
M("1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!D97-T<G5C=&]R#0H-"B`@("`O*BH-"B`@
M("`@*B!014%27T-O;6UO;B!D97-T<G5C=&]R#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?4$5!4E]#
M;VUM;VXH*0T*("`@('L-"B`@("`@("`@+R\@9&]E<VXG="!W;W)K(&1U92!T
M;R!B=6<@(S$T-S0T#0H@("`@("`@("\O)'1E;7!F:6QE<R`]("1T:&ES+3Y?
M=&5M<&9I;&5S.PT*("`@("`@("`D=&5M<&9I;&5S(#TF("1'3$]"04Q36R=?
M4$5!4E]#;VUM;VY?=&5M<&9I;&5S)UT[#0H@("`@("`@('=H:6QE("@D9FEL
M92`](&%R<F%Y7W-H:69T*"1T96UP9FEL97,I*2![#0H@("`@("`@("`@("!I
M9B`H0&ES7V1I<B@D9FEL92DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@G4WES=&5M)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@4WES=&5M.CIR;2AA<G)A>2@G+7)F)RP@)&9I
M;&4I*3L-"B`@("`@("`@("`@('T@96QS96EF("AF:6QE7V5X:7-T<R@D9FEL
M92DI('L-"B`@("`@("`@("`@("`@("!U;FQI;FLH)&9I;&4I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&%D9%1E;7!&:6QE*"D-"@T*("`@("\J*@T*("`@("`J(%)E9VES
M=&5R(&$@=&5M<&]R87)Y(&9I;&4@;W(@9&ER96-T;W)Y+B`@5VAE;B!T:&4@
M9&5S=')U8W1O<B!I<PT*("`@("`J(&5X96-U=&5D+"!A;&P@<F5G:7-T97)E
M9"!T96UP;W)A<GD@9FEL97,@86YD(&1I<F5C=&]R:65S(&%R90T*("`@("`J
M(')E;6]V960N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL
M92`@;F%M92!O9B!F:6QE(&]R(&1I<F5C=&]R>0T*("`@("`J#0H@("`@("H@
M0')E='5R;B!V;VED#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9%1E;7!&:6QE*"1F:6QE*0T*("`@
M('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1G)O;G1E;F0G
M*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T9R;VYT96YD
M+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@4$5!4E]&<F]N=&5N9#HZ861D
M5&5M<$9I;&4H)&9I;&4I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!M:T1I<DAI97(H*0T*#0H@("`@+RHJ#0H@("`@("H@5W)A<'!E<B!T
M;R!3>7-T96TZ.FUK1&ER*"DL(&-R96%T97,@82!D:7)E8W1O<GD@87,@=V5L
M;"!A<PT*("`@("`J(&%N>2!N96-E<W-A<GD@<&%R96YT(&1I<F5C=&]R:65S
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&1I<B`@9&ER96-T
M;W)Y(&YA;64-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N
M('-U8V-E<W,L(&]R(&$@4$5!4B!E<G)O<@T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!M:T1I<DAI97(H
M)&1I<BD-"B`@("![#0H@("`@("`@("1T:&ES+3YL;V<H,BP@(BL@8W)E871E
M(&1I<B`D9&ER(BD[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T
M96TG*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP
M)SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@4WES=&5M.CIM:T1I<BAA
M<G)A>2@G+7`G+"`D9&ER*2D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&QO9R@I#0H-"B`@("`O*BH-"B`@("`@*B!,;V=G:6YG(&UE=&AO
M9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("!L;V<@
M;&5V96P@*#`@:7,@<75I970L(&AI9VAE<B!I<R!N;VES:65R*0T*("`@("`J
M($!P87)A;2!S=')I;F<@)&US9R`@("!M97-S86=E('1O('=R:71E('1O('1H
M92!L;V<-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@;&]G*"1L979E;"P@)&US9RP@)&%P<&5N9%]C<FQF
M(#T@=')U92D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^9&5B=6<@/CT@
M)&QE=F5L*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]&<F]N=&5N9"<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+T9R;VYT96YD+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D=6D@/2`F4$5!4E]&<F]N=&5N9#HZ<VEN9VQE=&]N*"D[#0H@("`@
M("`@("`@("!I9B`H:7-?82@D=6DL("=014%27T9R;VYT96YD)RDI('L-"B`@
M("`@("`@("`@("`@("`D=6DM/FQO9R@D;7-G+"`D87!P96YD7V-R;&8I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!P<FEN="`B
M)&US9UQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!M:U1E;7!$:7(H*0T*#0H@("`@+RHJ
M#0H@("`@("H@0W)E871E(&%N9"!R96=I<W1E<B!A('1E;7!O<F%R>2!D:7)E
M8W1O<GDN#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;7!D:7(@
M*&]P=&EO;F%L*2!$:7)E8W1O<GD@=&\@=7-E(&%S('1M<&1I<BX-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@5VEL;"!U<V4@<WES=&5M(&1E9F%U
M;'1S("AF;W(@97AA;7!L90T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`O=&UP(&]R(&,Z7'=I;F1O=W-<=&5M<"D@:68@;F]T('-P96-I9FEE9`T*
M("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@;F%M92!O9B!C<F5A=&5D
M(&1I<F5C=&]R>0T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!M:U1E;7!$:7(H)'1M<&1I<B`]("<G*0T*
M("`@('L-"B`@("`@("`@:68@*"1T;7!D:7(I('L-"B`@("`@("`@("`@("1T
M;W!T(#T@87)R87DH)RUT)RP@)'1M<&1I<BD[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D=&]P="`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@
M("`@("`@)'1O<'0@/2!A<G)A>5]M97)G92@D=&]P="P@87)R87DH)RUD)RP@
M)W!E87(G*2D[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG
M*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T;7!D:7(@/2!3>7-T96TZ.FUK
M=&5M<"@D=&]P="DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^861D5&5M<$9I;&4H)'1M<&1I<BD[
M#0H@("`@("`@(')E='5R;B`D=&UP9&ER.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!S971&<F]N=&5N9$]B:F5C="@I#0H-"B`@("`O*BH-
M"B`@("`@*B!3970@;V)J96-T('1H870@<F5P<F5S96YT<R!T:&4@9G)O;G1E
M;F0@=&\@8F4@=7-E9"X-"B`@("`@*@T*("`@("`J($!P87)A;2`@;V)J96-T
M(%)E9F5R96YC92!O9B!T:&4@9G)O;G1E;F0@;V)J96-T#0H@("`@("H@0')E
M='5R;B!V;VED#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!S971&<F]N=&5N9$]B:F5C="@F)'5I*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/G5I(#T@)B1U:3L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!I;F9O1G)O;51G>D9I;&4H*0T*#0H@("`@+RHJ#0H@
M("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4@9FEL
M92X@($5X<&5C=',@=&AE(&YA;64@;V8-"B`@("`@*B!A(&=Z:7!P960@=&%R
M(&9I;&4@87,@:6YP=70N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D9FEL92`@;F%M92!O9B`N=&=Z(&9I;&4-"B`@("`@*@T*("`@("`J($!R
M971U<FX@87)R87D@(&%R<F%Y('=I=&@@<&%C:V%G92!I;F9O<FUA=&EO;@T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C
M871E9"!U<V4@4$5!4E]086-K86=E1FEL92T^9G)O;51G>D9I;&4H*2!I;G-T
M96%D#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;F9O1G)O;51G
M>D9I;&4H)&9I;&4I#0H@("`@>PT*("`@("`@("`D<&%C:V%G969I;&4@/2`F
M;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@
M("1P9B`]("8D<&%C:V%G969I;&4M/F9R;VU49WI&:6QE*"1F:6QE+"!014%2
M7U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1P9BDI('L-"B`@("`@("`@("`@("1E<G)S(#T@)'!F+3YG9715<V5R:6YF
M;R@I.PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G)S*2D@>PT*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1E<G)S(&%S("1E<G)O<BD@>PT*("`@
M("`@("`@("`@("`@("`@("`D92`]("1T:&ES+3YR86ES945R<F]R*"1E<G)O
M<ELG;65S<V%G92==+"`D97)R;W);)V-O9&4G72P@;G5L;"P@;G5L;"P@)&5R
M<F]R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!O<W10<F]C97-S5F%L:61086-K86=E>&UL*"1P9BD[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&EN9F]&<F]M1&5S8W)I
M<'1I;VY&:6QE*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;G,@:6YF;W)M
M871I;VX@86)O=70@82!P86-K86=E(&9I;&4N("!%>'!E8W1S('1H92!N86UE
M(&]F#0H@("`@("H@82!P86-K86=E('AM;"!F:6QE(&%S(&EN<'5T+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&1E<V-F:6QE("!N86UE(&]F
M('!A8VMA9V4@>&UL(&9I;&4-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R
M87D@(&%R<F%Y('=I=&@@<&%C:V%G92!I;F9O<FUA=&EO;@T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E9"!U<V4@
M4$5!4E]086-K86=E1FEL92T^9G)O;5!A8VMA9V5&:6QE*"D@:6YS=&5A9`T*
M("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YF;T9R;VU$97-C<FEP
M=&EO;D9I;&4H)&1E<V-F:6QE*0T*("`@('L-"B`@("`@("`@)'!A8VMA9V5F
M:6QE(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*
M("`@("`@("`D<&8@/2`F)'!A8VMA9V5F:6QE+3YF<F]M4&%C:V%G949I;&4H
M)&1E<V-F:6QE+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("1E<G)S(#T@
M)'!F+3YG9715<V5R:6YF;R@I.PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1E<G)S*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E<G)S(&%S
M("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@("`@("`D92`]("1T:&ES+3YR
M86ES945R<F]R*"1E<G)O<ELG;65S<V%G92==+"`D97)R;W);)V-O9&4G72P@
M;G5L;"P@;G5L;"P@)&5R<F]R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!O<W10<F]C97-S5F%L:61086-K
M86=E>&UL*"1P9BD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&EN9F]&<F]M4W1R:6YG*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;G,@
M:6YF;W)M871I;VX@86)O=70@82!P86-K86=E(&9I;&4N("!%>'!E8W1S('1H
M92!C;VYT96YT<PT*("`@("`J(&]F(&$@<&%C:V%G92!X;6P@9FEL92!A<R!I
M;G!U="X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@("1D871A("!C
M;VYT96YT<R!O9B!P86-K86=E+GAM;"!F:6QE#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("`@87)R87D@=VET:"!P86-K86=E(&EN9F]R;6%T:6]N
M#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!D97!R
M96-A=&5D('5S92!014%27U!A8VMA9V5&:6QE+3YF<F]M6&UL<W1R:6YG*"D@
M:6YS=&5A9`T*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YF;T9R
M;VU3=')I;F<H)&1A=&$I#0H@("`@>PT*("`@("`@("`D<&%C:V%G969I;&4@
M/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RD[#0H@("`@
M("`@("1P9B`]("8D<&%C:V%G969I;&4M/F9R;VU8;6Q3=')I;F<H)&1A=&$L
M(%!%05)?5D%,241!5$5?3D]234%,+"!F86QS92D[#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("1E<G)S(#T@)'!F
M+3YG9715<V5R:6YF;R@I.PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E
M<G)S*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E<G)S(&%S("1E
M<G)O<BD@>PT*("`@("`@("`@("`@("`@("`@("`D92`]("1T:&ES+3YR86ES
M945R<F]R*"1E<G)O<ELG;65S<V%G92==+"`D97)R;W);)V-O9&4G72P@;G5L
M;"P@;G5L;"P@)&5R<F]R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!O<W10<F]C97-S5F%L:61086-K86=E
M>&UL*"1P9BD[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?<&]S=%!R;V-E<W-686QI9%!A8VMA9V5X;6PH)B1P9BD-"B`@("![
M#0H@("`@("`@(&EF("AI<U]A*"1P9BP@)U!%05)?4&%C:V%G949I;&5?=C(G
M*2D@>PT*("`@("`@("`@("`@+R\@<V]R="!O9B!M86ME('1H:7,@:6YT;R!A
M('!A8VMA9V4N>&UL(#$N,"US='EL92!A<G)A>0T*("`@("`@("`@("`@+R\@
M8VAA;F=E;&]G(&ES(&YO="!C;VYV97)T960@=&\@;VQD(&9O<FUA="X-"B`@
M("`@("`@("`@("1A<G(@/2`D<&8M/G1O07)R87DH=')U92D[#0H@("`@("`@
M("`@("`D87)R(#T@87)R87E?;65R9V4H)&%R<BP@)&%R<ELG;VQD)UTI.PT*
M("`@("`@("`@("`@=6YS970H)&%R<ELG;VQD)UTI.PT*("`@("`@("`@("`@
M=6YS970H)&%R<ELG>'-D=F5R<VEO;B==*3L-"B`@("`@("`@("`@('5N<V5T
M*"1A<G);)V-O;G1E;G1S)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG
M8V]M<&%T:6)L92==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)V-H86YN
M96PG72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=U<FDG72D[#0H@("`@
M("`@("`@("!U;G-E="@D87)R6R=D97!E;F1E;F-I97,G72D[#0H@("`@("`@
M("`@("!U;G-E="@D87)R6R=P:'!R96QE87-E)UTI.PT*("`@("`@("`@("`@
M=6YS970H)&%R<ELG97AT<W)C<F5L96%S92==*3L-"B`@("`@("`@("`@('5N
M<V5T*"1A<G);)V5X=&)I;G)E;&5A<V4G72D[#0H@("`@("`@("`@("!U;G-E
M="@D87)R6R=B=6YD;&4G72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=L
M96%D)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG9&5V96QO<&5R)UTI
M.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG:&5L<&5R)UTI.PT*("`@("`@
M("`@("`@=6YS970H)&%R<ELG8V]N=')I8G5T;W(G72D[#0H@("`@("`@("`@
M("`D87)R6R=F:6QE;&ES="==(#T@)'!F+3YG971&:6QE;&ES="@I.PT*("`@
M("`@("`@("`@)'1H:7,M/G!K9VEN9F\@/2`D87)R.PT*("`@("`@("`@("`@
M<F5T=7)N("1A<G([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&AI<RT^<&MG:6YF;R`]("1P9BT^=&]!<G)A>2@I.PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YP:V=I;F9O.PT*("`@("`@("!]#0H@("`@?0T*("`@
M("\O('M[>R!I;F9O1G)O;4%N>2@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U
M<FYS('!A8VMA9V4@:6YF;W)M871I;VX@9G)O;2!D:69F97)E;G0@<V]U<F-E
M<PT*("`@("`J#0H@("`@("H@5&AI<R!M971H;V0@:7,@86)L92!T;R!E>'1R
M86-T(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G90T*("`@("`J(&9R;VT@
M82`N=&=Z(&%R8VAI=F4@;W(@9G)O;2!A(%A-3"!P86-K86=E(&1E9FEN:71I
M;VX@9FEL92X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("H@0'!A<F%M("!S=')I;F<@1FEL96YA;64@;V8@=&AE('-O=7)C92`H)W!A
M8VMA9V4N>&UL)RP@)SQP86-K86=E/BYT9WHG*0T*("`@("`J($!R971U<FX@
M<W1R:6YG#0H@("`@("H@0&1E<')E8V%T960@=7-E(%!%05)?4&%C:V%G949I
M;&4M/F9R;VU!;GE&:6QE*"D@:6YS=&5A9`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&EN9F]&<F]M06YY*"1I;F9O*0T*("`@('L-"B`@("`@("`@:68@*&ES
M7W-T<FEN9R@D:6YF;RD@)B8@9FEL95]E>&ES=',H)&EN9F\I*2![#0H@("`@
M("`@("`@("`D<&%C:V%G969I;&4@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H
M)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@("`@("`D<&8@/2`F)'!A8VMA9V5F
M:6QE+3YF<F]M06YY1FEL92@D:6YF;RP@4$5!4E]604Q)1$%415].3U)-04PI
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@
M("`@("`@("`@("`@("1E<G)S(#T@)'!F+3YG9715<V5R:6YF;R@I.PT*("`@
M("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R<RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&5R<G,@87,@)&5R<F]R*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D92`]("1T:&ES+3YR86ES945R<F]R*"1E
M<G)O<ELG;65S<V%G92==+"`D97)R;W);)V-O9&4G72P@;G5L;"P@;G5L;"P@
M)&5R<F]R*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&]S=%!R;V-E<W-6
M86QI9%!A8VMA9V5X;6PH)'!F*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)&EN9F\[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('AM
M;$9R;VU);F9O*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A;B!834P@
M9&]C=6UE;G0@8F%S960@;VX@=&AE('!A8VMA9V4@:6YF;R`H87,@<F5T=7)N
M960-"B`@("`@*B!B>2!T:&4@4$5!4E]#;VUM;VXZ.FEN9F]&<F]M*B!M971H
M;V1S*2X-"B`@("`@*@T*("`@("`J($!P87)A;2!A<G)A>2`@)'!K9VEN9F\@
M('!A8VMA9V4@:6YF;PT*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@
M6$U,(&1A=&$-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("H@0&1E<')E8V%T960@=7-E(&$@4$5!4E]086-K86=E1FEL95]V*B!O8FIE
M8W0G<R!G96YE<F%T;W(@:6YS=&5A9`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('AM;$9R;VU);F9O*"1P:V=I;F9O*0T*("`@('L-"B`@("`@("`@)&-O;F9I
M9R`]("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("1P86-K
M86=E9FEL92`]("9N97<@4$5!4E]086-K86=E1FEL92@D8V]N9FEG*3L-"B`@
M("`@("`@)'!F(#T@)B1P86-K86=E9FEL92T^9G)O;4%R<F%Y*"1P:V=I;F9O
M*3L-"B`@("`@("`@)&=E;B`]("8D<&8M/F=E=$1E9F%U;'1'96YE<F%T;W(H
M*3L-"B`@("`@("`@<F5T=7)N("1G96XM/G1O6&UL*%!%05)?5D%,241!5$5?
M4$%#2T%'24Y'*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M=F%L:61A=&5086-K86=E26YF;R@I#0H-"B`@("`O*BH-"B`@("`@*B!686QI
M9&%T92!834P@<&%C:V%G92!D969I;FET:6]N(&9I;&4N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@('-T<FEN9R`D:6YF;R!&:6QE;F%M92!O9B!T:&4@<&%C
M:V%G92!A<F-H:79E(&]R(&]F('1H90T*("`@("`J("`@("`@("`@("`@("`@
M('!A8VMA9V4@9&5F:6YI=&EO;B!F:6QE#0H@("`@("H@0'!A<F%M("!A<G)A
M>2`D97)R;W)S($%R<F%Y('1H870@=VEL;"!C;VYT86EN('1H92!E<G)O<G,-
M"B`@("`@*B!`<&%R86T@(&%R<F%Y("1W87)N:6YG<R!!<G)A>2!T:&%T('=I
M;&P@8V]N=&%I;B!T:&4@=V%R;FEN9W,-"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`D9&ER7W!R969I>"`H;W!T:6]N86PI(&1I<F5C=&]R>2!W:&5R92!S;W5R
M8V4@9FEL97,-"B`@("`@*B`@("`@("`@("`@("`@("!M87D@8F4@9F]U;F0L
M(&]R(&5M<'1Y(&EF('1H97D@87)E(&YO="!A=F%I;&%B;&4-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J
M($!D97!R96-A=&5D('5S92!T:&4@=F%L:61A=&EO;B!O9B!014%27U!A8VMA
M9V5&:6QE(&]B:F5C=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T
M95!A8VMA9V5);F9O*"1I;F9O+"`F)&5R<F]R<RP@)B1W87)N:6YG<RP@)&1I
M<E]P<F5F:7@@/2`G)RD-"B`@("![#0H@("`@("`@("1C;VYF:6<@/2`F4$5!
M4E]#;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("`D<&%C:V%G969I;&4@
M/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)&-O;F9I9RD[#0H@("`@("`@(%!%
M05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@:68@*'-T<G!O<R@D:6YF;RP@)SP_>&UL)RD@(3T](&9A
M;'-E*2![#0H@("`@("`@("`@("`D<&8@/2`F)'!A8VMA9V5F:6QE+3YF<F]M
M6&UL4W1R:6YG*"1I;F9O+"!014%27U9!3$E$051%7TY/4DU!3"P@)R<I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'!F(#T@)B1P86-K86=E
M9FEL92T^9G)O;4%N>49I;&4H)&EN9F\L(%!%05)?5D%,241!5$5?3D]234%,
M*3L-"B`@("`@("`@?0T*("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-
M"B`@("`@("`@("`@("1E<G)S(#T@)'!F+3YG9715<V5R:6YF;R@I.PT*("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G)S*2D@>PT*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1E<G)S(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=E<G)O<B<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`]("1E<G)O<ELG;65S
M<V%G92==.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'=A<FYI;F=S6UT@/2`D97)R;W);)VUE<W-A
M9V4G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@8G5I;&10<F]V:61E<T%R<F%Y*"D-"@T*
M("`@("\J*@T*("`@("`J($)U:6QD(&$@(G!R;W9I9&5S(B!A<G)A>2!F<F]M
M(&1A=&$@<F5T=7)N960@8GD-"B`@("`@*B!A;F%L>7IE4V]U<F-E0V]D92@I
M+B`@5&AE(&9O<FUA="!O9B!T:&4@8G5I;'0@87)R87D@:7,@;&EK90T*("`@
M("`J('1H:7,Z#0H@("`@("H-"B`@("`@*B`@87)R87DH#0H@("`@("H@("`@
M)V-L87-S.TUY0VQA<W,G(#T^("=A<G)A>2@G='EP92<@/3X@)V-L87-S)RP@
M)VYA;64G(#T^("=->4-L87-S)RDL#0H@("`@("H@("`@+BXN#0H@("`@("H@
M("D-"B`@("`@*@T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1S<F-I
M;F9O(&%R<F%Y('=I=&@@:6YF;W)M871I;VX@86)O=70@82!S;W5R8V4@9FEL
M90T*("`@("`J(&%S(')E='5R;F5D(&)Y('1H92!A;F%L>7IE4V]U<F-E0V]D
M92@I(&UE=&AO9"X-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&)U:6QD4')O=FED97-!<G)A>2@D<W)C:6YF;RD-"B`@
M("![#0H@("`@("`@("1F:6QE(#T@8F%S96YA;64H)'-R8VEN9F];)W-O=7)C
M95]F:6QE)UTI.PT*("`@("`@("`D<&X@/2`G)SL-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94YA;64I*2![#0H@("`@("`@("`@("`D<&X@
M/2`D=&AI<RT^7W!A8VMA9V5.86UE.PT*("`@("`@("!]#0H@("`@("`@("1P
M;FP@/2!S=')L96XH)'!N*3L-"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];
M)V1E8VQA<F5D7V-L87-S97,G72!A<R`D8VQA<W,I('L-"B`@("`@("`@("`@
M("1K97D@/2`B8VQA<W,[)&-L87-S(CL-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LD:V5Y72DI('L-"B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1T:&ES+3YP:V=I;F9O6R=P<F]V:61E<R==6R1K97E=(#T-"B`@("`@
M("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G(#T^("=C
M;&%S<R<L("=N86UE)R`]/B`D8VQA<W,I.PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1S<F-I;F9O6R=I;FAE<FET86YC92==6R1C;&%S<UTI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;)&ME>5U;
M)V5X=&5N9',G72`]#0H@("`@("`@("`@("`@("`@("`@("1S<F-I;F9O6R=I
M;FAE<FET86YC92==6R1C;&%S<UT[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];)V1E8VQA<F5D7VUE=&AO
M9',G72!A<R`D8VQA<W,@/3X@)&UE=&AO9',I('L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1M971H;V1S(&%S("1M971H;V0I('L-"B`@("`@("`@("`@("`@
M("`D9G5N8W1I;VX@/2`B)&-L87-S.CHD;65T:&]D(CL-"B`@("`@("`@("`@
M("`@("`D:V5Y(#T@(F9U;F-T:6]N.R1F=6YC=&EO;B([#0H@("`@("`@("`@
M("`@("`@:68@*"1M971H;V1[,'T@/3T@)U\G('Q\("%S=')C87-E8VUP*"1M
M971H;V0L("1C;&%S<RD@?'P-"B`@("`@("`@("`@("`@("`@("`@:7-S970H
M)'1H:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LD:V5Y
M72`]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE
M+"`G='EP92<@/3X@)V9U;F-T:6]N)RP@)VYA;64G(#T^("1F=6YC=&EO;BD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!F;W)E86-H
M("@D<W)C:6YF;ULG9&5C;&%R961?9G5N8W1I;VYS)UT@87,@)&9U;F-T:6]N
M*2![#0H@("`@("`@("`@("`D:V5Y(#T@(F9U;F-T:6]N.R1F=6YC=&EO;B([
M#0H@("`@("`@("`@("!I9B`H)&9U;F-T:6]N>S!](#T]("=?)R!\?"!I<W-E
M="@D=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LD:V5Y72DI('L-"B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@A<W1R<W1R*"1F=6YC=&EO;BP@)SHZ)RD@)B8@<W1R;F-A<V5C
M;7`H)&9U;F-T:6]N+"`D<&XL("1P;FPI*2![#0H@("`@("`@("`@("`@("`@
M)'=A<FYI;F=S6UT@/2`B:6XQ("(@+B`D9FEL92`N("(Z(&9U;F-T:6]N(%PB
M)&9U;F-T:6]N7"(@;F]T('!R969I>&5D('=I=&@@<&%C:V%G92!N86UE(%PB
M)'!N7"(B.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/G!K
M9VEN9F];)W!R;W9I9&5S)UU;)&ME>5T@/0T*("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:6QE)ST^("1F:6QE+"`G='EP92<@/3X@)V9U;F-T:6]N)RP@)VYA
M;64G(#T^("1F=6YC=&EO;BD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@86YA;'EZ95-O=7)C94-O9&4H*0T*#0H@("`@
M+RHJ#0H@("`@("H@06YA;'EZ92!T:&4@<V]U<F-E(&-O9&4@;V8@=&AE(&=I
M=F5N(%!(4"!F:6QE#0H@("`@("H-"B`@("`@*B!`<&%R86T@('-T<FEN9R!&
M:6QE;F%M92!O9B!T:&4@4$A0(&9I;&4-"B`@("`@*B!`<F5T=7)N(&UI>&5D
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!A;F%L>7IE4V]U<F-E0V]D92@D9FEL92D-"B`@("![#0H@("`@("`@(&EF
M("@A9G5N8W1I;VY?97AI<W1S*")T;VME;E]G971?86QL(BDI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(61E9FEN960H)U1?1$]#7T-/34U%3E0G*2D@>PT*("`@("`@("`@("`@9&5F
M:6YE*"=47T1/0U]#3TU-14Y4)RP@5%]#3TU-14Y4*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(61E9FEN960H)U1?24Y415)&04-%)RDI('L-"B`@("`@
M("`@("`@(&1E9FEN92@G5%])3E1%4D9!0T4G+"`M,2D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%D969I;F5D*"=47TE-4$Q%345.5%,G*2D@>PT*("`@
M("`@("`@("`@9&5F:6YE*"=47TE-4$Q%345.5%,G+"`M,2D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D9G`@/2!`9F]P96XH)&9I;&4L(")R(BDI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![
M#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1C;VYT
M96YT<R`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1C;VYT96YT<R`](&9R96%D*"1F<"P@9FEL
M97-I>F4H)&9I;&4I*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@
M("`@("!]#0H@("`@("`@("1T;VME;G,@/2!T;VME;E]G971?86QL*"1C;VYT
M96YT<RD[#0HO*@T*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)'1O:V5N<RD[("1I*RLI('L-"B`@("`@("`@("`@($!L:7-T*"1T;VME;BP@
M)&1A=&$I(#T@)'1O:V5N<ULD:5T[#0H@("`@("`@("`@("!I9B`H:7-?<W1R
M:6YG*"1T;VME;BDI('L-"B`@("`@("`@("`@("`@("!V87)?9'5M<"@D=&]K
M96XI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!P
M<FEN="!T;VME;E]N86UE*"1T;VME;BD@+B`G("<[#0H@("`@("`@("`@("`@
M("`@=F%R7V1U;7`H<G1R:6TH)&1A=&$I*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T**B\-"B`@("`@("`@)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@
M)'!A<F5N7VQE=F5L(#T@,#L-"B`@("`@("`@)&)R86-K971?;&5V96P@/2`P
M.PT*("`@("`@("`D8G)A8V5?;&5V96P@/2`P.PT*("`@("`@("`D;&%S='!H
M<&1O8R`]("<G.PT*("`@("`@("`D8W5R<F5N=%]C;&%S<R`]("<G.PT*("`@
M("`@("`D8W5R<F5N=%]I;G1E<F9A8V4@/2`G)SL-"B`@("`@("`@)&-U<G)E
M;G1?8VQA<W-?;&5V96P@/2`M,3L-"B`@("`@("`@)&-U<G)E;G1?9G5N8W1I
M;VX@/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M
M,3L-"B`@("`@("`@)&1E8VQA<F5D7V-L87-S97,@/2!A<G)A>2@I.PT*("`@
M("`@("`D9&5C;&%R961?:6YT97)F86-E<R`](&%R<F%Y*"D[#0H@("`@("`@
M("1D96-L87)E9%]F=6YC=&EO;G,@/2!A<G)A>2@I.PT*("`@("`@("`D9&5C
M;&%R961?;65T:&]D<R`](&%R<F%Y*"D[#0H@("`@("`@("1U<V5D7V-L87-S
M97,@/2!A<G)A>2@I.PT*("`@("`@("`D=7-E9%]F=6YC=&EO;G,@/2!A<G)A
M>2@I.PT*("`@("`@("`D97AT96YD<R`](&%R<F%Y*"D[#0H@("`@("`@("1I
M;7!L96UE;G1S(#T@87)R87DH*3L-"B`@("`@("`@)&YO9&5P<R`](&%R<F%Y
M*"D[#0H@("`@("`@("1I;G%U;W1E(#T@9F%L<V4[#0H@("`@("`@("1I;G1E
M<F9A8V4@/2!F86QS93L-"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ
M96]F*"1T;VME;G,I.R`D:2LK*2![#0H@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'1O:V5N<ULD:5TI*2![#0H@("`@("`@("`@("`@("`@;&ES="@D=&]K
M96XL("1D871A*2`]("1T;VME;G-;)&E=.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D=&]K96X@/2`D=&]K96YS6R1I73L-"B`@
M("`@("`@("`@("`@("`D9&%T82`]("<G.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"1I;G%U;W1E*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1T;VME;B`A/2`G(B<I('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&EN<75O=&4@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@<W=I=&-H("@D=&]K96XI('L-"B`@("`@("`@("`@("`@
M("!C87-E(%1?5TA)5$534$%#13H-"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("`@("`@8V%S92`G.R<Z#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D:6YT97)F86-E*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!C87-E("<B)SH-"B`@("`@("`@("`@("`@
M("`@("`@)&EN<75O=&4@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E(%1?0U523%E?3U!%3CH-"B`@
M("`@("`@("`@("`@("!C87-E(%1?1$],3$%27T]014Y?0U523%E?0E)!0T53
M.@T*("`@("`@("`@("`@("`@(&-A<V4@)WLG.B`D8G)A8V5?;&5V96PK*SL@
M8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("=])SH-"B`@("`@
M("`@("`@("`@("`@("`@)&)R86-E7VQE=F5L+2T[#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D8W5R<F5N=%]C;&%S<U]L979E;"`]/2`D8G)A8V5?;&5V
M96PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S
M(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S
M<U]L979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]/2`D
M8G)A8V5?;&5V96PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R
M96YT7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@
M("`@("`@("`@("`@8V%S92`G6R<Z("1B<F%C:V5T7VQE=F5L*RL[(&-O;G1I
M;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G72<Z("1B<F%C:V5T7VQE
M=F5L+2T[(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G*"<Z
M("1P87)E;E]L979E;"LK.R`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@
M("`@8V%S92`G*2<Z("1P87)E;E]L979E;"TM.R`@(&-O;G1I;G5E(#([#0H@
M("`@("`@("`@("`@("`@8V%S92!47TE.5$521D%#13H-"B`@("`@("`@("`@
M("`@("`@("`@)&EN=&5R9F%C92`]('1R=64[#0H@("`@("`@("`@("`@("`@
M8V%S92!47T-,05-3.@T*("`@("`@("`@("`@("`@("`@("!I9B`H*"1C=7)R
M96YT7V-L87-S7VQE=F5L("$]("TQ*2!\?"`H)&-U<G)E;G1?9G5N8W1I;VY?
M;&5V96P@(3T@+3$I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!014%2
M.CIR86ES945R<F]R*")087)S97(@97)R;W(Z(&EN=F%L:60@4$A0(&9O=6YD
M(&EN(&9I;&4@7"(D9FEL95PB(BP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!014%27T-/34U/3E]%4E)/4E])3E9!3$E$4$A0*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&-A<V4@5%]&54Y#5$E/3CH-"B`@
M("`@("`@("`@("`@("!C87-E(%1?3D57.@T*("`@("`@("`@("`@("`@(&-A
M<V4@5%]%6%1%3D13.@T*("`@("`@("`@("`@("`@(&-A<V4@5%])35!,14U%
M3E13.@T*("`@("`@("`@("`@("`@("`@("`D;&]O:U]F;W(@/2`D=&]K96X[
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("`@("`@8V%S92!47U-44DE.1SH-"B`@("`@("`@("`@("`@("`@("`@:68@
M*'9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@)S(N,"<L("<\)RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2AS=')T
M;VQO=V5R*"1D871A*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<'5B;&EC)RP@)W!R:79A=&4G+"`G<')O=&5C=&5D)RP@)V%B<W1R
M86-T)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6YT
M97)F86-E)RP@)VEM<&QE;65N=',G+"`G=&AR;W<G*2`-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%2.CIR86ES945R<F]R*"=%<G)O<CH@4$A0-2!T;VME
M;B!E;F-O=6YT97)E9"!I;B`G("X@)&9I;&4@+B`-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%C:V%G:6YG('-H;W5L9"!B92!D;VYE(&EN(%!(
M4"`U)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;&]O:U]F;W(@
M/3T@5%]#3$%34RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?8VQA<W,@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C
M=7)R96YT7V-L87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E8VQA<F5D7V-L87-S97-;72`]("1C=7)R96YT
M7V-L87-S.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?
M9F]R(#T](%1?24Y415)&04-%*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D8W5R<F5N=%]I;G1E<F9A8V4@/2`D9&%T83L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1C=7)R96YT7V-L87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C
M97-;72`]("1C=7)R96YT7VEN=&5R9F%C93L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47TE-4$Q%345.5%,I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;7!L96UE;G1S6R1C=7)R96YT7V-L
M87-S72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)&QO;VM?9F]R(#T](%1?15A414Y$4RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&5X=&5N9'-;)&-U<G)E;G1?8VQA<W-=(#T@)&1A=&$[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%]&54Y#
M5$E/3BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT
M7V-L87-S*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?9G5N8W1I;VX@/2`B)&-U<G)E;G1?8VQA<W,Z.B1D871A(CL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?;65T:&]D<ULD8W5R
M<F5N=%]C;&%S<UU;72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"1C=7)R96YT7VEN=&5R9F%C92D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@(B1C=7)R
M96YT7VEN=&5R9F%C93HZ)&1A=&$B.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D96-L87)E9%]M971H;V1S6R1C=7)R96YT7VEN=&5R9F%C95U;
M72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO
M;B`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D96-L
M87)E9%]F=6YC=&EO;G-;72`]("1C=7)R96YT7V9U;F-T:6]N.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D;2`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%].15<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1U<V5D7V-L87-S97-;)&1A=&%=(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`D;&]O:U]F;W(@/2`P.PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]605))04),13H-"B`@
M("`@("`@("`@("`@("`@("`@)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?
M1$]#7T-/34U%3E0Z#0H@("`@("`@("`@("`@("`@8V%S92!47T-/34U%3E0Z
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<A7B]<*EPJ
M7',A)RP@)&1A=&$I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%S
M='!H<&1O8R`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8VA?86QL*"<O0&YO9&5P7',K*%Q3*RDO)RP@)&QA<W1P:'!D
M;V,L("1M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V1E
M<',@/2!A<G)A>5]M97)G92@D;F]D97!S+"`D;5LQ72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C
M87-E(%1?1$]50DQ%7T-/3$]..@T*("`@("`@("`@("`@("`@("`@("!I9B`H
M(2@D=&]K96YS6R1I("T@,5U;,%T@/3T@5%]72$E415-004-%('Q\("1T;VME
M;G-;)&D@+2`Q75LP72`]/2!47U-44DE.1RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(E!A<G-E<B!E<G)O<CH@:6YV
M86QI9"!02%`@9F]U;F0@:6X@9FEL92!<(B1F:6QE7"(B+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05)?0T]-34].7T524D]27TE.5D%,2410
M2%`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1C
M;&%S<R`]("1T;VME;G-;)&D@+2`Q75LQ73L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*'-T<G1O;&]W97(H)&-L87-S*2`A/2`G<&%R96YT)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'5S961?8VQA<W-E<ULD8VQA<W-=(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@(")S;W5R8V5?9FEL
M92(@/3X@)&9I;&4L#0H@("`@("`@("`@("`B9&5C;&%R961?8VQA<W-E<R(@
M/3X@)&1E8VQA<F5D7V-L87-S97,L#0H@("`@("`@("`@("`B9&5C;&%R961?
M:6YT97)F86-E<R(@/3X@)&1E8VQA<F5D7VEN=&5R9F%C97,L#0H@("`@("`@
M("`@("`B9&5C;&%R961?;65T:&]D<R(@/3X@)&1E8VQA<F5D7VUE=&AO9',L
M#0H@("`@("`@("`@("`B9&5C;&%R961?9G5N8W1I;VYS(B`]/B`D9&5C;&%R
M961?9G5N8W1I;VYS+`T*("`@("`@("`@("`@(G5S961?8VQA<W-E<R(@/3X@
M87)R87E?9&EF9BAA<G)A>5]K97ES*"1U<V5D7V-L87-S97,I+"`D;F]D97!S
M*2P-"B`@("`@("`@("`@(")I;FAE<FET86YC92(@/3X@)&5X=&5N9',L#0H@
M("`@("`@("`@("`B:6UP;&5M96YT<R(@/3X@)&EM<&QE;65N=',L#0H@("`@
M("`@("`@("`I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R`@
M8F5T=&5R4W1A=&5S*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A;B!A
M<G)A>2!C;VYT86EN:6YG(&%L;"!O9B!T:&4@<W1A=&5S('1H870@87)E(&UO
M<F4@<W1A8FQE('1H86X-"B`@("`@*B!O<B!E<75A;"!T;R!T:&4@<&%S<V5D
M(&EN('-T871E#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(%)E;&5A
M<V4@<W1A=&4-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!$971E<FUI;F5S('=H
M971H97(@=&\@:6YC;'5D92`D<W1A=&4@:6X@=&AE(&QI<W0-"B`@("`@*B!`
M<F5T=7)N(&9A;'-E?&%R<F%Y($9A;'-E(&EF("1S=&%T92!I<R!N;W0@82!V
M86QI9"!R96QE87-E('-T871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8F5T
M=&5R4W1A=&5S*"1S=&%T92P@)&EN8VQU9&4@/2!F86QS92D-"B`@("![#0H@
M("`@("`@('-T871I8R`D<W1A=&5S(#T@87)R87DH)W-N87!S:&]T)RP@)V1E
M=F5L)RP@)V%L<&AA)RP@)V)E=&$G+"`G<W1A8FQE)RD[#0H@("`@("`@("1I
M(#T@87)R87E?<V5A<F-H*"1S=&%T92P@)'-T871E<RD[#0H@("`@("`@(&EF
M("@D:2`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&EN8VQU9&4I('L-"B`@("`@("`@
M("`@("1I+2T[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y7W-L
M:6-E*"1S=&%T97,L("1I("L@,2D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&1E=&5C=$1E<&5N9&5N8VEE<R@I#0H-"B`@("!F=6YC=&EO
M;B!D971E8W1$97!E;F1E;F-I97,H)&%N>2P@)'-T871U<U]C86QL8F%C:R`]
M(&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@B
M=&]K96Y?9V5T7V%L;"(I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\@
M/2`D=&AI<RT^:6YF;T9R;VU!;GDH)&%N>2DI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:7-?87)R87DH)&EN9F\I*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&1E<',@/2!A<G)A
M>2@I.PT*("`@("`@("`D=7-E9%]C(#T@)&1E8VQ?8R`]("1D96-L7V8@/2`D
M9&5C;%]M(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&EN9F];)V9I
M;&5L:7-T)UT@87,@)&9I;&4@/3X@)&9A*2![#0H@("`@("`@("`@("`D=&UP
M(#T@)'1H:7,M/F%N86QY>F53;W5R8V5#;V1E*"1F:6QE*3L-"B`@("`@("`@
M("`@("1U<V5D7V,@/2!`87)R87E?;65R9V4H)'5S961?8RP@)'1M<%LG=7-E
M9%]C;&%S<V5S)UTI.PT*("`@("`@("`@("`@)&1E8VQ?8R`]($!A<G)A>5]M
M97)G92@D9&5C;%]C+"`D=&UP6R=D96-L87)E9%]C;&%S<V5S)UTI.PT*("`@
M("`@("`@("`@)&1E8VQ?9B`]($!A<G)A>5]M97)G92@D9&5C;%]F+"`D=&UP
M6R=D96-L87)E9%]F=6YC=&EO;G,G72D[#0H@("`@("`@("`@("`D9&5C;%]M
M(#T@0&%R<F%Y7VUE<F=E*"1D96-L7VTL("1T;7!;)V1E8VQA<F5D7VUE=&AO
M9',G72D[#0H@("`@("`@("`@("`D:6YH97)I(#T@0&%R<F%Y7VUE<F=E*"1I
M;FAE<FDL("1T;7!;)VEN:&5R:71A;F-E)UTI.PT*("`@("`@("!]#0H@("`@
M("`@("1U<V5D7V,@/2!A<G)A>5]U;FEQ=64H)'5S961?8RD[#0H@("`@("`@
M("1D96-L7V,@/2!A<G)A>5]U;FEQ=64H)&1E8VQ?8RD[#0H@("`@("`@("1U
M;F1E8VQ?8R`](&%R<F%Y7V1I9F8H)'5S961?8RP@)&1E8VQ?8RD[#0H@("`@
M("`@(')E='5R;B!A<G)A>2@G=7-E9%]C;&%S<V5S)R`]/B`D=7-E9%]C+`T*
M("`@("`@("`@("`@("`@("`@("`@)V1E8VQA<F5D7V-L87-S97,G(#T^("1D
M96-L7V,L#0H@("`@("`@("`@("`@("`@("`@("`G9&5C;&%R961?;65T:&]D
M<R<@/3X@)&1E8VQ?;2P-"B`@("`@("`@("`@("`@("`@("`@("=D96-L87)E
M9%]F=6YC=&EO;G,G(#T^("1D96-L7V8L#0H@("`@("`@("`@("`@("`@("`@
M("`G=6YD96-L87)E9%]C;&%S<V5S)R`]/B`D=6YD96-L7V,L#0H@("`@("`@
M("`@("`@("`@("`@("`G:6YH97)I=&%N8V4G(#T^("1I;FAE<FDL#0H@("`@
M("`@("`@("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!G9715<V5R4F]L97,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M('1H92!V86QI9"!R;VQE<R!F;W(@82!014%2('!A8VMA9V4@;6%I;G1A:6YE
M<@T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9715<V5R4F]L97,H*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VUM;VY?;6%I
M;G1A:6YE<E]R;VQE<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971296QE87-E4W1A=&5S*"D-"@T*("`@("\J*@T*("`@("`J($=E
M="!T:&4@=F%L:60@<&%C:V%G92!R96QE87-E('-T871E<R!O9B!P86-K86=E
M<PT*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971296QE87-E4W1A=&5S*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N
M7W)E;&5A<V5?<W1A=&5S)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&=E=$1E<&5N9&5N8WE4>7!E<R@I#0H-"B`@("`O*BH-"B`@("`@
M*B!'970@=&AE(&EM<&QE;65N=&5D(&1E<&5N9&5N8WD@='EP97,@*'!H<"P@
M97AT+"!P:V<@971C+BD-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87D-
M"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5P
M96YD96YC>51Y<&5S*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG7U!%05)?0V]M;6]N7V1E<&5N9&5N8WE?='EP97,G73L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1&5P96YD96YC>5)E;&%T:6]N
M<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&EM<&QE;65N=&5D(&1E
M<&5N9&5N8WD@<F5L871I;VYS("AH87,L(&QT+"!G92!E=&,N*0T*("`@("`J
M#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971$97!E;F1E;F-Y4F5L871I;VYS*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7V1E
M<&5N9&5N8WE?<F5L871I;VYS)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=$9I;&52;VQE<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'
M970@=&AE(&EM<&QE;65N=&5D(&9I;&4@<F]L97,-"B`@("`@*@T*("`@("`J
M($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T1FEL95)O;&5S*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7V9I;&5?<F]L97,G73L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T4F5P;&%C96UE;G14>7!E
M<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&EM<&QE;65N=&5D(&9I
M;&4@<F5P;&%C96UE;G0@='EP97,@:6X-"B`@("`@*@T*("`@("`J($!R971U
M<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T4F5P;&%C96UE;G14>7!E<R@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]R97!L86-E;65N=%]T>7!E<R==
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G9710<F]V:61E
M5'EP97,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!I;7!L96UE;G1E
M9"!F:6QE(')E<&QA8V5M96YT('1Y<&5S(&EN#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=%!R;W9I9&54>7!E<R@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]P<F]V:61E7W1Y<&5S)UT[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=%-C<FEP=%!H87-E
M<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&EM<&QE;65N=&5D(&9I
M;&4@<F5P;&%C96UE;G0@='EP97,@:6X-"B`@("`@*@T*("`@("`J($!R971U
M<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T4V-R:7!T4&AA<V5S*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D
M1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W-C<FEP=%]P:&%S97,G73L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=F%L:61086-K86=E3F%M92@I
M#0H-"B`@("`O*BH-"B`@("`@*B!497-T('=H971H97(@82!S=')I;F<@8V]N
M=&%I;G,@82!V86QI9"!P86-K86=E(&YA;64N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE('1H92!P86-K86=E(&YA;64@=&\@=&5S=`T*
M("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED4&%C
M:V%G94YA;64H)&YA;64I#0H@("`@>PT*("`@("`@("!R971U<FX@*&)O;VPI
M<')E9U]M871C:"A014%27T-/34U/3E]004-+04=%7TY!345?4%)%1RP@)&YA
M;64I.PT*("`@('T-"@T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('9A;&ED
M4&%C:V%G959E<G-I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@5&5S="!W:&5T
M:&5R(&$@<W1R:6YG(&-O;G1A:6YS(&$@=F%L:60@<&%C:V%G92!V97)S:6]N
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=F5R('1H92!P86-K
M86=E('9E<G-I;VX@=&\@=&5S=`T*("`@("`J#0H@("`@("H@0')E='5R;B!B
M;V]L#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('9A;&ED4&%C:V%G959E<G-I;VXH)'9E<BD-"B`@("![
M#0H@("`@("`@(')E='5R;B`H8F]O;"EP<F5G7VUA=&-H*%!%05)?0T]-34].
M7U!!0TM!1T5?5D524TE/3E]04D5'+"`D=F5R*3L-"B`@("!]#0H-"@T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(&1O=VYL;V%D2'1T<"@I#0H-"B`@("`O
M*BH-"B`@("`@*B!$;W=N;&]A9"!A(&9I;&4@=&AR;W5G:"!(5%10+B`@0V]N
M<VED97)S('-U9V=E<W1E9"!F:6QE(&YA;64@:6X-"B`@("`@*B!#;VYT96YT
M+61I<W!O<VET:6]N.B!H96%D97(@86YD(&-A;B!R=6X@82!C86QL8F%C:R!F
M=6YC=&EO;B!F;W(-"B`@("`@*B!D:69F97)E;G0@979E;G1S+B`@5&AE(&-A
M;&QB86-K('=I;&P@8F4@8V%L;&5D('=I=&@@='=O#0H@("`@("H@<&%R86UE
M=&5R<SH@=&AE(&-A;&QB86-K('1Y<&4L(&%N9"!P87)A;65T97)S+B`@5&AE
M(&EM<&QE;65N=&5D#0H@("`@("H@8V%L;&)A8VL@='EP97,@87)E.@T*("`@
M("`J#0H@("`@("H@("=S971U<"<@("`@("`@8V%L;&5D(&%T('1H92!V97)Y
M(&)E9VEN;FEN9RP@<&%R86UE=&5R(&ES(&$@54D@;V)J96-T#0H@("`@("H@
M("`@("`@("`@("`@("`@=&AA="!S:&]U;&0@8F4@=7-E9"!F;W(@86QL(&]U
M='!U=`T*("`@("`J("`G;65S<V%G92<@("`@('1H92!P87)A;65T97(@:7,@
M82!S=')I;F<@=VET:"!A;B!I;F9O<FUA=&EO;F%L(&UE<W-A9V4-"B`@("`@
M*B`@)W-A=F5A<R<@("`@("!M87D@8F4@=7-E9"!T;R!S879E('=I=&@@82!D
M:69F97)E;G0@9FEL92!N86UE+"!T:&4-"B`@("`@*B`@("`@("`@("`@("`@
M("!P87)A;65T97(@:7,@=&AE(&9I;&5N86UE('1H870@:7,@86)O=70@=&\@
M8F4@=7-E9"X-"B`@("`@*B`@("`@("`@("`@("`@("!)9B!A("=S879E87,G
M(&-A;&QB86-K(')E='5R;G,@82!N;VXM96UP='D@<W1R:6YG+`T*("`@("`J
M("`@("`@("`@("`@("`@('1H870@9FEL92!N86UE('=I;&P@8F4@=7-E9"!A
M<R!T:&4@9FEL96YA;64@:6YS=&5A9"X-"B`@("`@*B`@("`@("`@("`@("`@
M("!.;W1E('1H870@)'-A=F5?9&ER('=I;&P@;F]T(&)E(&%F9F5C=&5D(&)Y
M('1H:7,L(&]N;'D-"B`@("`@*B`@("`@("`@("`@("`@("!T:&4@8F%S96YA
M;64@;V8@=&AE(&9I;&4N#0H@("`@("H@("=S=&%R="<@("`@("`@9&]W;FQO
M860@:7,@<W1A<G1I;F<L('!A<F%M971E<B!I<R!N=6UB97(@;V8@8GET97,-
M"B`@("`@*B`@("`@("`@("`@("`@("!T:&%T(&%R92!E>'!E8W1E9"P@;W(@
M+3$@:68@=6YK;F]W;@T*("`@("`J("`G8GET97-R96%D)R`@('!A<F%M971E
M<B!I<R!T:&4@;G5M8F5R(&]F(&)Y=&5S(')E860@<V\@9F%R#0H@("`@("H@
M("=D;VYE)R`@("`@("`@9&]W;FQO860@:7,@8V]M<&QE=&4L('!A<F%M971E
M<B!I<R!T:&4@=&]T86P@;G5M8F5R#0H@("`@("H@("`@("`@("`@("`@("`@
M;V8@8GET97,@<F5A9`T*("`@("`J("`G8V]N;F9A:6QE9"<@(&EF('1H92!4
M0U`@8V]N;F5C=&EO;B!F86EL<RP@=&AI<R!C86QL8F%C:R!I<R!C86QL960-
M"B`@("`@*B`@("`@("`@("`@("`@("!W:71H(&%R<F%Y*&AO<W0L<&]R="QE
M<G)N;RQE<G)M<V<I#0H@("`@("H@("=W<FET969A:6QE9"<@:68@=W)I=&EN
M9R!T;R!D:7-K(&9A:6QS+"!T:&ES(&-A;&QB86-K(&ES(&-A;&QE9`T*("`@
M("`J("`@("`@("`@("`@("`@('=I=&@@87)R87DH9&5S=&9I;&4L97)R;7-G
M*0T*("`@("`J#0H@("`@("H@268@86X@2%144"!P<F]X>2!H87,@8F5E;B!C
M;VYF:6=U<F5D("AH='1P7W!R;WAY(%!%05)?0V]N9FEG#0H@("`@("H@<V5T
M=&EN9RDL('1H92!P<F]X>2!W:6QL(&)E('5S960N#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D=7)L("`@("`@('1H92!54DP@=&\@9&]W;FQO
M860-"B`@("`@*B!`<&%R86T@;V)J96-T("`D=6D@("`@("`@(%!%05)?1G)O
M;G1E;F1?*B!I;G-T86YC90T*("`@("`J($!P87)A;2!O8FIE8W0@("1C;VYF
M:6<@("`@4$5!4E]#;VYF:6<@:6YS=&%N8V4-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<V%V95]D:7(@("AO<'1I;VYA;"D@9&ER96-T;W)Y('1O('-A=F4@
M9FEL92!I;@T*("`@("`J($!P87)A;2!M:7AE9"`@("1C86QL8F%C:R`@*&]P
M=&EO;F%L*2!F=6YC=&EO;B]M971H;V0@=&\@8V%L;"!F;W(@<W1A='5S#0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!U<&1A=&5S#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4F5T=7)N<R!T:&4@9G5L;"!P
M871H(&]F('1H92!D;W=N;&]A9&5D(&9I;&4@;W(@82!014%2#0H@("`@("H@
M("`@("`@("`@("`@("`@(&5R<F]R(&]N(&9A:6QU<F4N("!)9B!T:&4@97)R
M;W(@:7,@8V%U<V5D(&)Y#0H@("`@("H@("`@("`@("`@("`@("`@('-O8VME
M="UR96QA=&5D(&5R<F]R<RP@=&AE(&5R<F]R(&]B:F5C="!W:6QL#0H@("`@
M("H@("`@("`@("`@("`@("`@(&AA=F4@=&AE(&9S;V-K;W!E;B!E<G)O<B!C
M;V1E(&%V86EL86)L92!T:')O=6=H#0H@("`@("H@("`@("`@("`@("`@("`@
M(&=E=$-O9&4H*2X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("H@0&1E<')E8V%T960@:6X@9F%V;W(@;V8@4$5!4E]$;W=N;&]A9&5R
M.CID;W=N;&]A9$AT='`H*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&1O=VYL
M;V%D2'1T<"@D=7)L+"`F)'5I+"`D<V%V95]D:7(@/2`G+B<L("1C86QL8F%C
M:R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]$;W=N;&]A9&5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G4$5!4B]$;W=N;&]A9&5R+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(%!%05)?1&]W;FQO861E<CHZ9&]W;FQO861(='1P*"1U<FPL("1U
M:2P@)'-A=F5?9&ER+"`D8V%L;&)A8VLI.PT*("`@('T-"@T*("`@("\O('U]
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"!R96QA
M=&EV92!O<B!A8G-O;'5T92!I;F-L=61E('!A=&@-"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@:7-);F-L=61E86)L92@D<&%T:"D-"B`@("![#0H@("`@("`@(&EF("AF
M:6QE7V5X:7-T<R@D<&%T:"D@)B8@:7-?<F5A9&%B;&4H)'!A=&@I*2![#0H@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D
M:7!A=&@@/2!E>'!L;V1E*%!!5$A?4T5005)!5$]2+"!I;FE?9V5T*"=I;F-L
M=61E7W!A=&@G*2D[#0H@("`@("`@(&9O<F5A8V@@*"1I<&%T:"!A<R`D:6YC
M;'5D92D@>PT*("`@("`@("`@("`@)'1E<W0@/2!R96%L<&%T:"@D:6YC;'5D
M92`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&%T:"D[#0H@("`@("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)'1E<W0I("8F(&ES7W)E861A8FQE*"1T97-T
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0I]#0IR97%U:7)E7V]N8V4@)U!%05(O0V]N9FEG+G!H<"<[#0IR97%U:7)E
M7V]N8V4@)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"C\^````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O0V]N9FEG+G!H<```````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,C`W,S<S`#$P-3$U-#,Q,#4W`#`R,#`R,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!014%27T-O;F9I9RP@8W5S=&]M:7IE9"!C;VYF:6=U<F%T
M:6]N(&AA;F1L:6YG(&9O<B!T:&4@4$5!4B!);G-T86QL97(-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0V]N9FEG+G!H<"QV(#$N,3(T
M(#(P,#8O,#,O,#(@,3@Z,30Z,3(@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M+PT*#0HO*BH-"B`J(%)E<75I<F5D(&9O<B!E<G)O<B!H86YD;&EN9PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!
M4B]296=I<W1R>2YP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+TEN<W1A;&QE
M<B]2;VQE+G!H<"<[#0IR97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*<F5Q
M=6ER95]O;F-E("=014%2+U)E;6]T92YP:'`G.PT*#0HO*BH-"B`J($QA<W0@
M8W)E871E9"!014%27T-O;F9I9R!I;G-T86YC92X-"B`J($!V87(@;V)J96-T
M#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N8V4G72`](&YU
M;&P[#0II9B`H(61E9FEN960H)U!%05)?24Y35$%,3%]$25(G*2!\?"`A4$5!
M4E])3E-404Q,7T1)4BD@>PT*("`@("1014%27TE.4U1!3$Q?1$E2(#T@4$A0
M7TQ)0D1)4B`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&5A<B<[#0I](&5L
M<V4@>PT*("`@("1014%27TE.4U1!3$Q?1$E2(#T@4$5!4E])3E-404Q,7T1)
M4CL-"GT-"@T*+R\@0F5L;W<@=V4@9&5F:6YE(&-O;G-T86YT<R!W:71H(&1E
M9F%U;'0@=F%L=65S(&9O<B!A;&P@8V]N9FEG=7)A=&EO;@T*+R\@<&%R86UE
M=&5R<R!E>&-E<'0@=7-E<FYA;64O<&%S<W=O<F0N("!!;&P@;V8@=&AE;2!C
M86X@:&%V92!T:&5I<@T*+R\@9&5F875L=',@<V5T('1H<F]U9V@@96YV:7)O
M;FUE;G0@=F%R:6%B;&5S+B`@5&AE(')E87-O;B!W92!U<V4@=&AE#0HO+R!0
M2%!?('!R969I>"!I<R!F;W(@<V]M92!S96-U<FET>2P@4$A0('!R;W1E8W1S
M(&5N=FER;VYM96YT#0HO+R!V87)I86)L97,@<W1A<G1I;F<@=VET:"!02%!?
M*BX-"@T*+R\@9&5F875L="!C:&%N;F5L(&%N9"!P<F5F97)R960@;6ER<F]R
M(&ES(&)A<V5D(&]N('=H971H97(@=V4@87)E(&EN=F]K960@=&AR;W5G:`T*
M+R\@=&AE(")P96%R(B!O<B!T:&4@(G!E8VPB(&-O;6UA;F0-"@T*:68@*"%D
M969I;F5D*"=014%27U)53E194$4G*2!\?"!014%27U)53E194$4@/3T@)W!E
M87(G*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T-(04Y.
M14PG+"`G<&5A<BYP:'`N;F5T)RD[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G
M4$5!4E]#3TY&24=?1$5&055,5%]#2$%.3D5,)RP@)W!E8VPN<&AP+FYE="<I
M.PT*?0T*#0II9B`H9V5T96YV*"=02%!?4$5!4E]365-#3TY&7T1)4B<I*2![
M#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]365-#3TY&1$E2)RP@9V5T96YV
M*"=02%!?4$5!4E]365-#3TY&7T1)4B<I*3L-"GT@96QS96EF("AG971E;G8H
M)U-Y<W1E;5)O;W0G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?4UE3
M0T].1D1)4B<L(&=E=&5N=B@G4WES=&5M4F]O="<I*3L-"GT@96QS92![#0H@
M("`@9&5F:6YE*"=014%27T-/3D9)1U]365-#3TY&1$E2)RP@4$A07U-94T-/
M3D9$25(I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!M87-T97)?<V5R=F5R#0II
M9B`H9V5T96YV*"=02%!?4$5!4E]-05-415)?4T525D52)RDI('L-"B`@("!D
M969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?34%35$527U-%4E9%4B<L(&=E
M=&5N=B@G4$A07U!%05)?34%35$527U-%4E9%4B<I*3L-"GT@96QS92![#0H@
M("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47TU!4U1%4E]315)615(G
M+"`G<&5A<BYP:'`N;F5T)RD[#0I]#0H-"B\O($1E9F%U;'0@9F]R(&AT='!?
M<')O>'D-"FEF("AG971E;G8H)U!(4%]014%27TA45%!?4%)/6%DG*2D@>PT*
M("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%](5%107U!23UA9)RP@
M9V5T96YV*"=02%!?4$5!4E](5%107U!23UA9)RDI.PT*?2!E;'-E:68@*&=E
M=&5N=B@G:'1T<%]P<F]X>2<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)
M1U]$149!54Q47TA45%!?4%)/6%DG+"!G971E;G8H)VAT='!?<')O>'DG*2D[
M#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%](
M5%107U!23UA9)RP@)R<I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!P:'!?9&ER
M#0II9B`H9V5T96YV*"=02%!?4$5!4E])3E-404Q,7T1)4B<I*2![#0H@("`@
M9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U!(4%]$25(G+"!G971E;G8H
M)U!(4%]014%27TE.4U1!3$Q?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!I9B`H
M0&ES7V1I<B@D4$5!4E])3E-404Q,7T1)4BDI('L-"B`@("`@("`@9&5F:6YE
M*"=014%27T-/3D9)1U]$149!54Q47U!(4%]$25(G+`T*("`@("`@("`@("`@
M("`@)%!%05)?24Y35$%,3%]$25(I.PT*("`@('T@96QS92![#0H@("`@("`@
M(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]02%!?1$E2)RP@)%!%05)?
M24Y35$%,3%]$25(I.PT*("`@('T-"GT-"@T*+R\@1&5F875L="!F;W(@97AT
M7V1I<@T*:68@*&=E=&5N=B@G4$A07U!%05)?15A414Y324].7T1)4B<I*2![
M#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T585%]$25(G+"!G
M971E;G8H)U!(4%]014%27T585$5.4TE/3E]$25(G*2D[#0I](&5L<V4@>PT*
M("`@(&EF("AI;FE?9V5T*"=E>'1E;G-I;VY?9&ER)RDI('L-"B`@("`@("`@
M9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T585%]$25(G+"!I;FE?9V5T
M*"=E>'1E;G-I;VY?9&ER)RDI.PT*("`@('T@96QS96EF("AD969I;F5D*"=0
M14%27T585$5.4TE/3E]$25(G*2`F)B!`:7-?9&ER*%!%05)?15A414Y324].
M7T1)4BDI('L-"B`@("`@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q4
M7T585%]$25(G+"!014%27T585$5.4TE/3E]$25(I.PT*("`@('T@96QS96EF
M("AD969I;F5D*"=02%!?15A414Y324].7T1)4B<I*2![#0H@("`@("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@4$A07T585$5.
M4TE/3E]$25(I.PT*("`@('T@96QS92![#0H@("`@("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@)RXG*3L-"B`@("!]#0I]#0H-
M"B\O($1E9F%U;'0@9F]R(&1O8U]D:7(-"FEF("AG971E;G8H)U!(4%]014%2
M7T1/0U]$25(G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,
M5%]$3T-?1$E2)RP@9V5T96YV*"=02%!?4$5!4E]$3T-?1$E2)RDI.PT*?2!E
M;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?1$]#7T1)
M4B<L#0H@("`@("`@("`@("1014%27TE.4U1!3$Q?1$E2+D1)4D5#5$]265]3
M15!!4D%43U(N)V1O8W,G*3L-"GT-"@T*+R\@1&5F875L="!F;W(@8FEN7V1I
M<@T*:68@*&=E=&5N=B@G4$A07U!%05)?0DE.7T1)4B<I*2![#0H@("`@9&5F
M:6YE*"=014%27T-/3D9)1U]$149!54Q47T))3E]$25(G+"!G971E;G8H)U!(
M4%]014%27T))3E]$25(G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?1$5&055,5%]"24Y?1$E2)RP@4$A07T))3D1)4BD[#0I]#0H-
M"B\O($1E9F%U;'0@9F]R(&1A=&%?9&ER#0II9B`H9V5T96YV*"=02%!?4$5!
M4E]$051!7T1)4B<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!
M54Q47T1!5$%?1$E2)RP@9V5T96YV*"=02%!?4$5!4E]$051!7T1)4B<I*3L-
M"GT@96QS92![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T1!
M5$%?1$E2)RP-"B`@("`@("`@("`@)%!%05)?24Y35$%,3%]$25(N1$E214-4
M3U)97U-%4$%2051/4BXG9&%T82<I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!T
M97-T7V1I<@T*:68@*&=E=&5N=B@G4$A07U!%05)?5$535%]$25(G*2D@>PT*
M("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]415-47T1)4B<L(&=E
M=&5N=B@G4$A07U!%05)?5$535%]$25(G*2D[#0I](&5L<V4@>PT*("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]415-47T1)4B<L#0H@("`@("`@
M("`@("1014%27TE.4U1!3$Q?1$E2+D1)4D5#5$]265]315!!4D%43U(N)W1E
M<W1S)RD[#0I]#0H-"B\O($1E9F%U;'0@9F]R(&-A8VAE7V1I<@T*:68@*&=E
M=&5N=B@G4$A07U!%05)?0T%#2$5?1$E2)RDI('L-"B`@("!D969I;F4H)U!%
M05)?0T].1DE'7T1%1D%53%1?0T%#2$5?1$E2)RP@9V5T96YV*"=02%!?4$5!
M4E]#04-(15]$25(G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#
M3TY&24=?1$5&055,5%]#04-(15]$25(G+`T*("`@("`@("`@("!3>7-T96TZ
M.G1M<&1I<B@I("X@1$E214-43U)97U-%4$%2051/4B`N("=P96%R)R`N#0H@
M("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(@+B`G8V%C:&4G*3L-"GT-
M"@T*+R\@1&5F875L="!F;W(@<&AP7V)I;@T*:68@*&=E=&5N=B@G4$A07U!%
M05)?4$A07T))3B<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!
M54Q47U!(4%]"24XG+"!G971E;G8H)U!(4%]014%27U!(4%]"24XG*2D[#0I]
M(&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]02%!?
M0DE.)RP@4$5!4E]#3TY&24=?1$5&055,5%]"24Y?1$E2+@T*("`@("`@("`@
M("!$25)%0U1/4EE?4T5005)!5$]2+B=P:'`G+BA/4U]724Y$3U=3(#\@)RYE
M>&4G(#H@)R<I*3L-"GT-"@T*+R\@1&5F875L="!F;W(@=F5R8F]S90T*:68@
M*&=E=&5N=B@G4$A07U!%05)?5D520D]312<I*2![#0H@("`@9&5F:6YE*"=0
M14%27T-/3D9)1U]$149!54Q47U9%4D)/4T4G+"!G971E;G8H)U!(4%]014%2
M7U9%4D)/4T4G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&
M24=?1$5&055,5%]615)"3U-%)RP@,2D[#0I]#0H-"B\O($1E9F%U;'0@9F]R
M('!R969E<G)E9%]S=&%T90T*:68@*&=E=&5N=B@G4$A07U!%05)?4%)%1D52
M4D5$7U-4051%)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%5
M3%1?4%)%1D524D5$7U-4051%)RP@9V5T96YV*"=02%!?4$5!4E]04D5&15)2
M141?4U1!5$4G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&
M24=?1$5&055,5%]04D5&15)2141?4U1!5$4G+"`G<W1A8FQE)RD[#0I]#0H-
M"B\O($1E9F%U;'0@9F]R('5M87-K#0II9B`H9V5T96YV*"=02%!?4$5!4E]5
M34%32R<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U5-
M05-+)RP@9V5T96YV*"=02%!?4$5!4E]534%32R<I*3L-"GT@96QS92![#0H@
M("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U5-05-+)RP@9&5C;V-T
M*'5M87-K*"DI*3L-"GT-"@T*+R\@1&5F875L="!F;W(@8V%C:&5?='1L#0II
M9B`H9V5T96YV*"=02%!?4$5!4E]#04-(15]45$PG*2D@>PT*("`@(&1E9FEN
M92@G4$5!4E]#3TY&24=?1$5&055,5%]#04-(15]45$PG+"!G971E;G8H)U!(
M4%]014%27T-!0TA%7U143"<I*3L-"GT@96QS92![#0H@("`@9&5F:6YE*"=0
M14%27T-/3D9)1U]$149!54Q47T-!0TA%7U143"<L(#,V,#`I.PT*?0T*#0HO
M+R!$969A=6QT(&9O<B!S:6=?='EP90T*:68@*&=E=&5N=B@G4$A07U!%05)?
M4TE'7U194$4G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,
M5%]324=?5%E012<L(&=E=&5N=B@G4$A07U!%05)?4TE'7U194$4G*2D[#0I]
M(&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]324=?
M5%E012<L("=G<&<G*3L-"GT-"@T*+R\@1&5F875L="!F;W(@<VEG7V)I;@T*
M:68@*&=E=&5N=B@G4$A07U!%05)?4TE'7T))3B<I*2![#0H@("`@9&5F:6YE
M*"=014%27T-/3D9)1U]$149!54Q47U-)1U]"24XG+"!G971E;G8H)U!(4%]0
M14%27U-)1U]"24XG*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#
M3TY&24=?1$5&055,5%]324=?0DE.)RP-"B`@("`@("`@("`@4WES=&5M.CIW
M:&EC:"@-"B`@("`@("`@("`@("`@("=G<&<G+"!/4U]724Y$3U=3(#\@)V,Z
M7&=N=7!G7&=P9RYE>&4G(#H@)R]U<W(O;&]C86PO8FEN+V=P9R<I*3L-"GT-
M"@T*+R\@1&5F875L="!F;W(@<VEG7VME>61I<@T*:68@*&=E=&5N=B@G4$A0
M7U!%05)?4TE'7TM%641)4B<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)
M1U]$149!54Q47U-)1U]+15E$25(G+"!G971E;G8H)U!(4%]014%27U-)1U]+
M15E$25(G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?
M1$5&055,5%]324=?2T591$E2)RP-"B`@("`@("`@("`@4$5!4E]#3TY&24=?
M4UE30T].1D1)4B`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&5A<FME>7,G
M*3L-"GT-"@T*+RHJ#0H@*B!4:&ES(&ES(&$@8VQA<W,@9F]R('-T;W)I;F<@
M8V]N9FEG=7)A=&EO;B!D871A+"!K965P:6YG('1R86-K(&]F#0H@*B!W:&EC
M:"!A<F4@<WES=&5M+61E9FEN960L('5S97(M9&5F:6YE9"!O<B!D969A=6QT
M960N#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#`N,0T*("HO#0IC;&%S<R!014%27T-O;F9I9R!E>'1E;F1S(%!%
M05(-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@+RHJ#0H@("`@
M("H@07)R87D@;V8@8V]N9FEG(&9I;&5S('5S960N#0H@("`@("H-"B`@("`@
M*B!`=F%R(&%R<F%Y(&QA>65R(#T^(&-O;F9I9R!F:6QE#0H@("`@("HO#0H@
M("`@=F%R("1F:6QE<R`](&%R<F%Y*`T*("`@("`@("`G<WES=&5M)R`]/B`G
M)RP-"B`@("`@("`@)W5S97(G(#T^("<G+`T*("`@("`@("`I.PT*#0H@("`@
M=F%R("1L87EE<G,@/2!A<G)A>2@I.PT*("`@(`T*("`@("\J*@T*("`@("`J
M($-O;F9I9W5R871I;VX@9&%T82P@='=O+61I;65N<VEO;F%L(&%R<F%Y('=H
M97)E('1H92!F:7)S=`T*("`@("`J(&1I;65N<VEO;B!I<R!T:&4@8V]N9FEG
M(&QA>65R("@G=7-E<B<L("=S>7-T96TG(&%N9"`G9&5F875L="<I+`T*("`@
M("`J(&%N9"!T:&4@<V5C;VYD(&1I;65N<VEO;B!I<R!K97EN86UE(#T^('9A
M;'5E+@T*("`@("`J#0H@("`@("H@5&AE(&]R9&5R(&EN('1H92!F:7)S="!D
M:6UE;G-I;VX@:7,@:6UP;W)T86YT(2`@16%R;&EE<@T*("`@("`J(&QA>65R
M<R!W:6QL('-H861O=R!L871E<B!O;F5S('=H96X@82!C;VYF:6<@=F%L=64@
M:7,-"B`@("`@*B!R97%U97-T960@*&EF(&$@)W5S97(G('9A;'5E(&5X:7-T
M<RP@:70@=VEL;"!B92!R971U<FYE9"!F:7)S="P-"B`@("`@*B!T:&5N("=S
M>7-T96TG(&%N9"!F:6YA;&QY("=D969A=6QT)RDN#0H@("`@("H-"B`@("`@
M*B!`=F%R(&%R<F%Y(&QA>65R(#T^(&%R<F%Y*&ME>6YA;64@/3X@=F%L=64L
M("XN+BD-"B`@("`@*B\-"B`@("!V87(@)&-O;F9I9W5R871I;VX@/2!A<G)A
M>2@-"B`@("`@("`@)W5S97(G(#T^(&%R<F%Y*"DL#0H@("`@("`@("=S>7-T
M96TG(#T^(&%R<F%Y*"DL#0H@("`@("`@("=D969A=6QT)R`]/B!A<G)A>2@I
M+`T*("`@("`@("`I.PT*("`@(`T*("`@("\J*@T*("`@("`J($-O;F9I9W5R
M871I;VX@=F%L=65S('1H870@8V%N(&)E('-E="!F;W(@82!C:&%N;F5L#0H@
M("`@("H-"B`@("`@*B!!;&P@;W1H97(@8V]N9FEG=7)A=&EO;B!V86QU97,@
M8V%N(&]N;'D@:&%V92!A(&=L;V)A;"!V86QU90T*("`@("`J($!V87(@87)R
M87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]C:&%N;F5L0V]N9FEG26YF;R`](&%R<F%Y*`T*("`@("`@("`G<&AP7V1I
M<B<L("=E>'1?9&ER)RP@)V1O8U]D:7(G+"`G8FEN7V1I<B<L("=D871A7V1I
M<B<L#0H@("`@("`@("=T97-T7V1I<B<L("=P:'!?8FEN)RP@)W5S97)N86UE
M)RP@)W!A<W-W;W)D)RP@)W9E<F)O<V4G+`T*("`@("`@("`G<')E9F5R<F5D
M7W-T871E)RP@)W5M87-K)RP@)W!R969E<G)E9%]M:7)R;W(G+`T*("`@("`@
M("`I.PT*#0H@("`@+RHJ#0H@("`@("H@0VAA;FYE;',@=&AA="!C86X@8F4@
M86-C97-S960-"B`@("`@*B!`<V5E('-E=$-H86YN96QS*"D-"B`@("`@*B!`
M=F%R(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@=F%R("1?8VAA;FYE;',@/2!A<G)A>2@G<&5A<BYP:'`N;F5T)RP@)W!E
M8VPN<&AP+FYE="<L("=?7W5R:2<I.PT*#0H@("`@+RHJ#0H@("`@("H@5&AI
M<R!V87)I86)L92!I<R!U<V5D('1O(&-O;G1R;VP@=&AE(&1I<F5C=&]R>2!V
M86QU97,@<F5T=7)N960-"B`@("`@*B!`<V5E('-E=$EN<W1A;&Q2;V]T*"D[
M#0H@("`@("H@0'9A<B!S=')I;F=\9F%L<V4-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]I;G-T86QL4F]O="`](&9A;'-E
M.PT*#0H@("`@+RHJ#0H@("`@("H@268@<F5Q=65S=&5D+"!T:&ES('=I;&P@
M86QW87ES(')E9F5R('1O('1H92!R96=I<W1R>0T*("`@("`J(&-O;G1A:6YE
M9"!I;B!P:'!?9&ER#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@
M("HO#0H@("`@=F%R("1?<F5G:7-T<GD@/2!A<G)A>2@I.PT*#0H@("`@+RHJ
M#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@('9A<B`D7W)E9TEN:71I86QI>F5D(#T@87)R87DH*3L-
M"@T*("`@("\J*@T*("`@("`J($!V87(@8F]O;`T*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VYO4F5G:7-T<GD@/2!F86QS
M93L-"@T*("`@("\J*@T*("`@("`J(&%M;W5N="!O9B!E<G)O<G,@9F]U;F0@
M=VAI;&4@<&%R<VEN9R!C;VYF:6<-"B`@("`@*B!`=F%R(&EN=&5G97(-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]E<G)O
M<G-&;W5N9"`](#`[#0H@("`@=F%R("1?;&%S=$5R<F]R(#T@;G5L;#L-"@T*
M("`@("\J*@T*("`@("`J($EN9F]R;6%T:6]N(&%B;W5T('1H92!C;VYF:6=U
M<F%T:6]N(&1A=&$N("!3=&]R97,@=&AE('1Y<&4L#0H@("`@("H@9&5F875L
M="!V86QU92!A;F0@82!D;V-U;65N=&%T:6]N('-T<FEN9R!F;W(@96%C:"!C
M;VYF:6=U<F%T:6]N#0H@("`@("H@=F%L=64N#0H@("`@("H-"B`@("`@*B!`
M=F%R(&%R<F%Y(&QA>65R(#T^(&%R<F%Y*&EN9F]T>7!E(#T^('9A;'5E+"`N
M+BXI#0H@("`@("HO#0H@("`@=F%R("1C;VYF:6=U<F%T:6]N7VEN9F\@/2!A
M<G)A>2@-"B`@("`@("`@+R\@0VAA;FYE;',O26YT97)N970@06-C97-S#0H@
M("`@("`@("=D969A=6QT7V-H86YN96PG(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^(%!%05)?0T].1DE'7T1%1D%53%1?0TA!3DY%3"P-"B`@("`@("`@("`@
M("=D;V,G(#T^("=T:&4@9&5F875L="!C:&%N;F5L('1O('5S92!F;W(@86QL
M(&YO;B!E>'!L:6-I="!C;VUM86YD<R<L#0H@("`@("`@("`@("`G<')O;7!T
M)R`]/B`G1&5F875L="!#:&%N;F5L)RP-"B`@("`@("`@("`@("=G<F]U<"<@
M/3X@)TEN=&5R;F5T($%C8V5S<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@
M("`G<')E9F5R<F5D7VUI<G)O<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G
M='EP92<@/3X@)W-T<FEN9R<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@
M4$5!4E]#3TY&24=?1$5&055,5%]#2$%.3D5,+`T*("`@("`@("`@("`@)V1O
M8R<@/3X@)W1H92!D969A=6QT('-E<G9E<B!O<B!M:7)R;W(@=&\@=7-E(&9O
M<B!C:&%N;F5L(&%C=&EO;G,G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@
M)T1E9F%U;'0@0VAA;FYE;"!-:7)R;W(G+`T*("`@("`@("`@("`@)V=R;W5P
M)R`]/B`G26YT97)N970@06-C97-S)RP-"B`@("`@("`@("`@("DL#0H@("`@
M("`@("=R96UO=&5?8V]N9FEG)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G<&%S<W=O<F0G+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M("<G+`T*("`@("`@("`@("`@)V1O8R<@/3X@)V9T<"!U<FP@;V8@<F5M;W1E
M(&-O;F9I9W5R871I;VX@9FEL92!T;R!U<V4@9F]R('-Y;F-H<F]N:7IE9"!I
M;G-T86QL)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=296UO=&4@0V]N
M9FEG=7)A=&EO;B!&:6QE)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TEN
M=&5R;F5T($%C8V5S<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G875T
M;U]D:7-C;W9E<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@
M)VEN=&5G97(G+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(#`L#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G=VAE=&AE<B!T;R!A=71O;6%T:6-A;&QY(&1I
M<V-O=F5R(&YE=R!C:&%N;F5L<R<L#0H@("`@("`@("`@("`G<')O;7!T)R`]
M/B`G075T;RUD:7-C;W9E<B!N97<@0VAA;FYE;',G+`T*("`@("`@("`@("`@
M)V=R;W5P)R`]/B`G26YT97)N970@06-C97-S)RP-"B`@("`@("`@("`@("DL
M#0H@("`@("`@("\O($EN=&5R;F5T($%C8V5S<PT*("`@("`@("`G;6%S=&5R
M7W-E<G9E<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W-T
M<FEN9R<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@)W!E87(N<&AP+FYE
M="<L#0H@("`@("`@("`@("`G9&]C)R`]/B`G;F%M92!O9B!T:&4@;6%I;B!0
M14%2('-E<G9E<B!;3D]4(%53140@24X@5$A)4R!615)324].72<L#0H@("`@
M("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!S97)V97(@6T1%4%)%0T%4141=
M)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TEN=&5R;F5T($%C8V5S<R<L
M#0H@("`@("`@("`@("`I+`T*("`@("`@("`G:'1T<%]P<F]X>2<@/3X@87)R
M87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L#0H@("`@("`@
M("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%](5%107U!2
M3UA9+`T*("`@("`@("`@("`@)V1O8R<@/3X@)TA45%`@<')O>'D@*&AO<W0Z
M<&]R="D@=&\@=7-E('=H96X@9&]W;FQO861I;F<@<&%C:V%G97,G+`T*("`@
M("`@("`@("`@)W!R;VUP="<@/3X@)TA45%`@4')O>'D@4V5R=F5R($%D9')E
M<W,G+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G26YT97)N970@06-C97-S
M)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("\O($9I;&4@3&]C871I;VYS
M#0H@("`@("`@("=P:'!?9&ER)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]
M/B!014%27T-/3D9)1U]$149!54Q47U!(4%]$25(L#0H@("`@("`@("`@("`G
M9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E("YP:'`@9FEL97,@87)E(&EN<W1A
M;&QE9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!D:7)E8W1O
M<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,G
M+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V5X=%]D:7(G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`T*("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?15A47T1)
M4BP-"B`@("`@("`@("`@("=D;V,G(#T^("=D:7)E8W1O<GD@=VAE<F4@;&]A
M9&%B;&4@97AT96YS:6]N<R!A<F4@:6YS=&%L;&5D)RP-"B`@("`@("`@("`@
M("=P<F]M<'0G(#T^("=02%`@97AT96YS:6]N(&1I<F5C=&]R>2<L#0H@("`@
M("`@("`@("`G9W)O=7`G(#T^("=&:6QE($QO8V%T:6]N<R<L#0H@("`@("`@
M("`@("`I+`T*("`@("`@("`G9&]C7V1I<B<@/3X@87)R87DH#0H@("`@("`@
M("`@("`G='EP92<@/3X@)V1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9&5F
M875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]$3T-?1$E2+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)V1I<F5C=&]R>2!W:&5R92!D;V-U;65N=&%T:6]N
M(&ES(&EN<W1A;&QE9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!
M4B!D;V-U;65N=&%T:6]N(&1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9W)O
M=7`G(#T^("=&:6QE($QO8V%T:6]N<R<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G8FEN7V1I<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@
M/3X@)V1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!
M4E]#3TY&24=?1$5&055,5%]"24Y?1$E2+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)V1I<F5C=&]R>2!W:&5R92!E>&5C=71A8FQE<R!A<F4@:6YS=&%L;&5D
M)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=014%2(&5X96-U=&%B;&5S
M(&1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=&:6QE($QO
M8V%T:6]N<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G9&%T85]D:7(G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG
M+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%5
M3%1?1$%405]$25(L#0H@("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y
M('=H97)E(&1A=&$@9FEL97,@87)E(&EN<W1A;&QE9"<L#0H@("`@("`@("`@
M("`G<')O;7!T)R`]/B`G4$5!4B!D871A(&1I<F5C=&]R>2<L#0H@("`@("`@
M("`@("`G9W)O=7`G(#T^("=&:6QE($QO8V%T:6]N<R`H061V86YC960I)RP-
M"B`@("`@("`@("`@("DL#0H@("`@("`@("=T97-T7V1I<B<@/3X@87)R87DH
M#0H@("`@("`@("`@("`G='EP92<@/3X@)V1I<F5C=&]R>2<L#0H@("`@("`@
M("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]415-47T1)
M4BP-"B`@("`@("`@("`@("=D;V,G(#T^("=D:7)E8W1O<GD@=VAE<F4@<F5G
M<F5S<VEO;B!T97-T<R!A<F4@:6YS=&%L;&5D)RP-"B`@("`@("`@("`@("=P
M<F]M<'0G(#T^("=014%2('1E<W0@9&ER96-T;W)Y)RP-"B`@("`@("`@("`@
M("=G<F]U<"<@/3X@)T9I;&4@3&]C871I;VYS("A!9'9A;F-E9"DG+`T*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)V-A8VAE7V1I<B<@/3X@87)R87DH#0H@
M("`@("`@("`@("`G='EP92<@/3X@)V1I<F5C=&]R>2<L#0H@("`@("`@("`@
M("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]#04-(15]$25(L
M#0H@("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H:6-H(&ES('5S
M960@9F]R(%A-3%)00R!C86-H92<L#0H@("`@("`@("`@("`G<')O;7!T)R`]
M/B`G4$5!4B!);G-T86QL97(@8V%C:&4@9&ER96-T;W)Y)RP-"B`@("`@("`@
M("`@("=G<F]U<"<@/3X@)T9I;&4@3&]C871I;VYS("A!9'9A;F-E9"DG+`T*
M("`@("`@("`@("`@*2P-"B`@("`@("`@)W!H<%]B:6XG(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=F:6QE)RP-"B`@("`@("`@("`@("=D
M969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47U!(4%]"24XL#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G4$A0($-,22]#1TD@8FEN87)Y(&9O<B!E>&5C
M=71I;F<@<V-R:7!T<R<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$A0
M($-,22]#1TD@8FEN87)Y)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T9I
M;&4@3&]C871I;VYS("A!9'9A;F-E9"DG+`T*("`@("`@("`@("`@*2P-"B`@
M("`@("`@+R\@36%I;G1A:6YE<G,-"B`@("`@("`@)W5S97)N86UE)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG)RP-"B`@("`@
M("`@("`@("=D969A=6QT)R`]/B`G)RP-"B`@("`@("`@("`@("=D;V,G(#T^
M("<H;6%I;G1A:6YE<G,I('EO=7(@4$5!4B!A8V-O=6YT(&YA;64G+`T*("`@
M("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@=7-E<FYA;64@*&9O<B!M86EN
M=&%I;F5R<RDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G36%I;G1A:6YE
M<G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W!A<W-W;W)D)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G<&%S<W=O<F0G+`T*("`@
M("`@("`@("`@)V1E9F%U;'0G(#T^("<G+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)RAM86EN=&%I;F5R<RD@>6]U<B!014%2(&%C8V]U;G0@<&%S<W=O<F0G
M+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@<&%S<W=O<F0@*&9O
M<B!M86EN=&%I;F5R<RDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G36%I
M;G1A:6YE<G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@+R\@061V86YC
M960-"B`@("`@("`@)W9E<F)O<V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=I;G1E9V5R)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]
M/B!014%27T-/3D9)1U]$149!54Q47U9%4D)/4T4L#0H@("`@("`@("`@("`G
M9&]C)R`]/B`G=F5R8F]S:71Y(&QE=F5L#0HP.B!R96%L;'D@<75I970-"C$Z
M('-O;65W:&%T('%U:65T#0HR.B!V97)B;W-E#0HS.B!D96)U9R<L#0H@("`@
M("`@("`@("`G<')O;7!T)R`]/B`G1&5B=6<@3&]G($QE=F5L)RP-"B`@("`@
M("`@("`@("=G<F]U<"<@/3X@)T%D=F%N8V5D)RP-"B`@("`@("`@("`@("DL
M#0H@("`@("`@("=P<F5F97)R961?<W1A=&4G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=S970G+`T*("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^(%!%05)?0T].1DE'7T1%1D%53%1?4%)%1D524D5$7U-4051%+`T*("`@
M("`@("`@("`@)V1O8R<@/3X@)W1H92!I;G-T86QL97(@=VEL;"!P<F5F97(@
M<F5L96%S97,@=VET:"!T:&ES('-T871E('=H96X@:6YS=&%L;&EN9R!P86-K
M86=E<R!W:71H;W5T(&$@=F5R<VEO;B!O<B!S=&%T92!S<&5C:69I960G+`T*
M("`@("`@("`@("`@)W9A;&ED7W-E="<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@)W-T86)L92<L("=B971A)RP@)V%L<&AA)RP@)V1E=F5L)RP@)W-N
M87!S:&]T)RDL#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4')E9F5R<F5D
M(%!A8VMA9V4@4W1A=&4G+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G061V
M86YC960G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W5M87-K)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G;6%S:R<L#0H@("`@("`@
M("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]534%32RP-
M"B`@("`@("`@("`@("=D;V,G(#T^("=U;6%S:R!U<V5D('=H96X@8W)E871I
M;F<@9FEL97,@*%5N:7@M;&EK92!S>7-T96US(&]N;'DI)RP-"B`@("`@("`@
M("`@("=P<F]M<'0G(#T^("=5;FEX(&9I;&4@;6%S:R<L#0H@("`@("`@("`@
M("`G9W)O=7`G(#T^("=!9'9A;F-E9"<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G8V%C:&5?='1L)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G:6YT96=E<B<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!
M4E]#3TY&24=?1$5&055,5%]#04-(15]45$PL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G86UO=6YT(&]F('-E8W,@=VAE<F4@=&AE(&QO8V%L(&-A8VAE(&ES
M('5S960@86YD(&YO="!U<&1A=&5D)RP-"B`@("`@("`@("`@("=P<F]M<'0G
M(#T^("=#86-H92!4:6UE5&],:79E)RP-"B`@("`@("`@("`@("=G<F]U<"<@
M/3X@)T%D=F%N8V5D)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=S:6=?
M='EP92<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W-E="<L
M#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,
M5%]324=?5%E012P-"B`@("`@("`@("`@("=D;V,G(#T^("=W:&EC:"!P86-K
M86=E('-I9VYA='5R92!M96-H86YI<VT@=&\@=7-E)RP-"B`@("`@("`@("`@
M("=V86QI9%]S970G(#T^(&%R<F%Y*"=G<&<G*2P-"B`@("`@("`@("`@("=P
M<F]M<'0G(#T^("=086-K86=E(%-I9VYA='5R92!4>7!E)RP-"B`@("`@("`@
M("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP-"B`@("`@("`@("`@("DL
M#0H@("`@("`@("=S:6=?8FEN)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G<W1R:6YG)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!0
M14%27T-/3D9)1U]$149!54Q47U-)1U]"24XL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G=VAI8V@@<&%C:V%G92!S:6=N871U<F4@;65C:&%N:7-M('1O('5S
M92<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4VEG;F%T=7)E($AA;F1L
M:6YG(%!R;V=R86TG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G36%I;G1A
M:6YE<G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W-I9U]K97EI9"<@
M/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L#0H@
M("`@("`@("`@("`G9&5F875L="<@/3X@)R<L#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G=VAI8V@@:V5Y('1O('5S92!F;W(@<VEG;FEN9R!W:71H)RP-"B`@
M("`@("`@("`@("=P<F]M<'0G(#T^("=3:6=N871U<F4@2V5Y($ED)RP-"B`@
M("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=S:6=?:V5Y9&ER)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@("`@("`@("`@("=D
M969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47U-)1U]+15E$25(L#0H@
M("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E('-I9VYA='5R
M92!K97ES(&%R92!L;V-A=&5D)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^
M("=3:6=N871U<F4@2V5Y($1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9W)O
M=7`G(#T^("=-86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@
M("`O+R!?7V-H86YN96QS(&ES(')E<V5R=F5D("T@=7-E9"!F;W(@8VAA;FYE
M;"US<&5C:69I8R!C;VYF:6=U<F%T:6]N#0H@("`@("`@("D[#0H-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!014%27T-O;F9I9RA;9FEL95TL(%MD969A
M=6QT<U]F:6QE72D-"@T*("`@("\J*@T*("`@("`J($-O;G-T<G5C=&]R+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE('1O(')E860@=7-E
M<BUD969I;F5D(&]P=&EO;G,@9G)O;0T*("`@("`J($!P87)A;2!S=')I;F<@
M9FEL92!T;R!R96%D('-Y<W1E;2UW:61E(&1E9F%U;'1S(&9R;VT-"B`@("`@
M*B!`<&%R86T@8F]O;"`@(&1E=&5R;6EN97,@=VAE=&AE<B!A(')E9VES=')Y
M(&]B:F5C="`B9F]L;&]W<R(-"B`@("`@*B`@("`@("`@("`@("`@('1H92!V
M86QU92!O9B!P:'!?9&ER("AI<R!A=71O;6%T:6-A;&QY(&-R96%T960-"B`@
M("`@*B`@("`@("`@("`@("`@(&%N9"!M;W9E9"!W:&5N('!H<%]D:7(@:7,@
M8VAA;F=E9"D-"B`@("`@*B!`<&%R86T@8F]O;"`@(&EF('1R=64L(&9A:6QS
M(&EF(&-O;F9I9W5R871I;VX@9FEL97,@8V%N;F]T(&)E(&QO861E9`T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J($!S
M964@4$5!4E]#;VYF:6<Z.G-I;F=L971O;@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%!%05)?0V]N9FEG*"1U<V5R7V9I;&4@/2`G)RP@)'-Y<W1E;5]F:6QE
M(#T@)R<L("1F='!?9FEL92`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("1S=')I8W0@/2!T<G5E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E!%05(H*3L-"B`@("`@("`@4$5!4E]);G-T86QL97)?4F]L93HZ:6YI=&EA
M;&EZ94-O;F9I9R@D=&AI<RD[#0H@("`@("`@("1S;"`]($1)4D5#5$]265]3
M15!!4D%43U([#0H@("`@("`@(&EF("AE;7!T>2@D=7-E<E]F:6QE*2D@>PT*
M("`@("`@("`@("`@:68@*$]37U=)3D1/5U,I('L-"B`@("`@("`@("`@("`@
M("`D=7-E<E]F:6QE(#T@4$5!4E]#3TY&24=?4UE30T].1D1)4B`N("1S;"`N
M("=P96%R+FEN:2<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1U<V5R7V9I;&4@/2!G971E;G8H)TA/344G*2`N("1S;"`N("<N
M<&5A<G)C)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H96UP='DH)'-Y<W1E;5]F:6QE*2D@>PT*("`@("`@("`@("`@:68@*$]3
M7U=)3D1/5U,I('L-"B`@("`@("`@("`@("`@("`D<WES=&5M7V9I;&4@/2!0
M14%27T-/3D9)1U]365-#3TY&1$E2("X@)'-L("X@)W!E87)S>7,N:6YI)SL-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'-Y<W1E
M;5]F:6QE(#T@4$5!4E]#3TY&24=?4UE30T].1D1)4B`N("1S;"`N("=P96%R
M+F-O;F8G.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@
M)'1H:7,M/FQA>65R<R`](&%R<F%Y7VME>7,H)'1H:7,M/F-O;F9I9W5R871I
M;VXI.PT*("`@("`@("`D=&AI<RT^9FEL97-;)W5S97(G72`]("1U<V5R7V9I
M;&4[#0H@("`@("`@("1T:&ES+3YF:6QE<ULG<WES=&5M)UT@/2`D<WES=&5M
M7V9I;&4[#0H@("`@("`@(&EF("@D=7-E<E]F:6QE("8F($!F:6QE7V5X:7-T
M<R@D=7-E<E]F:6QE*2D@>PT*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1T
M:&ES+3YR96%D0V]N9FEG1FEL92@D=7-E<E]F:6QE+"`G=7-E<B<L("1S=')I
M8W0I.PT*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V5R<F]R<T9O=6YD(#X@,"D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EF("@D<WES=&5M7V9I;&4@)B8@0&9I;&5?97AI
M<W1S*"1S>7-T96U?9FEL92DI('L-"B`@("`@("`@("`@("1T:&ES+3YM97)G
M94-O;F9I9T9I;&4H)'-Y<W1E;5]F:6QE+"!F86QS92P@)W-Y<W1E;2<L("1S
M=')I8W0I.PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?97)R;W)S1F]U;F0@
M/B`P*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("`@("`@
M?0T*#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H(21F='!?9FEL92D@>PT*
M("`@("`@("`@("`@)&9T<%]F:6QE(#T@)'1H:7,M/F=E="@G<F5M;W1E7V-O
M;F9I9R<I.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1F='!?9FEL92`F
M)B!D969I;F5D*"=014%27U)%34]414E.4U1!3$Q?3TLG*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/G)E861&5%!#;VYF:6=&:6QE*"1F='!?9FEL92D[#0H@
M("`@("`@('T-"@T*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]N9FEG=7)A
M=&EO;E]I;F9O(&%S("1K97D@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6=U<F%T:6]N6R=D969A=6QT)UU;)&ME>5T@/2`D:6YF;ULG
M9&5F875L="==.PT*("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M/E]R96=I
M<W1R>5LG9&5F875L="==(#T@)FYE=R!014%27U)E9VES=')Y*"1T:&ES+3YC
M;VYF:6=U<F%T:6]N6R=D969A=6QT)UU;)W!H<%]D:7(G72D[#0H@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GE;)V1E9F%U;'0G72T^<V5T0V]N9FEG*"1T:&ES
M*3L-"B`@("`@("`@)'1H:7,M/E]R96=);FET:6%L:7IE9%LG9&5F875L="==
M(#T@9F%L<V4[#0H@("`@("`@("\O)$=,3T)!3%-;)U]014%27T-O;F9I9U]I
M;G-T86YC92==(#T@)B1T:&ES.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!S:6YG;&5T;VXH6V9I;&5=+"!;9&5F875L='-?9FEL95TI#0H-
M"B`@("`O*BH-"B`@("`@*B!3=&%T:6,@<VEN9VQE=&]N(&UE=&AO9"X@($EF
M('EO=2!W86YT('1O(&ME97`@;VYL>2!O;F4@:6YS=&%N8V4-"B`@("`@*B!O
M9B!T:&ES(&-L87-S(&EN('5S92P@=&AI<R!M971H;V0@=VEL;"!G:79E('EO
M=2!A(')E9F5R96YC92!T;PT*("`@("`J('1H92!L87-T(&-R96%T960@4$5!
M4E]#;VYF:6<@;V)J96-T(&EF(&]N92!E>&ES=',L(&]R(&-R96%T92!A#0H@
M("`@("H@;F5W(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@*&]P=&EO;F%L*2!F:6QE('1O(')E860@=7-E<BUD969I;F5D(&]P=&EO
M;G,@9G)O;0T*("`@("`J($!P87)A;2!S=')I;F<@*&]P=&EO;F%L*2!F:6QE
M('1O(')E860@<WES=&5M+7=I9&4@9&5F875L=',@9G)O;0T*("`@("`J#0H@
M("`@("H@0')E='5R;B!O8FIE8W0@86X@97AI<W1I;F<@;W(@;F5W(%!%05)?
M0V]N9FEG(&EN<W1A;F-E#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J#0H@("`@("H@0'-E92!014%27T-O;F9I9SHZ4$5!4E]#;VYF
M:6<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1U<V5R7V9I
M;&4@/2`G)RP@)'-Y<W1E;5]F:6QE(#T@)R<L("1S=')I8W0@/2!T<G5E*0T*
M("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D1TQ/0D%,4ULG7U!%05)?
M0V]N9FEG7VEN<W1A;F-E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)U]014%27T-O;F9I9U]I;G-T86YC92==.PT*("`@("`@("!]#0H-
M"B`@("`@("`@)'1?8V]N9B`]("9N97<@4$5!4E]#;VYF:6<H)'5S97)?9FEL
M92P@)'-Y<W1E;5]F:6QE+"!F86QS92P@)'-T<FEC="D[#0H@("`@("`@(&EF
M("@D=%]C;VYF+3Y?97)R;W)S1F]U;F0@/B`P*2![#0H@("`@("`@("`@("`@
M<F5T=7)N("1T7V-O;F8M/FQA<W1%<G)O<CL-"B`@("`@("`@?0T*#0H@("`@
M("`@("1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N8V4G72`]("8D=%]C
M;VYF.PT*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O;F9I9U]I
M;G-T86YC92==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!V
M86QI9$-O;F9I9W5R871I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M
M:6YE('=H971H97(@86YY(&-O;F9I9W5R871I;VX@9FEL97,@:&%V92!B965N
M(&1E=&5C=&5D+"!A;F0@=VAE=&AE<B!A#0H@("`@("H@<F5G:7-T<GD@;V)J
M96-T(&-A;B!B92!R971R:65V960@9G)O;2!T:&ES(&-O;F9I9W5R871I;VXN
M#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H@0'-I;F-E(%!%05(@,2XT
M+C!A,0T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED0V]N9FEG=7)A=&EO
M;B@I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/FES1&5F:6YE9$QA>65R
M*"=U<V5R)RD@?'P@)'1H:7,M/FES1&5F:6YE9$QA>65R*"=S>7-T96TG*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!R96%D0V]N9FEG1FEL92A;9FEL95TL(%ML87EE<ETI#0H-"B`@("`O
M*BH-"B`@("`@*B!296%D<R!C;VYF:6=U<F%T:6]N(&1A=&$@9G)O;2!A(&9I
M;&4N("!!;&P@97AI<W1I;F<@=F%L=65S(&EN#0H@("`@("H@=&AE(&-O;F9I
M9R!L87EE<B!A<F4@9&ES8V%R9&5D(&%N9"!R97!L86-E9"!W:71H(&1A=&$@
M9G)O;2!T:&4-"B`@("`@*B!F:6QE+@T*("`@("`J($!P87)A;2!S=')I;F<@
M9FEL92!T;R!R96%D(&9R;VTL(&EF($Y53$P@;W(@;F]T('-P96-I9FEE9"P@
M=&AE#0H@("`@("H@("`@("`@("`@("`@("!L87-T+75S960@9FEL92!F;W(@
M=&AE('-A;64@;&%Y97(@*'-E8V]N9"!P87)A;2D@:7,@=7-E9`T*("`@("`J
M($!P87)A;2!S=')I;F<@8V]N9FEG(&QA>65R('1O(&EN<V5R="!D871A(&EN
M=&\@*"=U<V5R)R!O<B`G<WES=&5M)RD-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M5%)512!O;B!S=6-C97-S(&]R(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<F5A9$-O;F9I9T9I;&4H)&9I;&4@/2!N
M=6QL+"`D;&%Y97(@/2`G=7-E<B<L("1S=')I8W0@/2!T<G5E*0T*("`@('L-
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YF:6QE<ULD;&%Y97)=*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")U;FMN;W=N
M(&-O;F9I9R!L87EE<B!@)&QA>65R)R(I.PT*("`@("`@("!]#0H-"B`@("`@
M("`@:68@*"1F:6QE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D9FEL92`]
M("1T:&ES+3YF:6QE<ULD;&%Y97)=.PT*("`@("`@("!]#0H-"B`@("`@("`@
M)&1A=&$@/2`D=&AI<RT^7W)E861#;VYF:6=$871A1G)O;2@D9FEL92D[#0H-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&1A=&$I*2![#0H@("`@("`@
M("`@("!I9B`H)'-T<FEC="D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M97)R;W)S1F]U;F0K*SL-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&%S=$5R
M<F]R(#T@)&1A=&$[#0H-"B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&$[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)'1H:7,M/F9I;&5S6R1L87EE<ET@/2`D9FEL93L-"B`@("`@
M("`@?0T*#0H@("`@("`@("1T:&ES+3Y?9&5C;V1E26YP=70H)&1A=&$I.PT*
M("`@("`@("`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=(#T@)&1A=&$[
M#0H@("`@("`@("1T:&ES+3Y?<V5T=7!#:&%N;F5L<R@I.PT*("`@("`@("!I
M9B`H(21T:&ES+3Y?;F]296=I<W1R>2`F)B`H)'!H<&1I<B`]("1T:&ES+3YG
M970H)W!H<%]D:7(G+"`D;&%Y97(L("=P96%R+G!H<"YN970G*2DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72`]("9N97<@4$5!
M4E]296=I<W1R>2@D<&AP9&ER*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<F5G
M:7-T<GE;)&QA>65R72T^<V5T0V]N9FEG*"1T:&ES*3L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<F5G26YI=&EA;&EZ961;)&QA>65R72`](&9A;'-E.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]R96=I
M<W1R>5LD;&%Y97)=*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F<@=7)L('1O('1H92!R96UO=&4@8V]N9FEG(&9I;&4L(&QI
M:V4@9G1P.B\O=W=W+F5X86UP;&4N8V]M+W!E87(O8V]N9FEG+FEN:0T*("`@
M("`J($!R971U<FX@=')U97Q014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<F5A9$944$-O;F9I9T9I;&4H)'!A=&@I#0H@("`@>PT*("`@("`@
M("!D;R![("\O('!O;W(@;6%N)W,@=')Y#0H@("`@("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@G3F5T7T944"<I*2![#0H@("`@("`@("`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)U!%05)?0V]M;6]N)RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H4$5!4E]#;VUM
M;VXZ.FES26YC;'5D96%B;&4H)TYE="]&5%`N<&AP)RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@:6YC;'5D95]O;F-E("=.970O1E10+G!H<"<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@G3F5T7T944"<I("8F#0H@("`@("`@("`@("`@("`@
M("`H8VQA<W-?97AI<W1S*"=014%27T944"<I('Q\(%!%05)?0V]M;6]N.CII
M<TEN8VQU9&5A8FQE*"=014%2+T944"YP:'`G*2DI('L-"B`@("`@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O1E10+G!H<"<[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]F='`@/2`F;F5W(%!%05)?1E10.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9G1P+3YP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@)&4@/2`D=&AI<RT^7V9T
M<"T^:6YI="@D<&%T:"D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9G1P
M+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)'1M<"`](%-Y<W1E;3HZ;6MT96UP*"<M9"<I.PT*("`@("`@("`@("`@("`@
M(%!%05)?0V]M;6]N.CIA9&1496UP1FEL92@D=&UP*3L-"B`@("`@("`@("`@
M("`@("`D92`]("1T:&ES+3Y?9G1P+3YG970H8F%S96YA;64H)'!A=&@I+"`D
M=&UP("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@("`@("`@
M("`@("=P96%R+FEN:2<L(&9A;'-E+"!&5%!?0DE.05)9*3L-"B`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]F='`M/G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!014%27T-O;6UO;CHZ861D5&5M<$9I;&4H
M)'1M<"`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&5A<BYI;FDG*3L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V9T<"T^9&ES8V]N;F5C="@I.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9G1P+3YP;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/F9I;&5S6R=F='`G72`]("1T;7`@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!E87(N:6YI)SL-"B`@("`@("`@
M("`@("`@("`D92`]("1T:&ES+3YR96%D0V]N9FEG1FEL92AN=6QL+"`G9G1P
M)RD[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4I*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)&9A:6P@/2!A<G)A>2@I.PT*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN
M9F\@87,@)&ME>2`]/B`D=F%L*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI;E]A<G)A>2@D=&AI<RT^9V5T1W)O=7`H)&ME>2DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=&:6QE($QO8V%T:6]N<R<L("=&:6QE
M($QO8V%T:6]N<R`H061V86YC960I)RDI("8F#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YG9714>7!E*"1K97DI(#T]("=D:7)E8W1O<GDG
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!A;GD@9&ER96-T;W)Y
M(&-O;F9I9W,@;75S="!B92!S970@9F]R('1H:7,@=&\@=V]R:PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^8V]N9FEG=7)A
M=&EO;ELG9G1P)UU;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9A:6Q;72`]("1K97D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1F86EL*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D9F%I;"`]("<B)R`N(&EM<&QO9&4H)R(L("(G+"`D
M9F%I;"D@+B`G(B<[#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3YF:6QE<ULG9G1P)UTI.PT*("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^8V]N9FEG=7)A=&EO;ELG9G1P)UTI.PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G15)23U(Z($9T<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@;75S="!S970@86QL("<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)V1I<F5C=&]R>2!C;VYF:6=U<F%T:6]N('9A<FEA8FQE
M<RX@(%1H97-E('9A<FEA8FQE<R!W97)E(&YO="!S970Z("<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)&9A:6PI.PT*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYE=%]&5%`@;75S
M="!B92!I;G-T86QL960@=&\@=7-E(')E;6]T92!C;VYF:6<G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?2!W:&EL92`H9F%L<V4I.R`O+R!P;V]R(&UA
M;B=S(&-A=&-H#0H@("`@("`@('5N<V5T*"1T:&ES+3YF:6QE<ULG9G1P)UTI
M.PT*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F\@<F5M;W1E
M(&AO<W0@<W!E8VEF:65D)RD[#0H@("`@?0T*#0H@("`@+R\@>WM[(%]S971U
M<$-H86YN96QS*"D-"B`@("`-"B`@("`O*BH-"B`@("`@*B!296%D<R!T:&4@
M97AI<W1I;F<@8V]N9FEG=7)A=&EO;G,@86YD(&-R96%T97,@=&AE(%]C:&%N
M;F5L<R!A<G)A>2!F<F]M(&ET#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W-E
M='5P0VAA;FYE;',H*0T*("`@('L-"B`@("`@("`@)'-E="`](&%R<F%Y7V9L
M:7`H87)R87E?=F%L=65S*"1T:&ES+3Y?8VAA;FYE;',I*3L-"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/F-O;F9I9W5R871I;VX@87,@)&QA>65R(#T^("1D
M871A*2![#0H@("`@("`@("`@("`D:2`](#$P,#`[#0H@("`@("`@("`@("!I
M9B`H:7-S970H)&1A=&%;)U]?8VAA;FYE;',G72DI('L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9&%T85LG7U]C:&%N;F5L<R==(&%S("1C:&%N;F5L
M(#T^("1I;F9O*2![#0H@("`@("`@("`@("`@("`@("`@("1S971;)&-H86YN
M96Q=(#T@)&DK*SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L<R`](&%R<F%Y
M7W9A;'5E<RAA<G)A>5]F;&EP*"1S970I*3L-"B`@("`@("`@)'1H:7,M/G-E
M=$-H86YN96QS*"1T:&ES+3Y?8VAA;FYE;',I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D96QE=&5#:&%N;F5L*&-H86YN96PI#0H-"B`@
M("!F=6YC=&EO;B!D96QE=&5#:&%N;F5L*"1C:&%N;F5L*0T*("`@('L-"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/F-O;F9I9W5R871I;VX@87,@)&QA>65R
M(#T^("1D871A*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)U]?
M8VAA;FYE;',G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1A
M=&%;)U]?8VAA;FYE;',G75MS=')T;VQO=V5R*"1C:&%N;F5L*5TI*2![#0H@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N
M6R1L87EE<EU;)U]?8VAA;FYE;',G75MS=')T;VQO=V5R*"1C:&%N;F5L*5TI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^7V-H86YN96QS(#T@87)R87E?9FQI<"@D=&AI
M<RT^7V-H86YN96QS*3L-"B`@("`@("`@=6YS970H)'1H:7,M/E]C:&%N;F5L
M<UMS=')T;VQO=V5R*"1C:&%N;F5L*5TI.PT*("`@("`@("`D=&AI<RT^7V-H
M86YN96QS(#T@87)R87E?9FQI<"@D=&AI<RT^7V-H86YN96QS*3L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;65R9V5#;VYF:6=&:6QE*&9I
M;&4L(%MO=F5R<FED95TL(%ML87EE<ETI#0H-"B`@("`O*BH-"B`@("`@*B!-
M97)G97,@9&%T82!I;G1O(&$@8V]N9FEG(&QA>65R(&9R;VT@82!F:6QE+B`@
M1&]E<R!T:&4@<V%M90T*("`@("`J('1H:6YG(&%S(')E861#;VYF:6=&:6QE
M+"!E>&-E<'0@:70@9&]E<R!N;W0@<F5P;&%C92!A;&P-"B`@("`@*B!E>&ES
M=&EN9R!V86QU97,@:6X@=&AE(&-O;F9I9R!L87EE<BX-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&9I;&4@=&\@<F5A9"!F<F]M#0H@("`@("H@0'!A<F%M(&)O
M;VP@=VAE=&AE<B!T;R!O=F5R=W)I=&4@97AI<W1I;F<@9&%T82`H9&5F875L
M="!44E5%*0T*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&QA>65R('1O
M(&EN<V5R="!D871A(&EN=&\@*"=U<V5R)R!O<B`G<WES=&5M)RD-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&EF('1R=64L(&5R<F]R<R!A<F4@<F5T=7)N960@
M:68@9FEL92!O<&5N:6YG(&9A:6QS#0H@("`@("H@0')E='5R;B!B;V]L(%12
M544@;VX@<W5C8V5S<R!O<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&UE<F=E0V]N9FEG1FEL92@D9FEL92P@)&]V
M97)R:61E(#T@=')U92P@)&QA>65R(#T@)W5S97(G+"`D<W1R:6-T(#T@=')U
M92D-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9FEL97-;)&QA
M>65R72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B=6YK;F]W;B!C;VYF:6<@;&%Y97(@8"1L87EE<B<B*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&9I;&4@/3T](&YU;&PI('L-"B`@("`@("`@("`@
M("1F:6QE(#T@)'1H:7,M/F9I;&5S6R1L87EE<ET[#0H@("`@("`@('T-"B`@
M("`@("`@)&1A=&$@/2`D=&AI<RT^7W)E861#;VYF:6=$871A1G)O;2@D9FEL
M92D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1D871A*2D@>PT*("`@
M("`@("`@("`@:68@*"1S=')I8W0I('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V5R<F]R<T9O=6YD*RL[#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQA
M<W1%<G)O<B`]("1D871A.PT*#0H@("`@("`@("`@("`@("`@<F5T=7)N("1D
M871A.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7V1E8V]D94EN<'5T*"1D871A*3L-"B`@("`@("`@:68@*"1O
M=F5R<FED92D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9W5R871I;VY;
M)&QA>65R72`]#0H@("`@("`@("`@("`@("`@4$5!4E]#;VYF:6<Z.F%R<F%Y
M365R9V5296-U<G-I=F4H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72P@
M)&1A=&$I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/F-O;F9I9W5R871I;VY;)&QA>65R72`]#0H@("`@("`@("`@("`@("`@4$5!
M4E]#;VYF:6<Z.F%R<F%Y365R9V5296-U<G-I=F4H)&1A=&$L("1T:&ES+3YC
M;VYF:6=U<F%T:6]N6R1L87EE<ETI.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?<V5T=7!#:&%N;F5L<R@I.PT*("`@("`@("!I9B`H(21T:&ES+3Y?
M;F]296=I<W1R>2`F)B`H)'!H<&1I<B`]("1T:&ES+3YG970H)W!H<%]D:7(G
M+"`D;&%Y97(L("=P96%R+G!H<"YN970G*2DI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?<F5G:7-T<GE;)&QA>65R72`]("9N97<@4$5!4E]296=I<W1R>2@D
M<&AP9&ER*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R
M72T^<V5T0V]N9FEG*"1T:&ES*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<F5G
M26YI=&EA;&EZ961;)&QA>65R72`](&9A;'-E.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=
M*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@87)R87E-97)G95)E8W5R<VEV92@D
M87)R,BP@)&%R<C$I#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@
M("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@
M("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A<G)A>4UE<F=E
M4F5C=7)S:79E*"1A<G(R+"`D87)R,2D-"B`@("![#0H@("`@("`@("1R970@
M/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D87)R,B!A<R`D:V5Y(#T^
M("1D871A*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1A<G(Q6R1K97E=
M*2D@>PT*("`@("`@("`@("`@("`@("1R971;)&ME>5T@/2`D9&%T83L-"B`@
M("`@("`@("`@("`@("!U;G-E="@D87)R,5LD:V5Y72D[#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&1A=&$I*2![#0H@("`@("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D87)R,5LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)')E=%LD:V5Y72`]("1A<G(Q6R1K97E=.PT*("`@("`@("`@("`@("`@("`@
M("!U;G-E="@D87)R,5LD:V5Y72D[#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M<F5T6R1K97E=(#T@4$5!4E]#;VYF:6<Z.F%R<F%Y365R9V5296-U<G-I=F4H
M)&%R<C%;)&ME>5TL("1A<G(R6R1K97E=*3L-"B`@("`@("`@("`@("`@("!U
M;G-E="@D87)R,5LD:V5Y72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&%R<F%Y7VUE<F=E*"1R970L("1A<G(Q*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=W)I=&5#;VYF:6=&:6QE
M*%MF:6QE72P@6VQA>65R72D-"@T*("`@("\J*@T*("`@("`J(%=R:71E<R!D
M871A(&EN=&\@82!C;VYF:6<@;&%Y97(@9G)O;2!A(&9I;&4N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@9FEL92!T;R!R96%D(&9R;VTL
M(&]R(&YU;&P@9F]R(&1E9F%U;'0-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O
M;F9I9R!L87EE<B!T;R!I;G-E<G0@9&%T82!I;G1O("@G=7-E<B<@;W(-"B`@
M("`@*B`@("`@("`@("`@("`@("=S>7-T96TG*0T*("`@("`J($!P87)A;2!S
M=')I;F=\;G5L;"!D871A('1O('=R:71E('1O(&-O;F9I9R!F:6QE(&]R(&YU
M;&P@9F]R(&EN=&5R;F%L(&1A=&$@6T1%4%)%0T%4141=#0H@("`@("H@0')E
M='5R;B!B;V]L(%12544@;VX@<W5C8V5S<R!O<B!A(%!%05(@97)R;W(@;VX@
M9F%I;'5R90T*("`@("`J+PT*("`@(&9U;F-T:6]N('=R:71E0V]N9FEG1FEL
M92@D9FEL92`](&YU;&PL("1L87EE<B`]("=U<V5R)RP@)&1A=&$@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]L87IY0VAA;FYE;%-E='5P*"1L
M87EE<BD[#0H@("`@("`@(&EF("@D;&%Y97(@/3T@)V)O=&@G('Q\("1L87EE
M<B`]/2`G86QL)RD@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F9I
M;&5S(&%S("1T>7!E(#T^("1F:6QE*2![#0H@("`@("`@("`@("`@("`@)&5R
M<B`]("1T:&ES+3YW<FET94-O;F9I9T9I;&4H)&9I;&4L("1T>7!E+"`D9&%T
M82D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YF
M:6QE<ULD;&%Y97)=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")U;FMN;W=N(&-O;F9I9R!F:6QE('1Y<&4@8"1L87EE<B<B
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9I;&4@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@("1F:6QE(#T@)'1H:7,M/F9I;&5S6R1L87EE<ET[#0H@
M("`@("`@('T-"B`@("`@("`@)&1A=&$@/2`H)&1A=&$@/3T](&YU;&PI(#\@
M)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72`Z("1D871A.PT*("`@("`@
M("`D=&AI<RT^7V5N8V]D94]U='!U="@D9&%T82D[#0H@("`@("`@("1O<'0@
M/2!A<G)A>2@G+7`G+"!D:7)N86UE*"1F:6QE*2D[#0H@("`@("`@(&EF("@A
M0%-Y<W1E;3HZ;6M$:7(H)&]P="DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-R96%T92!D:7)E8W1O<GDZ
M("(@+B!D:7)N86UE*"1F:6QE*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*$!I<U]F:6QE*"1F:6QE*2`F)B`A0&ES7W=R:71E86)L92@D9FEL92DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B;F\@=W)I
M=&4@86-C97-S('1O("1F:6QE(2(I.PT*("`@("`@("!]#0H@("`@("`@("1F
M<"`]($!F;W!E;B@D9FEL92P@(G<B*3L-"B`@("`@("`@:68@*"$D9G`I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]#
M;VYF:6<Z.G=R:71E0V]N9FEG1FEL92!F;W!E;B@G)&9I;&4G+"=W)RD@9F%I
M;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)&-O;G1E;G1S(#T@(B-014%2
M7T-O;F9I9R`P+CE<;B(@+B!S97)I86QI>F4H)&1A=&$I.PT*("`@("`@("!I
M9B`H(4!F=W)I=&4H)&9P+"`D8V]N=&5N=',I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?0V]N9FEG.CIW<FET94-O
M;F9I9T9I;&4Z(&9W<FET92!F86EL960B*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@7W)E861#;VYF:6=$871A1G)O;2AF:6QE*0T*#0H@("`@+RHJ#0H@("`@
M("H@4F5A9',@8V]N9FEG=7)A=&EO;B!D871A(&9R;VT@82!F:6QE(&%N9"!R
M971U<FYS('1H92!P87)S960@9&%T80T*("`@("`J(&EN(&%N(&%R<F%Y+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE('1O(')E860@9G)O
M;0T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2!C;VYF:6=U<F%T:6]N
M(&1A=&$@;W(@82!014%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]R
M96%D0V]N9FEG1&%T849R;VTH)&9I;&4I#0H@("`@>PT*("`@("`@("`D9G`@
M/2!`9F]P96XH)&9I;&4L(")R(BD[#0H@("`@("`@(&EF("@A)&9P*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?0V]N
M9FEG.CIR96%D0V]N9FEG1FEL92!F;W!E;B@G)&9I;&4G+"=R)RD@9F%I;&5D
M(BD[#0H@("`@("`@('T-"B`@("`@("`@)'-I>F4@/2!F:6QE<VEZ92@D9FEL
M92D[#0H@("`@("`@("1R="`](&=E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@I
M.PT*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H,"D[#0H@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI
M('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)&-O
M;G1E;G1S(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&4I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@0&9R96%D*"1F<"P@
M)'-I>F4I.PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&5M<'1Y*"1C;VYT96YT<RDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]N9FEG=7)A=&EO;B!F:6QE
M("(G("X@)&9I;&4@+B`G(B!I<R!E;7!T>2<I.PT*("`@("`@("!]#0H@("`@
M("`@(`T*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H)')T*3L-
M"@T*("`@("`@("`D=F5R<VEO;B`](&9A;'-E.PT*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UXC4$5!4E]#;VYF:6=<<RLH7%,K*5QS*R]S:2<L("1C;VYT
M96YT<RP@)&UA=&-H97,I*2![#0H@("`@("`@("`@("`D=F5R<VEO;B`]("1M
M871C:&5S6S%=.PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W5B<W1R*"1C
M;VYT96YT<RP@<W1R;&5N*"1M871C:&5S6S!=*2D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`O+R!-=7-E=6T@8V]N9FEG(&9I;&4-"B`@("`@
M("`@("`@(&EF("AS=6)S='(H)&-O;G1E;G1S+#`L,BD@/3T@)V$Z)RD@>PT*
M("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)S`N,2<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1V97)S:6]N("8F('9E<G-I
M;VY?8V]M<&%R92@B)'9E<G-I;VXB+"`G,2<L("<\)RDI('L-"@T*("`@("`@
M("`@("`@+R\@;F\@)T`G+"!I="!I<R!P;W-S:6)L92!T:&%T('5N<V5R:6%L
M:7IE#0H@("`@("`@("`@("`O+R!R86ES97,@82!N;W1I8V4@8G5T(&ET('-E
M96US('1O(&)L;V-K($E/('1O#0H@("`@("`@("`@("`O+R!35$1/550@:68@
M82`G0"<@:7,@=7-E9"!A;F0@82!N;W1I8V4@:7,@<F%I<V4-"B`@("`@("`@
M("`@("1D871A(#T@=6YS97)I86QI>F4H)&-O;G1E;G1S*3L-"@T*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D9&%T82D@)B8@(21D871A*2![#0H@("`@
M("`@("`@("`@("`@:68@*"1C;VYT96YT<R`]/2!S97)I86QI>F4H9F%L<V4I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M97)R(#T@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?0V]N9FEG.B!B860@9&%T
M82!I;B`D9FEL92(I.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&5R
M<CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("AS=')L96XH=')I;2@D8V]N=&5N=',I*2`^(#`I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&5R<F]R(#T@(E!%05)?0V]N9FEG.B!B860@9&%T82!I
M;B`D9FEL92([#0H@("`@("`@("`@("`@("`@("`@("1E<G(@/2`D=&AI<RT^
M<F%I<V5%<G)O<B@D97)R;W(I.PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&5R<CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`O+R!A9&0@<&%R<VEN9R!O9B!N
M97=E<B!F;W)M871S(&AE<F4N+BX-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1E<G(@/2`D=&AI<RT^<F%I<V5%<G)O<B@B)&9I;&4Z('5N:VYO
M=VX@=F5R<VEO;B!@)'9E<G-I;VXG(BD[#0H@("`@("`@("`@("!R971U<FX@
M)&5R<CL@#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1D871A.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971#;VYF1FEL92AL87EE
M<BD-"B`@("`O*BH-"B`@("`J($=E=',@=&AE(&9I;&4@=7-E9"!F;W(@<W1O
M<FEN9R!T:&4@8V]N9FEG(&9O<B!A(&QA>65R#0H@("`@*@T*("`@("H@0'!A
M<F%M('-T<FEN9R`D;&%Y97(@)W5S97(G(&]R("=S>7-T96TG#0H@("`@*B\-
M"@T*("`@(&9U;F-T:6]N(&=E=$-O;F9&:6QE*"1L87EE<BD-"B`@("![#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^9FEL97-;)&QA>65R73L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>2!I
M;F9O<FUA=&EO;B!O;B!A(')O;&4@87,@<&%R<V5D(&9R;VT@:71S('AM;"!F
M:6QE#0H@("`@("H@0')E='5R;B!T<G5E?%!%05)?17)R;W(-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?861D0V]N
M9FEG5F%R<R@D=F%R<RD-"B`@("![#0H@("`@("`@(&EF("AC;W5N="@D=F%R
M<RD@/B`S*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)U)O;&5S(&-A;B!O;FQY(&1E9FEN92`S(&YE=R!C;VYF:6<@=F%R:6%B
M;&5S(&]R(&QE<W,G*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D
M=F%R<R!A<R`D;F%M92`]/B`D=F%R*2![#0H@("`@("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1V87(I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=#;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N(&UU<W0@
M8F4@86X@87)R87DG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)'9A<ELG='EP92==*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!M=7-T(&-O;G1A:6X@82!T>7!E)RD[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)'9A<ELG='EP
M92==+`T*("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S=')I;F<G+"`G
M;6%S:R<L("=P87-S=V]R9"<L("=D:7)E8W1O<GDG+"`G9FEL92<L("=S970G
M*2DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*`T*("`@("`@("`@("`@("`@("`@("`@("`@)T-O;F9I9W5R871I
M;VX@='EP92!M=7-T(&)E(&]N92!O9B!D:7)E8W1O<GDL(&9I;&4L('-T<FEN
M9RP@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G;6%S:RP@<V5T+"!O
M<B!P87-S=V]R9"<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'9A<ELG9&5F875L="==*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@-
M"B`@("`@("`@("`@("`@("`@("`@)T-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@;75S="!C;VYT86EN(&$@9&5F875L="!V86QU92`H(F1E9F%U;'0B(&EN
M9&5X*2<I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'9A<ELG9&5F875L="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5A;%]D969A=6QT(#T@)R<[#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1V87);)V1E9F%U;'0G72!A<R`D8V]N9FEG7W9A
M<B`]/B`D=F%L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1C;VYF:6=?=F%R+"`G=&5X="<I(#T]/2`P*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E86Q?9&5F875L="`N/2`D=F%L.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D8V]N9FEG
M7W9A<BP@)V-O;G-T86YT)RD@/3T](#`I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H9&5F:6YE9"@D=F%L*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5A;%]D969A=6QT("X](&-O;G-T86YT
M*"1V86PI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=5;FMN;W=N(&-O;G-T86YT("(G("X@)'9A;"`N("<B(')E<75E
M<W1E9"!I;B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=D969A=6QT('9A;'5E(&9O<B!C;VYF:6=U<F%T:6]N('9A<FEA8FQE
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M86UE("X@)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M
M/F-O;F9I9W5R871I;VY?:6YF;ULD8V]N9FEG7W9A<ETI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E86Q?9&5F875L="`N/0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG=7)A=&EO
M;E]I;F9O6R1C;VYF:6=?=F%R75LG9&5F875L="==.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=5;FMN;W=N(')E<75E<W0@9F]R("(G("X@
M)&-O;F9I9U]V87(@+B`G(B!V86QU92!I;B`G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0@=F%L=64@9F]R(&-O;F9I9W5R
M871I;VX@=F%R:6%B;&4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F%M92`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)'9A<ELG9&5F875L="==(#T@)')E86Q?9&5F875L=#L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1V87);)W1Y<&4G72`]
M/2`G:6YT96=E<B<I('L-"B`@("`@("`@("`@("`@("`@("`@)'9A<ELG9&5F
M875L="==(#T@*&EN=&5G97(I("1V87);)V1E9F%U;'0G73L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1V87);)V1O8R==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@)T-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@;75S="!C;VYT86EN(&$@<W5M;6%R>2`H
M(F1O8R(@:6YD97@I)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1V87);)W!R;VUP="==*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@
M("`@)T-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@;75S="!C;VYT86EN(&$@
M<VEM<&QE('!R;VUP="`H(G!R;VUP="(@:6YD97@I)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1V87);)V=R;W5P)UTI*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*
M("`@("`@("`@("`@("`@("`@("`G0V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!M=7-T(&-O;G1A:6X@82!S:6UP;&4@9W)O=7`@*")G<F]U<"(@:6YD97@I
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD;F%M95TI*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#;VYF:6=U<F%T:6]N
M('9A<FEA8FQE("(G("X@)&YA;64@+@T*("`@("`@("`@("`@("`@("`@("`G
M(B!A;')E861Y(&5X:7-T<R<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD;F%M95T@/2`D=F%R.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@
M("\O('M[>R!?96YC;V1E3W5T<'5T*"9D871A*0T*#0H@("`@+RHJ#0H@("`@
M("H@16YC;V1E<R]S8W)A;6)L97,@8V]N9FEG=7)A=&EO;B!D871A(&)E9F]R
M92!W<FET:6YG('1O(&9I;&5S+@T*("`@("`J($-U<G)E;G1L>2P@)W!A<W-W
M;W)D)R!V86QU97,@=VEL;"!B92!B87-E-C0M96YC;V1E9"!A<R!T;R!A=F]I
M9`T*("`@("`J('1H870@<&5O<&QE('-P;W0@8VQE87)T97AT('!A<W-W;W)D
M<R!B>2!A8V-I9&5N="X-"B`@("`@*@T*("`@("`J($!P87)A;2!A<G)A>2`H
M<F5F97)E;F-E*2!A<G)A>2!T;R!E;F-O9&4@=F%L=65S(&EN#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?96YC;V1E3W5T<'5T*"8D9&%T82D-"B`@("![#0H@("`@("`@(&9O<F5A
M8V@@*"1D871A(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@("!I
M9B`H)&ME>2`]/2`G7U]C:&%N;F5L<R<I('L-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9&%T85LG7U]C:&%N;F5L<R==(&%S("1C:&%N;F5L(#T^("1B
M;&%H*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?96YC;V1E3W5T
M<'5T*"1D871A6R=?7V-H86YN96QS)UU;)&-H86YN96Q=*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2![#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D='EP92`]("1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5U;
M)W1Y<&4G73L-"B`@("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L-"B`@("`@
M("`@("`@("`@("`O+R!W92!B87-E-C0M96YC;V1E('!A<W-W;W)D<R!S;R!T
M:&5Y(&%R92!A="!L96%S=`T*("`@("`@("`@("`@("`@("\O(&YO="!S:&]W
M;B!I;B!P;&%I;B!B>2!A8V-I9&5N=`T*("`@("`@("`@("`@("`@(&-A<V4@
M)W!A<W-W;W)D)SH@>PT*("`@("`@("`@("`@("`@("`@("`D9&%T85LD:V5Y
M72`](&)A<V4V-%]E;F-O9&4H)&1A=&%;)&ME>5TI.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@8V%S92`G;6%S:R<Z('L-"B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)&ME>5T@/2!O8W1D96,H)&1A=&%;)&ME>5TI.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]D96-O9&5);G!U="@F9&%T82D-
M"@T*("`@("\J*@T*("`@("`J($1E8V]D97,O=6YS8W)A;6)L97,@8V]N9FEG
M=7)A=&EO;B!D871A(&%F=&5R(')E861I;F<@9G)O;2!F:6QE<RX-"B`@("`@
M*@T*("`@("`J($!P87)A;2!A<G)A>2`H<F5F97)E;F-E*2!A<G)A>2!T;R!E
M;F-O9&4@=F%L=65S(&EN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M5%)512!O;B!S=6-C97-S#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*@T*("`@("`J($!S964@4$5!4E]#;VYF:6<Z.E]E;F-O9&5/
M=71P=70-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9&5C;V1E26YP=70H)B1D
M871A*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D9&%T82DI('L-
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@
M(&9O<F5A8V@@*"1D871A(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@
M("`@("!I9B`H)&ME>2`]/2`G7U]C:&%N;F5L<R<I('L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9&%T85LG7U]C:&%N;F5L<R==(&%S("1C:&%N;F5L
M(#T^("1B;&%H*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5C
M;V1E26YP=70H)&1A=&%;)U]?8VAA;FYE;',G75LD8VAA;FYE;%TI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72DI('L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1T>7!E(#T@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD
M:V5Y75LG='EP92==.PT*("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PT*
M("`@("`@("`@("`@("`@(&-A<V4@)W!A<W-W;W)D)SH@>PT*("`@("`@("`@
M("`@("`@("`@("`D9&%T85LD:V5Y72`](&)A<V4V-%]D96-O9&4H)&1A=&%;
M)&ME>5TI.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@8V%S92`G;6%S:R<Z('L-"B`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!D96-O8W0H)&1A=&%;
M)&ME>5TI.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&=E=$1E9F%U;'1#:&%N;F5L*%ML87EE<ETI#0H@("`@+RHJ#0H@("`@("H@
M4F5T<FEE=F4@=&AE(&1E9F%U;'0@8VAA;FYE;"X-"B`@("`@*@T*("`@("`J
M($]N('-T87)T=7`L(&-H86YN96QS(&%R92!N;W0@:6YI=&EA;&EZ960L('-O
M(&EF('1H92!D969A=6QT(&-H86YN96P@:7,@;F]T#0H@("`@("H@<&5A<BYP
M:'`N;F5T+"!T:&5N(&EN:71I86QI>F4@=&AE(&-O;F9I9RX-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(')E9VES=')Y(&QA>65R#0H@("`@("H@0')E='5R;B!S
M=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971$969A=6QT
M0VAA;FYE;"@D;&%Y97(@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)')E="`]
M(&9A;'-E.PT*("`@("`@("!I9B`H)&QA>65R(#T]/2!N=6QL*2![#0H@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^;&%Y97)S(&%S("1L87EE<BD@>PT*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;ELD;&%Y97)=6R=D969A=6QT7V-H86YN96PG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)')E="`]("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;
M)V1E9F%U;'1?8VAA;FYE;"==.PT*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS96EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=
M6R=D969A=6QT7V-H86YN96PG72DI('L-"B`@("`@("`@("`@("1R970@/2`D
M=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=D969A=6QT7V-H86YN96PG
M73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')E="`]/2`G<&5A<BYP:'`N
M;F5T)R`F)B!D969I;F5D*"=014%27U)53E194$4G*2`F)B!014%27U)53E19
M4$4@/3T@)W!E8VPG*2![#0H@("`@("`@("`@("`D<F5T(#T@)W!E8VPN<&AP
M+FYE="<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1R970I('L-"B`@("`@
M("`@("`@(&EF("@D<F5T("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L87IY0VAA;FYE;%-E='5P*"D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@4$5!4E]#3TY&24=?1$5&055,5%]#2$%.3D5,.PT*
M("`@('T-"@T*("`@("\O('M[>R!G970H:V5Y+"!;;&%Y97)=*0T*("`@("\J
M*@T*("`@("`J(%)E='5R;G,@82!C;VYF:6=U<F%T:6]N('9A;'5E+"!P<FEO
M<FET:7II;F<@;&%Y97)S(&%S('!E<B!T:&4-"B`@("`@*B!L87EE<G,@<')O
M<&5R='DN#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!K
M97D-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@=&AE(&-O;F9I9R!V
M86QU92P@;W(@3E5,3"!I9B!N;W0@9F]U;F0-"B`@("`@*@T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T*"1K97DL
M("1L87EE<B`](&YU;&PL("1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME
M>5TI*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&ME>2`]/2`G7U]C:&%N;F5L<R<I('L-"B`@("`@("`@
M("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D:V5Y
M(#T]("=D969A=6QT7V-H86YN96PG*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F=E=$1E9F%U;'1#:&%N;F5L*"1L87EE<BD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)&-H86YN
M96P@/2`D=&AI<RT^9V5T1&5F875L=$-H86YN96PH*3L-"B`@("`@("`@?2!E
M;'-E:68@*"1C:&%N;F5L("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7VQA>GE#:&%N;F5L4V5T=7`H*3L-"B`@("`@("`@?0T*
M("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H86YN96PI.PT*("`@
M("`@("`-"B`@("`@("`@)'1E<W0@/2`H:6Y?87)R87DH)&ME>2P@)'1H:7,M
M/E]C:&%N;F5L0V]N9FEG26YF;RDI(#\-"B`@("`@("`@("`@("1T:&ES+3Y?
M9V5T0VAA;FYE;%9A;'5E*"1K97DL("1L87EE<BP@)&-H86YN96PI(#H-"B`@
M("`@("`@("`@(&YU;&P[#0H@("`@("`@(&EF("@D=&5S="`A/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?:6YS=&%L;%)O;W0I('L-"B`@
M("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'1H:7,M/F=E=$=R;W5P*"1K
M97DI+`T*("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=&:6QE($QO8V%T
M:6]N<R<L("=&:6QE($QO8V%T:6]N<R`H061V86YC960I)RDI("8F#0H@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%1Y<&4H)&ME>2D@/3T@)V1I
M<F5C=&]R>2<I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<')E<&5N9%!A=&@H)'1E<W0L("1T:&ES+3Y?:6YS=&%L;%)O;W0I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E='5R;B`D=&5S=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&QA>65R
M(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;&%Y
M97)S(&%S("1L87EE<BD@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&5S="`]("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L
M87EE<EU;)&ME>5T[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M7VEN<W1A;&Q2;V]T*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:6Y?87)R87DH)'1H:7,M/F=E=$=R;W5P*"1K97DI+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)T9I;&4@3&]C871I;VYS)RP@)T9I
M;&4@3&]C871I;VYS("A!9'9A;F-E9"DG*2D@)B8-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YG9714>7!E*"1K97DI(#T]("=D:7)E
M8W1O<GDG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<')E<&5N9%!A=&@H)'1E<W0L("1T:&ES+3Y?:6YS=&%L;%)O
M;W0I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D:V5Y(#T]("=P
M<F5F97)R961?;6ER<F]R)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E9R`]("8D=&AI<RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E9RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1C
M:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1C:&%N;F5L.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(21C:&%N+3YG971-:7)R;W(H)'1E<W0I("8F("1C:&%N+3YG971.86UE*"D@
M(3T@)'1E<W0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1C:&%N;F5L.R`O+R!M:7)R;W(@9&]E<R!N;W0@97AI<W0-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T97-T.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YC
M;VYF:6=U<F%T:6]N6R1L87EE<EU;)&ME>5TI*2![#0H@("`@("`@("`@("`D
M=&5S="`]("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)&ME>5T[#0H@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]I;G-T86QL4F]O="D@>PT*("`@("`@
M("`@("`@("`@(&EF("AI;E]A<G)A>2@D=&AI<RT^9V5T1W)O=7`H)&ME>2DL
M#0H@("`@("`@("`@("`@("`@("`@("`@87)R87DH)T9I;&4@3&]C871I;VYS
M)RP@)T9I;&4@3&]C871I;VYS("A!9'9A;F-E9"DG*2D@)B8-"B`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^9V5T5'EP92@D:V5Y*2`]/2`G9&ER96-T
M;W)Y)RD@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M<F5P96YD4&%T:"@D=&5S="P@)'1H:7,M/E]I;G-T86QL4F]O="D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"1K97D@/3T@)W!R969E<G)E9%]M:7)R;W(G*2![#0H@("`@("`@("`@("`@
M("`@)')E9R`]("8D=&AI<RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@("`@
M("`@("!I9B`H:7-?;V)J96-T*"1R96<I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D8VAA;FYE;#L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H
M(21C:&%N+3YG971-:7)R;W(H)'1E<W0I("8F("1C:&%N+3YG971.86UE*"D@
M(3T@)'1E<W0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M8VAA;FYE;#L@+R\@;6ER<F]R(&1O97,@;F]T(&5X:7-T#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!R971U<FX@)'1E<W0[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&YU;&P[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(%]G971#:&%N;F5L5F%L=64H:V5Y+"!V86QU92P@6VQA>65R72D-"B`@
M("`O*BH-"B`@("`@*B!2971U<FYS(&$@8VAA;FYE;"US<&5C:69I8R!C;VYF
M:6=U<F%T:6]N('9A;'5E+"!P<FEO<FET:7II;F<@;&%Y97)S(&%S('!E<B!T
M:&4-"B`@("`@*B!L87EE<G,@<')O<&5R='DN#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U
M<FX@;6EX960@=&AE(&-O;F9I9R!V86QU92P@;W(@3E5,3"!I9B!N;W0@9F]U
M;F0-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]G971#:&%N;F5L5F%L=64H)&ME>2P@)&QA>65R+"`D
M8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("@D:V5Y(#T]("=?7V-H86YN
M96QS)R!\?"`D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]
M(&YU;&P[#0H@("`@("`@(&EF("@D;&%Y97(@/3T](&YU;&PI('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YL87EE<G,@87,@)&EL87EE<BD@>PT*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;ELD:6QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L75LD:V5Y72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3YC;VYF:6=U<F%T
M:6]N6R1I;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN96Q=6R1K97E=.PT*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI
M<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN
M96Q=6R1K97E=*2D@>PT*("`@("`@("`@("`@)')E="`]("1T:&ES+3YC;VYF
M:6=U<F%T:6]N6R1L87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%U;)&ME
M>5T[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1K97D@/3T@)W!R969E<G)E
M9%]M:7)R;W(G*2![#0H@("`@("`@("`@("!I9B`H)')E="`A/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@("`@("1R96<@/2`F)'1H:7,M/F=E=%)E9VES=')Y
M*"1L87EE<BD[#0H@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D<F5G
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G+3YG971#
M:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)&-H86YN96P[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"$D8VAA;BT^9V5T36ER<F]R*"1R970I
M("8F("1C:&%N+3YG971.86UE*"D@(3T@)')E="D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1C:&%N;F5L.R`O+R!M:7)R;W(@9&]E<R!N
M;W0@97AI<W0-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`D=&AI<RT^9V5T
M1&5F875L=$-H86YN96PH)&QA>65R*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D8VAA;FYE;#L@+R\@=V4@;75S="!U<V4@=&AE(&-H86YN96P@;F%M
M92!A<R!T:&4@<')E9F5R<F5D(&UI<G)O<@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@:68@=&AE('5S97(@:&%S(&YO="!C:&]S96X@
M86X@86QT97)N871E#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9V5T1&5F875L=$-H86YN96PH)&QA>65R
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)')E=#L-"B`@("!]#0H-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!S970H
M:V5Y+"!V86QU92P@6VQA>65R72D-"@T*("`@("\J*@T*("`@("`J(%-E="!A
M(&-O;F9I9R!V86QU92!I;B!A('-P96-I9FEC(&QA>65R("AD969A=6QT<R!T
M;R`G=7-E<B<I+@T*("`@("`J($5N9F]R8V5S('1H92!T>7!E<R!D969I;F5D
M(&EN('1H92!C;VYF:6=U<F%T:6]N7VEN9F\@87)R87DN("!!;@T*("`@("`J
M(&EN=&5G97(@8V]N9FEG('9A<FEA8FQE('=I;&P@8F4@8V%S="!T;R!I;G0L
M(&%N9"!A('-E="!C;VYF:6<-"B`@("`@*B!V87)I86)L92!W:6QL(&)E('9A
M;&ED871E9"!A9V%I;G-T(&ET<R!L96=A;"!V86QU97,N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!K97D-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&-O;F9I9R!V86QU90T*("`@("`J($!P87)A;2!S=')I;F<@*&]P
M=&EO;F%L*2!C;VYF:6<@;&%Y97(-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H
M86YN96P@=&\@<V5T('1H:7,@=F%L=64@9F]R+"!O<B!N=6QL(&9O<B!G;&]B
M86P@=F%L=64-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S
M+"!&04Q312!O;B!F86EL=7)E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T
M*"1K97DL("1V86QU92P@)&QA>65R(#T@)W5S97(G+"`D8VAA;FYE;"`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1K97D@/3T@)U]?8VAA;FYE;',G
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D:V5Y(#T]("=D969A=6QT7V-H86YN96PG*2![#0H@("`@
M("`@("`@("`O+R!C86X@;VYL>2!S970@=&AI<R!V86QU92!G;&]B86QL>0T*
M("`@("`@("`@("`@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@
M("`@("`@(&EF("@D=F%L=64@(3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VQA>GE#:&%N;F5L4V5T=7`H)&QA>65R*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&ME>2`]
M/2`G<')E9F5R<F5D7VUI<G)O<B<I('L-"B`@("`@("`@("`@(&EF("@D8VAA
M;FYE;"`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.R`O+R!C86XG="!S970@=&AE(%]?=7)I('!S975D;RUC:&%N;F5L)W,@
M;6ER<F]R#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YG971296=I<W1R>2@D;&%Y97(I.PT*("`@("`@("`@("`@:68@*&ES
M7V]B:F5C="@D<F5G*2D@>PT*("`@("`@("`@("`@("`@("1C:&%N(#T@)B1R
M96<M/F=E=$-H86YN96PH)&-H86YN96P@/R`D8VAA;FYE;"`Z("=P96%R+G!H
M<"YN970G*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M8VAA;BDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(21C:&%N
M+3YG971-:7)R;W(H)'9A;'5E*2`F)B`D8VAA;BT^9V5T3F%M92@I("$]("1V
M86QU92D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[("\O
M(&UI<G)O<B!D;V5S(&YO="!E>&ES=`T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!E>'1R86-T*"1T
M:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI.PT*("`@("`@("!S=VET
M8V@@*"1T>7!E*2![#0H@("`@("`@("`@("!C87-E("=I;G1E9V5R)SH-"B`@
M("`@("`@("`@("`@("`D=F%L=64@/2`H:6YT*21V86QU93L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W-E="<Z('L-"B`@
M("`@("`@("`@("`@("`O+R!)9B!A('9A;&ED7W-E="!I<R!S<&5C:69I960L
M(')E<75I<F4@=&AE('9A;'5E('1O#0H@("`@("`@("`@("`@("`@+R\@8F4@
M:6X@=&AE('-E="X@($EF('1H97)E(&ES(&YO('9A;&ED7W-E="P@86-C97!T
M#0H@("`@("`@("`@("`@("`@+R\@86YY('9A;'5E+@T*("`@("`@("`@("`@
M("`@(&EF("@D=F%L:61?<V5T*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M<V5T*"1V86QI9%]S970I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H*&ME
M>2@D=F%L:61?<V5T*2`]/3T@,"`F)B`A:6Y?87)R87DH)'9A;'5E+"`D=F%L
M:61?<V5T*2D@?'P-"B`@("`@("`@("`@("`@("`@("`@("`@("AK97DH)'9A
M;&ED7W-E="D@(3T](#`@)B8@96UP='DH)'9A;&ED7W-E=%LD=F%L=65=*2DI
M#0H@("`@("`@("`@("`@("`@("`@('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21C:&%N;F5L*2![
M#0H@("`@("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3YG970H)V1E9F%U;'1?
M8VAA;FYE;"<L(&YU;&PL("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6EN7V%R<F%Y*"1C:&%N;F5L+"`D=&AI<RT^7V-H86YN
M96QS*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]L87IY0VAA;FYE;%-E='5P
M*"1L87EE<BD[#0H@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YG971296=I
M<W1R>2@D;&%Y97(I.PT*("`@("`@("`@("`@:68@*"1R96<I('L-"B`@("`@
M("`@("`@("`@("`D8VAA;FYE;"`]("1R96<M/F-H86YN96Q.86UE*"1C:&%N
M;F5L*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:6Y?87)R
M87DH)&-H86YN96PL("1T:&ES+3Y?8VAA;FYE;',I*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@D8VAA;FYE;"`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1K97DL("1T:&ES+3Y?8VAA;FYE
M;$-O;F9I9TEN9F\I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I
M9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L75LD:V5Y
M72`]("1V86QU93L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@:68@*"1K97D@/3T@)V1E9F%U;'1?8VAA;FYE;"<I('L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1R96<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("1R96<@/2`F)'1H:7,M/F=E=%)E9VES=')Y*"1L87EE<BD[#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A)')E9RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^9V5T4F5G:7-T<GDH*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H)')E9RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@/2`D<F5G+3YC:&%N;F5L3F%M92@D=F%L=64I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(21V86QU92D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)&ME>5T@/2`D=F%L=64[#0H@("`@
M("`@(&EF("@D:V5Y(#T]("=P:'!?9&ER)R`F)B`A)'1H:7,M/E]N;U)E9VES
M=')Y*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<F5G:7-T
M<GE;)&QA>65R72D@?'P-"B`@("`@("`@("`@("`@("`@("1V86QU92`A/2`D
M=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM/FEN<W1A;&Q?9&ER*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=(#T@)FYE=R!0
M14%27U)E9VES=')Y*"1V86QU92D[#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R96=);FET:6%L:7IE9%LD;&%Y97)=(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=+3YS971#;VYF:6<H)'1H
M:7,I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@(&9U;F-T:6]N(%]L
M87IY0VAA;FYE;%-E='5P*"1U<V5L87EE<B`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@:68@*"1T:&ES+3Y?;F]296=I<W1R>2D@>PT*("`@("`@("`@("`@
M<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@("1M97)G92`](&9A;'-E.PT*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)E9VES=')Y(&%S("1L87EE<B`]
M/B`D<"D@>PT*("`@("`@("`@("`@:68@*"1U<V5L87EE<B`F)B`D=7-E;&%Y
M97(@(3T@)&QA>65R*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<F5G26YI
M=&EA;&EZ961;)&QA>65R72D@>PT*("`@("`@("`@("`@("`@(&EF("@D;&%Y
M97(@/3T@)V1E9F%U;'0G("8F(&ES<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)W5S
M97(G72D@?'P-"B`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^
M7W)E9VES=')Y6R=S>7-T96TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M+R\@;VYL>2!U<V4@=&AE(&1E9F%U;'0@<F5G:7-T<GD@:68@=&AE<F4@87)E
M(&YO(&%L=&5R;F%T:79E<PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I
M<U]O8FIE8W0H)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'!H<&1I<B`]("1T:&ES+3YG970H)W!H<%]D
M:7(G+"`D;&%Y97(L("=P96%R+G!H<"YN970G*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=(#T@)FYE=R!0
M14%27U)E9VES=')Y*"1P:'!D:7(I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=+3YS971#;VYF:6<H)'1H:7,I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=);FET:6%L
M:7IE9%LD;&%Y97)=(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M7W)E9VES=')Y6R1L87EE<ETI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YS971#:&%N;F5L<R@D=&AI
M<RT^7W)E9VES=')Y6R1L87EE<ETM/FQI<W1#:&%N;F5L<R@I+"`D;65R9V4I
M.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G26YI=&EA;&EZ961;)&QA
M>65R72`]('1R=64[#0H@("`@("`@("`@("`@("`@)&UE<F=E(#T@=')U93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"B`@("`O+R![>WL@
M<V5T0VAA;FYE;',H*0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E="!T:&4@
M;&ES="!O9B!C:&%N;F5L<RX-"B`@("`@*@T*("`@("`J(%1H:7,@<VAO=6QD
M(&)E('-E="!V:6$@82!C86QL('1O('M`;&EN:R!014%27U)E9VES=')Y.CIL
M:7-T0VAA;FYE;',H*7T-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`
M<&%R86T@8F]O;`T*("`@("`J($!R971U<FX@8F]O;"!S=6-C97-S(&]F(&]P
M97)A=&EO;@T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$-H86YN96QS*"1C
M:&%N;F5L<RP@)&UE<F=E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1C:&%N;F5L<RDI('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UE<F=E*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7V-H86YN96QS(#T@87)R87E?;65R9V4H)'1H:7,M
M/E]C:&%N;F5L<RP@)&-H86YN96QS*3L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;',@/2`D8VAA;FYE;',[#0H@("`@
M("`@('T-"B`@("`@("`@9F]R96%C:"`H)&-H86YN96QS(&%S("1C:&%N;F5L
M*2![#0H@("`@("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H86YN
M96PI.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;&%Y97)S(&%S("1L
M87EE<BD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F-O
M;F9I9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L72D-
M"B`@("`@("`@("`@("`@("`@("`@("!\?"`A:7-?87)R87DH)'1H:7,M/F-O
M;F9I9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9W5R871I;VY;
M)&QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L72`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!G9714>7!E*&ME>2D-"@T*("`@("\J*@T*("`@("`J($=E="!T
M:&4@='EP92!O9B!A(&-O;F9I9R!V86QU92X-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U
M<FX@<W1R:6YG('1Y<&4L(&]N92!O9B`B<W1R:6YG(BP@(FEN=&5G97(B+"`B
M9FEL92(L#0H@("`@("H@(F1I<F5C=&]R>2(L(")S970B(&]R(")P87-S=V]R
M9"(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T5'EP92@D:V5Y*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME
M>5TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-O;F9I9W5R871I
M;VY?:6YF;ULD:V5Y75LG='EP92==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9V5T1&]C<RAK97DI#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&1O8W5M
M96YT871I;VX@9F]R(&$@8V]N9FEG('9A;'5E+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`@8V]N9FEG(&ME>0T*("`@("`J#0H@("`@("H@0')E
M='5R;B!S=')I;F<@9&]C=6UE;G1A=&EO;B!S=')I;F<-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971$;V-S*"1K97DI#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=D
M;V,G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*("`@("`@("\O('U]?0T*("`@("\O('M[>R!G9710<F]M<'0H:V5Y*0T*
M#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!S:&]R="!D;V-U;65N=&%T:6]N
M(&9O<B!A(&-O;F9I9R!V86QU92X-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R
M:6YG('-H;W)T(&1O8W5M96YT871I;VX@<W1R:6YG#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T4')O;7!T*"1K97DI#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=P
M<F]M<'0G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*("`@("\O('U]?0T*("`@("\O('M[>R!G971'<F]U<"AK97DI#0H-
M"B`@("`O*BH-"B`@("`@*B!'970@=&AE('!A<F%M971E<B!G<F]U<"!F;W(@
M82!C;VYF:6<@:V5Y+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@
M8V]N9FEG(&ME>0T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@<&%R
M86UE=&5R(&=R;W5P#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1W)O=7`H)&ME>2D-
M"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;E]I;F9O6R1K97E=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC
M;VYF:6=U<F%T:6]N7VEN9F];)&ME>5U;)V=R;W5P)UT[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!G971'<F]U<',H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M('1H92!L:7-T(&]F('!A<F%M971E<B!G<F]U<',N#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y(&QI<W0@;V8@<&%R86UE=&5R(&=R;W5P<PT*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=$=R;W5P<R@I#0H@("`@>PT*("`@("`@("`D=&UP
M(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F-O;F9I9W5R
M871I;VY?:6YF;R!A<R`D:V5Y(#T^("1I;F9O*2![#0H@("`@("`@("`@("`D
M=&UP6R1I;F9O6R=G<F]U<"==72`](#$[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&%R<F%Y7VME>7,H)'1M<"D[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&=E=$=R;W5P2V5Y<R@I#0H-"B`@("`O*BH-"B`@("`@
M*B!'970@=&AE(&QI<W0@;V8@=&AE('!A<F%M971E<G,@:6X@82!G<F]U<"X-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P('!A<F%M971E
M<B!G<F]U<`T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2!L:7-T(&]F
M('!A<F%M971E<G,@:6X@)&=R;W5P#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1W)O
M=7!+97ES*"1G<F]U<"D-"B`@("![#0H@("`@("`@("1K97ES(#T@87)R87DH
M*3L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF
M;R!A<R`D:V5Y(#T^("1I;F9O*2![#0H@("`@("`@("`@("!I9B`H)&EN9F];
M)V=R;W5P)UT@/3T@)&=R;W5P*2![#0H@("`@("`@("`@("`@("`@)&ME>7-;
M72`]("1K97D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1K97ES.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!G9713971686QU97,H:V5Y*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H
M92!L:7-T(&]F(&%L;&]W960@<V5T('9A;'5E<R!F;W(@82!C;VYF:6<@=F%L
M=64N("!2971U<FYS#0H@("`@("H@3E5,3"!F;W(@8V]N9FEG('9A;'5E<R!T
M:&%T(&%R92!N;W0@<V5T<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87D@
M96YU;65R871E9"!A<G)A>2!O9B!S970@=F%L=65S+"!O<B!.54Q,(&EF('1H
M90T*("`@("`J("`@("`@("`@("`@("`@8V]N9FEG(&ME>2!I<R!U;FMN;W=N
M(&]R(&YO="!A('-E=`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%-E=%9A;'5E<R@D
M:V5Y*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U
M<F%T:6]N7VEN9F];)&ME>5TI("8F#0H@("`@("`@("`@("!I<W-E="@D=&AI
M<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=T>7!E)UTI("8F#0H@("`@
M("`@("`@("`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=T>7!E
M)UT@/3T@)W-E="<I#0H@("`@("`@('L-"B`@("`@("`@("`@("1V86QI9%]S
M970@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=V86QI9%]S
M970G73L-"B`@("`@("`@("`@(')E<V5T*"1V86QI9%]S970I.PT*("`@("`@
M("`@("`@:68@*&ME>2@D=F%L:61?<V5T*2`]/3T@,"D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=F%L:61?<V5T.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)'9A;&ED7W-E="D[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=$ME>7,H*0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T(&%L;"!T:&4@8W5R<F5N="!C;VYF:6<@:V5Y<RX-"B`@("`@*@T*("`@
M("`J($!R971U<FX@87)R87D@<VEM<&QE(&%R<F%Y(&]F(&-O;F9I9R!K97ES
M#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$ME>7,H*0T*("`@('L-"B`@("`@("`@)&ME>7,@/2!A
M<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^;&%Y97)S(&%S("1L
M87EE<BD@>PT*("`@("`@("`@("`@)'1E<W0@/2`D=&AI<RT^8V]N9FEG=7)A
M=&EO;ELD;&%Y97)=.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T97-T6R=?
M7V-H86YN96QS)UTI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1E
M<W1;)U]?8VAA;FYE;',G72!A<R`D8VAA;FYE;"`]/B`D8V]N9FEG<RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D:V5Y<R`](&%R<F%Y7VUE<F=E*"1K97ES
M+"`D8V]N9FEG<RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@=6YS970H)'1E<W1;)U]?8VAA;FYE;',G72D[#0H@
M("`@("`@("`@("`D:V5Y<R`](&%R<F%Y7VUE<F=E*"1K97ES+"`D=&5S="D[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)&ME>7,I
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!R96UO=F4H:V5Y
M+"!;;&%Y97)=*0T*#0H@("`@+RHJ#0H@("`@("H@4F5M;W9E('1H92!A(&-O
M;F9I9R!K97D@9G)O;2!A('-P96-I9FEC(&-O;F9I9R!L87EE<BX-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`H;W!T:6]N86PI(&-O;F9I9R!L87EE<@T*
M("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@
M1D%,4T4@;VX@9F%I;'5R90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R96UO=F4H)&ME>2P@)&QA>65R
M(#T@)W5S97(G*0T*("`@('L-"B`@("`@("`@)&-H86YN96P@/2`D=&AI<RT^
M9V5T1&5F875L=$-H86YN96PH*3L-"B`@("`@("`@:68@*"1C:&%N;F5L("$]
M/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)U]?8VAA;FYE;',G75LD8VAA
M;FYE;%U;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M
M/F-O;F9I9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L
M75LD:V5Y72D[#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)&ME>5TI*2![#0H@("`@("`@("`@
M("!U;G-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=*3L-
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@<F5M;W9E3&%Y97(H;&%Y97(I#0H-"B`@("`O*BH-"B`@("`@*B!496UP
M;W)A<FEL>2!R96UO=F4@86X@96YT:7)E(&-O;F9I9R!L87EE<BX@(%5312!7
M251(($-!4D4A#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I
M9R!K97D-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@*&]P=&EO;F%L
M*2!C;VYF:6<@;&%Y97(-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!4
M4E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5M
M;W9E3&%Y97(H)&QA>65R*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<ETI*2![#0H@("`@("`@("`@("`D
M=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=(#T@87)R87DH*3L-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<W1O
M<F4H6VQA>65R72D-"@T*("`@("\J*@T*("`@("`J(%-T;W)E<R!C;VYF:6=U
M<F%T:6]N(&1A=&$@:6X@82!L87EE<BX-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@8V]N9FEG(&QA>65R('1O('-T;W)E#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!O<B!014%2(&5R<F]R
M(&]N(&9A:6QU<F4-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<W1O<F4H)&QA>65R(#T@)W5S97(G+"`D
M9&%T82`](&YU;&PI#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/G=R
M:71E0V]N9FEG1FEL92AN=6QL+"`D;&%Y97(L("1D871A*3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=&]$969A=6QT*&ME>2D-"@T*("`@
M("\J*@T*("`@("`J(%5N<V5T('1H92!U<V5R+61E9FEN960@=F%L=64@;V8@
M82!C;VYF:6<@:V5Y+"!R979E<G1I;F<@=&AE#0H@("`@("H@=F%L=64@=&\@
M=&AE('-Y<W1E;2UD969I;F5D(&]N92X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@8V]N9FEG(&ME>0T*("`@("`J#0H@("`@("H@0')E='5R;B!B
M;V]L(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!T;T1E9F%U;'0H)&ME>2D-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R
M;W(H(E!%05)?0V]N9FEG.CIT;T1E9F%U;'0H*2!D97!R96-A=&5D+"!U<V4@
M4$5!4E]#;VYF:6<Z.G)E;6]V92@I(&EN<W1E860B+"!%7U5315)?3D]424-%
M*3L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F4H)&ME>2P@)W5S97(G
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&5F:6YE9$)Y
M*&ME>2D-"@T*("`@("\J*@T*("`@("`J(%1E;&QS('=H870@8V]N9FEG(&QA
M>65R('1H870@9V5T<R!T;R!D969I;F4@82!K97DN#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!K97D-"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B!R971U<FX@=&AE(&1E9FEN:6YG(&-H86YN96P-"B`@("`@*@T*("`@
M("`J($!R971U<FX@<W1R:6YG?&%R<F%Y('1H92!C;VYF:6<@;&%Y97(L(&]R
M(&%N(&5M<'1Y('-T<FEN9R!I9B!N;W0@9F]U;F0N#0H@("`@("H-"B`@("`@
M*B`@("`@("`@(&EF("1R971U<FYC:&%N;F5L+"!T:&4@<F5T=7)N(&ES(&%N
M(&%R<F%Y(&%R<F%Y*"=L87EE<B<@/3X@;&%Y97)N86UE+`T*("`@("`J("`@
M("`@("`@)V-H86YN96PG(#T^(&-H86YN96QN86UE*2P@;W(@86X@96UP='D@
M<W1R:6YG(&EF(&YO="!F;W5N9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D969I;F5D0GDH)&ME>2P@
M)')E='5R;F-H86YN96P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YL87EE<G,@87,@)&QA>65R*2![#0H@("`@("`@("`@("`D
M8VAA;FYE;"`]("1T:&ES+3YG971$969A=6QT0VAA;FYE;"@I.PT*("`@("`@
M("`@("`@:68@*"1C:&%N;F5L("$]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD
M;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN96Q=6R1K97E=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E='5R;F-H86YN96PI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@G;&%Y97(G(#T^("1L
M87EE<BP@)V-H86YN96PG(#T^("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&QA>65R.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=
M*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D<F5T=7)N8VAA;FYE;"D@>PT*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH)VQA>65R)R`]/B`D
M;&%Y97(L("=C:&%N;F5L)R`]/B`G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D;&%Y97([#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("<G.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!I<T1E9F%U;'1E9"AK
M97DI#0H-"B`@("`O*BH-"B`@("`@*B!496QL<R!W:&5T:&5R(&$@8V]N9FEG
M('9A;'5E(&AA<R!A('-Y<W1E;2UD969I;F5D('9A;'5E+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`@(&-O;F9I9R!K97D-"B`@("`@*@T*("`@
M("`J($!R971U<FX@8F]O;`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*@T*("`@("`J($!D97!R96-A=&5D#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@:7-$969A=6QT960H)&ME>2D-"B`@("![#0H@("`@("`@('1R
M:6=G97)?97)R;W(H(E!%05)?0V]N9FEG.CII<T1E9F%U;'1E9"@I(&1E<')E
M8V%T960L('5S92!014%27T-O;F9I9SHZ9&5F:6YE9$)Y*"D@:6YS=&5A9"(L
M($5?55-%4E].3U1)0T4I.PT*("`@("`@("!R971U<FX@)'1H:7,M/F1E9FEN
M961">2@D:V5Y*2`]/2`G<WES=&5M)SL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@:7-$969I;F5D*&ME>2D-"@T*("`@("\J*@T*("`@("`J
M(%1E;&QS('=H971H97(@82!G:79E;B!K97D@97AI<W1S(&%S(&$@8V]N9FEG
M('9A;'5E+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@
M:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@=VAE=&AE<B`\8V]N
M9FEG(&ME>3X@97AI<W1S(&EN('1H:7,@;V)J96-T#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES1&5F
M:6YE9"@D:V5Y*0T*("`@('L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQA
M>65R<R!A<R`D;&%Y97(I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@:7-$969I;F5D3&%Y97(H:V5Y*0T*#0H@("`@+RHJ#0H@
M("`@("H@5&5L;',@=VAE=&AE<B!A(&=I=F5N(&-O;F9I9R!L87EE<B!E>&ES
M=',N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!L87EE
M<@T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L('=H971H97(@/&-O;F9I
M9R!L87EE<CX@97AI<W1S(&EN('1H:7,@;V)J96-T#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES1&5F
M:6YE9$QA>65R*"1L87EE<BD-"B`@("![#0H@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=*3L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@9V5T3&%Y97)S*"D-"@T*("`@("\J*@T*
M("`@("`J(%)E='5R;G,@=&AE(&QA>65R<R!D969I;F5D("AE>&-E<'0@=&AE
M("=D969A=6QT)R!O;F4I#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M(&]F('1H92!D969I;F5D(&QA>65R<PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=$QA>65R<R@I#0H@("`@>PT*("`@("`@("`D8V8@/2`D=&AI<RT^8V]N
M9FEG=7)A=&EO;CL-"B`@("`@("`@=6YS970H)&-F6R=D969A=6QT)UTI.PT*
M("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D8V8I.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!A<&E697)S:6]N*"D-"B`@("!F=6YC=&EO
M;B!A<&E697)S:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G,2XQ)SL-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N
M(%!%05)?4F5G:7-T<GD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4F5G
M:7-T<GDH)'5S92`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H)'5S92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&QA>65R(#T@)W5S97(G.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&QA>65R(#T@)'5S93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]R96=I<W1R>5LD
M;&%Y97)=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T
M<GE;)&QA>65R73L-"B`@("`@("`@?2!E;'-E:68@*"1U<V4@/3T](&YU;&P@
M)B8@:7-S970H)'1H:7,M/E]R96=I<W1R>5LG<WES=&5M)UTI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]R96=I<W1R>5LG<WES=&5M)UT[#0H@
M("`@("`@('T@96QS96EF("@D=7-E(#T]/2!N=6QL("8F(&ES<V5T*"1T:&ES
M+3Y?<F5G:7-T<GE;)V1E9F%U;'0G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)E9VES=')Y6R=D969A=6QT)UT[#0H@("`@("`@('T@96QS
M96EF("@D=7-E*2![#0H@("`@("`@("`@("`D82`](&9A;'-E.PT*("`@("`@
M("`@("`@<F5T=7)N("1A.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@+R\@;VYL>2!G;R!H97)E(&EF(&YU;&P@=V%S('!A<W-E9"!I;@T*("`@
M("`@("`@("`@9&EE*")#4DE424-!3"!%4E)/4CH@4F5G:7-T<GD@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D(&9R;VT@86YY('9A;'5E(BD[#0H@("`@("`@
M('T-"B`@("!]#0H@("`@+RHJ#0H@("`@("H@5&AI<R!I<R!T;R!A;&QO=R!C
M=7-T;VUI>F%T:6]N(&QI:V4@=&AE('5S92!O9B!I;G-T86QL<F]O=`T*("`@
M("`J($!P87)A;2!014%27U)E9VES=')Y#0H@("`@("H@0')E='5R;B!B;V]L
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4F5G:7-T<GDH)B1R96<L("1L
M87EE<B`]("=U<V5R)RD-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7VYO
M4F5G:7-T<GDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1L87EE<BP@87)R87DH)W5S
M97(G+"`G<WES=&5M)RDI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=
M(#T@)B1R96<[#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)')E9RDI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72T^<V5T0V]N9FEG
M*"1T:&ES*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!N;U)E9VES=')Y*"D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?;F]296=I<W1R>2`]('1R=64[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0')E='5R;B!014%27U)E;6]T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N("9G971296UO=&4H*0T*("`@('L-"B`@("`@("`@)')E;6]T
M92`]("9N97<@4$5!4E]296UO=&4H)'1H:7,I.PT*("`@("`@("!R971U<FX@
M)')E;6]T93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(%!%
M05)?4D535`T*("`@("`J+PT*("`@(&9U;F-T:6]N("9G971215-4*"1V97)S
M:6]N+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D=F5R
M<VEO;B`]('-T<E]R97!L86-E*"<N)RP@)R<L("1V97)S:6]N*3L-"B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S(#T@)U!%05)?4D535%\G("X@
M)'9E<G-I;VXI*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O
M4D535"\G("X@)'9E<G-I;VX@+B`G+G!H<"<[#0H@("`@("`@('T-"B`@("`@
M("`@)')E;6]T92`]("9N97<@)&-L87-S*"1T:&ES+"`D;W!T:6]N<RD[#0H@
M("`@("`@(')E='5R;B`D<F5M;W1E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%1H92!F='`@<V5R=F5R(&ES('-E="!I;B![0&QI;FL@<F5A9$944$-O
M;F9I9T9I;&4H*7TN("!)="!E>&ES=',@;VYL>2!I9B!A#0H@("`@("H@<F5M
M;W1E(&-O;F9I9W5R871I;VX@9FEL92!H87,@8F5E;B!S<&5C:69I960-"B`@
M("`@*B!`<F5T=7)N(%!%05)?1E10?&9A;'-E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@)F=E=$944"@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]F='`I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]F='`[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D82`](&9A;'-E.PT*
M("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+R\@>WM[(%]P<F5P96YD4&%T:"@D<&%T:"P@)'!R97!E;F0I#0H-"B`@
M("!F=6YC=&EO;B!?<')E<&5N9%!A=&@H)'!A=&@L("1P<F5P96YD*0T*("`@
M('L-"B`@("`@("`@:68@*'-T<FQE;B@D<')E<&5N9"D@/B`P*2![#0H@("`@
M("`@("`@("!I9B`H3U-?5TE.1$]74R`F)B!P<F5G7VUA=&-H*"<O7EMA+7I=
M.B]I)RP@)'!A=&@I*2![#0H@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R]>6V$M>ETZ+VDG+"`D<')E<&5N9"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)'!R97!E;F0@/2!S=6)S='(H)'!R97!E;F0L(#(I.PT*("`@("`@
M("`@("`@("`@('T@96QS96EF("@D<')E<&5N9'LP?2`A/2`G7%PG*2![#0H@
M("`@("`@("`@("`@("`@("`@("1P<F5P96YD(#T@(EQ<)'!R97!E;F0B.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&%T:"`]('-U
M8G-T<B@D<&%T:"P@,"P@,BD@+B`D<')E<&5N9"`N('-U8G-T<B@D<&%T:"P@
M,BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1P
M871H(#T@)'!R97!E;F0@+B`D<&%T:#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)'!A=&@[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!I;G-T
M86QL871I;VX@9&ER96-T;W)Y('1O('!R97!E;F0@=&\@86QL(%]D:7(@=F%R
M:6%B;&5S+"!O<B!F86QS92!T;PT*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@9&ES86)L90T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$EN<W1A;&Q2
M;V]T*"1R;V]T*0T*("`@('L-"B`@("`@("`@:68@*'-U8G-T<B@D<F]O="P@
M+3$I(#T]($1)4D5#5$]265]315!!4D%43U(I('L-"B`@("`@("`@("`@("1R
M;V]T(#T@<W5B<W1R*"1R;V]T+"`P+"`M,2D[#0H@("`@("`@('T-"B`@("`@
M("`@)&]L9"`]("1T:&ES+3Y?:6YS=&%L;%)O;W0[#0H@("`@("`@("1T:&ES
M+3Y?:6YS=&%L;%)O;W0@/2`D<F]O=#L-"B`@("`@("`@:68@*"@D;VQD("$]
M("1R;V]T*2`F)B`A)'1H:7,M/E]N;U)E9VES=')Y*2![#0H@("`@("`@("`@
M("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?<F5G:7-T<GDI(&%S("1L
M87EE<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D;&%Y97(@/3T@)V9T<"<@
M?'P@(6ES<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72`]#0H@
M("`@("`@("`@("`@("`@("`@("9N97<@4$5!4E]296=I<W1R>2@D=&AI<RT^
M9V5T*"=P:'!?9&ER)RP@)&QA>65R+"`G<&5A<BYP:'`N;F5T)RDI.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72T^<V5T0V]N
M9FEG*"1T:&ES*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9TEN:71I
M86QI>F5D6R1L87EE<ET@/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@('T-"GT-"@T*/SX-"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+T1E<&5N9&5N8WDN<&AP````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`T,S(R,@`Q,#4Q-30S,3`U-P`P,C`V-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\O#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@
M-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L-"B\O('P@075T:&]R<SH@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N
M970N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@
M("`@("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L-"B\O#0HO+R!42$E3($9)3$4@25,@1$504D5#051%1"!)
M3B!&059/4B!/1B!$15!%3D1%3D-9,BY02%`L($%.1"!)4R!.3U0@55-%1"!)
M3B!42$4@24Y35$%,3$52#0HO+R`D260Z($1E<&5N9&5N8WDN<&AP+'8@,2XT
M,2`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*#0IR97%U:7)E
M7V]N8V4@(E!%05(N<&AP(CL-"G)E<75I<F5?;VYC92`B3U,O1W5E<W,N<&AP
M(CL-"@T*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?34E34TE.1R<L("`@("`@
M("`M,2D[#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]#3TY&3$E#5"<L("`@
M("`@("TR*3L-"F1E9FEN92@G4$5!4E]$15!%3D1%3D-97U501U)!1$5?34E.
M3U(G+"`@+3,I.PT*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?55!'4D%$15]-
M04I/4B<L("`M-"D[#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]"041?1$50
M14Y$14Y#62<L("TU*3L-"F1E9FEN92@G4$5!4E]$15!%3D1%3D-97TU)4U-)
M3D=?3U!424].04PG+"`M-BD[#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]#
M3TY&3$E#5%]/4%1)3TY!3"<L("`@("`@("TW*3L-"F1E9FEN92@G4$5!4E]$
M15!%3D1%3D-97U501U)!1$5?34E.3U)?3U!424].04PG+"`@+3@I.PT*9&5F
M:6YE*"=014%27T1%4$5.1$5.0UE?55!'4D%$15]-04I/4E]/4%1)3TY!3"<L
M("`M.2D[#0H-"B\J*@T*("H@1&5P96YD96YC>2!C:&5C:R!F;W(@4$5!4B!P
M86-K86=E<PT*("H-"B`J(%1H92!C;&%S<R!I<R!B87-E9"!O;B!T:&4@9&5P
M96YD96YC>2!21D,@=&AA="!C86X@8F4@9F]U;F0@870-"B`J(&AT='`Z+R]C
M=G,N<&AP+FYE="]C=G,N<&AP+W!E87)W96(O<F9C+B!)="!R97%U:7)E<R!0
M2%`@/CT@-"XQ#0H@*@T*("H@0&%U=&AO<B!4;VUA<R!6+E8N5F]X(#QC;WA`
M:61E8VYE="YC;VT^#0H@*B!`875T:&]R(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J+PT*8VQA<W,@4$5!4E]$97!E;F1E;F-Y#0I[#0H@("`@+R\@
M>WM[(&-O;G-T<G5C=&]R#0H@("`@+RHJ#0H@("`@("H@0V]N<W1R=6-T;W(-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'!A<F%M
M("!O8FIE8W0@4F5G:7-T<GD@;V)J96-T#0H@("`@("H@0')E='5R;B!V;VED
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]$97!E;F1E;F-Y*"8D<F5G
M:7-T<GDI#0H@("`@>PT*("`@("`@("`D=&AI<RT^<F5G:7-T<GD@/2`F)')E
M9VES=')Y.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C86QL
M0VAE8VM-971H;V0H*0T*#0H@("`@+RHJ#0H@("`@*B!4:&ES(&UE=&AO9"!M
M87!S('1H92!834P@9&5P96YD96YC>2!D969I;FET:6]N('1O('1H90T*("`@
M("H@8V]R<F5S<&]N9&EN9R!O;F4@9G)O;2!014%27T1E<&5N9&5N8WD-"B`@
M("`J#0H@("`@*B`\<')E/@T*("`@("H@)&]P=',@/3X@07)R87D-"B`@("`J
M("`@("@-"B`@("`J("`@("`@("!;='EP95T@/3X@<&MG#0H@("`@*B`@("`@
M("`@6W)E;%T@/3X@9V4-"B`@("`J("`@("`@("!;=F5R<VEO;ET@/3X@,RXT
M#0H@("`@*B`@("`@("`@6VYA;65=(#T^($A434Q?0V]M;6]N#0H@("`@*B`@
M("`@("`@6V]P=&EO;F%L72`]/B!F86QS90T*("`@("H@("`@*0T*("`@("H@
M/"]P<F4^#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@17)R;W(@;65S
M<V%G90T*("`@("H@0'!A<F%M("!A<G)A>2`@3W!T:6]N<PT*("`@("H@0')E
M='5R;B!B;V]L96%N#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C86QL0VAE8VM-
M971H;V0H)B1E<G)M<V<L("1O<'1S*0T*("`@('L-"B`@("`@("`@)')E;"`]
M(&ES<V5T*"1O<'1S6R=R96PG72D@/R`D;W!T<ULG<F5L)UT@.B`G:&%S)SL-
M"B`@("`@("`@)')E<2`](&ES<V5T*"1O<'1S6R=V97)S:6]N)UTI(#\@)&]P
M='-;)W9E<G-I;VXG72`Z(&YU;&P[#0H@("`@("`@("1N86UE(#T@:7-S970H
M)&]P='-;)VYA;64G72D@/R`D;W!T<ULG;F%M92==(#H@;G5L;#L-"B`@("`@
M("`@)&-H86YN96P@/2!I<W-E="@D;W!T<ULG8VAA;FYE;"==*2`_("1O<'1S
M6R=C:&%N;F5L)UT@.B`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@)&]P="`]
M("AI<W-E="@D;W!T<ULG;W!T:6]N86PG72D@)B8@)&]P='-;)V]P=&EO;F%L
M)UT@/3T@)WEE<R<I(#\-"B`@("`@("`@("`@("1O<'1S6R=O<'1I;VYA;"==
M(#H@;G5L;#L-"B`@("`@("`@)&5R<FUS9R`]("<G.PT*("`@("`@("!S=VET
M8V@@*"1O<'1S6R=T>7!E)UTI('L-"B`@("`@("`@("`@(&-A<V4@)W!K9R<Z
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC:&5C:U!A8VMA9V4H
M)&5R<FUS9RP@)&YA;64L("1R97$L("1R96PL("1O<'0L("1C:&%N;F5L*3L-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V5X
M="<Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC:&5C:T5X=&5N
M<VEO;B@D97)R;7-G+"`D;F%M92P@)')E<2P@)')E;"P@)&]P="D[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=P:'`G.@T*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8VAE8VM02%`H)&5R<FUS
M9RP@)')E<2P@)')E;"D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E("=P<F]G)SH-"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F-H96-K4')O9W)A;2@D97)R;7-G+"`D;F%M92D[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=O<R<Z#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC:&5C:T]3*"1E<G)M<V<L("1N
M86UE*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@)W-A<&DG.@T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8VAE
M8VM305!)*"1E<G)M<V<L("1N86UE*3L-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@(&-A<V4@)WIE;F0G.@T*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^8VAE8VM:96YD*"1E<G)M<V<L("1N86UE*3L-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("(G>R1O<'1S6R=T>7!E)UU])R!D97!E
M;F1E;F-Y('1Y<&4@;F]T('-U<'!O<G1E9"([#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAE8VM086-K86=E*"D-"@T*
M("`@("\J*@T*("`@("`J(%!A8VMA9V4@9&5P96YD96YC:65S(&-H96-K(&UE
M=&AO9`T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D97)R;7-G("`@
M($5M<'1Y('-T<FEN9RP@:70@=VEL;"!B92!P;W!U;&%T960@=VET:"!A;B!E
M<G)O<B!M97-S86=E+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@("`@3F%M92!O9B!T:&4@<&%C:V%G92!T;R!T97-T#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<F5Q("`@("`@(%1H92!P86-K86=E('9E<G-I;VX@
M<F5Q=6ER960-"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96QA=&EO;B`@2&]W
M('1O(&-O;7!A<F4@=F5R<VEO;G,@=VET:"!E86-H(&]T:&5R#0H@("`@("H@
M0'!A<F%M(&)O;VP@("`D;W!T("`@("`@(%=H971H97(@=&AE(')E;&%T:6]N
M<VAI<"!I<R!O<'1I;VYA;`T*("`@("`J($!P87)A;2!S=')I;F<@)&-H86YN
M96P@("!#:&%N;F5L(&YA;64-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX
M960@8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@97)R;W(@<W1R:6YG
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAE8VM086-K86=E*"8D97)R;7-G
M+"`D;F%M92P@)')E<2`](&YU;&PL("1R96QA=&EO;B`]("=H87,G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;W!T(#T@9F%L<V4L("1C:&%N;F5L
M(#T@)W!E87(N<&AP+FYE="<I#0H@("`@>PT*("`@("`@("!I9B`H:7-?<W1R
M:6YG*"1R97$I("8F('-U8G-T<B@D<F5Q+"`P+"`R*2`]/2`G=BXG*2![#0H@
M("`@("`@("`@("`D<F5Q(#T@<W5B<W1R*"1R97$L(#(I.PT*("`@("`@("!]
M#0H@("`@("`@('-W:71C:"`H)')E;&%T:6]N*2![#0H@("`@("`@("`@("!C
M87-E("=H87,G.@T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/G)E9VES
M=')Y+3YP86-K86=E17AI<W1S*"1N86UE+"`D8VAA;FYE;"DI('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1O<'0I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1E<G)M<V<@/2`B<&%C:V%G92!@)&-H86YN96PO)&YA;64G(&ES
M(')E8V]M;65N9&5D('1O('5T:6QI>F4@<V]M92!F96%T=7)E<RXB.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]-
M25-324Y'7T]05$E/3D%,.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B<F5Q=6ER97,@<&%C:V%G92!@
M)&-H86YN96PO)&YA;64G(CL-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05)?1$5014Y$14Y#65]-25-324Y'.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!C
M87-E("=N;W0G.@T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^<F5G:7-T
M<GDM/G!A8VMA9V5%>&ES=',H)&YA;64L("1C:&%N;F5L*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D97)R;7-G(#T@(F-O;F9L:6-T<R!W:71H('!A8VMA
M9V4@8"1C:&%N;F5L+R1N86UE)R([#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!014%27T1%4$5.1$5.0UE?0T].1DQ)0U0[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@(&-A<V4@)VQT)SH-"B`@("`@("`@("`@(&-A<V4@)VQE)SH-"B`@("`@
M("`@("`@(&-A<V4@)V5Q)SH-"B`@("`@("`@("`@(&-A<V4@)VYE)SH-"B`@
M("`@("`@("`@(&-A<V4@)V=E)SH-"B`@("`@("`@("`@(&-A<V4@)V=T)SH-
M"B`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3YR96=I<W1R>2T^
M<&%C:V%G94EN9F\H)&YA;64L("=V97)S:6]N)RP@)&-H86YN96PI.PT*("`@
M("`@("`@("`@("`@(&EF("@A)'1H:7,M/G)E9VES=')Y+3YP86-K86=E17AI
M<W1S*"1N86UE+"`D8VAA;FYE;"D-"B`@("`@("`@("`@("`@("`@("`@?'P@
M(79E<G-I;VY?8V]M<&%R92@B)'9E<G-I;VXB+"`B)')E<2(L("1R96QA=&EO
M;BDI#0H@("`@("`@("`@("`@("`@>PT*("`@("`@("`@("`@("`@("`@("`D
M8V]D92`]("1T:&ES+3YC;V1E1G)O;5)E;&%T:6]N*"1R96QA=&EO;BP@)'9E
M<G-I;VXL("1R97$L("1O<'0I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&]P="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<FUS9R`](")P
M86-K86=E(&`D8VAA;FYE;"\D;F%M92<@=F5R<VEO;B`B("X@)'1H:7,M/G-I
M9VY/<&5R871O<B@D<F5L871I;VXI("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B("1R97$@:7,@<F5C;VUM96YD960@=&\@=71I;&EZ92!S;VUE
M(&9E871U<F5S+B([#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'9E
M<G-I;VXI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R;7-G
M("X]("(@($EN<W1A;&QE9"!V97)S:6]N(&ES("1V97)S:6]N(CL-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D8V]D93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`D97)R;7-G(#T@(G)E<75I<F5S('!A8VMA9V4@8"1C
M:&%N;F5L+R1N86UE)R`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS:6=N3W!E<F%T;W(H)')E;&%T:6]N*2`N("(@)')E<2([#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D8V]D93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@("1E<G)M<V<@/2`B<F5L871I;VX@)R1R96QA=&EO;B<@=VET
M:"!R97%U:7)E;65N="`G)')E<2<@:7,@;F]T('-U<'!O<G1E9"`H;F%M93TD
M8VAA;FYE;"\D;F%M92DB.PT*("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%
M3D-97T)!1%]$15!%3D1%3D-9.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!C:&5C:U!A8VMA9V55;FEN<W1A;&PH*0T*#0H@("`@+RHJ#0H@
M("`@("H@0VAE8VL@<&%C:V%G92!D97!E;F1E;F-I97,@;VX@=6YI;G-T86QL
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O<B`@("`@5&AE
M(')E<W5L=&%N="!E<G)O<B!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1W87)N:6YG("`@5&AE(')E<W5L=&%N="!W87)N:6YG('-T<FEN9PT*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!.86UE(&]F('1H92!P86-K
M86=E('1O('1E<W0-"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%N;F5L("`@
M0VAA;FYE;"!N86UE(&]F('1H92!P86-K86=E#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N(&)O;VP@=')U92!I9B!T:&5R92!W97)E(&5R<F]R<PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&-H96-K4&%C:V%G955N:6YS=&%L;"@F)&5R<F]R
M+"`F)'=A<FYI;F<L("1P86-K86=E+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN
M970G*0T*("`@('L-"B`@("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1C
M:&%N;F5L*3L-"B`@("`@("`@)&5R<F]R(#T@;G5L;#L-"B`@("`@("`@)&-H
M86YN96QS(#T@)'1H:7,M/G)E9VES=')Y+3YL:7-T06QL4&%C:V%G97,H*3L-
M"B`@("`@("`@9F]R96%C:"`H)&-H86YN96QS(&%S("1C:&%N;F5L;F%M92`]
M/B`D<&%C:V%G97,I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E
M<R!A<R`D<&MG*2![#0H@("`@("`@("`@("`@("`@:68@*"1P:V<@/3T@)'!A
M8VMA9V4@)B8@)&-H86YN96P@/3T@)&-H86YN96QN86UE*2![#0H@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D9&5P<R`]("1T:&ES+3YR96=I<W1R>2T^<&%C:V%G
M94EN9F\H)'!K9RP@)W)E;&5A<V5?9&5P<R<L("1C:&%N;F5L*3L-"B`@("`@
M("`@("`@("`@("!I9B`H96UP='DH)&1E<',I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9&5P*2![#0H@("`@("`@("`@
M("`@("`@("`@("1D97!C:&%N;F5L(#T@:7-S970H)&1E<%LG8VAA;FYE;"==
M*2`_("1D97!;)V-H86YN96PG72`Z("=P96%R+G!H<"YN970G.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==(#T]("=P:V<G("8F("AS
M=')C87-E8VUP*"1D97!;)VYA;64G72P@)'!A8VMA9V4I(#T](#`I("8F#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("@D9&5P8VAA;FYE;"`]/2`D8VAA
M;FYE;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P6R=R
M96PG72`]/2`G;F4G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;W!T:6]N86PG72D@
M)B8@)&1E<%LG;W!T:6]N86PG72`]/2`G>65S)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1W87)N:6YG("X](")<;E=A<FYI;F<Z(%!A8VMA
M9V4@)R1D97!C:&%N;F5L+R1P:V<G(&]P=&EO;F%L;'D@9&5P96YD<R!O;B`G
M)&-H86YN96PZ+W!A8VMA9V4G(CL-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R
M("X](")086-K86=E("<D9&5P8VAA;FYE;"\D<&MG)R!D97!E;F1S(&]N("<D
M8VAA;FYE;"\D<&%C:V%G92=<;B([#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("@D
M97)R;W(I(#\@=')U92`Z(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!C:&5C:T5X=&5N<VEO;B@I#0H-"B`@("`O*BH-"B`@("`@
M*B!%>'1E;G-I;VX@9&5P96YD96YC:65S(&-H96-K(&UE=&AO9`T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@3F%M92!O9B!T
M:&4@97AT96YS:6]N('1O('1E<W0-"B`@("`@*B!`<&%R86T@<W1R:6YG("1R
M97%?97AT7W9E<B!297%U:7)E9"!E>'1E;G-I;VX@=F5R<VEO;B!T;R!C;VUP
M87)E('=I=&@-"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96QA=&EO;B`@("!(
M;W<@=&\@8V]M<&%R92!V97)S:6]N<R!W:71H(&5A8VAO=&AE<@T*("`@("`J
M($!P87)A;2!B;V]L("`@)&]P="`@("`@("`@(%=H971H97(@=&AE(')E;&%T
M:6]N<VAI<"!I<R!O<'1I;VYA;`T*("`@("`J#0H@("`@("H@0')E='5R;B!M
M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R<F]R(&]R('1H92!E<G)O<B!S=')I
M;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C:&5C:T5X=&5N<VEO;B@F)&5R
M<FUS9RP@)&YA;64L("1R97$@/2!N=6QL+"`D<F5L871I;VX@/2`G:&%S)RP-
M"B`@("`@("`@)&]P="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1R
M96QA=&EO;B`]/2`G;F]T)RD@>PT*("`@("`@("`@("`@:68@*&5X=&5N<VEO
M;E]L;V%D960H)&YA;64I*2![#0H@("`@("`@("`@("`@("`@)&5R<FUS9R`]
M(")C;VYF;&EC=',@=VET:"`@4$A0(&5X=&5N<VEO;B`G)&YA;64G(CL-"B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%3D-97T-/3D9,24-4
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@
M("!I9B`H(65X=&5N<VEO;E]L;V%D960H)&YA;64I*2![#0H@("`@("`@("`@
M("!I9B`H)')E;&%T:6]N(#T]("=N92<I('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M)&]P="D@>PT*("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B)R1N86UE)R!0
M2%`@97AT96YS:6]N(&ES(')E8V]M;65N9&5D('1O('5T:6QI>F4@<V]M92!F
M96%T=7)E<R([#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$
M14Y#65]-25-324Y'7T]05$E/3D%,.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)&5R<FUS9R`]("(G)&YA;64G(%!(4"!E>'1E;G-I;VX@:7,@;F]T
M(&EN<W1A;&QE9"([#0H@("`@("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%
M3D-97TU)4U-)3D<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1R96QA=&EO
M;B`]/2`G:&%S)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@("1C;V1E(#T@9F%L<V4[#0H@("`@("`@(&EF("AI
M<U]S=')I;F<H)')E<2D@)B8@<W5B<W1R*"1R97$L(#`L(#(I(#T]("=V+B<I
M('L-"B`@("`@("`@("`@("1R97$@/2!S=6)S='(H)')E<2P@,BD[#0H@("`@
M("`@('T-"B`@("`@("`@)&5X=%]V97(@/2!P:'!V97)S:6]N*"1N86UE*3L-
M"B`@("`@("`@)&]P97)A=&]R(#T@)')E;&%T:6]N.PT*("`@("`@("`O+R!&
M;W)C92!P87)A;7,@=&\@8F4@<W1R:6YG<RP@;W1H97)W:7-E('1H92!C;VUP
M87)A=&EO;B!W:6QL(&9A:6P@*&5X+B`P+CD]/3`N.3`I#0H@("`@("`@(&EF
M("@A=F5R<VEO;E]C;VUP87)E*"(D97AT7W9E<B(L("(D<F5Q(BP@)&]P97)A
M=&]R*2D@>PT*("`@("`@("`@("`@)&5R<FUS9R`]("(G)&YA;64G(%!(4"!E
M>'1E;G-I;VX@=F5R<VEO;B`B("X-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M<VEG;D]P97)A=&]R*"1O<&5R871O<BD@+B`B("1R97$@:7,@<F5Q=6ER960B
M.PT*("`@("`@("`@("`@)&-O9&4@/2`D=&AI<RT^8V]D949R;VU296QA=&EO
M;B@D<F5L871I;VXL("1E>'1?=F5R+"`D<F5Q+"`D;W!T*3L-"B`@("`@("`@
M("`@(&EF("@D;W!T*2![#0H@("`@("`@("`@("`@("`@)&5R<FUS9R`]("(G
M)&YA;64G(%!(4"!E>'1E;G-I;VX@=F5R<VEO;B`B("X@)'1H:7,M/G-I9VY/
M<&5R871O<B@D;W!E<F%T;W(I("X-"B`@("`@("`@("`@("`@("`@("`@(B`D
M<F5Q(&ES(')E8V]M;65N9&5D('1O('5T:6QI>F4@<V]M92!F96%T=7)E<R([
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1C;V1E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D8V]D93L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAE8VM/4R@I#0H-"B`@("`O*BH-
M"B`@("`@*B!/<&5R871I;F<@<WES=&5M("!D97!E;F1E;F-I97,@8VAE8VL@
M;65T:&]D#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<R`@3F%M
M92!O9B!T:&4@;W!E<F%T:6YG('-Y<W1E;0T*("`@("`J#0H@("`@("H@0')E
M='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R<F]R(&]R('1H92!E<G)O
M<B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C:&5C:T]3*"8D97)R
M;7-G+"`D;W,I#0H@("`@>PT*("`@("`@("`O+R!86%@@1FEX;64Z($EM<&QE
M;65N="!A(&UO<F4@9FQE>&EB;&4@=V%Y+"!L:6ME#0H@("`@("`@("\O(&-O
M;6UA('-E<&%R871E9"!V86QU97,@;W(@<V]M971H:6YG('-I;6EL87(@=&\@
M4$5!4E]/4PT*("`@("`@("!S=&%T:6,@)&UY;W,[#0H@("`@("`@(&EF("AE
M;7!T>2@D;7EO<RDI('L-"B`@("`@("`@("`@("1M>6]S(#T@;F5W($]37T=U
M97-S*"D[#0H@("`@("`@('T-"B`@("`@("`@+R\@;VYL>2`G:&%S)R!R96QA
M=&EO;B!I<R!C=7)R96YT;'D@<W5P<&]R=&5D#0H@("`@("`@(&EF("@D;7EO
M<RT^;6%T8VA3:6=N871U<F4H)&]S*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1E<G)M<V<@/2`B)R1O<R<@
M;W!E<F%T:6YG('-Y<W1E;2!N;W0@<W5P<&]R=&5D(CL-"B`@("`@("`@<F5T
M=7)N(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5#L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@8VAE8VM02%`H*0T*#0H@("`@+RHJ#0H@("`@
M("H@4$A0('9E<G-I;VX@8VAE8VL@;65T:&]D#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1R97$@("!W:&EC:"!V97)S:6]N('1O(&-O;7!A<F4-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96QA=&EO;B`@:&]W('1O(&-O;7!A
M<F4@=&AE('9E<G-I;VX-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@
M8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@97)R;W(@<W1R:6YG#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@8VAE8VM02%`H)B1E<G)M<V<L("1R97$L
M("1R96QA=&EO;B`]("=G92<I#0H@("`@>PT*("`@("`@("`O+R!T:&ES('=O
M=6QD(&)E(&$@8FET('-T=7!I9"P@8G5T(&]H('=E;&P@.BD-"B`@("`@("`@
M:68@*"1R96QA=&EO;B`]/2`G:&%S)RD@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<F5L871I;VX@/3T@
M)VYO="<I('L-"B`@("`@("`@("`@("1E<G)M<V<@/2`B26YV86QI9"!D97!E
M;F1E;F-Y("T@)VYO="<@:7,@86QL;W=E9"!W:&5N('-P96-I9GEI;F<@4$A0
M+"!Y;W4@;75S="!R=6X@4$A0(&EN(%!(4"([#0H@("`@("`@("`@("!R971U
M<FX@4$5!4E]$15!%3D1%3D-97T)!1%]$15!%3D1%3D-9.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AS=6)S='(H)')E<2P@,"P@,BD@/3T@)W8N)RD@>PT*
M("`@("`@("`@("`@)')E<2`]('-U8G-T<B@D<F5Q+#(L('-T<FQE;B@D<F5Q
M*2`M(#(I.PT*("`@("`@("!]#0H@("`@("`@("1P:'!?=F5R(#T@<&AP=F5R
M<VEO;B@I.PT*("`@("`@("`D;W!E<F%T;W(@/2`D<F5L871I;VX[#0H@("`@
M("`@(&EF("@A=F5R<VEO;E]C;VUP87)E*"(D<&AP7W9E<B(L("(D<F5Q(BP@
M)&]P97)A=&]R*2D@>PT*("`@("`@("`@("`@)&5R<FUS9R`](")02%`@=F5R
M<VEO;B`B("X@)'1H:7,M/G-I9VY/<&5R871O<B@D;W!E<F%T;W(I("X-"B`@
M("`@("`@("`@("`@("`B("1R97$@:7,@<F5Q=6ER960B.PT*("`@("`@("`@
M("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5#L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&-H96-K4')O9W)A;2@I#0H-"B`@("`O*BH-"B`@("`@
M*B!%>'1E<FYA;"!P<F]G<F%M(&-H96-K(&UE=&AO9"X@($QO;VMS(&9O<B!E
M>&5C=71A8FQE(&9I;&5S(&EN#0H@("`@("H@9&ER96-T;W)I97,@;&ES=&5D
M(&EN('1H92!0051((&5N=FER;VYM96YT('9A<FEA8FQE+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<')O9W)A;2`@('=H:6-H('!R;V=R86T@
M=&\@;&]O:R!F;W(-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@8F]O
M;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@97)R;W(@<W1R:6YG#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@8VAE8VM0<F]G<F%M*"8D97)R;7-G+"`D<')O
M9W)A;2D-"B`@("![#0H@("`@("`@("\O(%A86"!&25A-12!H;VYO<B!S869E
M(&UO9&4-"B`@("`@("`@)&5X95]S=69F:7@@/2!/4U]724Y$3U=3(#\@)RYE
M>&4G(#H@)R<[#0H@("`@("`@("1P871H7V5L96UE;G1S(#T@97AP;&]D92A0
M051(7U-%4$%2051/4BP@9V5T96YV*"=0051()RDI.PT*("`@("`@("!F;W)E
M86-H("@D<&%T:%]E;&5M96YT<R!A<R`D9&ER*2![#0H@("`@("`@("`@("`D
M9FEL92`]("1D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!R;V=R86T@
M+B`D97AE7W-U9F9I>#L-"B`@("`@("`@("`@(&EF("A`9FEL95]E>&ES=',H
M)&9I;&4I("8F($!I<U]E>&5C=71A8FQE*"1F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D97)R;7-G(#T@(B<D<')O9W)A;2<@<')O9W)A;2!I<R!N
M;W0@<')E<V5N="!I;B!T:&4@4$%42"([#0H@("`@("`@(')E='5R;B!014%2
M7T1%4$5.1$5.0UE?34E34TE.1SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@8VAE8VM305!)*"D-"@T*("`@("\J*@T*("`@("`J(%-!4$D@
M8F%C:V5N9"!C:&5C:R!M971H;V0N("!697)S:6]N(&-O;7!A<FES;VX@:7,@
M;F]T('EE=`T*("`@("`J(&%V86EL86)L92!H97)E+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@(&YA;64@;V8@4T%022!B86-K
M96YD#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q("`@=VAI8V@@=F5R<VEO
M;B!T;R!C;VUP87)E#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5L871I;VX@
M(&AO=R!T;R!C;VUP87)E('9E<G-I;VYS("AC=7)R96YT;'D-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@:&%R9&-O9&5D('1O("=H87,G*0T*
M("`@("`J($!R971U<FX@;6EX960@8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O
M<B!T:&4@97)R;W(@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAE
M8VM305!)*"8D97)R;7-G+"`D;F%M92P@)')E<2`](&YU;&PL("1R96QA=&EO
M;B`]("=H87,G*0T*("`@('L-"B`@("`@("`@+R\@6%A8($9I>&UE.B!4:&5R
M92!I<R!N;R!W87D@=&\@:VYO=R!I9B!T:&4@=7-E<B!H87,@;W(-"B`@("`@
M("`@+R\@;F]T(&]T:&5R(%-!4$D@8F%C:V5N9',@:6YS=&%L;&5D('1H86X@
M=&AE(&EN<W1A;&QE<B!O;F4-"@T*("`@("`@("`D<V%P:5]B86-K96YD(#T@
M<&AP7W-A<&E?;F%M92@I.PT*("`@("`@("`O+R!697)S:6]N(&-O;7!A<FES
M;VYS(&YO="!S=7!P;W)T960L('-A<&D@8F%C:V5N9',@9&]N)W0@:&%V90T*
M("`@("`@("`O+R!V97)S:6]N(&EN9F]R;6%T:6]N('EE="X-"B`@("`@("`@
M:68@*"1S87!I7V)A8VME;F0@/3T@)&YA;64I('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D97)R;7-G(#T@(B<D
M<V%P:5]B86-K96YD)R!305!)(&)A8VME;F0@;F]T('-U<'!O<G1E9"([#0H@
M("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?0T].1DQ)0U0[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-H96-K6F5N9"@I#0H-"B`@
M("`O*BH-"B`@("`@*B!:96YD('9E<G-I;VX@8VAE8VL@;65T:&]D#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1R97$@("!W:&EC:"!V97)S:6]N
M('1O(&-O;7!A<F4-"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96QA=&EO;B`@
M:&]W('1O(&-O;7!A<F4@=&AE('9E<G-I;VX-"B`@("`@*@T*("`@("`J($!R
M971U<FX@;6EX960@8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@97)R
M;W(@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAE8VM:96YD*"8D
M97)R;7-G+"`D<F5Q+"`D<F5L871I;VX@/2`G9V4G*0T*("`@('L-"B`@("`@
M("`@:68@*'-U8G-T<B@D<F5Q+"`P+"`R*2`]/2`G=BXG*2![#0H@("`@("`@
M("`@("`D<F5Q(#T@<W5B<W1R*"1R97$L,BP@<W1R;&5N*"1R97$I("T@,BD[
M#0H@("`@("`@('T-"B`@("`@("`@)'IE;F1?=F5R(#T@>F5N9%]V97)S:6]N
M*"D[#0H@("`@("`@("1O<&5R871O<B`]('-U8G-T<B@D<F5L871I;VXL,"PR
M*3L-"B`@("`@("`@:68@*"%V97)S:6]N7V-O;7!A<F4H(B1Z96YD7W9E<B(L
M("(D<F5Q(BP@)&]P97)A=&]R*2D@>PT*("`@("`@("`@("`@)&5R<FUS9R`]
M("):96YD('9E<G-I;VX@(B`N("1T:&ES+3YS:6=N3W!E<F%T;W(H)&]P97)A
M=&]R*2`N#0H@("`@("`@("`@("`@("`@(B`D<F5Q(&ES(')E<75I<F5D(CL-
M"B`@("`@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?0T].1DQ)0U0[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!S:6=N3W!E<F%T;W(H*0T*#0H@("`@
M+RHJ#0H@("`@("H@0V]N=F5R=',@=&5X="!C;VUP87)I;F<@;W!E<F%T;W)S
M('1O('1H96T@<VEG;B!E<75I=F%L96YT<PT*("`@("`J#0H@("`@("H@17AA
M;7!L93H@)V=E)R!T;R`G/CTG#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J($!P87)A;2`@<W1R:6YG($]P97)A=&]R#0H@("`@("H@
M0')E='5R;B!S=')I;F<@4VEG;B!E<75I=F%L96YT#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<VEG;D]P97)A=&]R*"1O<&5R871O<BD-"B`@("![#0H@("`@
M("`@('-W:71C:"@D;W!E<F%T;W(I('L-"B`@("`@("`@("`@(&-A<V4@)VQT
M)SH@<F5T=7)N("<\)SL-"B`@("`@("`@("`@(&-A<V4@)VQE)SH@<F5T=7)N
M("<\/2<[#0H@("`@("`@("`@("!C87-E("=G="<Z(')E='5R;B`G/B<[#0H@
M("`@("`@("`@("!C87-E("=G92<Z(')E='5R;B`G/CTG.PT*("`@("`@("`@
M("`@8V%S92`G97$G.B!R971U<FX@)ST])SL-"B`@("`@("`@("`@(&-A<V4@
M)VYE)SH@<F5T=7)N("<A/2<[#0H@("`@("`@("`@("!D969A=6QT.@T*("`@
M("`@("`@("`@("`@(')E='5R;B`D;W!E<F%T;W([#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]D949R;VU296QA=&EO
M;B@I#0H-"B`@("`O*BH-"B`@("`@*B!#;VYV97)T(')E;&%T:6]N(&EN=&\@
M8V]R<F5S<&]N9&EN9R!C;V1E#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J($!P87)A;2`@<W1R:6YG(%)E;&%T:6]N#0H@("`@("H@
M0'!A<F%M("!S=')I;F<@5F5R<VEO;@T*("`@("`J($!P87)A;2`@<W1R:6YG
M(%)E<75I<F5M96YT#0H@("`@("H@0'!A<F%M("!B;V]L("`@3W!T:6]N86P@
M9&5P96YD96YC>2!I;F1I8V%T;W(-"B`@("`@*B!`<F5T=7)N(&EN=&5G97(-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;V1E1G)O;5)E;&%T:6]N*"1R96QA
M=&EO;BP@)'9E<G-I;VXL("1R97$L("1O<'0@/2!F86QS92D-"B`@("![#0H@
M("`@("`@("1C;V1E(#T@4$5!4E]$15!%3D1%3D-97T)!1%]$15!%3D1%3D-9
M.PT*("`@("`@("!S=VET8V@@*"1R96QA=&EO;BD@>PT*("`@("`@("`@("`@
M8V%S92`G9W0G.B!C87-E("=G92<Z(&-A<V4@)V5Q)SH-"B`@("`@("`@("`@
M("`@("`O+R!U<&=R861E#0H@("`@("`@("`@("`@("`@)&AA=F5?;6%J;W(@
M/2!P<F5G7W)E<&QA8V4H)R]<1"XJ+R<L("<G+"`D=F5R<VEO;BD[#0H@("`@
M("`@("`@("`@("`@)&YE961?;6%J;W(@/2!P<F5G7W)E<&QA8V4H)R]<1"XJ
M+R<L("<G+"`D<F5Q*3L-"B`@("`@("`@("`@("`@("!I9B`H)&YE961?;6%J
M;W(@/B`D:&%V95]M86IO<BD@>PT*("`@("`@("`@("`@("`@("`@("`D8V]D
M92`]("1O<'0@/R!014%27T1%4$5.1$5.0UE?55!'4D%$15]-04I/4E]/4%1)
M3TY!3"`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%
M05)?1$5014Y$14Y#65]54$=2041%7TU!2D]2.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1C;V1E(#T@)&]P="`_
M(%!%05)?1$5014Y$14Y#65]54$=2041%7TU)3D]27T]05$E/3D%,(#H-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]$15!%3D1%
M3D-97U501U)!1$5?34E.3U([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G;'0G.B!C87-E
M("=L92<Z(&-A<V4@)VYE)SH-"B`@("`@("`@("`@("`@("`D8V]D92`]("1O
M<'0@/R!014%27T1%4$5.1$5.0UE?0T].1DQ)0U1?3U!424].04P@.@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?1$5014Y$14Y#65]#
M3TY&3$E#5#L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)&-O9&4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]
M#0H_/@T*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(O1&5P96YD96YC>41"+G!H<```````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#4V,38R`#$P-3$U-#,Q,#4W`#`R,3`W-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+RHJ#0H@*B!0
M14%27T1E<&5N9&5N8WE$0BP@861V86YC960@:6YS=&%L;&5D('!A8VMA9V5S
M(&1E<&5N9&5N8WD@9&%T86)A<V4-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!4;VUA<R!6+B!6+B!#
M;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!$97!E;F1E;F-Y1$(N<&AP+'8@,2XS,"`R
M,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC
M92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*
M("HO#0H-"B\J*@T*("H@3F5E9&5D(&9O<B!E<G)O<B!H86YD;&EN9PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!
M4B]#;VYF:6<N<&AP)SL-"@T*+RHJ#0H@*B!4<F%C:R!D97!E;F1E;F-Y(')E
M;&%T:6]N<VAI<',@8F5T=V5E;B!I;G-T86QL960@<&%C:V%G97,-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A=71H
M;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C+FYE="YC;VT^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]$97!E;F1E;F-Y1$(-"GL-
M"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@+RHJ#0H@("`@("H@5&AI
M<R!I<R!I;FET:6%L:7IE9"!B>2![0&QI;FL@<V5T0V]N9FEG*"E]#0H@("`@
M("H@0'9A<B!014%27T-O;F9I9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@('9A<B`D7V-O;F9I9SL-"B`@("`O*BH-"B`@("`@*B!4
M:&ES(&ES(&EN:71I86QI>F5D(&)Y('M`;&EN:R!S971#;VYF:6<H*7T-"B`@
M("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!V87(@)%]R96=I<W1R>3L-"B`@("`O*BH-"B`@
M("`@*B!&:6QE;F%M92!O9B!T:&4@9&5P96YD96YC>2!$0B`H=7-U86QL>2`N
M9&5P9&(I#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]D97!D8B`](&9A;'-E.PT*("`@
M("\J*@T*("`@("`J($9I;&4@;F%M92!O9B!T:&4@;&]C:V9I;&4@*'5S=6%L
M;'D@+F1E<&1B;&]C:RD-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VQO8VMF:6QE(#T@
M9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@3W!E;B!F:6QE(')E<V]U<F-E(&9O
M<B!L;V-K:6YG('1H92!L;V-K9FEL90T*("`@("`J($!V87(@<F5S;W5R8V5\
M9F%L<V4-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V
M87(@)%]L;V-K1G`@/2!F86QS93L-"B`@("`O*BH-"B`@("`@*B!!4$D@=F5R
M<VEO;B!O9B!T:&ES(&-L87-S+"!U<V5D('1O('9A;&ED871E(&$@9FEL92!O
M;BUD:7-K#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]V97)S:6]N(#T@)S$N,"<[#0H@
M("`@+RHJ#0H@("`@("H@0V%C:&5D(&1E<&5N9&5N8WD@9&%T86)A<V4@9FEL
M90T*("`@("`J($!V87(@87)R87E\;G5L;`T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@('9A<B`D7V-A8VAE.PT*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[("8@<VEN9VQE=&]N*"D-"@T*("`@("\J*@T*("`@("`J
M($=E="!A(')A=R!D97!E;F1E;F-Y(&1A=&%B87-E+B`@0V%L;',@<V5T0V]N
M9FEG*"D@86YD(&%S<V5R=$1E<'-$0B@I#0H@("`@("H@0'!A<F%M(%!%05)?
M0V]N9FEG#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!F=6QL('!A=&@@
M=&\@=&AE(&1E<&5N9&5N8WD@9&%T86)A<V4L(&]R(&9A;'-E('1O('5S92!D
M969A=6QT#0H@("`@("H@0')E='5R;B!014%27T1E<&5N9&5N8WE$0GQ014%2
M7T5R<F]R#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M("9S:6YG;&5T;VXH)B1C;VYF:6<L("1D97!D8B`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?1$5014Y$14Y#
M641"7TE.4U1!3D-%)UT-"B`@("`@("`@("`@("`@6R1C;VYF:6<M/F=E="@G
M<&AP7V1I<B<L(&YU;&PL("=P96%R+G!H<"YN970G*5TI*2![#0H@("`@("`@
M("`@("`D82`](&YE=R!014%27T1E<&5N9&5N8WE$0CL-"B`@("`@("`@("`@
M("1'3$]"04Q36R=?4$5!4E]$15!%3D1%3D-91$)?24Y35$%.0T4G70T*("`@
M("`@("`@("`@("!;)&-O;F9I9RT^9V5T*"=P:'!?9&ER)RP@;G5L;"P@)W!E
M87(N<&AP+FYE="<I72`]("8D83L-"B`@("`@("`@("`@("1A+3YS971#;VYF
M:6<H)&-O;F9I9RP@)&1E<&1B*3L-"B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E(#T@)&$M/F%S<V5R=$1E<'-$0B@I*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T1%4$5.1$5.0UE$0E])
M3E-404Y#12==#0H@("`@("`@("`@("`@(%LD8V]N9FEG+3YG970H)W!H<%]D
M:7(G+"!N=6QL+"`G<&5A<BYP:'`N;F5T)RE=.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%-E="!U<"!T:&4@<F5G:7-T<GDO;&]C871I;VX@;V8@9&5P
M96YD96YC>2!$0@T*("`@("`J($!P87)A;2!014%27T-O;F9I9WQF86QS90T*
M("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@9G5L;"!P871H('1O('1H92!D
M97!E;F1E;F-Y(&1A=&%B87-E+"!O<B!F86QS92!T;R!U<V4@9&5F875L=`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$-O;F9I9R@F)&-O;F9I9RP@)&1E
M<&1B(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(21C;VYF:6<I('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS
M:6YG;&5T;VXH*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^7V-O;F9I9RT^9V5T4F5G:7-T
M<GDH*3L-"B`@("`@("`@:68@*"$D9&5P9&(I('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?9&5P9&(@/2`D=&AI<RT^7V-O;F9I9RT^9V5T*"=P:'!?9&ER)RP@
M;G5L;"P@)W!E87(N<&AP+FYE="<I("X-"B`@("`@("`@("`@("`@("!$25)%
M0U1/4EE?4T5005)!5$]2("X@)RYD97!D8B<[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D=&AI<RT^7V1E<&1B(#T@)&1E<&1B.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?;&]C:V9I;&4@/2!D:7)N86UE*"1T:&ES
M+3Y?9&5P9&(I("X@1$E214-43U)97U-%4$%2051/4B`N("<N9&5P9&)L;V-K
M)SL-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("!F=6YC=&EO;B!H87-7<FET
M94%C8V5S<R@I#0H@("`@>PT*("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D
M=&AI<RT^7V1E<&1B*2D@>PT*("`@("`@("`@("`@)&1I<B`]("1T:&ES+3Y?
M9&5P9&([#0H@("`@("`@("`@("!W:&EL92`H)&1I<B`F)B`D9&ER("$]("<N
M)RD@>PT*("`@("`@("`@("`@("`@("1D:7(@/2!D:7)N86UE*"1D:7(I.R`O
M+R!C9"`N+@T*("`@("`@("`@("`@("`@(&EF("@D9&ER("$]("<N)R`F)B!`
M9FEL95]E>&ES=',H)&1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*$!I<U]W<FET96%B;&4H)&1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!`:7-?=W)I=&5A8FQE*"1T:&ES+3Y?9&5P9&(I
M.PT*("`@('T-"@T*("`@("\O('M[>R!A<W-E<G1$97!S1$(H*0T*#0H@("`@
M+RHJ#0H@("`@("H@0W)E871E('1H92!D97!E;F1E;F-Y(&1A=&%B87-E+"!I
M9B!I="!D;V5S;B=T(&5X:7-T+B`@17)R;W(@:68@=&AE(&1A=&%B87-E(&ES
M#0H@("`@("H@;F5W97(@=&AA;B!T:&4@8V]D92!R96%D:6YG(&ET+@T*("`@
M("`J($!R971U<FX@=F]I9'Q014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@87-S97)T1&5P<T1"*"D-"B`@("![#0H@("`@("`@(&EF("@A:7-?
M9FEL92@D=&AI<RT^7V1E<&1B*2D@>PT*("`@("`@("`@("`@)'1H:7,M/G)E
M8G5I;&1$0B@I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1E
M<&1B(#T@)'1H:7,M/E]G971$97!$0B@I.PT*("`@("`@("`@("`@+R\@1&%T
M871Y<&4@9F]R;6%T(&AA<R!B965N(&-H86YG960L(')E8G5I;&0@=&AE($1E
M<',@1$(-"B`@("`@("`@("`@(&EF("@D9&5P9&);)U]V97)S:6]N)UT@/"`D
M=&AI<RT^7W9E<G-I;VXI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5B
M=6EL9$1"*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&1E
M<&1B6R=?=F5R<VEO;B==>S!](#X@)'1H:7,M/E]V97)S:6]N>S!]*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T1E<&5N
M9&5N8WD@9&%T86)A<V4@:7,@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@
M("`@("`@)&1E<&1B6R=?=F5R<VEO;B==("X@)RP@86YD('=E(&%R92!V97)S
M:6]N("<@+@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9E<G-I;VX@
M+B`G+"!C86YN;W0@8V]N=&EN=64G*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E="!A(&QI<W0@;V8@
M:6YS=&%L;&5D('!A8VMA9V5S('1H870@9&5P96YD(&]N('1H:7,@<&%C:V%G
M90T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C
M:V%G949I;&5?=C)\87)R87D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5P96YD96YT4&%C:V%G97,H
M)B1P:V<I#0H@("`@>PT*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9V5T1&5P
M1$(H*3L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG*2D@>PT*("`@("`@
M("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN96PH
M*2D[#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!K9RT^
M9V5T4&%C:V%G92@I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&MG6R=C:&%N;F5L)UTI.PT*("`@
M("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V=;)W!A8VMA9V4G
M72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D871A6R=P86-K
M86=E<R==6R1C:&%N;F5L75LD<&%C:V%G95TI*2![#0H@("`@("`@("`@("!R
M971U<FX@)&1A=&%;)W!A8VMA9V5S)UU;)&-H86YN96Q=6R1P86-K86=E73L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T(&$@;&ES="!O9B!T:&4@86-T=6%L(&1E<&5N
M9&5N8VEE<R!O9B!I;G-T86QL960@<&%C:V%G97,@=&AA="!D97!E;F0@;VX-
M"B`@("`@*B!A('!A8VMA9V4N#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G
M949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V,GQA<G)A>0T*("`@("`J($!R
M971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971$
M97!E;F1E;G1086-K86=E1&5P96YD96YC:65S*"8D<&MG*0T*("`@('L-"B`@
M("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E=$1E<$1"*"D[#0H@("`@("`@(&EF
M("AI<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@
M<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@
M)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA9V4H*2D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8VAA;FYE;"`]('-T<G1O
M;&]W97(H)'!K9ULG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("1P86-K86=E
M(#T@<W1R=&]L;W=E<B@D<&MG6R=P86-K86=E)UTI.PT*("`@("`@("!]#0H@
M("`@("`@("1D97!E;F0@/2`D=&AI<RT^9V5T1&5P96YD96YT4&%C:V%G97,H
M)'!K9RD[#0H@("`@("`@(&EF("@A)&1E<&5N9"D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1D97!E;F1E;F-I
M97,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D9&5P96YD(&%S("1I
M;F9O*2![#0H@("`@("`@("`@("`D=&5M<"`]("1T:&ES+3YG971$97!E;F1E
M;F-I97,H)&EN9F\I.PT*("`@("`@("`@("`@9F]R96%C:"`H)'1E;7`@87,@
M)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!;
M)V1E<"==6R=C:&%N;F5L)UTI(#T]('-T<G1O;&]W97(H)&-H86YN96PI("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D9&5P6R=D97`G
M75LG;F%M92==*2`]/2!S=')T;VQO=V5R*"1P86-K86=E*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D9&5P96YD96YC:65S6R1I;F9O6R=C:&%N;F5L)UU=
M6R1I;F9O6R=P86-K86=E)UU=6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)&1E<&5N9&5N8VEE<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@
M82!L:7-T(&]F(&1E<&5N9&5N8VEE<R!O9B!T:&ES(&EN<W1A;&QE9"!P86-K
M86=E#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]0
M86-K86=E1FEL95]V,GQA<G)A>0T*("`@("`J($!R971U<FX@87)R87E\9F%L
M<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971$97!E;F1E;F-I97,H)B1P
M:V<I#0H@("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1P:V<I*2![#0H@
M("`@("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)'!K9RT^9V5T0VAA
M;FYE;"@I*3L-"B`@("`@("`@("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D
M<&MG+3YG971086-K86=E*"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P:V=;)V-H86YN96PG72D[
M#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!K9ULG<&%C
M:V%G92==*3L-"B`@("`@("`@?0T*("`@("`@("`D9&%T82`]("1T:&ES+3Y?
M9V5T1&5P1$(H*3L-"B`@("`@("`@:68@*&ES<V5T*"1D871A6R=D97!E;F1E
M;F-I97,G75LD8VAA;FYE;%U;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1D871A6R=D97!E;F1E;F-I97,G75LD8VAA;FYE;%U;)'!A8VMA
M9V5=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B`D<&%R96YT
M(&1E<&5N9',@;VX@)&-H:6QD+"!N96%R(&]R(&1E97`-"B`@("`@*B!`<&%R
M86T@87)R87E\4$5!4E]086-K86=E1FEL95]V,GQ014%27U!A8VMA9V5&:6QE
M7W8R#0H@("`@("H@0'!A<F%M(&%R<F%Y?%!%05)?4&%C:V%G949I;&5?=C)\
M4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&1E
M<&5N9'-/;B@D<&%R96YT+"`D8VAI;&0I#0H@("`@>PT*("`@("`@("`D8R`]
M(&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3Y?9V5T1&5P1$(H*3L-"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&5P96YD<T]N*"1P87)E;G0L("1C:&EL9"P@
M)&,I.PT*("`@('T-"B`@("`-"B`@("!F=6YC=&EO;B!?9&5P96YD<T]N*"1P
M87)E;G0L("1C:&EL9"P@)B1C:&5C:V5D*0T*("`@('L-"B`@("`@("`@:68@
M*&ES7V]B:F5C="@D<&%R96YT*2D@>PT*("`@("`@("`@("`@)&-H86YN96P@
M/2!S=')T;VQO=V5R*"1P87)E;G0M/F=E=$-H86YN96PH*2D[#0H@("`@("`@
M("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!A<F5N="T^9V5T4&%C:V%G
M92@I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C:&%N;F5L
M(#T@<W1R=&]L;W=E<B@D<&%R96YT6R=C:&%N;F5L)UTI.PT*("`@("`@("`@
M("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P87)E;G1;)W!A8VMA9V4G72D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V]B:F5C="@D8VAI;&0I*2![
M#0H@("`@("`@("`@("`D9&5P8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H:6QD
M+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@)&1E<'!A8VMA9V4@/2!S
M=')T;VQO=V5R*"1C:&EL9"T^9V5T4&%C:V%G92@I*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1D97!C:&%N;F5L(#T@<W1R=&]L;W=E<B@D
M8VAI;&1;)V-H86YN96PG72D[#0H@("`@("`@("`@("`D9&5P<&%C:V%G92`]
M('-T<G1O;&]W97(H)&-H:6QD6R=P86-K86=E)UTI.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D8VAE8VME9%LD8VAA;FYE;%U;)'!A8VMA9V5=
M6R1D97!C:&%N;F5L75LD9&5P<&%C:V%G95TI*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[("\O(&%V;VED(&5N9&QE<W,@<F5C=7)S:6]N#0H@("`@
M("`@('T-"B`@("`@("`@)&-H96-K961;)&-H86YN96Q=6R1P86-K86=E75LD
M9&5P8VAA;FYE;%U;)&1E<'!A8VMA9V5=(#T@=')U93L-"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V-A8VAE6R=D97!E;F1E;F-I97,G75LD8VAA;FYE
M;%U;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8V%C:&5;)V1E
M<&5N9&5N8VEE<R==6R1C:&%N;F5L75LD<&%C:V%G95T@87,@)&EN9F\I('L-
M"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1I;F9O6R=D97`G75LG8VAA
M;FYE;"==*2`]/2!S=')T;VQO=V5R*"1D97!C:&%N;F5L*2`F)@T*("`@("`@
M("`@("`@("`@("`@<W1R=&]L;W=E<B@D:6YF;ULG9&5P)UU;)VYA;64G72D@
M/3T@<W1R=&]L;W=E<B@D9&5P<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V-A8VAE6R=D97!E;F1E;F-I97,G75LD
M8VAA;FYE;%U;)'!A8VMA9V5=(&%S("1I;F9O*2![#0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]D97!E;F1S3VXH87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("=C:&%N;F5L)R`]/B`D:6YF;ULG9&5P)UU;)V-H86YN96PG72P-"B`@
M("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1I;F9O6R=D97`G75LG
M;F%M92==*2P@)&-H:6QD+"`D8VAE8VME9"DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4F5G:7-T97(@9&5P96YD96YC:65S(&]F(&$@<&%C:V%G92!T:&%T(&ES(&)E
M:6YG(&EN<W1A;&QE9"!O<B!U<&=R861E9`T*("`@("`J($!P87)A;2!014%2
M7U!A8VMA9V5&:6QE7W8R?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!I;G-T86QL4&%C:V%G92@F)'!A8VMA9V4I#0H@("`@
M>PT*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9V5T1&5P1$(H*3L-"B`@("`@
M("`@=6YS970H)'1H:7,M/E]C86-H92D[#0H@("`@("`@("1T:&ES+3Y?<V5T
M4&%C:V%G941E<',H)&1A=&$L("1P86-K86=E*3L-"B`@("`@("`@)'1H:7,M
M/E]W<FET941E<$1"*"1D871A*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!296UO=F4@9&5P96YD96YC:65S(&]F(&$@<&%C:V%G92!T:&%T(&ES(&)E
M:6YG('5N:6YS=&%L;&5D+"!O<B!U<&=R861E9"X-"B`@("`@*@T*("`@("`J
M(%5P9W)A9&5D('!A8VMA9V5S(&9I<G-T('5N:6YS=&%L;"P@=&AE;B!I;G-T
M86QL#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]0
M86-K86=E1FEL95]V,GQA<G)A>2!)9B!A;B!A<G)A>2P@=&AE;B!I="!M=7-T
M(&AA=F4-"B`@("`@*B`@("`@("`@:6YD:6-E<R`G8VAA;FYE;"<@86YD("=P
M86-K86=E)PT*("`@("`J+PT*("`@(&9U;F-T:6]N('5N:6YS=&%L;%!A8VMA
M9V4H)B1P:V<I#0H@("`@>PT*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9V5T
M1&5P1$(H*3L-"B`@("`@("`@=6YS970H)'1H:7,M/E]C86-H92D[#0H@("`@
M("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@("`@("`@("1C:&%N
M;F5L(#T@<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@
M("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA9V4H
M*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8VAA;FYE;"`]
M('-T<G1O;&]W97(H)'!K9ULG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("1P
M86-K86=E(#T@<W1R=&]L;W=E<B@D<&MG6R=P86-K86=E)UTI.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-S970H)&1A=&%;)V1E<&5N9&5N8VEE<R==
M6R1C:&%N;F5L75LD<&%C:V%G95TI*2![#0H@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9&%T85LG9&5P
M96YD96YC:65S)UU;)&-H86YN96Q=6R1P86-K86=E72!A<R`D9&5P*2![#0H@
M("`@("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=D97`G75LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&1E<&-H86YN96P@/2`G7U]U<FDG.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D9&5P8VAA;FYE;"`]('-T<G1O;&]W97(H)&1E
M<%LG9&5P)UU;)V-H86YN96PG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&1A=&%;)W!A8VMA9V5S)UU;)&1E<&-H86YN96Q=
M6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA;64G72E=*2D@>PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=P86-K86=E<R==6R1D97!C:&%N
M;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI72!A<PT*("`@
M("`@("`@("`@("`@("`@("`@("1I(#T^("1I;F9O*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D:6YF;ULG8VAA;FYE;"==(#T]("1C:&%N;F5L("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=P86-K86=E)UT@
M/3T@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N
M9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@D9F]U;F0I('L-"B`@("`@("`@
M("`@("`@("!U;G-E="@D9&%T85LG<&%C:V%G97,G75LD9&5P8VAA;FYE;%U;
M<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG;F%M92==*5U;)&E=*3L-"B`@("`@
M("`@("`@("`@("!I9B`H(6-O=6YT*"1D871A6R=P86-K86=E<R==6R1D97!C
M:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&1A=&%;)W!A8VMA9V5S)UU;
M)&1E<&-H86YN96Q=6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA;64G72E=
M*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%C;W5N="@D9&%T85LG<&%C
M:V%G97,G75LD9&5P8VAA;FYE;%TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D9&%T85LG<&%C:V%G97,G75LD9&5P8VAA;FYE;%TI.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)W!A8VMA9V5S)UU;)&1E
M<&-H86YN96Q=6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA;64G72E=(#T-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W9A;'5E<R@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T85LG<&%C:V%G97,G75LD9&5P
M8VAA;FYE;%U;<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG;F%M92==*5TI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!U;G-E="@D9&%T85LG9&5P96YD96YC:65S)UU;)&-H86YN96Q=
M6R1P86-K86=E72D[#0H@("`@("`@(&EF("@A8V]U;G0H)&1A=&%;)V1E<&5N
M9&5N8VEE<R==6R1C:&%N;F5L72DI('L-"B`@("`@("`@("`@('5N<V5T*"1D
M871A6R=D97!E;F1E;F-I97,G75LD8VAA;FYE;%TI.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A8V]U;G0H)&1A=&%;)V1E<&5N9&5N8VEE<R==*2D@>PT*
M("`@("`@("`@("`@=6YS970H)&1A=&%;)V1E<&5N9&5N8VEE<R==*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(6-O=6YT*"1D871A6R=P86-K86=E<R==
M*2D@>PT*("`@("`@("`@("`@=6YS970H)&1A=&%;)W!A8VMA9V5S)UTI.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?=W)I=&5$97!$0B@D9&%T82D[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5B=6EL9"!T:&4@9&5P96YD
M96YC>2!$0B!B>2!R96%D:6YG(')E9VES=')Y(&5N=')I97,N#0H@("`@("H@
M0')E='5R;B!T<G5E?%!%05)?17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!R96)U:6QD1$(H*0T*("`@('L-"B`@("`@("`@)&1E<&1B(#T@87)R87DH
M)U]V97)S:6]N)R`]/B`D=&AI<RT^7W9E<G-I;VXI.PT*("`@("`@("!I9B`H
M(21T:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`O+R!A
M;&QO=R!S=&%R='5P(&9O<B!R96%D+6]N;'D@=VET:"!O;&1E<B!296=I<W1R
M>0T*("`@("`@("`@("`@<F5T=7)N("1D97!D8CL-"B`@("`@("`@?0T*("`@
M("`@("`D<&%C:V%G97,@/2`D=&AI<RT^7W)E9VES=')Y+3YL:7-T06QL4&%C
M:V%G97,H*3L-"B`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S("1C:&%N
M;F5L(#T^("1P<RD@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'!S(&%S("1P
M86-K86=E*2![#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`D=&AI<RT^
M7W)E9VES=')Y+3YG971086-K86=E*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S971086-K86=E1&5P<R@D9&5P9&(L
M("1P86-K86=E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D97)R;W(@/2`D=&AI<RT^7W=R:71E1&5P1$(H)&1E<&1B*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-A
M8VAE(#T@)&1E<&1B.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!296=I<W1E<B!U<V%G92!O9B!T:&4@9&5P96YD
M96YC>2!$0B!T;R!P<F5V96YT(')A8V4@8V]N9&ET:6]N<PT*("`@("`J($!P
M87)A;2!I;G0@;VYE(&]F('1H92!,3T-+7RH@8V]N<W1A;G1S#0H@("`@("H@
M0')E='5R;B!T<G5E?%!%05)?17)R;W(-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;&]C:R@D;6]D92`]($Q/0TM?
M15@I#0H@("`@>PT*("`@("`@("!I9B`H(65R96=I*"=7:6YD;W=S(#DG+"!P
M:'!?=6YA;64H*2DI('L-"B`@("`@("`@("`@(&EF("@D;6]D92`A/2!,3T-+
M7U5.("8F(&ES7W)E<V]U<F-E*"1T:&ES+3Y?;&]C:T9P*2D@>PT*("`@("`@
M("`@("`@("`@("\O(%A86"!D;V5S(&YO="!C:&5C:R!T>7!E(&]F(&QO8VL@
M*$Q/0TM?4T@O3$]#2U]%6"D-"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1O<&5N7VUO9&4@/2`G
M=R<[#0H@("`@("`@("`@("`O+R!86%@@4&5O<&QE(')E<&]R=&5D('!R;V)L
M96US('=I=&@@3$]#2U]32"!A;F0@)W<G#0H@("`@("`@("`@("!I9B`H)&UO
M9&4@/3T]($Q/0TM?4T@I('L-"B`@("`@("`@("`@("`@("!I9B`H0"%I<U]F
M:6QE*"1T:&ES+3Y?;&]C:V9I;&4I*2![#0H@("`@("`@("`@("`@("`@("`@
M('1O=6-H*"1T:&ES+3Y?;&]C:V9I;&4I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D;W!E;E]M;V1E(#T@)W(G.PT*("`@("`@("`@
M("`@?0T*#0H@("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3Y?
M;&]C:T9P*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]C:T9P(#T@
M0&9O<&5N*"1T:&ES+3Y?;&]C:V9I;&4L("1O<&5N7VUO9&4I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^
M7VQO8VM&<"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@B8V]U;&0@;F]T(&-R96%T92!$97!E;F1E;F-Y(&QO8VL@9FEL
M92(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H:7-S970H)'!H<%]E<G)O<FUS9RD@/R`B.B`B("X@)'!H<%]E<G)O<FUS
M9R`Z("(B*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(2AI
M;G0I9FQO8VLH)'1H:7,M/E]L;V-K1G`L("1M;V1E*2D@>PT*("`@("`@("`@
M("`@("`@('-W:71C:"`H)&UO9&4I('L-"B`@("`@("`@("`@("`@("`@("`@
M8V%S92!,3T-+7U-(.B`D<W1R(#T@)W-H87)E9"<[("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!C87-E($Q/0TM?15@Z("1S='(@/2`G97AC;'5S
M:79E)SL@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@3$]#2U]5
M3CH@)'-T<B`]("=U;FQO8VLG.R`@("!B<F5A:SL-"B`@("`@("`@("`@("`@
M("`@("`@9&5F875L=#H@("`@("`D<W1R(#T@)W5N:VYO=VXG.R`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&%C<75I<F4@)'-T<B!L;V-K
M("@D=&AI<RT^7VQO8VMF:6QE*2(I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%)E;&5A<V4@=7-A9V4@;V8@9&5P96YD96YC>2!$0@T*("`@("`J
M($!R971U<FX@=')U97Q014%27T5R<F]R#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5N;&]C:R@I#0H@("`@>PT*
M("`@("`@("`D<F5T(#T@)'1H:7,M/E]L;V-K*$Q/0TM?54XI.PT*("`@("`@
M("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]L;V-K1G`I*2![#0H@("`@("`@
M("`@("!F8VQO<V4H)'1H:7,M/E]L;V-K1G`I.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?;&]C:T9P(#T@;G5L;#L-"B`@("`@("`@<F5T=7)N("1R
M970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@3&]A9"!T:&4@9&5P96YD
M96YC>2!D871A8F%S92!F<F]M(&1I<VLL(&]R(')E='5R;B!T:&4@8V%C:&4-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y?%!%05)?17)R;W(-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?9V5T1&5P1$(H*0T*("`@('L-"B`@("`@("`@:68@*"$D
M=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"=?=F5R<VEO;B<@/3X@)'1H:7,M/E]V97)S:6]N*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C86-H92DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-A8VAE.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)&9P(#T@9F]P96XH)'1H:7,M/E]D97!D8BP@)W(G*2D@
M>PT*("`@("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD
M(&YO="!O<&5N(&1E<&5N9&5N8VEE<R!F:6QE(&`B+B1T:&ES+3Y?9&5P9&(N
M(B<B*3L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@
M("`@("`@("1R="`](&=E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@I.PT*("`@
M("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H,"D[#0H@("`@("`@(&-L
M96%R<W1A=&-A8VAE*"D[#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H
M)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@(&9C;&]S92@D
M9G`I.PT*("`@("`@("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ92AF:6QE7V=E
M=%]C;VYT96YT<R@D=&AI<RT^7V1E<&1B*2D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D9&%T82`]('5N<V5R:6%L:7IE*&9R96%D*"1F<"P@
M9FEL97-I>F4H)'1H:7,M/E]D97!D8BDI*3L-"B`@("`@("`@("`@(&9C;&]S
M92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?
M<G5N=&EM92@D<G0I.PT*("`@("`@("`D=&AI<RT^7V-A8VAE(#T@)&1A=&$[
M#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!7<FET92!O=70@=&AE(&1E<&5N9&5N8WD@9&%T86)A<V4@=&\@9&ES
M:PT*("`@("`J($!P87)A;2!A<G)A>2!T:&4@9&%T86)A<V4-"B`@("`@*B!`
M<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]W<FET941E<$1"*"8D9&5P<RD-
M"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M
M/E]L;V-K*$Q/0TM?15@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)&9P(#T@9F]P96XH)'1H:7,M/E]D
M97!D8BP@)W=B)RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[
M#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V]U;&0@
M;F]T(&]P96X@9&5P96YD96YC:65S(&9I;&4@8"(N)'1H:7,M/E]D97!D8BXB
M)R!F;W(@=W)I=&EN9R(I.PT*("`@("`@("!]#0H@("`@("`@("1R="`](&=E
M=%]M86=I8U]Q=6]T97-?<G5N=&EM92@I.PT*("`@("`@("!S971?;6%G:6-?
M<75O=&5S7W)U;G1I;64H,"D[#0H@("`@("`@(&9W<FET92@D9G`L('-E<FEA
M;&EZ92@D9&5P<RDI.PT*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I
M;64H)')T*3L-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("1T:&ES
M+3Y?=6YL;V-K*"D[#0H@("`@("`@("1T:&ES+3Y?8V%C:&4@/2`D9&5P<SL-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@4F5G:7-T97(@86QL(&1E<&5N9&5N8VEE<R!F<F]M(&$@<&%C:V%G92!I
M;B!T:&4@9&5P96YD96YC:65S(&1A=&%B87-E+"!I;B!E<W-E;F-E#0H@("`@
M("H@(FEN<W1A;&QI;F<B('1H92!P86-K86=E)W,@9&5P96YD96YC>2!I;F9O
M<FUA=&EO;@T*("`@("`J($!P87)A;2!A<G)A>2!T:&4@9&%T86)A<V4-"B`@
M("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&
M:6QE7W8R#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@7W-E=%!A8VMA9V5$97!S*"8D9&%T82P@)B1P:V<I#0H@("`@
M>PT*("`@("`@("`D<&MG+3YS971#;VYF:6<H)'1H:7,M/E]C;VYF:6<I.PT*
M("`@("`@("!I9B`H)'!K9RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G
M,2XP)RD@>PT*("`@("`@("`@("`@)&=E;B`]("8D<&MG+3YG971$969A=6QT
M1V5N97)A=&]R*"D[#0H@("`@("`@("`@("`D9&5P<R`]("1G96XM/F1E<&5N
M9&5N8VEE<U1O5C(H*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1D97!S(#T@)'!K9RT^9V5T1&5P<RAT<G5E*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(21D97!S*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@
M("`@('T-"B`@("`@("`@)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T<G1O;&]W
M97(H)'!K9RT^9V5T0VAA;FYE;"@I*5U;<W1R=&]L;W=E<B@D<&MG+3YG9710
M86-K86=E*"DI70T*("`@("`@("`@("`@/2!A<G)A>2@I.PT*("`@("`@("!I
M9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72DI('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA
M9V4G75LP72DI('L-"B`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G
M75LG<&%C:V%G92==(#T@87)R87DH)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA
M9V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D
M9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E9VES=&5R1&5P*"1D871A+"`D<&MG+"`D
M9&5P+"`G<F5Q=6ER960G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G
M72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V]P=&EO;F%L
M)UU;)W!A8VMA9V4G75LP72DI('L-"B`@("`@("`@("`@("`@("`D9&5P<ULG
M;W!T:6]N86PG75LG<&%C:V%G92==(#T@87)R87DH)&1E<'-;)V]P=&EO;F%L
M)UU;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M;W)E86-H("@D9&5P<ULG;W!T:6]N86PG75LG<&%C:V%G92==(&%S("1D97`I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=&5R1&5P*"1D871A
M+"`D<&MG+"`D9&5P+"`G;W!T:6]N86PG*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;
M)W-U8G!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E
M<'-;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G75LP72DI('L-"B`@("`@("`@
M("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG<W5B<&%C:V%G92==(#T@87)R
M87DH)&1E<'-;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G72D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG<F5Q=6ER960G
M75LG<W5B<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E9VES=&5R1&5P*"1D871A+"`D<&MG+"`D9&5P+"`G<F5Q=6ER
M960G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)&1E<'-;)V]P=&EO;F%L)UU;)W-U8G!A8VMA9V4G72DI('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V]P=&EO;F%L)UU;)W-U8G!A
M8VMA9V4G75LP72DI('L-"B`@("`@("`@("`@("`@("`D9&5P<ULG;W!T:6]N
M86PG75LG<W5B<&%C:V%G92==(#T@87)R87DH)&1E<'-;)V]P=&EO;F%L)UU;
M)W-U8G!A8VMA9V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M;W)E86-H("@D9&5P<ULG;W!T:6]N86PG75LG<W5B<&%C:V%G92==(&%S("1D
M97`I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=&5R1&5P*"1D
M871A+"`D<&MG+"`D9&5P+"`G;W!T:6]N86PG*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<'-;)V=R;W5P)UTI
M*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=G<F]U<"==6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("1D97!S6R=G<F]U<"==(#T@87)R87DH
M)&1E<'-;)V=R;W5P)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9F]R96%C:"`H)&1E<'-;)V=R;W5P)UT@87,@)&=R;W5P*2![#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LG<&%C:V%G92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1G<F]U<%LG<&%C:V%G92==
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=P86-K
M86=E)UT@/2!A<G)A>2@D9W)O=7!;)W!A8VMA9V4G72D[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R
M;W5P6R=P86-K86=E)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K9RP@)&1E<"P@
M)V]P=&EO;F%L)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O
M=7!;)V%T=')I8G,G75LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&=R;W5P6R=S=6)P86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&=R;W5P6R=S=6)P86-K86=E)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7!;)W-U8G!A8VMA9V4G72`]
M(&%R<F%Y*"1G<F]U<%LG<W5B<&%C:V%G92==*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9W)O=7!;
M)W-U8G!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)E9VES=&5R1&5P*"1D871A+"`D<&MG+"`D9&5P+"`G
M;W!T:6]N86PG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U
M<%LG871T<FEB<R==6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@D9&%T85LG9&5P96YD96YC:65S)UU;<W1R=&]L;W=E
M<B@D<&MG+3YG971#:&%N;F5L*"DI70T*("`@("`@("`@("`@("!;<W1R=&]L
M;W=E<B@D<&MG+3YG971086-K86=E*"DI72`]/2!A<G)A>2@I*2![#0H@("`@
M("`@("`@("!U;G-E="@D9&%T85LG9&5P96YD96YC:65S)UU;<W1R=&]L;W=E
M<B@D<&MG+3YG971#:&%N;F5L*"DI70T*("`@("`@("`@("`@("!;<W1R=&]L
M;W=E<B@D<&MG+3YG971086-K86=E*"DI72D[#0H@("`@("`@("`@("!I9B`H
M(6-O=6YT*"1D871A6R=D97!E;F1E;F-I97,G75MS=')T;VQO=V5R*"1P:V<M
M/F=E=$-H86YN96PH*2E=*2D@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1D
M871A6R=D97!E;F1E;F-I97,G75MS=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN
M96PH*2E=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>2!T:&4@9&%T86)A<V4-"B`@
M("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&
M:6QE7W8R#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H92!S<&5C:69I8R!D97!E
M;F1E;F-Y#0H@("`@("H@0'!A<F%M(')E<75I<F5D?&]P=&EO;F%L('=H971H
M97(@=&AI<R!I<R!A(')E<75I<F5D(&]R(&%N(&]P=&EO;F%L(&1E<`T*("`@
M("`J($!P87)A;2!S=')I;F=\9F%L<V4@9&5P96YD96YC>2!G<F]U<"!T:&ES
M(&1E<&5N9&5N8WD@:7,@9G)O;2P@;W(@9F%L<V4@9F]R(&]R9&EN87)Y(&1E
M<`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]R96=I<W1E<D1E<"@F)&1A=&$L
M("8D<&MG+"`D9&5P+"`D='EP92P@)&=R;W5P(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("`D:6YF;R`](&%R<F%Y*`T*("`@("`@("`@("`@)V1E<"<@/3X@
M)&1E<"P-"B`@("`@("`@("`@("=T>7!E)R`]/B`D='EP92P-"B`@("`@("`@
M("`@("=G<F]U<"<@/3X@)&=R;W5P*3L-"@T*("`@("`@("!I9B`H:7-S970H
M)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@)&1E<&-H86YN96P@
M/2`D9&5P6R=C:&%N;F5L)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D9&5P8VAA;FYE;"`]("=?7W5R:2<[#0H@("`@("`@('T-"B`@("`@
M("`@)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T<G1O;&]W97(H)'!K9RT^9V5T
M0VAA;FYE;"@I*5U;<W1R=&]L;W=E<B@D<&MG+3YG971086-K86=E*"DI75M=
M#0H@("`@("`@("`@("`]("1I;F9O.PT*("`@("`@("!I9B`H:7-S970H)&1A
M=&%;)W!A8VMA9V5S)UU;<W1R=&]L;W=E<B@D9&5P8VAA;FYE;"E=6W-T<G1O
M;&]W97(H)&1E<%LG;F%M92==*5TI*2![#0H@("`@("`@("`@("`D9F]U;F0@
M/2!F86QS93L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=P86-K86=E
M<R==6W-T<G1O;&]W97(H)&1E<&-H86YN96PI75MS=')T;VQO=V5R*"1D97!;
M)VYA;64G72E=#0H@("`@("`@("`@("`@("`@("!A<R`D:2`]/B`D<"D@>PT*
M("`@("`@("`@("`@("`@(&EF("@D<%LG8VAA;FYE;"==(#T]('-T<G1O;&]W
M97(H)'!K9RT^9V5T0VAA;FYE;"@I*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("1P6R=P86-K86=E)UT@/3T@<W1R=&]L;W=E<B@D<&MG+3YG971086-K
M86=E*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A)&9O=6YD*2![
M#0H@("`@("`@("`@("`@("`@)&1A=&%;)W!A8VMA9V5S)UU;<W1R=&]L;W=E
M<B@D9&5P8VAA;FYE;"E=6W-T<G1O;&]W97(H)&1E<%LG;F%M92==*5U;70T*
M("`@("`@("`@("`@("`@("`@("`](&%R<F%Y*"=C:&%N;F5L)R`]/B!S=')T
M;VQO=V5R*"1P:V<M/F=E=$-H86YN96PH*2DL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A8VMA9V4G(#T^('-T<G1O;&]W97(H)'!K9RT^9V5T
M4&%C:V%G92@I*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D9&%T85LG<&%C:V%G97,G75MS=')T;VQO=V5R*"1D
M97!C:&%N;F5L*5U;<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI75M=#0H@("`@
M("`@("`@("`@("`@/2!A<G)A>2@G8VAA;FYE;"<@/3X@<W1R=&]L;W=E<B@D
M<&MG+3YG971#:&%N;F5L*"DI+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)W!A8VMA9V4G(#T^('-T<G1O;&]W97(H)'!K9RT^9V5T4&%C:V%G92@I*2D[
M#0H@("`@("`@('T-"B`@("!]#0I]#0H_/@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O1&5P96YD96YC>3(N<&AP````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,30Q,#8Q`#$P-3$U-#,Q,#4W`#`R,#<T-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27T1E<&5N9&5N8WDR+"!A9'9A;F-E9"!D97!E;F1E;F-Y('9A
M;&ED871I;VX-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@1&5P96YD96YC>3(N<&AP+'8@,2XU,"`R,#`V+S`Q+S`V(#`T.C0W.C,V
M(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@4F5Q
M=6ER960@9F]R('1H92!014%27U9!3$E$051%7RH@8V]N<W1A;G1S#0H@*B\-
M"G)E<75I<F5?;VYC92`G4$5!4B]686QI9&%T92YP:'`G.PT*#0HO*BH-"B`J
M($1E<&5N9&5N8WD@8VAE8VL@9F]R(%!%05(@<&%C:V%G97,-"B`J#0H@*B!4
M:&ES(&-L87-S(&AA;F1L97,@8F]T:"!V97)S:6]N(#$N,"!A;F0@,BXP(&1E
M<&5N9&5N8VEE<PT*("H@5T%23DE.1SH@*F%N>2H@8VAA;F=E<R!T;R!T:&ES
M(&-L87-S(&UU<W0@8F4@9'5P;&EC871E9"!I;B!T:&4-"B`J('1E<W1?4$5!
M4E]$97!E;F1E;F-Y,B!C;&%S<R!F;W5N9"!I;B!T97-T<R]014%27T1E<&5N
M9&5N8WDR+W-E='5P+G!H<"YI;F,L#0H@*B!O<B!U;FET('1E<W1S('=I;&P@
M;F]T(&%C='5A;&QY('9A;&ED871E('1H92!C:&%N9V5S#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP
M83$-"B`J+PT*8VQA<W,@4$5!4E]$97!E;F1E;F-Y,@T*>PT*("`@("\J*@T*
M("`@("`J($]N92!O9B!T:&4@4$5!4E]604Q)1$%415\J('-T871E<PT*("`@
M("`J($!S964@4$5!4E]604Q)1$%415].3U)-04P-"B`@("`@*B!`=F%R(&EN
M=&5G97(-"B`@("`@*B\-"B`@("!V87(@)%]S=&%T93L-"B`@("`O*BH-"B`@
M("`@*B!#;VUM86YD+6QI;F4@;W!T:6]N<R!T;R!I;G-T86QL+W5P9W)A9&4O
M=6YI;G-T86QL(&-O;6UA;F1S#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@
M("HO#0H@("`@=F%R("1?;W!T:6]N<SL-"B`@("`O*BH-"B`@("`@*B!`=F%R
M($]37T=U97-S#0H@("`@("HO#0H@("`@=F%R("1?;W,[#0H@("`@+RHJ#0H@
M("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("HO#0H@("`@=F%R("1?
M<F5G:7-T<GD[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T-O;F9I9PT*
M("`@("`J+PT*("`@('9A<B`D7V-O;F9I9SL-"B`@("`O*BH-"B`@("`@*B!`
M=F%R(%!%05)?1&5P96YD96YC>41"#0H@("`@("HO#0H@("`@=F%R("1?9&5P
M96YD96YC>61B.PT*("`@("\J*@T*("`@("`J($]U='!U="!O9B!014%27U)E
M9VES=')Y.CIP87)S961086-K86=E3F%M92@I#0H@("`@("H@0'9A<B!A<G)A
M>0T*("`@("`J+PT*("`@('9A<B`D7V-U<G)E;G1086-K86=E.PT*("`@("\J
M*@T*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!P87)A;2!A
M<G)A>2!I;G-T86QL871I;VX@;W!T:6]N<PT*("`@("`J($!P87)A;2!A<G)A
M>2!F;W)M870@;V8@4$5!4E]296=I<W1R>3HZ<&%R<V5D4&%C:V%G94YA;64H
M*0T*("`@("`J($!P87)A;2!I;G0@:6YS=&%L;&%T:6]N('-T871E("AO;F4@
M;V8@4$5!4E]604Q)1$%415\J*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%
M05)?1&5P96YD96YC>3(H)B1C;VYF:6<L("1I;G-T86QL;W!T:6]N<RP@)'!A
M8VMA9V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@
M/2!014%27U9!3$E$051%7TE.4U1!3$Q)3D<I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7V-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]$97!E;F1E;F-Y1$(G*2D@>PT*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+T1E<&5N9&5N8WE$0BYP:'`G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D:6YS=&%L;&]P=&EO;G-;)W!A8VMA
M9VEN9W)O;W0G72DI('L-"B`@("`@("`@("`@("\O(&UA:V4@<W5R92!D97!D
M8B!I<R!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@("1C;VYF
M:6<M/G-E=$EN<W1A;&Q2;V]T*"1I;G-T86QL;W!T:6]N<ULG<&%C:V%G:6YG
M<F]O="==*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M(#T@)B1C;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("1T:&ES+3Y?
M9&5P96YD96YC>61B(#T@)E!%05)?1&5P96YD96YC>41".CIS:6YG;&5T;VXH
M)&-O;F9I9RD[#0H@("`@("`@(&EF("AI<W-E="@D:6YS=&%L;&]P=&EO;G-;
M)W!A8VMA9VEN9W)O;W0G72DI('L-"B`@("`@("`@("`@("1C;VYF:6<M/G-E
M=$EN<W1A;&Q2;V]T*&9A;'-E*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7V]P=&EO;G,@/2`D:6YS=&%L;&]P=&EO;G,[#0H@("`@("`@("1T:&ES
M+3Y?<W1A=&4@/2`D<W1A=&4[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"=/4U]'=65S<R<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)T]3
M+T=U97-S+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]O<R`]
M(&YE=R!/4U]'=65S<SL-"B`@("`@("`@)'1H:7,M/E]C=7)R96YT4&%C:V%G
M92`]("1P86-K86=E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]G971%>'1R
M85-T<FEN9R@D9&5P*0T*("`@('L-"B`@("`@("`@)&5X=')A(#T@)R`H)SL-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("<G.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=R96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@)&5X=')A("X]
M("=R96-O;6UE;F1E9"!V97)S:6]N("<@+B`D9&5P6R=R96-O;6UE;F1E9"==
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("1E>'1R82`N/2`G=F5R
M<VEO;B`^/2`G("X@)&1E<%LG;6EN)UT[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1E>'1R82`A/2`G("@G*2![#0H@("`@("`@("`@("`@("`@
M("`@("1E>'1R82`N/2`G+"`G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D97AT<F$@+CT@)W9E<G-I;VX@/#T@)R`N("1D97!;)VUA
M>"==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1E>'1R82`A
M/2`G("@G*2![#0H@("`@("`@("`@("`@("`@("`@("1E>'1R82`N/2`G+"`G
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D97AT<F$@
M+CT@)V5X8VQU9&5D('9E<G-I;VYS.B`G.PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1D97!;)V5X8VQU9&4G72!A<R`D:2`]/B`D97AC;'5D92D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1E>'1R82`N/2`G+"`G.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1E>'1R82`N/2`D97AC;'5D93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@)&5X=')A("X]("<I)SL-"B`@("`@("`@:68@*"1E>'1R82`]
M/2`G("@I)RD@>PT*("`@("`@("`@("`@)&5X=')A(#T@)R<[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1E>'1R83L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!4:&ES(&UA:V5S('5N:70M=&5S=&EN9R!A(&AE8VL@;V8@82!L
M;W0@96%S:65R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4$A07T]3*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B!02%!?3U,[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@5&AI<R!M86ME<R!U;FET+71E<W1I;F<@82!H96-K(&]F
M(&$@;&]T(&5A<VEE<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E='-Y<VYA
M;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W,M/F=E=%-Y
M<VYA;64H*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3<&5C:69Y(&$@
M9&5P96YD96YC>2!O;B!A;B!/4RX@(%5S92!A<F-H(&9O<B!D971A:6QE9"!O
M<R]P<F]C97-S;W(@:6YF;W)M871I;VX-"B`@("`@*@T*("`@("`J(%1H97)E
M(&%R92!T=V\@9V5N97)I8R!/4R!D97!E;F1E;F-I97,@=&AA="!W:6QL(&)E
M('1H92!M;W-T(&-O;6UO;BP@=6YI>"!A;F0@=VEN9&]W<RX-"B`@("`@*B!/
M=&AE<B!O<'1I;VYS(&%R92!L:6YU>"P@9G)E96)S9"P@9&%R=VEN("A/4R!8
M*2P@<W5N;W,L(&ER:7@L(&AP=7@L(&%I>`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('9A;&ED871E3W-$97!E;F1E;F-Y*"1D97`I#0H@("`@>PT*("`@("`@
M("!I9B`H)'1H:7,M/E]S=&%T92`A/2!014%27U9!3$E$051%7TE.4U1!3$Q)
M3D<@)B8-"B`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`A/2!014%27U9!
M3$E$051%7T1/5TY,3T%$24Y'*2![#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("`D;F]T(#T@=')U93L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1N;W0@/2!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&1E<%LG;F%M92==(#T]("<J)RD@>PT*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<W=I=&-H
M("AS=')T;VQO=V5R*"1D97!;)VYA;64G72DI('L-"B`@("`@("`@("`@(&-A
M<V4@)W=I;F1O=W,G(#H-"B`@("`@("`@("`@("`@("!I9B`H)&YO="D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<BAS=6)S='(H)'1H
M:7,M/F=E=%!(4%]/4R@I+"`P+"`S*2D@/3T@)W=I;B<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N
M;V1E<',G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#
M86YN;W0@:6YS=&%L;"`E<R!O;B!7:6YD;W=S(BD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@B=V%R;FEN9SH@0V%N;F]T(&EN
M<W1A;&P@)7,@;VX@5VEN9&]W<R(I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M<W5B<W1R*"1T:&ES+3YG97102%!?3U,H*2P@,"P@,RDI("$]("=W:6XG*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG;F]D97!S)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B0V%N(&]N;'D@:6YS=&%L;"`E<R!O;B!7:6YD;W=S(BD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@B=V%R;FEN
M9SH@0V%N(&]N;'D@:6YS=&%L;"`E<R!O;B!7:6YD;W=S(BD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&-A<V4@)W5N:7@G(#H-"B`@("`@("`@("`@("`@("`D=6YI8V5S(#T@
M87)R87DH)VQI;G5X)RP@)V9R965B<V0G+"`G9&%R=VEN)RP@)W-U;F]S)RP@
M)VER:7@G+"`G:'!U>"<L("=A:7@G*3L-"B`@("`@("`@("`@("`@("!I9B`H
M)&YO="D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'1H
M:7,M/F=E=%-Y<VYA;64H*2P@)'5N:6-E<RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G
M72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#86YN;W0@
M:6YS=&%L;"`E<R!O;B!A;GD@56YI>"!S>7-T96TB*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B=V%R;FEN9SH@0V%N;F]T(&EN<W1A;&P@)7,@
M;VX@86YY(%5N:7@@<WES=&5M(BD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1T
M:&ES+3YG9713>7-N86UE*"DL("1U;FEC97,I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S
M)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N(&]N
M;'D@:6YS=&%L;"`E<R!O;B!A(%5N:7@@<WES=&5M(BD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(G=A<FYI;F<Z($-A;B!O;FQY(&EN<W1A;&P@
M)7,@;VX@82!5;FEX('-Y<W1E;2(I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!D969A=6QT(#H-
M"B`@("`@("`@("`@("`@("!I9B`H)&YO="D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI(#T]('-T<G1O;&]W
M97(H)'1H:7,M/F=E=%-Y<VYA;64H*2DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@
M)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@:6YS
M=&%L;"`E<R!O;B`G("X@)&1E<%LG;F%M92==("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R!O<&5R871I;F<@<WES=&5M)RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@
M0V%N;F]T(&EN<W1A;&P@)7,@;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!;)VYA;64G72`N("<@;W!E<F%T:6YG('-Y<W1E
M;2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&1E<%LG;F%M92==*2`A/2!S
M=')T;VQO=V5R*"1T:&ES+3YG9713>7-N86UE*"DI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D
M97!S)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N
M;F]T(&EN<W1A;&P@)7,@;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YG9713>7-N86UE*"D@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G(&]P97)A=&EN9R!S>7-T96TL(&-A;B!O
M;FQY(&EN<W1A;&P@;VX@)R`N("1D97!;)VYA;64G72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@0V%N;F]T
M(&EN<W1A;&P@)7,@;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YG9713>7-N86UE*"D@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(&]P97)A=&EN9R!S>7-T96TL(&-A;B!O;FQY
M(&EN<W1A;&P@;VX@)R`N("1D97!;)VYA;64G72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M86ME<R!U;FET+71E<W1I
M;F<@82!H96-K(&]F(&$@;&]T(&5A<VEE<@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&UA=&-H4VEG;F%T=7)E*"1P871T97)N*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?;W,M/FUA=&-H4VEG;F%T=7)E*"1P871T97)N*3L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3<&5C:69Y(&$@8V]M<&QE>"!D
M97!E;F1E;F-Y(&]N(&%N($]3+W!R;V-E<W-O<B]K97)N96P@=F5R<VEO;BP-
M"B`@("`@*B!5<V4@3U,@9F]R('-I;7!L92!O<&5R871I;F<@<WES=&5M(&1E
M<&5N9&5N8WDN#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('1H92!O;FQY(&1E
M<&5N9&5N8WD@=&AA="!A8V-E<'1S(&%N(&5R96=A8FQE('!A='1E<FXN("!4
M:&4@<&%T=&5R;@T*("`@("`J('=I;&P@8F4@;6%T8VAE9"!A9V%I;G-T('1H
M92!P:'!?=6YA;64H*2!O=71P=70@<&%R<V5D(&)Y($]37T=U97-S#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5!<F-H1&5P96YD96YC>2@D9&5P
M*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]6
M04Q)1$%415])3E-404Q,24Y'*2![#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("`D;F]T(#T@=')U93L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1N;W0@/2!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(21T:&ES+3YM871C:%-I9VYA='5R92@D9&5P6R=P
M871T97)N)UTI*2![#0H@("`@("`@("`@("!I9B`H(21N;W0I('L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S
M)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M)7,@07)C:&ET96-T=7)E(&1E<&5N9&5N8WD@9F%I;&5D+"!D;V5S(&YO="`G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=M871C:"`B)R`N("1D97!;
M)W!A='1E<FXG72`N("<B)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W
M87)N:6YG.B`E<R!!<F-H:71E8W1U<F4@9&5P96YD96YC>2!F86EL960L(&1O
M97,@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G;F]T(&UA=&-H("(G
M("X@)&1E<%LG<&%T=&5R;B==("X@)R(G*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@D;F]T*2![#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P
M<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)R5S($%R8VAI=&5C='5R92!D97!E;F1E;F-Y(&9A:6QE9"P@<F5Q=6ER960@
M(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG<&%T=&5R;B==
M("X@)R(G*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S
M($%R8VAI=&5C='5R92!D97!E;F1E;F-Y(&9A:6QE9"P@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5Q=6ER960@(B<@+B`D9&5P6R=P871T97)N
M)UT@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M86ME<R!U;FET+71E<W1I;F<@82!H
M96-K(&]F(&$@;&]T(&5A<VEE<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&5X
M=&5N<VEO;E]L;V%D960H)&YA;64I#0H@("`@>PT*("`@("`@("!R971U<FX@
M97AT96YS:6]N7VQO861E9"@D;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@5&AI<R!M86ME<R!U;FET+71E<W1I;F<@82!H96-K(&]F(&$@;&]T
M(&5A<VEE<@T*("`@("`J+PT*("`@(&9U;F-T:6]N('!H<'9E<G-I;VXH)&YA
M;64@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*"1N86UE("$]/2!N=6QL
M*2![#0H@("`@("`@("`@("!R971U<FX@<&AP=F5R<VEO;B@D;F%M92D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@<&AP=F5R<VEO
M;B@I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&5%>'1E;G-I;VY$97!E;F1E;F-Y*"1D97`L("1R97%U:7)E9"`]('1R=64I
M#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`A/2!014%27U9!
M3$E$051%7TE.4U1!3$Q)3D<@)B8-"B`@("`@("`@("`@("`@)'1H:7,M/E]S
M=&%T92`A/2!014%27U9!3$E$051%7T1/5TY,3T%$24Y'*2![#0H@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D;&]A9&5D
M(#T@)'1H:7,M/F5X=&5N<VEO;E]L;V%D960H)&1E<%LG;F%M92==*3L-"B`@
M("`@("`@)&5X=')A(#T@)'1H:7,M/E]G971%>'1R85-T<FEN9R@D9&5P*3L-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG97AC;'5D92==*2D@>PT*("`@
M("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;)V5X
M8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<W-E="@D9&5P6R=M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA>"==
M*2`F)@T*("`@("`@("`@("`@("`A:7-S970H)&1E<%LG<F5C;VUM96YD960G
M72D@)B8@(6ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@
M(&EF("@D;&]A9&5D*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(&-O;F9L:6-T
M<R!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D97!;)VYA;64G72`N("<B)R`N("1E>'1R82D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(&-O;F9L
M:6-T<R!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!;)VYA;64G72`N("<B)R`N("1E>'1R82D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D<F5Q=6ER960I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F
M;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"<E<R!R97%U:7)E<R!02%`@97AT96YS:6]N("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE)UT@
M+B`G(B<@+B`D97AT<F$I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N
M:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!02%`@97AT96YS:6]N("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G
M(B<@+B`D97AT<F$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YW87)N:6YG*"<E<R!C86X@;W!T:6]N86QL>2!U<V4@4$A0(&5X
M=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N
M86UE)UT@+B`G(B<@+B`D97AT<F$I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21L;V%D960I
M('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@A)')E<75I<F5D*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"<E<R!C86X@;W!T:6]N86QL
M>2!U<V4@4$A0(&5X=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("1D97!;)VYA;64G72`N("<B)R`N("1E>'1R82D[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"<E<R!R97%U:7)E<R!02%`@97AT96YS:6]N("(G("X@
M)&1E<%LG;F%M92==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B)R`N
M("1E>'1R82D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I
M<F5S(%!(4"!E>'1E;G-I;VX@(B<@+B`D9&5P6R=N86UE)UT@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)R(G("X@)&5X=')A*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D=F5R<VEO;B`]("AS=')I;F<I("1T
M:&ES+3YP:'!V97)S:6]N*"1D97!;)VYA;64G72D[#0H@("`@("`@(&EF("AE
M;7!T>2@D=F5R<VEO;BDI('L-"B`@("`@("`@("`@("1V97)S:6]N(#T@)S`G
M.PT*("`@("`@("!]#0H@("`@("`@("1F86EL(#T@9F%L<V4[#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@(&EF("@A
M=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D9&5P6R=M:6XG72P@)SX])RDI
M('L-"B`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@:68@*"%V97)S:6]N7V-O;7!A<F4H)'9E<G-I
M;VXL("1D97!;)VUA>"==+"`G/#TG*2D@>PT*("`@("`@("`@("`@("`@("1F
M86EL(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&9A:6P@)B8@(6ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P
M<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@
M<F5Q=6ER97,@4$A0(&5X=&5N<VEO;B`B)R`N("1D97!;)VYA;64G72`N#0H@
M("`@("`@("`@("`@("`@("`@("<B)R`N("1E>'1R82`N("<L(&EN<W1A;&QE
M9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G
M=V%R;FEN9SH@)7,@<F5Q=6ER97,@4$A0(&5X=&5N<VEO;B`B)R`N("1D97!;
M)VYA;64G72`N#0H@("`@("`@("`@("`@("`@("`@("<B)R`N("1E>'1R82`N
M("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS96EF("@H:7-S970H)&1E<%LG;6EN
M)UTI('Q\(&ES<V5T*"1D97!;)VUA>"==*2D@)B8@(21F86EL("8F(&ES<V5T
M*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@8V]N9FQI8W1S('=I=&@@4$A0(&5X
M=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G
M72`N("<B)R`N("1E>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@
M+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@8V]N
M9FQI8W1S('=I=&@@4$A0(&5X=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@
M("`@("`@("1D97!;)VYA;64G72`N("<B)R`N("1E>'1R82`N("<L(&EN<W1A
M;&QE9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G
M72DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)V5X8VQU9&4G72!A
M<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O
M;7!A<F4H)'9E<G-I;VXL("1E>&-L=61E+"`G/3TG*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)R5S(&ES(&YO="!C;VUP871I8FQE('=I=&@@4$A0(&5X=&5N<VEO
M;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M
M92==("X@)R(@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D97AC;'5D92D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI
M;F<H)W=A<FYI;F<Z("5S(&ES(&YO="!C;VUP871I8FQE('=I=&@@4$A0(&5X
M=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E
M<%LG;F%M92==("X@)R(@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97AC;'5D92D[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H=F5R<VEO;E]C;VUP87)E*"1V
M97)S:6]N+"`D97AC;'5D92P@)R$])RD@)B8@:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@8V]N9FQI8W1S('=I=&@@4$A0
M(&5X=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<%LG;F%M92==("X@)R(G("X@)&5X=')A("X@)RP@:6YS=&%L;&5D('9E
M<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@8V]N9FQI8W1S('=I=&@@4$A0(&5X
M=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E
M<%LG;F%M92==("X@)R(G("X@)&5X=')A("X@)RP@:6YS=&%L;&5D('9E<G-I
M;VX@:7,@)R`N("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&1E<%LG<F5C;VUM96YD960G72DI('L-"B`@
M("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1D97!;
M)W)E8V]M;65N9&5D)UTL("<]/2<I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@
M(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!D97!E
M;F1E;F-Y.B!02%`@97AT96YS:6]N("<@+B`D9&5P6R=N86UE)UT@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)R!V97)S:6]N("(G("X@)'9E<G-I;VX@
M+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R!I<R!N;W0@=&AE
M(')E8V]M;65N9&5D('9E<G-I;VX@(B<@+B`D9&5P6R=R96-O;6UE;F1E9"==
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B+"!B=70@;6%Y(&)E(&-O
M;7!A=&EB;&4L('5S92`M+69O<F-E('1O(&EN<W1A;&PG*3L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(&1E<&5N9&5N8WDZ(%!(4"!E
M>'1E;G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N
M86UE)UT@+B`G('9E<G-I;VX@(B<@+B`D=F5R<VEO;B`N("<B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G(&ES(&YO="!T:&4@<F5C;VUM96YD960@
M=F5R<VEO;B`B)R`N("1D97!;)W)E8V]M;65N9&5D)UTN)R(G*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&50:'!$97!E;F1E;F-Y*"1D97`I#0H@("`@>PT*("`@("`@("!I9B`H)'1H
M:7,M/E]S=&%T92`A/2!014%27U9!3$E$051%7TE.4U1!3$Q)3D<@)B8-"B`@
M("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`A/2!014%27U9!3$E$051%7T1/
M5TY,3T%$24Y'*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@?0T*("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3YP:'!V97)S:6]N*"D[
M#0H@("`@("`@("1E>'1R82`]("1T:&ES+3Y?9V5T17AT<F%3=')I;F<H)&1E
M<"D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-
M"B`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P
M6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@(&EF
M("@A=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D9&5P6R=M:6XG72P@)SX]
M)RDI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O
M<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G)7,@<F5Q=6ER97,@4$A0)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D97AT<F$@+B`G+"!I;G-T86QL960@=F5R<VEO;B!I<R`G
M("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN
M9SH@)7,@<F5Q=6ER97,@4$A0)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97AT<F$@+B`G+"!I;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E<G-I
M;VXI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@
M("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG
M;6%X)UTL("<\/2<I*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S(%!(4"<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X=')A("X@)RP@:6YS=&%L;&5D('9E
M<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI
M;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S(%!(4"<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&5X=')A("X@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@
M)R`N("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU
M9&4G72DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)V5X8VQU9&4G
M72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N
M7V-O;7!A<F4H)'9E<G-I;VXL("1E>&-L=61E+"`G/3TG*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D
M97!S)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(&ES(&YO="!C
M;VUP871I8FQE('=I=&@@4$A0('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YW87)N:6YG*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=W
M87)N:6YG.B`E<R!I<R!N;W0@8V]M<&%T:6)L92!W:71H(%!(4"!V97)S:6]N
M("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UA:V5S('5N:70M=&5S
M=&EN9R!A(&AE8VL@;V8@82!L;W0@96%S:65R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T4$5!4E9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("<Q+C0N.2<[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A=&5096%R
M:6YS=&%L;&5R1&5P96YD96YC>2@D9&5P*0T*("`@('L-"B`@("`@("`@)'!E
M87)V97)S:6]N(#T@)'1H:7,M/F=E=%!%05)697)S:6]N*"D[#0H@("`@("`@
M("1E>'1R82`]("1T:&ES+3Y?9V5T17AT<F%3=')I;F<H)&1E<"D[#0H@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@
M("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L=61E
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AV
M97)S:6]N7V-O;7!A<F4H)'!E87)V97)S:6]N+"`D9&5P6R=M:6XG72P@)SPG
M*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G)7,@<F5Q=6ER97,@4$5!4B!);G-T86QL97(G("X@)&5X=')A("X-"B`@
M("`@("`@("`@("`@("`@("`@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N
M("1P96%R=F5R<VEO;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@
M<F5Q=6ER97,@4$5!4B!);G-T86QL97(G("X@)&5X=')A("X-"B`@("`@("`@
M("`@("`@("`@("`@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1P96%R
M=F5R<VEO;BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@:68@*'9E
M<G-I;VY?8V]M<&%R92@D<&5A<G9E<G-I;VXL("1D97!;)VUA>"==+"`G/B<I
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO
M;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)R5S(')E<75I<F5S(%!%05(@26YS=&%L;&5R)R`N("1E>'1R
M82`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G+"!I;G-T86QL960@=F5R
M<VEO;B!I<R`G("X@)'!E87)V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A
M<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S(%!%05(@26YS=&%L;&5R)R`N
M("1E>'1R82`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G+"!I;G-T86QL
M960@=F5R<VEO;B!I<R`G("X@)'!E87)V97)S:6]N*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)&1E<%LG97AC;'5D92==6S!=*2D@>PT*("`@("`@("`@("`@("`@
M("1D97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P6R=E>&-L
M=61E)UT@87,@)&5X8VQU9&4I('L-"B`@("`@("`@("`@("`@("!I9B`H=F5R
M<VEO;E]C;VUP87)E*"1E>&-L=61E+"`D<&5A<G9E<G-I;VXL("<]/2<I*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R
M8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G)7,@:7,@;F]T(&-O;7!A=&EB;&4@=VET:"!014%2
M($EN<W1A;&QE<B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F5R<VEO;B`G("X@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YW87)N:6YG*"=W87)N:6YG.B`E<R!I<R!N;W0@8V]M<&%T:6)L92!W:71H
M(%!%05(@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)TEN<W1A
M;&QE<B!V97)S:6]N("<@+B`D97AC;'5D92D[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@=F%L:61A=&53=6)P86-K86=E1&5P96YD96YC>2@D9&5P+"`D<F5Q
M=6ER960L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M
M/G9A;&ED871E4&%C:V%G941E<&5N9&5N8WDH)&1E<"P@)')E<75I<F5D+"`D
M<&%R86US*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R
M87D@9&5P96YD96YC>2!I;F9O<FUA=&EO;B`H,BXP(&9O<FUA="D-"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B!W:&5T:&5R('1H:7,@:7,@82!R97%U:7)E9"!D
M97!E;F1E;F-Y#0H@("`@("H@0'!A<F%M(&%R<F%Y(&$@;&ES="!O9B!D;W=N
M;&]A9&5D('!A8VMA9V5S('1O(&)E(&EN<W1A;&QE9"P@:68@86YY#0H@("`@
M("H@0'!A<F%M(&)O;VQE86X@:68@=')U92P@=&AE;B!D97!S(&]N('!E87(N
M<&AP+FYE="!T:&%T(&9A:6P@=VEL;"!A;'-O(&-H96-K#0H@("`@("H@("`@
M("`@("`@("`@("`@86=A:6YS="!P96-L+G!H<"YN970@<&%C:V%G97,@=&\@
M86-C;VUO9&%T92!E>'1E;G-I;VYS('1H870@:&%V90T*("`@("`J("`@("`@
M("`@("`@("`@(&UO=F5D('1O('!E8VPN<&AP+FYE="!F<F]M('!E87(N<&AP
M+FYE=`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E4&%C:V%G941E
M<&5N9&5N8WDH)&1E<"P@)')E<75I<F5D+"`D<&%R86US+"`D9&5P=C$@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7W-T871E("$](%!%
M05)?5D%,241!5$5?24Y35$%,3$E.1R`F)@T*("`@("`@("`@("`@("`D=&AI
M<RT^7W-T871E("$](%!%05)?5D%,241!5$5?1$]73DQ/041)3D<I('L-"B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@>PT*("`@("`@
M("`@("`@:68@*"1T:&ES+3YE>'1E;G-I;VY?;&]A9&5D*"1D97!;)W!R;W9I
M9&5S97AT96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@)'-A=F4@/2`D
M9&5P.PT*("`@("`@("`@("`@("`@("1S=6)D97`@/2`D9&5P.PT*("`@("`@
M("`@("`@("`@("1S=6)D97!;)VYA;64G72`]("1S=6)D97!;)W!R;W9I9&5S
M97AT96YS:6]N)UT[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@
M("1R970@/2`D=&AI<RT^=F%L:61A=&5%>'1E;G-I;VY$97!E;F1E;F-Y*"1S
M=6)D97`L("1R97%U:7)E9"D[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(&EF("@A4$5!4CHZ
M:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)
M1$%415])3E-404Q,24Y'*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]V86QI9&%T95!A8VMA9V5);G-T86QL*"1D97`L("1R97%U:7)E9"P@)&1E
M<'8Q*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`]
M/2!014%27U9!3$E$051%7T1/5TY,3T%$24Y'*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]V86QI9&%T95!A8VMA9V5$;W=N;&]A9"@D9&5P+"`D
M<F5Q=6ER960L("1P87)A;7,L("1D97!V,2D[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5086-K86=E1&]W;FQO860H)&1E
M<"P@)')E<75I<F5D+"`D<&%R86US+"`D9&5P=C$@/2!F86QS92D-"B`@("![
M#0H@("`@("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@
M("`@("`@:68@*&ES<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@("`@("`@
M)&1E<%LG8VAA;FYE;"==(#T@)U]?=7)I)SL-"B`@("`@("`@?0T*("`@("`@
M("`D9&5P;F%M92`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.
M86UE5&]3=')I;F<H)&1E<"P@=')U92D[#0H@("`@("`@("1F;W5N9"`](&9A
M;'-E.PT*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2D@>PT*
M("`@("`@("`@("`@:68@*"1P87)A;2T^:7-%<75A;"@-"B`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B`D9&5P6R=N86UE)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)&1E<%LG8VAA;FYE
M;"==*2DI('L-"B`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"1D97!V,2`F)B`D9&5P6R=C:&%N;F5L)UT@/3T@)W!E87(N<&AP
M+FYE="<I('L-"B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M+3YI<T5Q=6%L
M*`T*("`@("`@("`@("`@("`@("`@87)R87DH)W!A8VMA9V4G(#T^("1D97!;
M)VYA;64G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]
M/B`G<&5C;"YP:'`N;F5T)RDI*2![#0H@("`@("`@("`@("`@("`@("`@("1F
M;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(21F;W5N9"`F)B!I<W-E="@D9&5P6R=P<F]V:61E<V5X=&5N
M<VEO;B==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D
M<&%R86TI('L-"B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M+3YI<T5X=&5N
M<VEO;B@D9&5P6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"D@>PT*("`@("`@("`@("`@
M)'9E<G-I;VX@/2`D<&%R86TM/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@("`@
M("1I;G-T86QL960@/2!F86QS93L-"B`@("`@("`@("`@("1D;W=N;&]A9&5D
M(#T@=')U93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W)E9VES=')Y+3YP86-K86=E17AI<W1S*"1D97!;)VYA;64G72P@
M)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("1I;G-T86QL
M960@/2!T<G5E.PT*("`@("`@("`@("`@("`@("1D;W=N;&]A9&5D(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7W)E9VES
M=')Y+3YP86-K86=E:6YF;R@D9&5P6R=N86UE)UTL("=V97)S:6]N)RP-"B`@
M("`@("`@("`@("`@("`@("`@)&1E<%LG8VAA;FYE;"==*3L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"1D97!;)V-H86YN
M96PG72`]/2`G<&5C;"YP:'`N;F5T)R`F)B`D=&AI<RT^7W)E9VES=')Y+3YP
M86-K86=E17AI<W1S*"1D97!;)VYA;64G72P-"B`@("`@("`@("`@("`@("`@
M("`@("`G<&5A<BYP:'`N;F5T)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&EN<W1A;&QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("1D;W=N
M;&]A9&5D(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("1V97)S:6]N
M(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G96EN9F\H)&1E<%LG;F%M92==
M+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G<&5A<BYP
M:'`N;F5T)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)'9E<G-I;VX@/2`G;F]T(&EN<W1A;&QE9"!O<B!D;W=N
M;&]A9&5D)SL-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QE9"`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("`@("`D9&]W;FQO861E9"`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D97AT<F$@/2`D=&AI<RT^7V=E=$5X=')A4W1R:6YG*"1D
M97`I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![
M#0H@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E
M<%LG97AC;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6ES<V5T*"1D97!;)VUI;B==*2`F)B`A:7-S970H)&1E<%LG
M;6%X)UTI("8F#0H@("`@("`@("`@("`@("%I<W-E="@D9&5P6R=R96-O;6UE
M;F1E9"==*2`F)B`A:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@
M("`@("`@:68@*"1I;G-T86QL960@?'P@)&1O=VYL;V%D960I('L-"B`@("`@
M("`@("`@("`@("`D:6YS=&%L;&5D(#T@)&EN<W1A;&QE9"`_("=I;G-T86QL
M960G(#H@)V1O=VYL;V%D960G.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1V97)S:6]N*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5S
M="`]("(L("1I;G-T86QL960@=F5R<VEO;B!I<R`B("X@)'9E<G-I;VX[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5S="`]("<G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G)7,@8V]N9FQI8W1S('=I=&@@<&%C:V%G92`B)R`N("1D
M97!N86UE("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M97AT<F$@+B`D<F5S="D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI
M;F<H)W=A<FYI;F<Z("5S(&-O;F9L:6-T<R!W:71H('!A8VMA9V4@(B<@+B`D
M9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5X=')A("X@)')E<W0I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H)')E<75I<F5D*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@<F5Q=6ER
M97,@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D97AT<F$I.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!P86-K86=E("(G
M("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E>'1R82D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G=A<FYI;F<H)R5S(&-A;B!O<'1I;VYA;&QY('5S92!P86-K86=E
M("(G("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X=')A*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D:6YS=&%L;&5D("8F("$D9&]W
M;FQO861E9"D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L
M:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1R97%U:7)E9"D@>PT*("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E
M<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"<E<R!R97%U:7)E<R!P86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S('!A8VMA9V4@(B<@
M+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M97AT<F$I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"<E
M<R!C86X@;W!T:6]N86QL>2!U<V4@<&%C:V%G92`B)R`N("1D97!N86UE("X@
M)R(G("X-"B`@("`@("`@("`@("`@("`@("`@)&5X=')A*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D9F%I;"`](&9A;'-E.PT*("`@
M("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("!I
M9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D9&5P6R=M:6XG72P@)SPG
M*2D@>PT*("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X
M)UTI*2![#0H@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S
M:6]N+"`D9&5P6R=M87@G72P@)SXG*2D@>PT*("`@("`@("`@("`@("`@("1F
M86EL(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&9A:6P@)B8@(6ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*
M("`@("`@("`@("`@)&EN<W1A;&QE9"`]("1I;G-T86QL960@/R`G:6YS=&%L
M;&5D)R`Z("=D;W=N;&]A9&5D)SL-"B`@("`@("`@("`@("1D97!;)W!A8VMA
M9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("1D97`@/2`D=&AI
M<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L
M('1R=64I.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO
M;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C
M92==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G)7,@<F5Q=6ER97,@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G
M("X-"B`@("`@("`@("`@("`@("`@("`@)&5X=')A("X@(BP@)&EN<W1A;&QE
M9"!V97)S:6]N(&ES("(@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G
M=V%R;FEN9SH@)7,@<F5Q=6ER97,@<&%C:V%G92`B)R`N("1D97!N86UE("X@
M)R(G("X-"B`@("`@("`@("`@("`@("`@("`@)&5X=')A("X@(BP@)&EN<W1A
M;&QE9"!V97)S:6]N(&ES("(@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS96EF("@H:7-S970H)&1E<%LG;6EN)UTI('Q\(&ES
M<V5T*"1D97!;)VUA>"==*2D@)B8@(21F86EL("8F#0H@("`@("`@("`@("`@
M(&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2`F)B`A:7-S970H)&1E<%LG97AC
M;'5D92==*2D@>PT*("`@("`@("`@("`@)&EN<W1A;&QE9"`]("1I;G-T86QL
M960@/R`G:6YS=&%L;&5D)R`Z("=D;W=N;&]A9&5D)SL-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(&-O;F9L:6-T<R!W
M:71H('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N("1E>'1R82`N#0H@
M("`@("`@("`@("`@("`@("`@("(L("1I;G-T86QL960@=F5R<VEO;B!I<R`B
M("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(&-O
M;F9L:6-T<R!W:71H('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1E>'1R82`N("(L("1I;G-T86QL960@=F5R
M<VEO;B!I<R`B("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@
M("`@("`@("`@("`D:6YS=&%L;&5D(#T@)&EN<W1A;&QE9"`_("=I;G-T86QL
M960G(#H@)V1O=VYL;V%D960G.PT*("`@("`@("`@("`@9F]R96%C:"`H)&1E
M<%LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@("`@("`@
M:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&5X8VQU9&4L("<]/2<I
M("8F("%I<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==
M*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!I<R!N;W0@8V]M<&%T
M:6)L92!W:71H("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M;G-T86QL960@+B`G('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D97!N86UE("X@)R(@=F5R<VEO;B`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D97AC;'5D92D[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(&ES(&YO="!C;VUP871I
M8FQE('=I=&@@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M<W1A;&QE9"`N("<@<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E<&YA;64@+B`G(B!V97)S:6]N("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1E>&-L=61E*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS96EF("AV97)S:6]N7V-O
M;7!A<F4H)'9E<G-I;VXL("1E>&-L=61E+"`G(3TG*2`F)B!I<W-E="@D9&5P
M6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A
M;&QE9"`]("1I;G-T86QL960@/R`G:6YS=&%L;&5D)R`Z("=D;W=N;&]A9&5D
M)SL-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F
M;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"<E<R!C;VYF;&EC=',@=VET:"!P86-K86=E("(G
M("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E>'1R82`N("(L("1I;G-T86QL960@=F5R<VEO;B!I<R`B("X@)'9E
M<G-I;VXI.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N
M:6YG.B`E<R!C;VYF;&EC=',@=VET:"!P86-K86=E("(G("X@)&1E<&YA;64@
M+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R82`N
M("(L("1I;G-T86QL960@=F5R<VEO;B!I<R`B("X@)'9E<G-I;VXI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=R
M96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@)&EN<W1A;&QE9"`]("1I
M;G-T86QL960@/R`G:6YS=&%L;&5D)R`Z("=D;W=N;&]A9&5D)SL-"B`@("`@
M("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1D97!;)W)E
M8V]M;65N9&5D)UTL("<]/2<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(&EF("@A)&9O=6YD("8F("1I;G-T86QL960I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T4&%C:V%G92@D
M9&5P6R=N86UE)UTL("1D97!;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@D<&%R86TI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F5N="D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1P87)E;G0M/FES17%U86PH)'1H:7,M/E]C
M=7)R96YT4&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D9F]U;F0I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R86TM/FES0V]M
M<&%T:6)L92@D<&%R96YT*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>R`O+R!T:&ES(&ES(&9O<B!V
M86QI9%!A8VMA9V4H*2!C86QL<PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F5N="`]("1T:&ES+3Y?<F5G:7-T<GDM/F=E=%!A8VMA9V4H)'1H:7,M
M/E]C=7)R96YT4&%C:V%G95LG<&%C:V%G92==+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!A8VMA9V5;)V-H86YN96PG
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F5N="`A/3T@
M;G5L;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R
M86TM/FES0V]M<&%T:6)L92@D<&%R96YT*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P
M<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)VQO;W-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G)7,@9&5P96YD96YC>2!P86-K86=E("(G("X@)&1E
M<&YA;64@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(@)R`N("1I;G-T
M86QL960@+B`G('9E<G-I;VX@)R`N("1V97)S:6]N("X@#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G(&ES(&YO="!T:&4@<F5C;VUM96YD960@=F5R<VEO
M;B`G("X@)&1E<%LG<F5C;VUM96YD960G72`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G+"!B=70@;6%Y(&)E(&-O;7!A=&EB;&4L('5S92`M+69O<F-E
M('1O(&EN<W1A;&PG*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI
M;F<Z("5S(&1E<&5N9&5N8WD@<&%C:V%G92`B)R`N("1D97!N86UE("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("<B("<@+B`D:6YS=&%L;&5D("X@)R!V
M97)S:6]N("<@+B`D=F5R<VEO;B`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G(&ES(&YO="!T:&4@<F5C;VUM96YD960@=F5R<VEO;B`G("X@)&1E<%LG
M<F5C;VUM96YD960G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T95!A8VMA9V5);G-T86QL*"1D97`L
M("1R97%U:7)E9"P@)&1E<'8Q(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)'1H:7,M/E]V86QI9&%T95!A8VMA9V5$;W=N;&]A9"@D9&5P+"`D
M<F5Q=6ER960L(&%R<F%Y*"DL("1D97!V,2D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@5F5R:69Y('1H870@=6YI;G-T86QL:6YG('!A8VMA9V5S('!A
M<W-E9"!I;B!T;R!C;VUM86YD(&QI;F4@:7,@3TLN#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@4$5!4E]);G-T86QL97(@)&1L#0H@("`@("H@0')E='5R;B!0
M14%27T5R<F]R?'1R=64-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T
M95!A8VMA9V55;FEN<W1A;&PH)B1D;"D-"B`@("![#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1T:&ES+3Y?9&5P96YD96YC>61B*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&5P96YD96YC>61B.PT*("`@("`@("!]
M#0H@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`O+R!C;VYS
M=')U8W0@86X@87)R87D@;V8@(F1O=VYL;V%D960B('!A8VMA9V5S('1O(&9O
M;VP@=&AE('!A8VMA9V4@9&5P96YD96YC>2!C:&5C:V5R#0H@("`@("`@("\O
M(&EN=&\@=7-I;F<@=&AE<V4@=&\@=F%L:61A=&4@=6YI;G-T86QL<R!O9B!C
M:7)C=6QA<B!D97!E;F1E;F-I97,-"B`@("`@("`@)&1O=VYL;V%D960@/2`F
M)&1L+3YG9715;FEN<W1A;&Q086-K86=E<R@I.PT*("`@("`@("!F;W)E86-H
M("@D9&]W;FQO861E9"!A<R`D:2`]/B`D<&8I('L-"B`@("`@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"=014%27T1O=VYL;V%D97)?4&%C:V%G92<I*2![
M#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D
M97(O4&%C:V%G92YP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&1P(#T@)FYE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D9&PI.PT*("`@
M("`@("`@("`@)&1P+3YS971086-K86=E1FEL92@D9&]W;FQO861E9%LD:5TI
M.PT*("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2`F)&1P.PT*("`@("`@("!]
M#0H@("`@("`@("1D97!S(#T@)'1H:7,M/E]D97!E;F1E;F-Y9&(M/F=E=$1E
M<&5N9&5N=%!A8VMA9V5$97!E;F1E;F-I97,H)'1H:7,M/E]C=7)R96YT4&%C
M:V%G92D[#0H@("`@("`@("1F86EL(#T@9F%L<V4[#0H@("`@("`@(&EF("@D
M9&5P<RD@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1E<',@87,@)&-H86YN
M96P@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YF
M;R!A<R`D<&%C:V%G92`]/B`D9',I('L-"B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&1S(&%S("1D*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9%LG9&5P)UU;)W!A8VMA9V4G72`]("1D6R=D97`G75LG;F%M92==.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-H96-K97(@/2`F;F5W(%!%05)?
M1&5P96YD96YC>3(H)'1H:7,M/E]C;VYF:6<L("1T:&ES+3Y?;W!T:6]N<RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@
M/3X@)&-H86YN96PL("=P86-K86=E)R`]/B`D<&%C:V%G92DL("1T:&ES+3Y?
M<W1A=&4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<"`]("1D6R=D
M97`G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E9"`]("1D
M6R=T>7!E)UT@/3T@)W)E<75I<F5D)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1R970@/2`D8VAE8VME<BT^7W9A;&ED871E4&%C:V%G955N:6YS=&%L
M;"@D9&5P+"`D<F5Q=6ER960L("1P87)A;7,L("1D;"D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&PM/FQO9R@P+"`D<F5T6S!=*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("A014%2.CII<T5R<F]R
M*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1L+3YL
M;V<H,"P@)')E="T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F
M86EL*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=N;V1E<',G72D@?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@-
M"B`@("`@("`@("`@("`@("`@("`@)W=A<FYI;F<Z("5S('-H;W5L9"!N;W0@
M8F4@=6YI;G-T86QL960L(&]T:&5R(&EN<W1A;&QE9"!P86-K86=E<R!D97!E
M;F0@)R`N#0H@("`@("`@("`@("`@("`@("`@("=O;B!T:&ES('!A8VMA9V4G
M*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("`@("`G
M)7,@8V%N;F]T(&)E('5N:6YS=&%L;&5D+"!O=&AE<B!I;G-T86QL960@<&%C
M:V%G97,@9&5P96YD(&]N('1H:7,@<&%C:V%G92<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]V86QI9&%T95!A8VMA9V55;FEN<W1A;&PH)&1E<"P@
M)')E<75I<F5D+"`D<&%R86US+"`F)&1L*0T*("`@('L-"B`@("`@("`@)&1E
M<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`D9&5P;F%M
M92`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I
M;F<H)&1E<"P@=')U92D[#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@
M("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2D@>PT*("`@("`@("`@
M("`@:68@*"1P87)A;2T^:7-%<75A;"@D=&AI<RT^7V-U<G)E;G1086-K86=E
M*2D@>PT*("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7W)E9VES=')Y+3YP86-K86=E:6YF
M;R@D9&5P6R=N86UE)UTL("=V97)S:6]N)RP-"B`@("`@("`@("`@("1D97!;
M)V-H86YN96PG72D[#0H@("`@("`@(&EF("@A)'9E<G-I;VXI('L-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@("1E>'1R
M82`]("1T:&ES+3Y?9V5T17AT<F%3=')I;F<H)&1E<"D[#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@
M("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UTI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.R`O+R!U;FEN<W1A;&P@3TL@+2!T:&5S92!P86-K86=E<R!C;VYF;&EC="`H
M<')O8F%B;'D@:6YS=&%L;&5D('=I=&@@+2UF;W)C92D-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6ES<V5T*"1D97!;)VUI;B==*2`F)B`A:7-S970H)&1E
M<%LG;6%X)UTI*2![#0H@("`@("`@("`@("!I9B`H)')E<75I<F5D*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO
M9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)R5S)R`N("1E>'1R82`N("<@:7,@<F5Q=6ER960@8GD@:6YS=&%L;&5D
M('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<&YA
M;64@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@
M)7,G("X@)&5X=')A("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<@:7,@
M<F5Q=6ER960@8GD@:6YS=&%L;&5D('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N
M("<B)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)R5S
M)R`N("1E>'1R82`N#0H@("`@("`@("`@("`@("`@("`@("<@8V%N(&)E(&]P
M=&EO;F%L;'D@=7-E9"!B>2!I;G-T86QL960@<&%C:V%G92`B)R`N("1D97!N
M86UE("X@)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D9F%I;"`](&9A;'-E.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN
M)UTI*2![#0H@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S
M:6]N+"`D9&5P6R=M:6XG72P@)SX])RDI('L-"B`@("`@("`@("`@("`@("`D
M9F%I;"`]('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@:68@
M*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG;6%X)UTL("<\/2<I
M*2![#0H@("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D9F%I;"D@>PT*("`@("`@
M("`@("`@:68@*"1F;W5N9"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&1L+3Y?7U]C:&5C:V5D6R1T:&ES+3Y?8W5R<F5N=%!A8VMA9V5;)V-H
M86YN96PG75T-"B`@("`@("`@("`@("`@("`@("`@("!;)'1H:7,M/E]C=7)R
M96YT4&%C:V%G95LG<&%C:V%G92==72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)&1L+3Y?7U]C:&5C:V5D6R1T:&ES+3Y?8W5R<F5N=%!A8VMA9V5;)V-H
M86YN96PG75T-"B`@("`@("`@("`@("`@("`@("`@("!;)'1H:7,M/E]C=7)R
M96YT4&%C:V%G95LG<&%C:V%G92==72`]('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@("1D97!S(#T@)'1H:7,M/E]D97!E;F1E;F-Y9&(M/F=E=$1E<&5N
M9&5N=%!A8VMA9V5$97!E;F1E;F-I97,H#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-U<G)E;G1086-K86=E*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1D97!S*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9&5P<R!A<R`D8VAA;FYE;"`]/B`D:6YF;RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1P86-K
M86=E(#T^("1D<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9',@87,@)&0I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D6R=D97`G75LG<&%C:V%G92==(#T@)&1;)V1E
M<"==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8VAE8VME<B`]("9N97<@4$5!4E]$97!E;F1E;F-Y,B@D=&AI<RT^
M7V-O;F9I9RP@)'1H:7,M/E]O<'1I;VYS+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA
M;FYE;"P@)W!A8VMA9V4G(#T^("1P86-K86=E*2P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T871E*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97`@/2`D9%LG
M9&5P)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5Q=6ER960@/2`D9%LG='EP92==(#T]("=R97%U:7)E9"<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)&-H96-K97(M
M/E]V86QI9&%T95!A8VMA9V55;FEN<W1A;&PH)&1E<"P@)')E<75I<F5D+"`D
M<&%R86US+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D;"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:R`S.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M86EL(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21F86EL
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H)')E<75I<F5D*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F
M)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&1E<&YA
M;64@+B`D97AT<F$@+B`G(&ES(')E<75I<F5D(&)Y(&EN<W1A;&QE9"!P86-K
M86=E)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G("(E<R(G*3L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("<@+B`D9&5P;F%M92`N
M("1E>'1R82`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(&ES(')E<75I
M<F5D(&)Y(&EN<W1A;&QE9"!P86-K86=E("(E<R(G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^=V%R;FEN9R@D9&5P;F%M92`N("1E>'1R82`N("<@
M8V%N(&)E(&]P=&EO;F%L;'D@=7-E9"!B>2!I;G-T86QL960@<&%C:V%G92<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R`B)7,B)RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@=F%L:61A=&4@82!D;W=N;&]A9&5D('!A
M8VMA9V4@86=A:6YS="!I;G-T86QL960@<&%C:V%G97,-"B`@("`@*B`-"B`@
M("`@*B!!<R!O9B!014%2(#$N-"XS+"!T:&ES('=I;&P@;VYL>2!V86QI9&%T
M90T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y?%!%05)?1&]W;FQO861E
M<E]086-K86=E?%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J("`@("`@("`@("`@("`D<&MG('!A8VMA9V4@:61E;G1I
M9FEE<B`H96ET:&5R#0H@("`@("H@("`@("`@("`@("`@("`@("`@87)R87DH
M)W!A8VMA9V4G(#T^(&)L86@L("=C:&%N;F5L)R`]/B!B;&%H*2!O<B!A;B!A
M<G)A>2!W:71H#0H@("`@("H@("`@("`@("`@("`@("`@("`@:6YD97@@)VEN
M9F\G(')E9F5R96YC:6YG(&%N(&]B:F5C="D-"B`@("`@*B!`<&%R86T@4$5!
M4E]$;W=N;&]A9&5R("1D;`T*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M(&9U;&P@;&ES="!O9B!P86-K86=E<R!T;R!I;G-T86QL#0H@("`@("H@0')E
M='5R;B!T<G5E?%!%05)?17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V
M86QI9&%T95!A8VMA9V4H)'!K9RP@)B1D;"P@)'!A<F%M<R`](&%R<F%Y*"DI
M#0H@("`@>PT*("`@("`@("!I9B`H:7-?87)R87DH)'!K9RD@)B8@:7-S970H
M)'!K9ULG:6YF;R==*2D@>PT*("`@("`@("`@("`@)&1E<',@/2`D=&AI<RT^
M7V1E<&5N9&5N8WED8BT^9V5T1&5P96YD96YT4&%C:V%G941E<&5N9&5N8VEE
M<R@D<&MG6R=I;F9O)UTI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)&1E<',@/2`D=&AI<RT^7V1E<&5N9&5N8WED8BT^9V5T1&5P96YD96YT
M4&%C:V%G941E<&5N9&5N8VEE<R@D<&MG*3L-"B`@("`@("`@?0T*("`@("`@
M("`D9F%I;"`](&9A;'-E.PT*("`@("`@("!I9B`H)&1E<',I('L-"B`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1O=VYL;V%D97)?4&%C
M:V%G92<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+T1O=VYL;V%D97(O4&%C:V%G92YP:'`G.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&1P(#T@)FYE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D
M9&PI.PT*("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG*2D@>PT*("`@
M("`@("`@("`@("`@("1D<"T^<V5T4&%C:V%G949I;&4H)'!K9RD[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1D<"T^<V5T1&]W
M;FQO86154DPH)'!K9RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!0
M14%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@
M("`@("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D8VAA;FYE;"`]/B`D:6YF
M;RD@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1P86-K
M86=E(#T^("1D<RD@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1P86-K9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*'-T<G1O;&]W97(H)'!A8VMD+3YG971086-K86=E*"DI(#T]('-T<G1O
M;&]W97(H)'!A8VMA9V4I("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%C:V0M/F=E=$-H86YN96PH*2`]/2`D8VAA;FYE;"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D;"T^;&]G*#,L("=S:VEP<&EN
M9R!I;G-T86QL960@<&%C:V%G92!C:&5C:R!O9B`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R
M>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG
M(#T^("1C:&%N;F5L+"`G<&%C:V%G92<@/3X@)'!A8VMA9V4I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E*2`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(L
M('9E<G-I;VX@(B<@+B`D<&%C:V0M/F=E=%9E<G-I;VXH*2`N("<B('=I;&P@
M8F4@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1O=VYL;V%D960@86YD(&EN<W1A;&QE9"<I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([("\O(&IU;7`@=&\@;F5X="!P
M86-K86=E#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1S
M(&%S("1D*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8VAE8VME<B`]
M("9N97<@4$5!4E]$97!E;F1E;F-Y,B@D=&AI<RT^7V-O;F9I9RP@)'1H:7,M
M/E]O<'1I;VYS+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=C:&%N;F5L)R`]/B`D8VAA;FYE;"P@)W!A8VMA9V4G(#T^("1P86-K86=E
M*2P@)'1H:7,M/E]S=&%T92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5P(#T@)&1;)V1E<"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M<75I<F5D(#T@)&1;)W1Y<&4G72`]/2`G<F5Q=6ER960G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E="`]("1C:&5C:V5R+3Y?=F%L:61A=&5086-K
M86=E1&]W;FQO860H)&1E<"P@)')E<75I<F5D+"!A<G)A>2@F)&1P*2D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&PM/FQO9R@P+"`D<F5T
M6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("A014%2
M.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1L+3YL;V<H,"P@)')E="T^9V5T365S<V%G92@I*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!014%2
M.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1F86EL*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H#0H@("`@("`@("`@("`@("`@)R5S(&-A;FYO="!B92!I;G-T86QL960L
M(&-O;F9L:6-T<R!W:71H(&EN<W1A;&QE9"!P86-K86=E<R<I.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J('9A;&ED871E(&$@<&%C:V%G92YX;6P@,2XP(&1E<&5N9&5N8WD-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T941E<&5N9&5N8WDQ*"1D
M97`L("1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<W-E="@D9&5P6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@("`@)&1E<%LG
M;W!T:6]N86PG72`]("=N;R<[#0H@("`@("`@('T-"B`@("`@("`@;&ES="@D
M;F5W9&5P+"`D='EP92D@/2`D=&AI<RT^;F]R;6%L:7IE1&5P*"1D97`I.PT*
M("`@("`@("!I9B`H(21N97=D97`I('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B26YV86QI9"!$97!E;F1E;F-Y(BD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,L(")V86QI
M9&%T97LD='EP97U$97!E;F1E;F-Y(BDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y(GTH)&YE=V1E
M<"P@)&1E<%LG;W!T:6]N86PG72`]/2`G;F\G+`T*("`@("`@("`@("`@("`@
M("1P87)A;7,L('1R=64I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0V]N=F5R="!A(#$N,"!D97`@:6YT;R!A(#(N,"!D97`-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!N;W)M86QI>F5$97`H)&1E<"D-"B`@("![
M#0H@("`@("`@("1T>7!E<R`](&%R<F%Y*`T*("`@("`@("`@("`@)W!K9R<@
M/3X@)U!A8VMA9V4G+`T*("`@("`@("`@("`@)V5X="<@/3X@)T5X=&5N<VEO
M;B<L#0H@("`@("`@("`@("`G;W,G(#T^("=/<R<L#0H@("`@("`@("`@("`G
M<&AP)R`]/B`G4&AP)PT*("`@("`@("`I.PT*("`@("`@("!I9B`H:7-S970H
M)'1Y<&5S6R1D97!;)W1Y<&4G75TI*2![#0H@("`@("`@("`@("`D='EP92`]
M("1T>7!E<ULD9&5P6R=T>7!E)UU=.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*&9A;'-E+"!F86QS92D[#0H@("`@("`@
M('T-"B`@("`@("`@)&YE=V1E<"`](&%R<F%Y*"D[#0H@("`@("`@('-W:71C
M:"`H)'1Y<&4I('L-"B`@("`@("`@("`@(&-A<V4@)U!A8VMA9V4G(#H-"B`@
M("`@("`@("`@("`@("`D;F5W9&5P6R=C:&%N;F5L)UT@/2`G<&5A<BYP:'`N
M;F5T)SL-"B`@("`@("`@("`@(&-A<V4@)T5X=&5N<VEO;B<@.@T*("`@("`@
M("`@("`@8V%S92`G3W,G(#H-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=N
M86UE)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@?0T*("`@("`@("`D9&5P6R=R96PG72`](%!%05)?1&5P96YD96YC
M>3(Z.G-I9VY/<&5R871O<B@D9&5P6R=R96PG72D[#0H@("`@("`@('-W:71C
M:"`H)&1E<%LG<F5L)UTI('L-"B`@("`@("`@("`@(&-A<V4@)VAA<R<@.@T*
M("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;F5W9&5P+"`D='EP92D[
M#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)VYO="<@
M.@T*("`@("`@("`@("`@("`@("1N97=D97!;)V-O;F9L:6-T<R==(#T@=')U
M93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G/CTG
M(#H-"B`@("`@("`@("`@(&-A<V4@)SXG(#H-"B`@("`@("`@("`@("`@("`D
M;F5W9&5P6R=M:6XG72`]("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@
M("`@("!I9B`H)&1E<%LG<F5L)UT@/3T@)SXG*2![#0H@("`@("`@("`@("`@
M("`@("`@("1N97=D97!;)V5X8VQU9&4G72`]("1D97!;)W9E<G-I;VXG73L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@(&-A<V4@)SP])R`Z#0H@("`@("`@("`@("!C87-E("<\)R`Z#0H@
M("`@("`@("`@("`@("`@)&YE=V1E<%LG;6%X)UT@/2`D9&5P6R=V97)S:6]N
M)UT[#0H@("`@("`@("`@("`@("`@:68@*"1D97!;)W)E;"==(#T]("<\)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D;F5W9&5P6R=E>&-L=61E)UT@/2`D
M9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=N92<@.@T*("`@("`@("`@
M("`@8V%S92`G(3TG(#H-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M:6XG
M72`]("<P)SL-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M87@G72`]("<Q
M,#`P,#`G.PT*("`@("`@("`@("`@("`@("1N97=D97!;)V5X8VQU9&4G72`]
M("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G/3TG(#H-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M
M:6XG72`]("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`D;F5W
M9&5P6R=M87@G72`]("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D='EP92`]/2`G4&AP)RD@
M>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D;F5W9&5P6R=M:6XG72DI('L-
M"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M:6XG72`]("<T+C(N,"<[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1N97=D97!;
M)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("1N97=D97!;)VUA>"==(#T@
M)S8N,"XP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@87)R87DH)&YE=V1E<"P@)'1Y<&4I.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($-O;G9E<G1S('1E>'0@8V]M<&%R:6YG(&]P97)A=&]R<R!T
M;R!T:&5M('-I9VX@97%U:79A;&5N=',-"B`@("`@*@T*("`@("`J($5X86UP
M;&4Z("=G92<@=&\@)SX])PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B!`<&%R86T@('-T<FEN9R!/<&5R871O<@T*("`@("`J($!R
M971U<FX@<W1R:6YG(%-I9VX@97%U:79A;&5N=`T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-I9VY/<&5R871O<B@D;W!E<F%T;W(I#0H@("`@>PT*("`@("`@
M("!S=VET8V@H)&]P97)A=&]R*2![#0H@("`@("`@("`@("!C87-E("=L="<Z
M(')E='5R;B`G/"<[#0H@("`@("`@("`@("!C87-E("=L92<Z(')E='5R;B`G
M/#TG.PT*("`@("`@("`@("`@8V%S92`G9W0G.B!R971U<FX@)SXG.PT*("`@
M("`@("`@("`@8V%S92`G9V4G.B!R971U<FX@)SX])SL-"B`@("`@("`@("`@
M(&-A<V4@)V5Q)SH@<F5T=7)N("<]/2<[#0H@("`@("`@("`@("!C87-E("=N
M92<Z(')E='5R;B`G(3TG.PT*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@
M("`@("`@("`@("!R971U<FX@)&]P97)A=&]R.PT*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D;7-G*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG:6=N;W)E+65R<F]R
M<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"1M
M<V<I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H)&US9RP@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C
M:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=%!A8VMA9V4L('1R=64I*2D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=V%R
M;FEN9R@D;7-G*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&%R<F%Y*'-P<FEN
M=&8H)&US9RP@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654
M;U-T<FEN9R@-"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!A8VMA9V4L
M('1R=64I*2D[#0H@("`@?0T*?0T*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+T]3+P``````````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q
M,#4W`#`Q-38V-0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3U,O1W5E
M<W,N<&AP````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,C4W-3<`,3`U,34T,S$P-3<`,#$W-3`Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO*BH-"B`J(%1H92!/
M4U]'=65S<R!C;&%S<PT*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@
M*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@($=R96=O<GD@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!'=65S<RYP:'`L=B`Q+C(P(#(P,#4O,3`O,C8@,3DZ,S,Z,#,@
M8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B
M;&4@<VEN8V4@4$5!4B`P+C$-"B`J+PT*#0HO+R![>WL@=6YA;64@97AA;7!L
M97,-"@T*+R\@<&AP7W5N86UE*"D@=VET:&]U="!A<F=S(')E='5R;G,@=&AE
M('-A;64@87,@)W5N86UE("UA)RP@;W(@82!02%`M8W5S=&]M#0HO+R!S=')I
M;F<@9F]R(%=I;F1O=W,N#0HO+R!02%`@=F5R<VEO;G,@<')I;W(@=&\@-"XS
M(')E='5R;B!T:&4@=6YA;64@;V8@=&AE(&AO<W0@=VAE<F4@4$A0('=A<R!B
M=6EL="P-"B\O(&%S(&]F(#0N,R!I="!R971U<FYS('1H92!U;F%M92!O9B!T
M:&4@:&]S="!R=6YN:6YG('1H92!02%`@8V]D92X-"B\O#0HO+R!00R!2961(
M870@3&EN=7@@-RXQ.@T*+R\@3&EN=7@@:&]S="YE>&%M<&QE+F-O;2`R+C0N
M,BTR(",Q(%-U;B!!<'(@."`R,#HT,3HS,"!%1%0@,C`P,2!I-C@V('5N:VYO
M=VX-"B\O#0HO+R!00R!$96)I86X@4&]T871O.@T*+R\@3&EN=7@@:&]S="`R
M+C0N,3<@(S(@4TU0(%1U92!&96(@,3(@,34Z,3`Z,#0@0T54(#(P,#(@:38X
M-B!U;FMN;W=N#0HO+PT*+R\@4$,@1G)E94)31"`S+C,Z#0HO+R!&<F5E0E-$
M(&AO<W0N97AA;7!L92YC;VT@,RXS+5-404),12!&<F5E0E-$(#,N,RU35$%"
M3$4@(S`Z($UO;B!&96(@,C$@,#`Z-#(Z,S$@0T54(#(P,#`@("`@(')O;W1`
M97AA;7!L92YC;VTZ+W5S<B]S<F,O<WES+V-O;7!I;&4O0T].1DE'("!I,S@V
M#0HO+PT*+R\@4$,@1G)E94)31"`T+C,Z#0HO+R!&<F5E0E-$(&AO<W0N97AA
M;7!L92YC;VT@-"XS+5)%3$5!4T4@1G)E94)31"`T+C,M4D5,14%312`C,3H@
M36]N($IU;B`R-2`Q,3HQ.3HT,R!%1%0@,C`P,2`@("`@<F]O=$!E>&%M<&QE
M+F-O;3HO=7-R+W-R8R]S>7,O8V]M<&EL92]#3TY&24<@(&DS.#8-"B\O#0HO
M+R!00R!&<F5E0E-$(#0N-3H-"B\O($9R965"4T0@:&]S="YE>&%M<&QE+F-O
M;2`T+C4M4U1!0DQ%($9R965"4T0@-"XU+5-404),12`C,#H@5V5D($9E8B`@
M-B`R,SHU.3HR,R!#150@,C`P,B`@("`@<F]O=$!E>&%M<&QE+F-O;3HO=7-R
M+W-R8R]S>7,O8V]M<&EL92]#3TY&24<@(&DS.#8-"B\O#0HO+R!00R!&<F5E
M0E-$(#0N-2!W+W5N86UE(&9R;VT@1TY5('-H96QL=71I;',Z#0HO+R!&<F5E
M0E-$(&AO<W0N97AA;7!L92YC;VT@-"XU+5-404),12!&<F5E0E-$(#0N-2U3
M5$%"3$4@(S`Z(%=E9"!&96(@(&DS.#8@=6YK;F]W;@T*+R\-"B\O($A0(#DP
M,#`O-S$R($A0+558(#$P.@T*+R\@2%`M55@@:7$@0BXQ,"XQ,"!!(#DP,#`O
M-S$R(#(P,#@T,CDQ,3,@='=O+75S97(@;&EC96YS90T*+R\-"B\O($A0(#DP
M,#`O-S$R($A0+558(#$P('<O=6YA;64@9G)O;2!'3E4@<VAE;&QU=&EL<SH-
M"B\O($A0+558(&AO<W0@0BXQ,"XQ,"!!(#DP,#`O-S$R('5N:VYO=VX-"B\O
M#0HO+R!)0DT@4E,V,#`P+S4U,"!!25@@-"XS.@T*+R\@04E8(&AO<W0@,R`T
M(#`P,#`P,S4S,4,P,`T*+R\-"B\O($%)6"`T+C,@=R]U;F%M92!F<F]M($=.
M52!S:&5L;'5T:6QS.@T*+R\@04E8(&AO<W0@,R`T(#`P,#`P,S4S,4,P,"!U
M;FMN;W=N#0HO+PT*+R\@4T=)($]N>7@@25))6"`V+C4@=R]U;F%M92!F<F]M
M($=.52!S:&5L;'5T:6QS.@T*+R\@25))6#8T(&AO<W0@-BXU(#`Q,#DQ.#(P
M($E0,3D@;6EP<PT*+R\-"B\O(%-'22!/;GEX($E225@@-BXU.@T*+R\@25))
M6#8T(&AO<W0@-BXU(#`Q,#DQ.#(P($E0,3D-"B\O#0HO+R!3<&%R8U-T871I
M;VX@,C`@4V]L87)I<R`X('<O=6YA;64@9G)O;2!'3E4@<VAE;&QU=&EL<SH-
M"B\O(%-U;D]3(&AO<W0N97AA;7!L92YC;VT@-2XX($=E;F5R:6-?,3`X-3(X
M+3$R('-U;C1M('-P87)C#0HO+PT*+R\@4W!A<F-3=&%T:6]N(#(P(%-O;&%R
M:7,@.#H-"B\O(%-U;D]3(&AO<W0N97AA;7!L92YC;VT@-2XX($=E;F5R:6-?
M,3`X-3(X+3$R('-U;C1M('-P87)C(%-53E<L4U!!4D-S=&%T:6]N+3(P#0HO
M+PT*+R\@36%C($]3(%@@*$1A<G=I;BD-"B\O($1A<G=I;B!H;VUE+65D96XN
M;&]C86P@-RXU+C`@1&%R=VEN($ME<FYE;"!697)S:6]N(#<N-2XP.B!4:'4@
M075G("`U(#$Y.C(V.C$V(%!$5"`R,#`T.R!R;V]T.GAN=2]X;G4M-3$W+C<N
M,C$N;V)J?C,O4D5,14%315]04$,@(%!O=V5R($UA8VEN=&]S:`T*+R\-"B\O
M($UA8R!/4R!8(&5A<FQY('9E<G-I;VYS#0HO+R`-"@T*+R\@?7U]#0H-"B\J
M(%1/1$\Z#0H@*B`M(&1E9FEN92!E;F1I86YN97-S+"!T;R!A;&QO=R!M871C
M:%-I9VYA='5R92@B8FEG96YD(BD@971C+@T*("HO#0H-"B\J*@T*("H@4F5T
M<FEE=F5S(&EN9F]R;6%T:6]N(&%B;W5T('1H92!C=7)R96YT(&]P97)A=&EN
M9R!S>7-T96T-"B`J#0H@*B!4:&ES(&-L87-S('5S97,@<&AP7W5N86UE*"D@
M=&\@9W)O:R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8W5R<F5N="!/4PT*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@($=R96=O<GD@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,"XQ#0H@*B\-"F-L87-S($]37T=U97-S#0I[#0H@("`@=F%R("1S
M>7-N86UE.PT*("`@('9A<B`D;F]D96YA;64[#0H@("`@=F%R("1C<'4[#0H@
M("`@=F%R("1R96QE87-E.PT*("`@('9A<B`D97AT<F$[#0H-"B`@("!F=6YC
M=&EO;B!/4U]'=65S<R@D=6YA;64@/2!N=6QL*0T*("`@('L-"B`@("`@("`@
M;&ES="@D=&AI<RT^<WES;F%M92P-"B`@("`@("`@("`@("`D=&AI<RT^<F5L
M96%S92P-"B`@("`@("`@("`@("`D=&AI<RT^8W!U+`T*("`@("`@("`@("`@
M("1T:&ES+3YE>'1R82P-"B`@("`@("`@("`@("`D=&AI<RT^;F]D96YA;64I
M(#T@)'1H:7,M/G!A<G-E4VEG;F%T=7)E*"1U;F%M92D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<&%R<V53:6=N871U<F4H)'5N86UE(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@('-T871I8R`D<WES;6%P(#T@87)R87DH#0H@("`@("`@
M("`@("`G2%`M55@G(#T^("=H<'5X)RP-"B`@("`@("`@("`@("=)4DE8-C0G
M(#T^("=I<FEX)RP-"B`@("`@("`@*3L-"B`@("`@("`@<W1A=&EC("1C<'5M
M87`@/2!A<G)A>2@-"B`@("`@("`@("`@("=I-3@V)R`]/B`G:3,X-B<L#0H@
M("`@("`@("`@("`G:38X-B<@/3X@)VDS.#8G+`T*("`@("`@("`@("`@)W!P
M8R<@/3X@)W!O=V5R<&,G+`T*("`@("`@("`I.PT*("`@("`@("!I9B`H)'5N
M86UE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D=6YA;64@/2!P:'!?=6YA
M;64H*3L-"B`@("`@("`@?0T*("`@("`@("`D<&%R=',@/2!S<&QI="@G6ULZ
M<W!A8V4Z75TK)RP@=')I;2@D=6YA;64I*3L-"B`@("`@("`@)&X@/2!C;W5N
M="@D<&%R=',I.PT*#0H@("`@("`@("1R96QE87-E(#T@)&UA8VAI;F4@/2`D
M8W!U(#T@)R<[#0H@("`@("`@("1S>7-N86UE(#T@)'!A<G1S6S!=.PT*("`@
M("`@("`D;F]D96YA;64@/2`D<&%R='-;,5T[#0H@("`@("`@("1C<'4@/2`D
M<&%R='-;)&XM,5T[#0H@("`@("`@("1E>'1R82`]("<G.PT*("`@("`@("!I
M9B`H)&-P=2`]/2`G=6YK;F]W;B<I('L-"B`@("`@("`@("`@("1C<'4@/2`D
M<&%R='-;)&XM,ET[#0H@("`@("`@('T-"@T*("`@("`@("!S=VET8V@@*"1S
M>7-N86UE*2![#0H@("`@("`@("`@("!C87-E("=!25@G(#H-"B`@("`@("`@
M("`@("`@("`D<F5L96%S92`]("(D<&%R='-;,UTN)'!A<G1S6S)=(CL-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)U=I;F1O
M=W,G(#H-"B`@("`@("`@("`@("`@("!S=VET8V@@*"1P87)T<ULQ72D@>PT*
M("`@("`@("`@("`@("`@("`@("!C87-E("<Y-2\Y."<Z#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5L96%S92`]("<Y>"<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@9&5F875L
M=#H-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E(#T@)'!A<G1S
M6S%=.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1C<'4@/2`G:3,X-B<[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=,:6YU
M>"<@.@T*("`@("`@("`@("`@("`@("1E>'1R82`]("1T:&ES+3Y?9&5T96-T
M1VQI8F-697)S:6]N*"D[#0H@("`@("`@("`@("`@("`@+R\@=7-E(&]N;'D@
M=&AE(&9I<G-T('1W;R!D:6=I=',@9G)O;2!T:&4@:V5R;F5L('9E<G-I;VX-
M"B`@("`@("`@("`@("`@("`D<F5L96%S92`](&5R96=?<F5P;&%C92@G7BA;
M6SID:6=I=#I=72M<+EM;.F1I9VET.EU=*RDN*B<L("=<,2<L("1P87)T<ULR
M72D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E
M("=-86,G(#H-"B`@("`@("`@("`@("`@("`D<WES;F%M92`]("=D87)W:6XG
M.PT*("`@("`@("`@("`@("`@("1N;V1E;F%M92`]("1P87)T<ULR73L-"B`@
M("`@("`@("`@("`@("`D<F5L96%S92`]("1P87)T<ULS73L-"B`@("`@("`@
M("`@("`@("!I9B`H)&-P=2`]/2`G36%C:6YT;W-H)RD@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'!A<G1S6R1N("T@,ET@/3T@)U!O=V5R)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-P=2`]("=P;W=E<G!C)SL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)T1A<G=I;B<@
M.@T*("`@("`@("`@("`@("`@(&EF("@D8W!U(#T]("=-86-I;G1O<V@G*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R='-;)&X@+2`R72`]/2`G
M4&]W97(G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W!U(#T@)W!O
M=V5R<&,G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@97)E9U]R97!L86-E
M*"=>*%M;.F1I9VET.EU=*UPN6ULZ9&EG:70Z75TK*2XJ)RP@)UPQ)RP@)'!A
M<G1S6S)=*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@)')E;&5A<V4@/2!E<F5G7W)E
M<&QA8V4H)RTN*B<L("<G+"`D<&%R='-;,ETI.PT*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("!]#0H-"@T*("`@("`@("!I9B`H:7-S970H)'-Y
M<VUA<%LD<WES;F%M95TI*2![#0H@("`@("`@("`@("`D<WES;F%M92`]("1S
M>7-M87!;)'-Y<VYA;65=.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'-Y<VYA;64@/2!S=')T;VQO=V5R*"1S>7-N86UE*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&-P=6UA<%LD8W!U72DI('L-"B`@("`@
M("`@("`@("1C<'4@/2`D8W!U;6%P6R1C<'5=.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!A<G)A>2@D<WES;F%M92P@)')E;&5A<V4L("1C<'4L("1E
M>'1R82P@)&YO9&5N86UE*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&5T
M96-T1VQI8F-697)S:6]N*"D-"B`@("![#0H@("`@("`@('-T871I8R`D9VQI
M8F,@/2!F86QS93L-"B`@("`@("`@:68@*"1G;&EB8R`A/3T@9F%L<V4I('L-
M"B`@("`@("`@("`@(')E='5R;B`D9VQI8F,[("\O(&YO(&YE960@=&\@<G5N
M('1H:7,@;75L=&EP;&4@=&EM97,-"B`@("`@("`@?0T*("`@("`@("!I;F-L
M=61E7V]N8V4@(E-Y<W1E;2YP:'`B.PT*("`@("`@("!I9B`H(69I;&5?97AI
M<W1S*"<O=7-R+V)I;B]C<'`G*2!\?"`A:7-?97AE8W5T86)L92@G+W5S<B]B
M:6XO8W!P)RDI('L-"B`@("`@("`@("`@("\O(%5S92!G;&EB8R=S(#QF96%T
M=7)E<RYH/B!H96%D97(@9FEL92!T;PT*("`@("`@("`@("`@+R\@9V5T(&UA
M:F]R(&%N9"!M:6YO<B!V97)S:6]N(&YU;6)E<CH-"B`@("`@("`@("`@(&EF
M("@D9F5A='5R97-?9FEL92`]($!F;W!E;B@G+W5S<B]I;F-L=61E+V9E871U
M<F5S+F@G+"`G<F(G*2`I('L-"B`@("`@("`@("`@("`@("!W:&EL92`H(69E
M;V8H)&9E871U<F5S7V9I;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1L
M:6YE(#T@9F=E=',H)&9E871U<F5S7V9I;&4L(#@Q.3(I.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H(21L:6YE('Q\("AS=')P;W,H)&QI;F4L("<C9&5F
M:6YE)RD@/3T](&9A;'-E*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*'-T<G!O<R@D;&EN92P@)U]?1TQ)0D-?7R<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!M86IO<B!V97)S:6]N(&YU;6)E
M<B`C9&5F:6YE(%]?1TQ)0D-?7R!V97)S:6]N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D;&EN92`]('!R96=?<W!L:70H)R]<<RLO)RP@)&QI;F4I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&=L:6)C7VUA:F]R(#T@=')I;2@D
M;&EN95LR72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&=L:6)C7VUI;F]R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;&EN92P@)U]?
M1TQ)0D-?34E.3U)?7R<I*2`@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@9V]T('1H92!M:6YO<B!V97)S:6]N(&YU;6)E<@T*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@(V1E9FEN92!?7T=,24)#7TU)3D]27U\@=F5R<VEO
M;@T*("`@("`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2!P<F5G7W-P;&ET
M*"<O7',K+R<L("1L:6YE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1G
M;&EB8U]M:6YO<B`]('1R:6TH)&QI;F5;,ETI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1G;&EB8U]M86IO<BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&9C;&]S92@D9F5A='5R97-?9FEL92D[#0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D9VQI8F-?;6%J;W(I('Q\("%I<W-E="@D
M9VQI8F-?;6EN;W(I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M9VQI8F,@/2`G)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1G;&EB8R`]("=G;&EB8R<@+B!T<FEM*"1G;&EB8U]M86IO
M<BD@+B`B+B(@+B!T<FEM*"1G;&EB8U]M:6YO<BD@.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@<F5T=7)N("1G;&EB8R`]("<G.PT*("`@("`@("!]
M#0H@("`@("`@("1T;7!F:6QE(#T@4WES=&5M.CIM:W1E;7`H(F=L:6)C=&5S
M="(I.PT*("`@("`@("`D9G`@/2!F;W!E;B@D=&UP9FEL92P@(G<B*3L-"B`@
M("`@("`@9G=R:71E*"1F<"P@(B-I;F-L=61E(#QF96%T=7)E<RYH/EQN7U]'
M3$E"0U]?(%]?1TQ)0D-?34E.3U)?7UQN(BD[#0H@("`@("`@(&9C;&]S92@D
M9G`I.PT*("`@("`@("`D8W!P(#T@<&]P96XH(B]U<W(O8FEN+V-P<"`D=&UP
M9FEL92(L(")R(BD[#0H@("`@("`@("1M86IO<B`]("1M:6YO<B`](#`[#0H@
M("`@("`@('=H:6QE("@D;&EN92`](&9G971S*"1C<'`L(#$P,C0I*2![#0H@
M("`@("`@("`@("!I9B`H)&QI;F5[,'T@/3T@)R,G('Q\('1R:6TH)&QI;F4I
M(#T]("<G*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H;&ES="@D;6%J;W(L("1M:6YO<BD@
M/2!E>'!L;V1E*"<@)RP@=')I;2@D;&EN92DI*2![#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<&-L;W-E*"1C<'`I.PT*("`@("`@("!U;FQI;FLH)'1M<&9I;&4I.PT*("`@
M("`@("!I9B`H(2@D;6%J;W(@)B8@)&UI;F]R*2`F)B!I<U]L:6YK*"<O;&EB
M+VQI8F,N<V\N-B<I*2![#0H@("`@("`@("`@("`O+R!,970G<R!T<GD@<F5A
M9&EN9R!T:&4@;&EB8RYS;RXV('-Y;6QI;FL-"B`@("`@("`@("`@(&EF("AE
M<F5G*"=>;&EB8RTH6RXJ72E<+G-O)"<L(&)A<V5N86UE*')E861L:6YK*"<O
M;&EB+VQI8F,N<V\N-B<I*2P@)&UA=&-H97,I*2![#0H@("`@("`@("`@("`@
M("`@;&ES="@D;6%J;W(L("1M:6YO<BD@/2!E>'!L;V1E*"<N)RP@)&UA=&-H
M97,I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A
M*"1M86IO<B`F)B`D;6EN;W(I*2![#0H@("`@("`@("`@("!R971U<FX@)&=L
M:6)C(#T@)R<[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1G;&EB8R`]
M(")G;&EB8WLD;6%J;W)]+GLD;6EN;W)](CL-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!G9713:6=N871U<F4H*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3YE>'1R82DI('L-"B`@("`@("`@("`@(')E='5R;B`B>R1T:&ES
M+3YS>7-N86UE?2U[)'1H:7,M/G)E;&5A<V5]+7LD=&AI<RT^8W!U?2([#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N(")[)'1H:7,M/G-Y<VYA;65]+7LD
M=&AI<RT^<F5L96%S97TM>R1T:&ES+3YC<'5]+7LD=&AI<RT^97AT<F%](CL-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9713>7-N86UE*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^<WES;F%M93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971.;V1E;F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)'1H:7,M/FYO9&5N86UE.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$-P
M=2@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F-P=3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971296QE87-E*"D-"B`@("![#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F5L96%S93L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!G971%>'1R82@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F5X
M=')A.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&UA=&-H4VEG;F%T=7)E*"1M
M871C:"D-"B`@("![#0H@("`@("`@(&EF("AI<U]A<G)A>2@D;6%T8V@I*2![
M#0H@("`@("`@("`@("`D9G)A9VUE;G1S(#T@)&UA=&-H.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&9R86=M96YT<R`](&5X<&QO9&4H)RTG
M+"`D;6%T8V@I.PT*("`@("`@("!]#0H@("`@("`@("1N(#T@8V]U;G0H)&9R
M86=M96YT<RD[#0H@("`@("`@("1M871C:&5S(#T@,#L-"B`@("`@("`@:68@
M*"1N(#X@,"D@>PT*("`@("`@("`@("`@)&UA=&-H97,@*ST@)'1H:7,M/E]M
M871C:$9R86=M96YT*"1F<F%G;65N='-;,%TL("1T:&ES+3YS>7-N86UE*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&X@/B`Q*2![#0H@("`@("`@("`@
M("`D;6%T8VAE<R`K/2`D=&AI<RT^7VUA=&-H1G)A9VUE;G0H)&9R86=M96YT
M<ULQ72P@)'1H:7,M/G)E;&5A<V4I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D;B`^(#(I('L-"B`@("`@("`@("`@("1M871C:&5S("L]("1T:&ES+3Y?
M;6%T8VA&<F%G;65N="@D9G)A9VUE;G1S6S)=+"`D=&AI<RT^8W!U*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)&X@/B`S*2![#0H@("`@("`@("`@("`D
M;6%T8VAE<R`K/2`D=&AI<RT^7VUA=&-H1G)A9VUE;G0H)&9R86=M96YT<ULS
M72P@)'1H:7,M/F5X=')A*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M*"1M871C:&5S(#T]("1N*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?;6%T
M8VA&<F%G;65N="@D9G)A9VUE;G0L("1V86QU92D-"B`@("![#0H@("`@("`@
M(&EF("AS=')C<W!N*"1F<F%G;65N="P@)RH_)RD@/"!S=')L96XH)&9R86=M
M96YT*2D@>PT*("`@("`@("`@("`@)')E9R`]("=>)R`N('-T<E]R97!L86-E
M*&%R<F%Y*"<J)RP@)S\G+"`G+R<I+"!A<G)A>2@G+BHG+"`G+B<L("=<7"\G
M*2P@)&9R86=M96YT*2`N("<D)SL-"B`@("`@("`@("`@(')E='5R;B!E<F5G
M:2@D<F5G+"`D=F%L=64I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`H
M)&9R86=M96YT(#T]("<J)R!\?"`A<W1R8V%S96-M<"@D9G)A9VUE;G0L("1V
M86QU92DI.PT*("`@('T-"@T*?0T*+RH-"B`J($QO8V%L(%9A<FEA8FQE<SH-
M"B`J(&EN9&5N="UT86)S+6UO9&4Z(&YI;`T*("H@8RUB87-I8RUO9F9S970Z
M(#0-"B`J($5N9#H-"B`J+PT*/SX-"@``````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+P``````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#4W`#`Q-C4P-@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O6$U,7U!A<G-E<B\`````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(P-#8R`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+P``````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C$V
M,C0`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S
M97(O=&5S=',O,#`U+G!H<'0`````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C<U
M`#$P-3$U-#,Q,#4W`#`R,S`S-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+51%4U0M+0I834P@4&%R<V5R.B!M:7AI;F<@
M8VAA<F%C=&5R(&5N8V]D:6YG<PHM+5-+25!)1BTM"CP_<&AP(&EF("@A97AT
M96YS:6]N7VQO861E9"@B>&UL(BDI(&5C:&\@)W-K:7`G.R`_/@HM+49)3$4M
M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0HO+PHO+R!497-T(&9O<CH@6$U,+U!A
M<G-E<BYP:'`*+R\@4&%R=',@=&5S=&5D.B`M(&UI>&EN9R!C:&%R86-T97(@
M96YC;V1I;F=S"B\O"B\O(%1H:7,@:7,@=VAA="!W92!T97-T.@HO+R`Q(%54
M1BTX("`@("`@+3X@25-/+3@X-3DM,0HO+R`R(%541BTX("`@("`@+3X@55,M
M05-#24D*+R\@,R!)4T\M.#@U.2TQ("T^(%541BTX"B\O(#0@25-/+3@X-3DM
M,2`M/B!54RU!4T-)20HO+R`U(%53+4%30TE)("`@+3X@551&+3@*+R\@-B!5
M4RU!4T-)22`@("T^($E33RTX.#4Y+3$*+R\*"G)E<75I<F5?;VYC92`B+BXO
M4&%R<V5R+G!H<"(["@IC;&%S<R!497-T16YC;V1I;F=S,2!E>'1E;F1S(%A-
M3%]087)S97(@>PH@("`@=F%R("1O=71P=70@/2`G)SL*"B`@("!F=6YC=&EO
M;B!497-T16YC;V1I;F=S,2@D=&\L("1F<F]M*2!["B`@("`@("`@)'1H:7,M
M/EA-3%]087)S97(H)&9R;VTL("=E=F5N="<L("1T;RD["B`@("!]"B`@("!F
M=6YC=&EO;B!S=&%R=$AA;F1L97(H)'AP+"`D96QE;2P@)&%T=')I8G,I('L*
M("`@("`@("`D=&AI<RT^;W5T<'5T("X]("(\)&5L96T^(CL*("`@('T*("`@
M(&9U;F-T:6]N(&5N9$AA;F1L97(H)'AP+"`D96QE;2D@>PH@("`@("`@("1T
M:&ES+3YO=71P=70@+CT@(CPO)&5L96T^(CL*("`@('T*("`@(&9U;F-T:6]N
M(&-D871A2&%N9&QE<B@D>'`L("1D871A*2!["B`@("`@("`@)'1H:7,M/F]U
M='!U="`N/2`D9&%T83L*("`@('T*("`@(&9U;F-T:6]N('1E<W0H)&1A=&$I
M('L*("`@("`@("`O+R`D=&AI<RT^;W5T<'5T(#T@)R<["B`@("`@("`@)'1H
M:7,M/G!A<G-E4W1R:6YG*"1D871A+"!T<G5E*3L*("`@("`@("!R971U<FX@
M)'1H:7,M/F]U='!U=#L*("`@('T*?0H*)'AM;"`]("(\/WAM;"!V97)S:6]N
M/2<Q+C`G(#\^(CL*)&EN<'5T(#T@87)R87DH"B`@("`B551&+3@B("`@("`@
M/3X@(CQA/F%B8\.FP[C#I3PO83XB+`H@("`@(DE33RTX.#4Y+3$B(#T^("(\
M83YA8F/F^.4\+V$^(BP*("`@(")54RU!4T-)22(@("`]/B`B/&$^86)C86]A
M/"]A/B(**3L*"B1E;F-O9&EN9W,@/2!A<G)A>5]K97ES*"1I;G!U="D["F9O
M<F5A8V@@*"1I;G!U="!A<R`D<W)C96YC(#T^("1S=')I;F<I('L*("`@(&9O
M<F5A8V@@*"1E;F-O9&EN9W,@87,@)'1G=&5N8RD@>PH@("`@("`@(&EF("@D
M<W)C96YC(#T]("1T9W1E;F,I('L*("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@?0H@("`@("`@('!R:6YT(")497-T:6YG("1S<F-E;F,@+3X@)'1G
M=&5N8SH@(CL*("`@("`@("`D<"`])B!N97<@5&5S=$5N8V]D:6YG<S$H)'1G
M=&5N8RP@)'-R8V5N8RD["B`@("`@("`@)&4@/2`D<"T^=&5S="@D:6YP=71;
M)'-R8V5N8UTI.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E*2D@>PH@
M("`@("`@("`@("!P<FEN=&8H(D]/4%,Z("5S7&XB+"`D92T^9V5T365S<V%G
M92@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!V87)?9'5M<"@D
M92D["B`@("`@("`@?0H@("`@?0I]"@H_/@HM+4584$5#5"TM"E1E<W1I;F<@
M551&+3@@+3X@25-/+3@X-3DM,3H@<W1R:6YG*#$S*2`B/$$^86)CYOCE/"]!
M/B(*5&5S=&EN9R!55$8M."`M/B!54RU!4T-)23H@<W1R:6YG*#$S*2`B/$$^
M86)C/S\_/"]!/B(*5&5S=&EN9R!)4T\M.#@U.2TQ("T^(%541BTX.B!S=')I
M;F<H,38I("(\03YA8F/#IL.XPZ4\+T$^(@I497-T:6YG($E33RTX.#4Y+3$@
M+3X@55,M05-#24DZ('-T<FEN9R@Q,RD@(CQ!/F%B8S\_/SPO03XB"E1E<W1I
M;F<@55,M05-#24D@+3X@551&+3@Z('-T<FEN9R@Q,RD@(CQ!/F%B8V%O83PO
M03XB"E1E<W1I;F<@55,M05-#24D@+3X@25-/+3@X-3DM,3H@<W1R:6YG*#$S
M*2`B/$$^86)C86]A/"]!/B(*````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E
M<W1S+S`P,RYP:'!T````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0R,@`Q,#4Q
M-30S,3`U-P`P,C,P,C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2U415-4+2T*6$U,(%!A<G-E<CH@<&%R<V4@9G)O;2!F
M:6QE(')E<V]U<F-E"BTM4TM)4$E&+2T*/#]P:'`@:68@*"%E>'1E;G-I;VY?
M;&]A9&5D*")X;6PB*2D@96-H;R`G<VMI<"<[(#\^"BTM1DE,12TM"CP_<&AP
M("\O("TJ+2!#*RL@+2HM"B\O"B\O(%1E<W0@9F]R.B!834PO4&%R<V5R+G!H
M<`HO+R!087)T<R!T97-T960Z("T@<&%R<V5R(&-R96%T:6]N"B\O("`@("`@
M("`@("`@("`@+2!S;VUE(&AA;F1L97)S"B\O("`@("`@("`@("`@("`@+2!P
M87)S92!F<F]M(&9I;&4@<F5S;W5R8V4*+R\*8VAD:7(@*&1I<FYA;64H7U]&
M24Q%7U\I*3L*"G)E<75I<F5?;VYC92`B+BXO4&%R<V5R+G!H<"(["@IC;&%S
M<R!?7U1E<W1087)S97(S(&5X=&5N9',@6$U,7U!A<G-E<B!["B`@("!F=6YC
M=&EO;B!?7U1E<W1087)S97(S*"D@>PH@("`@("`@("1T:&ES+3Y834Q?4&%R
M<V5R*"D["B`@("!]"B`@("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H)'AP+"`D
M96QE;65N="P@)&%T=')I8G,I('L*("`@("`@("!P<FEN="`B/"1E;&5M96YT
M(CL*("`@("`@("!R97-E="@D871T<FEB<RD["B`@("`@("`@=VAI;&4@*&QI
M<W0H)&ME>2P@)'9A;"D@/2!E86-H*"1A='1R:6)S*2D@>PH@("`@("`@("`@
M("`D96YC(#T@:'1M;&5N=&ET:65S*"1V86PI.PH@("`@("`@("`@("!P<FEN
M="`B("1K97D]7"(D96YC7"(B.PH@("`@("`@('T*("`@("`@("!P<FEN="`B
M/B(["B`@("!]"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L96UE
M;G0I('L*("`@("`@("!P<FEN="`B/"\D96QE;65N=#Y<;B(["B`@("!]"B`@
M("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'AP+"`D8V1A=&$I('L*("`@("`@
M("!P<FEN="`B/"%;0T1!5$%;)&-D871A75T^(CL*("`@('T*("`@(&9U;F-T
M:6]N(&1E9F%U;'1(86YD;&5R*"1X<"P@)&-D871A*2!["@H@("`@?0I]"G!R
M:6YT(")N97<@7U]497-T4&%R<V5R,R`B.PIV87)?9'5M<"AG971?8VQA<W,H
M)&\@/2!N97<@7U]497-T4&%R<V5R,R@I*2D["G!R:6YT(")F;W!E;B`B.PIP
M<FEN="!I<U]R97-O=7)C92@D9G`@/2!F;W!E;B@B=&5S=#,N>&UL(BP@(G(B
M*2DN(EQN(CL*<')I;G0@(G-E=$EN<'5T("(["G9A<E]D=6UP*"1O+3YS971)
M;G!U="@D9G`I*3L*<')I;G0@(G!A<G-E("(["G9A<E]D=6UP*"1O+3YP87)S
M92@I*3L*"C\^"BTM15A014-4+2T*;F5W(%]?5&5S=%!A<G-E<C,@<W1R:6YG
M*#$S*2`B7U]T97-T<&%R<V5R,R(*9F]P96X@,0IS971);G!U="!B;V]L*'1R
M=64I"G!A<G-E(#Q23T]4/CPA6T-$051!6V9O;UU=/CPO4D]/5#X*8F]O;"AT
M<G5E*0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`T+G!H<'0`````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,3(Q`#$P-3$U-#,Q,#4W`#`R,S`Q-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+51%4U0M+0I8
M34P@4&%R<V5R.B!E<G)O<B!C;&%S<PHM+5-+25!)1BTM"CP_<&AP(&EF("@A
M97AT96YS:6]N7VQO861E9"@B>&UL(BDI(&5C:&\@)W-K:7`G.R`_/@HM+49)
M3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0HO+PHO+R!497-T(&9O<CH@6$U,
M+U!A<G-E<BYP:'`*+R\@4&%R=',@=&5S=&5D.B`M('!A<G-E<B!E<G)O<B!C
M;&%S<PHO+PH*<F5Q=6ER95]O;F-E("(N+B]087)S97(N<&AP(CL*"G!R:6YT
M(")N97<@6$U,7U!A<G-E<B`B.PIV87)?9'5M<"AG971?8VQA<W,H)'`@/2!N
M97<@6$U,7U!A<G-E<B@I*2D["B1E(#T@)'`M/G!A<G-E4W1R:6YG*"(\/WAM
M;"!V97)S:6]N/2<Q+C`G(#\^/&9O;SX\+V)A<CXB+"!T<G5E*3L*:68@*%!%
M05(Z.FES17)R;W(H)&4I*2!["B`@("!P<FEN=&8H(F5R<F]R(&UE<W-A9V4Z
M("5S7&XB+"`D92T^9V5T365S<V%G92@I*3L*?2!E;'-E('L*("`@('!R:6YT
M(")N;R!E<G)O<EQN(CL*?0H*/SX*+2U%6%!%0U0M+0IN97<@6$U,7U!A<G-E
M<B!S=')I;F<H,3`I(")X;6Q?<&%R<V5R(@IE<G)O<B!M97-S86=E.B!834Q?
M4&%R<V5R.B!M:7-M871C:&5D('1A9R!A="!834P@:6YP=70@;&EN92`Q"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`R+G!H<'0`````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S$R`#$P-3$U-#,Q,#4W`#`R,S`Q-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+51%
M4U0M+0I834P@4&%R<V5R.B!P87)S92!F<F]M(&9I;&4*+2U32TE0248M+0H\
M/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO("=S:VEP
M)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*+R\@5&5S
M="!F;W(Z(%A-3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!P87)S
M97(@8W)E871I;VX*+R\@("`@("`@("`@("`@("`M('-O;64@:&%N9&QE<G,*
M+R\@("`@("`@("`@("`@("`M('!A<G-E(&9R;VT@9FEL90HO+PIC:&1I<B`H
M9&ER;F%M92A?7T9)3$5?7RDI.PH*<F5Q=6ER95]O;F-E("(N+B]087)S97(N
M<&AP(CL*"F-L87-S(%]?5&5S=%!A<G-E<C(@97AT96YD<R!834Q?4&%R<V5R
M('L*("`@(&9U;F-T:6]N(%]?5&5S=%!A<G-E<C(H*2!["B`@("`@("`@)'1H
M:7,M/EA-3%]087)S97(H*3L*("`@('T*("`@(&9U;F-T:6]N('-T87)T2&%N
M9&QE<B@D>'`L("1E;&5M96YT+"`D871T<FEB<RD@>PH@("`@("`@('!R:6YT
M("(\)&5L96UE;G0B.PH@("`@("`@(')E<V5T*"1A='1R:6)S*3L*("`@("`@
M("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L*2`](&5A8V@H)&%T=')I8G,I*2![
M"B`@("`@("`@("`@("1E;F,@/2!H=&UL96YT:71I97,H)'9A;"D["B`@("`@
M("`@("`@('!R:6YT("(@)&ME>3U<(B1E;F-<(B(["B`@("`@("`@?0H@("`@
M("`@('!R:6YT("(^(CL*("`@('T*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H
M)'AP+"`D96QE;65N="D@>PH@("`@("`@('!R:6YT("(\+R1E;&5M96YT/EQN
M(CL*("`@('T*("`@(&9U;F-T:6]N(&-D871A2&%N9&QE<B@D>'`L("1C9&%T
M82D@>PH@("`@("`@('!R:6YT("(\(5M#1$%405LD8V1A=&%=73XB.PH@("`@
M?0H@("`@9G5N8W1I;VX@9&5F875L=$AA;F1L97(H)'AP+"`D8V1A=&$I('L*
M"B`@("!]"GT*<')I;G0@(FYE=R!?7U1E<W1087)S97(R("(["G9A<E]D=6UP
M*&=E=%]C;&%S<R@D;R`](&YE=R!?7U1E<W1087)S97(R*"DI*3L*<')I;G0@
M(G-E=$EN<'5T1FEL92`B.PIP<FEN="!I<U]R97-O=7)C92@D;RT^<V5T26YP
M=71&:6QE*")T97-T,BYX;6PB*2DN(EQN(CL*<')I;G0@(G!A<G-E("(["G9A
M<E]D=6UP*"1O+3YP87)S92@I*3L*"C\^"BTM15A014-4+2T*;F5W(%]?5&5S
M=%!A<G-E<C(@<W1R:6YG*#$S*2`B7U]T97-T<&%R<V5R,B(*<V5T26YP=71&
M:6QE(#$*<&%R<V4@/%)/3U0^/"%;0T1!5$%;9F]O75T^/"]23T]4/@IB;V]L
M*'1R=64I"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A
M<G-E<B]T97-T<R]T97-T,BYX;6P`````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M-#<`,3`U,34T,S$P-3<`,#(S-#`U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_>&UL('9E<G-I;VX])S$N,"<@/SX*/')O
M;W0^9F]O/"]R;V]T/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O
M=&5S=#,N>&UL````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#0W`#$P-3$U-#,Q
M,#4W`#`R,S0P-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2<Q+C`G(#\^"CQR;V]T/F9O;SPO<F]O
M=#X`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P,2YP:'!T````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(S-P`Q,#4Q-30S,3`U-P`P,C,P,C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+2U4
M15-4+2T*6$U,(%!A<G-E<CH@<&%R<V4@<VEM<&QE('-T<FEN9PHM+5-+25!)
M1BTM"CP_<&AP(&EF("@A97AT96YS:6]N7VQO861E9"@B>&UL(BDI(&5C:&\@
M)W-K:7`G.R`_/@HM+49)3$4M+0H\/W!H<`HO+PHO+R!497-T(&9O<CH@6$U,
M+U!A<G-E<BYP:'`*+R\@4&%R=',@=&5S=&5D.B`M('!A<G-E<B!C<F5A=&EO
M;@HO+R`@("`@("`@("`@("`@("T@<V]M92!H86YD;&5R<PHO+R`@("`@("`@
M("`@("`@("T@<&%R<V4@<VEM<&QE('-T<FEN9PHO+PH*<F5Q=6ER95]O;F-E
M("(N+B]087)S97(N<&AP(CL*"F-L87-S(%]?5&5S=%!A<G-E<C$@97AT96YD
M<R!834Q?4&%R<V5R('L*("`@(&9U;F-T:6]N(%]?5&5S=%!A<G-E<C$H*2![
M"B`@("`@("`@)'1H:7,M/EA-3%]087)S97(H*3L*("`@('T*("`@(&9U;F-T
M:6]N('-T87)T2&%N9&QE<B@D>'`L("1E;&5M96YT+"`D871T<FEB<RD@>PH@
M("`@("`@('!R:6YT("(\)&5L96UE;G0B.PH@("`@("`@(')E<V5T*"1A='1R
M:6)S*3L*("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L*2`](&5A8V@H
M)&%T=')I8G,I*2!["B`@("`@("`@("`@("1E;F,@/2!H=&UL96YT:71I97,H
M)'9A;"D["B`@("`@("`@("`@('!R:6YT("(@)&ME>3U<(B1E;F-<(B(["B`@
M("`@("`@?0H@("`@("`@('!R:6YT("(^(CL*("`@('T*("`@(&9U;F-T:6]N
M(&5N9$AA;F1L97(H)'AP+"`D96QE;65N="D@>PH@("`@("`@('!R:6YT("(\
M+R1E;&5M96YT/EQN(CL*("`@('T*("`@(&9U;F-T:6]N(&-D871A2&%N9&QE
M<B@D>'`L("1C9&%T82D@>PH@("`@("`@('!R:6YT("(\(5M#1$%405LD8V1A
M=&%=73XB.PH@("`@?0H@("`@9G5N8W1I;VX@9&5F875L=$AA;F1L97(H)'AP
M+"`D8V1A=&$I('L*"B`@("!]"GT*97)R;W)?<F5P;W)T:6YG*#$P,C,I.PIP
M<FEN="`B;F5W(%]?5&5S=%!A<G-E<C$@(CL*=F%R7V1U;7`H9V5T7V-L87-S
M*"1O(#T@;F5W(%]?5&5S=%!A<G-E<C$H*2DI.PIP<FEN="`B<&%R<V53=')I
M;F<@(CL*=F%R7V1U;7`H)&\M/G!A<G-E4W1R:6YG*"(\/WAM;"!V97)S:6]N
M/2<Q+C`G(#\^/')O;W0^9F]O/"]R;V]T/B(L(#$I*3L*"C\^"BTM15A014-4
M+2T*;F5W(%]?5&5S=%!A<G-E<C$@<W1R:6YG*#$S*2`B7U]T97-T<&%R<V5R
M,2(*<&%R<V53=')I;F<@/%)/3U0^/"%;0T1!5$%;9F]O75T^/"]23T]4/@IB
M;V]L*'1R=64I"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+P``
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#4W`#`Q-C<W,P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(P,3,U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`U-P`P,C$T,S``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1"+W1E<W1S+V1R:79E<B]S971U<"YI;F,N8W9S+F]R:6<`````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`W-38R`#$P-3$U-#,Q,#4W`#`R-3`R,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*+RHJ"B`J($5S=&%B
M;&ES:&5S('1H92!I;F-L=61E7W!A=&@L($133B=S(&%N9"!C;VYN96-T:6]N
M("1O<'1I;VYS"B`J"B`J($EF('1H:7,@9FEL92!I<R!N86UE9"`B<V5T=7`N
M:6YC+F-V<RPB(&ET(&ES('1H92!O<FEG:6YA;"!O;F4@9G)O;2!#5E,N"B`J
M(%!L96%S92!D;R!T:&4@9F]L;&]W:6YG.@H@*B`@(#$I($UA:V4@82!C;W!Y
M(&]F('1H:7,@9FEL92!N86UE9"`B<V5T=7`N:6YC(BX*("H@("`R*2!4:&5N
M+"!I;B!T:&4@8V]P>2P@961I="!T:&4@)&1S;G,@87)R87D@87,@87!P<F]P
M<FEA=&4@9F]R('EO=7(*("H@("`@("!E;G9I<F]N;65N="X*("H@("`S*2!!
M="!L96%S="!O;F4@96QE;65N="!O9B!T:&4@)&1S;G,@87)R87D@;F5E9',@
M=&\@8F4@=6YC;VUM96YT960N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@
M("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z
M('-E='5P+FEN8RYC=G,L=B`Q+C8@,C`P-2\P,B\Q-"`R,SHS,SHR,"!D86YI
M96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$0@H@*B\*"FEF("@A9&5F:6YE9"@G4$%42%]315!!4D%43U(G
M*2D@>PH@("`@:68@*'-T<FES='(H4$A07T]3+"`G5TE.)RDI('L*("`@("`@
M("`O*BH*("`@("`@("`@*B!4:&4@<W1R:6YG('5S960@=&\@9&5L:6UI="!E
M;&5M96YT<R!O9B!T:&4@<&%T:"X*("`@("`@("`@*B\*("`@("`@("!D969I
M;F4H)U!!5$A?4T5005)!5$]2)RP@)SLG*3L*("`@('T@96QS92!["B`@("`@
M("`@+RHJ"B`@("`@("`@("H@5&AE('-T<FEN9R!U<V5D('1O(&1E;&EM:70@
M96QE;65N=',@;V8@=&AE('!A=&@N"B`@("`@("`@("HO"B`@("`@("`@9&5F
M:6YE*"=0051(7U-%4$%2051/4B<L("<Z)RD["B`@("!]"GT*"B\J"B`J($EF
M('1H92!P871H('1O('EO=7(@4$5!4B!I;G-T86QL871I;VX@:7,@9F]U;F0@
M:6X@=&AE(&QE9G0@:&%N9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E
M<W-I;VX@8F5L;W<L('1H870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE
M(&9R;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!U
M<V4@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F($1"+"!W:&EC:"!S:&]U
M;&0@8F4@9F]U;F0@=FEA('1H90H@*B!C;VUP=71E<B=S(&1E9F%U;'0@:6YC
M;'5D95]P871H+B`@061D("<N)R!T;R!T:&4@:6YC;'5D95]P871H"B`J('1O
M(&5N<W5R92`G+B<@:7,@:6X@=&AE<F4N"B`J(`H@*B!)9B!T:&4@<&%T:"!H
M87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@=&AE(&EF*"D@97AP<F5S<VEO
M;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M92!F<F]M(&$@0U93(&-H
M96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4:&5R969O<F4L('=E)VQL(&%S
M<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R<VEO;B!O9@H@*B!$
M0B!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G
M+VAO;64O;'5C97(O=V]R:R]P96%R+W-H87)E+W!H<"<@(3T@)T`G+B=I;F-L
M=61E7W!A=&@G+B=`)RD@>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@
M:6YI7V=E="@G:6YC;'5D95]P871H)RD*("`@("`@("`@("`@+B!0051(7U-%
M4$%2051/4B`N("<N)PH@("`@*3L*?2!E;'-E('L*("`@(&EN:5]S970H)VEN
M8VQU9&5?<&%T:"<L(')E86QP871H*&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B\N+B<I"B`@("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<@+B!0
M051(7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN:5]G970H)VEN8VQU9&5?
M<&%T:"<I"B`@("`I.PI]"@HO*BH*("H@1W)A8B!T:&4@4$5!4B!$0B!C;&%S
M<V5S+@H@*B\*<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH*+R\@3W!T:6]N<R!U
M<V5D('=H96X@8V]N;F5C=&EN9PHD;W!T:6]N<R`](&%R<F%Y*`H@("`@+R\G
M;W!T:6UI>F4G(#T^("=P;W)T86)I;&ET>2<L"B`@("`G<&]R=&%B:6QI='DG
M(#T^($1"7U!/4E1!0DE,25197T%,3"P*("`@("=D96)U9R<@/3X@,BP**3L*
M"B1D8F%S961S;B`](&%R<F%Y*`H@("`@)W!H<'1Y<&4G("`]/B`G9&)A<V4G
M+`H@("`@)V1A=&%B87-E)R`]/B`G+W!A=&@O86YD+VYA;64O;V8O9&)A<V4O
M9FEL92<L"B`@("`G;6]D92<@("`@(#T^(#(L"B`@("`G9FEE;&1S)R`@(#T^
M(&%R<F%Y*`H@("`@("`@(&%R<F%Y*"=A)RP@)TXG+"`U+"`P*2P*("`@("`@
M("!A<G)A>2@G8B<L("=#)RP@-#`I+`H@("`@("`@(&%R<F%Y*"=C)RP@)T,G
M+"`R-34I+`H@("`@("`@(&%R<F%Y*"=D)RP@)T,G+"`R,"DL"B`@("`I+`HI
M.PH*+RH*("H@56YC;VUM96YT(&%T(&QE87-T(&]N92!O9B!T:&4@9F]L;&]W
M:6YG(&5L96UE;G1S+@H@*B!7:&5N(')U;FYI;F<@=&AE("YP:'!T('1E<W1S
M+"!T:&4@9FER<W0@=6YC;VUM96YT960@96QE;65N="!I<R!U<V5D+@H@*B!7
M:&5N(')U;FYI;F<@=&AE(&UU;'1I8V]N;F5C="YP:'`@=&5S="P@86QL('5N
M8V]M;65N=&5D(&5L96UE;G1S(&%R92!U<V5D+@H@*B\*)&1S;G,@/2!A<G)A
M>2@*("`@("\O("=D8F%S92<@("`@/3X@)&1B87-E9'-N+`H@("`@+R\@)V9B
M<W%L)R`@("`]/B`G9F)S<6PZ+R]?<WES=&5M.D`O9&(G+`H@("`@+R\@)V9I
M<F5B:7)D)R`]/B`G:6)A<V4H9FER96)I<F0I.B\O4UE31$)!.FUA<W1E<FME
M>4`O+V]P="]I;G1E<F)A<V4O97AA;7!L97,O96UP;&]Y964N9V1B/V1I86QE
M8W0],R<L"B`@("`O+R`G:69X)R`@("`@(#T^("=I9G@Z+R]U<V5R.G!W0&QO
M8V%L:&]S="]D8B<L"B`@("`O+R`G;7-Q;"<@("`@(#T^("=M<W%L.B\O+V1B
M)RP*"B`@("`O+R!)="=S(&%D=FES86)L92!T;R!U<V4@;VYL>2!O;F4@;V8@
M=&AE(&9O;&QO=VEN9R!A="!A('1I;64Z"B`@("`O+R`G;7-S<6PG("`@(#T^
M("=M<W-Q;#HO+W-A0'-O;65H;W-T+W!U8G,G+`H@("`@+R\@)W-Y8F%S92<@
M("`]/B`G<WEB87-E.B\O<V%`<V]M96AO<W0O<'5B<R<L"@H@("`@+R\@)VUY
M<W%L)R`@("`]/B`G;7ES<6PZ+R]R;V]T0&QO8V%L:&]S="]T97-T)RP*("`@
M("\O("=M>7-Q;&DG("`@/3X@)VUY<W%L:3HO+W)O;W1`;&]C86QH;W-T+W1E
M<W0G+`H@("`@+R\@)V]C:3@G("`@("`]/B`G;V-I.#HO+W-Y<W1E;3IM86YA
M9V5R0"<L"B`@("`O+R`G86-C97-S)R`@(#T^("=O9&)C*&%C8V5S<RDZ+R]A
M9&UI;D`O4WES=&5M1'-N3F%M92<L"B`@("`O+R`G9&(R)R`@("`@(#T^("=O
M9&)C*&1B,BDZ+R]D8C)I;G-T,3I86%A80"]304U03$4G+`H@("`@+R\@)W!G
M<W%L)R`@("`]/B`G<&=S<6PZ+R]P;W-T9W)E<T!L;V-A;&AO<W0O=&5S="<L
M"B`@("`O+R`G<W%L:71E)R`@(#T^("=S<6QI=&4Z+R]D=6UM>3I`;&]C86QH
M;W-T+R<@+B!G971C=V0H*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G=&5S
M="YD8C]M;V1E/3`V-#0G+`HI.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P,W-I;7!L97%U
M97)Y+G!H<'0``````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S4W`#$P-3$U-#,Q,#4W`#`R-3`U
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I$0E]D<FEV97(Z.G-I;7!L95%U97)Y"BTM24Y)+2T*97)R;W)?
M<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA
M;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_
M/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G
M.PIR97%U:7)E7V]N8V4@)RXN+W-I;7!L97%U97)Y+FEN8R<["C\^"BTM15A0
M14-4+2T*<&%S<V5D"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#1N=6UC;VQS+G!H<'0`````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#,U,``Q,#4Q-30S,3`U-P`P,C0Q-#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2U415-4+2T*1$)?
M9')I=F5R.CIN=6U#;VQS"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T
M-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@
M<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H
M<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N8V4@
M)RXN+VYU;6-O;',N:6YC)SL*/SX*+2U%6%!%0U0M+0HQ"C(*,PHT"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+S`U<V5Q=65N8V5S+G!H<'0`````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$P,3<`,3`U,34T,S$P-3<`,#(T-#8Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ<V5Q
M=65N8V5S"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)
M1BTM"CP_<&AP"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["F-H9&ER*&1I<FYA
M;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.PHD
M=&%B;&5);F9O(#T@)&1B+3YD<F]P4V5Q=65N8V4H)V%J:V1S;&9A:F]I:FMA
M9&EE)RD["FEF("A$0CHZ:7-%<G)O<B@D=&%B;&5);F9O*2`F)B`D=&%B;&5)
M;F9O+3YC;V1E(#T]($1"7T524D]27TY/5%]#05!!0DQ%*2!["B`@("!D:64H
M(G-K:7`@)'1A8FQE26YF;RT^;65S<V%G92(I.PI]"C\^"BTM1DE,12TM"CP_
M<&AP"G)E<75I<F5?;VYC92`G+B]C;VYN96-T+FEN8R<["G)E<75I<F5?;VYC
M92`G+BXO<V5Q=65N8V5S+FEN8R<["C\^"BTM15A014-4+2T*86X@97)R;W(@
M:7,@=&AE('!R;W!E<B!R97-P;VYS92!H97)E"F%N(&5R<F]R(&-O=6=H="!B
M>2!T:&4@97)R;W(@:&%N9&QE<B!I<R!G;V]D"F$],0IB/3(*8BUA/3$*8STQ
M"F0],0IE/3$*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9')I=F5R+S`V<')E<&5X96,N<&AP=```````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(S-S4`,3`U,34T,S$P-3<`,#(T,S$R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM5$535"TM"D1"7V1R:79E
M<CHZ<')E<&%R92]E>&5C=71E"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@
M,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\
M/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N
M8V4@)RXN+W!R97!E>&4N:6YC)SL*/SX*+2U%6%!%0U0M+0HM+2TM+2TM+2TM
M+2TQ+2TM+2TM+2TM+2TM"G-T:#$L<W1H,BQS=&@S+'-T:#0@8W)E871E9`IS
M=&@Q.B`_(&%S('!A<F%M+"!P87-S:6YG(&%S(&%R<F%Y+BXN('-T:#$@97AE
M8W5T960*<W1H,CH@(2!A;F0@/R!A<R!P87)A;7,L('!A<W-I;F<@87,@87)R
M87DN+BX@<W1H,B!E>&5C=71E9`IS=&@S.B`_+"`A(&%N9"`F(&%S('!A<F%M
M<RP@<&%S<VEN9R!A<R!A<G)A>2XN+B!S=&@S(&5X96-U=&5D"G-T:#0Z(&YO
M('!A<F%M<RXN+B!S=&@T(&5X96-U=&5D"G)E<W5L=',Z"GPW,B`M(&$@+2`@
M+2!\"GPW,B`M(&1I<F5C="`M("`M('P*?#<R("T@:70G<R!G;V]D("T@;W!A
M<75E('!L86-E:&]L9&5R)W,@=&5S="`M('P*?#<R("T@=&AA="=S(')I9VAT
M("T@("T@?`H*+2TM+2TM+2TM+2TM,BTM+2TM+2TM+2TM+0IR97-U;'1S.@I\
M-S(@+2!S970Q("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M(#$R,S0M
M-38M-SA\"GPW,B`M('-E=#(@+2!O<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T
M("T@?`I\-S(@+2!S970S("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M
M('P*"BTM+2TM+2TM+2TM+3,M+2TM+2TM+2TM+2T*5%)510I&04Q310H*+2TM
M+2TM+2TM+2TM-"TM+2TM+2TM+2TM+0I\-S(@+2!S970Q("T@;W!A<75E('!L
M86-E:&]L9&5R)W,@=&5S="`M(#$R,S0M-38M-SA\"GPW,B`M('-E=#(@+2!O
M<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T("T@?`I\-S(@+2!S970S("T@;W!A
M<75E('!L86-E:&]L9&5R)W,@=&5S="`M('P*?GX*?GX*?#<R("T@<V5T,2`M
M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X?`I^?@I\
M-S(@+2!S970Q("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M(#$R,S0M
M-38M-SA\"GPW,B`M('-E=#(@+2!O<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T
M("T@?`I\-S(@+2!S970S("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M
M('P*?GX*"BTM+2TM+2TM+2TM+34M+2TM+2TM+2TM+2T*:6YS97)T.B!O:V%Y
M"F$@/2`Q,2P@8B`]('1H<F5E+"!D(#T@9V]T(&5X<&5C=&5D(&]U=&-O;64*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#AA
M9F9E8W1E9')O=W,N<&AP=``````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<W,@`Q,#4Q-30S,3`U
M-P`P,C4Q-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2U415-4+2T*1$)?9')I=F5R.CIA9F9E8W1E9%)O=W,*+2U)3DDM
M+0IE<G)O<E]R97!O<G1I;F<@/2`R,#0W"BTM4TM)4$E&+2T*/#]P:'`@8VAD
M:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF
M+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP"G)E<75I<F5?;VYC92`G+B]M:W1A
M8FQE+FEN8R<["@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE
M<BX*("H*("H@1')O<',@=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@
M86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J
M"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2(&5R<F]R(&]B:F5C="!A=71O
M;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O
M:60*("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T
M:6]N('!E*"1O*2!["B`@("!G;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B
M;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI
M.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!
M0TLL("=P92<I.PH*"B\O($-L96%N('1A8FQE"B1D8F@M/G%U97)Y*")$14Q%
M5$4@1E)/32!P:'!T97-T(BD["@HO+R!!9F9E8W1E9"!R;W=S(&)Y($E.4T52
M5"!S=&%T96UE;G0*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@
M*&$L8BD@5D%,5453*#$L("=T97-T)RDB*3L*)&1B:"T^<75E<GDH(DE.4T52
M5"!)3E1/('!H<'1E<W0@*&$L8BD@5D%,5453*#(L("=T97-T)RDB*3L*<')I
M;G1F*"(E9"!A9G1E<B!I;G-E<G1<;B(L("1D8F@M/F%F9F5C=&5D4F]W<R@I
M*3L*"B\O($%F9F5C=&5D(')O=W,@8GD@4T5,14-4('-T871E;65N=`HD9&)H
M+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["G!R:6YT9B@B)60@
M869T97(@<V5L96-T7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H*2D["B1D8F@M
M/G%U97)Y*")$14Q%5$4@1E)/32!P:'!T97-T(%=(15)%(&(@/2`G=&5S="<B
M*3L*<')I;G1F*"(E9"!A9G1E<B!D96QE=&5<;B(L("1D8F@M/F%F9F5C=&5D
M4F]W<R@I*3L*"B\O($%F9F5C=&5D(')O=W,@8GD@1$5,151%('-T871E;65N
M=`HD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="`H82QB*2!604Q5
M15,H,2P@)W1E<W0G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP
M=&5S="`H82QB*2!604Q515,H,BP@)W1E<W0G*2(I.PHD9&)H+3YQ=65R>2@B
M1$5,151%($923TT@<&AP=&5S="(I.PIP<FEN=&8H(B5D(&%F=&5R(&1E;&5T
M92!A;&Q<;B(L("1D8F@M/F%F9F5C=&5D4F]W<R@I*3L*"@HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D
M9&)H+"`G<&AP=&5S="<I.PH*/SX*+2U%6%!%0U0M+0HQ(&%F=&5R(&EN<V5R
M=`HP(&%F=&5R('-E;&5C=`HR(&%F=&5R(&1E;&5T90HR(&%F=&5R(&1E;&5T
M92!A;&P*````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B\P.6YU;7)O=W,N<&AP=```````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,#$R`#$P-3$U-#,Q,#4W`#`R-#$W-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+51%4U0M+0I$0E]D<FEV
M97(Z.FYU;5)O=W,*+2U)3DDM+0IE<G)O<E]R97!O<G1I;F<@/2`R,#0W"BTM
M4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U
M:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP"G)E
M<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I<F5?;VYC92`G+BXO
M;G5M<F]W<RYI;F,G.PH_/@HM+4584$5#5"TM"BAW86YT(#$I(&=O="`Q(&9R
M;VT@9FER<W0**'=A;G0@,BD@9V]T(#(@9G)O;2`P"BAW86YT(#,I(&=O="`S
M(&9R;VT@,0HH=V%N="`T*2!G;W0@-"!F<F]M(#(**'=A;G0@-2D@9V]T(#4@
M9G)O;2`S"BAW86YT(#8I(&=O="`V(&9R;VT@-`HH=V%N="`U*2!G;W0@-2!F
M<F]M(#X@,"`H<&%S<VEN9R!P87)A;7,@=&\@<75E<GDI"BAW86YT(#0I(&=O
M="`T(&9R;VT@/"`T("AD;VEN9R!P<F5P87)E+V5X96-U=&4I"BAW86YT(#(I
M(&=O="`R(&9R;VT@-2!A;F0@-B!N;W0@9&5L971E9`HH=V%N="`P*2!G;W0@
M,"!F<F]M(#P@,`H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q,&5R<F]R;6%P+G!H<'0`````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`S-C,S`#$P-3$U-#,Q,#4W`#`R-#,Q-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+51%4U0M+0I$
M0E]D<FEV97(Z.F5R<F]R(&UA<'!I;F<*+2U)3DDM+0IE<G)O<E]R97!O<G1I
M;F<@/2`R,#0W"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)
M3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,
M12TM"CP_<&AP"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I
M<F5?;VYC92`G+BXO97)R;W)S+FEN8R<["C\^"BTM15A014-4+2T*1$)?15)2
M3U)?3D]354-(5$%"3$4@9F]R('-E;&5C=#H@(&UA=&-H97,@97AP96-T960@
M;W5T8V]M90I$0E]%4E)/4E].3U-50TA404),12!F;W(@9')O<#H@(&UA=&-H
M97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E].3U1?1D]53D0@9F]R(&1R
M;W`@:6YD97@Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?
M04Q214%$65]%6$E35%,@9F]R(&-R96%T92!T86)L93H@(&UA=&-H97,@97AP
M96-T960@;W5T8V]M90I$0E]%4E)/4E]!3%)%04197T5825-44R!F;W(@8W)E
M871E(&EN9&5X.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]2
M7T-/3E-44D%)3E0@9F]R('!R:6UA<GD@:V5Y(&EN<V5R="!D=7!L:6-A=&4Z
M("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?0T].4U1204E.
M5"!F;W(@<')I;6%R>2!K97D@=7!D871E(&1U<&QI8V%T93H@(&UA=&-H97,@
M97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!U;FEQ
M=64@:V5Y(&EN<V5R="!D=7!L:6-A=&4Z("!M871C:&5S(&5X<&5C=&5D(&]U
M=&-O;64*1$)?15)23U)?0T].4U1204E.5"!F;W(@=6YI<75E(&ME>2!U<&1A
M=&4@9'5P;&EC871E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T52
M4D]27T-/3E-44D%)3E0@9F]R(&9O<F5I9VX@:V5Y(&]N(&EN<V5R=#H@(&UA
M=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]#3TY35%)!24Y4(&9O
M<B!F;W)E:6=N(&ME>2!O;B!D96QE=&4Z("!M871C:&5S(&5X<&5C=&5D(&]U
M=&-O;64*1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"!O;B!I;G-E<G0Z
M("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?0T].4U1204E.
M5%].3U1?3E5,3"!O;B!U<&1A=&4Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O
M;64*1$)?15)23U)?3D]354-(1DE%3$0@:F]I;FEN9R!/3B!B;V=U<R!C;VQU
M;6XZ("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?3D]354-(
M1DE%3$0@:F]I;FEN9R!54TE.1R!B;V=U<R!C;VQU;6XZ("!M871C:&5S(&5X
M<&5C=&5D(&]U=&-O;64*1$)?15)23U)?1$E66D523SH@(&UA=&-H97,@97AP
M96-T960@;W5T8V]M90I$0E]%4E)/4E])3E9!3$E$7TY534)%4B!P=71T:6YG
M(&-H87)S(&EN($E.5"!C;VQU;6XZ("!M871C:&5S(&5X<&5C=&5D(&]U=&-O
M;64*1$)?15)23U)?24Y604Q)1%].54U"15(@<'5T=&EN9R!F;&]A="!I;B!)
M3E0@8V]L=6UN.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]2
M7TE.5D%,241?3E5-0D52('!U='1I;F<@97AC97-S:79E(&EN="!I;B!)3E0@
M8V]L=6UN.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TE.
M5D%,241?3E5-0D52('!U='1I;F<@:6YT(&EN($-(05(@8V]L=6UN.B`@;6%T
M8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TY/4U5#2$9)14Q$.B`@
M;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27U-93E1!6#H@(&UA
M=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]604Q515]#3U5.5%]/
M3E]23U<Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?24Y6
M04Q)1"!O;B!#2$%2(&-O;'5M;B!D871A('1O;R!L;VYG.B`@;6%T8VAE<R!E
M>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TE.5D%,240@;VX@5D%20TA!4B!C
M;VQU;6X@9&%T82!T;V\@;&]N9SH@(&UA=&-H97,@97AP96-T960@;W5T8V]M
M90H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]D<FEV97(O,3%T<F%N<V%C=&EO;G,N<&AP=```````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,30Q-0`Q,#4Q-30S,3`U-P`P,C4Q-S4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*1$)?9')I
M=F5R.CIT<F%N<V%C=&EO;B!T97-T"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG
M(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP"F-H9&ER*&1I<FYA;64H7U]&24Q%
M7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.PII9B`H(21D8BT^
M9F5A='5R97-;)W1R86YS86-T:6]N<R==*2!["B`@("!D:64H)W-K:7`@=&AI
M<R!D<FEV97(@9&]E<R!N;W0@<W5P<&]R="!T<F%N<V%C=&EO;G,G*3L*?0H_
M/@HM+49)3$4M+0H\/W!H<`HD;F5E9&EN;F]D8B`]('1R=64["G)E<75I<F5?
M;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I<F5?;VYC92`G+BXO=')A;G-A
M8W1I;VYS+FEN8R<["C\^"BTM15A014-4+2T*,2D@869T97(@875T;V-O;6UI
M=#H@8FEN9R!O;F4N("!O<',];VL*,BD@8F5F;W)E(&-O;6UI=#H@8FEN9R!O
M;F4@='=O('1H<F5E+B`@;W!S/6]K"C,I(&%F=&5R(&-O;6UI=#H@8FEN9R!O
M;F4@='=O('1H<F5E+B`@;W!S/6]K"C0I(&)E9F]R92!R;VQL8F%C:SH@8FEN
M9R!O;F4@='=O('1H<F5E(&9O=7(@9FEV92X@(&]P<SUO:PHU*2!A9G1E<B!R
M;VQL8F%C:SH@8FEN9R!O;F4@='=O('1H<F5E+B`@;W!S/6]K"C8I(&)E9F]R
M92!A=71O8V]M;6ET*W)O;&QB86-K.B!B:6YG(&]N92!T=V\@=&AR964@<VEX
M('-E=F5N+B`@;W!S/6]K"C<I(&%F=&5R(&%U=&]C;VUM:70K<F]L;&)A8VLZ
M(&)I;F<@;VYE('1W;R!T:')E92!S:7@@<V5V96XN("!O<',];VL*."D@=&5S
M=&EN9R!T:&%T('-E;&5C="!D;V5S;B=T(&1I<W1U<F)E(&]P8V]U;G0Z(&]K
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,3-L:6UI="YP:'!T````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`V,@`Q,#4Q-30S,3`U-P`P,C,V,#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2U415-4+2T*
M1$)?9')I=F5R.CIR;W<@;&EM:70*+2U)3DDM+0IE<G)O<E]R97!O<G1I;F<@
M/2`R,#0W"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?
M7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM
M"CP_<&AP"G)E<75I<F5?;VYC92`G+B]C;VYN96-T+FEN8R<["G)E<75I<F5?
M;VYC92`G+B]D<F]P=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E("<N+B]L:6UI
M="YI;F,G.PH_/@HM+4584$5#5"TM"CT]/3T]/3T@1G)O;3H@,"!\?"!.=6UB
M97(@;V8@<F]W<R!T;R!F971C:#H@,3`@/3T]/3T]/0HQ+BT@<F5S=6QT(#`*
M,BXM(')E<W5L="`Q"C,N+2!R97-U;'0@,@HT+BT@<F5S=6QT(#,*-2XM(')E
M<W5L="`T"C8N+2!R97-U;'0@-0HW+BT@<F5S=6QT(#8*."XM(')E<W5L="`W
M"CDN+2!R97-U;'0@.`HQ,"XM(')E<W5L="`Y"CT]/3T]/3T@1G)O;3H@,3`@
M?'P@3G5M8F5R(&]F(')O=W,@=&\@9F5T8V@Z(#$P(#T]/3T]/3T*,3$N+2!R
M97-U;'0@,3`*,3(N+2!R97-U;'0@,3$*,3,N+2!R97-U;'0@,3(*,30N+2!R
M97-U;'0@,3,*,34N+2!R97-U;'0@,30*,38N+2!R97-U;'0@,34*,3<N+2!R
M97-U;'0@,38*,3@N+2!R97-U;'0@,3<*,3DN+2!R97-U;'0@,3@*,C`N+2!R
M97-U;'0@,3D*/3T]/3T]/2!&<F]M.B`R,"!\?"!.=6UB97(@;V8@<F]W<R!T
M;R!F971C:#H@,3`@/3T]/3T]/0HR,2XM(')E<W5L="`R,`HR,BXM(')E<W5L
M="`R,0HR,RXM(')E<W5L="`R,@HR-"XM(')E<W5L="`R,PHR-2XM(')E<W5L
M="`R-`HR-BXM(')E<W5L="`R-0HR-RXM(')E<W5L="`R-@HR."XM(')E<W5L
M="`R-PHR.2XM(')E<W5L="`R.`HS,"XM(')E<W5L="`R.0H]/3T]/3T]($9R
M;VTZ(#,P('Q\($YU;6)E<B!O9B!R;W=S('1O(&9E=&-H.B`Q,"`]/3T]/3T]
M"C,Q+BT@<F5S=6QT(#,P"C,R+BT@<F5S=6QT(#,Q"C,S+BT@<F5S=6QT(#,R
M"CT]/3T]/3T@4&%S<VEN9R`D<&%R86US('Q\($9R;VTZ(#$Q('Q\($YU;6)E
M<B!O9B!R;W=S('1O(&9E=&-H.B`S(#T]/3T]/3T*,3(N+2!R97-U;'0@,3$*
M,3,N+2!R97-U;'0@,3(*,30N+2!R97-U;'0@,3,*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R
M:79E<B\Q-&9E=&-H;6]D95]O8FIE8W0N<&AP=```````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C$W`#$P
M-3$U-#,Q,#4W`#`R-3<U-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````M+51%4U0M+0I$0E]D<FEV97(Z.F9E=&-H;6]D92!O
M8FIE8W0*+2U)3DDM+0IE<G)O<E]R97!O<G1I;F<@/2`R,#0W"BTM4TM)4$E&
M+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N
M8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP"G)E<75I<F5?
M;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I<F5?;VYC92`G+BXO9F5T8VAM
M;V1E7V]B:F5C="YI;F,G.PH_/@HM+4584$5#5"TM"BTM+2!F971C:"!W:71H
M('!A<F%M($1"7T9%5$-(34]$15]/0DI%0U0@+2TM"G-T9&-L87-S("T^(&$@
M8B!C(&0*<W1D8VQA<W,@+3X@82!B(&,@9`HM+2T@9F5T8V@@=VET:"!D969A
M=6QT(&9E=&-H;6]D92!$0E]&151#2$U/1$5?3T)*14-4("TM+0IS=&1C;&%S
M<R`M/B!A(&(@8R!D"G-T9&-L87-S("T^(&$@8B!C(&0*+2TM(&9E=&-H('=I
M=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-3T1%7T]"2D5#5"!A;F0@
M8VQA<W,@1$)?<F]W("TM+0ID8E]R;W<@+3X@82!B(&,@9`ID8E]R;W<@+3X@
M82!B(&,@9`HM+2T@9F5T8V@@=VET:"!D969A=6QT(&9E=&-H;6]D92!$0E]&
M151#2$U/1$5?3T)*14-4('=I=&@@;F\@8VQA<W,@=&AE;B!$0E]R;W<@+2TM
M"G-T9&-L87-S("T^(&$@8B!C(&0*9&)?<F]W("T^(&$@8B!C(&0*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+V1R:79E<B\Q-7%U;W1E+G!H<'0`````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S
M-C`Q`#$P-3$U-#,Q,#4W`#`R,S8R-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.G%U;W1E
M"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_
M<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N
M+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@
M)RXO8V]N;F5C="YI;F,G.PIR97%U:7)E7V]N8V4@)RXO9')O<'1A8FQE+FEN
M8R<["@H*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J
M"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R
M<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`
M<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC
M86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J
M($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P
M92@D;RD@>PH@("`@9VQO8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("!D<F]P7W1A8FQE*"1D
M8F@L("=P96%R<75O=&4G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]
M"@HO+R!$0DU3(&)O;VQE86X@8V]L=6UN('1Y<&4@<VEM=6QA=&EO;BXN+@HD
M8F]O;&5A;E]C;VQ?='EP92`](&%R<F%Y*`H@("`@)V1B87-E)R`@/3X@)TQO
M9VEC86PG+`H@("`@)V9B<W%L)R`@/3X@)T)/3TQ%04XG+`H@("`@)VEB87-E
M)R`@/3X@)U--04Q,24Y4)RP*("`@("=I9G@G("`@(#T^("=334%,3$E.5"<L
M"B`@("`G;7-Q;"<@("`]/B`G24Y414=%4B<L"B`@("`G;7-S<6PG("`]/B`G
M0DE4)RP*("`@("=M>7-Q;"<@(#T^("=424Y924Y4*#$I)RP*("`@("=M>7-Q
M;&DG(#T^("=424Y924Y4*#$I)RP*("`@("=O8VDX)R`@(#T^("=.54U"15(H
M,2DG+`H@("`@)V]D8F,G("`@/3X@)U--04Q,24Y4)RP*("`@("=P9W-Q;"<@
M(#T^("="3T],14%.)RP*("`@("=S<6QI=&4G(#T^("=)3E1%1T52)RP*("`@
M("=S>6)A<V4G(#T^("=424Y924Y4)RP**3L*"B\O(&%D:G5S="!T:&EN9W,@
M9F]R('-P96-I9FEC($1"35,G<PH*:68@*"1D8F@M/G!H<'1Y<&4@/3T@)V]D
M8F,G*2!["B`@("!I9B`H)&1B:"T^9&)S>6YT87@@/3T@)V]D8F,G*2!["B`@
M("`@("`@)'1Y<&4@/2`D9&)H+3YP:'!T>7!E.PH@("`@?2!E;'-E('L*("`@
M("`@("`D='EP92`]("1D8F@M/F1B<WEN=&%X.PH@("`@?0I](&5L<V4@>PH@
M("`@)'1Y<&4@/2`D9&)H+3YP:'!T>7!E.PI]"@IS=VET8V@@*"1T>7!E*2![
M"B`@("!C87-E("=A8V-E<W,G.@H@("`@("`@("1D96-I;6%L(#T@)U-)3D=,
M12<["B`@("`@("`@)&YU;&P@/2`G)SL*("`@("`@("`D8VAR("`]("=605)#
M2$%2*#@I)SL*("`@("`@("`D:61E;G1I9FEE<B`]("=Q7'5T(")D;G0G.PH@
M("`@("`@(&)R96%K.PH@("`@8V%S92`G9&(R)SH*("`@(&-A<V4@)VEB87-E
M)SH*("`@("`@("`D9&5C:6UA;"`]("=$14-)34%,*#,L,2DG.PH@("`@("`@
M("1N=6QL(#T@)R<["B`@("`@("`@)&-H<B`@/2`G5D%20TA!4B@X*2<["B`@
M("`@("`@)&ED96YT:69I97(@/2`G<5QU=%T@(F1N6W0G.PH@("`@("`@(&)R
M96%K.PH@("`@8V%S92`G:69X)SH*("`@("`@("`O+R!D;VEN9R!T:&ES(&9O
M<B!I9G@@=&\@:V5E<"!C97)T86EN('9E<G-I;VYS(&AA<'!Y"B`@("`@("`@
M)&1E8VEM86P@/2`G1$5#24U!3"@S+#$I)SL*("`@("`@("`D;G5L;"`]("<G
M.PH@("`@("`@("1C:'(@(#T@)T-(05(H."DG.PH@("`@("`@("1I9&5N=&EF
M:65R(#T@)R<["B`@("`@("`@8G)E86L["B`@("!C87-E("=M<W%L)SH*("`@
M("`@("`D9&5C:6UA;"`]("=214%,)SL*("`@("`@("`D;G5L;"`]("<G.PH@
M("`@("`@("1C:'(@(#T@)T-(05(H."DG.PH@("`@("`@("1I9&5N=&EF:65R
M(#T@)R<["B`@("`@("`@8G)E86L["B`@("!C87-E("=F8G-Q;"<Z"B`@("!C
M87-E("=O8VDX)SH*("`@("`@("`D9&5C:6UA;"`]("=$14-)34%,*#,L,2DG
M.PH@("`@("`@("1N=6QL(#T@)R<["B`@("`@("`@)&-H<B`@/2`G5D%20TA!
M4B@X*2<["B`@("`@("`@)&ED96YT:69I97(@/2`G<5QU=%T@9&Y;="<["B`@
M("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@("1D96-I;6%L(#T@
M)T1%0TE-04PH,RPQ*2<["B`@("`@("`@)&YU;&P@/2`G3E5,3"<["B`@("`@
M("`@)&-H<B`@/2`G5D%20TA!4B@X*2<["B`@("`@("`@)&ED96YT:69I97(@
M/2`G<5QU=%T@(F1N6W0G.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&5A<G%U;W1E
M)RD["@H*:68@*"1I9&5N=&EF:65R*2!["B`@("!S=VET8V@@*"1D8F@M/G!H
M<'1Y<&4I('L*("`@("`@("!C87-E("=S>6)A<V4G.@H@("`@("`@("`@("`D
M<F5S(#T@)&1B:"T^<75E<GDH)W-E="!Q=6]T961?:61E;G1I9FEE<B!O;B<I
M.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RD@*2!["B`@("`@
M("`@("`@("`@("!P92@D<F5S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@?0H@("`@)&-R96%T92`]
M("1D8F@M/G%U97)Y*"(*("`@("`@("!#4D5!5$4@5$%"3$4@<&5A<G%U;W1E
M("@*("`@("`@("`@(&X@)&1E8VEM86P@)&YU;&PL"B`@("`@("`@("!S("1C
M:'(@)&YU;&PL"B`@("`@("`@("`B("X@)&1B:"T^<75O=&5)9&5N=&EF:65R
M*"1I9&5N=&EF:65R*2`N("(@)&1E8VEM86P@)&YU;&PL"B`@("`@("`@("!B
M('LD8F]O;&5A;E]C;VQ?='EP95LD9&)H+3YP:'!T>7!E77T@)&YU;&P*("`@
M("`@("`I"B`@("`B*3L*"B`@("!I9B`H1$(Z.FES17)R;W(H)&-R96%T92D@
M*2!["B`@("`@("`@<&4H)&-R96%T92D["B`@("!]"@H@("`@)&EN9F\@/2`D
M9&)H+3YT86)L94EN9F\H)W!E87)Q=6]T92<I.PH@("`@:68@*$1".CII<T5R
M<F]R*"1I;F9O*2`I('L*("`@("`@("!I9B`H)&EN9F\M/F-O9&4@/3T@1$)?
M15)23U)?3D]47T-!4$%"3$4I('L*("`@("`@("`@("`@<')I;G0@(D=O="!O
M=71C;VUE(&5X<&5C=&5D(&9R;VT@9&5L:6UI=&5D(&ED96YT:69I97(N7&XB
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT(")T86)L94EN
M9F\H*2!F86EL960N7&XB.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@
M("`@:68@*"1I9&5N=&EF:65R(#T]("1I;F9O6S)=6R=N86UE)UTI('L*("`@
M("`@("`@("`@<')I;G0@(D=O="!O=71C;VUE(&5X<&5C=&5D(&9R;VT@9&5L
M:6UI=&5D(&ED96YT:69I97(N7&XB.PH@("`@("`@("`@("`O+R!P<FEN="`B
M0T],54U.($Y!344@25,Z('LD:6YF;ULR75LG;F%M92==?5QN(CL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B17AP96-T960@8V]L=6UN
M(&YA;64Z("<D:61E;G1I9FEE<B<@+BXN("(["B`@("`@("`@("`@('!R:6YT
M(")!8W1U86P@8V]L=6UN(&YA;64Z("=[)&EN9F];,EU;)VYA;64G77TG7&XB
M.PH@("`@("`@('T*("`@('T*"GT@96QS92!["B`@("`D9&)H+3YQ=65R>2@B
M"B`@("`@("`@0U)%051%(%1!0DQ%('!E87)Q=6]T92`H"B`@("`@("`@("!N
M("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@<R`D8VAR("1N=6QL+`H@("`@
M("`@("`@<&QA:6YI9&5N=&EF:65R("1D96-I;6%L("1N=6QL+`H@("`@("`@
M("`@8B![)&)O;VQE86Y?8V]L7W1Y<&5;)&1B:"T^<&AP='EP95U]("1N=6QL
M"B`@("`@("`@*0H@("`@(BD["B`@("!P<FEN="`B1V]T(&]U=&-O;64@97AP
M96-T960@9G)O;2!D96QI;6ET960@:61E;G1I9FEE<BY<;B(["GT*"@HD9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I
M.PH*"B1S=')I;F=S(#T@87)R87DH"B`@("`B)R(L"B`@("`B7"(B+`H@("`@
M(EQ<(BP*("`@("(E(BP*("`@(")?(BP*("`@("(G)R(L"B`@("`B7")<(B(L
M"B`@("`B7%Q<7"(L"B`@("`B7%PG7%PG(BP*("`@(")<7%PB7%Q<(B(**3L*
M"B1N=6US(#T@87)R87DH"B`@("`Q,BXS+`H@("`@,34L"BD["@HD8F]O;',@
M/2!A<G)A>2@*("`@(%12544L"B`@("!&04Q312P**3L*"@IE8VAO(")3=')I
M;F<@97-C87!E('1E<W0Z("(["F9O<F5A8V@@*"1S=')I;F=S(&%S("1S*2![
M"B`@("`D<75O=&5D(#T@)&1B:"T^<75O=&53;6%R="@D<RD["B`@("`D9&)H
M+3YQ=65R>2@B24Y315)4($E.5$\@<&5A<G%U;W1E("AS*2!604Q515,@*"1Q
M=6]T960I(BD["GT*)&1I9F8@/2!A<G)A>5]D:69F*"1S=')I;F=S+"`D<F5S
M(#T@)&1B:"T^9V5T0V]L*")314Q%0U0@<R!&4D]-('!E87)Q=6]T92(I*3L*
M:68@*&-O=6YT*"1D:69F*2`^(#`I('L*("`@(&5C:&\@(D9!24PB.PH@("`@
M<')I;G1?<B@D<W1R:6YG<RD["B`@("!P<FEN=%]R*"1R97,I.PI](&5L<V4@
M>PH@("`@96-H;R`B3TLB.PI]"@HD9&)H+3YQ=65R>2@B1$5,151%($923TT@
M<&5A<G%U;W1E(BD["@H*96-H;R`B7&Y.=6UB97(@97-C87!E('1E<W0Z("([
M"F9O<F5A8V@@*"1N=6US(&%S("1N*2!["B`@("`D<75O=&5D(#T@)&1B:"T^
M<75O=&53;6%R="@D;BD["B`@("`D9&)H+3YQ=65R>2@B24Y315)4($E.5$\@
M<&5A<G%U;W1E("AN*2!604Q515,@*"1Q=6]T960I(BD["GT*"B1D:69F(#T@
M87)R87DH*3L*)')E<R`])B`D9&)H+3YG971#;VPH)U-%3$5#5"!N($923TT@
M<&5A<G%U;W1E($]21$52($)9(&XG*3L*9F]R96%C:"`H)&YU;7,@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("!I9B`H)'9A;"`A/2`D<F5S6R1K97E=*2!["B`@
M("`@("`@)&1I9F9;72`]("(D=F%L("$]('LD<F5S6R1K97E=?2(["B`@("!]
M"GT*"FEF("AC;W5N="@D9&EF9BD@/B`P*2!["B`@("!E8VAO(")&04E,7&XB
M.PH@("`@<')I;G1?<B@D9&EF9BD["GT@96QS92!["B`@("!E8VAO("=/2R<[
M"GT*"B1D8F@M/G%U97)Y*"=$14Q%5$4@1E)/32!P96%R<75O=&4G*3L*"@IE
M8VAO(")<;D)O;VQE86X@97-C87!E('1E<W0Z("(["B1I(#T@,3L*9F]R96%C
M:"`H)&)O;VQS(&%S("1B*2!["B`@("`D<75O=&5D(#T@)&1B:"T^<75O=&53
M;6%R="@D8BD["B`@("`D9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&5A<G%U
M;W1E("AN+"!B*2!604Q515,@*"1I+"`D<75O=&5D*2(I.PH@("`@)&DK*SL*
M?0H*)&1I9F8@/2!A<G)A>2@I.PHD<F5S(#TF("1D8F@M/F=E=$-O;"@G4T5,
M14-4(&(L(&X@1E)/32!P96%R<75O=&4@3U)$15(@0ED@;B<I.PIF;W)E86-H
M("@D8F]O;',@87,@)&ME>2`]/B`D=F%L*2!["B`@("!I9B`H)'9A;"`]/3T@
M=')U92D@>PH@("`@("`@(&EF("@D<F5S6R1K97E=(#T](#$@?'P@)')E<ULD
M:V5Y72`]/2!T<G5E('Q\"B`@("`@("`@("`@('-U8G-T<BAS=')T;VQO=V5R
M*"1R97-;)&ME>5TI+"`P+"`Q*2`]/2`G="<I"B`@("`@("`@>PH@("`@("`@
M("`@("`O+R!G;V]D"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1I
M9F9;72`](")I;CIT<G5E("$](&]U=#I[)')E<ULD:V5Y77TB.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@:68@*"1R97-;)&ME>5T@/3T@,"!\
M?"`D<F5S6R1K97E=(#T](&9A;'-E('Q\"B`@("`@("`@("`@('-U8G-T<BAS
M=')T;VQO=V5R*"1R97-;)&ME>5TI+"`P+"`Q*2`]/2`G9B<I"B`@("`@("`@
M>PH@("`@("`@("`@("`O+R!G;V]D"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&1I9F9;72`](")I;CIF86QS92`A/2!O=70Z>R1R97-;)&ME>5U]
M(CL*("`@("`@("!]"B`@("!]"GT*"FEF("AC;W5N="@D9&EF9BD@/B`P*2![
M"B`@("!E8VAO(")&04E,7&XB.PH@("`@<')I;G1?<B@D9&EF9BD["GT@96QS
M92!["B`@("!E8VAO(")/2UQN(CL*?0H*"B1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P96%R
M<75O=&4G*3L*"C\^"BTM15A014-4+2T*1V]T(&]U=&-O;64@97AP96-T960@
M9G)O;2!D96QI;6ET960@:61E;G1I9FEE<BX*4W1R:6YG(&5S8V%P92!T97-T
M.B!/2PI.=6UB97(@97-C87!E('1E<W0Z($]+"D)O;VQE86X@97-C87!E('1E
M<W0Z($]+"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9')I=F5R+S$V=&%B;&5I;F9O+G!H<'0`````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#8V,C,`
M,3`U,34T,S$P-3<`,#(T-#0T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ=&%B;&5);F9O
M"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_
M<&AP"@HO*BH*("H@0V%L;',@=&%B;&5);F9O*"D@:6X@=F%R:6]U<R!W87ES
M(&%N9"!C:&5C:W,@=&\@<V5E('1H870@=&AE(&]U='!U=`H@*B!M871C:&5S
M('=H870G<R!E>'!E8W1E9"X*("H*("H@5&AE<V4@=&5S=',@86-C;W5N="!F
M;W(@96%C:"!$0DU3('5S:6YG(&1I9F9E<F5N="!C;VQU;6X@='EP97,@86YD
M"B`J(')E<&]R=&EN9R!B86-K(&1I9F9E<F5N="!I;F9O<FUA=&EO;BX@(%1H
M97-E(&1I9F9E<F5N8V5S(&%R92!A8V-O=6YT960*("H@9F]R(&EN('1H92`\
M=F%R/B1Q=6ER:W,\+W9A<CX@87)R87DL('=H:6-H(&AA<R!T:&4@9F]L;&]W
M:6YG(&9O<FUA=#H*("H*("H@/'!R93X*("H@)V1R:79E<B<@/3X@87)R87DH
M"B`J("`@("`G8VQO8B<@/3X@1$)-4R=S(&-O;'5M;B!T>7!E(&9O<B!C<F5A
M=&EN9R!#3$]"(&9I96QD<PH@*B`@("`@)V1A=&4G(#T^($1"35,G<R!C;VQU
M;6X@='EP92!F;W(@8W)E871I;F<@1$%412!F:65L9',*("H@("`@("=D871E
M;&ET97)A;"<@/3X@5&AE(%-13"!K97EW;W)D(&YE8V5S<V%R>2!F;W(@9&5F
M:6YI;F<@9&%T97,*("H@("`@("=F:6YD<U]T86)L92<@/3X@0V%N('1H:7,@
M1$)-4R!D971E<FUI;F4@=&%B;&4@;F%M97,@9G)O;2!Q=65R:65S/PH@*B`@
M("`@)W-I>F5?9G)O;5]T86)L92<@/3X@1&]E<R!T:&ES($1"35,@:VYO=R!T
M:&4@8V]L=6UN('-I>F4@=FEA('1A8FQE(&YA;64_"B`J("`@("`G:&%N9&QE
M<U]R97-U;'1S)R`]/B!#86X@=&AE($1"35,@9V5T(&EN9F\@9G)O;2!Q=65R
M>2!R97-U;'1S/PH@*B`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("H@("`@
M("`@("!%>'1R82!C;VUM86YD<R!T;R!B92!P87-S960@=&\@4$A0)W,@979A
M;"@I(&9U;F-T:6]N"B`J("`@("`I"B`J("`@("`P(#T^(&%R<F%Y*`H@*B`@
M("`@("`@("\O("!);F9O(&5X<&5C=&5D('1O(&)E(')E<&]R=&5D(&9O<B!P
M:'!T97-T7V9K+F$*("H@("`@("`@("`O+R`@*$E.5$5'15(@3D]4($Y53$PI
M("A53DE1544@2T59('=I=&@@9"D*("H@("`@("`@("`G='EP92<@/3X@0V]L
M=6UN('1Y<&4@<F5P;W)T960@8GD@=&AE($1"35,*("H@("`@("`@("`G;&5N
M)R`]/B!#;VQU;6X@<VEZ92!R97!O<G1E9"!B>2!T:&4@1$)-4PH@*B`@("`@
M("`@("=F;&%G<R<@/3X@1FQA9W,@<F5P;W)T960@8GD@=&AE($1"35,*("H@
M("`@("D*("H@("`@(#$@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B
M92!R97!O<G1E9"!F;W(@<&AP=&5S=%]F:RYF:PH@*B`@("`@("`@("`@("`@
M("`@("`H24Y414=%4B!.3U0@3E5,3"D@*%!224U!4ED@2T59*0H@*B`@("`@
M,B`]/B!A<G)A>2@I("!);F9O(&5X<&5C=&5D('1O(&)E(')E<&]R=&5D(&9O
M<B!P:'!T97-T7V9K+F,*("H@("`@("`@("`@("`@("`@("`@*$-,3T(O0TA!
M4B]605)#2$%2($Y53$PI"B`J("`@("`S(#T^(&%R<F%Y*"D@($EN9F\@97AP
M96-T960@=&\@8F4@<F5P;W)T960@9F]R('!H<'1E<W1?9FLN9`H@*B`@("`@
M("`@("`@("`@("`@("`H1$%412!.3U0@3E5,3"D@*%5.25%512!+15D@=VET
M:"!A*0H@*B`@("`@-"`]/B!A<G)A>2@I("!);F9O(&5X<&5C=&5D('1O(&)E
M(')E<&]R=&5D(&9O<B!P:'!T97-T7V9K+F4*("H@("`@("`@("`@("`@("`@
M("`@*$-(05(H,BD@1$5&055,5"`G(&4G($Y/5"!.54Q,*0H@*B`@("`@-2`]
M/B!A<G)A>2@I("!);F9O(&5X<&5C=&5D('1O(&)E(')E<&]R=&5D(&9O<B!P
M:'!T97-T7V9K+F8*("H@("`@("`@("`@("`@("`@("`@*$1%0TE-04PH,BPQ
M*2!.54Q,*0H@*B`@("`@.2`]/B!A<G)A>2@I("!);F9O(&5X<&5C=&5D('1O
M(&)E(')E<&]R=&5D(&9O<B!P:'!T97-T+F0*("H@("`@("`@("`@("`@("`@
M("`@*%9!4D-(05(H,C`I($Y53$PI"B`J("D*("H@/"]P<F4^"B`J"B`J($!C
M871E9V]R>2!$871A8F%S90H@*B!`<&%C:V%G92`@1$(*("H@0'9E<G-I;VX@
M("1)9#H@,39T86)L96EN9F\N<&AP="QV(#$N,S(@,C`P-2\P,B\Q-"`Q-SHP
M-#HQ-R!D86YI96QC($5X<"`D"B`J($!A=71H;W(@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0&%N86QY<VES86YD<V]L=71I;VYS+F-O;3X*("H@0'-E
M92`@("`@($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("HO"@IE<G)O<E]R97!O
M<G1I;F<H15]!3$PI.PIC:&1I<BAD:7)N86UE*%]?1DE,15]?*2D["G)E<75I
M<F5?;VYC92`G+B]S:VEP:68N:6YC)SL*)'1A8FQE26YF;R`]("1D8BT^=&%B
M;&5);F9O*"=A:FMD<VQF86IO:6IK861I92<I.PII9B`H1$(Z.FES17)R;W(H
M)'1A8FQE26YF;RD@)B8@)'1A8FQE26YF;RT^8V]D92`]/2!$0E]%4E)/4E].
M3U1?0T%004),12D@>PH@("`@9&EE*")S:VEP("1T86)L94EN9F\M/FUE<W-A
M9V4B*3L*?0H*/SX*+2U&24Q%+2T*/#]P:'`*"B\O("`D260Z(#$V=&%B;&5I
M;F9O+G!H<'0L=B`Q+C,R(#(P,#4O,#(O,30@,3<Z,#0Z,3<@9&%N:65L8R!%
M>'`@)`H*+RHJ"B`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%N9"!M86ME
M('1H92!P:'!T97-T('1A8FQE+@H@*B\*<F5Q=6ER95]O;F-E("<N+VUK=&%B
M;&4N:6YC)SL*"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R
M+@H@*@H@*B!);B!G96YE<F%L+"!I="!P<FEN=',@;W5T(&%N(&5R<F]R(&UE
M<W-A9V4@86YD(&MI;&QS('1H92!P<F]C97-S+@H@*B!"=70@<V]M92!E<G)O
M<G,@87)E(&5X<&5C=&5D(&%N9"!A;&QO=V5D('1O(&5X:7-T+@H@*@H@*B!`
M<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC
M86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J
M($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P
M92@D;RE["B`@("!G;&]B86P@)&1B:"P@)'%U:7)K<SL*"B`@("!I9B`H)&\M
M/F=E=$UE<W-A9V4H*2`]/2`B1$(@17)R;W(Z(&-A;B=T(&1I<W1I;F=U:7-H
M(&1U<&QI8V%T92!F:65L9"!N86UE<R(I('L*("`@("`@("!P<FEN="`B3D]4
M24-%.B`D9&)H+3YP:'!T>7!E(&-A;B=T(&1I<W1I;F=U:7-H(&1U<&QI8V%T
M92!F:65L9"!N86UE<R(["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF
M("@D;RT^9V5T0V]D92@I(#T]($1"7T524D]27TY/5%]#05!!0DQ%("8F"B`@
M("`@("`@(21Q=6ER:W-;)&1B:"T^<&AP='EP92`N("<Z)R`N("1D8F@M/F1B
M<WEN=&%X75LG:&%N9&QE<U]R97-U;'1S)UTI"B`@("!["B`@("`@("`@<F5T
M=7)N.PH@("`@?0H*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I
M.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S=%]F:R<I.PH*("`@(&1I
M92@D;RT^=&]3=')I;F<H*2D["GT*"B\J*@H@*B!,;V]P('1H<F]U9V@@86X@
M87)R87D@<F5T=7)N960@9G)O;2!T86)L94EN9F\H*2P@8V]M<&%R92!T:&4@
M86-T=6%L"B`J(&-O;G1E;G1S('1O('1H92!E>'!E8W1E9"!C;VYT96YT<RX@
M($EF('1H92!A8W1U86P@<F5S=6QT<R!M871C:"!T:&4*("H@97AP96-T871I
M;VYS+"!S87D@<V\N("!)9B!N;W0L('-A>2!S;R!A;F0@<VAO=R!T:&4@:6YF
M;W)M871I;VXN"B`J"B`J($!P87)A;2!A<G)A>2`@("1A<G)A>2`@("`@=&AE
M(&%R<F%Y('1O(&)E(&5X86UI;F5D"B`J($!P87)A;2!S=')I;F<@("1E>'!E
M8W1E9"`@=&AE(&5X<&5C=&5D(&-O;G1E;G1S(&]F('1H92!A<G)A>0H@*B!`
M<&%R86T@<W1R:6YG("`D9FEE;&0@("`@(&9I96QD(&EN9&5X(&YU;6)E<B!O
M9B`D<75R:6MS(&%N9"!T86)L90H@*B!`<&%R86T@8F]O;&5A;B`D<75E<GD@
M("`@('1R=64@:68@87)R87D@:7,@9G)O;2!A('%U97)Y(&]R(&9A;'-E(&EF
M(&%R<F%Y"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@=&%B;&5)
M;F9O*"D*("H@0')E='5R;B!V;VED"B`J+PIF=6YC=&EO;B!E>&%M:6YE07)R
M87E$871A*"1A<G)A>2P@)&5X<&5C=&5D+"`D9FEE;&0@/2!F86QS92P@)'%U
M97)Y(#T@=')U92D@>PH@("`@9VQO8F%L("1D8F@L("1Q=6ER:W,["@H@("`@
M)'%U:7)K7VME>2`]("1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y
M;G1A>#L*"B`@("!I9B`H1$(Z.FES17)R;W(H)&%R<F%Y*2`F)B`D87)R87DM
M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U1?0T%004),12D@>PH@("`@("`@
M('!R:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*("`@("`@("!R
M971U<FX["B`@("!]"@H@("`@:68@*"%I<U]A<G)A>2@D87)R87DI*2!["B`@
M("`@("`@<')I;G0@(E1H:7,@1$U"4R!D:61N)W0@<')O9'5C92!P<F]P97(@
M<F5S=6QT<UQN(CL*("`@("`@("!R971U<FX["B`@("!]"@H@("`@:68@*&ES
M7VEN="@D9FEE;&0I*2!["B`@("`@("`@)&%R<F%Y(#T@)&%R<F%Y6R1F:65L
M9%T["B`@("!]"@H@("`@)&%C='5A;"`]("<G.PH@("`@9F]R96%C:"`H)&%R
M<F%Y(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@:68@*"1F:65L9"`A
M/3T@9F%L<V4@)B8*("`@("`@("`@("`@:7-S970H)'%U:7)K<ULD<75I<FM?
M:V5Y75LD9FEE;&1=6R1K97E=*2D*("`@("`@("!["B`@("`@("`@("`@(&EF
M("@D:V5Y(#T]("=F;&%G<R<@)B8@)'9A;'5E(#T]("<G("8F("1Q=65R>2`F
M)@H@("`@("`@("`@("`@("`@(21Q=6ER:W-;)'%U:7)K7VME>5U;)V9I;F1S
M7W1A8FQE)UTI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1A8W1U
M86P@+CT@(B1K97D@+BXN(&UA=&-H960@97AP96-T960@=F%L=65<;B(["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H)'%U:7)K
M<ULD<75I<FM?:V5Y75LD9FEE;&1=6R1K97E=(#T]("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K97D@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=65<;B(["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=64@/3T@,`H@("`@("`@("`@
M("`@("`@("`@("`@("`F)B`A)'%U:7)K<ULD<75I<FM?:V5Y75LG<VEZ95]F
M<F]M7W1A8FQE)UTI"B`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!M871C:&5D(&5X
M<&5C=&5D('9A;'5E7&XB.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K97D@+BXN
M('=A<R`G)'9A;'5E)R!B=70@=V4@97AP96-T960@(CL*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%C='5A;"`N/2`B)WLD<75I<FMS6R1Q=6ER:U]K97E=
M6R1F:65L9%U;)&ME>5U])UQN(CL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G=&%B;&4G*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&9I96QD(#P](#4I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'9A;'5E(#T]("=P:'!T97-T7V9K)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E7&XB.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=64@/3T@)R<@)B8@)'%U
M97)Y("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`A)'%U:7)K<ULD
M<75I<FM?:V5Y75LG9FEN9'-?=&%B;&4G72D*("`@("`@("`@("`@("`@("`@
M("`@("`@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%C='5A;"`N
M/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU95QN(CL*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A8W1U86P@+CT@(B1K97D@+BXN('=A<R`G)'9A;'5E)R!B
M=70@=V4@97AP96-T960@)W!H<'1E<W1?9FLG7&XB.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E
M(#T]("=P:'!T97-T)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D86-T
M=6%L("X]("(D:V5Y("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E7&XB.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D=F%L=64@/3T@)R<@)B8@)'%U97)Y("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`A)'%U:7)K<ULD<75I<FM?:V5Y75LG9FEN
M9'-?=&%B;&4G72D*("`@("`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&%C='5A;"`N/2`B)&ME>2`N+BX@;6%T
M8VAE9"!E>'!E8W1E9"!V86QU95QN(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1U
M86P@+CT@(B1K97D@+BXN('=A<R`G)'9A;'5E)R!B=70@=V4@97AP96-T960@
M)W!H<'1E<W1?9FLG7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%C='5A;"`N/2`B)&ME
M>2`]/B`D=F%L=65<;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"B`@("!I9B`H)&%C='5A;"`]/2`D97AP96-T960I('L*("`@("`@("!P<FEN
M="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["B`@("!](&5L<V4@>PH@
M("`@("`@('!R:6YT(")$241.)U0@;6%T8V@@97AP96-T960@=F%L=65S+BXN
M7&XB.PH@("`@("`@('!R:6YT(")^?GY^?GY^?EQN17AP96-T960Z7&XD97AP
M96-T961<;B(["B`@("`@("`@<')I;G0@(GY^?GY<;D%C='5A;#I<;B1A8W1U
M86Q<;GY^?GY^?GY^7&Y<;B(["B`@("!]"GT*"B\J*@H@*B!,;V]P('1H<F]U
M9V@@86X@87)R87D@;V8@=&%B;&4@:6YF;R!D871A(&%N9"!R971U<FX@=&AE
M(')E<W5L=',N"B`J"B`J($!P87)A;2!A<G)A>2`@)&%R<F%Y("!T:&4@87)R
M87D@=&\@8F4@97AA;6EN960*("H@0')E='5R;B!S=')I;F<*("HO"F9U;F-T
M:6]N(')E='5R;D%R<F%Y1&%T82@D87)R87DI('L*("`@(&=L;V)A;"`D9&)H
M+"`D<75I<FMS.PH*("`@("1Q=6ER:U]K97D@/2`D9&)H+3YP:'!T>7!E("X@
M)SHG("X@)&1B:"T^9&)S>6YT87@["@H@("`@:68@*"$D<75I<FMS6R1Q=6ER
M:U]K97E=6R=H86YD;&5S7W)E<W5L=',G72D@>PH@("`@("`@(')E='5R;B`B
M7&XB.PH@("`@?0H*("`@("1O=70@/2`G)SL*("`@(&9O<F5A8V@@*"1A<G)A
M>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("1O=70@+CT@(B1K97D@
M/3X@)'9A;'5E7&XB.PH@("`@?0H@("`@<F5T=7)N("1O=70["GT*"@HD9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I
M.PH*"B1Q=6ER:W,@/2!A<G)A>2@*("`@("=F8G-Q;#IF8G-Q;"<@/3X@87)R
M87DH"B`@("`@("`@)V-L;V(G(#T^("=#2$%2*#(Y*2<L"B`@("`@("`@)V1A
M=&4G(#T^("=$051%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<@1$%4
M12`G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?
M<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y
M*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#$@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L
M"B`@("`@("`@("`@("=L96XG(#T^(#`L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#(@/3X@87)R87DH
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!4D%#5$52)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@,CDL"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@
M("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)T1!5$4G+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#2$%204-415(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`R+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G
M+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=$14-)34%,)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#D@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!4D%#5$52
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@)VEB87-E.FEB87-E
M)R`]/B!A<G)A>2@*("`@("`@("`G8VQO8B<@/3X@)U9!4D-(05(H-3`I)RP*
M("`@("`@("`G9&%T92<@/3X@)T1!5$4G+`H@("`@("`@("=D871E;&ET97)A
M;"<@/3X@)R<L"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@
M("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N
M9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@
M87)R87DH"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)TE.5$5'15(G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y(&YO=%]N
M=6QL)RP*("`@("`@("`I+`H@("`@("`@(#$@/3X@87)R87DH"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG(#T^
M(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)W!R:6UA<GE?:V5Y(&YO=%]N
M=6QL)RP*("`@("`@("`I+`H@("`@("`@(#(@/3X@87)R87DH"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G5D%20TA!4B<L"B`@("`@("`@("`@("=L96XG(#T^
M(#4P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@
M("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=$051%
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S
M)R`]/B`G=6YI<75E7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@
M("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T-(05(G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`R+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("=N;W1?;G5L;"!D969A=6QT)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@
M87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G3E5-15))0R@Y+#$I)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G)RP*("`@("`@("`I+`H@("`@("`@(#D@/3X@87)R87DH"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G5D%20TA!4B<L"B`@("`@("`@("`@("=L96XG(#T^
M(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@
M("`I+`H*("`@("=I8F%S93IF:7)E8FER9"<@/3X@87)R87DH"B`@("`@("`@
M)V-L;V(G(#T^("=605)#2$%2*#4P*2<L"B`@("`@("`@)V1A=&4G(#T^("=$
M051%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F
M:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L
M92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U
M92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@
M("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%
M1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G=6YI<75E7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'
M15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("=P<FEM87)Y7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(
M05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`U,"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G1$%412<L"B`@("`@("`@("`@("=L96XG
M(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)W5N:7%U95]K97D@;F]T
M7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@9&5F875L="<L
M"B`@("`@("`@*2P*("`@("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)TY5345224,H.2PQ*2<L"B`@("`@("`@("`@("=L96XG(#T^
M(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@
M("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(
M05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G:69X.FEF>"<@
M/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=#2$%2*#(Y*2<L"B`@("`@
M("`@)V1A=&4G(#T^("=#2$%2*#$P*2<L"B`@("`@("`@)V1A=&5L:71E<F%L
M)R`]/B`G)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@
M("`@("=S:7IE7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD
M;&5S7W)E<W5L=',G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]/B!A
M<G)A>2@*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G4U%,24Y4)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@
M("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=344Q)3E0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@
M("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U-13$-(05(G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`R.2P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G4U%,0TA!4B<L"B`@("`@("`@("`@("=L96XG(#T^
M(#$P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@
M("`@*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)U-13$-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@
M("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U-13$1%0TE-
M04PG+`H@("`@("`@("`@("`G;&5N)R`]/B`U,3,L"B`@("`@("`@("`@("=F
M;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)U-13$-(05(G+`H@("`@("`@("`@("`G
M;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@
M("`I+`H@("`@*2P*"B`@("`G;7-Q;#IM<W%L)R`]/B!A<G)A>2@*("`@("`@
M("`G8VQO8B<@/3X@)U1%6%0H,C4U*2<L"B`@("`@("`@)V1A=&4G(#T^("=#
M2$%2*#$P*2<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*("`@("`@
M("`G9FEN9'-?=&%B;&4G(#T^('1R=64L"B`@("`@("`@)W-I>F5?9G)O;5]T
M86)L92<@/3X@=')U92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T
M<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@*2P*
M("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN
M="<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#$@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@-"P*("`@("`@("`@("`@+R\@9F]R('-O;64@<F5A<V]N+"!T
M:&4@=6YI<75E('!R;W!E<G1Y(&%L=V%Y<R!C;VYT86EN<R`P"B`@("`@("`@
M("`@("\O("=F;&%G<R<@/3X@)W5N:7%U95]K97D@;F]T7VYU;&PG+`H@("`@
M("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G
M+`H@("`@("`@("`@("`G;&5N)R`]/B`R-34L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G='EP92<@/3X@)V-H87(G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`Q,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@
M("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=R96%L)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@."P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@("`@(#D@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G8VAA<B<L"B`@("`@("`@("`@("=L96XG(#T^(#(P+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`I+`H*
M("`@("=M<W-Q;#IM<W-Q;"<@/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^
M("=415A4)RP*("`@("`@("`G9&%T92<@/3X@)U--04Q,1$%4151)344G+`H@
M("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@("`@)V9I;F1S7W1A
M8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!F
M86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@
M("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@("`@("=I;FE?<V5T
M*")M<W-Q;"YD871E=&EM96-O;G9E<G0B+"`B3V9F(BD[)RP*("`@("`@("`@
M("`@)R1D8F@M/G%U97)Y*")3150@1$%4149/4DU!5"!Y;60B*3LG+`H@("`@
M("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@
M("`G9FQA9W,G(#T^("=M=6QT:7!L95]K97D@=6YI<75E7VME>2!N;W1?;G5L
M;"<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)W!R:6UA<GE?:V5Y(&YO=%]N=6QL)RP*
M("`@("`@("`I+`H@("`@("`@(#(@/3X@87)R87DH"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=L96XG(#T^(#0P.38L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`S
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V1A=&5T:6UE)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G;75L=&EP;&5?:V5Y('5N:7%U95]K97D@;F]T7VYU;&PG+`H@("`@("`@
M("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-2`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=R96%L)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,3DL"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)V-H87(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@
M("`G;7ES<6PZ;7ES<6PG(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G
M5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@("`G9&%T
M96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@=')U
M92P*("`@("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!T<G5E+`H@("`@("`@
M("=H86YD;&5S7W)E<W5L=',G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S
M)R`]/B!A<G)A>2@*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@)VQE;B<@
M/3X@,3$L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&UU;'1I
M<&QE7VME>2<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^
M(#$Q+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!P<FEM87)Y
M7VME>2<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)V)L;V(G+`H@("`@("`@("`@("`G;&5N)R`]/B`V
M-34S-2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G8FQO8B<L"B`@("`@("`@
M*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)V1A=&4G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G;F]T7VYU;&P@;75L=&EP;&5?:V5Y)RP*("`@("`@("`I
M+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M<W1R:6YG)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-2`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=R96%L)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*
M("`@("`@("`I+`H@("`@("`@(#D@/3X@87)R87DH"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@
M("`@)VUY<W%L:3IM>7-Q;&DG(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]
M/B`G5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@("`G
M9&%T96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@
M=')U92P*("`@("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@
M("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM
M86YD<R<@/3X@87)R87DH"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L
M96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&UU
M;'1I<&QE7VME>2!G<F]U<%]B>2<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@
M("`@("=L96XG(#T^(#`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N
M=6QL('!R:6UA<GE?:V5Y(&=R;W5P7V)Y)RP*("`@("`@("`I+`H@("`@("`@
M(#(@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G8FQO8B<L"B`@
M("`@("`@("`@("=L96XG(#T^(#`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)V)L;V(G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=D871E)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&UU;'1I<&QE
M7VME>2<L"B`@("`@("`@*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)V-H87(G+`H@("`@("`@("`@("`G;&5N)R`]/B`P
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@
M*2P*("`@("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)V1E8VEM86PG+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@
M("`G9FQA9W,G(#T^("=G<F]U<%]B>2<L"B`@("`@("`@*2P*("`@("`@("`Y
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W9A<F-H87(G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G;V-I.#IO8VDX)R`]/B!A
M<G)A>2@*("`@("`@("`G8VQO8B<@/3X@)T-,3T(G+`H@("`@("`@("=D871E
M)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*("`@
M("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE7V9R
M;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L=',G
M(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)R1D8F@M/G%U97)Y*")!3%1%4B!315-324].(%-%5"!.3%-?1$%4
M15]&3U)-050@/2!<)UE965DM34TM1$1<)R(I.R<L"B`@("`@("`@*2P*("`@
M("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TY534)%
M4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(R+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TY534)%4B<L"B`@("`@("`@
M("`@("=L96XG(#T^(#(R+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?
M;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)T-,3T(G+`H@("`@("`@("`@("`G;&5N)R`]/B`T
M,#`P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@
M("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=$051%
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@-RP*("`@("`@("`@("`@)V9L86=S
M)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#2$%2)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=.54U"15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,BP*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#D@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G5D%20TA!4B<L
M"B`@("`@("`@("`@("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G
M(#T^("<G+`H@("`@("`@("DL"B`@("`I+`H*("`@("=O9&)C.F%C8V5S<R<@
M/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=415A4)RP*("`@("`@("`G
M9&%T92<@/3X@)T1!5$5424U%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^
M("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?
M<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y
M*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I
M+`H@("`@("`@(#$@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M24Y414=%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#$P+`H@("`@("`@("`@
M("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TQ/3D=#2$%2)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@,C4U+`H@("`@("`@("`@("`G9FQA9W,G
M(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=$051%5$E-12<L"B`@("`@("`@("`@("=L96XG
M(#T^(#$Y+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@
M("`@("`@*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R+`H@("`@
M("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T1%0TE-
M04PG+`H@("`@("`@("`@("`G;&5N)R`]/B`Q-2P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#D@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G5D%20TA!4B<L"B`@("`@("`@("`@("=L
M96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@
M("DL"B`@("`I+`H*("`@("=O9&)C.F1B,B<@/3X@87)R87DH"B`@("`@("`@
M)V-L;V(G(#T^("=#3$]")RP*("`@("`@("`G9&%T92<@/3X@)T1!5$4G+`H@
M("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@("`@)V9I;F1S7W1A
M8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!F
M86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@
M("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@*2P*("`@("`@("`P
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'15(G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL
M)RP*("`@("`@("`I+`H@("`@("`@(#(@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G0TQ/0B<L"B`@("`@("`@("`@("=L96XG(#T^(#$P-#@U
M-S8L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@
M("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T1!5$4G
M+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@)V9L86=S
M)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#2$%2)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=$14-)34%,)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#D@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G5D%20TA!4B<L
M"B`@("`@("`@("`@("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G
M(#T^("<G+`H@("`@("`@("DL"B`@("`I+`H*("`@("=P9W-Q;#IP9W-Q;"<@
M/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=415A4)RP*("`@("`@("`G
M9&%T92<@/3X@)T1!5$4G+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L
M"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ
M95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U
M;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("<D9&)H+3YQ=65R>2@B4T54($1!5$535%E,12`]($E33R(I
M.R<L"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`G='EP92<@/3X@)VEN=#0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!U;FEQ=65?:V5Y(&UU
M;'1I<&QE7VME>2<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)VEN=#0G+`H@("`@("`@("`@("`G;&5N
M)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!P<FEM
M87)Y7VME>2<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`M,2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@
M("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&%T
M92<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL('5N:7%U95]K97D@;75L=&EP;&5?:V5Y)RP*("`@
M("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G8G!C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@+3$L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&1E9F%U;'1?)3(P92<L"B`@
M("`@("`@*2P*("`@("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)VYU;65R:6,G+`H@("`@("`@("`@("`G;&5N)R`]/B`M,2P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#D@
M/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G=F%R8VAA<B<L"B`@
M("`@("`@("`@("=L96XG(#T^("TQ+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("<G+`H@("`@("`@("DL"B`@("`I+`H*("`@("=S<6QI=&4Z<W%L:71E)R`]
M/B!A<G)A>2@*("`@("`@("`G8VQO8B<@/3X@)T-,3T(G+`H@("`@("`@("=D
M871E)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*
M("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE
M7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L
M=',G(#T^(&9A;'-E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@
M("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)TE.5$5'15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@
M("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'
M15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("=P<FEM87)Y7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T-,3T(G
M+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA9W,G
M(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=$051%)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@
M("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G;F]T7VYU;&P@9&5F875L=%\E,C!E)RP*("`@("`@("`I
M+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M1$5#24U!3"<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@
M("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@
M("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@
M("`@("`I+`H@("`@*2P*"B`@("`G<WEB87-E.G-Y8F%S92<@/3X@87)R87DH
M"B`@("`@("`@)V-L;V(G(#T^("=415A4)RP*("`@("`@("`G9&%T92<@/3X@
M)U--04Q,1$%4151)344G+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L
M"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ
M95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U
M;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("<D9&)H+3YQ=65R>2@B4T54($1!5$5&3U)-050@>6UD(BD[
M)RP*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3$L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VUU;'1I<&QE7VME>2!U;FEQ=65?:V5Y
M)RP*("`@("`@("`I+`H@("`@("`@(#$@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3$L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)W5N:7%U95]K97DG+`H@("`@("`@("DL
M"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=S
M=')I;F<G+`H@("`@("`@("`@("`G;&5N)R`]/B`S,C<V."P*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&%T971I;64G+`H@("`@("`@
M("`@("`G;&5N)R`]/B`R.2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;75L
M=&EP;&5?:V5Y('5N:7%U95]K97DG+`H@("`@("`@("DL"B`@("`@("`@-"`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`R+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G
M+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=R96%L)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#D@
M/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)R<L"B`@("`@("`@*2P*("`@("DL"BD["@H*)'%U:7)K7VME>2`]("1D8F@M
M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>#L*"FEF("@A:7-S970H
M)'%U:7)K<ULD<75I<FM?:V5Y72DI('L*("`@(&1I92@B5&AI<R!T97-T(&1O
M97,@;F]T('EE="!S=7!P;W)T("1Q=6ER:U]K97DB*3L*?0H*:68@*&-O=6YT
M*"1Q=6ER:W-;)'%U:7)K7VME>5U;)V-O;6UA;F1S)UTI*2!["B`@("!F;W)E
M86-H("@D<75I<FMS6R1Q=6ER:U]K97E=6R=C;VUM86YD<R==(&%S("1V86QU
M92D@>PH@("`@("`@(&5V86PH)'9A;'5E*3L*("`@('T*?0H*"B1D8F@M/G%U
M97)Y*"=$14Q%5$4@1E)/32!P:'!T97-T)RD["B1D8F@M/G%U97)Y*"))3E-%
M4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H,2P@)V]N92<L("=/;F4G+"`G,C`P
M,2TP,BTQ-B<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T
M(%9!3%5%4R`H,BP@)W1W;R<L("=4=V\G+"`G,C`P,2TP,BTQ-2<I(BD["B1D
M8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H,RP@)W1H
M<F5E)RP@)U1H<F5E)RP@)S(P,#$M,#(M,30G*2(I.PH*"B1D8F@M/G-E=$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D
M8F@L("=P:'!T97-T7V9K)RD["B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["@H*:68@*"1Q=6ER:U]K97D@/3T@
M)V]D8F,Z86-C97-S)RD@>PH@("`@)&1E9F%U;'1?92`]("<G.PH@("`@)&1E
M8VEM86P@("`]("=.54U%4DE#)SL*?2!E;'-E:68@*"1Q=6ER:U]K97D@/3T@
M)VUS<6PZ;7-Q;"<I('L*("`@("1D969A=6QT7V4@/2`G)SL*("`@("1D96-I
M;6%L("`@/2`G4D5!3"<["GT@96QS92!["B`@("`D9&5F875L=%]E(#T@(D1%
M1D%53%0@)R!E)R(["B`@("`D9&5C:6UA;"`@(#T@)T1%0TE-04PH,BPQ*2<[
M"GT*"B\O("1N=6QL(&ES('-E="!I;B!M:W1A8FQE+FEN8PH*<W=I=&-H("@D
M9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=M<W%L)SH*("`@("`@("`D9&)H
M+3YQ=65R>2@B"B`@("`@("`@("`@($-214%412!404),12!P:'!T97-T7V9K
M("@*("`@("`@("`@("`@("`@(&$@24Y414=%4B!.3U0@3E5,3"P*("`@("`@
M("`@("`@("`@(&9K($E.5$5'15(@3D]4($Y53$PL"B`@("`@("`@("`@("`@
M("!C('LD<75I<FMS6R1Q=6ER:U]K97E=6R=C;&]B)UU]("1N=6QL+`H@("`@
M("`@("`@("`@("`@9"![)'%U:7)K<ULD<75I<FM?:V5Y75LG9&%T92==?2!.
M3U0@3E5,3"P*("`@("`@("`@("`@("`@(&4@0TA!4B@R*2`D9&5F875L=%]E
M($Y/5"!.54Q,+`H@("`@("`@("`@("`@("`@9B`D9&5C:6UA;"`D;G5L;`H@
M("`@("`@("`@("`I"B`@("`@("`@(BD["B`@("`@("`@)&1B:"T^<75E<GDH
M)T-214%412!53DE1544@24Y$15@@9FMP:R!/3B!P:'!T97-T7V9K("AF:RDG
M*3L*("`@("`@("`D9&)H+3YQ=65R>2@G0U)%051%(%5.25%512!)3D1%6"!F
M:W5K($].('!H<'1E<W1?9FL@*&$L(&0I)RD["B`@("`@("`@8G)E86L["B`@
M("!D969A=6QT.@H@("`@("`@("1D8F@M/G%U97)Y*"(*("`@("`@("`@("`@
M0U)%051%(%1!0DQ%('!H<'1E<W1?9FL@*`H@("`@("`@("`@("`@("`@82!)
M3E1%1T52($Y/5"!.54Q,+`H@("`@("`@("`@("`@("`@9FL@24Y414=%4B!.
M3U0@3E5,3"P*("`@("`@("`@("`@("`@(&,@>R1Q=6ER:W-;)'%U:7)K7VME
M>5U;)V-L;V(G77T@)&YU;&PL"B`@("`@("`@("`@("`@("!D('LD<75I<FMS
M6R1Q=6ER:U]K97E=6R=D871E)UU]($Y/5"!.54Q,+`H@("`@("`@("`@("`@
M("`@92!#2$%2*#(I("1D969A=6QT7V4@3D]4($Y53$PL"B`@("`@("`@("`@
M("`@("!F("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@("`@("`@4%))34%2
M62!+15D@*&9K*2P*("`@("`@("`@("`@("`@(%5.25%512`H82P@9"D*("`@
M("`@("`@("`@*0H@("`@("`@("(I.PI]"@HD9&)H+3YQ=65R>2@B0U)%051%
M($E.1$58('1H961I9'@@3TX@<&AP=&5S=%]F:R`H9"DB*3L*)&1B:"T^<75E
M<GDH(DE.4T525"!)3E1/('!H<'1E<W1?9FL@5D%,5453("@Q,"P@,2P@)T]N
M92<L(@H@("`@("`@("`@("`N("1Q=6ER:W-;)'%U:7)K7VME>5U;)V1A=&5L
M:71E<F%L)UT@+B`B)S(P,#$M,#(M,38G+"`@)V,Q)RP@,2XQ*2(I.PHD9&)H
M+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S=%]F:R!604Q515,@*#(P+"`R
M+"`G5'=O)RPB"B`@("`@("`@("`@("X@)'%U:7)K<ULD<75I<FM?:V5Y75LG
M9&%T96QI=&5R86PG72`N("(G,C`P,2TP,BTQ-2<L("=C,B<L(#(N,BDB*3L*
M)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W1?9FL@5D%,5453("@S
M,"P@,RP@)U1H<F5E)RPB"B`@("`@("`@("`@("X@)'%U:7)K<ULD<75I<FM?
M:V5Y75LG9&%T96QI=&5R86PG72`N("(G,C`P,2TP,BTQ-"<L("=C,R<L(#,N
M,RDB*3L*"F9U;F-T:6]N("9R=6Y1=65R>2@I('L*("`@(&=L;V)A;"`D9&)H
M+"`D<F5S=6QT;V)J.PH*("`@("1Q=6ER:U]K97D@/2`D9&)H+3YP:'!T>7!E
M("X@)SHG("X@)&1B:"T^9&)S>6YT87@["@H@("`@<W=I=&-H("@D<75I<FM?
M:V5Y*2!["B`@("`@("`@8V%S92`G;V1B8SID8C(G.@H@("`@("`@("`@("`O
M+R!C86XG="!E>'1R86-T(&)L;V(G<R!T:&ES('=A>2!S;R!M86ME(&$@9F%K
M92!C;VQU;6X*("`@("`@("`@("`@)'%U97)Y(#T@(E-%3$5#5"!P:'!T97-T
M7V9K+F$L('!H<'1E<W1?9FLN9FLL("=T96UP>'EZ)R!!4R!C+"(*("`@("`@
M("`@("`@("`@("`@("X@)R!P:'!T97-T7V9K+F0L('!H<'1E<W1?9FLN92P@
M<&AP=&5S=%]F:RYF+"<*("`@("`@("`@("`@("`@("`@("X@)R!P:'!T97-T
M+F$L('!H<'1E<W0N8BP@<&AP=&5S="YC+"!P:'!T97-T+F0G"B`@("`@("`@
M("`@("`@("`@("`N("<@1E)/32!P:'!T97-T7V9K+"!P:'!T97-T)PH@("`@
M("`@("`@("`@("`@("`@+B`G(%=(15)%('!H<'1E<W0N82`]('!H<'1E<W1?
M9FLN9FLG.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=M<W%L
M.FUS<6PG.@H@("`@("`@("`@("`D<75E<GD@/2`G4T5,14-4('!H<'1E<W1?
M9FLN82P@<&AP=&5S=%]F:RYF:RP@<&AP=&5S=%]F:RYC+"<*("`@("`@("`@
M("`@("`@("`@("X@)R!P:'!T97-T7V9K+F0L('!H<'1E<W1?9FLN92P@<&AP
M=&5S=%]F:RYF+"<*("`@("`@("`@("`@("`@("`@("X@)R!P:'!T97-T+F$L
M('!H<'1E<W0N8BP@<&AP=&5S="YC+"!P:'!T97-T+F0G"B`@("`@("`@("`@
M("`@("`@("`N("<@1E)/32!P:'!T97-T7V9K+"!P:'!T97-T)PH@("`@("`@
M("`@("`@("`@("`@+B`G(%=(15)%('!H<'1E<W0N82`]('!H<'1E<W1?9FLN
M9FLG.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("`D<75E<GD@/2`G4T5,14-4('!H<'1E<W1?9FLN82P@<&AP=&5S
M=%]F:RYF:RP@<&AP=&5S=%]F:RYC+"<*("`@("`@("`@("`@("`@("`@("X@
M)R!P:'!T97-T7V9K+F0L('!H<'1E<W1?9FLN92P@<&AP=&5S=%]F:RYF+"<*
M("`@("`@("`@("`@("`@("`@("X@)R!P:'!T97-T+F$L('!H<'1E<W0N8BP@
M<&AP=&5S="YC+"!P:'!T97-T+F0G"B`@("`@("`@("`@("`@("`@("`N("<@
M1E)/32!P:'!T97-T7V9K+"!P:'!T97-T)PH@("`@("`@("`@("`@("`@("`@
M+B`G(%=(15)%('!H<'1E<W0N82`]('!H<'1E<W1?9FLN9FLG.PH@("`@?0H@
M("`@)')E<W5L=&]B:B`])B`D9&)H+3YQ=65R>2@D<75E<GDI.PH@("`@<F5T
M=7)N("1R97-U;'1O8FH["GT*"@HD97AP96-T960P,2`]("=T86)L92`N+BX@
M;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN86UE(#T^(&$*='EP92`N+BX@;6%T
M8VAE9"!E>'!E8W1E9"!V86QU90IL96X@+BXN(&UA=&-H960@97AP96-T960@
M=F%L=64*9FQA9W,@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*)SL*"B1E
M>'!E8W1E9#`R(#T@)W1A8FQE("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M"FYA;64@/3X@9FL*='EP92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IL
M96X@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*9FQA9W,@+BXN(&UA=&-H
M960@97AP96-T960@=F%L=64*)SL*"B1E>'!E8W1E9#`S(#T@)W1A8FQE("XN
M+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA;64@/3X@8PIT>7!E("XN+B!M
M871C:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E
M9"!V86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90HG.PH*
M)&5X<&5C=&5D,#0@/2`G=&%B;&4@+BXN(&UA=&-H960@97AP96-T960@=F%L
M=64*;F%M92`]/B!D"G1Y<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*
M;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C
M:&5D(&5X<&5C=&5D('9A;'5E"B<["@HD97AP96-T960P-2`]("=T86)L92`N
M+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN86UE(#T^(&4*='EP92`N+BX@
M;6%T8VAE9"!E>'!E8W1E9"!V86QU90IL96X@+BXN(&UA=&-H960@97AP96-T
M960@=F%L=64*9FQA9W,@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*)SL*
M"B1E>'!E8W1E9#`V(#T@)W1A8FQE("XN+B!M871C:&5D(&5X<&5C=&5D('9A
M;'5E"FYA;64@/3X@9@IT>7!E("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G<R`N+BX@;6%T
M8VAE9"!E>'!E8W1E9"!V86QU90HG.PH*)&5X<&5C=&5D,3`@/2`G=&%B;&4@
M+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;F%M92`]/B!D"G1Y<&4@+BXN
M(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"B<[
M"@H*"G!R:6YT(")<;CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/5QN(CL*<')I;G0@(E!A<W-I;F<@<F5S=6QT($]"2D5#5"!T
M;R!M971H;V0@:6X@1$)?/'1Y<&4^+EQN(CL*<')I;G0@(D]U='!U="`](&1E
M9F%U;'0N7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM7&XB.PHD<F5S=6QT;V)J(#TF(')U;E%U97)Y*"D[
M"B1A<G)A>2`]("1D8F@M/G1A8FQE26YF;R@D<F5S=6QT;V)J*3L*"G!R:6YT
M(")<;F-O;'5M;B`P.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87DL("1E
M>'!E8W1E9#`Q+"`P*3L*"G!R:6YT(")<;F-O;'5M;B`Y.EQN(CL*97AA;6EN
M94%R<F%Y1&%T82@D87)R87DL("1E>'!E8W1E9#$P+"`Y*3L*"@IP<FEN="`B
M7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<
M;B(["G!R:6YT(")087-S:6YG(')E<W5L="!)1"!T;R!M971H;V0@:6X@1$)?
M/'1Y<&4^+EQN(CL*<')I;G0@(D]U='!U="`]($1"7U1!0DQ%24Y&3U]/4D1%
M4BY<;B(["G!R:6YT("(M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2U<;B(["B1R97-U;'1O8FH@/28@<G5N475E<GDH*3L*)&%R
M<F%Y(#T@)&1B:"T^=&%B;&5);F9O*"1R97-U;'1O8FHM/G)E<W5L="P@1$)?
M5$%"3$5)3D9/7T]21$52*3L*"G!R:6YT(")<;F-O;'5M;B`P.EQN(CL*97AA
M;6EN94%R<F%Y1&%T82@D87)R87DL("1E>'!E8W1E9#`Q+"`P*3L*"G!R:6YT
M(")<;F-O;'5M;B`S.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87DL("1E
M>'!E8W1E9#`T+"`S*3L*"G!R:6YT(")<;FYU;5]F:65L9',Z("(["FEF("@D
M<75I<FMS6R1Q=6ER:U]K97E=6R=H86YD;&5S7W)E<W5L=',G72`F)B`D87)R
M87E;)VYU;5]F:65L9',G72`]/2`Q,"D@>PH@("`@<')I;G0@(FUA=&-H960@
M97AP96-T960@<F5S=6QT7&XB.PI](&5L<V5I9B`H1$(Z.FES17)R;W(H)&%R
M<F%Y*2`F)B`D87)R87DM/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U1?0T%0
M04),12D@>PH@("`@<')I;G0@(FUA=&-H960@97AP96-T960@<F5S=6QT7&XB
M.PI](&5L<V4@>PH@("`@<')I;G0@(E1H:7,@1$U"4R!D:61N)W0@<')O9'5C
M92!P<F]P97(@<F5S=6QT<UQN(CL*?0H*<')I;G0@(EQN;W)D97(Z7&XB.PII
M9B`H)'%U:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UT@)B8@
M:7-?87)R87DH)&%R<F%Y6R=O<F1E<B==*2D@>PH@("`@)&5X<&5C=&5D(#T@
M)V$@/3X@-@IB(#T^(#<*8R`]/B`X"F0@/3X@.0IE(#T^(#0*9B`]/B`U"F9K
M(#T^(#$*)SL*("`@(&MS;W)T*"1A<G)A>5LG;W)D97(G72D["B`@("!E>&%M
M:6YE07)R87E$871A*"1A<G)A>5LG;W)D97(G72P@)&5X<&5C=&5D*3L*?2!E
M;'-E:68@*$1".CII<T5R<F]R*"1A<G)A>2D@)B8@)&%R<F%Y+3YG971#;V1E
M*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@('!R:6YT(")M871C
M:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")4
M:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O<&5R(')E<W5L='-<;B(["GT*
M"@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]7&XB.PIP<FEN="`B4&%S<VEN9R!$0E]404),14E.1D]?3U)$
M15)404),12!T;R!M971H;V0@:6X@1$)?<F5S=6QT+EQN(CL*<')I;G0@(D]U
M='!U="`]($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%+EQN(CL*<')I;G0@(BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+5QN(CL*
M)')E<W5L=&]B:B`])B!R=6Y1=65R>2@I.PHD87)R87D@/2`D<F5S=6QT;V)J
M+3YT86)L94EN9F\H1$)?5$%"3$5)3D9/7T]21$525$%"3$4I.PHO+R!&<F5E
M('1H:7,@=&\@:V5E<"!I;G1E<F)A<V4@:&%P<'DN"B1R97-U;'1O8FHM/F9R
M964H*3L*"G!R:6YT(")<;F-O;'5M;B`P.EQN(CL*97AA;6EN94%R<F%Y1&%T
M82@D87)R87DL("1E>'!E8W1E9#`Q+"`P*3L*"G!R:6YT(")<;F-O;'5M;B`S
M.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87DL("1E>'!E8W1E9#`T+"`S
M*3L*"G!R:6YT(")<;FYU;5]F:65L9',Z("(["FEF("@D<75I<FMS6R1Q=6ER
M:U]K97E=6R=H86YD;&5S7W)E<W5L=',G72`F)B`D87)R87E;)VYU;5]F:65L
M9',G72`]/2`Q,"D@>PH@("`@<')I;G0@(FUA=&-H960@97AP96-T960@<F5S
M=6QT7&XB.PI](&5L<V5I9B`H1$(Z.FES17)R;W(H)&%R<F%Y*2`F)B`D87)R
M87DM/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U1?0T%004),12D@>PH@("`@
M<')I;G0@(FUA=&-H960@97AP96-T960@<F5S=6QT7&XB.PI](&5L<V4@>PH@
M("`@<')I;G0@(E1H:7,@1$U"4R!D:61N)W0@<')O9'5C92!P<F]P97(@<F5S
M=6QT<UQN(CL*?0H*"G!R:6YT("=O<F1E<G1A8FQE6W!H<'1E<W1=.B`G.PHD
M97AP96-T960@/2`G82`]/B`V"F(@/3X@-PIC(#T^(#@*9"`]/B`Y"B<["FEF
M("@D<75I<FMS6R1Q=6ER:U]K97E=6R=H86YD;&5S7W)E<W5L=',G70H@("`@
M)B8@:7-S970H)&%R<F%Y6R=O<F1E<G1A8FQE)UU;)W!H<'1E<W0G72DI('L*
M("`@("1A8W1U86P@/2!R971U<FY!<G)A>41A=&$H)&%R<F%Y6R=O<F1E<G1A
M8FQE)UU;)W!H<'1E<W0G72D["GT@96QS92!["B`@("`D86-T=6%L(#T@)R<[
M"GT*:68@*"1A8W1U86P@/3T@)&5X<&5C=&5D*2!["B`@("!P<FEN="`B;6%T
M8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["GT@96QS92!["B`@("!I9B`H*"1Q
M=6ER:W-;)'%U:7)K7VME>5U;)V9I;F1S7W1A8FQE)UT@/3T](&9A;'-E(`H@
M("`@("`@('Q\($1".CII<T5R<F]R*"1A<G)A>2D@)B8@)&%R<F%Y+3YG971#
M;V1E*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I"B`@("`@("`@)B8@)&%C
M='5A;"`]/2`G)RD@>PH@("`@("`@('!R:6YT(")M871C:&5D(&5X<&5C=&5D
M(')E<W5L=%QN(CL*("`@('T@96QS92!["B`@("`@("`@<')I;G0@(D1)1$XG
M5"!M871C:"!E>'!E8W1E9"!V86QU97,N+BY<;B(["B`@("`@("`@<')I;G0@
M(GY^?GY^?GY^7&Y%>'!E8W1E9#I<;B1E>'!E8W1E9%QN(CL*("`@("`@("!P
M<FEN="`B?GY^?EQN06-T=6%L.EQN)&%C='5A;%QN?GY^?GY^?GY<;EQN(CL*
M("`@('T*?0H*"G!R:6YT("=O<F1E<G1A8FQE6W!H<'1E<W1?9FM=.B`G.PHD
M97AP96-T960@/2`G82`]/B`P"F9K(#T^(#$*8R`]/B`R"F0@/3X@,PIE(#T^
M(#0*9B`]/B`U"B<["FEF("@D<75I<FMS6R1Q=6ER:U]K97E=6R=H86YD;&5S
M7W)E<W5L=',G70H@("`@)B8@:7-S970H)&%R<F%Y6R=O<F1E<G1A8FQE)UU;
M)W!H<'1E<W1?9FLG72DI('L*("`@("1A8W1U86P@/2!R971U<FY!<G)A>41A
M=&$H)&%R<F%Y6R=O<F1E<G1A8FQE)UU;)W!H<'1E<W1?9FLG72D["GT@96QS
M92!["B`@("`D86-T=6%L(#T@)R<["GT*:68@*"1A8W1U86P@/3T@)&5X<&5C
M=&5D*2!["B`@("!P<FEN="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B([
M"GT@96QS92!["B`@("!I9B`H*"1Q=6ER:W-;)'%U:7)K7VME>5U;)V9I;F1S
M7W1A8FQE)UT@/3T](&9A;'-E(`H@("`@("`@('Q\($1".CII<T5R<F]R*"1A
M<G)A>2D@)B8@)&%R<F%Y+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]47T-!
M4$%"3$4I"B`@("`@("`@)B8@)&%C='5A;"`]/2`G)RD@>PH@("`@("`@('!R
M:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*("`@('T@96QS92![
M"B`@("`@("`@<')I;G0@(D1)1$XG5"!M871C:"!E>'!E8W1E9"!V86QU97,N
M+BY<;B(["B`@("`@("`@<')I;G0@(GY^?GY^?GY^7&Y%>'!E8W1E9#I<;B1E
M>'!E8W1E9%QN(CL*("`@("`@("!P<FEN="`B?GY^?EQN06-T=6%L.EQN)&%C
M='5A;%QN?GY^?GY^?GY<;EQN(CL*("`@('T*?0H*"G!R:6YT(")<;CT]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/5QN(CL*<')I
M;G0@(E!A<W-I;F<@5$%"3$4@3D%-12`G<&AP=&5S=%]F:R<@=&\@;65T:&]D
M(&EN($1"7SQD<FEV97(^+EQN(CL*<')I;G0@(D]U='!U="`](&1E9F%U;'0N
M7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM7&XB.PHD87)R87D@/2`D9&)H+3YT86)L94EN9F\H)W!H<'1E
M<W1?9FLG*3L*"G!R:6YT(")<;F-O;'5M;B`P.EQN(CL*97AA;6EN94%R<F%Y
M1&%T82@D87)R87DL("1E>'!E8W1E9#`Q+"`P+"!F86QS92D["@IP<FEN="`B
M7&YC;VQU;6X@,3I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP
M96-T960P,BP@,2P@9F%L<V4I.PH*<')I;G0@(EQN8V]L=6UN(#(Z7&XB.PIE
M>&%M:6YE07)R87E$871A*"1A<G)A>2P@)&5X<&5C=&5D,#,L(#(L(&9A;'-E
M*3L*"G!R:6YT(")<;F-O;'5M;B`S.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D
M87)R87DL("1E>'!E8W1E9#`T+"`S+"!F86QS92D["@IP<FEN="`B7&YC;VQU
M;6X@-#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P
M-2P@-"P@9F%L<V4I.PH*<')I;G0@(EQN8V]L=6UN(#4Z7&XB.PIE>&%M:6YE
M07)R87E$871A*"1A<G)A>2P@)&5X<&5C=&5D,#8L(#4L(&9A;'-E*3L*"@IP
M<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3U<;B(["G!R:6YT(")087-S:6YG(%1!0DQ%($Y!344@)W!H<'1E<W1?
M9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/BY<;B(["G!R:6YT(")/=71P
M=70@/2!$0E]404),14E.1D]?1E5,3"Y<;B(["G!R:6YT("(M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(["B1A<G)A>2`]
M("1D8F@M/G1A8FQE26YF;R@G<&AP=&5S=%]F:R<L($1"7U1!0DQ%24Y&3U]&
M54Q,*3L*"G!R:6YT(")<;F-O;'5M;B`P.EQN(CL*97AA;6EN94%R<F%Y1&%T
M82@D87)R87DL("1E>'!E8W1E9#`Q+"`P+"!F86QS92D["@IP<FEN="`B7&YO
M<F1E<CI<;B(["B1E>'!E8W0@/2=A(#T^(#`*9FL@/3X@,0IC(#T^(#(*9"`]
M/B`S"F4@/3X@-`IF(#T^(#4*)SL*97AA;6EN94%R<F%Y1&%T82@D87)R87E;
M)V]R9&5R)UTL("1E>'!E8W0L(&9A;'-E+"!F86QS92D["@IP<FEN="`B7&YO
M<F1E<G1A8FQE6W!H<'1E<W1?9FM=.EQN(CL*)&5X<&5C="`])V$@/3X@,`IF
M:R`]/B`Q"F,@/3X@,@ID(#T^(#,*92`]/B`T"F8@/3X@-0HG.PIE>&%M:6YE
M07)R87E$871A*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T7V9K)UTL
M("1E>'!E8W0I.PH*"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")087-S:6YG(%1!0DQ%
M($Y!344@)W!H<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/B!!
M1T%)3BY<;B(["G!R:6YT(")/=71P=70@/2!$0E]404),14E.1D]?1E5,3"P@
M;&]W97)C87-I;F<@='5R;F5D(&]F9BY<;B(["G!R:6YT("(M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(["B1D8F@M/G-E
M=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465]!3$P@7B!$
M0E]03U)404))3$E465],3U=%4D-!4T4I.PHD87)R87D@/2`D9&)H+3YT86)L
M94EN9F\H)W!H<'1E<W1?9FLG+"!$0E]404),14E.1D]?1E5,3"D["@HO+R!T
M97-T:6YG(&YO;BUL;W=E<F-A<VEN9R!A8F]V92!T;R!E;G-U<F4@<')O9W)A
M;2!D;V5S;B=T(&1I92X*+R\@;&]W97)C87-E('1H92!N86UE<R!H97)E('1O
M(&5N<W5R92!T97-T('5N:69O<FUI='DN"B1A<G)A>5LP75LG=&%B;&4G72`]
M('-T<G1O;&]W97(H)&%R<F%Y6S!=6R=T86)L92==*3L*)&%R<F%Y6S!=6R=N
M86UE)UT@/2!S=')T;VQO=V5R*"1A<G)A>5LP75LG;F%M92==*3L*"G!R:6YT
M(")<;F-O;'5M;B`P.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87DL(#`L
M(&9A;'-E*3L*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PID<F]P7W1A
M8FQE*"1D8F@L("=P:'!T97-T7V9K)RD["@H_/@HM+4584$5#5"TM"CT]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S:6YG
M(')E<W5L="!/0DI%0U0@=&\@;65T:&]D(&EN($1"7SQT>7!E/BX*3W5T<'5T
M(#T@9&5F875L="X*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM"@IC;VQU;6X@,#H*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*
M"F-O;'5M;B`Y.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H*/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"E!A<W-I;F<@<F5S
M=6QT($E$('1O(&UE=&AO9"!I;B!$0E\\='EP93XN"D]U='!U="`]($1"7U1!
M0DQ%24Y&3U]/4D1%4BX*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"@IC;VQU;6X@,#H*;6%T8VAE9"!E>'!E8W1E9"!R97-U
M;'0*"F-O;'5M;B`S.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H*;G5M7V9I
M96QD<SH@;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"F]R9&5R.@IM871C:&5D
M(&5X<&5C=&5D(')E<W5L=`H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"E!A<W-I;F<@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4@=&\@;65T:&]D(&EN($1"7W)E<W5L="X*3W5T<'5T(#T@1$)?5$%"3$5)
M3D9/7T]21$525$%"3$4N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@<F5S
M=6QT"@IC;VQU;6X@,SH*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"FYU;5]F
M:65L9',Z(&UA=&-H960@97AP96-T960@<F5S=6QT"F]R9&5R=&%B;&5;<&AP
M=&5S=%TZ(&UA=&-H960@97AP96-T960@<F5S=6QT"F]R9&5R=&%B;&5;<&AP
M=&5S=%]F:UTZ(&UA=&-H960@97AP96-T960@<F5S=6QT"@H]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!404),
M12!.04U%("=P:'!T97-T7V9K)R!T;R!M971H;V0@:6X@1$)?/&1R:79E<CXN
M"D]U='!U="`](&1E9F%U;'0N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@
M<F5S=6QT"@IC;VQU;6X@,3H*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"F-O
M;'5M;B`R.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H*8V]L=6UN(#,Z"FUA
M=&-H960@97AP96-T960@<F5S=6QT"@IC;VQU;6X@-#H*;6%T8VAE9"!E>'!E
M8W1E9"!R97-U;'0*"F-O;'5M;B`U.@IM871C:&5D(&5X<&5C=&5D(')E<W5L
M=`H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"E!A<W-I;F<@5$%"3$4@3D%-12`G<&AP=&5S=%]F:R<@=&\@;65T:&]D(&EN
M($1"7SQD<FEV97(^+@I/=71P=70@/2!$0E]404),14E.1D]?1E5,3"X*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@IC;VQU
M;6X@,#H*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"F]R9&5R.@IM871C:&5D
M(&5X<&5C=&5D(')E<W5L=`H*;W)D97)T86)L95MP:'!T97-T7V9K73H*;6%T
M8VAE9"!E>'!E8W1E9"!R97-U;'0*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S:6YG(%1!0DQ%($Y!344@)W!H<'1E
M<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/B!!1T%)3BX*3W5T<'5T
M(#T@1$)?5$%"3$5)3D9/7T953$PL(&QO=V5R8V%S:6YG('1U<FYE9"!O9F8N
M"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*
M8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1$(O=&5S=',O9')I=F5R+S$W<75E<GDN<&AP=```````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#<S,S0`,3`U,34T,S$P-3<`,#(S-C0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ
M<75E<GD*+2U)3DDM+0IE<G)O<E]R97!O<G1I;F<@/2`R,#0W"BTM4TM)4$E&
M+2T*/#]P:'`*"B\J*@H@*B!#86QL<R!T:&4@<75E<GDH*2!M971H;V0@:6X@
M=F%R:6]U<R!W87ES(&%G86EN<W0@86YY($1"35,N"B`J"B`J($!S964@("`@
M("!$0E]C;VUM;VXZ.G%U97)Y*"D*("H@"B`J($!P86-K86=E("!$0@H@*B!`
M=F5R<VEO;B`@)$ED.B`Q-W%U97)Y+G!H<'0L=B`Q+C$S(#(P,#4O,#(O,38@
M,3,Z-30Z-3(@9&%N:65L8R!%>'`@)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*
M("H@0&%U=&AO<B`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`86YA;'ES
M:7-A;F1S;VQU=&EO;G,N8V]M/@H@*B!`:6YT97)N86P*("HO"@IC:&1I<BAD
M:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC
M)SL*"C\^"BTM1DE,12TM"CP_<&AP"@HO+R`D260Z(#$W<75E<GDN<&AP="QV
M(#$N,3,@,C`P-2\P,B\Q-B`Q,SHU-#HU,B!D86YI96QC($5X<"`D"@HO*BH*
M("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@86YD(&UA:V4@=&AE('!H<'1E
M<W0@=&%B;&4N"B`J+PIR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PH*
M"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R+@H@*@H@*B!$
M<F]P<R!T:&4@<&AP=&5S="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M
M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M
M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@
M<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E
M(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I
M('L*("`@(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G
M<&AP=&5S="<I.PH*("`@(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"B1D8F@M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD[
M"@H*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]!4U-/0RD["@H*
M)')E<R`])B`D9&)H+3YQ=65R>2@G1$5,151%($923TT@<&AP=&5S="!72$52
M12!A(#T@,3<G*3L*<')I;G0@)S$I(&1E;&5T93H@)R`N("@D<F5S(#T]/2!$
M0E]/2R`_("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1R97,@/28@)&1B
M:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@*&$L(&(L(&,I(%9!3%5%
M4R`H,3<L("=O;F4G+"`G3VYE)RDB*3L*<')I;G0@)S(I(&EN<V5R=#H@)R`N
M("@D<F5S(#T]/2!$0E]/2R`_("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*
M"B1R97,@/28@)&1B:"T^<75E<GDH)TE.4T525"!)3E1/('!H<'1E<W0@*&$L
M(&(L(&,I(%9!3%5%4R`H/RP@/RP@/RDG+"!A<G)A>2@Q-RP@)W1W;R<L("=4
M=V\G*2D["G!R:6YT("<S*2!I;G-E<G0Z("<@+B`H)')E<R`]/3T@1$)?3TL@
M/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<;B(["@H*)')E<R`])B`D9&)H+3YQ
M=65R>2@G4T5,14-4(&$L(&(@1E)/32!P:'!T97-T(%=(15)%(&$@/2`Q-R<I
M.PHD<F]W(#T@)')E<RT^9F5T8VA2;W<H*3L*<')I;G0@(C0I(&$@/2![)')O
M=ULG82==?2P@8B`]('LD<F]W6R=B)UU]7&XB.PHD<F5S+3YF<F5E*"D[("`O
M+R!K965P(&9B<W%L(&AA<'!Y+@H*)')E<R`])B`D9&)H+3YQ=65R>2@G4T5,
M14-4(&$L(&(@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_)RP@87)R87DH)U1W
M;R<I*3L*)')O=R`]("1R97,M/F9E=&-H4F]W*"D["G!R:6YT("(U*2!A(#T@
M>R1R;W=;)V$G77TL(&(@/2![)')O=ULG8B==?5QN(CL*"@HD87)R87D@/2!A
M<G)A>2@*("`@("=F;V\G(#T^(#$Q+`H@("`@)V)A<B<@/3X@)W1H<F5E)RP*
M("`@("=B87HG(#T^(&YU;&PL"BD["B1R97,@/28@)&1B:"T^<75E<GDH)TE.
M4T525"!)3E1/('!H<'1E<W0@*&$L(&(L(&0I(%9!3%5%4R`H/RP@/RP@/RDG
M+"`D87)R87DI.PIP<FEN="`G-BD@:6YS97)T.B`G("X@*"1R97,@/3T]($1"
M7T]+(#\@)V]K87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*)')E<R`])B`D9&)H
M+3YQ=65R>2@G4T5,14-4(&$L(&(L(&0@1E)/32!P:'!T97-T(%=(15)%(&$@
M/2`_)RP@,3$I.PHD<F]W(#T@)')E<RT^9F5T8VA2;W<H*3L*<')I;G0@(C<I
M(&$@/2![)')O=ULG82==?2P@8B`]('LD<F]W6R=B)UU]+"!D(#T@(CL*:68@
M*"1D8F@M/G!H<'1Y<&4@/3T@)VUS<6PG*2!["B`@("!I9B`H87)R87E?:V5Y
M7V5X:7-T<R@G9"<L("1R;W<I*2!["B`@("`@("`@)'1Y<&4@/2!G971T>7!E
M*"1R;W=;)V0G72D["B`@("`@("`@:68@*"1T>7!E(#T]("=.54Q,)R!\?"`D
M<F]W6R=D)UT@/3T@)R<I('L*("`@("`@("`@("`@<')I;G0@(F=O="!E>'!E
M8W1E9"!V86QU95QN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P
M<FEN="`B15)2.B!E>'!E8W1E9"!D)W,@='EP92!T;R!B92!.54Q,(&)U="!I
M="=S("1T>7!E(&%N9"!T:&4@=F%L=64@:7,@(CL*("`@("`@("`@("`@<')I
M;G0@)')O=ULG9"==("X@(EQN(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@
M("`@("`@("\O(&AT='`Z+R]B=6=S+G!H<"YN970O/VED/3,Q.38P"B`@("`@
M("`@<')I;G0@(E!R:6]R('1O(%!(4"`T+C,N,3$@;W(@-2XP+C0L(%!(4"=S
M(&US<6P@97AT96YS:6]N('-I;&5N=&QY(@H@("`@("`@("`@("`@("X@(B!D
M<F]P<&5D(&-O;'5M;G,@=VET:"!N=6QL('9A;'5E<RX@66]U(&YE960@=&\@
M=7!G<F%D92Y<;B(["B`@("!]"GT@96QS92!["B`@("`D='EP92`](&=E='1Y
M<&4H)')O=ULG9"==*3L*("`@(&EF("@D='EP92`]/2`G3E5,3"<@?'P@)')O
M=ULG9"==(#T]("<G*2!["B`@("`@("`@<')I;G0@(F=O="!E>'!E8W1E9"!V
M86QU95QN(CL*("`@('T@96QS92!["B`@("`@("`@<')I;G0@(D524CH@97AP
M96-T960@9"=S('1Y<&4@=&\@8F4@3E5,3"!B=70@:70G<R`D='EP92!A;F0@
M=&AE('9A;'5E(&ES("(["B`@("`@("`@<')I;G0@)')O=ULG9"==("X@(EQN
M(CL*("`@('T*?0H*"B1R97,@/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-
M('!H<'1E<W0@5TA%4D4@82`](#\G+"!A<G)A>2@Q-RDI.PIP<FEN="`G."D@
M9&5L971E.B`G("X@*"1R97,@/3T]($1"7T]+(#\@)V]K87DG(#H@)V5R<F]R
M)RD@+B`B7&XB.PH*)')E<R`])B`D9&)H+3YQ=65R>2@G1$5,151%($923TT@
M<&AP=&5S="!72$5212!A(#T@/R<L(&%R<F%Y*#`I*3L*<')I;G0@)SDI(&1E
M;&5T92!W:71H(&%R<F%Y*#`I(&%S('!A<F%M.B`G("X@*"1R97,@/3T]($1"
M7T]+(#\@)V]K87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*)')E<R`])B`D9&)H
M+3YQ=65R>2@G1$5,151%($923TT@<&AP=&5S="!72$5212!A(#T@/R<L(#`I
M.PIP<FEN="`G,3`I(&1E;&5T92!W:71H(#`@87,@<&%R86TZ("<@+B`H)')E
M<R`]/3T@1$)?3TL@/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<;B(["@H*)&1B
M:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?
M=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"C\^"BTM15A014-4+2T*,2D@9&5L
M971E.B!O:V%Y"C(I(&EN<V5R=#H@;VMA>0HS*2!I;G-E<G0Z(&]K87D*-"D@
M82`](#$W+"!B(#T@;VYE"C4I(&$@/2`Q-RP@8B`]('1W;PHV*2!I;G-E<G0Z
M(&]K87D*-RD@82`](#$Q+"!B(#T@=&AR964L(&0@/2!G;W0@97AP96-T960@
M=F%L=64*."D@9&5L971E.B!O:V%Y"CDI(&1E;&5T92!W:71H(&%R<F%Y*#`I
M(&%S('!A<F%M.B!O:V%Y"C$P*2!D96QE=&4@=VET:"`P(&%S('!A<F%M.B!O
M:V%Y"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$X9V5T+G!H<'0`
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S8T,#4`,3`U,34T,S$P-3<`,#(S,C8R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M5$535"TM"D1"7V1R:79E<CHZ9V5T"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG
M(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP"@HO*BH*("H@0V%L;',@=&AE(&=E
M="HH*2!M971H;V1S(&EN('9A<FEO=7,@=V%Y<R!A9V%I;G-T(&%N>2!$0DU3
M+@H@*@H@*B!`<V5E($1"7T-O;6UO;CHZ9V5T06QL*"DL($1"7T-O;6UO;CHZ
M9V5T07-S;V,H*2P@1$)?0V]M;6]N.CIG971#;VPH*0H@*B`@("`@($1"7T-O
M;6UO;CHZ9V5T3&ES=$]F*"DL($1"7T-O;6UO;CHZ9V5T3VYE*"DL($1"7T-O
M;6UO;CHZ9V5T4F]W*"D*("H*("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N
M("`D260Z(#$X9V5T+G!H<'0L=B`Q+CD@,C`P-2\P,B\Q-"`R,SHT-SHU-"!D
M86YI96QC($5X<"`D"B`J($!C871E9V]R>2!$871A8F%S90H@*B!`875T:&]R
M("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!A;F%L>7-I<V%N9'-O;'5T
M:6]N<RYC;VT^"B`J($!I;G1E<FYA;`H@*B\*"F-H9&ER*&1I<FYA;64H7U]&
M24Q%7U\I*3L*<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.PH*/SX*+2U&
M24Q%+2T*/#]P:'`*"B\O("1)9#H@,3AG970N<&AP="QV(#$N.2`R,#`U+S`R
M+S$T(#(S.C0W.C4T(&1A;FEE;&,@17AP("0*"B\J*@H@*B!#;VYN96-T('1O
M('1H92!D871A8F%S92!A;F0@;6%K92!T:&4@/&MB9#YP:'!T97-T/"]K8F0^
M('1A8FQE+@H@*B\*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*"@HO
M*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@1')O
M<',@=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S
M<V%G92!A;F0@:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O
M8FIE8W0@("1O("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A
M<W-E9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!0
M14%2.CIS971%<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*7L*
M("`@(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP
M=&5S="<I.PH*("`@(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"B1D8F@M/G-E
M=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["@H*
M)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453("@R+"`G
M='=O)RP@)U1W;R<L("<R,#`R+3`R+3(R)RDB*3L*)&1B:"T^<75E<GDH(DE.
M4T525"!)3E1/('!H<'1E<W0@5D%,5453("@T,BP@)W1H<F5E)RP@)U1H<F5E
M)RP@)S(P,#,M,#,M,C,G*2(I.PH*"G!R:6YT("(]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT
M("=T97-T:6YG(&=E=$]N93H@)SL*)')E="`])B`D9&)H+3YG971/;F4H(E-%
M3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@)U1W;R<B*3L*<')I;G1?
M<B@D<F5T*3L*<')I;G0@(EQN(CL*"G!R:6YT("=T97-T:6YG(&=E=$]N92!W
M:71H('-T<FEN9R!P87)A;7,Z("<["B1R970@/28@)&1B:"T^9V5T3VYE*"=3
M14Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`](#\G+"`G5&AR964G*3L*
M<')I;G1?<B@D<F5T*3L*<')I;G0@(EQN(CL*"G!R:6YT("=T97-T:6YG(&=E
M=$]N92!W:71H(&%R<F%Y('!A<F%M<SH@)SL*)')E="`])B`D9&)H+3YG971/
M;F4H)U-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R<L(&%R<F%Y
M*"=4=V\G*2D["G!R:6YT7W(H)')E="D["G!R:6YT(")<;B(["@IP<FEN="`B
M7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3U<;B(["G!R:6YT(")T97-T:6YG(&=E=%)O=SI<;B(["B1R970@
M/28@)&1B:"T^9V5T4F]W*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@
M8R`]("=4=V\G(BD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G
M9712;W<@=VET:"!N=6QL('!A<F%M<RP@1$)?1D540TA-3T1%7T]21$52140Z
M7&XB.PHD<F5T(#TF("1D8F@M/F=E=%)O=R@B4T5,14-4("H@1E)/32!P:'!T
M97-T(%=(15)%(&,@/2`G5'=O)R(L"B`@("`@("`@;G5L;"P@1$)?1D540TA-
M3T1%7T]21$52140I.PIP<FEN=%]R*"1R970I.PH*+R\@5$A)4R!$3T533B=4
M(%=/4DL@1%5%(%1/($)!0TM705)$4R!#3TU0051)0DE,2519($-205`*+R\@
M<')I;G0@(G1E<W1I;F<@9V5T4F]W('=I=&@@<W1R:6YG('!A<F%M<RP@1$)?
M1D540TA-3T1%7T]21$52140Z7&XB.PHO+R`D<F5T(#TF("1D8F@M/F=E=%)O
M=R@G4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_)RP*+R\@("`@
M("`@("`G5'=O)RP@1$)?1D540TA-3T1%7T]21$52140I.PHO+R!P<FEN=%]R
M*"1R970I.PHO+PHO+R!T97-T:6YG(&=E=%)O=R!W:71H('-T<FEN9R!P87)A
M;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.@HO+R!!<G)A>0HO+R`H"B\O("`@
M("!;,%T@/3X@,@HO+R`@("`@6S%=(#T^('1W;PHO+R`@("`@6S)=(#T^(%1W
M;PHO+R`@("`@6S-=(#T^(#(P,#(M,#(M,C(*+R\@*0H*("`@<')I;G0@(G1E
M<W1I;F<@9V5T4F]W('=I=&@@4D5615)3140@87)G<SH@1$)?1D540TA-3T1%
M7T%34T]#+"!A<G)A>2!P87)A;7,Z7&XB.PH@("`D<F5T(#TF("1D8F@M/F=E
M=%)O=R@G4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_)RP*("`@
M("`@("`@("!$0E]&151#2$U/1$5?05-33T,L(&%R<F%Y*"=4=V\G*2D["B`@
M('!R:6YT7W(H)')E="D["B`@(`H@("!P<FEN="`B=&5S=&EN9R!G9712;W<@
M=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z7&XB.PH@
M("`D<F5T(#TF("1D8F@M/F=E=%)O=R@B4T5,14-4("H@1E)/32!P:'!T97-T
M(%=(15)%(&,@/2`G5'=O)R(L"B`@("`@("`@("`@1$)?1D540TA-3T1%7T%3
M4T]#*3L*("`@<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=%)O
M=R!W:71H(&%R<F%Y('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*
M)')E="`])B`D9&)H+3YG9712;W<H)U-%3$5#5"`J($923TT@<&AP=&5S="!7
M2$5212!C(#T@/R<L"B`@("`@("`@87)R87DH)U1W;R<I+"!$0E]&151#2$U/
M1$5?05-33T,I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T
M4F]W('=I=&@@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4.EQN
M(CL*)')E="`])B`D9&)H+3YG9712;W<H)U-%3$5#5"`J($923TT@<&AP=&5S
M="!72$5212!C(#T@/R<L"B`@("`@("`@87)R87DH)U1W;R<I+"!$0E]&151#
M2$U/1$5?3T)*14-4*3L*<')I;G1?<B@D<F5T*3L*"@IP<FEN="`B7&X]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3U<;B(["G!R:6YT(")T97-T:6YG(&=E=$-O;#I<;B(["B1R970@/28@)&1B
M:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E<W0@3U)$15(@0ED@8B(I
M.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T0V]L(&]N('%U
M97)Y('=I=&@@;F\@<F5C;W)D<SI<;B(["B1R970@/28@)&1B:"T^9V5T0V]L
M*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@82`^(#(P,"<I.PIP<FEN
M=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T0V]L('=I=&@@:6YV86QI
M9"!C;VQU;6X@:60Z7&XB.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*)')E="`])B`D9&)H+3YG971#;VPH)U-%3$5#5"!B
M($923TT@<&AP=&5S="!/4D1%4B!"62!B)RP@,2D["FEF("A$0CHZ:7-%<G)O
M<B@D<F5T*2D@>PH@("`@96-H;R`D<F5T+3YG971-97-S86=E*"D@+B`B7&XB
M.PI](&5L<V4@>PH@("`@<')I;G0@(CX^(%-H;W5L9"!H879E('!R;V1U8V5D
M("=N;R!S=6-H(&9I96QD)R!E<G)O<EQN(CL*?0HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*<')I;G0@(G1E
M<W1I;F<@9V5T0V]L('=I=&@@,2!C;VPZ7&XB.PHD<F5T(#TF("1D8F@M/F=E
M=$-O;"@B4T5,14-4("H@1E)/32!P:'!T97-T($]21$52($)9(&(B+"`Q*3L*
M<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$-O;"!W:71H(&(@
M8V]L.EQN(CL*)')E="`])B`D9&)H+3YG971#;VPH(E-%3$5#5"`J($923TT@
M<&AP=&5S="!/4D1%4B!"62!B(BP@)V(G*3L*<')I;G1?<B@D<F5T*3L*"G!R
M:6YT(")T97-T:6YG(&=E=$-O;"!W:71H(&(@8V]L+"!S8V%L87(@<&%R86US
M.EQN(CL*)')E="`])B`D9&)H+3YG971#;VPH(E-%3$5#5"`J($923TT@<&AP
M=&5S="!72$5212!A(#P@/R!/4D1%4B!"62!B(BP*("`@("`@("`G8B<L(#$P
M,"D["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971#;VP@=VET
M:"!B(&-O;"P@87)R87D@<&%R86US.EQN(CL*)')E="`])B`D9&)H+3YG971#
M;VPH(E-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!A(#P@/R!/4D1%4B!"
M62!B(BP*("`@("`@("`G8B<L(&%R<F%Y*#$P,"DI.PIP<FEN=%]R*"1R970I
M.PH*"G!R:6YT(")<;CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/5QN(CL*<')I;G0@(G1E<W1I;F<@9V5T07-S
M;V,Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@
M8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#$P,"!/4D1%4B!"62!B)RD["G!R
M:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H(&9A
M;'-E(&9O<F-E+"!N=6QL('!A<F%M<RP@1$)?1D540TA-3T1%7T]21$52140Z
M7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*")314Q%0U0@82P@8BP@8R!&
M4D]-('!H<'1E<W0@5TA%4D4@82`\(#$P,"!/4D1%4B!"62!B(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@9F%L<V4L(&YU;&PL($1"7T9%5$-(34]$15]/
M4D1%4D5$*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$%S
M<V]C('=I=&@@9F%L<V4@9F]R8V4L('-C86QA<B!P87)A;7,L($1"7T9%5$-(
M34]$15]!4U-/0SI<;B(["B1R970@/28@)&1B:"T^9V5T07-S;V,H)U-%3$5#
M5"!A+"!B+"!C($923TT@<&AP=&5S="!72$5212!A(#P@/R!/4D1%4B!"62!B
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L(#$P,"P@1$)?1D54
M0TA-3T1%7T%34T]#*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG
M(&=E=$%S<V]C('=I=&@@='=O(&-O;',L(&9A;'-E(&9O<F-E+"!S8V%L87(@
M<&%R86US+"!$0E]&151#2$U/1$5?05-33T,Z7&XB.PHD<F5T(#TF("1D8F@M
M/F=E=$%S<V]C*"=314Q%0U0@82P@8B!&4D]-('!H<'1E<W0@5TA%4D4@82`\
M(#\@3U)$15(@0ED@8B<L"B`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E
M+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP
M<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H('1W;R!C;VQS+"!T<G5E(&9O
M<F-E+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,Z7&XB.PHD
M<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8B!&4D]-('!H<'1E
M<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@('1R=64L(#$P,"P@1$)?1D540TA-3T1%7T%34T]#*3L*<')I;G1?
M<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@
M9F]R8V4L('-C86QA<B!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0RP@=')U
M92!G<F]U<#I<;B(["B1R970@/28@)&1B:"T^9V5T07-S;V,H)U-%3$5#5"!A
M+"!B+"!C($923TT@<&AP=&5S="!72$5212!A(#P@/R!/4D1%4B!"62!B)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L(#$P,"P@1$)?1D540TA-
M3T1%7T%34T]#+"!T<G5E*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T
M:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@9F]R8V4L(&%R<F%Y('!A<F%M<RP@
M1$)?1D540TA-3T1%7T]"2D5#5#I<;B(["B1R970@/28@)&1B:"T^9V5T07-S
M;V,H)U-%3$5#5"!A+"!B+"!C($923TT@<&AP=&5S="!72$5212!A(#P@/R!/
M4D1%4B!"62!B)RP*("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L(&%R
M<F%Y*#$P,"DL($1"7T9%5$-(34]$15]/0DI%0U0I.PIP<FEN=%]R*"1R970I
M.PH*<')I;G0@(G1E<W1I;F<@9V5T07-S;V,@=VET:"!T<G5E(&9O<F-E+"!A
M<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]/0DI%0U0L('1R=64@9W)O=7`Z
M7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@8R!&
M4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@(&9A;'-E+"!A<G)A>2@Q,#`I+"!$0E]&151#2$U/
M1$5?3T)*14-4+"!T<G5E*3L*<')I;G1?<B@D<F5T*3L*"@IP<FEN="`B7&X]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3U<;B(["G!R:6YT(")T97-T:6YG(&=E=$%L;#I<;B(["B1R970@/28@
M)&1B:"T^9V5T06QL*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`]
M("=4=V\G($]2(&,@/2`G5&AR964G(BD["G!R:6YT7W(H)')E="D["@IP<FEN
M="`B=&5S=&EN9R!G971!;&P@=VET:"!N=6QL('!A<F%M<RP@1$)?1D540TA-
M3T1%7T]21$52140Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%L;"@B4T5,14-4
M("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`G5'=O)R!/4B!C(#T@)U1H<F5E
M)R(L"B`@("`@("`@;G5L;"P@1$)?1D540TA-3T1%7T]21$52140I.PIP<FEN
M=%]R*"1R970I.PH*+R\@5$A)4R!$3T533B=4(%=/4DL@1%5%(%1/($)!0TM7
M05)$4R!#3TU0051)0DE,2519($-205`*+R\@<')I;G0@(G1E<W1I;F<@9V5T
M06QL('=I=&@@<W1R:6YG('!A<F%M<RP@1$)?1D540TA-3T1%7T]21$52140Z
M7&XB.PHO+R`D<F5T(#TF("1D8F@M/F=E=$%L;"@G4T5,14-4("H@1E)/32!P
M:'!T97-T(%=(15)%(&,@/2`_)RP*+R\@("`@("`@("`G5'=O)RP@1$)?1D54
M0TA-3T1%7T]21$52140I.PHO+R!P<FEN=%]R*"1R970I.PHO+PHO+R!T97-T
M:6YG(&=E=$%L;"!W:71H('-T<FEN9R!P87)A;7,L($1"7T9%5$-(34]$15]/
M4D1%4D5$.@HO+R!!<G)A>0HO+R`H"B\O("`@("!;,%T@/3X@,@HO+R`@("`@
M6S%=(#T^('1W;PHO+R`@("`@6S)=(#T^(%1W;PHO+R`@("`@6S-=(#T^(#(P
M,#(M,#(M,C(*+R\@*0H*("`@<')I;G0@(G1E<W1I;F<@9V5T06QL('=I=&@@
M4D5615)3140@87)G<SH@1$)?1D540TA-3T1%7T%34T]#+"!A<G)A>2!P87)A
M;7,Z7&XB.PH@("`D<F5T(#TF("1D8F@M/F=E=$%L;"@G4T5,14-4("H@1E)/
M32!P:'!T97-T(%=(15)%(&,@/2`_($]2(&,@/2`_($]21$52($)9(&,G+`H@
M("`@("`@("`@($1"7T9%5$-(34]$15]!4U-/0RP@87)R87DH)U1W;R<L("=4
M:')E92<I*3L*("`@<')I;G1?<B@D<F5T*3L*("`@"B`@('!R:6YT(")T97-T
M:6YG(&=E=$%L;"!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%5$-(34]$15]!
M4U-/0SI<;B(["B`@("1R970@/28@)&1B:"T^9V5T06QL*")314Q%0U0@*B!&
M4D]-('!H<'1E<W0@5TA%4D4@8R`]("=4=V\G($]2(&,@/2`G5&AR964G(BP*
M("`@("`@("`@("!$0E]&151#2$U/1$5?05-33T,I.PH@("!P<FEN=%]R*"1R
M970I.PH*<')I;G0@(G1E<W1I;F<@9V5T06QL('=I=&@@87)R87D@<&%R86US
M+"!$0E]&151#2$U/1$5?05-33T,Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%L
M;"@G4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_($]2(&,@/2`_
M($]21$52($)9(&,G+`H@("`@("`@(&%R<F%Y*"=4=V\G+"`G5&AR964G*2P@
M1$)?1D540TA-3T1%7T%34T]#*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T
M97-T:6YG(&=E=$%L;"!W:71H(&%R<F%Y('!A<F%M<RP@1$)?1D540TA-3T1%
M7T]"2D5#5#I<;B(["B1R970@/28@)&1B:"T^9V5T06QL*"=314Q%0U0@*B!&
M4D]-('!H<'1E<W0@5TA%4D4@8R`](#\@3U(@8R`](#\@3U)$15(@0ED@8R<L
M"B`@("`@("`@87)R87DH)U1W;R<L("=4:')E92<I+"!$0E]&151#2$U/1$5?
M3T)*14-4*3L*<')I;G1?<B@D<F5T*3L*"@IP<FEN="`B7&X]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B([
M"G!R:6YT("=T97-T:6YG(&=E=$]N92!W:71H(&YU;&P@=F%L=64@:6X@8V]L
M=6UN.B`G.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q5
M15,@*#DL("=N:6YE)RP@)R<L($Y53$PI(BD["B1R970@/28@)&1B:"T^9V5T
M3VYE*"=314Q%0U0@9"!&4D]-('!H<'1E<W0@5TA%4D4@82`](#DG*3L*:68@
M*"1R970@/3T]("<G*2!["B`@("!P<FEN="`B;6%T8VAE<R!E>'!E8W1E9"!R
M97-U;'1<;B(["GT@96QS92!["B`@("!I9B`H)&1B:"T^<&AP='EP92`]/2`G
M;7-Q;"<I('L*("`@("`@("!I9B`H9V5T='EP92@D<F5T*2`]/2`G3E5,3"<I
M('L*("`@("`@("`@("`@+R\@;7-Q;"!D;V5S;B=T(&5V96X@<F5T=7)N('1H
M92!C;VQU;6XN("!*;WDA(#HI"B`@("`@("`@("`@("\O(&AT='`Z+R]B=6=S
M+G!H<"YN970O/VED/3,Q.38P"B`@("`@("`@("`@('!R:6YT(")M871C:&5S
M(&5X<&5C=&5D(')E<W5L=%QN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!P<FEN="`B5T]7+"!M4U%,(&YO=R!R971U<FYS(&-O;'5M;G,@=&AA
M="!H879E($Y53$Q3(&EN('1H96U<;B(["B`@("`@("`@?0H@("`@?2!E;'-E
M('L*("`@("`@("!P<FEN="`G='EP93TG("X@9V5T='EP92@D<F5T*2`N("(L
M('9A;'5E/21R971<;B(["B`@("!]"GT*"G!R:6YT("=T97-T:6YG(&=E=$]N
M92!W:71H(&5M<'1Y('-T<FEN9R!I;B!C;VQU;6XZ("<["B1R970@/28@)&1B
M:"T^9V5T3VYE*"=314Q%0U0@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`](#DG
M*3L*:68@*"1R970@/3T]("<G*2!["B`@("!P<FEN="`B96UP='D@<W1R:6YG
M7&XB.PI](&5L<V4@>PH@("`@<')I;G0@)W1Y<&4])R`N(&=E='1Y<&4H)')E
M="D@+B`B+"!V86QU93TD<F5T7&XB.PI]"@H*<')I;G0@(EQN/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB
M.PH*"F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"@H_/@HM+4584$5#
M5"TM"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0IT97-T:6YG(&=E=$]N93H@,@IT97-T:6YG(&=E=$]N92!W
M:71H('-T<FEN9R!P87)A;7,Z(#0R"G1E<W1I;F<@9V5T3VYE('=I=&@@87)R
M87D@<&%R86US.B`R"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T*=&5S=&EN9R!G9712;W<Z"D%R<F%Y"B@*
M("`@(%LP72`]/B`R"B`@("!;,5T@/3X@='=O"B`@("!;,ET@/3X@5'=O"B`@
M("!;,UT@/3X@,C`P,BTP,BTR,@HI"G1E<W1I;F<@9V5T4F]W('=I=&@@;G5L
M;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.@I!<G)A>0HH"B`@("!;
M,%T@/3X@,@H@("`@6S%=(#T^('1W;PH@("`@6S)=(#T^(%1W;PH@("`@6S-=
M(#T^(#(P,#(M,#(M,C(**0IT97-T:6YG(&=E=%)O=R!W:71H(%)%5D524T5$
M(&%R9W,Z($1"7T9%5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.@I!<G)A
M>0HH"B`@("!;85T@/3X@,@H@("`@6V)=(#T^('1W;PH@("`@6V-=(#T^(%1W
M;PH@("`@6V1=(#T^(#(P,#(M,#(M,C(**0IT97-T:6YG(&=E=%)O=R!W:71H
M(%)%5D524T5$(&%R9W,Z($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@
M("`@6V%=(#T^(#(*("`@(%MB72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@
M(%MD72`]/B`R,#`R+3`R+3(R"BD*=&5S=&EN9R!G9712;W<@=VET:"!A<G)A
M>2!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6V%=
M(#T^(#(*("`@(%MB72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@(%MD72`]
M/B`R,#`R+3`R+3(R"BD*=&5S=&EN9R!G9712;W<@=VET:"!A<G)A>2!P87)A
M;7,L($1"7T9%5$-(34]$15]/0DI%0U0Z"G-T9$-L87-S($]B:F5C=`HH"B`@
M("!;85T@/3X@,@H@("`@6V)=(#T^('1W;PH@("`@6V-=(#T^(%1W;PH@("`@
M6V1=(#T^(#(P,#(M,#(M,C(**0H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"G1E<W1I;F<@9V5T0V]L.@I!
M<G)A>0HH"B`@("!;,%T@/3X@-#(*("`@(%LQ72`]/B`T,@H@("`@6S)=(#T^
M(#(**0IT97-T:6YG(&=E=$-O;"!O;B!Q=65R>2!W:71H(&YO(')E8V]R9',Z
M"D%R<F%Y"B@**0IT97-T:6YG(&=E=$-O;"!W:71H(&EN=F%L:60@8V]L=6UN
M(&ED.@I$0B!%<G)O<CH@;F\@<W5C:"!F:65L9`IT97-T:6YG(&=E=$-O;"!W
M:71H(#$@8V]L.@I!<G)A>0HH"B`@("!;,%T@/3X@8FEN9PH@("`@6S%=(#T^
M('1H<F5E"B`@("!;,ET@/3X@='=O"BD*=&5S=&EN9R!G971#;VP@=VET:"!B
M(&-O;#H*07)R87D**`H@("`@6S!=(#T^(&)I;F<*("`@(%LQ72`]/B!T:')E
M90H@("`@6S)=(#T^('1W;PHI"G1E<W1I;F<@9V5T0V]L('=I=&@@8B!C;VPL
M('-C86QA<B!P87)A;7,Z"D%R<F%Y"B@*("`@(%LP72`]/B!B:6YG"B`@("!;
M,5T@/3X@=&AR964*("`@(%LR72`]/B!T=V\**0IT97-T:6YG(&=E=$-O;"!W
M:71H(&(@8V]L+"!A<G)A>2!P87)A;7,Z"D%R<F%Y"B@*("`@(%LP72`]/B!B
M:6YG"B`@("!;,5T@/3X@=&AR964*("`@(%LR72`]/B!T=V\**0H*/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"G1E<W1I;F<@9V5T07-S;V,Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@07)R87D*
M("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!T:')E90H@("`@("`@("`@
M("!;,5T@/3X@5&AR964*("`@("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@
M("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@='=O"B`@("`@("`@("`@(%LQ
M72`]/B!4=V\*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!F
M86QS92!F;W)C92P@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$
M.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@
M("`@("!;,%T@/3X@=&AR964*("`@("`@("`@("`@6S%=(#T^(%1H<F5E"B`@
M("`@("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@
M("`@6S!=(#T^('1W;PH@("`@("`@("`@("!;,5T@/3X@5'=O"B`@("`@("`@
M*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@9F]R8V4L('-C86QA
M<B!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6S0R
M72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6V)=(#T^('1H<F5E
M"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("D*"B`@("!;,ET@
M/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MB72`]/B!T=V\*("`@
M("`@("`@("`@6V-=(#T^(%1W;PH@("`@("`@("D*"BD*=&5S=&EN9R!G971!
M<W-O8R!W:71H('1W;R!C;VQS+"!F86QS92!F;W)C92P@<V-A;&%R('!A<F%M
M<RP@1$)?1D540TA-3T1%7T%34T]#.@I!<G)A>0HH"B`@("!;-#)=(#T^('1H
M<F5E"B`@("!;,ET@/3X@='=O"BD*=&5S=&EN9R!G971!<W-O8R!W:71H('1W
M;R!C;VQS+"!T<G5E(&9O<F-E+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/
M1$5?05-33T,Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@07)R87D*("`@("`@("`H
M"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@("`@("D*"B`@("!;,ET@
M/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MB72`]/B!T=V\*("`@
M("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!F86QS92!F;W)C92P@
M<V-A;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#+"!T<G5E(&=R;W5P
M.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@
M("`@("!;,%T@/3X@07)R87D*("`@("`@("`@("`@("`@("@*("`@("`@("`@
M("`@("`@("`@("!;8ET@/3X@8FEN9PH@("`@("`@("`@("`@("`@("`@(%MC
M72`]/B!4:&ES(&ES(&$@=&5S=`H@("`@("`@("`@("`@("`@*0H*("`@("`@
M("`@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@("`@("`@("`H"B`@("`@("`@
M("`@("`@("`@("`@6V)=(#T^('1H<F5E"B`@("`@("`@("`@("`@("`@("`@
M6V-=(#T^(%1H<F5E"B`@("`@("`@("`@("`@("`I"@H@("`@("`@("D*"B`@
M("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!!
M<G)A>0H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@(%MB
M72`]/B!T=V\*("`@("`@("`@("`@("`@("`@("!;8UT@/3X@5'=O"B`@("`@
M("`@("`@("`@("`I"@H@("`@("`@("D*"BD*=&5S=&EN9R!G971!<W-O8R!W
M:71H(&9A;'-E(&9O<F-E+"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]/
M0DI%0U0Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@<W1D0VQA<W,@3V)J96-T"B`@
M("`@("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@("`@("`@6V)=
M(#T^('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("D*
M"B`@("!;,ET@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@*`H@("`@("`@
M("`@("!;85T@/3X@,@H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@
M("`@(%MC72`]/B!4=V\*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@
M=VET:"!T<G5E(&9O<F-E+"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]/
M0DI%0U0L('1R=64@9W)O=7`Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@07)R87D*
M("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!S=&1#;&%S<R!/8FIE8W0*
M("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@("`@("!;85T@/3X@
M-#(*("`@("`@("`@("`@("`@("`@("!;8ET@/3X@8FEN9PH@("`@("`@("`@
M("`@("`@("`@(%MC72`]/B!4:&ES(&ES(&$@=&5S=`H@("`@("`@("`@("`@
M("`@*0H*("`@("`@("`@("`@6S%=(#T^('-T9$-L87-S($]B:F5C=`H@("`@
M("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@(%MA72`]/B`T,@H@
M("`@("`@("`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@("`@("`@("`@
M("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("`@("`@("`@*0H*("`@("`@
M("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;
M,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@("`@("`@("`H"B`@("`@
M("`@("`@("`@("`@("`@6V%=(#T^(#(*("`@("`@("`@("`@("`@("`@("!;
M8ET@/3X@='=O"B`@("`@("`@("`@("`@("`@("`@6V-=(#T^(%1W;PH@("`@
M("`@("`@("`@("`@*0H*("`@("`@("`I"@HI"@H]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*=&5S=&EN9R!G
M971!;&PZ"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A>0H@("`@("`@("@*("`@
M("`@("`@("`@6S!=(#T^(#(*("`@("`@("`@("`@6S%=(#T^('1W;PH@("`@
M("`@("`@("!;,ET@/3X@5'=O"B`@("`@("`@("`@(%LS72`]/B`R,#`R+3`R
M+3(R"B`@("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@
M("`@("`@("`@6S!=(#T^(#0R"B`@("`@("`@("`@(%LQ72`]/B!T:')E90H@
M("`@("`@("`@("!;,ET@/3X@5&AR964*("`@("`@("`@("`@6S-=(#T^(#(P
M,#,M,#,M,C,*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T06QL('=I=&@@;G5L
M;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.@I!<G)A>0HH"B`@("!;
M,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B`R"B`@
M("`@("`@("`@(%LQ72`]/B!T=V\*("`@("`@("`@("`@6S)=(#T^(%1W;PH@
M("`@("`@("`@("!;,UT@/3X@,C`P,BTP,BTR,@H@("`@("`@("D*"B`@("!;
M,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B`T,@H@
M("`@("`@("`@("!;,5T@/3X@=&AR964*("`@("`@("`@("`@6S)=(#T^(%1H
M<F5E"B`@("`@("`@("`@(%LS72`]/B`R,#`S+3`S+3(S"B`@("`@("`@*0H*
M*0IT97-T:6YG(&=E=$%L;"!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%5$-(
M34]$15]!4U-/0RP@87)R87D@<&%R86US.@I!<G)A>0HH"B`@("!;,%T@/3X@
M07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`T,@H@("`@("`@
M("`@("!;8ET@/3X@=&AR964*("`@("`@("`@("`@6V-=(#T^(%1H<F5E"B`@
M("`@("`@("`@(%MD72`]/B`R,#`S+3`S+3(S"B`@("`@("`@*0H*("`@(%LQ
M72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6V%=(#T^(#(*("`@
M("`@("`@("`@6V)=(#T^('1W;PH@("`@("`@("`@("!;8UT@/3X@5'=O"B`@
M("`@("`@("`@(%MD72`]/B`R,#`R+3`R+3(R"B`@("`@("`@*0H**0IT97-T
M:6YG(&=E=$%L;"!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%5$-(34]$15]!
M4U-/0SH*07)R87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;85T@/3X@,@H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@
M("`@("`@(%MC72`]/B!4=V\*("`@("`@("`@("`@6V1=(#T^(#(P,#(M,#(M
M,C(*("`@("`@("`I"@H@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;85T@/3X@-#(*("`@("`@("`@("`@6V)=(#T^('1H<F5E"B`@
M("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("`@("!;9%T@/3X@,C`P
M,RTP,RTR,PH@("`@("`@("D*"BD*=&5S=&EN9R!G971!;&P@=VET:"!A<G)A
M>2!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6S!=
M(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@
M("`@("`@("`@6V)=(#T^('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E
M90H@("`@("`@("`@("!;9%T@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"B`@
M("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`R
M"B`@("`@("`@("`@(%MB72`]/B!T=V\*("`@("`@("`@("`@6V-=(#T^(%1W
M;PH@("`@("`@("`@("!;9%T@/3X@,C`P,BTP,BTR,@H@("`@("`@("D*"BD*
M=&5S=&EN9R!G971!;&P@=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$
M15]/0DI%0U0Z"D%R<F%Y"B@*("`@(%LP72`]/B!S=&1#;&%S<R!/8FIE8W0*
M("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`T,@H@("`@("`@("`@("!;
M8ET@/3X@=&AR964*("`@("`@("`@("`@6V-=(#T^(%1H<F5E"B`@("`@("`@
M("`@(%MD72`]/B`R,#`S+3`S+3(S"B`@("`@("`@*0H*("`@(%LQ72`]/B!S
M=&1#;&%S<R!/8FIE8W0*("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`R
M"B`@("`@("`@("`@(%MB72`]/B!T=V\*("`@("`@("`@("`@6V-=(#T^(%1W
M;PH@("`@("`@("`@("!;9%T@/3X@,C`P,BTP,BTR,@H@("`@("`@("D*"BD*
M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/0IT97-T:6YG(&=E=$]N92!W:71H(&YU;&P@=F%L=64@:6X@8V]L
M=6UN.B!M871C:&5S(&5X<&5C=&5D(')E<W5L=`IT97-T:6YG(&=E=$]N92!W
M:71H(&5M<'1Y('-T<FEN9R!I;B!C;VQU;6XZ(&5M<'1Y('-T<FEN9PH*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q.6=E=&QI
M<W1O9BYP:'!T`````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V,3<R`#$P-3$U-#,Q,#4W`#`R
M-#4P,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+51%4U0M+0I$0E]D<FEV97(Z.F=E=$QI<W1/9@HM+4E.22TM"F5R<F]R
M7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N
M86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@
M/SX*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN
M8R<["@HO*@H@*B!!;B!A<G)A>2!W:71H(&ME>7,@8V]N=&%I;FEN9R!T:&4@
M)'1Y<&4@=&\@8F4@<&%S<V5D('1O('1H92!G971,:7-T3V8H*0H@*B!M971H
M;V0N("!4:&4@=F%L=65S(&]F('1H92!M86EN(&%R<F%Y(&%R92!A('-U8BUA
M<G)A>2!T:&%T(&AA<R!K97ES"B`J(&QI<W1I;F<@=&AE('!H<'1Y<&4@86YD
M(&1B<WEN=&%X(&]F(&5A8V@@9')I=F5R(&%N9"!V86QU97,@;V8@=&AE"B`J
M(')E<W5L="!E>'!E8W1E9"!F<F]M('1H92!C;VUB:6YA=&EO;B!O9B!A;&P@
M=&AE<V4@9F%C=&]R<RX*("HO"B1T97-T<R`](&%R<F%Y*`H@("`@)W1A8FQE
M<R<@/3X@87)R87DH"B`@("`@("`@)V1B87-E.F1B87-E)R`]/B!$0E]%4E)/
M4E]53E-54%!/4E1%1"P*("`@("`@("`G9F)S<6PZ9F)S<6PG(#T^("=A<G)A
M>2<L"B`@("`@("`@)VEB87-E.FEB87-E)R`]/B`G87)R87DG+`H@("`@("`@
M("=I8F%S93IF:7)E8FER9"<@/3X@)V%R<F%Y)RP*("`@("`@("`G:69X.FEF
M>"<@/3X@)V%R<F%Y)RP*("`@("`@("`G;7-Q;#IM<W%L)R`]/B`G87)R87DG
M+`H@("`@("`@("=M<W-Q;#IM<W-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G
M;7ES<6PZ;7ES<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUY<W%L:3IM>7-Q
M;&DG(#T^("=A<G)A>2<L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@)V%R<F%Y
M)RP*("`@("`@("`G;V1B8SIA8V-E<W,G(#T^("=A<G)A>2<L"B`@("`@("`@
M)V]D8F,Z9&(R)R`]/B`G87)R87DG+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@
M/3X@)V%R<F%Y)RP*("`@("`@("`G<W%L:71E.G-Q;&ET92<@/3X@)V%R<F%Y
M)RP*("`@("`@("`G<WEB87-E.G-Y8F%S92<@/3X@)V%R<F%Y)RP*("`@("DL
M"B`@("`G=FEE=W,G(#T^(&%R<F%Y*`H@("`@("`@("=D8F%S93ID8F%S92<@
M/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V9B<W%L.F9B<W%L
M)R`]/B`G87)R87DG+`H@("`@("`@("=I8F%S93II8F%S92<@/3X@)V%R<F%Y
M)RP*("`@("`@("`G:6)A<V4Z9FER96)I<F0G(#T^("=A<G)A>2<L"B`@("`@
M("`@)VEF>#II9G@G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@
M("=M<W%L.FUS<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@
M("=M<W-Q;#IM<W-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G;7ES<6PZ;7ES
M<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M>7-Q;&DZ
M;7ES<6QI)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V-I
M.#IO8VDX)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B
M8SIA8V-E<W,G(#T^("=A<G)A>2<L"B`@("`@("`@)V]D8F,Z9&(R)R`]/B`G
M87)R87DG+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y)RP*("`@
M("`@("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?15)23U)?54Y355!03U)4140L
M"B`@("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^("=A<G)A>2<L"B`@("`I+`H@
M("`@)W5S97)S)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^
M($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@
M/3X@)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^("=A<G)A>2<L
M"B`@("`@("`@)VEB87-E.F9I<F5B:7)D)R`]/B`G87)R87DG+`H@("`@("`@
M("=I9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G
M;7-Q;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G
M;7-S<6PZ;7-S<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@
M("=M>7-Q;#IM>7-Q;"<@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*
M("`@("`@("`G;7ES<6QI.FUY<W%L:2<@/3X@1$)?15)23U)?04-#15-37U9)
M3TQ!5$E/3BP*("`@("`@("`G;V-I.#IO8VDX)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;V1B8SIA8V-E<W,G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=O9&)C.F1B,B<@/3X@1$)?15)23U)?54Y3
M55!03U)4140L"B`@("`@("`@)W!G<W%L.G!G<W%L)R`]/B`G87)R87DG+`H@
M("`@("`@("=S<6QI=&4Z<W%L:71E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%
M1"P*("`@("`@("`G<WEB87-E.G-Y8F%S92<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`I+`H@("`@)V1A=&%B87-E<R<@/3X@87)R87DH"B`@("`@
M("`@)V1B87-E.F1B87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@
M("`@("`G9F)S<6PZ9F)S<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@
M("`@("`@("=I8F%S93II8F%S92<@/3X@1$)?15)23U)?54Y355!03U)4140L
M"B`@("`@("`@)VEB87-E.F9I<F5B:7)D)R`]/B!$0E]%4E)/4E]53E-54%!/
M4E1%1"P*("`@("`@("`G:69X.FEF>"<@/3X@1$)?15)23U)?54Y355!03U)4
M140L"B`@("`@("`@)VUS<6PZ;7-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G
M;7-S<6PZ;7-S<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@
M("=M>7-Q;#IM>7-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G;7ES<6QI.FUY
M<W%L:2<@/3X@)V%R<F%Y)RP*("`@("`@("`G;V-I.#IO8VDX)R`]/B!$0E]%
M4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SIA8V-E<W,G(#T^("=A
M<G)A>2<L"B`@("`@("`@)V]D8F,Z9&(R)R`]/B`G87)R87DG+`H@("`@("`@
M("=P9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G<W%L:71E.G-Q
M;&ET92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)W-Y8F%S
M93IS>6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@*2P*("`@
M("=F=6YC=&EO;G,G(#T^(&%R<F%Y*`H@("`@("`@("=D8F%S93ID8F%S92<@
M/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V9B<W%L.F9B<W%L
M)R`]/B`G87)R87DG+`H@("`@("`@("=I8F%S93II8F%S92<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)VEB87-E.F9I<F5B:7)D)R`]/B!$
M0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G:69X.FEF>"<@/3X@1$)?
M15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUS<6PZ;7-Q;"<@/3X@1$)?
M15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUS<W%L.FUS<W%L)R`]/B!$
M0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES<6PZ;7ES<6PG(#T^
M($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M>7-Q;&DZ;7ES<6QI
M)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V-I.#IO8VDX
M)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SIA8V-E
M<W,G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=O9&)C.F1B
M,B<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)W!G<W%L.G!G
M<W%L)R`]/B`G87)R87DG+`H@("`@("`@("=S<6QI=&4Z<W%L:71E)R`]/B!$
M0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G<WEB87-E.G-Y8F%S92<@
M/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`I+`H@("`@)W!R;V-E9'5R
M97,G(#T^(&%R<F%Y*`H@("`@("`@("=D8F%S93ID8F%S92<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)V9B<W%L.F9B<W%L)R`]/B`G87)R
M87DG+`H@("`@("`@("=I8F%S93II8F%S92<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VEB87-E.F9I<F5B:7)D)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G:69X.FEF>"<@/3X@1$)?15)23U)?54Y3
M55!03U)4140L"B`@("`@("`@)VUS<6PZ;7-Q;"<@/3X@1$)?15)23U)?54Y3
M55!03U)4140L"B`@("`@("`@)VUS<W%L.FUS<W%L)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G;7ES<6PZ;7ES<6PG(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=M>7-Q;&DZ;7ES<6QI)R`]/B!$0E]%
M4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V-I.#IO8VDX)R`]/B!$0E]%
M4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SIA8V-E<W,G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=O9&)C.F1B,B<@/3X@1$)?
M15)23U)?54Y355!03U)4140L"B`@("`@("`@)W!G<W%L.G!G<W%L)R`]/B`G
M87)R87DG+`H@("`@("`@("=S<6QI=&4Z<W%L:71E)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G<WEB87-E.G-Y8F%S92<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`I+`H@("`@)W-C:&5M82YT86)L97,G(#T^
M(&%R<F%Y*`H@("`@("`@("=D8F%S93ID8F%S92<@/3X@1$)?15)23U)?54Y3
M55!03U)4140L"B`@("`@("`@)V9B<W%L.F9B<W%L)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=I8F%S93IF:7)E8FER9"<@/3X@1$)?
M15)23U)?54Y355!03U)4140L"B`@("`@("`@)VEF>#II9G@G(#T^($1"7T52
M4D]27U5.4U504$]25$5$+`H@("`@("`@("=M<W%L.FUS<6PG(#T^($1"7T52
M4D]27U5.4U504$]25$5$+`H@("`@("`@("=M<W-Q;#IM<W-Q;"<@/3X@1$)?
M15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]/B!$
M0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES<6QI.FUY<W%L:2<@
M/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]C:3@Z;V-I."<@
M/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S
M)R`]/B`G87)R87DG+`H@("`@("`@("=O9&)C.F1B,B<@/3X@)V%R<F%Y)RP*
M("`@("`@("`G<&=S<6PZ<&=S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)W-Q
M;&ET93IS<6QI=&4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@
M("=S>6)A<V4Z<WEB87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@
M("DL"B`@("`G<WEN;VYY;7,G(#T^(&%R<F%Y*`H@("`@("`@("=D8F%S93ID
M8F%S92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V9B<W%L
M.F9B<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G:6)A
M<V4Z:6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=I
M8F%S93IF:7)E8FER9"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@
M("`@)VEF>#II9G@G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@
M("=M<W%L.FUS<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@
M("=M<W-Q;#IM<W-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@
M("`@)VUY<W%L.FUY<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@
M("`@("`G;7ES<6QI.FUY<W%L:2<@/3X@1$)?15)23U)?54Y355!03U)4140L
M"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@)V%R<F%Y)RP*("`@("`@("`G;V1B
M8SIA8V-E<W,G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=O
M9&)C.F1B,B<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)W!G
M<W%L.G!G<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G
M<W%L:71E.G-Q;&ET92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@
M("`@)W-Y8F%S93IS>6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@
M("`@*2P**3L*"B\J*@H@*B!$971E<FUI;F4@:68@=&AE(&]U='!U="!F<F]M
M('1H92!D<FEV97(@;6%T8VAE<R!W:&%T('=E(&5X<&5C=`H@*@H@*B!)9B!T
M:&EN9W,@87)E(&%S('=E(&5X<&5C="P@;F]T:&EN9R!I<R!P<FEN=&5D(&]U
M="X*("H*("H@268@=&AI;F=S(&=O('=R;VYG+"!P<FEN="`B54Y%6%!%0U1%
M1"!/551#3TU%(B!A;F0@9&ES<&QA>0H@*B!W:&%T(&AA<'!E;F5D+@H@*@H@
M*B!`<&%R86T@;6EX960@("1R97-U;'0@("`@=&AE(')E<W5L="!F<F]M(&=E
M=$QI<W1/9@H@*B!`<&%R86T@;6EX960@("1E>'!E8W1E9"`@=&AE(&5X<&5C
M=&5D(')E<W5L=`H@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@=&AE(&YA
M;64@;V8@=&AE(&-U<G)E;G0@=&5S=`H@*@H@*B!`<F5T=7)N('9O:60*("HO
M"F9U;F-T:6]N(&-H96-K7V]U='!U="@D<F5S=6QT+"`D97AP96-T960L("1N
M86UE*2!["B`@("!I9B`H:7-?;V)J96-T*"1R97-U;'0I*2!["B`@("`@("`@
M:68@*"1R97-U;'0M/F=E=$-O9&4H*2`A/3T@)&5X<&5C=&5D*2!["B`@("`@
M("`@("`@(&5C:&\@(E5.15A014-4140@3U540T]-12!&3U(@)&YA;64N+BY<
M;B(["B`@("`@("`@("`@(&5C:&\@)')E<W5L="T^9V5T1&5B=6=);F9O*"D@
M+B`B7&XB.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@)'1Y<&4@
M/2!G971T>7!E*"1R97-U;'0I.PH@("`@("`@(&EF("@D='EP92`A/2`D97AP
M96-T960I('L*("`@("`@("`@("`@:68@*"1E>'!E8W1E9"`]/3T@1$)?15)2
M3U)?04-#15-37U9)3TQ!5$E/3@H@("`@("`@("`@("`@("`@)B8@)'1Y<&4@
M/3T@)V%R<F%Y)RD*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@+R\@
M5&AI<R!U<V5R(&AA<R!A8V-E<W,@=&\@=&AE(&UY<W%L('1A8FQE+@H@("`@
M("`@("`@("`@("`@+R\@3F]T(&$@<')O8FQE;0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@96-H;R`B54Y%6%!%0U1%1"!/551#3TU%
M($9/4B`D;F%M92XN+EQN(CL*("`@("`@("`@("`@("`@(&5C:&\@(B`@17AP
M96-T960Z("1E>'!E8W1E9%QN(CL*("`@("`@("`@("`@("`@(&5C:&\@)R`@
M4F5S=6QT.B`G.PH@("`@("`@("`@("`@("`@<')I;G1?<B@D<F5S=6QT*3L*
M("`@("`@("`@("`@("`@(&5C:&\@(EQN(CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*?0H*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PIF;W)E86-H("@D=&5S=',@87,@)'1E<W0@/3X@)&1B
M;7,I('L*("`@(&-H96-K7V]U='!U="@D9&)H+3YG971,:7-T3V8H)'1E<W0I
M+`H@("`@("`@("`@("`@("`@("1D8FUS6R1D8F@M/G!H<'1Y<&4@+B`G.B<@
M+B`D9&)H+3YD8G-Y;G1A>%TL"B`@("`@("`@("`@("`@("`@)'1E<W0I.PI]
M"@H*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH*/SX*+2U%6%!%0U0M
M+0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+V-O;FYE
M8W0N:6YC````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T,#``,3`U,34T,S$P-3<`
M,#(S-30U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH*("H@0V]N;F5C=',@=&\@=&AE(&1A=&%B87-E"B`J
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@
M("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$
M86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z(&-O;FYE8W0N:6YC+'8@,2XQ,B`R
M,#`U+S`R+S`R(#`P.C0P.C(S(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*97)R;W)?
M<F5P;W)T:6YG*$5?04Q,*3L*"B\O(%-E='1I;F<@;V8@)&]P=&EO;G,@86YD
M(')E<75I<FEN9R!$0B!A<F4@9&]N92!I;B!S971U<"YI;F,*"B\J*@H@*B!%
M<W1A8FQI<V@@=&AE(&EN8VQU9&5?<&%T:"P@1%-.)W,@86YD(&-O;FYE8W1I
M;VX@)&]P=&EO;G,*("HO"G)E<75I<F5?;VYC92`G+B]S971U<"YI;F,G.PH*
M:68@*&5M<'1Y*"1D<VYS*2D@>PH@("`@9&EE*"=!="!L96%S="!O;F4@96QE
M;65N="!O9B`D9'-N<R!M=7-T(&)E(&1E9FEN960@:6X@<V5T=7`N:6YC)RD[
M"GT*"FQI<W0H)&1B;7,L("1D<VXI(#T@96%C:"@D9'-N<RD["@II9B`H)&1B
M;7,@/3T@)VUS<W%L)RD@>PH@("`@:6YI7W-E="@G;7-S<6PN=&5X=&QI;6ET
M)RP@-#`Y-BD["B`@("!I;FE?<V5T*"=M<W-Q;"YT97AT<VEZ92<L(#0P.38I
M.PI]"@HD9&)H(#TF($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*:68@
M*$1".CII<T5R<F]R*"1D8F@I*2!["B`@("!D:64H)V-O;FYE8W0N:6YC.B`G
M("X@)&1B:"T^=&]3=')I;F<H*2D["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]D<FEV97(O;6MT86)L92YI;F,`````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,#$V-``Q,#4Q-30S,3`U-P`P,C,U-#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"B\J*@H@*B!#<F5A
M=&5S('1H92`\:V)D/G!H<'1E<W0\+VMB9#X@=&%B;&4*("H*("H@5')I97,@
M=&\@9')O<"!T:&4@=&%B;&4@9FER<W0L(&EN(&-A<V4@:70@86QR96%D>2!E
M>&ES=',N"B`J"B`J(#QP<F4^"B`J($-214%412!404),12!P:'!T97-T("@*
M("H@("!A($E.5$5'15(@3E5,3"P*("H@("!B($-(05(H-#`I($1%1D%53%0@
M)V1E9B<@3D]4($Y53$PL"B`J("`@8R!605)#2$%2*#(U-2D@3E5,3"P*("H@
M("!D(%9!4D-(05(H,C`I($Y53$PI"B`J(#PO<')E/@H@*@H@*B!.965D(#QK
M8F0^3D]4($Y53$P\+VMB9#X@;VX@/&MB9#YB/"]K8F0^('1O('1E<W0*("H@
M/&MB9#Y$0E]03U)404))3$E465]25%))33PO:V)D/BX@($U3(%-13"!A;F0@
M4WEB87-E('1R:6T@;W5T<'5T(&9R;VT*("H@/&MB9#Y605)#2$%2/"]K8F0^
M+"!B=70@;F]T(&]N(#QK8F0^0TA!4CPO:V)D/BX*("H*("H@3F5E9"`\:V)D
M/D1%1D%53%0\+VMB9#X@=F%L=64@;VX@/&MB9#YB/"]K8F0^(&)E8V%U<V4@
M3W)A8VQE(&-O;G-I9&5R<PH@*B!A;B!E;7!T>2!S=')I;F<@=&\@8F4@/&MB
M9#Y.54Q,/"]K8F0^+@H@*@H@*B!);B!/<F%C;&4L('=H96X@=7-I;F<@<&QA
M8V5H;VQD97)S(&EN(#QK8F0^5TA%4D4\+VMB9#X@8VQA=7-E<R!O;B`*("H@
M/&MB9#Y#2$%2/"]K8F0^(&-O;'5M;G,L('1H92!C;VQU;6X@;75S="!H879E
M(#QK8F0^4E1224TH*3PO:V)D/B!R=6X@;VX*("H@=&AE(&-O;'5M;CH*("H@
M/'-A;7`^"B`J("`@(%-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!25%))
M32AB*2`](#\*("H@/"]S86UP/@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@
M("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'
M<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED
M.B!M:W1A8FQE+FEN8RQV(#$N,3D@,C`P-2\P,B\Q-"`R,SHS,SHR,"!D86YI
M96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!%<W1A8FQI<VAE<R!T:&4@1$(@;V)J
M96-T(&%N9"!C;VYN96-T<R!T;R!T:&4@9&%T86)A<V4*("HO"G)E<75I<F5?
M;VYC92`G+B]C;VYN96-T+FEN8R<["@HO*BH*("H@1V5T('1H92!D<F]P7W1A
M8FQE*"D@9G5N8W1I;VX*("HO"G)E<75I<F5?;VYC92`G+B]D<F]P=&%B;&4N
M:6YC)SL*"B\J*@H@*B!4:&4@97)R;W(@:&%N9&QE<B!F;W(@=&AE(&1R;W`@
M=&%B;&4@<')O8V5D=7)E"B`J"B`J(%!R:6YT<R!O=70@86X@97)R;W(@;65S
M<V%G92!A;F0@9&EE<RX*("HO"F9U;F-T:6]N(&1E8G5G7V1I92@D;RE["B`@
M("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@H*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H
M<'1E<W0G*3L*"B\O)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7U1224='15(I.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M0T%,3$)!0TLL("=D96)U9U]D:64G*3L*"FEF("@D9&)H+3YP:'!T>7!E(#T]
M("=O9&)C)RD@>PH@("`@:68@*"1D8F@M/F1B<WEN=&%X(#T]("=O9&)C)RD@
M>PH@("`@("`@("1T>7!E(#T@)&1B:"T^<&AP='EP93L*("`@('T@96QS92![
M"B`@("`@("`@)'1Y<&4@/2`D9&)H+3YD8G-Y;G1A>#L*("`@('T*?2!E;'-E
M('L*("`@("1T>7!E(#T@)&1B:"T^<&AP='EP93L*?0H*"G-W:71C:"`H)'1Y
M<&4I('L*("`@(&-A<V4@)V%C8V5S<R<Z"B`@("`@("`@)&YU;&P@/2`G3E5,
M3"<["B`@("`@("`@)&-H<F,@/2`G5D%20TA!4B@R-34I)SL*("`@("`@("`D
M8VAR9"`]("=605)#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`G)SL*
M("`@("`@("`D=&%B;&5T>7!E(#T@)R<["B`@("`@("`@8G)E86L["B`@("!C
M87-E("=D8C(G.@H@("`@8V%S92`G:6)A<V4G.@H@("`@("`@("1N=6QL(#T@
M)R<["B`@("`@("`@)&-H<F,@/2`G5D%20TA!4B@R-34I)SL*("`@("`@("`D
M8VAR9"`]("=605)#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`B1$5&
M055,5"`G9&5F)R!.3U0@3E5,3"(["B`@("`@("`@)'1A8FQE='EP92`]("<G
M.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G9F)S<6PG.@H@("`@("`@("1N
M=6QL(#T@)R<["B`@("`@("`@)&-H<F,@/2`G0TA!4B@R-34I)SL*("`@("`@
M("`D8VAR9"`]("=#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`B1$5&
M055,5"`G9&5F)R!.3U0@3E5,3"(["B`@("`@("`@)&1A=&5?;&ET97)A;"`]
M("<@1$%412`G.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*("`@("`@("!B
M<F5A:SL*("`@(&-A<V4@)VEF>"<Z"B`@("`@("`@+R\@9&]I;F<@=&AI<R!F
M;W(@:69X('1O(&ME97`@8V5R=&%I;B!V97)S:6]N<R!H87!P>0H@("`@("`@
M("1N=6QL(#T@)R<["B`@("`@("`@)&-H<F,@/2`G0TA!4B@R-34I)SL*("`@
M("`@("`D8VAR9"`]("=#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`B
M1$5&055,5"`G9&5F)R!.3U0@3E5,3"(["B`@("`@("`@)'1A8FQE='EP92`]
M("<G.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@
M)&YU;&P@/2`G)SL*("`@("`@("`D8VAR8R`]("=#2$%2*#(U-2DG.PH@("`@
M("`@("1C:')D(#T@)T-(05(H,C`I)SL*("`@("`@("`D9&5F875L="`]("<G
M.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*("`@("`@("!B<F5A:SL*("`@
M(&-A<V4@)VUY<W%L)SH*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("`@("`@)&YU
M;&P@/2`G3E5,3"<["B`@("`@("`@)&-H<F,@/2`G5D%20TA!4B@R-34I)SL*
M("`@("`@("`D8VAR9"`]("=605)#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U
M;'0@/2`B1$5&055,5"`G9&5F)R!.3U0@3E5,3"(["B`@("`@("`@:68@*"%E
M;7!T>2@D;F5E9&EN;F]D8BDI('L*("`@("`@("`@("`@)'1A8FQE='EP92`]
M("=465!%/4E.3D]$0B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1A8FQE='EP92`]("<G.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*("`@
M(&1E9F%U;'0Z"B`@("`@("`@)&YU;&P@/2`G3E5,3"<["B`@("`@("`@)&-H
M<F,@/2`G5D%20TA!4B@R-34I)SL*("`@("`@("`D8VAR9"`]("=605)#2$%2
M*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`B1$5&055,5"`G9&5F)R!.3U0@
M3E5,3"(["B`@("`@("`@)'1A8FQE='EP92`]("<G.PI]"@IS=VET8V@@*"1D
M8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)V1B87-E)SH*("`@("`@("`O+R!F
M:6QE(&5X:7-T<R!O<B!W87,@8W)E871E9"!I;B!$0E]D8F%S93HZ8V]N;F5C
M="@I"B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@("1T97-T
M7VUK=&%B;&5?<75E<GD@/2`B"B`@("`@("`@("`@($-214%412!404),12!P
M:'!T97-T("@*("`@("`@("`@("`@("!A($E.5$5'15(@)&YU;&PL"B`@("`@
M("`@("`@("`@8B!#2$%2*#0P*2`D9&5F875L="P*("`@("`@("`@("`@("!C
M("1C:')C("1N=6QL+`H@("`@("`@("`@("`@(&0@)&-H<F0@)&YU;&PI("1T
M86)L971Y<&4*("`@("`@("`B.PI]"@H*)&1B:"T^<75E<GDH)'1E<W1?;6MT
M86)L95]Q=65R>2D["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T
M(%9!3%5%4R@T,BP@)V)I;F<G+"`G5&AI<R!I<R!A('1E<W0G+"`G,3DY.2TQ
M,2TR,2<I(BD["@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S
M+V1R:79E<B]M=6QT:6-O;FYE8W0N<&AP````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,3`W
M`#$P-3$U-#,Q,#4W`#`R-#8T-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H92!V87)I
M;W5S('=A>7,@1$(G<R!C;VYN96-T*"D@9G5N8W1I;VX@;W!E<F%T97,*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@("1)9#H@;75L=&EC;VYN96-T+G!H<"QV(#$N
M,B`R,#`U+S`R+S`S(#`U.C0Y.C0U(&1A;FEE;&,@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J($!S:6YC
M92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("HO
M"@HO*BH*("H@17-T86)L:7-H('1H92!I;F-L=61E7W!A=&@L($133B=S(&%N
M9"!C;VYN96-T:6]N("1O<'1I;VYS"B`J+PIR97%U:7)E7V]N8V4@)RXO<V5T
M=7`N:6YC)SL*"F9O<F5A8V@@*"1D<VYS(&%S("1D8FUS(#T^("1D<VXI('L*
M("`@(&5C:&\@(CT]/3T]/3T]("1D8FUS(#T]/3T]/3T]7&XB.PH@("`@)&]P
M=&EO;G-;)W!E<G-I<W1E;G0G72`](&9A;'-E.PH@("`@)&1B:"`])B!$0CHZ
M8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("!I9B`H1$(Z.FES17)R;W(H
M)&1B:"DI('L*("`@("`@("!E8VAO("=04D]"3$5-.B`G("X@)&1B:"T^9V5T
M57-E<DEN9F\H*2`N(")<;B(["B`@("`@("`@8V]N=&EN=64["B`@("!]"@H@
M("`@:68@*"1D8F@M/G!R;W9I9&5S*"=N97=?;&EN:R<I"B`@("`@("`@)B8@
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)&1B:"T^<')O=FED97,H
M)VYE=U]L:6YK)RDL("<^/2<I*0H@("`@>PH@("`@("`@("1P<F]B<R`](&9A
M;'-E.PH@("`@("`@("1D<VX@/2!$0CHZ<&%R<V5$4TXH)&1S;BD["B`@("`@
M("`@)&1S;ELG;F5W7VQI;FLG72`]('1R=64["B`@("`@("`@)&1B:"`])B!$
M0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1D8F@I*2!["B`@("`@("`@("`@(&5C:&\@)TY%5R!,24Y+(%!2
M3T),14TZ("<@+B`D9&)H+3YG9715<V5R26YF;R@I("X@(EQN(CL*("`@("`@
M("`@("`@)'!R;V)S(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M9&)H+3YP<F]V:61E<R@G<&-O;FYE8W0G*2D@>PH@("`@("`@("`@("`D;W!T
M:6]N<ULG<&5R<VES=&5N="==(#T@=')U93L*("`@("`@("`@("`@)&1B:"T^
M9&ES8V]N;F5C="@I.PH@("`@("`@("`@("`D9&)H(#TF($1".CIC;VYN96-T
M*"1D<VXL("1O<'1I;VYS*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1D8F@I*2!["B`@("`@("`@("`@("`@("!E8VAO("=015)325-4($Y%5T-/
M3B!04D]"3$5-.B`G("X@)&1B:"T^9V5T57-E<DEN9F\H*2`N(")<;B(["B`@
M("`@("`@("`@("`@("`D<')O8G,@/2!T<G5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!U;G-E="@D9'-N6R=N97=?;&EN:R==*3L*("`@("`@("`@
M("`@)&1B:"T^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("`D9&)H(#TF($1"
M.CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*("`@("`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1D8F@I*2!["B`@("`@("`@("`@("`@("!E8VAO("=015)3
M25-4($],1$-/3B!04D]"3$5-.B`G("X@)&1B:"T^9V5T57-E<DEN9F\H*2`N
M(")<;B(["B`@("`@("`@("`@("`@("`D<')O8G,@/2!T<G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D<')O8G,I('L*("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@("1D8F@M/F1I<V-O
M;FYE8W0H*3L*"B`@("!](&5L<V5I9B`H)&1B:"T^<')O=FED97,H)W!C;VYN
M96-T)RDI('L*("`@("`@("`D;W!T:6]N<ULG<&5R<VES=&5N="==(#T@=')U
M93L*("`@("`@("`D9&)H+3YD:7-C;VYN96-T*"D["B`@("`@("`@)&1B:"`]
M)B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1D8F@I*2!["B`@("`@("`@("`@(&5C:&\@)U!%4E-)4U0@
M4%)/0DQ%33H@)R`N("1D8F@M/F=E=%5S97));F9O*"D@+B`B7&XB.PH@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@)&1B:"T^9&ES
M8V]N;F5C="@I.PH@("`@?0H@("`@96-H;R`B1T]/1%QN(CL*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+W)U;BYC=G,`
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V-C``,3`U,34T,S$P-3<`,#(R
M-S4Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",A("]B:6XO<V@*"B,@)$ED.B!R=6XN8W9S+'8@,2XR(#(P,#0O,#(O,C`@
M,3@Z-3<Z-3(@9&%N:65L8R!%>'`@)`H*(R!V=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=@HC(%!%05(@1$(@5$53
M5"!35$%25$52"B,*(R`@(%1O(')U;B!A;&P@=&5S=',Z("`N+W)U;@HC("`@
M5&\@<G5N(&]N92!T97-T.B`@("XO<G5N(#QT97-T(&9I;&4@;F%M93X*(R`@
M($5X86UP;&4Z("`@("`@("`@("`N+W)U;B!D8E]P87)S961S;BYP:'!T"B,*
M(R!"969O<F4@<G5N;FEN9R!T:&4@=&5S=',@>6]U(&UU<W0@861J=7-T('1H
M90HC(&9O;&QO=VEN9R!T:')E92!V87)I86)L97,Z"@HC("`@5&AE(&9U;&P@
M<&%T:"!T;R!Y;W5R(%!(4"!D:7)E8W1O<GDZ"B`@("!$0E]415-47U!(4%]0
M051(/6,Z+W!R;V=R87XQ+W!H<`H*(R`@(%1H92!N86UE(&]F('EO=7(@4$A0
M($-,22!E>&5C=71A8FQE"B,@("`H97AA;7!L97,@<&AP+F5X92P@<&AP+6-L
M:2YE>&4L(&-L:2]P:'`N97AE*3H*("`@($1"7U1%4U1?4$A07T-,23UP:'`N
M97AE"@HC("`@5&AE(&9U;&P@<&%T:"!T;R!T:&4@<')E<V5N="!D:7)E8W1O
M<GD*(R`@("AN;W0@=7-I;F<@)%!71"!D=64@=&\@0WEG=VEN*3H*("`@($1"
M7U1%4U1?1$E2/60Z+W!E87)T97-T+W!E87(O1$(O=&5S=',O9')I=F5R"@HC
M(%Y>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>
M7EY>7EY>"@H*"E1%4U1?4$A07T5814-55$%"3$4])$1"7U1%4U1?4$A07U!!
M5$@O)$1"7U1%4U1?4$A07T-,20IE>'!O<G0@5$535%]02%!?15A%0U5404),
M10H*:68@6R`D(R`M9W0@,"!="G1H96X*("`@('1E<W0])#$*96QS90H@("`@
M=&5S=#TJ+G!H<'0*9FD*"B1415-47U!(4%]%6$5#551!0DQ%("1$0E]415-4
M7U!(4%]0051(+W)U;BUT97-T<RYP:'`@)$1"7U1%4U1?1$E2+R1[=&5S='T*
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+W-E
M='5P+FEN8RYC=G,`````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<U-C``,3`U,34T,S$P
M-3<`,#(T,#8R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@HO*BH*("H@17-T86)L:7-H97,@=&AE(&EN8VQU9&5?
M<&%T:"P@1%-.)W,@86YD(&-O;FYE8W1I;VX@)&]P=&EO;G,*("H*("H@268@
M=&AI<R!F:6QE(&ES(&YA;65D(")S971U<"YI;F,N8W9S+"(@:70@:7,@=&AE
M(&]R:6=I;F%L(&]N92!F<F]M($-64RX*("H@4&QE87-E(&1O('1H92!F;VQL
M;W=I;F<Z"B`J("`@,2D@36%K92!A(&-O<'D@;V8@=&AI<R!F:6QE(&YA;65D
M(")S971U<"YI;F,B+@H@*B`@(#(I(%1H96XL(&EN('1H92!C;W!Y+"!E9&ET
M('1H92`D9'-N<R!A<G)A>2!A<R!A<'!R;W!R:6%T92!F;W(@>6]U<@H@*B`@
M("`@(&5N=FER;VYM96YT+@H@*B`@(#,I($%T(&QE87-T(&]N92!E;&5M96YT
M(&]F('1H92`D9'-N<R!A<G)A>2!N965D<R!T;R!B92!U;F-O;6UE;G1E9"X*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R
M>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@
M($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP"B`J($!V97)S:6]N("`@("1)9#H@<V5T=7`N:6YC+F-V<RQV(#$N
M-B`R,#`U+S`R+S$T(#(S.C,S.C(P(&1A;FEE;&,@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*:68@
M*"%D969I;F5D*"=0051(7U-%4$%2051/4B<I*2!["B`@("!I9B`H<W1R:7-T
M<BA02%!?3U,L("=724XG*2D@>PH@("`@("`@("\J*@H@("`@("`@("`J(%1H
M92!S=')I;F<@=7-E9"!T;R!D96QI;6ET(&5L96UE;G1S(&]F('1H92!P871H
M+@H@("`@("`@("`J+PH@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%43U(G
M+"`G.R<I.PH@("`@?2!E;'-E('L*("`@("`@("`O*BH*("`@("`@("`@*B!4
M:&4@<W1R:6YG('5S960@=&\@9&5L:6UI="!E;&5M96YT<R!O9B!T:&4@<&%T
M:"X*("`@("`@("`@*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2
M)RP@)SHG*3L*("`@('T*?0H*+RH*("H@268@=&AE('!A=&@@=&\@>6]U<B!0
M14%2(&EN<W1A;&QA=&EO;B!I<R!F;W5N9"!I;B!T:&4@;&5F="!H86YD"B`J
M('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO;B!B96QO=RP@=&AA="!M
M96%N<R!T:&ES(&9I;&4@:&%S"B`J(&-O;64@9G)O;2!T:&4@4$5!4B!I;G-T
M86QL97(N("!4:&5R969O<F4L(&QE="=S('5S92!T:&4*("H@:6YS=&%L;&5D
M('9E<G-I;VX@;V8@1$(L('=H:6-H('-H;W5L9"!B92!F;W5N9"!V:6$@=&AE
M"B`J(&-O;7!U=&5R)W,@9&5F875L="!I;F-L=61E7W!A=&@N("!!9&0@)RXG
M('1O('1H92!I;F-L=61E7W!A=&@*("H@=&\@96YS=7)E("<N)R!I<R!I;B!T
M:&5R92X*("H@"B`J($EF('1H92!P871H(&AA<R!N;W0@8F5E;B!S=6)S=&ET
M=71E9"!I;B!T:&4@:68H*2!E>'!R97-S:6]N+`H@*B!T:&ES(&9I;&4@:&%S
M(&QI:V5L>2!C;VUE(&9R;VT@82!#5E,@8VAE8VMO=70@;W(@82`N=&%R(&9I
M;&4N"B`J(%1H97)E9F]R92P@=V4G;&P@87-S=6UE('1H92!T97-T<R!S:&]U
M;&0@=7-E('1H92!V97)S:6]N(&]F"B`J($1"('1H870@:&%S(&-O;64@9G)O
M;2!T:&5R92!A<R!W96QL+@H@*B\*:68@*"<O=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PH@("`@
M:6YI7W-E="@G:6YC;'5D95]P871H)RP@:6YI7V=E="@G:6YC;'5D95]P871H
M)RD*("`@("`@("`@("`@+B!0051(7U-%4$%2051/4B`N("<N)PH@("`@*3L*
M?2!E;'-E('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(')E86QP871H
M*&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I"B`@("`@("`@("`@("X@
M4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@
M("`@("`N(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PI]"@HO*BH*
M("H@1W)A8B!T:&4@4$5!4B!$0B!C;&%S<V5S+@H@*B\*<F5Q=6ER95]O;F-E
M("=$0BYP:'`G.PH*+R\@3W!T:6]N<R!U<V5D('=H96X@8V]N;F5C=&EN9PHD
M;W!T:6]N<R`](&%R<F%Y*`H@("`@+R\G;W!T:6UI>F4G(#T^("=P;W)T86)I
M;&ET>2<L"B`@("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,25197T%,
M3"P*("`@("=D96)U9R<@/3X@,BP**3L*"B1D8F%S961S;B`](&%R<F%Y*`H@
M("`@)W!H<'1Y<&4G("`]/B`G9&)A<V4G+`H@("`@)V1A=&%B87-E)R`]/B`G
M+W!A=&@O86YD+VYA;64O;V8O9&)A<V4O9FEL92<L"B`@("`G;6]D92<@("`@
M(#T^(#(L"B`@("`G9FEE;&1S)R`@(#T^(&%R<F%Y*`H@("`@("`@(&%R<F%Y
M*"=A)RP@)TXG+"`U+"`P*2P*("`@("`@("!A<G)A>2@G8B<L("=#)RP@-#`I
M+`H@("`@("`@(&%R<F%Y*"=C)RP@)T,G+"`R-34I+`H@("`@("`@(&%R<F%Y
M*"=D)RP@)T,G+"`R,"DL"B`@("`I+`HI.PH*+RH*("H@56YC;VUM96YT(&%T
M(&QE87-T(&]N92!O9B!T:&4@9F]L;&]W:6YG(&5L96UE;G1S+@H@*B!7:&5N
M(')U;FYI;F<@=&AE("YP:'!T('1E<W1S+"!T:&4@9FER<W0@=6YC;VUM96YT
M960@96QE;65N="!I<R!U<V5D+@H@*B!7:&5N(')U;FYI;F<@=&AE(&UU;'1I
M8V]N;F5C="YP:'`@=&5S="P@86QL('5N8V]M;65N=&5D(&5L96UE;G1S(&%R
M92!U<V5D+@H@*B\*)&1S;G,@/2!A<G)A>2@*("`@("\O("=D8F%S92<@("`@
M/3X@)&1B87-E9'-N+`H@("`@+R\@)V9B<W%L)R`@("`]/B`G9F)S<6PZ+R]?
M<WES=&5M.D`O9&(G+`H@("`@+R\@)V9I<F5B:7)D)R`]/B`G:6)A<V4H9FER
M96)I<F0I.B\O4UE31$)!.FUA<W1E<FME>4`O+V]P="]I;G1E<F)A<V4O97AA
M;7!L97,O96UP;&]Y964N9V1B/V1I86QE8W0],R<L"B`@("`O+R`G:69X)R`@
M("`@(#T^("=I9G@Z+R]U<V5R.G!W0&QO8V%L:&]S="]D8B<L"B`@("`O+R`G
M;7-Q;"<@("`@(#T^("=M<W%L.B\O+V1B)RP*"B`@("`O+R!)="=S(&%D=FES
M86)L92!T;R!U<V4@;VYL>2!O;F4@;V8@=&AE(&9O;&QO=VEN9R!A="!A('1I
M;64Z"B`@("`O+R`G;7-S<6PG("`@(#T^("=M<W-Q;#HO+W-A0'-O;65H;W-T
M+W!U8G,G+`H@("`@+R\@)W-Y8F%S92<@("`]/B`G<WEB87-E.B\O<V%`<V]M
M96AO<W0O<'5B<R<L"@H@("`@+R\@)VUY<W%L)R`@("`]/B`G;7ES<6PZ+R]R
M;V]T0&QO8V%L:&]S="]T97-T)RP*("`@("\O("=M>7-Q;&DG("`@/3X@)VUY
M<W%L:3HO+W)O;W1`;&]C86QH;W-T+W1E<W0G+`H@("`@+R\@)V]C:3@G("`@
M("`]/B`G;V-I.#HO+W-Y<W1E;3IM86YA9V5R0"<L"B`@("`O+R`G86-C97-S
M)R`@(#T^("=O9&)C*&%C8V5S<RDZ+R]A9&UI;D`O4WES=&5M1'-N3F%M92<L
M"B`@("`O+R`G9&(R)R`@("`@(#T^("=O9&)C*&1B,BDZ+R]D8C)I;G-T,3I8
M6%A80"]304U03$4G+`H@("`@+R\@)W!G<W%L)R`@("`]/B`G<&=S<6PZ+R]P
M;W-T9W)E<T!L;V-A;&AO<W0O=&5S="<L"B`@("`O+R`G<W%L:71E)R`@(#T^
M("=S<6QI=&4Z+R]D=6UM>3I`;&]C86QH;W-T+R<@+B!G971C=V0H*2`N($1)
M4D5#5$]265]315!!4D%43U(@+B`G=&5S="YD8C]M;V1E/3`V-#0G+`HI.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1$(O=&5S=',O9')I=F5R+W-K:7!I9BYI;F,`````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(Q,C8`,3`U,34T,S$P-3<`,#(S-#`V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@02!T97-T
M('1O(&UA:V4@<W5R92!T:&4@9&%T86)A<V4@8V%N(&)E(&-O;FYE8W1E9"!T
M;PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G
M;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@
M("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!S:VEP:68N:6YC+'8@,2XW
M(#(P,#4O,#(O,#(@,#`Z-#`Z,C,@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*
M("H@17-T86)L:7-H('1H92!I;F-L=61E7W!A=&@L($133B=S(&%N9"!C;VYN
M96-T:6]N("1O<'1I;VYS"B`J+PIR97%U:7)E7V]N8V4@)RXO<V5T=7`N:6YC
M)SL*"FEF("AE;7!T>2@D9'-N<RDI('L*("`@(&1I92@G<VMI<"!!="!L96%S
M="!O;F4@96QE;65N="!O9B`D9'-N<R!M=7-T(&)E(&1E9FEN960@:6X@<V5T
M=7`N:6YC)RD["GT*"FQI<W0H)&1B;7,L("1D<VXI(#T@96%C:"@D9'-N<RD[
M"@HD9&)H(#TF($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*:68@*$1"
M.CII<T5R<F]R*"1D8F@I*2!["B`@("!D:64H)W-K:7`@)R`N("1D8F@M/FUE
M<W-A9V4I.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#%C;VYN
M96-T+G!H<'0````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(U-``Q,#4Q-30S,3`U-P`P
M,C0Q,C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+2U415-4+2T*1$)?9')I=F5R.CIC;VYN96-T"BTM24Y)+2T*97)R;W)?
M<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA
M;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_
M/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G
M.PH*+RHJ"B`J($1E=&5R;6EN92!I9B!T:&4@9&%T86)A<V4@8V]N;F5C=&EO
M;B!M871C:&5S('=H870G<R!E>'!E8W1E9`H@*@H@*B!`<&%R86T@;V)J96-T
M("1D8F@@("!T:&4@4$5!4B!$0B!O8FIE8W0*("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@=&AE(&YA;64@;V8@=&AE(&-U<G)E;G0@=&5S=`H@*@H@*B!`<F5T
M=7)N('9O:60*("HO"F9U;F-T:6]N(&-H96-K7V1B:"@D9&)H+"`D;F%M92D@
M>PH@("`@:68@*$1".CII<T5R<F]R*"1D8F@I*2!["B`@("`@("`@9&EE*"=C
M;VYN96-T+FEN8SH@)R`N("1D8F@M/G1O4W1R:6YG*"DI.PH@("`@?0H@("`@
M:68@*&ES7V]B:F5C="@D9&)H*2D@>PH@("`@("`@('!R:6YT("(D;F%M92!I
M<R!A;B!O8FIE8W1<;B(["B`@("!]"B`@("!S=VET8V@@*"1D8F@M/G!H<'1Y
M<&4I('L*("`@("`@("!C87-E("=D8F%S92<Z"B`@("`@("`@("`@(&EF("AI
M<U]I;G0H)&1B:"T^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@('!R
M:6YT("(D;F%M92!I<R!C;VYN96-T961<;B(["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!P<FEN="`B)&YA;64@3D]4(&-O;FYE8W1E
M9%QN(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!C87-E("=M>7-Q;&DG.@H@("`@("`@("`@("!I9B`H:7-?82@D9&)H+3YC
M;VYN96-T:6]N+"`G;7ES<6QI)RDI('L*("`@("`@("`@("`@("`@('!R:6YT
M("(D;F%M92!I<R!C;VYN96-T961<;B(["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!P<FEN="`B)&YA;64@3D]4(&-O;FYE8W1E9%QN
M(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("!I9B`H9V5T='EP92@D9&)H+3YC;VYN96-T
M:6]N*2`]/2`G<F5S;W5R8V4G*2!["B`@("`@("`@("`@("`@("!P<FEN="`B
M)&YA;64@:7,@8V]N;F5C=&5D7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<')I;G0@(B1N86UE($Y/5"!C;VYN96-T961<;B([
M"B`@("`@("`@("`@('T*("`@('T*?0H*"F-H96-K7V1B:"@D9&)H+"`G)&1B
M:"<I.PH*"B1T97-T7V%R<F%Y7V1S;B`]($1".CIP87)S94133B@D9'-N*3L*
M9F]R96%C:"`H)'1E<W1?87)R87E?9'-N(&%S("1K97D@/3X@)'9A;'5E*2![
M"B`@("!I9B`H)'9A;'5E(#T]/2!F86QS92D@>PH@("`@("`@('5N<V5T*"1T
M97-T7V%R<F%Y7V1S;ELD:V5Y72D["B`@("!]"GT*"B1D8FAA(#TF($1".CIC
M;VYN96-T*"1T97-T7V%R<F%Y7V1S;BP@)&]P=&EO;G,I.PIC:&5C:U]D8F@H
M)&1B:&$L("<D9&)H82<I.PH*"B1T;7`@(#T@<V5R:6%L:7IE*"1D8FAA*3L*
M)&1B:'4@/2!U;G-E<FEA;&EZ92@D=&UP*3L*8VAE8VM?9&)H*"1D8FAU+"`G
M)&1B:'4G*3L*"C\^"BTM15A014-4+2T*)&1B:"!I<R!A;B!O8FIE8W0*)&1B
M:"!I<R!C;VYN96-T960*)&1B:&$@:7,@86X@;V)J96-T"B1D8FAA(&ES(&-O
M;FYE8W1E9`HD9&)H=2!I<R!A;B!O8FIE8W0*)&1B:'4@:7,@8V]N;F5C=&5D
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`R9F5T8V@N<&AP
M=```````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-C``,3`U,34T,S$P-3<`,#(S-34T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M5$535"TM"D1"7V1R:79E<CHZ9F5T8V@*+2U)3DDM+0IE<G)O<E]R97!O<G1I
M;F<@/2`R,#0W"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)
M3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,
M12TM"CP_<&AP"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I
M<F5?;VYC92`G+BXO9F5T8VAM;V1E<RYI;F,G.PH_/@HM+4584$5#5"TM"G1E
M<W1I;F<@9F5T8VAR;W<Z"G)O=R`Q.B`T,BP@8FEN9RP@5&AI<R!I<R!A('1E
M<W0L(#$Y.3DM,3$M,C$*<F]W(#(Z(#$L(&]N92P@3VYE+"`R,#`Q+3`R+3$V
M"G)O=R`S.B`R+"!T=V\L(%1W;RP@,C`P,2TP,BTQ-0IR;W<@-#H@,RP@=&AR
M964L(%1H<F5E+"`R,#`Q+3`R+3$T"G)O=R`U.B!.54Q,"G1E<W1I;F<@9F5T
M8VAM;V1E<SH@9F5T8VAR;W<@9&5F875L="!D969A=6QT+"!P;W)T86)I;&ET
M>2!M;V1E($1"7U!/4E1!0DE,25197T%,3"!>($1"7U!/4E1!0DE,25197U)4
M4DE-"C`@,2`R(#,*;W5T<'5T(&UA=&-H960@97AP96-T960@9F]R;6%T"G1E
M<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&1E9F%U;'0@9&5F875L=`HP
M(#$@,B`S"C0R(&)I;F<@5&AI<R!I<R!A('1E<W0@,3DY.2TQ,2TR,0IT97-T
M:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@9&5F875L=`HP(#$@
M,B`S"G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@87-S;V,@9&5F875L
M=`IA(&(@8R!D"G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@;W)D97)E
M9"!D969A=6QT('=I=&@@87-S;V,@<W!E8VEF:65D"F$@8B!C(&0*=&5S=&EN
M9R!F971C:&UO9&5S.B!F971C:')O=R!A<W-O8R!D969A=6QT('=I=&@@;W)D
M97)E9"!S<&5C:69I960*,"`Q(#(@,PIT97-T:6YG(&9E=&-H;6]D97,Z(&9E
M=&-H:6YT;R!O<F1E<F5D(&1E9F%U;'0*,"`Q(#(@,PIT97-T:6YG(&9E=&-H
M;6]D97,Z(&9E=&-H:6YT;R!A<W-O8R!D969A=6QT"F$@8B!C(&0*=&5S=&EN
M9R!F971C:&UO9&5S.B!F971C:&EN=&\@;W)D97)E9"!D969A=6QT('=I=&@@
M87-S;V,@<W!E8VEF:65D"F$@8B!C(&0*=&5S=&EN9R!F971C:&UO9&5S.B!F
M971C:&EN=&\@87-S;V,@9&5F875L="!W:71H(&]R9&5R960@<W!E8VEF:65D
M"C`@,2`R(#,*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D8E]F86-T;W)Y+G!H<'0`````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C<Q,0`Q,#4Q-30S,3`U-P`P,C,Q-#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2U415-4+2T*1$(Z.F9A8W1O<GD*+2U3
M2TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I
M<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@
M+2HM($,K*R`M*BT*<F5Q=6ER95]O;F-E("<N+VEN8VQU9&4N:6YC)SL*<F5Q
M=6ER95]O;F-E("=$0BYP:'`G.PH*)&)A8VME;F1S(#T@87)R87DH"B`@("`G
M9&)A<V4G+`H@("`@)V9B<W%L)RP*("`@("=I8F%S92<L"B`@("`G:69X)RP*
M("`@("=M<W%L)RP*("`@("=M<W-Q;"<L"B`@("`G;7ES<6PG+`H@("`@)VUY
M<W%L:2<L"B`@("`G;V-I."<L"B`@("`G;V1B8R<L"B`@("`G<&=S<6PG+`H@
M("`@)W-Q;&ET92<L"B`@("`G<WEB87-E)RP**3L*"F9O<F5A8V@@*"1B86-K
M96YD<R!A<R`D;F%M92D@>PH@("`@)&]B:B`]($1".CIF86-T;W)Y*"1N86UE
M*3L*"B`@("!P<FEN="`B=&5S=&EN9R`D;F%M93H@(CL*("`@(&EF("A$0CHZ
M:7-%<G)O<B@D;V)J*2D@>PH)("`@('!R:6YT("=E<G)O<CH@)R`N("1O8FHM
M/F=E=$UE<W-A9V4H*2`N(")<;B(["B`@("!](&5L<V4@>PH)("`@('!R:6YT
M("=O8FIE8W0Z("<@+B`D;V)J+3YT;U-T<FEN9R@I("X@(EQN(CL*("`@('T*
M?0H*/SX*+2U'150M+0HM+5!/4U0M+0HM+4584$5#5"TM"G1E<W1I;F<@9&)A
M<V4Z(&]B:F5C=#H@9&)?9&)A<V4Z("AP:'!T>7!E/61B87-E+"!D8G-Y;G1A
M>#UD8F%S92D*=&5S=&EN9R!F8G-Q;#H@;V)J96-T.B!D8E]F8G-Q;#H@*'!H
M<'1Y<&4]9F)S<6PL(&1B<WEN=&%X/69B<W%L*0IT97-T:6YG(&EB87-E.B!O
M8FIE8W0Z(&1B7VEB87-E.B`H<&AP='EP93UI8F%S92P@9&)S>6YT87@]:6)A
M<V4I"G1E<W1I;F<@:69X.B!O8FIE8W0Z(&1B7VEF>#H@*'!H<'1Y<&4]:69X
M+"!D8G-Y;G1A>#UI9G@I"G1E<W1I;F<@;7-Q;#H@;V)J96-T.B!D8E]M<W%L
M.B`H<&AP='EP93UM<W%L+"!D8G-Y;G1A>#UM<W%L*0IT97-T:6YG(&US<W%L
M.B!O8FIE8W0Z(&1B7VUS<W%L.B`H<&AP='EP93UM<W-Q;"P@9&)S>6YT87@]
M;7-S<6PI"G1E<W1I;F<@;7ES<6PZ(&]B:F5C=#H@9&)?;7ES<6PZ("AP:'!T
M>7!E/6UY<W%L+"!D8G-Y;G1A>#UM>7-Q;"D*=&5S=&EN9R!M>7-Q;&DZ(&]B
M:F5C=#H@9&)?;7ES<6QI.B`H<&AP='EP93UM>7-Q;&DL(&1B<WEN=&%X/6UY
M<W%L:2D*=&5S=&EN9R!O8VDX.B!O8FIE8W0Z(&1B7V]C:3@Z("AP:'!T>7!E
M/6]C:3@L(&1B<WEN=&%X/6]C:3@I"G1E<W1I;F<@;V1B8SH@;V)J96-T.B!D
M8E]O9&)C.B`H<&AP='EP93UO9&)C+"!D8G-Y;G1A>#US<6PY,BD*=&5S=&EN
M9R!P9W-Q;#H@;V)J96-T.B!D8E]P9W-Q;#H@*'!H<'1Y<&4]<&=S<6PL(&1B
M<WEN=&%X/7!G<W%L*0IT97-T:6YG('-Q;&ET93H@;V)J96-T.B!D8E]S<6QI
M=&4Z("AP:'!T>7!E/7-Q;&ET92P@9&)S>6YT87@]<W%L:71E*0IT97-T:6YG
M('-Y8F%S93H@;V)J96-T.B!D8E]S>6)A<V4Z("AP:'!T>7!E/7-Y8F%S92P@
M9&)S>6YT87@]<WEB87-E*0H`````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1B7VES;6%N:7`N<&AP=```
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C0W`#$P-3$U-#,Q,#4W`#`R,S$T
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I$0CHZ:7--86YI<`HM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I
M<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G
M.R`_/@HM+49)3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0IR97%U:7)E7V]N
M8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@)T1"+G!H<"<["@IF
M=6YC=&EO;B!T97-T*"1Q=65R>2D@>PH@("`@<')I;G1F*"(E<R`Z("5D7&XB
M+"!P<F5G7W)E<&QA8V4H)R]<<RLN*B\G+"`G)RP@)'%U97)Y*2P*("`@("`@
M("`@("!$0CHZ:7--86YI<"@D<75E<GDI*3L*?0H*<')I;G0@(G1E<W1I;F<@
M1$(Z.FES36%N:7`N+BY<;B(["@IT97-T*")314Q%0U0@*B!&4D]-('1A8FQE
M(BD["G1E<W0H(E-E;&5C="`J(&9R;VT@=&%B;&4B*3L*=&5S="@B<V5L96-T
M("H@1G)O;2!T86)L92(I.PIT97-T*")S16Q%0W0@*B!F<D]M('1A8FQE(BD[
M"G1E<W0H(E-%3$5#5"!$25-424Y#5"!N86UE($923TT@=&%B;&4B*3L*=&5S
M="@B55!$051%('1A8FQE(%-%5"!F;V\@/2`G8F%R)R(I.PIT97-T*")$14Q%
M5$4@1E)/32!T86)L92(I.PIT97-T*")D96QE=&4@9G)O;2!T86)L92!W:&5R
M92!I9"!I<R!N=6QL(BD["G1E<W0H(F-R96%T92!T86)L92`H:60@:6YT96=E
M<BP@;F%M92!V87)C:&%R*#$P,"DI(BD["G1E<W0H(D-214%412!315%514Y#
M12!F;V\B*3L*=&5S="@B7")#4D5!5$4@4%)/0T5$55)%(&9O;UPB(BD["G1E
M<W0H(D=204Y4(%-%3$5#5"!/3B!T86)L92!43R!U<V5R(BD["G1E<W0H(E)%
M5D]+12!314Q%0U0@3TX@=&%B;&4@1E)/32!U<V5R(BD["G1E<W0H(E-(3U<@
M3U!424].4R(I.PIT97-T*")$4D]0(%1!0DQ%(&9O;R(I.PIT97-T*")!3%1%
M4B!404),12!F;V\@041$($-/3%5-3B`H8F%R($E.5$5'15(I(BD["G1E<W0H
M(B`@4T5,14-4("H@1E)/32!T86)L92(I.PIT97-T*"(@($1%3$5412!&4D]-
M('1A8FQE(BD["C\^"BTM1T54+2T*+2U03U-4+2T*+2U%6%!%0U0M+0IT97-T
M:6YG($1".CII<TUA;FEP+BXN"E-%3$5#5"`Z(#`*4V5L96-T(#H@,`IS96QE
M8W0@.B`P"G-%;$5#="`Z(#`*4T5,14-4(#H@,`I54$1!5$4@.B`Q"D1%3$54
M12`Z(#$*9&5L971E(#H@,0IC<F5A=&4@.B`Q"D-214%412`Z(#$*(D-214%4
M12`Z(#$*1U)!3E0@.B`Q"E)%5D]+12`Z(#$*4TA/5R`Z(#`*1%)/4"`Z(#$*
M04Q415(@.B`Q"B`Z(#`*(#H@,0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9&)?97)R;W(R+G!H<'0`````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8R,S8`,3`U,34T,S$P-3<`,#(R-S$V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"D1".CI%<G)O<B`R"BTM
M4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U
M:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP"G)E
M<75I<F5?;VYC92`G+B]I;F-L=61E+FEN8R<["G)E<75I<F5?;VYC92`G1$(N
M<&AP)SL*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@IF=6YC=&EO;B!M>69U
M;F,H)B1O8FHI('L*("`@('!R:6YT("=M>69U;F,@:&5R92P@;V)J/2<*("`@
M("`@("`@("X@<W1R=&]L;W=E<B@D;V)J+3YT;U-T<FEN9R@I*2`N(")<;B([
M"GT*9G5N8W1I;VX@;7EF=6YC,B@F)&]B:BD@>PH@("`@<')I;G0@)VUY9G5N
M8S(@:&5R92P@;V)J/2<*("`@("`@("`@("X@<W1R=&]L;W=E<B@D;V)J+3YT
M;U-T<FEN9R@I*2`N(")<;B(["GT*8VQA<W,@;7EC;&%S<R!["B`@("!F=6YC
M=&EO;B!M>69U;F,H)B1O8FHI('L*("`@("`@("!P<FEN="`G;7EC;&%S<SHZ
M;7EF=6YC(&AE<F4L(&]B:CTG"B`@("`@("`@("`N('-T<G1O;&]W97(H)&]B
M:BT^=&]3=')I;F<H*2D@+B`B7&XB.PH@("`@?0I]"F9U;F-T:6]N('1E<W1?
M97)R;W)?:&%N9&QE<B@D97)R;F\L("1E<G)M<V<L("1F:6QE+"`D;&EN92P@
M)'9A<G,I('L*("`@(&EF("AD969I;F5D*"=%7U-44DE#5"<I*2!["B`@("`@
M("`@:68@*"1E<G)N;R`F($5?4U1224-4"B`@("`@("`@("`@("8F("AE<G)O
M<E]R97!O<G1I;F<H*2`F($5?4U1224-4*2`A/2!%7U-44DE#5"D@>PH@("`@
M("`@("`@("`O+R!)9VYO<F4@15]35%))0U0@;F]T:6-E<R!U;FQE<W,@=&AE
M>2!H879E(&)E96X@='5R;F5D(&]N"B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&1E9FEN92@G15]35%))0U0G
M+"`R,#0X*3L*("`@('T*("`@("1E<G)O<G1Y<&4@/2!A<G)A>2`H"B`@("`@
M("`@15]%4E)/4B`]/B`G17)R;W(G+`H@("`@("`@($5?5T%23DE.1R`]/B`G
M5V%R;FEN9R<L"B`@("`@("`@15]005)312`]/B`G4&%R<VEN9R!%<G)O<B<L
M"B`@("`@("`@15].3U1)0T4@/3X@)TYO=&EC92<L"B`@("`@("`@15]#3U)%
M7T524D]2(#T^("=#;W)E($5R<F]R)RP*("`@("`@("!%7T-/4D5?5T%23DE.
M1R`]/B`G0V]R92!787)N:6YG)RP*("`@("`@("!%7T-/35!)3$5?15)23U(@
M/3X@)T-O;7!I;&4@17)R;W(G+`H@("`@("`@($5?0T]-4$E,15]705).24Y'
M(#T^("=#;VUP:6QE(%=A<FYI;F<G+`H@("`@("`@($5?55-%4E]%4E)/4B`]
M/B`G57-E<B!%<G)O<B<L"B`@("`@("`@15]54T527U=!4DY)3D<@/3X@)U5S
M97(@5V%R;FEN9R<L"B`@("`@("`@15]54T527TY/5$E#12`]/B`G57-E<B!.
M;W1I8V4G+`H@("`@("`@($5?4U1224-4(#T^("=3=')I8W0@3F]T:6-E)RP*
M("`@("D["B`@("`D<')E9FEX(#T@)&5R<F]R='EP95LD97)R;F]=.PH@("`@
M<')I;G0@<W1R=&]L;W=E<B@B)'!R969I>#H@)&5R<FUS9R!I;B`B("X@8F%S
M96YA;64H)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@("X@(B!O;B!L:6YE
M(%A86%QN(BD["GT*"B1O8FH@/2!N97<@;7EC;&%S<SL*"B1D8F@@/2!$0CHZ
M9F%C=&]R>2@B;7ES<6PB*3L*"G!R:6YT(")D969A=6QT.B`B.PHD92`]("1D
M8F@M/G)A:7-E17)R;W(H(G)E='5R;B!T97-T:6YG(&5R<F]R(BD["G!R:6YT
M('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI("X@(EQN(CL*"G!R:6YT(")G
M;&]B86P@9&5F875L=#H@(CL*4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27T-!3$Q"04-++"`B;7EF=6YC,B(I.PHD92`]("1D8F@M/G)A:7-E
M17)R;W(H(F=L;V)A;"!D969A=6QT('1E<W0B*3L*"B1D8F@M/G-E=$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D["G!R:6YT(")M;V1E/7!R:6YT
M.B`B.PHD92`]("1D8F@M/G)A:7-E17)R;W(H(G!R:6YT('1E<W1I;F<@97)R
M;W(B*3L*<')I;G0@(EQN(CL*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]#04Q,0D%#2RP@(FUY9G5N8R(I.PIP<FEN="`B;6]D93UF=6YC
M=&EO;B!C86QL8F%C:SH@(CL*)&4@/2`D9&)H+3YR86ES945R<F]R*")F=6YC
M=&EO;B!C86QL8F%C:R!T97-T:6YG(&5R<F]R(BD["@HD9&)H+3YS971%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL(&%R<F%Y*"1O8FHL(")M
M>69U;F,B*2D["G!R:6YT(")M;V1E/6]B:F5C="!C86QL8F%C:SH@(CL*)&4@
M/2`D9&)H+3YR86ES945R<F]R*")O8FIE8W0@8V%L;&)A8VL@=&5S=&EN9R!E
M<G)O<B(I.PH*<V5T7V5R<F]R7VAA;F1L97(H(G1E<W1?97)R;W)?:&%N9&QE
M<B(I.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?5%))1T=%
M4BD["G!R:6YT(")M;V1E/71R:6=G97(Z("(["B1E(#T@)&1B:"T^<F%I<V5%
M<G)O<B@B=')I9V=E<B!T97-T:6YG(&5R<F]R(BD["@H_/@HM+4584$5#5"TM
M"F1E9F%U;'0Z(%MD8E]E<G)O<CH@;65S<V%G93TB9&(@97)R;W(Z(')E='5R
M;B!T97-T:6YG(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T=7)N(&QE=F5L/6YO
M=&EC92!P<F5F:7@](B(@:6YF;STB(%MD8B!E<G)O<CH@=6YK;F]W;B!E<G)O
M<ETB70IG;&]B86P@9&5F875L=#H@;7EF=6YC,B!H97)E+"!O8FH]6V1B7V5R
M<F]R.B!M97-S86=E/2)D8B!E<G)O<CH@9VQO8F%L(&1E9F%U;'0@=&5S="(@
M8V]D93TM,2!M;V1E/6-A;&QB86-K(&-A;&QB86-K/6UY9G5N8S(@<')E9FEX
M/2(B(&EN9F\](B!;9&(@97)R;W(Z('5N:VYO=VX@97)R;W)=(ET*;6]D93UP
M<FEN=#H@1$(@17)R;W(Z('!R:6YT('1E<W1I;F<@97)R;W(*;6]D93UF=6YC
M=&EO;B!C86QL8F%C:SH@;7EF=6YC(&AE<F4L(&]B:CU;9&)?97)R;W(Z(&UE
M<W-A9V4](F1B(&5R<F]R.B!F=6YC=&EO;B!C86QL8F%C:R!T97-T:6YG(&5R
M<F]R(B!C;V1E/2TQ(&UO9&4]8V%L;&)A8VL@8V%L;&)A8VL];7EF=6YC('!R
M969I>#TB(B!I;F9O/2(@6V1B(&5R<F]R.B!U;FMN;W=N(&5R<F]R72)="FUO
M9&4];V)J96-T(&-A;&QB86-K.B!M>6-L87-S.CIM>69U;F,@:&5R92P@;V)J
M/5MD8E]E<G)O<CH@;65S<V%G93TB9&(@97)R;W(Z(&]B:F5C="!C86QL8F%C
M:R!T97-T:6YG(&5R<F]R(B!C;V1E/2TQ(&UO9&4]8V%L;&)A8VL@8V%L;&)A
M8VL];7EC;&%S<SHZ;7EF=6YC('!R969I>#TB(B!I;F9O/2(@6V1B(&5R<F]R
M.B!U;FMN;W=N(&5R<F]R72)="FUO9&4]=')I9V=E<CH@=7-E<B!N;W1I8V4Z
M(&1B(&5R<F]R.B!T<FEG9V5R('1E<W1I;F<@97)R;W(@:6X@<&5A<BYP:'`@
M;VX@;&EN92!X>'@*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V5R<F]R<RYI;F,`````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#,S-C$T`#$P-3$U-#,Q,#4W`#`R,C$U,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H
M92!D<FEV97)S)R!E<G)O<B!M87!P:6YG"B`J"B`J($5X96-U=&5D(&)Y(&1R
M:79E<B\Q,&5R<F]R;6%P+G!H<'0*("H*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E
M("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE
M;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("1)
M9#H@97)R;W)S+FEN8RQV(#$N,S4@,C`P-2\P,B\R."`P,CHP,CHT,2!D86YI
M96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!$971E<FUI;F4@:68@=&AE(&5R<F]R
M(&9R;VT@=&AE(&1R:79E<B!M871C:&5S('1H92!E<G)O<B!W92!E>'!E8W0*
M("H*("H@268@=&AI;F=S(&%R92!A<R!W92!E>'!E8W0L('!R:6YT(&]U="`B
M;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE(@H@*@H@*B!)9B!T:&EN9W,@9V\@
M=W)O;F<L('!R:6YT(")53D584$5#5$5$($]55$-/344B(&%N9"!D:7-P;&%Y
M('1H90H@*B!E<G)O<B=S(&EN9F]R;6%T:6]N+@H@*@H@*B!`<&%R86T@;V)J
M96-T("`D92`@("`@("`@("`@("`@("`@=&AE($1"7T5R<F]R(&]B:F5C="!F
M<F]M('1H92!Q=65R>0H@*B!`<&%R86T@:6YT("`@("`D97AP96-T961?9&)?
M8V]D92`@=&AE($1"7T524D]2*B!C;VYS=&%N="!T;R!E>'!E8W0*("H@0'!A
M<F%M(&)O;VQE86X@)'-H;W5L9%]B95]E<G)O<B`@(&1O97,@=&AE($1"35,@
M8V]N<VED97(@=&AI<R!A;B!E<G)O<C\*("H*("H@0')E='5R;B!V;VED"B`J
M+PIF=6YC=&EO;B!C:&5C:U]E<G)O<B@D92P@)&5X<&5C=&5D7V1B7V-O9&4L
M("1S:&]U;&1?8F5?97)R;W(@/2!T<G5E*2!["B`@("!I9B`H)'-H;W5L9%]B
M95]E<G)O<BD@>PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D92DI('L*("`@
M("`@("`@("`@:68@*"1E+3YG971#;V1E*"D@/3T@)&5X<&5C=&5D7V1B7V-O
M9&4I('L*("`@("`@("`@("`@("`@('!R:6YT(")M871C:&5S(&5X<&5C=&5D
M(&]U=&-O;65<;B(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!P<FEN="`B54Y%6%!%0U1%1"!/551#3TU%+BXN7&XB.PH@("`@("`@
M("`@("`@("`@<')I;G0@)R`@("!014%2.CI$0B!E<G)O<F-O9&4Z("<@+B`D
M92T^9V5T0V]D92@I("X@(EQN(CL*("`@("`@("`@("`@("`@('!R:6YT("<@
M("`@)R`N("1E+3YG9715<V5R26YF;R@I("X@(EQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT(")<;B`@("!5
M3D584$5#5$5$($]55$-/344N+BX@97AP96-T960@97)R;W(@8G5T(&ET('=A
M<VXG=%QN(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D92DI('L*("`@("`@("`@("`@<')I;G0@(E5.15A014-4
M140@3U540T]-12XN+B!D:61N)W0@97AP96-T(&5R<F]R(&)U="!I="!W87-<
M;B(["B`@("`@("`@("`@('!R:6YT("<@("`@4$5!4CHZ1$(@97)R;W)C;V1E
M.B`G("X@)&4M/F=E=$-O9&4H*2`N(")<;B(["B`@("`@("`@("`@('!R:6YT
M("<@("`@)R`N("1E+3YG9715<V5R26YF;R@I("X@(EQN(CL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B;6%T8VAE<R!E>'!E8W1E9"!O
M=71C;VUE7&XB.PH@("`@("`@('T*("`@('T*?0H*+RHJ"B`J($QO8V%L(&5R
M<F]R(&-A;&QB86-K(&AA;F1L97(*("H@"B`J($!P87)A;2!O8FIE8W0@("1O
M("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T
M:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%
M<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!P<FEN
M="`B7&XM+2TM+2TM+2TM+2TM+2U<;B(["B`@("!P<FEN="`B2&%V:6YG('!R
M;V)L96US(&-R96%T:6YG(&$@=&%B;&4@9F]R('1E<W1I;F<N+BY<;B(["B`@
M("!P<FEN="`D;RT^9V5T1&5B=6=);F9O*"D@+B`B7&XB.PH@("`@<')I;G0@
M(BTM+2TM+2TM+2TM+2TM+5QN(CL*?0H*"B1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH*"G!R:6YT("=$0E]%4E)/4E].3U-5
M0TA404),12!F;W(@<V5L96-T.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y*"=3
M14Q%0U0@*B!&4D]-('1A8FQE5&AA='-";V=U<R<I.PIC:&5C:U]E<G)O<B@D
M<F5S+"!$0E]%4E)/4E].3U-50TA404),12D["@IP<FEN="`G1$)?15)23U)?
M3D]354-(5$%"3$4@9F]R(&1R;W`Z("`G.PHD<F5S(#T@9')O<%]T86)L92@D
M9&)H+"`G=&%B;&54:&%T<T)O9W5S)RD["F-H96-K7V5R<F]R*"1R97,L($1"
M7T524D]27TY/4U5#2%1!0DQ%*3L*"G!R:6YT("=$0E]%4E)/4E].3U1?1D]5
M3D0@9F]R(&1R;W`@:6YD97@Z("`G.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4@
M+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>"D@>PH@("`@8V%S92`G9F)S<6PZ9F)S
M<6PG.@H@("`@8V%S92`G:6)A<V4Z9FER96)I<F0G.@H@("`@8V%S92`G:6)A
M<V4Z:6)A<V4G.@H@("`@8V%S92`G:69X.FEF>"<Z"B`@("!C87-E("=O9&)C
M.F1B,B<Z"B`@("!C87-E("=O8VDX.F]C:3@G.@H@("`@8V%S92`G<&=S<6PZ
M<&=S<6PG.@H@("`@8V%S92`G<W%L:71E.G-Q;&ET92<Z"B`@("`@("`@)')E
M<R`]("1D8F@M/G%U97)Y*"=$4D]0($E.1$58(&9A:V5I;F1E>"<I.PH@("`@
M("`@(&)R96%K.PH@("`@8V%S92`G;7-S<6PZ;7-S<6PG.@H@("`@8V%S92`G
M<WEB87-E.G-Y8F%S92<Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=$
M4D]0($E.1$58('!H<'1E<W0N9F%K96EN9&5X)RD["B`@("`@("`@8G)E86L[
M"B`@("!C87-E("=M<W%L.FUS<6PG.@H@("`@("`@("1R97,@/2`D9&)H+3YQ
M=65R>2@G1%)/4"!)3D1%6"!F86ME:6YD97@@1E)/32!P:'!T97-T)RD["B`@
M("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@("1R97,@/2`D9&)H
M+3YQ=65R>2@G1%)/4"!)3D1%6"!F86ME:6YD97@@3TX@<&AP=&5S="<I.PI]
M"F-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TY/5%]&3U5.1"D["@H*<')I
M;G0@)T1"7T524D]27T%,4D5!1%E?15A)4U13(&9O<B!C<F5A=&4@=&%B;&4Z
M("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH)'1E<W1?;6MT86)L95]Q=65R>2D[
M"F-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T%,4D5!1%E?15A)4U13*3L*
M"G!R:6YT("=$0E]%4E)/4E]!3%)%04197T5825-44R!F;W(@8W)E871E(&EN
M9&5X.B`@)SL*)')E<R`](&1R;W!?=&%B;&4H)&1B:"P@)V$G*3L*)&1B:"T^
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD[
M"B1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%(&$@*&$@24Y414=%
M4BDG*3L*)&1B:"T^<&]P17)R;W)(86YD;&EN9R@I.PHD<F5S(#T@)&1B:"T^
M<75E<GDH)T-214%412!)3D1%6"!A85]I9'@@3TX@82`H82DG*3L*)')E<R`]
M("1D8F@M/G%U97)Y*"=#4D5!5$4@24Y$15@@86%?:61X($].(&$@*&$I)RD[
M"G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G9F)S<6PG.@H@
M("`@("`@("\O($9R;VYT0F%S92!D;V5S;B=T(&%S<VEG;B!A('-P96-I9FEC
M(&-O9&4@9F]R('1H:7,@>65T+@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L
M($1"7T524D]27T%,4D5!1%E?15A)4U13+"!F86QS92D["B`@("`@("`@8G)E
M86L["B`@("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"
M7T524D]27T%,4D5!1%E?15A)4U13*3L*?0HD<F5S(#T@9')O<%]T86)L92@D
M9&)H+"`G82<I.PH*"G!R:6YT("=$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!P
M<FEM87)Y(&ME>2!I;G-E<G0@9'5P;&EC871E.B`@)SL*)')E<R`](&1R;W!?
M=&%B;&4H)&1B:"P@)V$G*3L*)&1B:"T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["G-W:71C:"`H)&1B:"T^<&AP='EP
M92D@>PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U
M97)Y*"=#4D5!5$4@5$%"3$4@82`H82!)3E1%1T52($Y/5"!.54Q,*2<I.PH@
M("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%5.25%512!)3D1%
M6"!A<&L@3TX@82`H82DG*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z
M"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@82`H
M82!)3E1%1T52($Y/5"!.54Q,+"!04DE-05)9($M%62`H82DI)RD["GT*)&1B
M:"T^<&]P17)R;W)(86YD;&EN9R@I.PHD<F5S(#T@)&1B:"T^<75E<GDH)TE.
M4T525"!)3E1/(&$@5D%,5453("@Q*2<I.PHD<F5S(#T@)&1B:"T^<75E<GDH
M)TE.4T525"!)3E1/(&$@5D%,5453("@Q*2<I.PIC:&5C:U]E<G)O<B@D<F5S
M+"!$0E]%4E)/4E]#3TY35%)!24Y4*3L*"@IP<FEN="`G1$)?15)23U)?0T].
M4U1204E.5"!F;W(@<')I;6%R>2!K97D@=7!D871E(&1U<&QI8V%T93H@("<[
M"B1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@82!604Q515,@*#(I
M)RD["B1R97,@/2`D9&)H+3YQ=65R>2@G55!$051%(&$@4T54(&$],2!72$52
M12!A/3(G*3L*8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?0T].4U1204E.
M5"D["@H*<')I;G0@)T1"7T524D]27T-/3E-44D%)3E0@9F]R('5N:7%U92!K
M97D@:6YS97)T(&1U<&QI8V%T93H@("<["B1R97,@/2!D<F]P7W1A8FQE*"1D
M8F@L("=A)RD["B1D8F@M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M0T%,3$)!0TLL("=P92<I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@
M(&-A<V4@)VUS<6PG.@H@("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%
M051%(%1!0DQ%(&$@*&$@24Y414=%4B!.3U0@3E5,3"DG*3L*("`@("`@("`D
M<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!53DE1544@24Y$15@@875K($].
M(&$@*&$I)RD["B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@
M("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%(&$@*&$@24Y414=%
M4B!.3U0@3E5,3"P@54Y)455%("AA*2DG*3L*?0HD9&)H+3YP;W!%<G)O<DAA
M;F1L:6YG*"D["B1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@82!6
M04Q515,@*#$I)RD["B1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@
M82!604Q515,@*#$I)RD["F-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T-/
M3E-44D%)3E0I.PH*"G!R:6YT("=$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!U
M;FEQ=64@:V5Y('5P9&%T92!D=7!L:6-A=&4Z("`G.PHD<F5S(#T@)&1B:"T^
M<75E<GDH)TE.4T525"!)3E1/(&$@5D%,5453("@R*2<I.PHD<F5S(#T@)&1B
M:"T^<75E<GDH)U501$%412!A(%-%5"!A/3$@5TA%4D4@83TR)RD["F-H96-K
M7V5R<F]R*"1R97,L($1"7T524D]27T-/3E-44D%)3E0I.PH*"G!R:6YT("=$
M0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!F;W)E:6=N(&ME>2!O;B!I;G-E<G0Z
M("`G.PHD<F5S(#T@9')O<%]T86)L92@D9&)H+"`G8B<I.PHD<F5S(#T@9')O
M<%]T86)L92@D9&)H+"`G82<I.PHD9&)H+3YP=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27T-!3$Q"04-++"`G<&4G*3L*<W=I=&-H("@D9&)H+3YP:'!T
M>7!E*2!["B`@("!C87-E("=M>7-Q;"<Z"B`@("!C87-E("=M>7-Q;&DG.@H@
M("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%(&$@*&$@
M24Y4($Y/5"!.54Q,+"`G"B`@("`@("`@("`@("`@("`@("`@+B`G4%))34%2
M62!+15D@*&$I*2`G"B`@("`@("`@("`@("`@("`@("`@+B`G5%E013U)3DY/
M1$(G*3L*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!404),
M12!B("AB($E.5"P@)PH@("`@("`@("`@("`@("`@("`@("X@)TE.1$58('!A
M<E]I;F0@*&(I+"`G"B`@("`@("`@("`@("`@("`@("`@+B`G1D]214E'3B!+
M15D@*&(I(%)%1D5214Y#15,@82`H82DI("<*("`@("`@("`@("`@("`@("`@
M("`N("=465!%/4E.3D]$0B<I.PH@("`@("`@("1D8F@M/G!O<$5R<F]R2&%N
M9&QI;F<H*3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=M<W%L)SH*("`@
M("`@("`O+R!M<W%L(&1O97,@;F]T('-U<'!O<G0@9F]R96EG;B!K97ES"B`@
M("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@82`H82!)
M3E1%1T52($Y/5"!.54Q,*2<I.PH@("`@("`@("1R97,@/2`D9&)H+3YQ=65R
M>2@G0U)%051%(%5.25%512!)3D1%6"!A=6L@3TX@82`H82DG*3L*("`@("`@
M("`D9&)H+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@)')E<R`]("1D
M8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@8B`H8B!)3E1%1T52(%)%1D5214Y#
M15,@82`H82DI)RD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2![
M"B`@("`@("`@("`@('!R:6YT(")M871C:&5S(&5X<&5C=&5D(&]U=&-O;65<
M;B(["B`@("`@("`@("`@('!R:6YT(")$0E]%4E)/4E]#3TY35%)!24Y4(&9O
M<B!F;W)E:6=N(&ME>2!O;B!D96QE=&4Z("!M871C:&5S(&5X<&5C=&5D(&]U
M=&-O;65<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@
M(E=/5RP@:70@<V5E;7,@;5-13"!N;W<@<W5P<&]R=',@<F5F97)E;F-E<UQN
M(CL*("`@("`@("`@("`@<')I;G0@(E=/5RP@:70@<V5E;7,@;5-13"!N;W<@
M<W5P<&]R=',@<F5F97)E;F-E<UQN(CL*("`@("`@("!]"B`@("`@("`@8G)E
M86L["@H@("`@9&5F875L=#H*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH
M)T-214%412!404),12!A("AA($E.5$5'15(@3D]4($Y53$PL(%!224U!4ED@
M2T59("AA*2DG*3L*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%4
M12!404),12!B("AB($E.5$5'15(@4D5&15)%3D-%4R!A("AA*2DG*3L*("`@
M("`@("`D9&)H+3YP;W!%<G)O<DAA;F1L:6YG*"D["GT*"FEF("@D9&)H+3YP
M:'!T>7!E("$]("=M<W%L)RD@>PH@("`@)')E<R`]("1D8F@M/G%U97)Y*"=)
M3E-%4E0@24Y43R!A("AA*2!V86QU97,@*#$I)RD["B`@("`D<F5S(#T@)&1B
M:"T^<75E<GDH)TE.4T525"!)3E1/(&(@*&(I('9A;'5E<R`H,BDG*3L*("`@
M('-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@("`@(&-A<V4@)W-Q;&ET
M92<Z"B`@("`@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T-/
M3E-44D%)3E0L(&9A;'-E*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)2
M3U)?0T].4U1204E.5"D["B`@("!]("`@"@H@("`@<')I;G0@)T1"7T524D]2
M7T-/3E-44D%)3E0@9F]R(&9O<F5I9VX@:V5Y(&]N(&1E;&5T93H@("<["B`@
M("`D<F5S(#T@)&1B:"T^<75E<GDH)TE.4T525"!)3E1/(&(@*&(I('9A;'5E
M<R`H,2DG*3L*("`@("1R97,@/2`D9&)H+3YQ=65R>2@G1$5,151%($923TT@
M82!72$5212!A(#T@,2<I.PH@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E*2![
M"B`@("`@("`@8V%S92`G<W%L:71E)SH*("`@("`@("`@("`@8VAE8VM?97)R
M;W(H)')E<RP@1$)?15)23U)?0T].4U1204E.5"P@9F%L<V4I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!C:&5C
M:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y4*3L*("`@('T*?0H*
M"G!R:6YT("=$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,(&]N(&EN<V5R
M=#H@("<["B1R97,@/2!D<F]P7W1A8FQE*"1D8F@L("=P96%R=&5S=&YU;&PG
M*3L*)&1B:"T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#
M2RP@)W!E)RD["B1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%('!E
M87)T97-T;G5L;"`H82!#2$%2*#,I($Y/5"!.54Q,*2<I.PHD9&)H+3YP;W!%
M<G)O<DAA;F1L:6YG*"D["B1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.
M5$\@<&5A<G1E<W1N=6QL(%9!3%5%4R`H3E5,3"DG*3L*8VAE8VM?97)R;W(H
M)')E<RP@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"D["@H*<')I;G0@
M)T1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$P@;VX@=7!D871E.B`@)SL*
M)')E<R`]("1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P96%R=&5S=&YU;&P@
M5D%,5453("@G;VYE)RDB*3L*)')E<R`]("1D8F@M/G%U97)Y*")54$1!5$4@
M<&5A<G1E<W1N=6QL(%-%5"!A(#T@3E5,3"!72$5212!A(#T@)V]N92<B*3L*
M<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=M>7-Q;"<Z"B`@
M("!C87-E("=M>7-Q;&DG.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"
M7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL(&9A;'-E*3L*("`@("`@("!B
M<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@
M1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"D["GT*"@IP<FEN="`G1$)?
M15)23U)?3D]354-(1DE%3$0@:F]I;FEN9R!/3B!B;V=U<R!C;VQU;6XZ("`G
M.PHD<F5S(#T@)&1B:"T^<75E<GDH)U-%3$5#5"`J($923TT@<&AP=&5S="!*
M3TE.(&$@3TX@*'!H<'1E<W0N82`](&$N8BDG*3L*<W=I=&-H("@D9&)H+3YP
M:'!T>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87@I('L*("`@(&-A<V4@)VUS
M<6PZ;7-Q;"<Z"B`@("!C87-E("=O9&)C.F%C8V5S<R<Z"B`@("`@("`@8VAE
M8VM?97)R;W(H)')E<RP@1$)?15)23U)?4UE.5$%8*3L*("`@("`@("!B<F5A
M:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?
M15)23U)?3D]354-(1DE%3$0I.PI]"@H*<')I;G0@)T1"7T524D]27TY/4U5#
M2$9)14Q$(&IO:6YI;F<@55-)3D<@8F]G=7,@8V]L=6UN.B`@)SL*)')E<R`]
M("1D8F@M/G%U97)Y*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@2D])3B!A(%53
M24Y'("AB*2<I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H
M+3YD8G-Y;G1A>"D@>PH@("`@8V%S92`G:6)A<V4Z:6)A<V4G.@H@("`@8V%S
M92`G:6)A<V4Z9FER96)I<F0G.@H@("`@8V%S92`G;7-Q;#IM<W%L)SH*("`@
M(&-A<V4@)V]D8F,Z86-C97-S)SH*("`@(&-A<V4@)V]D8F,Z9&(R)SH*("`@
M(&-A<V4@)W-Y8F%S93IS>6)A<V4G.@H@("`@("`@(&-H96-K7V5R<F]R*"1R
M97,L($1"7T524D]27U-93E1!6"D["B`@("`@("`@8G)E86L["B`@("!D969A
M=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TY/4U5#
M2$9)14Q$*3L*?0H*"G!R:6YT("=$0E]%4E)/4E]$259:15)/.B`@)SL*+R\@
M26YT97)B87-E(&1E=&5C=',@=&AE(&5R<F]R(&]N(&9E=&-H:6YG"B1R97,@
M/2`D9&)H+3YG971!;&PH)U-%3$5#5"`P+S`@1E)/32!P:'!T97-T)RD["G-W
M:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G;V1B8R<Z"B`@("`@
M("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@("`@("!C87-E
M("=A8V-E<W,G.@H@("`@("`@("`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@
M1$)?15)23U)?1$E66D523RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)V1B,B<Z"B`@("`@("`@("`@("`@("!C
M:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]$259:15)/*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*("`@(&-A
M<V4@)VEB87-E)SH*("`@(&-A<V4@)VEF>"<Z"B`@("!C87-E("=F8G-Q;"<Z
M"B`@("!C87-E("=M<W-Q;"<Z"B`@("!C87-E("=M>7-Q;"<Z"B`@("!C87-E
M("=M>7-Q;&DG.@H@("`@8V%S92`G<W%L:71E)SH*("`@(&-A<V4@)W-Y8F%S
M92<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?1$E66D52
M3RP@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G;7-Q;"<Z"B`@
M("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?4UE.5$%8*3L*("`@
M("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H
M)')E<RP@1$)?15)23U)?1$E66D523RD["GT*"@IP<FEN="`G1$)?15)23U)?
M24Y604Q)1%].54U"15(@<'5T=&EN9R!C:&%R<R!I;B!)3E0@8V]L=6UN.B`@
M)SL*)')E<R`]("1D8F@M/G%U97)Y*")54$1!5$4@<&AP=&5S="!3150@82`]
M("=A8F,G(%=(15)%(&$@/2`T,B(I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I
M('L*("`@(&-A<V4@)VUY<W%L)SH*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("!C
M87-E("=S<6QI=&4G.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T52
M4D]27TE.5D%,241?3E5-0D52+"!F86QS92D["B`@("`@("`@8G)E86L["B`@
M("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]2
M7TE.5D%,241?3E5-0D52*3L*?0H*"G!R:6YT("=$0E]%4E)/4E])3E9!3$E$
M7TY534)%4B!P=71T:6YG(&9L;V%T(&EN($E.5"!C;VQU;6XZ("`G.PHD<F5S
M(#T@)&1B:"T^<75E<GDH(E501$%412!P:'!T97-T(%-%5"!A(#T@."XY(%=(
M15)%(&$@/2`T,B(I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A
M<V4@)V9B<W%L)SH*("`@(&-A<V4@)VEB87-E)SH*("`@(&-A<V4@)VEF>"<Z
M"B`@("!C87-E("=M<W-Q;"<Z"B`@("!C87-E("=M>7-Q;"<Z"B`@("!C87-E
M("=M>7-Q;&DG.@H@("`@8V%S92`G;V-I."<Z"B`@("!C87-E("=O9&)C)SH*
M("`@(&-A<V4@)W!G<W%L)SH*("`@(&-A<V4@)W-Q;&ET92<Z"B`@("`@("`@
M8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y604Q)1%].54U"15(L(&9A
M;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE
M8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y604Q)1%].54U"15(I.PI]"@H*
M<')I;G0@)T1"7T524D]27TE.5D%,241?3E5-0D52('!U='1I;F<@97AC97-S
M:79E(&EN="!I;B!)3E0@8V]L=6UN.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y
M*")54$1!5$4@<&AP=&5S="!3150@82`](#$X-#0V-S0T,#<S-S`Y-34Q-C$V
M(%=(15)%(&$@/2`T,B(I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4@+B`G.B<@
M+B`D9&)H+3YD8G-Y;G1A>"D@>PH@("`@8V%S92`G:6)A<V4Z:6)A<V4G.@H@
M("`@8V%S92`G:6)A<V4Z9FER96)I<F0G.@H@("`@("`@(&-H96-K7V5R<F]R
M*"1R97,L($1"7T524D]27U-93E1!6"D["B`@("`@("`@8G)E86L["B`@("!C
M87-E("=F8G-Q;#IF8G-Q;"<Z"B`@("!C87-E("=M<W%L.FUS<6PG.@H@("`@
M8V%S92`G;7-S<6PZ;7-S<6PG.@H@("`@8V%S92`G;7ES<6PZ;7ES<6PG.@H@
M("`@8V%S92`G;7ES<6QI.FUY<W%L:2<Z"B`@("!C87-E("=O8VDX.F]C:3@G
M.@H@("`@8V%S92`G;V1B8SIA8V-E<W,G.@H@("`@8V%S92`G<W%L:71E.G-Q
M;&ET92<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y6
M04Q)1%].54U"15(L(&9A;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U
M;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y604Q)
M1%].54U"15(I.PI]"@H*<')I;G0@)T1"7T524D]27TE.5D%,241?3E5-0D52
M('!U='1I;F<@:6YT(&EN($-(05(@8V]L=6UN.B`@)SL*)')E<R`]("1D8F@M
M/G%U97)Y*")54$1!5$4@<&AP=&5S="!3150@8B`](#@@5TA%4D4@82`](#0R
M(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92`N("<Z)R`N("1D8F@M/F1B<WEN
M=&%X*2!["B`@("!C87-E("=I8F%S93II8F%S92<Z"B`@("!C87-E("=I8F%S
M93IF:7)E8FER9"<Z"B`@("!C87-E("=I9G@Z:69X)SH*("`@(&-A<V4@)VUS
M<W%L.FUS<W%L)SH*("`@(&-A<V4@)VUY<W%L.FUY<W%L)SH*("`@(&-A<V4@
M)VUY<W%L:3IM>7-Q;&DG.@H@("`@8V%S92`G;V-I.#IO8VDX)SH*("`@(&-A
M<V4@)V]D8F,Z86-C97-S)SH*("`@(&-A<V4@)W!G<W%L.G!G<W%L)SH*("`@
M(&-A<V4@)W-Q;&ET93IS<6QI=&4G.@H@("`@("`@(&-H96-K7V5R<F]R*"1R
M97,L($1"7T524D]27TE.5D%,241?3E5-0D52+"!F86QS92D["B`@("`@("`@
M8G)E86L["B`@("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L
M($1"7T524D]27TE.5D%,241?3E5-0D52*3L*?0H*"G!R:6YT("=$0E]%4E)/
M4E].3U-50TA&245,1#H@("<["B1R97,@/2`D9&)H+3YQ=65R>2@G4T5,14-4
M(&4@1E)/32!P:'!T97-T)RD["F-H96-K7V5R<F]R*"1R97,L($1"7T524D]2
M7TY/4U5#2$9)14Q$*3L*"@IP<FEN="`G1$)?15)23U)?4UE.5$%8.B`@)SL*
M)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4G*3L*8VAE8VM?97)R;W(H)')E
M<RP@1$)?15)23U)?4UE.5$%8*3L*"@IP<FEN="`G1$)?15)23U)?5D%,545?
M0T]53E1?3TY?4D]7.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@
M24Y43R!P:'!T97-T("AA*2!604Q515,@*#8W."P@,BDG*3L*<W=I=&-H("@D
M9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=M<W%L)SH*("`@("`@("!C:&5C
M:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L(&9A
M;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE
M8VM?97)R;W(H)')E<RP@1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7*3L*
M?0H*"G!R:6YT("=$0E]%4E)/4E])3E9!3$E$(&]N($-(05(@8V]L=6UN(&1A
M=&$@=&]O(&QO;F<Z("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH(DE.4T525"!)
M3E1/('!H<'1E<W0@*&(I(%9!3%5%4R`H)S$R,S0U-C<X.2XQ,C,T-38W.#DN
M,3(S-#4V-S@Y+C$R,S0U-C<X.2XQ)RDB*3L*<W=I=&-H("@D9&)H+3YP:'!T
M>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87@I('L*("`@(&-A<V4@)VUS<6PZ
M;7-Q;"<Z"B`@("!C87-E("=M<W-Q;#IM<W-Q;"<Z"B`@("!C87-E("=M>7-Q
M;#IM>7-Q;"<Z"B`@("!C87-E("=M>7-Q;&DZ;7ES<6QI)SH*("`@(&-A<V4@
M)V]D8F,Z86-C97-S)SH*("`@(&-A<V4@)W-Q;&ET93IS<6QI=&4G.@H@("`@
M8V%S92`G<WEB87-E.G-Y8F%S92<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E
M<RP@1$)?15)23U)?24Y604Q)1"P@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@
M("`@8V%S92`G9F)S<6PZ9F)S<6PG.@H@("`@("`@(&-H96-K7V5R<F]R*"1R
M97,L($1"7T524D]27U1254Y#051%1"D["B`@("`@("`@8G)E86L["B`@("!D
M969A=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TE.
M5D%,240I.PI]"@H*<')I;G0@)T1"7T524D]27TE.5D%,240@;VX@5D%20TA!
M4B!C;VQU;6X@9&%T82!T;V\@;&]N9SH@("<["B1R97,@/2`D9&)H+3YQ=65R
M>2@B24Y315)4($E.5$\@<&AP=&5S="`H9"D@5D%,5453("@G,3(S-#4V-S@Y
M+C$R,S0U-C<X.2XQ)RDB*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E("X@)SHG
M("X@)&1B:"T^9&)S>6YT87@I('L*("`@(&-A<V4@)VUS<6PZ;7-Q;"<Z"B`@
M("!C87-E("=M<W-Q;#IM<W-Q;"<Z"B`@("!C87-E("=M>7-Q;#IM>7-Q;"<Z
M"B`@("!C87-E("=M>7-Q;&DZ;7ES<6QI)SH*("`@(&-A<V4@)V]D8F,Z86-C
M97-S)SH*("`@(&-A<V4@)W-Q;&ET93IS<6QI=&4G.@H@("`@8V%S92`G<WEB
M87-E.G-Y8F%S92<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)2
M3U)?24Y604Q)1"P@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G
M9F)S<6PZ9F)S<6PG.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T52
M4D]27U1254Y#051%1"D["B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@
M("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TE.5D%,240I.PI]
M"@H*"F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*9')O<%]T86)L92@D
M9&)H+"`G8B<I.PID<F]P7W1A8FQE*"1D8F@L("=A)RD["F1R;W!?=&%B;&4H
M)&1B:"P@)W!E87)T97-T;G5L;"<I.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]F971C:&UO9&5?;V)J96-T+FEN8P``````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C(R-P`Q,#4Q-30S,3`U-P`P,C0Q,C``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@
M9')I=F5R<R<@;V)J96-T(&9E=&-H(&UO9&4@<')O8V5D=7)E<PH@*@H@*B!%
M>&5C=71E9"!B>2!D<FEV97(O,31F971C:&UO9&5?;V)J96-T+G!H<'0*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@("1)9#H@9F5T8VAM;V1E7V]B:F5C="YI;F,L
M=B`Q+C$Q(#(P,#4O,#(O,#,@,#4Z-#DZ-#0@9&%N:65L8R!%>'`@)`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO
M"@IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*+RHJ"B`J($QO8V%L(&5R<F]R
M(&-A;&QB86-K(&AA;F1L97(*("H*("H@1')O<',@=&AE('!H<'1E<W0@=&%B
M;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@=&AE
M"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2(&5R
M<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE=&AO
M9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L
M:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@)&1B:#L*
M"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@("!D:64H
M)&\M/G1O4W1R:6YG*"DI.PI]"@HO*BH*("H@4')I;G0@;W5T('1H92!O8FIE
M8W0*("HO"F9U;F-T:6]N('!R:6YT7V]B:B@F)&]B:BD@>PH@("`@:68@*"%I
M<U]O8FIE8W0H)&]B:BDI('L*("`@("`@("!E8VAO(")%4E)/4CH@;F\@;V)J
M96-T(5QN(CL*("`@('T@96QS92!["B`@("`@("`@96-H;R!S=')T;VQO=V5R
M*&=E=%]C;&%S<R@D;V)J*2D@+B`G("T^("<@+B!I;7!L;V1E*"<@)RP@87)R
M87E?:V5Y<R@H87)R87DI)&]B:BDI("X@(EQN(CL*("`@('T*?0H*"B1D8F@M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD[
M"@IE8VAO("(M+2T@9F5T8V@@=VET:"!P87)A;2!$0E]&151#2$U/1$5?3T)*
M14-4("TM+5QN(CL*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-
M('!H<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W*$1"7T9%5$-(34]$
M15]/0DI%0U0I.PIP<FEN=%]O8FHH)')O=RD["B1S=&@M/F9R964H*3L@("\O
M(&ME97`@9F)S<6P@:&%P<'DN"@HD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#
M5"`J($923TT@<&AP=&5S="(I.PHD<W1H+3YF971C:$EN=&\H)')O=RP@1$)?
M1D540TA-3T1%7T]"2D5#5"D["G!R:6YT7V]B:B@D<F]W*3L*)'-T:"T^9G)E
M92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"F5C:&\@(BTM+2!F971C:"!W
M:71H(&1E9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(34]$15]/0DI%0U0@+2TM
M7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]"2D5#5"D[
M"B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD[
M"B1R;W<@/2`D<W1H+3YF971C:%)O=R@I.PIP<FEN=%]O8FHH)')O=RD["B1S
M=&@M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@HD<W1H(#T@)&1B
M:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<W1H+3YF971C
M:$EN=&\H)')O=RD["G!R:6YT7V]B:B@D<F]W*3L*)'-T:"T^9G)E92@I.R`@
M+R\@:V5E<"!F8G-Q;"!H87!P>2X*"F5C:&\@(BTM+2!F971C:"!W:71H(&1E
M9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(34]$15]/0DI%0U0@86YD(&-L87-S
M($1"7W)O=R`M+2U<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/
M1$5?3T)*14-4+"`G1$)?<F]W)RD["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,
M14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@/2`D<W1H+3YF971C:%)O=R@I
M.PIP<FEN=%]O8FHH)')O=RD["B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S
M<6P@:&%P<'DN"@HD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@
M<&AP=&5S="(I.PHD<W1H+3YF971C:$EN=&\H)')O=RD["G!R:6YT7V]B:B@D
M<F]W*3L*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"F5C
M:&\@(BTM+2!F971C:"!W:71H(&1E9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(
M34]$15]/0DI%0U0@=VET:"!N;R!C;&%S<R!T:&5N($1"7W)O=R`M+2U<;B([
M"B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?3T)*14-4*3L*)'-T
M:"`]("1D8F@M/G%U97)Y*"=314Q%0U0@*B!&4D]-('!H<'1E<W0G*3L*)')O
M=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT7V]B:B@D<F]W*3L*)'-T:"T^
M9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"B1D8F@M/G-E=$9E=&-H
M36]D92A$0E]&151#2$U/1$5?3T)*14-4+"`G1$)?<F]W)RD["B1S=&@@/2`D
M9&)H+3YQ=65R>2@G4T5,14-4("H@1E)/32!P:'!T97-T)RD["B1R;W<@/2`D
M<W1H+3YF971C:%)O=R@I.PIP<FEN=%]O8FHH)')O=RD["@HD<W1H+3YF<F5E
M*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H@("`@("`@("`@("`@("`O+R!K
M965P(&EB87-E(&AA<'!Y.B!C86XG="!D<F]P('1B;"!T:&%T(&AA<R!R97-U
M;'1S(&]P96X@86=A:6YS="!I="X*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T
M)RD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9F5T8VAM;V1E<RYI;F,`````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3,S-C(`,3`U,34T,S$P-3<`,#(R-S4S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@=&AE
M(&1R:79E<G,G('9A<FEO=7,@9F5T8V@@;65T:&]D<PH@*@H@*B!%>&5C=71E
M9"!B>2!D<FEV97(O,#)F971C:"YP:'!T"B`J"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C
M:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD
M86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@
M4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@
M("`D260Z(&9E=&-H;6]D97,N:6YC+'8@,2XQ,2`R,#`U+S`R+S$T(#$W.C`T
M.C$T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($QO8V%L(&5R<F]R(&-A
M;&QB86-K(&AA;F1L97(*("H*("H@1')O<',@=&AE('!H<'1E<W0@=&%B;&4L
M('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@=&AE"B`J
M('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2(&5R<F]R
M(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE=&AO9`H@
M*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG
M*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@)&1B:#L*"B`@
M("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*
M("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@("!D:64H)&\M
M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?0T%,3$)!0TLL("=P92<I.PHD9&)H+3YS971/<'1I;VXH)V%U=&]F
M<F5E)RP@=')U92D["@HD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S
M="!604Q515,@*#$L("=O;F4G+"`G3VYE)RP@)S(P,#$M,#(M,38G*2(I.PHD
M9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,@*#(L("=T
M=V\G+"`G5'=O)RP@)S(P,#$M,#(M,34G*2(I.PHD9&)H+3YQ=65R>2@B24Y3
M15)4($E.5$\@<&AP=&5S="!604Q515,@*#,L("=T:')E92<L("=4:')E92<L
M("<R,#`Q+3`R+3$T)RDB*3L*"G!R:6YT(")T97-T:6YG(&9E=&-H<F]W.EQN
M(CL*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B
M*3L*9F]R("@D:2`](#$[("1I(#P](#4[("1I*RLI('L*("`@('!R:6YT(")R
M;W<@)&DZ("(["B`@("`D<F]W(#T@)'-T:"T^9F5T8VA2;W<H*3L*("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<F]W*2D@>PH@("`@("`@('!R:6YT("1R;W<M/G1O
M4W1R:6YG*"D@+B`B7&XB.PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H@("`@
M:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@("`@("`@<')I;G0@:6UP;&]D92@G
M+"`G+"`D<F]W*2`N(")<;B(["B`@("!](&5L<V4@>PH@("`@("`@('9A<E]D
M=6UP*"1R;W<I.PH@("`@?0I]"B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S
M<6P@:&%P<'DN"@HD9&)H+3YQ=65R>2@G1$5,151%($923TT@<&AP=&5S="!7
M2$5212!A(#P^(#0R)RD["@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@
M9F5T8VAR;W<@9&5F875L="!D969A=6QT+"!P;W)T86)I;&ET>2!M;V1E($1"
M7U!/4E1!0DE,25197T%,3"!>($1"7U!/4E1!0DE,25197U)44DE-7&XB.PHD
M9&)H+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?
M04Q,(%X@1$)?4$]25$%"24Q)5%E?4E1224TI.PHD<W1H(#T@)&1B:"T^<75E
M<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T
M8VA2;W<H*3L*<')I;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI
M+B)<;B(["B1A8W1U86P@/2!I;7!L;V1E*"<@)RP@87)R87E?=F%L=65S*"1R
M;W<I*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=F8G-Q
M;"<Z"B`@("!C87-E("=M<W%L)SH*("`@(&-A<V4@)VUY<W%L)SH*("`@(&-A
M<V4@)VUY<W%L:2<Z"B`@("!C87-E("=S<6QI=&4G.@H@("`@("`@("1E>'!E
M8W1E9"`]("<T,B!B:6YG(%1H:7,@:7,@82!T97-T(#$Y.3DM,3$M,C$G.PH@
M("`@("`@(&)R96%K.PH@("`@8V%S92`G:69X)SH*("`@("`@("`D97AP96-T
M960@/2`G-#(@8FEN9R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!4:&ES(&ES(&$@=&5S="`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,3DY.2TQ,2TR
M,2`@("`@("`@("`G.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@
M("`@("`D97AP96-T960@/2`G-#(@8FEN9R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!4:&ES(&ES(&$@=&5S="`Q.3DY+3$Q+3(Q)SL*
M?0II9B`H)&%C='5A;"`]/2`D97AP96-T960I('L*("`@(&5C:&\@(F]U='!U
M="!M871C:&5D(&5X<&5C=&5D(&9O<FUA=%QN(CL*?2!E;'-E('L*("`@(&5C
M:&\@(D1)1$XG5"!-051#2"$@($5X<&5C=&5D(&]U='!U=#H@)R1E>'!E8W1E
M9"<N("!!8W1U86P@;W5T<'5T.B`G)&%C='5A;"<N7&XB.PI]"B1S=&@M/F9R
M964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN9R!F
M971C:&UO9&5S.B!F971C:&EN=&\@9&5F875L="!D969A=6QT7&XB.PHD9&)H
M+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?04Q,
M*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B
M*3L*)')O=R`](&%R<F%Y*"D["B1S=&@M/F9E=&-H26YT;R@D<F]W*3L*<')I
M;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B(["G!R:6YT
M(&EM<&QO9&4H)R`G+"!A<G)A>5]V86QU97,H)')O=RDI+B)<;B(["B1S=&@M
M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN
M9R!F971C:&UO9&5S.B!F971C:')O=R!O<F1E<F5D(&1E9F%U;'1<;B(["B1D
M8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?3U)$15)%1"D["B1S=&@@
M/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@
M/2`D<W1H+3YF971C:%)O=R@I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?
M:V5Y<R@D<F]W*2DN(EQN(CL*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q
M;"!H87!P>2X*"G!R:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W
M(&%S<V]C(&1E9F%U;'1<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#
M2$U/1$5?05-33T,I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($92
M3TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H*3L*<')I;G0@
M:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B(["B1S=&@M/F9R
M964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN9R!F
M971C:&UO9&5S.B!F971C:')O=R!O<F1E<F5D(&1E9F%U;'0@=VET:"!A<W-O
M8R!S<&5C:69I961<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/
M1$5?3U)$15)%1"D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/
M32!P:'!T97-T(BD["B1R;W<@/2`D<W1H+3YF971C:%)O=RA$0E]&151#2$U/
M1$5?05-33T,I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W
M*2DN(EQN(CL*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*
M"G!R:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&%S<V]C(&1E
M9F%U;'0@=VET:"!O<F1E<F5D('-P96-I9FEE9%QN(CL*)&1B:"T^<V5T1F5T
M8VA-;V1E*$1"7T9%5$-(34]$15]!4U-/0RD["B1S=&@@/2`D9&)H+3YQ=65R
M>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@/2`D<W1H+3YF971C
M:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["G!R:6YT(&EM<&QO9&4H(B`B
M+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PHD<W1H+3YF<F5E*"D[("`O+R!K
M965P(&9B<W%L(&AA<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@
M9F5T8VAI;G1O(&]R9&5R960@9&5F875L=%QN(CL*)&1B:"T^<V5T1F5T8VA-
M;V1E*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*)'-T:"`]("1D8F@M/G%U97)Y
M*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`](&%R<F%Y*"D["B1S
M=&@M/F9E=&-H26YT;R@D<F]W*3L*<')I;G0@:6UP;&]D92@B("(L(&%R<F%Y
M7VME>7,H)')O=RDI+B)<;B(["B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S
M<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C:&EN
M=&\@87-S;V,@9&5F875L=%QN(CL*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%
M5$-(34]$15]!4U-/0RD["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@
M1E)/32!P:'!T97-T(BD["B1R;W<@/2!A<G)A>2@I.PHD<W1H+3YF971C:$EN
M=&\H)')O=RD["G!R:6YT(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I
M*2XB7&XB.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*
M<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&]R9&5R960@
M9&5F875L="!W:71H(&%S<V]C('-P96-I9FEE9%QN(CL*)&1B:"T^<V5T1F5T
M8VA-;V1E*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*)'-T:"`]("1D8F@M/G%U
M97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`](&%R<F%Y*"D[
M"B1S=&@M/F9E=&-H26YT;R@D<F]W+"!$0E]&151#2$U/1$5?05-33T,I.PIP
M<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*)'-T
M:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R:6YT(")T97-T
M:6YG(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!A<W-O8R!D969A=6QT('=I=&@@
M;W)D97)E9"!S<&5C:69I961<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$0E]&
M151#2$U/1$5?05-33T,I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J
M($923TT@<&AP=&5S="(I.PHD<F]W(#T@87)R87DH*3L*)'-T:"T^9F5T8VA)
M;G1O*"1R;W<L($1"7T9%5$-(34]$15]/4D1%4D5$*3L*<')I;G0@:6UP;&]D
M92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B(["@HD<W1H+3YF<F5E*"D[
M("`O+R!K965P(&9B<W%L(&AA<'!Y+@H@("`@("`@("`@("`@("`O+R!K965P
M(&EB87-E(&AA<'!Y.B!C86XG="!D<F]P('1B;"!T:&%T(&AA<R!R97-U;'1S
M(&]P96X@86=A:6YS="!I="X*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]I;F-L=61E+FEN8P``````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#`U
M,@`Q,#4Q-30S,3`U-P`P,C(R-3$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J*@H@*B!3971S('1H92!I;F-L
M=61E7W!A=&@L(&5R<F]R7W)E<&]R=&EN9R!A;F0@4$%42%]315!!4D%43U(@
M9F]R('1E<W1S"B`J(&EN('1H92!$0B]T97-T<R!D:7)E8W1O<GD*("H*("H@
M4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A
M=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE
M;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M"B`J($!V97)S:6]N("`@("1)9#H@:6YC;'5D92YI;F,L=B`Q+C4@,C`P-2\P
M,B\P,R`P-3HT.3HT-"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"F5R<F]R7W)E<&]R
M=&EN9RA%7T%,3"D["@II9B`H(61E9FEN960H)U!!5$A?4T5005)!5$]2)RDI
M('L*("`@(&EF("AS=')I<W1R*%!(4%]/4RP@)U=)3B<I*2!["B`@("`@("`@
M+RHJ"B`@("`@("`@("H@1&5F:6YE('1H92!P871H('-E<&%R871O<B!F;W(@
M=VEN9&]W<PH@("`@("`@("`J+PH@("`@("`@(&1E9FEN92@G4$%42%]315!!
M4D%43U(G+"`G.R<I.PH@("`@?2!E;'-E('L*("`@("`@("`O*BH*("`@("`@
M("`@*B!$969I;F4@=&AE('!A=&@@<V5P87)A=&]R(&9O<B!O=&AE<B!S>7-T
M96US"B`@("`@("`@("HO"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/
M4B<L("<Z)RD["B`@("!]"GT*"B\J"B`J($EF('1H92!P871H('1O('EO=7(@
M4$5!4B!I;G-T86QL871I;VX@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@
M*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@
M;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS
M=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!U<V4@=&AE"B`J(&EN<W1A;&QE
M9"!V97)S:6]N(&]F($1"+"!W:&EC:"!S:&]U;&0@8F4@9F]U;F0@=FEA('1H
M90H@*B!C;VUP=71E<B=S(&1E9F%U;'0@:6YC;'5D95]P871H+B`@061D("<N
M)R!T;R!T:&4@:6YC;'5D95]P871H"B`J('1O(&5N<W5R92`G+B<@:7,@:6X@
M=&AE<F4N"B`J(`H@*B!)9B!T:&4@<&%T:"!H87,@;F]T(&)E96X@<W5B<W1I
M='5T960@:6X@=&AE(&EF*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA
M<R!L:6ME;'D@8V]M92!F<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F
M:6QE+@H@*B!4:&5R969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO
M=6QD('5S92!T:&4@=F5R<VEO;B!O9@H@*B!$0B!T:&%T(&AA<R!C;VUE(&9R
M;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(G("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L*("`@
M(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G970H)VEN8VQU9&5?<&%T
M:"<I"B`@("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<*("`@("D[
M"GT@96QS92!["B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!R96%L<&%T
M:"AD:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*0H@("`@("`@("`@("`N(%!!
M5$A?4T5005)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(*("`@("`@("`@
M("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]L:6UI="YI;F,`````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#8R,@`Q,#4Q-30S,3`U-P`P,C$W-#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J*@H@*B!4
M97-T<R!T:&4@9')I=F5R<R<@;&EM:711=65R>2@I(&UE=&AO9`H@*@H@*B!%
M>&5C=71E9"!B>2!D<FEV97(O,3-L:6UI="YP:'!T"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@
M*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R
M<VEO;B`@("`D260Z(&QI;6ET+FEN8RQV(#$N,3$@,C`P-2\P,B\P,R`P-3HT
M.3HT-"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"F5R<F]R7W)E<&]R=&EN9RA%7T%,
M3"D["@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<@H@*@H@
M*B!$<F]P<R!T:&4@<&AP=&5S="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O
M<B!M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A
M<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L
M;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`
M<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H
M)&\I('L*("`@(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H
M+"`G<&AP=&5S="<I.PH*("`@(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"@HD
M9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O
M<%]T86)L92@D9&)H+"`G<&AP7VQI;6ET)RD["@HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*)&1B:"T^<75E
M<GDH)T-214%412!404),12!P:'!?;&EM:70@*&$@0TA!4B@R,"DI)RD["@H*
M)&9R;VT@("`@/2`P.PHD8V]U;G0@("`](#$P.PHD;G5M<F]W<R`](#,P.PH*
M9F]R("@D:3TP.R`D:3P])&YU;7)O=W,K,CL@)&DK*RD@>PH@("`@)&1B:"T^
M<75E<GDH(DE.4T525"!)3E1/('!H<%]L:6UI="!604Q515,H)W)E<W5L="`D
M:2<I(BD["GT*9F]R("@D:2`](#`[("1I(#P](#,[("1I*RLI('L*("`@("1F
M<F]M(#T@,3`@*B`D:3L*("`@("1R97,@/2`D9&)H+3YL:6UI=%%U97)Y*")S
M96QE8W0@*B!F<F]M('!H<%]L:6UI="(L("1F<F]M+"`D8V]U;G0I.PH@("`@
M96-H;R`B/3T]/3T]/2!&<F]M.B`D9G)O;2!\?"!.=6UB97(@;V8@<F]W<R!T
M;R!F971C:#H@)&-O=6YT(#T]/3T]/3U<;B(["B`@("!W:&EL92`H)')O=R`]
M("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI('L*("`@("`@
M("!E8VAO("1R97,M/F=E=%)O=T-O=6YT97(H*2`N("<N+2`G("X@)')O=ULG
M82==("X@(EQN(CL*("`@('T*("`@("1R97,M/F9R964H*3L@("\O(&ME97`@
M9F)S<6P@:&%P<'DN"GT*"@HD9G)O;2`@/2`Q,3L*)&-O=6YT(#T@,SL*"F5C
M:&\@(CT]/3T]/3T@4&%S<VEN9R!<)'!A<F%M<R!\?"!&<F]M.B`D9G)O;2!\
M?"!.=6UB97(@;V8@<F]W<R!T;R!F971C:#H@)&-O=6YT(#T]/3T]/3U<;B([
M"B1R97,@/2`D9&)H+3YL:6UI=%%U97)Y*"=314Q%0U0@*B!&4D]-('!H<%]L
M:6UI="!72$5212!A(#P@/R<L("1F<F]M+"`D8V]U;G0L(&%R<F%Y*"=R97-U
M;'0@.3DG*2D["G=H:6QE("@D<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?1D54
M0TA-3T1%7T%34T]#*2D@>PH@("`@96-H;R`D<F5S+3YG9712;W=#;W5N=&5R
M*"D@+B`G+BT@)R`N("1R;W=;)V$G72`N(")<;B(["GT*"B1R97,M/F9R964H
M*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"B`@("`@("`@("`@("`@("\O(&ME
M97`@:6)A<V4@:&%P<'DZ(&-A;B=T(&1R;W`@=&)L('1H870@:&%S(')E<W5L
M=',@;W!E;B!A9V%I;G-T(&ET+@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<%]L:6UI
M="<I.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]N=6UC;VQS+FEN8P``````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S4Q,P`Q,#4Q-30S,3`U-P`P,C(S,#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\J*@H@*B!497-T<R!T:&4@9')I=F5R<R<@;G5M0V]L<R@I(&UE=&AO
M9`H@*@H@*B!%>&5C=71E9"!B>2!D<FEV97(O,#1N=6UC;VQS+G!H<'0*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@("1)9#H@;G5M8V]L<RYI;F,L=B`Q+C<@,C`P
M-2\P,B\P,R`P-3HT.3HT-"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!,
M;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R"B`J"B`J($1R;W!S('1H92!P
M:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD
M(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D
M;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@
M=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T
M17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO
M8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["B`@("!D<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD[
M"@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD<W1H(#T@
M)&1B:"T^<75E<GDH(E-%3$5#5"!A($923TT@<&AP=&5S="(I.PIP<FEN=&8H
M(B5D7&XB+"`D<W1H+3YN=6U#;VQS*"DI.PHD<W1H(#T@)&1B:"T^<75E<GDH
M(E-%3$5#5"!A+&(@1E)/32!P:'!T97-T(BD["G!R:6YT9B@B)61<;B(L("1S
M=&@M/FYU;4-O;',H*2D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$L
M8BQC($923TT@<&AP=&5S="(I.PIP<FEN=&8H(B5D7&XB+"`D<W1H+3YN=6U#
M;VQS*"DI.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP
M=&5S="(I.PIP<FEN=&8H(B5D7&XB+"`D<W1H+3YN=6U#;VQS*"DI.PH*"G-W
M:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G:6)A<V4G.@H@("`@
M("`@("\J"B`@("`@("`@("H@26YT97)B87-E(&1O97-N)W0@86QL;W<@9')O
M<'!I;F<@=&%B;&5S('1H870@:&%V92!R97-U;'0*("`@("`@("`@*B!S971S
M('-T:6QL(&]P96XN"B`@("`@("`@("HO"B`@("`@("`@)&1B:"T^9G)E95)E
M<W5L="@D<W1H+3YR97-U;'0I.PH@("`@("`@(&)R96%K.PI]"B1D8F@M/G-E
M=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE
M*"1D8F@L("=P:'!T97-T)RD["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O;G5M<F]W<RYI;F,`````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8R,S8`,3`U,34T,S$P-3<`,#(R,S0V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*BH*("H@5&5S=',@=&AE(&1R:79E<G,G(&YU;5)O=W,H*2!M971H;V0*("H*
M("H@17AE8W5T960@8GD@9')I=F5R+S`Y;G5M<F]W<RYP:'!T"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A
M8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("`D260Z(&YU;7)O=W,N:6YC+'8@,2XQ,B`R,#`U+S`R
M+S`Y(#`W.C`W.C(T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($QO8V%L
M(&5R<F]R(&-A;&QB86-K(&AA;F1L97(*("H*("H@1')O<',@=&AE('!H<'1E
M<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL
M;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!0
M14%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES
M(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O
M<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@
M)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@
M("!P<FEN="`B7&XM+2TM+2TM+2TM+2U<;B(["B`@("!I9B`H)&\M/F=E=$-O
M9&4H*2`]/2!$0E]%4E)/4E].3U1?0T%004),12D@>PH@("`@("`@('!R:6YT
M(")4:&ES($1"35,@9&]E<R!N;W0@<W5P<&]R="!N=6U2;W=S*"DN(CL*("`@
M('T@96QS96EF("@D;RT^9V5T0V]D92@I(#T]($1"7T524D]27TU)4TU!5$-(
M*2!["B`@("`@("`@<')I;G0@(DUI<VUA=&-H(&)E='=E96X@=&AE(&YU;6)E
M<B!O9B!P;&%C96AO;&1E<G,@86YD('!A<F%M971E<G,N7&XB.PH@("`@("`@
M(&9O<F5A8V@@*"1O+3YB86-K=')A8V4@87,@)&ET96T@/3X@)&1E=&%I;"D@
M>PH@("`@("`@("`@("!I9B`H)&1E=&%I;%LG9G5N8W1I;VXG72`]/2`G<75E
M<GDG*2!["B`@("`@("`@("`@("`@("!E8VAO("=1545263H@)R`N("1D971A
M:6Q;)V%R9W,G75LP72`N(")<;B(["B`@("`@("`@("`@("`@("!E8VAO(")0
M05)!345415)3.EQN(CL*("`@("`@("`@("`@("`@('!R:6YT7W(H)&1E=&%I
M;%LG87)G<R==6S%=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T@
M96QS92!["B`@("`@("`@<')I;G0@)&\M/F=E=$1E8G5G26YF;R@I("X@(EQN
M(CL*("`@('T*("`@(&5X:70["GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["@H*)')E<R`]("1D8F@M/G%U
M97)Y*")314Q%0U0@82!&4D]-('!H<'1E<W0B*3L*:68@*"%$0CHZ:7-%<G)O
M<B@D<F]W<R`]("1R97,M/FYU;5)O=W,H*2DI('L*("`@('!R:6YT("(H=V%N
M="`Q*2!G;W0@)')O=W,@9G)O;2!F:7)S=%QN(CL*?2!E;'-E('L*("`@('!R
M:6YT(")<;B(["GT*9F]R("@D:2`](#`[("1I(#P@-3L@)&DK*RD@>PH@("`@
M)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@*&$I(%9!3%5%4R`H
M)&DI(BD["B`@("`D<F5S(#T@)&1B:"T^<75E<GDH(E-%3$5#5"!A($923TT@
M<&AP=&5S="(I.PH@("`@:68@*"%$0CHZ:7-%<G)O<B@D<F]W<R`]("1R97,M
M/FYU;5)O=W,H*2DI('L*("`@("`@("!P<FEN="`G*'=A;G0@)R`N("@D:2`K
M(#(I("X@(BD@9V]T("1R;W=S(&9R;VT@)&E<;B(["B`@("!](&5L<V4@>PH@
M("`@("`@('!R:6YT(")<;B(["B`@("!]"GT*"B1R97,@/2`D9&)H+3YQ=65R
M>2@G4T5,14-4(&$@1E)/32!P:'!T97-T(%=(15)%(&$@/B`_)RP@,"D["FEF
M("@A1$(Z.FES17)R;W(H)')O=W,@/2`D<F5S+3YN=6U2;W=S*"DI*2!["B`@
M("!P<FEN="`B*'=A;G0@-2D@9V]T("1R;W=S(&9R;VT@/B`P("AP87-S:6YG
M('!A<F%M<R!T;R!Q=65R>2E<;B(["GT@96QS92!["B`@("!P<FEN="`B7&XB
M.PI]"@HD<W1H(#T@)&1B:"T^<')E<&%R92@G4T5,14-4(&$@1E)/32!P:'!T
M97-T(%=(15)%(&$@/"`_)RD["B1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@L
M(&%R<F%Y*#0I*3L*:68@*"%$0CHZ:7-%<G)O<B@D<F]W<R`]("1R97,M/FYU
M;5)O=W,H*2DI('L*("`@('!R:6YT("(H=V%N="`T*2!G;W0@)')O=W,@9G)O
M;2`\(#0@*&1O:6YG('!R97!A<F4O97AE8W5T92E<;B(["GT@96QS92!["B`@
M("!P<FEN="`B7&XB.PI]"@HD9&)H+3YQ=65R>2@B1$5,151%($923TT@<&AP
M=&5S="!72$5212!A(#P@-"(I.PHD<F5S(#T@)&1B:"T^<75E<GDH(E-%3$5#
M5"!A($923TT@<&AP=&5S="(I.PII9B`H(41".CII<T5R<F]R*"1R;W=S(#T@
M)')E<RT^;G5M4F]W<R@I*2D@>PH@("`@<')I;G0@(BAW86YT(#(I(&=O="`D
M<F]W<R!F<F]M(#4@86YD(#8@;F]T(&1E;&5T961<;B(["GT@96QS92!["B`@
M("!P<FEN="`B7&XB.PI]"B1R97,@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@
M1E)/32!P:'!T97-T('=H97)E(&$@/"`P(BD["FEF("@A1$(Z.FES17)R;W(H
M)')O=W,@/2`D<F5S+3YN=6U2;W=S*"DI*2!["B`@("!P<FEN="`B*'=A;G0@
M,"D@9V]T("1R;W=S(&9R;VT@/"`P7&XB.PI](&5L<V4@>PH@("`@<')I;G0@
M(EQN(CL*?0H*"B1R97,M/F9R964H*3L@("\O(&ME97`@:6)A<V4@:&%P<'D*
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R
M;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+W!R97!E>&4N:6YC````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$T-S(T`#$P-3$U-#,Q,#4W`#`R,C,P-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J(%1E<W1S('1H92!D<FEV97)S)R!P<F5P87)E(&%N9"!E>&5C=71E
M(&UE=&AO9',*("H*("H@17AE8W5T960@8GD@9')I=F5R+S`V<')E<&5X96,N
M<&AP=`H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A
M=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO
M<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!P<F5P97AE+FEN8RQV
M(#$N,C4@,C`P-2\P,B\Q-B`Q,SHU-#HU,2!D86YI96QC($5X<"`D"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*
M"B1T;7!F:6QE(#T@=&5M<&YA;2@B+W1M<"(L(")P:'!T;7`B*3L*<F5G:7-T
M97)?<VAU=&1O=VY?9G5N8W1I;VXH(FUY7W-H=71D;W=N(BD["B1F<"`](&9O
M<&5N*"1T;7!F:6QE+"`B=R(I.PHD9FEL961A=&$@/2`B;W!A<75E('!L86-E
M:&]L9&5R)W,@=&5S="(["F9W<FET92@D9G`L("1F:6QE9&%T82D["F9C;&]S
M92@D9G`I.PH*"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R
M"B`J"B`J(%!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@
M=&AE('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2(&5R
M<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE=&AO
M9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L
M:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!P<FEN="`B7&XB("X@
M)&\M/G1O4W1R:6YG*"D["B`@("!E>&ET.PI]"@HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B\O(#$I($UU
M;'1I<&QE('!R97!A<F4O97AE8R!)3E-%4E0@<75E<FEE<PIE8VAO("(M+2TM
M+2TM+2TM+2TQ+2TM+2TM+2TM+2TM7&XB.PH*)'-T:#$@/2`D9&)H+3YP<F5P
M87)E*"))3E-%4E0@24Y43R!P:'!T97-T("AA+"!B*2!604Q515,@*#\L("=A
M)RDB*3L*)'-T:#(@/2`D9&)H+3YP<F5P87)E*"))3E-%4E0@24Y43R!P:'!T
M97-T("AA+&(I(%9!3%5%4R`H(2P_*2(I.PHD<W1H,R`]("1D8F@M/G!R97!A
M<F4H(DE.4T525"!)3E1/('!H<'1E<W0@*&$L8BQC*2!604Q515,@*#\L(2PF
M*2(I.PHD<W1H-"`]("1D8F@M/G!R97!A<F4H(DE.4T525"!)3E1/('!H<'1E
M<W0@*&$L(&(I(%9!3%5%4R`H-S(L("=D:7)E8W0G*2(I.PIP<FEN="`B<W1H
M,2QS=&@R+'-T:#,L<W1H-"!C<F5A=&5D7&XB.PIP<FEN="`G<W1H,3H@/R!A
M<R!P87)A;2P@<&%S<VEN9R!A<R!A<G)A>2XN+B`G.PII9B`H*"1R97,@/2`D
M9&)H+3YE>&5C=71E*"1S=&@Q+"!A<G)A>2@W,BDI*2`]/3T@1$)?3TLI('L*
M("`@('!R:6YT(")S=&@Q(&5X96-U=&5D7&XB.PI](&5L<V4@>PH@("`@<')I
M;G0@(G-T:#$@9F%I;&5D7&XB.PI]"@IP<FEN="`G<W1H,CH@(2!A;F0@/R!A
M<R!P87)A;7,L('!A<W-I;F<@87,@87)R87DN+BX@)SL*:68@*"@D<F5S(#T@
M)&1B:"T^97AE8W5T92@D<W1H,BP@87)R87DH-S(L(")T:&%T)W,@<FEG:'0B
M*2DI(#T]/2!$0E]/2RD@>PH@("`@<')I;G0@(G-T:#(@97AE8W5T961<;B([
M"GT@96QS92!["B`@("!P<FEN="`B<W1H,B!F86EL961<;B(["GT*"G!R:6YT
M("=S=&@S.B`_+"`A(&%N9"`F(&%S('!A<F%M<RP@<&%S<VEN9R!A<R!A<G)A
M>2XN+B`G.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VUS
M<6PG.@H@("`@("`@("1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@S+"!A<G)A
M>2@W,BP@(B=I=%Q<)W,@9V]O9"<B+"`D=&UP9FEL92DI.PH@("`@("`@(&)R
M96%K.PH@("`@9&5F875L=#H*("`@("`@("`D<F5S(#T@)&1B:"T^97AE8W5T
M92@D<W1H,RP@87)R87DH-S(L("(G:70G)W,@9V]O9"<B+"`D=&UP9FEL92DI
M.PI]"FEF("@D<F5S(#T]/2!$0E]/2RD@>PH@("`@<')I;G0@(G-T:#,@97AE
M8W5T961<;B(["GT@96QS92!["B`@("!P<FEN="`B<W1H,R!F86EL961<;B([
M"GT*"G!R:6YT("=S=&@T.B!N;R!P87)A;7,N+BX@)SL*:68@*"@D<F5S(#T@
M)&1B:"T^97AE8W5T92@D<W1H-"DI(#T]/2!$0E]/2RD@>PH@("`@<')I;G0@
M(G-T:#0@97AE8W5T961<;B(["GT@96QS92!["B`@("!P<FEN="`B<W1H-"!F
M86EL961<;B(["GT*<')I;G1?<F5S=6QT<R@I.PH*"B\O(#(I($]N92!P<F5P
M87)E9"P@;75L=&EP;&4@=&EM92!E>&5C=71E9`IE8VAO(")<;BTM+2TM+2TM
M+2TM+3(M+2TM+2TM+2TM+2U<;B(["@HD9&)H+3YQ=65R>2@G1$5,151%($92
M3TT@<&AP=&5S="<I.PHD<W1H(#T@)&1B:"T^<')E<&%R92@G24Y315)4($E.
M5$\@<&AP=&5S="`H82P@8BP@8RP@9"D@5D%,5453("@_+"`_+"`F+"`_*2<I
M.PHD9&%T82`](&%R<F%Y*`H@("`@,"`]/B!A<G)A>2@W,BP@)W-E=#$G+"`D
M=&UP9FEL92P@)S$R,S0M-38M-S@G*2P*("`@(#$@/3X@87)R87DH-S(L("=S
M970R)RP@)'1M<&9I;&4L(&YU;&PI+`H@("`@,B`]/B!A<G)A>2@W,BP@)W-E
M=#,G+"`D=&UP9FEL92P@;G5L;"D**3L*)')E<R`]("1D8F@M/F5X96-U=&5-
M=6QT:7!L92@D<W1H+"`D9&%T82D["G!R:6YT7W)E<W5L=',H*3L*"@HO+R`S
M*2!F<F5E4')E<&%R960H*2!T97-T"F5C:&\@(EQN+2TM+2TM+2TM+2TM,RTM
M+2TM+2TM+2TM+5QN(CL*"FEF("@D9&)H+3YF<F5E4')E<&%R960H)'-T:"DI
M('L*("`@(&5C:&\@)U12544G.PI](&5L<V4@>PH@("`@96-H;R`G1D%,4T4G
M.PI]"F5C:&\@(EQN(CL*:68@*"1D8F@M/F9R9650<F5P87)E9"@V-C8I*2![
M"B`@("!E8VAO("=44E5%)SL*?2!E;'-E('L*("`@(&5C:&\@)T9!3%-%)SL*
M?0IE8VAO(")<;B(["@H*+R\@-"D@4T5,14-4<R!T97-T<PIE8VAO(")<;BTM
M+2TM+2TM+2TM+30M+2TM+2TM+2TM+2U<;B(["B1S=&@Q(#T@)&1B:"T^<')E
M<&%R92@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&$@/2`_($]21$52
M($)9(&(B*3L*<')I;G1?-"@D<W1H,2P@-S(I.PIP<FEN=%\T*"1S=&@Q+"`W
M,2D["B1S=&@R(#T@)&1B:"T^<')E<&%R92@B4T5,14-4("H@1E)/32!P:'!T
M97-T(%=(15)%(&0@/2`_($]21$52($)9(&(B*3L*<')I;G1?-"@D<W1H,BP@
M)S$R,S0M-38M-S@G*3L*)'-T:#,@/2`D9&)H+3YP<F5P87)E*")314Q%0U0@
M*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`]("8@3U)$15(@0ED@8B(I.PIP<FEN
M=%\T*"1S=&@S+"`D=&UP9FEL92D["@H*+R\@-2D@05-33T-)051)5D4@05)2
M05D@<75E<FEE<PIE8VAO(")<;BTM+2TM+2TM+2TM+34M+2TM+2TM+2TM+2U<
M;B(["@HD<W1H-2`]("1D8F@M/G!R97!A<F4H)TE.4T525"!)3E1/('!H<'1E
M<W0@*&$L(&(L(&0I(%9!3%5%4R`H/RP@/RP@/RDG*3L*)&%R<F%Y(#T@87)R
M87DH"B`@("`G9F]O)R`]/B`Q,2P*("`@("=B87(G(#T^("=T:')E92<L"B`@
M("`G8F%Z)R`]/B!N=6QL+`HI.PHD<F5S(#T@)&1B:"T^97AE8W5T92@D<W1H
M-2P@)&%R<F%Y*3L*<')I;G0@)VEN<V5R=#H@)R`N("@D<F5S(#T]/2!$0E]/
M2R`_("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1S=&@V(#T@)&1B:"T^
M<')E<&%R92@G4T5,14-4(&$L(&(L(&0@1E)/32!P:'!T97-T(%=(15)%(&$@
M/2`_)RD["B1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@V+"!A<G)A>2@Q,2DI
M.PHD<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*3L*
M<')I;G0@(F$@/2![)')O=ULG82==?2P@8B`]('LD<F]W6R=B)UU]+"!D(#T@
M(CL*:68@*"1D8F@M/G!H<'1Y<&4@/3T@)VUS<6PG*2!["B`@("!I9B`H87)R
M87E?:V5Y7V5X:7-T<R@G9"<L("1R;W<I*2!["B`@("`@("`@)'1Y<&4@/2!G
M971T>7!E*"1R;W=;)V0G72D["B`@("`@("`@:68@*"1T>7!E(#T]("=.54Q,
M)R!\?"`D<F]W6R=D)UT@/3T@)R<I('L*("`@("`@("`@("`@<')I;G0@(F=O
M="!E>'!E8W1E9"!O=71C;VUE7&XB.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T>7!E(#T@9V5T='EP92@D<F]W6R=D)UTI.PH@("`@("`@("`@
M("!P<FEN="`B54XM97AP96-T960@;W5T8V]M93H@)'1Y<&5<;B(["B`@("`@
M("`@?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!H='1P.B\O8G5G<RYP:'`N
M;F5T+S]I9#TS,3DV,`H@("`@("`@('!R:6YT(")0<FEO<B!T;R!02%`@-"XS
M+C$Q(&]R(#4N,"XT+"!02%`G<R!M<W%L(&5X=&5N<VEO;B!S:6QE;G1L>2(*
M("`@("`@("`@("`@("`N("(@9')O<'!E9"!C;VQU;6YS('=I=&@@;G5L;"!V
M86QU97,N(%EO=2!N965D('1O('5P9W)A9&4N7&XB.PH@("`@?0I](&5L<V4@
M>PH@("`@)'1Y<&4@/2!G971T>7!E*"1R;W=;)V0G72D["B`@("!I9B`H)'1Y
M<&4@/3T@)W-T<FEN9R<I('L*("`@("`@("!P<FEN="`B9V]T(&5X<&5C=&5D
M(&]U=&-O;65<;B(["B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT(")53BUE
M>'!E8W1E9"!O=71C;VUE.B`D='EP95QN(CL*("`@('T*?0H*+RHJ"B`J($%U
M=&]M871I8V%L;'D@9G)E92!T:&4@<')E<&%R960@<W1A=&5M96YT<R!A;F0@
M<F5S=6QT<R!W:&5N('1H92!S8W)I<'0*("H@=&5R;6EN871E<PH@*@H@*B!`
M<F5T=7)N('9O:60*("HO"F9U;F-T:6]N(&UY7W-H=71D;W=N*"D@>PH@("`@
M9VQO8F%L("1T;7!F:6QE+"`D9&)H+"`D<W1H,2P@)'-T:#(L("1S=&@S+"`D
M<W1H-"P@)'-T:#4L("1S=&@V+"`D<F5S.PH*("`@('-W:71C:"`H)&1B:"T^
M<&AP='EP92D@>PH@("`@("`@(&-A<V4@)VEB87-E)SH*("`@("`@("`@("`@
M+RH*("`@("`@("`@("`@("H@26YT97)B87-E(&1O97-N)W0@86QL;W<@9')O
M<'!I;F<@=&%B;&5S('1H870@:&%V92!R97-U;'0*("`@("`@("`@("`@("H@
M<V5T<R!S=&EL;"!O<&5N+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@
M)&1B:"T^9G)E95!R97!A<F5D*"1S=&@Q*3L*("`@("`@("`@("`@)&1B:"T^
M9G)E95!R97!A<F5D*"1S=&@R*3L*("`@("`@("`@("`@)&1B:"T^9G)E95!R
M97!A<F5D*"1S=&@S*3L*("`@("`@("`@("`@)&1B:"T^9G)E95!R97!A<F5D
M*"1S=&@T*3L*("`@("`@("`@("`@)&1B:"T^9G)E95!R97!A<F5D*"1S=&@U
M*3L*("`@("`@("`@("`@)&1B:"T^9G)E95!R97!A<F5D*"1S=&@V*3L*("`@
M("`@("`@("`@)&1B:"T^9G)E95)E<W5L="@D<F5S+3YR97-U;'0I.PH@("`@
M("`@("`@("!B<F5A:SL*("`@('T*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@
M)W!H<'1E<W0G*3L*"B`@("!U;FQI;FLH)'1M<&9I;&4I.PI]"@HO*BH*("H@
M4')I;G0@;W5T('1H92!D871A(&EN('1E<W0@=&%B;&4*("H*("H@0')E='5R
M;B!V;VED"B`J+PIF=6YC=&EO;B!P<FEN=%]R97-U;'1S*"D@>PH@("`@9VQO
M8F%L("1D8F@["B`@("!P<FEN="`B<F5S=6QT<SI<;B(["B`@("`D<F5S(#T@
M)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!A(#T@
M-S(@3U)$15(@0ED@8B(I.PH@("`@)&D@/2`P.PH@("`@=VAI;&4@*"1R;W<@
M/2`D<F5S+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"DI('L*("`@
M("`@("!P<FEN="`G?"<@+B!I;7!L;V1E*"(@+2`B+"`D<F]W*2`N(")\7&XB
M.PH@("`@("`@("1I*RL["B`@("!]"B`@("!I9B`H(21I*2!["B`@("`@("`@
M<')I;G0@(E1H92!R96-O<F1S('=E<F4@;F]T(&9O=6YD+B`@1&ED('1H97D@
M9V5T(&EN<V5R=&5D/UQN(CL*("`@('T*?0H*+RHJ"B`J($5X96-U=&4@=&AE
M('!R97!A<F5D('-T871E;65N="!A;F0@<')I;G0@;W5T('1H92!D871A(&EN
M('1H92!R97-U;'0*("H*("H@0'!A<F%M(')E<V]U<F-E("`@("`D<W1H("`@
M=&AE('-T871E;65N="!H86YD;&4@=&\@<')O8V5S<PH@*B!`<&%R86T@<W1R
M:6YG?&%R<F%Y("1B:6YD("!T:&4@9&%T82!T:&%T('=I;&P@<F5P;&%C92!T
M:&4@<&QA8V5H;VQD97)S"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I
M;VX@<')I;G1?-"@D<W1H+"`D8FEN9"D@>PH@("`@9VQO8F%L("1D8F@["B`@
M("`D<F5S(#T@)&1B:"T^97AE8W5T92@D<W1H+"`D8FEN9"D["B`@("!W:&EL
M92`H)')O=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$
M*2D@>PH@("`@("`@('!R:6YT("=\)R`N(&EM<&QO9&4H(B`M("(L("1R;W<I
M("X@(GQ<;B(["B`@("!]"B`@("!E8VAO(")^?EQN(CL*?0H`````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]R=6XN8W9S````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38U,0`Q,#4Q-30S,3`U
M-P`P,C$T-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R$@+V)I;B]S:`H*(R`D260Z(')U;BYC=G,L=B`Q+C,@,C`P-"\P
M,B\R,"`Q.#HU-SHU,2!D86YI96QC($5X<"`D"@HC('9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V"B,@4$5!4B!$
M0B!415-4(%-405)415(*(PHC("`@5&\@<G5N(&%L;"!T97-T<SH@("XO<G5N
M"B,@("!4;R!R=6X@;VYE('1E<W0Z("`@+B]R=6X@/'1E<W0@9FEL92!N86UE
M/@HC("`@17AA;7!L93H@("`@("`@("`@("XO<G5N(&1B7W!A<G-E9'-N+G!H
M<'0*(PHC($)E9F]R92!R=6YN:6YG('1H92!T97-T<R!Y;W4@;75S="!A9&IU
M<W0@=&AE"B,@9F]L;&]W:6YG('1H<F5E('9A<FEA8FQE<SH*"B,@("!4:&4@
M9G5L;"!P871H('1O('EO=7(@4$A0(&1I<F5C=&]R>3H*("`@($1"7U1%4U1?
M4$A07U!!5$@]8SHO<')O9W)A?C$O<&AP"@HC("`@5&AE(&YA;64@;V8@>6]U
M<B!02%`@0TQ)(&5X96-U=&%B;&4*(R`@("AE>&%M<&QE<R!P:'`N97AE+"!P
M:'`M8VQI+F5X92P@8VQI+W!H<"YE>&4I.@H@("`@1$)?5$535%]02%!?0TQ)
M/7!H<"YE>&4*"B,@("!4:&4@9G5L;"!P871H('1O('1H92!P<F5S96YT(&1I
M<F5C=&]R>0HC("`@*&YO="!U<VEN9R`D4%=$(&1U92!T;R!#>6=W:6XI.@H@
M("`@1$)?5$535%]$25(]9#HO<&5A<G1E<W0O<&5A<B]$0B]T97-T<PH*(R!>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>
M7EY>7@H*"@I415-47U!(4%]%6$5#551!0DQ%/21$0E]415-47U!(4%]0051(
M+R1$0E]415-47U!(4%]#3$D*97AP;W)T(%1%4U1?4$A07T5814-55$%"3$4*
M"FEF(%L@)",@+6=T(#`@70IT:&5N"B`@("!T97-T/20Q"F5L<V4*("`@('1E
M<W0]*BYP:'!T"F9I"@HD5$535%]02%!?15A%0U5404),12`D1$)?5$535%]0
M2%!?4$%42"]R=6XM=&5S=',N<&AP("1$0E]415-47T1)4B\D>W1E<W1]"@``
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]S97%U
M96YC97,N:6YC````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S4V,0`Q,#4Q
M-30S,3`U-P`P,C(V,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@9')I=F5R<R<@
M<V5Q=65N8V4@*&%K82!A=71O7VEN8W)E;65N="D@;65T:&]D<PH@*@H@*B!%
M>&5C=71E9"!B>2!D<FEV97(O,#5S97%U96YC97,N<&AP=`H@*@H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A
M<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@
M0'9E<G-I;VX@("`@)$ED.B!S97%U96YC97,N:6YC+'8@,2XQ,2`R,#`U+S`R
M+S$X(#(R.C,X.C0S(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($QO8V%L
M(&5R<F]R(&AA;F1L97(*("HO"F9U;F-T:6]N(&5R<F]R7VAA;F1L97(H)B1O
M8FHI('L*("`@('!R:6YT(")S97%U96YC97,N:6YC(&5R<F]R7VAA;F1L97(Z
M7&X@("`@(CL*("`@('!R:6YT("1O8FHM/F=E=$1E8G5G26YF;R@I("X@(EQN
M7&XB.PI]"F]B7VEM<&QI8VET7V9L=7-H*'1R=64I.PH*)&1R;W`@/2`D9&)H
M+3YD<F]P4V5Q=65N8V4H)W1E<W0G*3L*:68@*$1".CII<T5R<F]R*"1D<F]P
M*2`F)@H@("`@)&1R;W`M/F=E=$-O9&4H*2`A/2!$0E]%4E)/4E].3U-50TA4
M04),12D*>PH@("`@<')I;G0@(D-O=6QD(&YO="!D<F]P('-E<75E;F-E+BXN
M7&XB.PH@("`@<')I;G0@)&1R;W`M/F=E=$1E8G5G26YF;R@I("X@(EQN7&XB
M.PH@("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)VEB87-E)R`F)@H@("`@("`@
M("1D<F]P+3YG971#;V1E*"D@/3T@1$)?15)23U)?04-#15-37U9)3TQ!5$E/
M3BD*("`@('L*("`@("`@("!P<FEN="`B57-E('1H:7,@<75E<GD@=&\@<')O
M=FED92!T:&4@<&5R;6ES<VEO;G,@;F5E9&5D.EQN(CL*("`@("`@("!P<FEN
M="`G("`@9W)A;G0@86QL(&]N(%)$0B1'14Y%4D%43U)3('1O(#Q54T523D%-
M13XG.PH@("`@?0H@("`@97AI=#L*?0H*+R\@,2D@=&5S="!T:&%T('-E<75E
M;F-E<R!A<F4@;F]T(&-R96%T960@:68@(F]N9&5M86YD(B!I<R!F86QS90H*
M)&4@/2`D9&)H+3YN97AT260H(G1E<W0B+"!F86QS92D["FEF("A$0CHZ:7-%
M<G)O<B@D92D@)B8@)&4M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U-50TA4
M04),12D@>PH@("`@<')I;G0@(F%N(&5R<F]R(&ES('1H92!P<F]P97(@<F5S
M<&]N<V4@:&5R95QN(CL*?2!E;'-E('L*("`@(&EF("A$0CHZ:7-%<G)O<B@D
M92DI('L*("`@("`@("!I9B`H)&1B:"T^<&AP='EP92`]/2`G:6)A<V4G("8F
M("1E+3YG971#;V1E*"D@/3T@1$)?15)23U)?4UE.5$%8*2!["B`@("`@("`@
M("`@('!R:6YT(")A;B!E<G)O<B!I<R!T:&4@<')O<&5R(')E<W!O;G-E(&AE
M<F5<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@(G1E
M<W0@,2D@=V4@97AP96-T960@=&\@9V5T(&)A8VL@)T1"($5R<F]R.B!N;R!S
M=6-H('1A8FQE)RY<;B(["B`@("`@("`@("`@('!R:6YT(")(97)E(&ES('1H
M92!E<G)O<B!W92!G;W0Z7&XB.PH@("`@("`@("`@("!P<FEN="`G0V]D93H@
M)R`N("1E+3YG971#;V1E*"D@+B`B7&XB.PH@("`@("`@("`@("!P<FEN="`G
M365S<V%G93H@)R`N("1E+3YG971-97-S86=E*"D@+B`B7&XB.PH@("`@("`@
M("`@("!P<FEN="`G1&5B=6<Z("<@+B`D92T^9V5T1&5B=6=);F9O*"D@+B`B
M7&Y<;B(["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!P<FEN="`B
M=&5S="`Q*2!W92!E>'!E8W1E9"!T;R!G970@8F%C:R`G1$(@17)R;W(Z(&YO
M('-U8V@@=&%B;&4G+EQN(CL*("`@("`@("!P<FEN="`B0G5T(&%N(&5R<F]R
M('=A<VXG="!G96YE<F%T961<;EQN(CL*("`@('T*?0H*+R\@,BD@=&5S="!T
M:&%T('1H92!S97%U96YC92!I<R!N;W0@8W)E871E9"!B=70@=&AE(&5R<F]R
M(&ES"B\O(&AA;F1L960@8GD@=&AE(&-L87-S(&5R<F]R(&AA;F1L97(*)&1B
M:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4+`H@("`@("`@
M("`@("`@("`@("`@("`@(")A;B!E<G)O<B!C;W5G:'0@8GD@=&AE(&5R<F]R
M(&AA;F1L97(@:7,@9V]O9%QN(BD["B1E(#T@)&1B:"T^;F5X=$ED*")T97-T
M(BP@9F%L<V4I.PII9B`H(41".CII<T5R<F]R*"1E*2D@>PH@("`@<')I;G0@
M(G1E<W0@,BD@9F%I;&5D(5QN(CL*?0HD9&)H+3Y?9&5F875L=%]E<G)O<E]M
M;V1E(#T@;G5L;#L*"B\O(#,I('1E<W0@=&AA="!S97%U96YC97,@87)E(&-R
M96%T960@:68@(F]N9&5M86YD(B!I<R!T<G5E+"!A;F0@=&AA=`HO+R!T=V\@
M<W5C8V5S<VEV92!N97AT261S(')E='5R;B!A9&IA8V5N="!V86QU97,*)&$@
M/2`D9&)H+3YN97AT260H(G1E<W0B*3L*)&(@/2`D9&)H+3YN97AT260H(G1E
M<W0B*3L*:68@*$1".CII<T5R<F]R*"1A*2D@>PH@("`@<')I;G0@)V$Z("<@
M+B`D82T^9V5T1&5B=6=);F9O*"D@+B`B7&Y<;B(["GT@96QS92!["B`@("!P
M<FEN="`B83TD85QN(CL*?0II9B`H1$(Z.FES17)R;W(H)&(I*2!["B`@("!P
M<FEN="`G8CH@)R`N("1B+3YG971$96)U9TEN9F\H*2`N(")<;EQN(CL*?2!E
M;'-E('L*("`@('!R:6YT(")B/21B7&XB.PI]"FEF("@A1$(Z.FES17)R;W(H
M)&$I("8F("%$0CHZ:7-%<G)O<B@D8BDI('L*("`@('!R:6YT("=B+6$])R`N
M("@D8BTD82D@+B`B7&XB.PI]"@HO+R`T*2!T97-T('1H870@=&AE('5S97(M
M<W!E8VEF:65D(&5R<F]R(&AA;F1L97(@:7,@<F5A;&QY(&1I<V%B;&5D"B\O
M(&1U<FEN9R!N97AT260L('=I=&@@<&5R+6]B:F5C="!H86YD;&5R(&%S('=E
M;&P@87,@9VQO8F%L(&AA;F1L97(*)&1B:"T^9')O<%-E<75E;F-E*")T97-T
M(BD["@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!
M0TLL("=E<G)O<E]H86YD;&5R)RD["B1C(#T@)&1B:"T^;F5X=$ED*")T97-T
M(BD["FEF("@A1$(Z.FES17)R;W(H)&,I*2!["B`@("!P<FEN="`B8STD8UQN
M(CL*?0HD9&)H+3YD<F]P4V5Q=65N8V4H(G1E<W0B*3L*)&1B:"T^7V1E9F%U
M;'1?97)R;W)?;6]D92`](&YU;&P["B1D(#T@)&1B:"T^;F5X=$ED*")T97-T
M(BD["FEF("@A1$(Z.FES17)R;W(H)&0I*2!["B`@("!P<FEN="`B9#TD9%QN
M(CL*?0H*+R\@-2D@=&5S="!T:&%T('1H92!S97%U96YC92!I<R!H86YD;&5D
M(')I9VAT('=H96X@=&AE('1A8FQE(&ES(&5M<'1Y"@HO+R!"86-K96YD('=I
M=&@@<F5A;"!S97%U96YC97,@;6%Y(&1O;B=T(&QI:V4@=&AA=`I014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B1D8F@M/G%U
M97)Y*"=$14Q%5$4@1E)/32!T97-T7W-E<2<I.PI014%2.CIP;W!%<G)O<DAA
M;F1L:6YG*"D["B1E(#T@)&1B:"T^;F5X=$E$*"=T97-T)RD["FEF("A$0CHZ
M:7-%<G)O<B@D9"DI('L*("`@('!R:6YT("=E.B`G("X@)&0M/F=E=$1E8G5G
M26YF;R@I("X@(EQN7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(F4])&1<;B([
M"GT*"B\O(&9I;F%L(&-L96%N+75P"B1D8F@M/F1R;W!397%U96YC92@B=&5S
M="(I.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]S:6UP;&5Q=65R>2YI;F,`````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S8R-0`Q,#4Q-30S,3`U-P`P,C,R,3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J*@H@*B!4
M97-T<R!T:&4@9')I=F5R<R<@<VEM<&QE475E<GDH*2!M971H;V0*("H*("H@
M17AE8W5T960@8GD@9')I=F5R+S`S<VEM<&QE<75E<GDN<&AP=`H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@)$ED.B!S:6UP;&5Q=65R>2YI;F,L=B`Q+C@@,C`P
M-2\P,B\P,R`P-3HT.3HT-"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!,
M;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R"B`J"B`J($1R;W!S('1H92!P
M:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD
M(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D
M;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@
M=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T
M17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO
M8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["B`@("!D<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD[
M"@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD<W1H(#T@
M)&1B:"T^<VEM<&QE475E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PH*
M<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=M>7-Q;&DG.@H@
M("`@("`@(&EF("AI<U]A*"1S=&@L("=M>7-Q;&E?<F5S=6QT)RDI('L*("`@
M("`@("`@("`@<')I;G0@(G!A<W-E9%QN(CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!P<FEN="`B4%)/0DQ%35QN(CL*("`@("`@("!]"B`@("`@
M("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@(&EF("AG971T>7!E*"1S
M=&@I(#T]("=R97-O=7)C92<I('L*("`@("`@("`@("`@<')I;G0@(G!A<W-E
M9%QN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B4%)/
M0DQ%35QN(CL*("`@("`@("!]"GT*"@IS=VET8V@@*"1D8F@M/G!H<'1Y<&4I
M('L*("`@(&-A<V4@)VEB87-E)SH*("`@("`@("`O*@H@("`@("`@("`J($EN
M=&5R8F%S92!D;V5S;B=T(&%L;&]W(&1R;W!P:6YG('1A8FQE<R!T:&%T(&AA
M=F4@<F5S=6QT"B`@("`@("`@("H@<V5T<R!S=&EL;"!O<&5N+@H@("`@("`@
M("`J+PH@("`@("`@("1D8F@M/F9R965297-U;'0H)'-T:"D["B`@("`@("`@
M8G)E86L["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1$(O=&5S=',O=')A;G-A8W1I;VYS+FEN8P``````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#4V-#0`,3`U,34T,S$P-3<`,#(S,S0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@
M=&AE(&1R:79E<G,G('1R86YS86-T:6]N(&AA;F1L:6YG(&UE=&AO9',*("H*
M("H@17AE8W5T960@8GD@9')I=F5R+S$Q=')A;G-A8W1I;VYS+G!H<'0*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@("1)9#H@=')A;G-A8W1I;VYS+FEN8RQV(#$N
M.2`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+R\@
M5&5S=&EN9R!H97)E(&1U92!T;R!S:VEP(&YO="!W;W)K:6YG(&-U<G)E;G1L
M>2!I;B!H96%D"FEF("@A)&1B:"T^9F5A='5R97-;)W1R86YS86-T:6]N<R==
M*2!["B`@("!D:64H)W1H:7,@9')I=F5R(&1O97,@;F]T('-U<'!O<G0@=')A
M;G-A8W1I;VYS)RD["GT*"B\O(%9I97<@=&AE('1A8FQE(&9R;VT@82!S97!A
M<F%T92!C;VYN96-T:6]N('-O('=E(&1O;B=T(&1I<W1U<F(*+R\@=&AE('1R
M86YS86-T:6]N+@HD9&)H,B`]($1".CIC;VYN96-T*"1D8F@M/F1S;BD["@IF
M=6YC=&EO;B!E<G)O<E]H86YD;&5R*"8D;V)J*2!["B`@("!P<FEN="`B7&XB
M("X@)&]B:BT^9V5T1&5B=6=);F9O*"D@+B`B7&XB.PI]"@IF=6YC=&EO;B!D
M=6UP=&%B;&4H)&5X<&5C=&5D*2!["B`@("!G;&]B86P@)&1B:"P@)&1B:#([
M"B`@("!P<FEN="!I;7!L;V1E*"<@)RP@)&1B:"T^9V5T0V]L*"=314Q%0U0@
M8B!&4D]-('!H<'1E<W0G*2D["@H@("`@:68@*&ES<V5T*"1D8F@M/G1R86YS
M86-T:6]N7V]P8V]U;G0I*2!["B`@("`@("`@:68@*"1E>'!E8W1E9"`]/2`D
M9&)H+3YT<F%N<V%C=&EO;E]O<&-O=6YT*2!["B`@("`@("`@("`@('!R:6YT
M("(N("!O<',];VM<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<')I;G0@(BX@(&]P<STD9&)H+3YT<F%N<V%C=&EO;E]O<&-O=6YT7&XB.PH@
M("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@<')I;G0@(BX@(&]P<SUO
M:UQN(CL*("`@('T*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27T-!3$Q"04-++"`G97)R;W)?:&%N9&QE<B<I.PH*"B1D8F@M/F%U=&]#
M;VUM:70H=')U92D["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T
M(%9!3%5%4R@Q+"`G;VYE)RP@)T]N92<L("<R,#`Q+3`R+3$Y)RDB*3L*"G!R
M:6YT("<Q*2!A9G1E<B!A=71O8V]M;6ET.B`G.PID=6UP=&%B;&4H,"D["@HD
M9&)H+3YA=71O0V]M;6ET*&9A;'-E*3L*)&1B:"T^<75E<GDH(DE.4T525"!)
M3E1/('!H<'1E<W0@5D%,5453*#(L("=T=V\G+"`G5'=O)RP@)S(P,#$M,#(M
M,C`G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q5
M15,H,RP@)W1H<F5E)RP@)U1H<F5E)RP@)S(P,#$M,#(M,C$G*2(I.PIP<FEN
M="`G,BD@8F5F;W)E(&-O;6UI=#H@)SL*9'5M<'1A8FQE*#(I.PH*)&1B:"T^
M8V]M;6ET*"D["G!R:6YT("<S*2!A9G1E<B!C;VUM:70Z("<["F1U;7!T86)L
M92@P*3L*"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%
M4R@T+"`G9F]U<B<L("=&;W5R)RP@)S(P,#$M,#(M,C(G*2(I.PHD9&)H+3YQ
M=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,H-2P@)V9I=F4G+"`G
M1FEV92<L("<R,#`Q+3`R+3(S)RDB*3L*<')I;G0@)S0I(&)E9F]R92!R;VQL
M8F%C:SH@)SL*9'5M<'1A8FQE*#(I.PH*)&1B:"T^<F]L;&)A8VLH*3L*<')I
M;G0@)S4I(&%F=&5R(')O;&QB86-K.B`G.PID=6UP=&%B;&4H,"D["B1D8F@M
M/G)O;&QB86-K*"D["@HD9&)H+3YA=71O0V]M;6ET*'1R=64I.PHD9&)H+3YQ
M=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,H-BP@)W-I>"<L("=3
M:7@G+"`G,C`P,2TP,BTR-"<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y4
M3R!P:'!T97-T(%9!3%5%4R@W+"`G<V5V96XG+"`G4V5V96XG+"`G,C`P,2TP
M,BTR-2<I(BD["G!R:6YT("<V*2!B969O<F4@875T;V-O;6UI="MR;VQL8F%C
M:SH@)SL*9'5M<'1A8FQE*#`I.PH*)&1B:"T^<F]L;&)A8VLH*3L*<')I;G0@
M)S<I(&%F=&5R(&%U=&]C;VUM:70K<F]L;&)A8VLZ("<["F1U;7!T86)L92@P
M*3L*"G!R:6YT("<X*2!T97-T:6YG('1H870@<V5L96-T(&1O97-N7"=T(&1I
M<W1U<F)E(&]P8V]U;G0Z("<["B1D8F@M/F%U=&]#;VUM:70H9F%L<V4I.PHD
M9&)H+3YS:6UP;&51=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1D
M8F@M/G-I;7!L95%U97)Y*")314Q%0U0@82QC($923TT@<&AP=&5S="(I.PHD
M9&)H+3YS:6UP;&51=65R>2@B4T5,14-4(&(L9"!&4D]-('!H<'1E<W0B*3L*
M:68@*&5M<'1Y*"1D8F@M/G1R86YS86-T:6]N7V]P8V]U;G0I*2!["B`@("!P
M<FEN="`B;VM<;B(["GT@96QS92!["B`@("!P<FEN="`B9F%I;&5D("AC;W5N
M=#TD9&)H+3YT<F%N<V%C=&EO;E]O<&-O=6YT*5QN(CL*?0H`````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]S:VEP:68N
M:6YC````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38U-P`Q,#4Q-30S
M,3`U-P`P,C(Q,C,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J*@H@*B!!('1E<W0@=&\@;6%K92!S=7)E(%!%
M05(@1$(@8V%N(&)E(&9O=6YD"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@
M("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z
M('-K:7!I9BYI;F,L=B`Q+C(@,C`P-2\P,B\P,R`P-3HT.3HT-"!D86YI96QC
M($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]$0@H@*B\*"B\J*@H@*B!3970@=7`@=&AE(&EN8VQU9&5?<&%T:"P@
M97)R;W)?<F5P;W)T:6YG(&%N9"!0051(7U-%4$%2051/4@H@*B\*<F5Q=6ER
M95]O;F-E("<N+VEN8VQU9&4N:6YC)SL*"FEF("@A:6YC;'5D95]O;F-E("=$
M0BYP:'`G*2!["B`@("!P<FEN="`G<VMI<"!C;W5L9"!N;W0@9FEN9"!$0BYP
M:'`G.PI]"@``````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M8E]E<G)O<BYP:'!T````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C$T-P`Q
M,#4Q-30S,3`U-P`P,C(V,S4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*1$(Z.D1"7T5R<F]R"BTM4TM)4$E&
M+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N
M8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP("\O("TJ+2!#
M*RL@+2HM"G)E<75I<F5?;VYC92`G+B]I;F-L=61E+FEN8R<["G)E<75I<F5?
M;VYC92`G1$(N<&AP)SL*"F9U;F-T:6]N('1E<W1?97)R;W)?:&%N9&QE<B@D
M97)R;F\L("1E<G)M<V<L("1F:6QE+"`D;&EN92P@)'9A<G,I('L*("`@(&EF
M("AD969I;F5D*"=%7U-44DE#5"<I*2!["B`@("`@("`@:68@*"1E<G)N;R`F
M($5?4U1224-4"B`@("`@("`@("`@("8F("AE<G)O<E]R97!O<G1I;F<H*2`F
M($5?4U1224-4*2`A/2!%7U-44DE#5"D@>PH@("`@("`@("`@("`O+R!)9VYO
M<F4@15]35%))0U0@;F]T:6-E<R!U;FQE<W,@=&AE>2!H879E(&)E96X@='5R
M;F5D(&]N"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!](&5L
M<V4@>PH@("`@("`@(&1E9FEN92@G15]35%))0U0G+"`R,#0X*3L*("`@('T*
M("`@("1E<G)O<G1Y<&4@/2!A<G)A>2`H"B`@("`@("`@15]%4E)/4B`]/B`G
M17)R;W(G+`H@("`@("`@($5?5T%23DE.1R`]/B`G5V%R;FEN9R<L"B`@("`@
M("`@15]005)312`]/B`G4&%R<VEN9R!%<G)O<B<L"B`@("`@("`@15].3U1)
M0T4@/3X@)TYO=&EC92<L"B`@("`@("`@15]#3U)%7T524D]2(#T^("=#;W)E
M($5R<F]R)RP*("`@("`@("!%7T-/4D5?5T%23DE.1R`]/B`G0V]R92!787)N
M:6YG)RP*("`@("`@("!%7T-/35!)3$5?15)23U(@/3X@)T-O;7!I;&4@17)R
M;W(G+`H@("`@("`@($5?0T]-4$E,15]705).24Y'(#T^("=#;VUP:6QE(%=A
M<FYI;F<G+`H@("`@("`@($5?55-%4E]%4E)/4B`]/B`G57-E<B!%<G)O<B<L
M"B`@("`@("`@15]54T527U=!4DY)3D<@/3X@)U5S97(@5V%R;FEN9R<L"B`@
M("`@("`@15]54T527TY/5$E#12`]/B`G57-E<B!.;W1I8V4G+`H@("`@("`@
M($5?4U1224-4(#T^("=3=')I8W0@3F]T:6-E)RP*("`@("D["B`@("`D<')E
M9FEX(#T@)&5R<F]R='EP95LD97)R;F]=.PH@("`@<')I;G0@(EQN)'!R969I
M>#H@)&5R<FUS9R!I;B`B("X@8F%S96YA;64H)&9I;&4I("X@(B!O;B!L:6YE
M(%A86%QN(CL*?0H*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*<V5T7V5R<F]R
M7VAA;F1L97(H)W1E<W1?97)R;W)?:&%N9&QE<B<I.PH*<')I;G0@(G1E<W1I
M;F<@9&EF9F5R96YT(&5R<F]R(&-O9&5S+BXN7&XB.PHD92`](&YE=R!$0E]%
M<G)O<B@I.R!P<FEN="!S=')T;VQO=V5R*"1E+3YT;U-T<FEN9R@I*2XB7&XB
M.PHD92`](&YE=R!$0E]%<G)O<B@B=&5S="!E<G)O<B(I.R!P<FEN="!S=')T
M;VQO=V5R*"1E+3YT;U-T<FEN9R@I*2XB7&XB.PHD92`](&YE=R!$0E]%<G)O
M<BA$0E]/2RD[('!R:6YT('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI+B)<
M;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"7T524D]2*3L@<')I;G0@<W1R=&]L
M;W=E<B@D92T^=&]3=')I;F<H*2DN(EQN(CL*)&4@/2!N97<@1$)?17)R;W(H
M1$)?15)23U)?4UE.5$%8*3L@<')I;G0@<W1R=&]L;W=E<B@D92T^=&]3=')I
M;F<H*2DN(EQN(CL*)&4@/2!N97<@1$)?17)R;W(H1$)?15)23U)?1$E66D52
M3RD[('!R:6YT('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI+B)<;B(["@IP
M<FEN="`B=&5S=&EN9R!D:69F97)E;G0@97)R;W(@;6]D97,N+BY<;B(["B1E
M(#T@;F5W($1"7T5R<F]R*$1"7T524D]2+"!014%27T524D]27U!224Y4*3L@
M<')I;G0@<W1R=&]L;W=E<B@D92T^=&]3=')I;F<H*2DN(EQN(CL*)&4@/2!N
M97<@1$)?17)R;W(H1$)?15)23U)?4UE.5$%8+"!014%27T524D]27U1224='
M15(I.PH*<')I;G0@(G1E<W1I;F<@9&EF9F5R96YT(&5R<F]R('-E<G9E<FET
M:65S+BXN7&XB.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4E]364Y405@L
M(%!%05)?15)23U)?5%))1T=%4BP@15]54T527TY/5$E#12D["B1E(#T@;F5W
M($1"7T5R<F]R*$1"7T524D]27U-93E1!6"P@4$5!4E]%4E)/4E]44DE'1T52
M+"!%7U5315)?5T%23DE.1RD["B1E(#T@;F5W($1"7T5R<F]R*$1"7T524D]2
M7U-93E1!6"P@4$5!4E]%4E)/4E]44DE'1T52+"!%7U5315)?15)23U(I.PH*
M/SX*+2U'150M+0HM+5!/4U0M+0HM+4584$5#5"TM"G1E<W1I;F<@9&EF9F5R
M96YT(&5R<F]R(&-O9&5S+BXN"EMD8E]E<G)O<CH@;65S<V%G93TB9&(@97)R
M;W(Z('5N:VYO=VX@97)R;W(B(&-O9&4]+3$@;6]D93UR971U<FX@;&5V96P]
M;F]T:6-E('!R969I>#TB(B!I;F9O/2(B70I;9&)?97)R;W(Z(&UE<W-A9V4]
M(F1B(&5R<F]R.B!T97-T(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T=7)N(&QE
M=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R<F]R.B!M97-S
M86=E/2)D8B!E<G)O<CH@;F\@97)R;W(B(&-O9&4],2!M;V1E/7)E='5R;B!L
M979E;#UN;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="EMD8E]E<G)O<CH@;65S
M<V%G93TB9&(@97)R;W(Z('5N:VYO=VX@97)R;W(B(&-O9&4]+3$@;6]D93UR
M971U<FX@;&5V96P];F]T:6-E('!R969I>#TB(B!I;F9O/2(B70I;9&)?97)R
M;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!S>6YT87@@97)R;W(B(&-O9&4]+3(@
M;6]D93UR971U<FX@;&5V96P];F]T:6-E('!R969I>#TB(B!I;F9O/2(B70I;
M9&)?97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!D:79I<VEO;B!B>2!Z97)O
M(B!C;V1E/2TQ,R!M;V1E/7)E='5R;B!L979E;#UN;W1I8V4@<')E9FEX/2(B
M(&EN9F\](B)="G1E<W1I;F<@9&EF9F5R96YT(&5R<F]R(&UO9&5S+BXN"D1"
M($5R<F]R.B!U;FMN;W=N(&5R<F]R6V1B7V5R<F]R.B!M97-S86=E/2)D8B!E
M<G)O<CH@=6YK;F]W;B!E<G)O<B(@8V]D93TM,2!M;V1E/7!R:6YT(&QE=F5L
M/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*"E5S97(@3F]T:6-E.B!$0B!%
M<G)O<CH@<WEN=&%X(&5R<F]R(&EN(%!%05(N<&AP(&]N(&QI;F4@6%A8"G1E
M<W1I;F<@9&EF9F5R96YT(&5R<F]R('-E<G9E<FET:65S+BXN"@I5<V5R($YO
M=&EC93H@1$(@17)R;W(Z('-Y;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L
M:6YE(%A86`H*57-E<B!787)N:6YG.B!$0B!%<G)O<CH@<WEN=&%X(&5R<F]R
M(&EN(%!%05(N<&AP(&]N(&QI;F4@6%A8"@I5<V5R($5R<F]R.B!$0B!%<G)O
M<CH@<WEN=&%X(&5R<F]R(&EN(%!%05(N<&AP(&]N(&QI;F4@6%A8"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9&)?<&%R<V5D<VXN<&AP=```````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,Q-C4`
M,3`U,34T,S$P-3<`,#(S,S(R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM5$535"TM"D1".CIP87)S94133@HM+5-+25!)
M1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O
M;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<"`O+R`M*BT@
M0RLK("TJ+0IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E
M7V]N8V4@)T1"+G!H<"<["@IF=6YC=&EO;B!T97-T*"1D<VXI('L*("`@(&5C
M:&\@(D133CH@)&1S;EQN(CL*("`@('!R:6YT7W(H1$(Z.G!A<G-E1%-.*"1D
M<VXI*3L*?0H*9G5N8W1I;VX@=&5S=$%R<F%Y*"1D<VXI('L*("`@(&5C:&\@
M(D133CH@87)R87E<;B(["B`@("!P<FEN=%]R*$1".CIP87)S94133B@D9'-N
M*2D["GT*"G!R:6YT(")T97-T:6YG($1".CIP87)S94133BXN+EQN7&XB.PH*
M=&5S="@B;7ES<6PB*3L*=&5S="@B;V1B8RAM<W-Q;"DB*3L*=&5S="@G;V1B
M8RAD8C(I.B\O=7-E<CIP87-S=V]R9$`O9&%T86)A<V4G*3L*=&5S="@G;V1B
M8RAA8V-E<W,I.B\O+V1A=&%B87-E)RD["G1E<W0H)V]D8F,Z+R]A9&UI;D`O
M9&%T87-O=7)C94YA;64G*3L*=&5S="@B;7ES<6PZ+R]L;V-A;&AO<W0B*3L*
M=&5S="@B;7ES<6PZ+R]R96UO=&4N:&]S="YC;VTO9&(B*3L*=&5S="@B;V-I
M.#HO+W-Y<W1E;3IM86YA9V5R0"(I.PIT97-T*")O8VDX.B\O=7-E<CIP87-S
M0'1N<RUN86UE(BD["G1E<W0H(F]D8F,H<V]L:60I.B\O9F]O.F)A<D!T8W`K
M;&]C86QH;W-T*S$S,3,B*3L@("\O(&1E<')E8V%T960*=&5S="@B<&=S<6PZ
M+R]U<V5R0'5N:7@K;&]C86QH;W-T+W!E87(B*3L@("`@("`@("`@+R\@9&5P
M<F5C871E9`IT97-T*")I8F%S93HO+W5S97(E-#!D;VUA:6XZ<&%S<W=O<F1`
M:&]S="(I.PIT97-T*")I8F%S93HO+W5S97)`9&]M86EN.G!A<W-`=V]R9$`O
M9&%T86)A<V4B*3L@("`O+R!A;'-O('-U<'!O<G1E9`IT97-T*")I9G@Z+R]U
M<V5R0&1O;6%I;CIP87-S0'=O<F1`:&]S="YC;VTO+W5S<B]D8B]G96YE<F%L
M+F1B(BD["G1E<W0H)VEF>#HO+W)E;6]T92YH;W-T+F-O;2]C.EQW:6YD;W=S
M7&UY+F1B)RD["G1E<W0H)V]C:3@Z+R]32$]/5$]55#HJ*BHJ*BI`*$1%4T-2
M25!424]./2A!1$1215-37TQ)4U0]*$%$1%)%4U,]*%!23U1/0T],/51#4"DH
M2$]35#TQ.3(N,38X+C$P,2XQ-C$I*%!/4E0],34R,2DI*2A#3TY.14-47T1!
M5$$]*%-%4E9)0T5?3D%-13U425,I*2DG*3L*"B\O(&YE=R!F;W)M871S"G1E
M<W0H(F]D8F,H<V]L:60I.B\O9F]O.F)A<D!L;V-A;&AO<W0Z,3,Q,R(I.PIT
M97-T*")P9W-Q;#HO+W5S97)`=6YI>"@I+W!E87(B*3L*=&5S="@B;7ES<6PZ
M+R]U<V5R0'5N:7@H+W!A=&@O=&\O<V]C:V5T*2]P96%R(BD["G1E<W0H(G!G
M<W%L.B\O=7-E<D!T8W`H*2]P96%R(BD["G1E<W0H(G!G<W%L.B\O=7-E<D!T
M8W`H<V]M96AO<W0I+W!E87(B*3L*=&5S="@B<&=S<6PZ+R]U<V5R.G!A<W-`
M=V]R9$!T8W`H<V]M96AO<W0Z-S<W-RDO<&5A<B(I.PH*+R\@<W!E8VEA;"!B
M86-K96YD(&]P=&EO;G,*=&5S="@G:6)A<V4Z+R]U<V5R.G!A<W-`;&]C86QH
M;W-T+R]V87(O;&EB+V1B87-E+F1B9C]R;VQE/69O;R<I.PIT97-T*"=D8F%S
M93HO+T`O/W)O;&4]9F]O)F1I86QE8W0]8F%R)RD["G1E<W0H)W-Q;&ET93HO
M+R\O=6YI>"]P871H+W1O+V1A=&%B87-E/V]P=&EO;CUV86QU929A;F]T:&5R
M;W!T:6]N/6%N;W1H97)V86QU92<I.PIT97-T*"=S<6QI=&4Z+R\O8SHO=VEN
M+W!A=&@O=&\O9&%T86)A<V4_;W!T:6]N/79A;'5E)RD["@HO+R!S;VUE(&5X
M86UP;&5S(&9R;VT@;6%N=6%L"G1E<W0H)VUY<W%L.B\O=7-E<FYA;65`:&]S
M='-P96,G*3L*=&5S="@G;7ES<6PZ+R]H;W-T<W!E8R]D871A8F%S92<I.PIT
M97-T*"=M>7-Q;#HO+VAO<W1S<&5C)RD["G1E<W0H)VUY<W%L.B\O+V1A=&%B
M87-E)RD["@HO+R!A<G)A>2!T97-T<PHD87)R87D@/2!A<G)A>2@*("`@("=P
M:'!T>7!E)R`@/3X@)VUY<W%L)RP*("`@("=H;W-T<W!E8R<@/3X@)V9O;V)A
M<B<L"BD["G1E<W1!<G)A>2@D87)R87DI.PH*/SX*+2U'150M+0HM+5!/4U0M
M+0HM+4584$5#5"TM"G1E<W1I;F<@1$(Z.G!A<G-E1%-.+BXN"@I$4TXZ(&UY
M<W%L"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN
M=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R
M9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^(`H@("`@6VAO<W1S<&5C72`]/B`*
M("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E
M72`]/B`**0I$4TXZ(&]D8F,H;7-S<6PI"D%R<F%Y"B@*("`@(%MP:'!T>7!E
M72`]/B!O9&)C"B`@("!;9&)S>6YT87A=(#T^(&US<W%L"B`@("!;=7-E<FYA
M;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@
M"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME
M=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;V1B8RAD8C(I.B\O
M=7-E<CIP87-S=V]R9$`O9&%T86)A<V4*07)R87D**`H@("`@6W!H<'1Y<&5=
M(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@9&(R"B`@("!;=7-E<FYA;65=
M(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@<&%S<W=O<F0*("`@(%MP<F]T
M;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^
M(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1A=&%B87-E
M"BD*1%-..B!O9&)C*&%C8V5S<RDZ+R\O9&%T86)A<V4*07)R87D**`H@("`@
M6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@86-C97-S"B`@
M("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T
M;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^
M(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1A=&%B87-E
M"BD*1%-..B!O9&)C.B\O861M:6Y`+V1A=&%S;W5R8V5.86UE"D%R<F%Y"B@*
M("`@(%MP:'!T>7!E72`]/B!O9&)C"B`@("!;9&)S>6YT87A=(#T^(&]D8F,*
M("`@(%MU<V5R;F%M95T@/3X@861M:6X*("`@(%MP87-S=V]R9%T@/3X@"B`@
M("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B`*("`@(%MP
M;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!D
M871A<V]U<F-E3F%M90HI"D133CH@;7ES<6PZ+R]L;V-A;&AO<W0*07)R87D*
M*`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;9&)S>6YT87A=(#T^(&UY
M<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@
M(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&QO8V%L:&]S
M=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A
M<V5=(#T^(`HI"D133CH@;7ES<6PZ+R]R96UO=&4N:&]S="YC;VTO9&(*07)R
M87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;9&)S>6YT87A=(#T^
M(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*
M("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(')E;6]T
M92YH;W-T+F-O;0H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@
M("!;9&%T86)A<V5=(#T^(&1B"BD*1%-..B!O8VDX.B\O<WES=&5M.FUA;F%G
M97)`"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O8VDX"B`@("!;9&)S>6YT
M87A=(#T^(&]C:3@*("`@(%MU<V5R;F%M95T@/3X@<WES=&5M"B`@("!;<&%S
M<W=O<F1=(#T^(&UA;F%G97(*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;
M:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@
M"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;V-I.#HO+W5S97(Z<&%S<T!T
M;G,M;F%M90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;V-I.`H@("`@6V1B
M<WEN=&%X72`]/B!O8VDX"B`@("!;=7-E<FYA;65=(#T^('5S97(*("`@(%MP
M87-S=V]R9%T@/3X@<&%S<PH@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH
M;W-T<W!E8UT@/3X@=&YS+6YA;64*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K
M971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ(&]D8F,H<V]L:60I
M.B\O9F]O.F)A<D!T8W`K;&]C86QH;W-T*S$S,3,*07)R87D**`H@("`@6W!H
M<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@<V]L:60*("`@(%MU
M<V5R;F%M95T@/3X@9F]O"B`@("!;<&%S<W=O<F1=(#T^(&)A<@H@("`@6W!R
M;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@;&]C86QH;W-T*S$S
M,3,*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B
M87-E72`]/B`**0I$4TXZ('!G<W%L.B\O=7-E<D!U;FEX*VQO8V%L:&]S="]P
M96%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!P9W-Q;`H@("`@6V1B<WEN
M=&%X72`]/B!P9W-Q;`H@("`@6W5S97)N86UE72`]/B!U<V5R"B`@("!;<&%S
M<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!U;FEX"B`@("!;:&]S='-P
M96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@;&]C86QH
M;W-T"B`@("!;9&%T86)A<V5=(#T^('!E87(**0I$4TXZ(&EB87-E.B\O=7-E
M<B4T,&1O;6%I;CIP87-S=V]R9$!H;W-T"D%R<F%Y"B@*("`@(%MP:'!T>7!E
M72`]/B!I8F%S90H@("`@6V1B<WEN=&%X72`]/B!I8F%S90H@("`@6W5S97)N
M86UE72`]/B!U<V5R0&1O;6%I;@H@("`@6W!A<W-W;W)D72`]/B!P87-S=V]R
M9`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@:&]S
M=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A
M<V5=(#T^(`HI"D133CH@:6)A<V4Z+R]U<V5R0&1O;6%I;CIP87-S0'=O<F1`
M+V1A=&%B87-E"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!I8F%S90H@("`@
M6V1B<WEN=&%X72`]/B!I8F%S90H@("`@6W5S97)N86UE72`]/B!U<V5R0&1O
M;6%I;@H@("`@6W!A<W-W;W)D72`]/B!P87-S0'=O<F0*("`@(%MP<F]T;V-O
M;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@
M("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1A=&%B87-E"BD*
M1%-..B!I9G@Z+R]U<V5R0&1O;6%I;CIP87-S0'=O<F1`:&]S="YC;VTO+W5S
M<B]D8B]G96YE<F%L+F1B"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!I9G@*
M("`@(%MD8G-Y;G1A>%T@/3X@:69X"B`@("!;=7-E<FYA;65=(#T^('5S97)`
M9&]M86EN"B`@("!;<&%S<W=O<F1=(#T^('!A<W-`=V]R9`H@("`@6W!R;W1O
M8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@:&]S="YC;VT*("`@(%MP
M;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`O
M=7-R+V1B+V=E;F5R86PN9&(**0I$4TXZ(&EF>#HO+W)E;6]T92YH;W-T+F-O
M;2]C.EQW:6YD;W=S7&UY+F1B"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!I
M9G@*("`@(%MD8G-Y;G1A>%T@/3X@:69X"B`@("!;=7-E<FYA;65=(#T^(`H@
M("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;
M:&]S='-P96-=(#T^(')E;6]T92YH;W-T+F-O;0H@("`@6W!O<G1=(#T^(`H@
M("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&,Z7'=I;F1O=W-<
M;7DN9&(**0I$4TXZ(&]C:3@Z+R]32$]/5$]55#HJ*BHJ*BI`*$1%4T-225!4
M24]./2A!1$1215-37TQ)4U0]*$%$1%)%4U,]*%!23U1/0T],/51#4"DH2$]3
M5#TQ.3(N,38X+C$P,2XQ-C$I*%!/4E0],34R,2DI*2A#3TY.14-47T1!5$$]
M*%-%4E9)0T5?3D%-13U425,I*2D*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^
M(&]C:3@*("`@(%MD8G-Y;G1A>%T@/3X@;V-I.`H@("`@6W5S97)N86UE72`]
M/B!32$]/5$]55`H@("`@6W!A<W-W;W)D72`]/B`J*BHJ*BH*("`@(%MP<F]T
M;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^("A$15-#4DE05$E/3CTH
M041$4D534U],25-4/2A!1$1215-3/2A04D]43T-/3#U40U`I*$A/4U0],3DR
M+C$V."XQ,#$N,38Q*2A03U)4/3$U,C$I*2DH0T].3D5#5%]$051!/2A315)6
M24-%7TY!344]5$E3*2DI"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]
M/B`*("`@(%MD871A8F%S95T@/3X@"BD*1%-..B!O9&)C*'-O;&ED*3HO+V9O
M;SIB87)`;&]C86QH;W-T.C$S,3,*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^
M(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@<V]L:60*("`@(%MU<V5R;F%M95T@
M/3X@9F]O"B`@("!;<&%S<W=O<F1=(#T^(&)A<@H@("`@6W!R;W1O8V]L72`]
M/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@;&]C86QH;W-T"B`@("!;<&]R=%T@
M/3X@,3,Q,PH@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI
M"D133CH@<&=S<6PZ+R]U<V5R0'5N:7@H*2]P96%R"D%R<F%Y"B@*("`@(%MP
M:'!T>7!E72`]/B!P9W-Q;`H@("`@6V1B<WEN=&%X72`]/B!P9W-Q;`H@("`@
M6W5S97)N86UE72`]/B!U<V5R"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R
M;W1O8V]L72`]/B!U;FEX"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=
M(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^('!E87(*
M*0I$4TXZ(&UY<W%L.B\O=7-E<D!U;FEX*"]P871H+W1O+W-O8VME="DO<&5A
M<@I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES<6P*("`@(%MD8G-Y;G1A
M>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@=7-E<@H@("`@6W!A<W-W
M;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=6YI>`H@("`@6VAO<W1S<&5C
M72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^("]P871H+W1O
M+W-O8VME=`H@("`@6V1A=&%B87-E72`]/B!P96%R"BD*1%-..B!P9W-Q;#HO
M+W5S97)`=&-P*"DO<&5A<@I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@<&=S
M<6P*("`@(%MD8G-Y;G1A>%T@/3X@<&=S<6P*("`@(%MU<V5R;F%M95T@/3X@
M=7-E<@H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P
M"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME
M=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^('!E87(**0I$4TXZ('!G<W%L.B\O
M=7-E<D!T8W`H<V]M96AO<W0I+W!E87(*07)R87D**`H@("`@6W!H<'1Y<&5=
M(#T^('!G<W%L"B`@("!;9&)S>6YT87A=(#T^('!G<W%L"B`@("!;=7-E<FYA
M;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=
M(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!S;VUE:&]S=`H@("`@6W!O<G1=
M(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^('!E87(*
M*0I$4TXZ('!G<W%L.B\O=7-E<CIP87-S0'=O<F1`=&-P*'-O;65H;W-T.C<W
M-S<I+W!E87(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^('!G<W%L"B`@("!;
M9&)S>6YT87A=(#T^('!G<W%L"B`@("!;=7-E<FYA;65=(#T^('5S97(*("`@
M(%MP87-S=V]R9%T@/3X@<&%S<T!W;W)D"B`@("!;<')O=&]C;VQ=(#T^('1C
M<`H@("`@6VAO<W1S<&5C72`]/B!S;VUE:&]S=`H@("`@6W!O<G1=(#T^(#<W
M-S<*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!P96%R"BD*
M1%-..B!I8F%S93HO+W5S97(Z<&%S<T!L;V-A;&AO<W0O+W9A<B]L:6(O9&)A
M<V4N9&)F/W)O;&4]9F]O"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!I8F%S
M90H@("`@6V1B<WEN=&%X72`]/B!I8F%S90H@("`@6W5S97)N86UE72`]/B!U
M<V5R"B`@("!;<&%S<W=O<F1=(#T^('!A<W,*("`@(%MP<F]T;V-O;%T@/3X@
M=&-P"B`@("!;:&]S='-P96-=(#T^(&QO8V%L:&]S=`H@("`@6W!O<G1=(#T^
M(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^("]V87(O;&EB
M+V1B87-E+F1B9@H@("`@6W)O;&5=(#T^(&9O;PHI"D133CH@9&)A<V4Z+R]`
M+S]R;VQE/69O;R9D:6%L96-T/6)A<@I!<G)A>0HH"B`@("!;<&AP='EP95T@
M/3X@9&)A<V4*("`@(%MD8G-Y;G1A>%T@/3X@9&)A<V4*("`@(%MU<V5R;F%M
M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T
M8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C
M:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@"B`@("!;<F]L95T@/3X@9F]O
M"B`@("!;9&EA;&5C=%T@/3X@8F%R"BD*1%-..B!S<6QI=&4Z+R\O+W5N:7@O
M<&%T:"]T;R]D871A8F%S93]O<'1I;VX]=F%L=64F86YO=&AE<F]P=&EO;CUA
M;F]T:&5R=F%L=64*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^('-Q;&ET90H@
M("`@6V1B<WEN=&%X72`]/B!S<6QI=&4*("`@(%MU<V5R;F%M95T@/3X@"B`@
M("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH
M;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*
M("`@(%MD871A8F%S95T@/3X@+W5N:7@O<&%T:"]T;R]D871A8F%S90H@("`@
M6V]P=&EO;ET@/3X@=F%L=64*("`@(%MA;F]T:&5R;W!T:6]N72`]/B!A;F]T
M:&5R=F%L=64**0I$4TXZ('-Q;&ET93HO+R]C.B]W:6XO<&%T:"]T;R]D871A
M8F%S93]O<'1I;VX]=F%L=64*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^('-Q
M;&ET90H@("`@6V1B<WEN=&%X72`]/B!S<6QI=&4*("`@(%MU<V5R;F%M95T@
M/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*
M("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T
M72`]/B`*("`@(%MD871A8F%S95T@/3X@8SHO=VEN+W!A=&@O=&\O9&%T86)A
M<V4*("`@(%MO<'1I;VY=(#T^('9A;'5E"BD*1%-..B!M>7-Q;#HO+W5S97)N
M86UE0&AO<W1S<&5C"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@
M("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N86UE72`]/B!U<V5R
M;F%M90H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P
M"B`@("!;:&]S='-P96-=(#T^(&AO<W1S<&5C"B`@("!;<&]R=%T@/3X@"B`@
M("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@"BD*1%-..B!M>7-Q
M;#HO+VAO<W1S<&5C+V1A=&%B87-E"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]
M/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N86UE
M72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C
M<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T<W!E8PH@("`@6W!O<G1=(#T^(`H@
M("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1A=&%B87-E"BD*
M1%-..B!M>7-Q;#HO+VAO<W1S<&5C"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]
M/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N86UE
M72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C
M<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T<W!E8PH@("`@6W!O<G1=(#T^(`H@
M("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;7ES
M<6PZ+R\O9&%T86)A<V4*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L
M"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@
M("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;
M:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@
M"B`@("!;9&%T86)A<V5=(#T^(&1A=&%B87-E"BD*1%-..B!A<G)A>0I!<G)A
M>0HH"B`@("!;<&AP='EP95T@/3X@;7ES<6P*("`@(%MD8G-Y;G1A>%T@/3X@
M;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@
M("`@6W!R;W1O8V]L72`]/B`*("`@(%MH;W-T<W!E8UT@/3X@9F]O8F%R"B`@
M("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@
M/3X@"BD*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O:6YC
M;'5D92YI;F,N;W)I9P``````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P-30`,3`U
M,34T,S$P-3<`,#(S,C$R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@HO*BH*("H@4V5T<R!T:&4@:6YC;'5D95]P
M871H+"!E<G)O<E]R97!O<G1I;F<@86YD(%!!5$A?4T5005)!5$]2(&9O<B!T
M97-T<PH@*B!I;B!T:&4@1$(O=&5S=',@9&ER96-T;W)Y"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`
M=F5R<VEO;B`@("`D260Z(&EN8VQU9&4N:6YC+'8@,2XU(#(P,#4O,#(O,#,@
M,#4Z-#DZ-#0@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@IE<G)O<E]R97!O<G1I;F<H
M15]!3$PI.PH*:68@*"%D969I;F5D*"=0051(7U-%4$%2051/4B<I*2!["B`@
M("!I9B`H<W1R:7-T<BA02%!?3U,L("=724XG*2D@>PH@("`@("`@("\J*@H@
M("`@("`@("`J($1E9FEN92!T:&4@<&%T:"!S97!A<F%T;W(@9F]R('=I;F1O
M=W,*("`@("`@("`@*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2
M)RP@)SLG*3L*("`@('T@96QS92!["B`@("`@("`@+RHJ"B`@("`@("`@("H@
M1&5F:6YE('1H92!P871H('-E<&%R871O<B!F;W(@;W1H97(@<WES=&5M<PH@
M("`@("`@("`J+PH@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%43U(G+"`G
M.B<I.PH@("`@?0I]"@HO*@H@*B!)9B!T:&4@<&%T:"!T;R!Y;W5R(%!%05(@
M:6YS=&%L;&%T:6]N(&ES(&9O=6YD(&EN('1H92!L969T(&AA;F0*("H@<&]R
M=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N(&)E;&]W+"!T:&%T(&UE86YS
M('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M('1H92!014%2(&EN<W1A;&QE
M<BX@(%1H97)E9F]R92P@;&5T)W,@=7-E('1H90H@*B!I;G-T86QL960@=F5R
M<VEO;B!O9B!$0BP@=VAI8V@@<VAO=6QD(&)E(&9O=6YD('9I82!T:&4*("H@
M8V]M<'5T97(G<R!D969A=6QT(&EN8VQU9&5?<&%T:"X@($%D9"`G+B<@=&\@
M=&AE(&EN8VQU9&5?<&%T:`H@*B!T;R!E;G-U<F4@)RXG(&ES(&EN('1H97)E
M+@H@*B`*("H@268@=&AE('!A=&@@:&%S(&YO="!B965N('-U8G-T:71U=&5D
M(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J('1H:7,@9FEL92!H87,@;&EK
M96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U="!O<B!A("YT87(@9FEL92X*
M("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@=&AE('1E<W1S('-H;W5L9"!U
M<V4@=&AE('9E<G-I;VX@;V8*("H@1$(@=&AA="!H87,@8V]M92!F<F]M('1H
M97)E(&%S('=E;&PN"B`J+PII9B`H)R]H;VUE+VQU8V5R+W=O<FLO<&5A<B]S
M:&%R92]P:'`G("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L*("`@(&EN
M:5]S970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I
M"B`@("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<*("`@("D["GT@
M96QS92!["B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!R96%L<&%T:"AD
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*0H@("`@("`@("`@("`N(%!!5$A?
M4T5005)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(*("`@("`@("`@("`@
M+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M3F5T7U--5%`O````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-3<`,#(P,#<W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R\`````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C$R-#$`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]33510+W1E
M<W1S+V)A<VEC+G!H<'0`````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S(T`#$P
M-3$U-#,Q,#4W`#`R,S(Q-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````M+51%4U0M+0I.971?4TU44#H@0F%S:6,@1G5N8W1I
M;VYA;&ET>0HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=.970O4TU4
M4"YP:'`G.PIR97%U:7)E7V]N8V4@)V-O;F9I9RYP:'`G.PH*:68@*"$@*"1S
M;71P(#T@;F5W($YE=%]33510*%1%4U1?2$]35$Y!344L(%1%4U1?4$]25"P@
M5$535%],3T-!3$A/4U0I*2D@>PH)9&EE*")5;F%B;&4@=&\@:6YS=&%N=&EA
M=&4@3F5T7U--5%`@;V)J96-T7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H
M)&4@/2`D<VUT<"T^8V]N;F5C="@I*2D@>PH)9&EE*"1E+3YG971-97-S86=E
M*"D@+B`B7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H)'-M='`M/FUA:6Q&
M<F]M*%1%4U1?1E)/32DI*2!["@ED:64H)U5N86)L92!T;R!S970@<V5N9&5R
M('1O(#PG("X@5$535%]&4D]-("X@(CY<;B(I.PI]"@II9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S(#T@)'-M='`M/G)C<'14;RA415-47U1/*2DI('L*"61I92@G
M56YA8FQE('1O(&%D9"!R96-I<&EE;G0@/"<@+B!415-47U1/("X@)SXZ("<@
M+@H)"21R97,M/F=E=$UE<W-A9V4H*2`N(")<;B(I.PI]"@II9B`H4$5!4CHZ
M:7-%<G)O<B@D<VUT<"T^9&%T82A415-47U-50DI%0U0@+B`B7')<;B(@+B!4
M15-47T)/1%DI*2D@>PH)9&EE*")5;F%B;&4@=&\@<V5N9"!D871A7&XB*3L*
M?0H*)'-M='`M/F1I<V-O;FYE8W0H*3L*"F5C:&\@)U-U8V-E<W,A)SL*"BTM
M15A014-4+2T*4W5C8V5S<R$*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]3
M3510+W1E<W1S+V-O;F9I9RYP:'`N9&ES=```````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-S4P`#$P-3$U-#,Q,#4W`#`R-#$V,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@0V]P>2!T:&ES(&9I
M;&4@=&\@8V]N9FEG+G!H<"!A;F0@8W5S=&]M:7IE('1H92!F;VQL;W=I;F<@
M=F%L=65S('1O"B`J('-U:70@>6]U<B!C;VYF:6=U<F%T:6]N+@H@*B\*"F1E
M9FEN92@G5$535%](3U-43D%-12<L("`@("`G;&]C86QH;W-T)RD["F1E9FEN
M92@G5$535%]03U)4)RP@("`@("`@("`R-2D["F1E9FEN92@G5$535%],3T-!
M3$A/4U0G+"`@("`G;&]C86QH;W-T)RD["F1E9FEN92@G5$535%]!551(7U53
M15(G+"`@("`G:F]N)RD["F1E9FEN92@G5$535%]!551(7U!!4U,G+"`@("`G
M<V5C<F5T)RD["F1E9FEN92@G5$535%]&4D]-)RP@("`@("`@("`G9G)O;4!E
M>&%M<&QE+F-O;2<I.PID969I;F4H)U1%4U1?5$\G+"`@("`@("`@("`@)W1O
M0&5X86UP;&4N8V]M)RD["F1E9FEN92@G5$535%]354)*14-4)RP@("`@("`G
M5&5S="!3=6)J96-T)RD["F1E9FEN92@G5$535%]"3T19)RP@("`@("`@("`G
M5&5S="!";V1Y)RD["@```````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R]Q
M=6]T961A=&$N<&AP=```````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0P,P`Q,#4Q-30S
M,3`U-P`P,C0Q,C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*3F5T7U--5%`Z('%U;W1E9&%T82@I(%QN('P@
M7'(@(#T^(%QR7&X@<F5P;&%C96UE;G0*+2U&24Q%+2T*/#]P:'`*"F5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?;VYC92`G3F5T+U--5%`N<&AP
M)SL*"B1T97-T<R`](&%R<F%Y*`H@("`@(EQN(B`@("`@("`@("`@("`@(#T^
M(")<<EQN(BP*("`@(")<<EQN(B`@("`@("`@("`@("`]/B`B7')<;B(L"B`@
M("`B7&YX>"(@("`@("`@("`@("`@/3X@(EQR7&YX>"(L"B`@("`B>'A<;B(@
M("`@("`@("`@("`@/3X@(GAX7')<;B(L"B`@("`B>'A<;GAX(B`@("`@("`@
M("`@/3X@(GAX7')<;GAX(BP*("`@(")<;EQN>'@B("`@("`@("`@("`]/B`B
M7')<;EQR7&YX>"(L"B`@("`B>'A<;EQN>'@B("`@("`@("`@/3X@(GAX7')<
M;EQR7&YX>"(L"B`@("`B>'A<;EQN(B`@("`@("`@("`@/3X@(GAX7')<;EQR
M7&XB+`H@("`@(EQR7&YX>"(@("`@("`@("`@(#T^(")<<EQN>'@B+`H@("`@
M(GAX7')<;B(@("`@("`@("`@(#T^(")X>%QR7&XB+`H@("`@(GAX7')<;GAX
M(B`@("`@("`@(#T^(")X>%QR7&YX>"(L"B`@("`B7')<;EQR7&YX>"(@("`@
M("`@/3X@(EQR7&Y<<EQN>'@B+`H@("`@(GAX7')<;EQR7&YX>"(@("`@(#T^
M(")X>%QR7&Y<<EQN>'@B+`H@("`@(GAX7')<;EQR7&XB("`@("`@(#T^(")X
M>%QR7&Y<<EQN(BP*("`@(")<<EQN7&YX>"(@("`@("`@("`]/B`B7')<;EQR
M7&YX>"(L"B`@("`B7&Y<<EQN>'@B("`@("`@("`@/3X@(EQR7&Y<<EQN>'@B
M+`H@("`@(GAX7')<;EQN>'@B("`@("`@(#T^(")X>%QR7&Y<<EQN>'@B+`H@
M("`@(GAX7&Y<<EQN>'@B("`@("`@(#T^(")X>%QR7&Y<<EQN>'@B+`H@("`@
M(GAX7')<;EQN(B`@("`@("`@(#T^(")X>%QR7&Y<<EQN(BP*("`@(")X>%QN
M7')<;B(@("`@("`@("`]/B`B>'A<<EQN7')<;B(L"B`@("`B7'(B("`@("`@
M("`@("`@("`@/3X@(EQR7&XB+`H@("`@(EQR>'@B("`@("`@("`@("`@(#T^
M(")<<EQN>'@B+`H@("`@(GAX7')X>"(@("`@("`@("`@(#T^(")X>%QR7&YX
M>"(L"B`@("`B>'A<<B(@("`@("`@("`@("`@/3X@(GAX7')<;B(L"B`@("`B
M7')<<B(@("`@("`@("`@("`@/3X@(EQR7&Y<<EQN(BP*("`@(")<<EQR>'@B
M("`@("`@("`@("`]/B`B7')<;EQR7&YX>"(L"B`@("`B>'A<<EQR>'@B("`@
M("`@("`@/3X@(GAX7')<;EQR7&YX>"(L"B`@("`B>'A<<EQR(B`@("`@("`@
M("`@/3X@(GAX7')<;EQR7&XB+`H@("`@(GAX7')X>%QN>'A<<EQN>'@B(#T^
M(")X>%QR7&YX>%QR7&YX>%QR7&YX>"(L"B`@("`B7')<<EQN7&XB("`@("`@
M("`@/3X@(EQR7&Y<<EQN7')<;B(L"BD["@HD:&%D17)R;W(@/2!F86QS93L*
M9F]R96%C:"`H)'1E<W1S(&%S("1I;G!U="`]/B`D97AP96-T*2!["B`@("`D
M;W5T<'5T(#T@)&EN<'5T.PH@("`@3F5T7U--5%`Z.G%U;W1E9&%T82@D;W5T
M<'5T*3L*("`@(&EF("@D;W5T<'5T("$]("1E>'!E8W0I('L*("`@("`@("!E
M8VAO(")%<G)O<CH@:6YP=70@(B`N('!R971T>7!R:6YT*"1I;G!U="D@+B`B
M+"!O=71P=70@(B`N('!R971T>7!R:6YT*"1O=71P=70I("X@(BP@97AP96-T
M960@(B`N('!R971T>7!R:6YT*"1E>'!E8W0I("X@(EQN(CL*("`@("`@("`D
M:&%D17)R;W(@/2!T<G5E.PH@("`@?0I]"@II9B`H(21H861%<G)O<BD@>PH@
M("`@96-H;R`B<W5C8V5S<UQN(CL*?0H*9G5N8W1I;VX@<')E='1Y<')I;G0H
M)'@I"GL*("`@(')E='5R;B!S=')?<F5P;&%C92AA<G)A>2@B7'(B+"`B7&XB
M*2P@87)R87DH)UQR)RP@)UQN)RDL("1X*3L*?0H*+2U%6%!%0U0M+0IS=6-C
M97-S"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T7U--5%`O=&5S=',O875T:"YP
M:'!T````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T,S8`,3`U,34T,S$P-3<`
M,#(S,3`P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM5$535"TM"DYE=%]33510.B!33510($%U=&AE;G1I8V%T:6]N"BTM
M1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TYE="]33510+G!H<"<["G)E
M<75I<F5?;VYC92`G8V]N9FEG+G!H<"<["@II9B`H(2`H)'-M='`@/2!N97<@
M3F5T7U--5%`H5$535%](3U-43D%-12P@5$535%]03U)4+"!415-47TQ/0T%,
M2$]35"DI*2!["@ED:64H(E5N86)L92!T;R!I;G-T86YT:6%T92!.971?4TU4
M4"!O8FIE8W1<;B(I.PI]"@II9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1S;71P
M+3YC;VYN96-T*"DI*2!["@ED:64H)&4M/F=E=$UE<W-A9V4H*2`N(")<;B(I
M.PI]"@II9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1S;71P+3YA=71H*%1%4U1?
M05542%]54T52+"!415-47T%55$A?4$%34RDI*2!["GT*"FEF("A014%2.CII
M<T5R<F]R*"1S;71P+3YM86EL1G)O;2A415-47T923TTI*2D@>PH)9&EE*"=5
M;F%B;&4@=&\@<V5T('-E;F1E<B!T;R`\)R`N(%1%4U1?1E)/32`N("(^7&XB
M*3L*?0H*:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1S;71P+3YR8W!T5&\H
M5$535%]43RDI*2!["@ED:64H)U5N86)L92!T;R!A9&0@<F5C:7!I96YT(#PG
M("X@5$535%]43R`N("<^.B`G("X*"0DD<F5S+3YG971-97-S86=E*"D@+B`B
M7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H)'-M='`M/F1A=&$H5$535%]3
M54)*14-4("X@(EQR7&XB("X@5$535%]"3T19*2DI('L*"61I92@B56YA8FQE
M('1O('-E;F0@9&%T85QN(BD["GT*"B1S;71P+3YD:7-C;VYN96-T*"D["@IE
M8VAO("=3=6-C97-S(2<["@HM+4584$5#5"TM"E-U8V-E<W,A"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O36%I;"\`````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-3<`,#$W,S<P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]-86EL+W1E<W1S+P``````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,C`U,S(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+TUA:6PO=&5S=',O<VUT<%]E<G)O<BYP:'!T
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S(W`#$P-3$U-#,Q,#4W`#`R,S8R
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I-86EL.B!33510($5R<F]R(%)E<&]R=&EN9PHM+5-+25!)1BTM
M"CP_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(O4F5G:7-T<GDN<&AP)SL*)')E
M9VES=')Y(#T@)FYE=R!014%27U)E9VES=')Y*"D["@II9B`H(21R96=I<W1R
M>2T^<&%C:V%G945X:7-T<R@G3F5T7U--5%`G*2D@9&EE*")S:VEP7&XB*3L*
M+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("=-86EL+G!H<"<["@HO*B!2
M969E<F5N8V4@82!B;V=U<R!33510('-E<G9E<B!A9&1R97-S('1O(&=U87)A
M;G1E92!A(&-O;FYE8W1I;VX@9F%I;'5R92X@*B\*)'!A<F%M<R`](&%R<F%Y
M*"=H;W-T)R`]/B`G8F]G=7,N:&]S="YT;&0G*3L*"B\J($-R96%T92!O=7(@
M4TU44"UB87-E9"!M86EL97(@;V)J96-T+B`J+PHD;6%I;&5R(#T@)DUA:6PZ
M.F9A8W1O<GDH)W-M='`G+"`D<&%R86US*3L*"B\J($%T=&5M<'0@=&\@<V5N
M9"!A;B!E;7!T>2!M97-S86=E(&EN(&]R9&5R('1O('1R:6=G97(@86X@97)R
M;W(N("HO"FEF("A014%2.CII<T5R<F]R*"1E(#T@)&UA:6QE<BT^<V5N9"AA
M<G)A>2@I+"!A<G)A>2@I+"`G)RDI*2!["B`@("!D:64H)&4M/F=E=$UE<W-A
M9V4H*2`N(")<;B(I.PI]"@HM+4584$5#5"TM"D9A:6QE9"!T;R!C;VYN96-T
M('1O(&)O9W5S+FAO<W0N=&QD.C(U(%M33510.B!&86EL960@=&\@8V]N;F5C
M="!S;V-K970Z(%5N:VYO=VX@97)R;W(Z(#`@*&-O9&4Z("TQ+"!R97-P;VYS
M93H@*5T*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TUA:6PO=&5S=',O<F9C.#(R+G!H
M<'0``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,3$U`#$P-3$U-#,Q,#4W
M`#`R,C0S-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+51%4U0M+0I-86EL7U)&0S@R,CH@061D<F5S<R!087)S:6YG"BTM
M1DE,12TM"CP_<&AP"G)E<75I<F5?;VYC92`G36%I;"]21D,X,C(N<&AP)SL*
M"B1P87)S97(@/2`F;F5W($UA:6Q?4D9#.#(R*"D["B`*+RH@02!S:6UP;&4L
M(&)A<F4@861D<F5S<RX@*B\*)&%D9')E<W,@/2`G=7-E<D!E>&%M<&QE+F-O
M;2<["G!R:6YT7W(H)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D861D<F5S
M<RP@;G5L;"P@=')U92P@=')U92DI.PH*+RH@061D<F5S<R!G<F]U<',N("HO
M"B1A9&1R97-S(#T@)TUY($=R;W5P.B`B4FEC:&%R9"(@/')I8VAA<F1`;&]C
M86QH;W-T/B`H02!C;VUM96YT*2P@=&5D0&5X86UP;&4N8V]M("A4960@0FQO
M9V=S*2P@0F%R;F5Y.R<["G!R:6YT7W(H)'!A<G-E<BT^<&%R<V5!9&1R97-S
M3&ES="@D861D<F5S<RP@;G5L;"P@=')U92P@=')U92DI.PH*+RH@02!V86QI
M9"!A9&1R97-S('=I=&@@<W!A8V5S(&EN('1H92!L;V-A;"!P87)T+B`J+PHD
M861D<F5S<R`]("<\(DIO;B!087)I<V4B0'!H<"YN970^)SL*<')I;G1?<B@D
M<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1A9&1R97-S+"!N=6QL+"!T<G5E
M+"!T<G5E*2D["@HO*B!!;B!I;G9A;&ED(&%D9')E<W,@=VET:"!S<&%C97,@
M:6X@=&AE(&QO8V%L('!A<G0N("HO"B1A9&1R97-S(#T@)SQ*;VX@4&%R:7-E
M0'!H<"YN970^)SL*)')E<W5L="`]("1P87)S97(M/G!A<G-E061D<F5S<TQI
M<W0H)&%D9')E<W,L(&YU;&PL('1R=64L('1R=64I.PII9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@96-H;R`D<F5S=6QT+3YG971-97-S86=E*"D@+B`B
M7&XB.PH*+2U%6%!%0U0M+0I!<G)A>0HH"B`@("!;,%T@/3X@<W1D0VQA<W,@
M3V)J96-T"B`@("`@("`@*`H@("`@("`@("`@("!;<&5R<V]N86Q=(#T^(`H@
M("`@("`@("`@("!;8V]M;65N=%T@/3X@07)R87D*("`@("`@("`@("`@("`@
M("@*("`@("`@("`@("`@("`@("D*"B`@("`@("`@("`@(%MM86EL8F]X72`]
M/B!U<V5R"B`@("`@("`@("`@(%MH;W-T72`]/B!E>&%M<&QE+F-O;0H@("`@
M("`@("D*"BD*07)R87D**`H@("`@6S!=(#T^('-T9$-L87-S($]B:F5C=`H@
M("`@("`@("@*("`@("`@("`@("`@6V=R;W5P;F%M95T@/3X@37D@1W)O=7`*
M("`@("`@("`@("`@6V%D9')E<W-E<UT@/3X@07)R87D*("`@("`@("`@("`@
M("`@("@*("`@("`@("`@("`@("`@("`@("!;,%T@/3X@<W1D0VQA<W,@3V)J
M96-T"B`@("`@("`@("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%MP97)S;VYA;%T@/3X@(E)I8VAA<F0B"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!;8V]M;65N=%T@/3X@07)R87D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%LP72`]/B!!(&-O;6UE;G0*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`I"@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@6VUA:6QB;WA=(#T^(')I8VAA<F0*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%MH;W-T72`]/B!L;V-A;&AO<W0*("`@("`@("`@("`@
M("`@("`@("`@("`@*0H*("`@("`@("`@("`@("`@("`@("!;,5T@/3X@<W1D
M0VQA<W,@3V)J96-T"B`@("`@("`@("`@("`@("`@("`@("`@("@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%MP97)S;VYA;%T@/3X@"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!;8V]M;65N=%T@/3X@07)R87D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%LP72`]/B!4960@0FQO9V=S"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*0H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%MM86EL8F]X72`]/B!T960*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%MH;W-T72`]/B!E>&%M<&QE+F-O;0H@("`@("`@("`@("`@
M("`@("`@("`@("`I"@H@("`@("`@("`@("`@("`@("`@(%LR72`]/B!S=&1#
M;&%S<R!/8FIE8W0*("`@("`@("`@("`@("`@("`@("`@("`@*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@6W!E<G-O;F%L72`]/B`*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%MC;VUM96YT72`]/B!!<G)A>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6VUA:6QB;WA=(#T^($)A<FYE>0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6VAO<W1=(#T^(&QO8V%L:&]S=`H@("`@("`@("`@("`@("`@("`@("`@
M("`I"@H@("`@("`@("`@("`@("`@*0H*("`@("`@("`I"@HI"D%R<F%Y"B@*
M("`@(%LP72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@("`H"B`@("`@("`@
M("`@(%MP97)S;VYA;%T@/3X@"B`@("`@("`@("`@(%MC;VUM96YT72`]/B!!
M<G)A>0H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@*0H*("`@
M("`@("`@("`@6VUA:6QB;WA=(#T^(")*;VX@4&%R:7-E(@H@("`@("`@("`@
M("!;:&]S=%T@/3X@<&AP+FYE=`H@("`@("`@("D*"BD*5F%L:61A=&EO;B!F
M86EL960@9F]R.B`\2F]N(%!A<FES94!P:'`N;F5T/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O6$U,7U)00R\`````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$W-C4R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S+P``````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U
M-P`P,C$P,30`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-
M3%]24$,O=&5S=',O=&5S=%]$=6UP+G!H<```````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S,#0R`#$P-3$U-#,Q,#4W`#`R,S0V-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RH*("H@268@=&AE('!A
M8VMA9V4@=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N
M9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H
M870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@
M:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H90H@*B!I;G-T
M86QL960@=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H;W5L9"!B92!I;B!T
M:&4@:6YC;'5D92!P871H+@H@*B`*("H@268@=&AE('9E<G-I;VX@:&%S(&YO
M="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J
M('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U
M="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@
M=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@6$U,7U)0
M0R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G
M,2XT+C@G("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG0"<I('L*("`@("\J
M*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@4$5!4B!I
M;G-T86QL871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("=834PO4E!#
M+T1U;7`N<&AP)SL*?2!E;'-E('L*("`@("\J*@H@("`@("H@1V5T('1H92!N
M965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I<F5C=&]R>0H@("`@("HO
M"B`@("!R97%U:7)E7V]N8V4@)RXN+T1U;7`N<&AP)SL*?0H*)'9A;"`](&YE
M=R!834Q?4E!#7U9A;'5E*&%R<F%Y*`H@("`@)W1I=&QE)R`@("`]/FYE=R!8
M34Q?4E!#7U9A;'5E*"=D87,@:7-T(&1E<B!4:71E;"<L("=S=')I;F<G*2P*
M("`@("=S=&%R=$1A=&4G/3YN97<@6$U,7U)00U]686QU92AM:W1I;64H,"PP
M+#`L,3,L,3$L,C`P-"DL("=D871E5&EM92YI<V\X-C`Q)RDL"B`@("`G96YD
M1&%T92<@(#T^;F5W(%A-3%]24$-?5F%L=64H;6MT:6UE*#`L,"PP+#$U+#$Q
M+#(P,#0I+"`G9&%T951I;64N:7-O.#8P,2<I+`H@("`@)V5R<F]R)R`@("`]
M/B=S=')I;F<G+`H@("`@)V%R:V5Y)R`@("`]/B!N97<@6$U,7U)00U]686QU
M92@@87)R87DH"B`@("`@("`@;F5W(%A-3%]24$-?5F%L=64H)W-I;7!L92!S
M=')I;F<G*2P*("`@("`@("!N97<@6$U,7U)00U]686QU92@Q,C,T-2P@)VEN
M="<I"B`@("`@("`@*2P@)V%R<F%Y)RD*("`@("D*("`@("PG<W1R=6-T)RD[
M"@I834Q?4E!#7T1U;7`H)'9A;"D["@IE8VAO("<]/3T]/3T]/3T]/3T]/2<@
M+B`B7')<;B(["B1V86PR(#T@;F5W(%A-3%]24$-?5F%L=64H-#0S-3,L("=I
M;G0G*3L*6$U,7U)00U]$=6UP*"1V86PR*3L*"F5C:&\@)ST]/3T]/3T]/3T]
M/3T])R`N(")<<EQN(CL*)'9A;#,@/2!N97<@6$U,7U)00U]686QU92@G=&AI
M<R!S:&]U;&0@8F4@82!S=')I;F<G+"`G<W1R:6YG)RD["EA-3%]24$-?1'5M
M<"@D=F%L,RD["@IE8VAO("<]/3T]/3T]/3T]/3T]/2<@+B`B7')<;B(["B1V
M86PT(#T@;F5W(%A-3%]24$-?5F%L=64H=')U92P@)V)O;VQE86XG*3L*6$U,
M7U)00U]$=6UP*"1V86PT*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#
M+W1E<W1S+V5X=')A+6QI;F5S+G!H<```````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C`Q
M-``Q,#4Q-30S,3`U-P`P,C,W-38`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"@T*+RHJ#0H@*B!497-T<R!H;W<@
M=&AE(%A-3%]24$,@<V5R=F5R(&AA;F1L97,@<&%R86UE=&5R<R!W:71H(&5M
M<'1Y('9A;'5E<RX-"B`J#0H@*B!)9B!Y;W4@87)E(')U;FYI;F<@=&AI<R!T
M97-T(&9R;VT@82!#5E,@8VAE8VMO=70L('EO=2!M=7-T(')E;F%M92!T:&4@
M=V]R:VEN9PT*("H@9&ER96-T;W)Y(&9R;VT@(EA-3%]24$,B('1O(")834PB
M+@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PT*("H@0'!A8VMA9V4@("`@
M6$U,7U)00PT*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N
M:65L8T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,C`P-2!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS90T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z(&5X=')A+6QI;F5S+G!H<"QV(#$N,2`R,#`V+S`T+S`W(#$T.C0X.C$T
M(&1A;FEE;&,@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]834Q?4E!##0H@*B!`<VEN8V4@("`@("!&:6QE(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-"XT#0H@*B\-"@T*+RH-"B`J($EF
M('1H92!P86-K86=E('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN('1H92!L
M969T(&AA;F0-"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO;B!B
M96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S#0H@*B!C;VUE(&9R;VT@
M=&AE(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H
M90T*("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC:"!S:&]U
M;&0@8F4@:6X@=&AE(&EN8VQU9&4@<&%T:"X-"B`J(`T*("H@268@=&AE('9E
M<G-I;VX@:&%S(&YO="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X
M<')E<W-I;VXL#0H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@
M82!#5E,@8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N#0H@*B!4:&5R969O<F4L
M('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R<VEO
M;B!O9@T*("H@6$U,7U)00R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@
M=V5L;"X-"B`J+PT*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E7W9E<G-I
M;VXG+B=`)RD@>PT*("`@("\J*@T*("`@("`J($=E="!T:&4@;F5E9&5D(&-L
M87-S(&9R;VT@=&AE(%!%05(@:6YS=&%L;&%T:6]N#0H@("`@("HO#0H@("`@
M<F5Q=6ER95]O;F-E("=834PO4E!#+G!H<"<[#0I](&5L<V4@>PT*("`@(&EF
M("AS=6)S='(H9&ER;F%M92A?7T9)3$5?7RDL("TY+"`M-BD@(3T@)UA-3"<I
M('L-"B`@("`@("`@96-H;R`B5&AE('!A<F5N="!D:7)E8W1O<GD@;75S="!B
M92!N86UE9"`G6$U,)RY<;B([#0H@("`@("`@(&5X:70[#0H@("`@?0T*#0H@
M("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@)RXN+RXN+R<-"B`@("`@("`@
M("`@("X@4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@T*
M("`@("`@("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0T*("`@("D[
M#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S<R!F<F]M
M('1H92!P87)E;G0@9&ER96-T;W)Y#0H@("`@("HO#0H@("`@<F5Q=6ER95]O
M;F-E("<N+B]24$,N<&AP)SL-"GT-"@T*)&EN<'5T(#T@(D9I<G-T(&QF<UQN
M7&Y396-O;F0@8W)L9G-<<EQN7')<;E1H:7)D(&-R<UQR7')&;W5R=&@@;&EN
M92([#0H-"B1E>'!E8W1?<F5M;W9E9"`]("(\/WAM;"!V97)S:6]N/5PB,2XP
M7"(@96YC;V1I;F<]7")55$8M.%PB/SX-"CQM971H;V1#86QL/@T*/&UE=&AO
M9$YA;64^;F%D83PO;65T:&]D3F%M93X-"CQP87)A;7,^#0H\<&%R86T^#0H\
M=F%L=64^/'-T<FEN9SY&:7)S="!L9G,-"E-E8V]N9"!C<FQF<PT*5&AI<F0@
M8W)S#0I&;W5R=&@@;&EN93PO<W1R:6YG/CPO=F%L=64^#0H\+W!A<F%M/@T*
M/"]P87)A;7,^#0H\+VUE=&AO9$-A;&P^#0HB.PT*#0HD97AP96-T7VYO=%]R
M96UO=F5D(#T@(CP_>&UL('9E<G-I;VX]7"(Q+C!<(B!E;F-O9&EN9SU<(E54
M1BTX7"(_/@T*/&UE=&AO9$-A;&P^#0H\;65T:&]D3F%M93YN861A/"]M971H
M;V1.86UE/@T*/'!A<F%M<SX-"CQP87)A;3X-"CQV86QU93X\<W1R:6YG/D9I
M<G-T(&QF<PT*#0I396-O;F0@8W)L9G,-"@T*5&AI<F0@8W)S#0H-"D9O=7)T
M:"!L:6YE/"]S=')I;F<^/"]V86QU93X-"CPO<&%R86T^#0H\+W!A<F%M<SX-
M"CPO;65T:&]D0V%L;#X-"B([#0H-"@T*)&US9R`](&YE=R!834Q?4E!#7TUE
M<W-A9V4H)VYA9&$G+"!A<G)A>2A834Q?4E!#7V5N8V]D92@D:6YP=70I*2D[
M#0HD;7-G+3YC<F5A=&5087EL;V%D*"D[#0II9B`H)&US9RT^<&%Y;&]A9"`]
M/2`D97AP96-T7W)E;6]V960I('L-"B`@("!E8VAO(")P87-S961<;B([#0I]
M(&5L<V4@>PT*("`@(&5C:&\@(E!23T),14U<;B([#0I]#0H-"B1M<V<@/2!N
M97<@6$U,7U)00U]-97-S86=E*"=N861A)RP@87)R87DH6$U,7U)00U]E;F-O
M9&4H)&EN<'5T*2DI.PT*)&US9RT^<F5M;W9E7V5X=')A7VQI;F5S(#T@9F%L
M<V4[#0HD;7-G+3YC<F5A=&5087EL;V%D*"D[#0II9B`H)&US9RT^<&%Y;&]A
M9"`]/2`D97AP96-T7VYO=%]R96UO=F5D*2![#0H@("`@96-H;R`B<&%S<V5D
M7&XB.PT*?2!E;'-E('L-"B`@("!E8VAO(")04D]"3$5-7&XB.PT*?0T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)0
M0R]T97-T<R]P<F]T;W!O<G0N<&AP````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C4U
M-#,`,3`U,34T,S$P-3<`,#(S-C`S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@=&AA="!P
M<F]P97)T:65S(&]F(%A-3%]24$-?0VQI96YT(&=E="!P<F]P97)L>2!S970*
M("H*("H@06YY(&EN9&EV:61U86P@=&5S=',@=&AA="!F86EL('=I;&P@:&%V
M92!T:&5I<B!N86UE+"!E>'!E8W1E9"!R97-U;'0*("H@86YD(&%C='5A;"!R
M97-U;'0@<')I;G1E9"!O=70N("!3;R!S965I;F<@;F\@;W5T<'5T('=H96X@
M97AE8W5T:6YG"B`J('1H:7,@9FEL92!I<R!A(&=O;V0@=&AI;F<N"B`J"B`J
M($-A;B!B92!R=6X@=FEA($-,22!O<B!A('=E8B!S97)V97(N"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@
M4V5R=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@
M("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y
M<FEG:'0@(#(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<')O=&]P;W)T+G!H<"QV(#$N-"`R
M,#`U+S`Q+S(T(#$W.C0X.C0W(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(*("HO
M"@HO*@H@*B!)9B!T:&4@<&%C:V%G92!V97)S:6]N(&YU;6)E<B!I<R!F;W5N
M9"!I;B!T:&4@;&5F="!H86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP
M<F5S<VEO;B!B96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S"B`J(&-O
M;64@9G)O;2!T:&4@4$5!4B!I;G-T86QL97(N("!4:&5R969O<F4L(&QE="=S
M('1E<W0@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F(%A-3%]24$,@=VAI
M8V@@<VAO=6QD(&)E(&EN('1H92!I;F-L=61E('!A=&@N"B`J(`H@*B!)9B!T
M:&4@=F5R<VEO;B!H87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@=&AE(&EF
M*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M92!F
M<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4:&5R969O
M<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R
M<VEO;B!O9@H@*B!834Q?4E!#('1H870@:&%S(&-O;64@9G)O;2!T:&5R92!A
M<R!W96QL+@H@*B\*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E7W9E<G-I
M;VXG+B=`)RD@>PH@("`@+RHJ"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S
M<R!F<F]M('1H92!014%2(&EN<W1A;&QA=&EO;@H@("`@("HO"B`@("!R97%U
M:7)E7V]N8V4@)UA-3"]24$,N<&AP)SL*?2!E;'-E('L*("`@("\J*@H@("`@
M("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I<F5C
M=&]R>0H@("`@("HO"B`@("!R97%U:7)E7V]N8V4@)RXN+U)00RYP:'`G.PI]
M"@HO*BH*("H@0V]M<&%R92!T:&4@=&5S="!R97-U;'0@=&\@=&AE(&5X<&5C
M=&5D(')E<W5L=`H@*@H@*B!)9B!T:&4@=&5S="!F86EL<RP@96-H;R!O=70@
M=&AE(')E<W5L=',N"B`J"B`J($!P87)A;2!A<G)A>2`@)&5X<&5C="`@("`@
M=&AE(&%R<F%Y(&]F(&]B:F5C="!P<F]P97)T:65S('EO=2!E>'!E8W0*("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@=&5S=`H@*B!`
M<&%R86T@;V)J96-T("1A8W1U86P@("`@('1H92!O8FIE8W0@<F5S=6QT<R!F
M<F]M('1H92!T97-T"B`J($!P87)A;2!S=')I;F<@)'1E<W1?;F%M92`@=&AE
M(&YA;64@;V8@=&AE('1E<W0*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC
M=&EO;B!C;VUP87)E*"1E>'!E8W0L("1A8W1U86PL("1T97-T7VYA;64I('L*
M("`@("1A8W1U86P@/2!G971?;V)J96-T7W9A<G,H)&%C='5A;"D["B`@("!I
M9B`H8V]U;G0H87)R87E?9&EF9B@D86-T=6%L+"`D97AP96-T*2DI('L*("`@
M("`@("!E8VAO("(D=&5S=%]N86UE(&9A:6QE9"Y<;D5X<&5C=#H@(CL*("`@
M("`@("!P<FEN=%]R*"1E>'!E8W0I.PH@("`@("`@(&5C:&\@(D%C='5A;#H@
M(CL*("`@("`@("!P<FEN=%]R*"1A8W1U86PI.PH@("`@("`@(&5C:&\@(EQN
M(CL*("`@('T*?0H*:68@*'!H<%]S87!I7VYA;64H*2`A/2`G8VQI)RD@>PH@
M("`@96-H;R`B/'!R93Y<;B(["GT*"@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G
M(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@
M("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<&]R="<@/3X@.#`L
M"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY7W!R;W1O8V]L)R`]/B`G
M:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@.#`X,"P*("`@("=P<F]X
M>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G)RP*("`@("=E
M<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@("`@)V1E8G5G
M)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P87-S=V]R9"<@
M/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T:&5P871H)RP@
M)W1H97-E<G9E<B<I.PIC;VUP87)E*"1X+"`D8RP@)V1E9F%U;'1S)RD["@HD
M>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V
M97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO
M+R<L"B`@("`G<&]R="<@/3X@.#`L"B`@("`G<')O>'DG(#T^("<G+`H@("`@
M)W!R;WAY7W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R
M="<@/3X@.#`X,"P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X
M>5]P87-S)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I
M;F<G(#T^("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]
M/B`G)RP*("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]2
M4$-?0VQI96YT*"=T:&5P871H)RP@)VAT='`Z+R]T:&5S97)V97(G*3L*8V]M
M<&%R92@D>"P@)&,L("=D969A=6QT<R!W:71H(&AT='`G*3L*"B1X(#T@87)R
M87DH"B`@("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@
M)W1H97-E<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@("`@
M)W!O<G0G(#T^(#0T,RP*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G<')O>'E?
M<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`X
M,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G
M(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@
M)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@
M("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE
M;G0H)W1H97!A=&@G+"`G:'1T<',Z+R]T:&5S97)V97(G*3L*8V]M<&%R92@D
M>"P@)&,L("=D969A=6QT<R!W:71H(&AT='!S)RD["@HD>"`](&%R<F%Y*`H@
M("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S
M97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P;W)T
M)R`]/B`T-#,L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY7W!R;W1O
M8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@.#`X,"P*
M("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G
M)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@
M("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P
M87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T
M:&5P871H)RP@)W-S;#HO+W1H97-E<G9E<B<I.PIC;VUP87)E*"1X+"`D8RP@
M)V1E9F%U;'1S('=I=&@@<W-L)RD["@H*)'@@/2!A<G)A>2@*("`@("=P871H
M)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*
M("`@("=P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!O<G0G(#T^(#8U
M+`H@("`@)W!R;WAY)R`]/B`G)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@
M)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@("`G<')O
M>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G
M97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U
M9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G
M(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L
M("=T:&5S97)V97(G+"`V-2D["F-O;7!A<F4H)'@L("1C+"`G<&]R="`V-2<I
M.PH*)'@@/2!A<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G
M<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)VAT
M='`Z+R\G+`H@("`@)W!O<G0G(#T^(#8U+`H@("`@)W!R;WAY)R`]/B`G)RP*
M("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY
M7W!O<G0G(#T^(#@P.#`L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G
M<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R
M<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M
M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!8
M34Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=H='1P.B\O=&AE<V5R=F5R)RP@
M-C4I.PIC;VUP87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET:"!H='1P)RD["@HD
M>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V
M97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O
M)RP*("`@("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G
M<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T
M)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY
M7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN
M9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^
M("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)0
M0U]#;&EE;G0H)W1H97!A=&@G+"`G:'1T<',Z+R]T:&5S97)V97(G+"`V-2D[
M"F-O;7!A<F4H)'@L("1C+"`G<&]R="`V-2!W:71H(&AT='!S)RD["@HD>"`]
M(&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G
M(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*
M("`@("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G<')O
M>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]
M/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A
M<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@
M/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G
M+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#
M;&EE;G0H)W1H97!A=&@G+"`G<W-L.B\O=&AE<V5R=F5R)RP@-C4I.PIC;VUP
M87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET:"!S<VPG*3L*"@HD>"`](&%R<F%Y
M*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T
M:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G
M<&]R="<@/3X@.#`L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G
M<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T
M)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY
M7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN
M9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^
M("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)0
M0U]#;&EE;G0H)W1H97!A=&@G+"`G=&AE<V5R=F5R)RP@,"P*("`@("`@("`@
M("`@("`@("`@("`@("`@)W1H97!R;WAY)RD["F-O;7!A<F4H)'@L("1C+"`G
M9&5F875L=',@<')O>'DG*3L*"B1X(#T@87)R87DH"B`@("`G<&%T:"<@/3X@
M)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G
M<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P;W)T)R`]/B`X,"P*("`@
M("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@
M/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@("`G
M<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@
M("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D
M96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O
M<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T
M:"<L("=H='1P.B\O=&AE<V5R=F5R)RP@,"P*("`@("`@("`@("`@("`@("`@
M("`@("`@)VAT='`Z+R]T:&5P<F]X>2<I.PIC;VUP87)E*"1X+"`D8RP@)V1E
M9F%U;'1S('=I=&@@:'1T<"!P<F]X>2<I.PH*)'@@/2!A<G)A>2@*("`@("=P
M871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R
M)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<&]R="<@/3X@
M-#0S+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@("`@)W!R;WAY7W!R
M;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`T-#,L
M"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@
M)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*
M("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G
M<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G
M=&AE<&%T:"<L("=H='1P<SHO+W1H97-E<G9E<B<L(#`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("=H='1P<SHO+W1H97!R;WAY)RD["F-O;7!A<F4H)'@L
M("1C+"`G9&5F875L=',@=VET:"!H='1P<R!P<F]X>2<I.PH*)'@@/2!A<G)A
M>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G
M=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G
M<&]R="<@/3X@-#0S+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@("`@
M)W!R;WAY7W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P<F]X>5]P;W)T
M)R`]/B`T-#,L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?
M<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG
M)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@
M)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#
M7T-L:65N="@G=&AE<&%T:"<L("=S<VPZ+R]T:&5S97)V97(G+"`P+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<W-L.B\O=&AE<')O>'DG*3L*8V]M<&%R
M92@D>"P@)&,L("=D969A=6QT<R!W:71H('-S;"!P<F]X>2<I.PH*"B1X(#T@
M87)R87DH"B`@("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@
M/3X@)W1H97-E<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=H='1P.B\O)RP*
M("`@("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*
M("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY
M7W!O<G0G(#T^(#8U-C4L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G
M<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R
M<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M
M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!8
M34Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=T:&5S97)V97(G+"`V-2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)W1H97!R;WAY)RP@-C4V-2D["F-O;7!A
M<F4H)'@L("1C+"`G<&]R="`V-2!P<F]X>2`V-38U)RD["@HD>"`](&%R<F%Y
M*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T
M:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G
M<&]R="<@/3X@-C4L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G
M<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T
M)R`]/B`V-38U+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY
M7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN
M9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^
M("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)0
M0U]#;&EE;G0H)W1H97!A=&@G+"`G:'1T<#HO+W1H97-E<G9E<B<L(#8U+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G:'1T<#HO+W1H97!R;WAY)RP@-C4V
M-2D["F-O;7!A<F4H)'@L("1C+"`G<&]R="`V-2!W:71H(&AT='`@<')O>'D@
M-C4V-2<I.PH*)'@@/2!A<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L
M"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@
M/3X@)W-S;#HO+R<L"B`@("`G<&]R="<@/3X@-C4L"B`@("`G<')O>'DG(#T^
M("=T:&5P<F]X>2<L"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=S<VPZ+R\G
M+`H@("`@)W!R;WAY7W!O<G0G(#T^(#8U-C4L"B`@("`G<')O>'E?=7-E<B<@
M/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^
M(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*
M("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI
M.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=H='1P<SHO
M+W1H97-E<G9E<B<L(#8U+`H@("`@("`@("`@("`@("`@("`@("`@("`G:'1T
M<',Z+R]T:&5P<F]X>2<L(#8U-C4I.PIC;VUP87)E*"1X+"`D8RP@)W!O<G0@
M-C4@=VET:"!H='1P<R!P<F]X>2`V-38U)RD["@HD>"`](&%R<F%Y*`H@("`@
M)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V
M97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P;W)T)R`]
M/B`V-2P*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P
M<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@-C4V
M-2P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]
M/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G
M+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@
M("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT
M*"=T:&5P871H)RP@)W-S;#HO+W1H97-E<G9E<B<L(#8U+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<W-L.B\O=&AE<')O>'DG+"`V-38U*3L*8V]M<&%R
M92@D>"P@)&,L("=P;W)T(#8U('=I=&@@<W-L('!R;WAY(#8U-C4G*3L*"@HD
M>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V
M97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O
M)RP*("`@("=P;W)T)R`]/B`T-#,L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X
M>2<L"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@("`@)W!R
M;WAY7W!O<G0G(#T^(#0T,RP*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@
M("=P<F]X>5]P87-S)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E
M<G)S=')I;F<G(#T^("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N
M86UE)R`]/B`G)RP*("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W
M(%A-3%]24$-?0VQI96YT*"=T:&5P871H)RP@)W1H97-E<G9E<B<L(#0T,RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)W1H97!R;WAY)RP@-#0S*3L*8V]M
M<&%R92@D>"P@)&,L("=P;W)T(#0T,R!N;R!P<F]T;V-O;"!A;F0@<')O>'D@
M<&]R="`T-#,@;F\@<')O=&]C;VPG*3L*"B1X(#T@87)R87DH"B`@("`G<&%T
M:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L
M"B`@("`G<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P;W)T)R`]/B`X
M,"P*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P<F]T
M;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@-C4V-2P*
M("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G
M)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@
M("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P
M87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T
M:&5P871H)RP@)W1H97-E<G9E<B<L(#`L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=S<VPZ+R]T:&5P<F]X>2<L(#8U-C4I.PIC;VUP87)E*"1X+"`D8RP@
M)W!O<G0@-#0S(&YO('!R;W1O8V]L(&%N9"!P<F]X>2!P;W)T(#0T,R!N;R!P
M<F]T;V-O;"<I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O96UP='DM
M=F%L=64N<&AP`````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,#0R`#$P-3$U-#,Q,#4W
M`#`R,S<W,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*+RHJ"B`J(%1E<W1S(&AO=R!T:&4@6$U,7U)00R!S97)V
M97(@:&%N9&QE<R!P87)A;65T97)S('=I=&@@96UP='D@=F%L=65S+@H@*@H@
M*B!)9B!Y;W4@87)E(')U;FYI;F<@=&AI<R!T97-T(&9R;VT@82!#5E,@8VAE
M8VMO=70L('EO=2!M=7-T(')E;F%M92!T:&4@=V]R:VEN9PH@*B!D:7)E8W1O
M<GD@9G)O;2`B6$U,7U)00R(@=&\@(EA-3"(N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*
M("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@96UP='DM=F%L=64N<&AP+'8@,2XQ(#(P,#4O,3`O
M,34@,C`Z,CDZ-#8@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XT"B`J+PH*+RH*
M("H@268@=&AE('!A8VMA9V4@=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@
M=&AE(&QE9G0@:&%N9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I
M;VX@8F5L;W<L('1H870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R
M;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T
M('1H90H@*B!I;G-T86QL960@=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H
M;W5L9"!B92!I;B!T:&4@:6YC;'5D92!P871H+@H@*B`*("H@268@=&AE('9E
M<G-I;VX@:&%S(&YO="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X
M<')E<W-I;VXL"B`J('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A
M($-64R!C:&5C:V]U="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W
M92=L;"!A<W-U;64@=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@
M;V8*("H@6$U,7U)00R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L
M;"X*("HO"FEF("@G,2XT+C@G("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG
M0"<I('L*("`@("\J*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O
M;2!T:&4@4$5!4B!I;G-T86QL871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O
M;F-E("=834PO4E!#+U-E<G9E<BYP:'`G.PI](&5L<V4@>PH@("`@:68@*'-U
M8G-T<BAD:7)N86UE*%]?1DE,15]?*2P@+3DL("TV*2`A/2`G6$U,)RD@>PH@
M("`@("`@(&5C:&\@(E1H92!P87)E;G0@9&ER96-T;W)Y(&UU<W0@8F4@;F%M
M960@)UA-3"<N7&XB.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@:6YI7W-E
M="@G:6YC;'5D95]P871H)RP@)RXN+RXN+R<*("`@("`@("`@("`@+B!0051(
M7U-%4$%2051/4B`N("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@
M("X@:6YI7V=E="@G:6YC;'5D95]P871H)RD*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!'970@=&AE(&YE961E9"!C;&%S<R!F<F]M('1H92!P87)E;G0@9&ER
M96-T;W)Y"B`@("`@*B\*("`@(')E<75I<F5?;VYC92`G+BXO4V5R=F5R+G!H
M<"<["GT*"B1'3$]"04Q36R=(5%107U)!5U]03U-47T1!5$$G72`](#P\/$5/
M4$]35`H\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/&UE=&AO9$-A;&P^"B`\;65T
M:&]D3F%M93YA;&QG;W0\+VUE=&AO9$YA;64^"B`@/'!A<F%M<SX*("`@/'!A
M<F%M/CQV86QU93X\<W1R:6YG/CPO<W1R:6YG/CPO=F%L=64^/"]P87)A;3X*
M("`@/'!A<F%M/CQV86QU93YF:7)S=#PO=F%L=64^/"]P87)A;3X*("`@/'!A
M<F%M/CQV86QU93X@(#PO=F%L=64^/"]P87)A;3X*("`@/'!A<F%M/CQV86QU
M93X\+W9A;'5E/CPO<&%R86T^"B`@/"]P87)A;7,^"B`\+VUE=&AO9$-A;&P^
M"D5/4$]35#L*"B1E>'!E8W0@/2`\/#Q%3T584`H\/WAM;"!V97)S:6]N/2(Q
M+C`B(&5N8V]D:6YG/2)55$8M."(_/@H\;65T:&]D4F5S<&]N<V4^"CQP87)A
M;7,^"CQP87)A;3X*/'9A;'5E/CQS=')I;F<^<&%R86T@,#H@)R<*<&%R86T@
M,3H@)V9I<G-T)PIP87)A;2`R.B`G("`G"G!A<F%M(#,Z("<G"CPO<W1R:6YG
M/CPO=F%L=64^"CPO<&%R86T^"CPO<&%R86US/@H\+VUE=&AO9%)E<W!O;G-E
M/@I%3T584#L*"FEN8VQU9&4@)RXO86QL9V]T+FEN8R<["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O6$U,7U)00R]T97-T<R]T>7!E<RYP:'``````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#8T-#``,3`U,34T,S$P-3<`,#(R-C<R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@HO*BH*
M("H@5&5S=',@:&]W('1H92!834Q?4E!#('-E<G9E<B!H86YD;&5S(&$@8G5N
M8V@@;V8@9&EF9F5R96YT('!A<F%M971E<@H@*B!D871A('1Y<&5S+@H@*@H@
M*B!)9B!Y;W4@87)E(')U;FYI;F<@=&AI<R!T97-T(&9R;VT@82!#5E,@8VAE
M8VMO=70L('EO=2!M=7-T(')E;F%M92!T:&4@=V]R:VEN9PH@*B!D:7)E8W1O
M<GD@9G)O;2`B6$U,7U)00R(@=&\@(EA-3"(N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*
M("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@='EP97,N<&AP+'8@,2XQ(#(P,#4O,3`O,34@,C`Z
M,CDZ-#8@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XT"B`J+PH*+RH*("H@268@
M=&AE('!A8VMA9V4@=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@=&AE(&QE
M9G0@:&%N9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L
M;W<L('1H870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE
M(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H90H@
M*B!I;G-T86QL960@=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H;W5L9"!B
M92!I;B!T:&4@:6YC;'5D92!P871H+@H@*B`*("H@268@=&AE('9E<G-I;VX@
M:&%S(&YO="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I
M;VXL"B`J('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C
M:&5C:V]U="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A
M<W-U;64@=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@
M6$U,7U)00R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO
M"FEF("@G,2XT+C@G("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG0"<I('L*
M("`@("\J*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@
M4$5!4B!I;G-T86QL871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("=8
M34PO4E!#+U-E<G9E<BYP:'`G.PI](&5L<V4@>PH@("`@:68@*'-U8G-T<BAD
M:7)N86UE*%]?1DE,15]?*2P@+3DL("TV*2`A/2`G6$U,)RD@>PH@("`@("`@
M(&5C:&\@(E1H92!P87)E;G0@9&ER96-T;W)Y(&UU<W0@8F4@;F%M960@)UA-
M3"<N7&XB.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@:6YI7W-E="@G:6YC
M;'5D95]P871H)RP@)RXN+RXN+R<*("`@("`@("`@("`@+B!0051(7U-%4$%2
M051/4B`N("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@:6YI
M7V=E="@G:6YC;'5D95]P871H)RD*("`@("D["@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE(&YE961E9"!C;&%S<R!F<F]M('1H92!P87)E;G0@9&ER96-T;W)Y
M"B`@("`@*B\*("`@(')E<75I<F5?;VYC92`G+BXO4V5R=F5R+G!H<"<["GT*
M"B1'3$]"04Q36R=(5%107U)!5U]03U-47T1!5$$G72`](#P\/$5/4$]35`H\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX*/&UE=&AO9$-A;&P^"B`\;65T:&]D3F%M
M93YA;&QG;W0\+VUE=&AO9$YA;64^"B`@/'!A<F%M<SX*("`@/'!A<F%M/CQV
M86QU93YD969A=6QT('1O('-T<FEN9SPO=F%L=64^/"]P87)A;3X*("`@/'!A
M<F%M/CQV86QU93X\<W1R:6YG/FEN<VED92!S=')I;F<\+W-T<FEN9SX\+W9A
M;'5E/CPO<&%R86T^"B`@(#QP87)A;3X\=F%L=64^/&EN=#XX/"]I;G0^/"]V
M86QU93X\+W!A<F%M/@H@("`\<&%R86T^/'9A;'5E/CQD871E=&EM92YI<V\X
M-C`Q/C(P,#4P.#`Y5#`Q.C,S.C0T/"]D871E=&EM92YI<V\X-C`Q/CPO=F%L
M=64^/"]P87)A;3X*"B`@(#QP87)A;3X*("`@(#QV86QU93X*("`@("`\87)R
M87D^"B`@("`@(#QD871A/@H@("`@("`@/'9A;'5E/@H@("`@("`@(#QS=')I
M;F<^83PO<W1R:6YG/@H@("`@("`@/"]V86QU93X*("`@("`@(#QV86QU93X*
M("`@("`@("`\<W1R:6YG/F(\+W-T<FEN9SX*("`@("`@(#PO=F%L=64^"B`@
M("`@(#PO9&%T83X*("`@("`\+V%R<F%Y/@H@("`@/"]V86QU93X*("`@/"]P
M87)A;3X*"B`@(#QP87)A;3X*("`@(#QV86QU93X*("`@("`\<W1R=6-T/@H@
M("`@("`\;65M8F5R/@H@("`@("`@/&YA;64^83PO;F%M93X*("`@("`@(#QV
M86QU93X*("`@("`@("`\<W1R:6YG/F%Y/"]S=')I;F<^"B`@("`@("`\+W9A
M;'5E/@H@("`@("`\+VUE;6)E<CX*("`@("`@/&UE;6)E<CX*("`@("`@(#QN
M86UE/F(\+VYA;64^"B`@("`@("`\=F%L=64^"B`@("`@("`@/'-T<FEN9SYB
M93PO<W1R:6YG/@H@("`@("`@/"]V86QU93X*("`@("`@/"]M96UB97(^"B`@
M("`@/"]S=')U8W0^"B`@("`\+W9A;'5E/@H@("`\+W!A<F%M/@H*("`\+W!A
M<F%M<SX*(#PO;65T:&]D0V%L;#X*14]03U-4.PH*)&5X<&5C="`](#P\/$5/
M15A0"CP_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^"CQM
M971H;V1297-P;VYS93X*/'!A<F%M<SX*/'!A<F%M/@H\=F%L=64^/'-T<FEN
M9SYP87)A;2`P.B`G9&5F875L="!T;R!S=')I;F<G"G!A<F%M(#$Z("=I;G-I
M9&4@<W1R:6YG)PIP87)A;2`R.B`G."<*<&%R86T@,SH@)S(P,#4P.#`Y5#`Q
M.C,S.C0T)PIP87)A;2`T.B!A<G)A>2`H"B`@,"`])F=T.R`G82<L"B`@,2`]
M)F=T.R`G8B<L"BD*<&%R86T@-3H@87)R87D@*`H@("=A)R`])F=T.R`G87DG
M+`H@("=B)R`])F=T.R`G8F4G+`HI"CPO<W1R:6YG/CPO=F%L=64^"CPO<&%R
M86T^"CPO<&%R86US/@H\+VUE=&AO9%)E<W!O;G-E/@I%3T584#L*"FEN8VQU
M9&4@)RXO86QL9V]T+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+UA-3%]24$,O=&5S=',O86QL9V]T+FEN8P``````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`S,#8P`#$P-3$U-#,Q,#4W`#`R,C<V-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RHJ
M"B`J(`H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A
M=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`R,#`U(%1H92!02%`@1W)O=7`*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&%L;&=O="YI
M;F,L=B`Q+C$@,C`P-2\Q,"\Q-2`R,#HR.3HT-B!D86YI96QC($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?
M4E!#"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C0*("HO"@IO8E]S=&%R="@I.PH*9G5N8W1I;VX@<F5T=7)N06QL
M1V]T*"1P87)A;7,I('L*("`@("1O=70@/2`G)SL*("`@("1C;W5N="`](&-O
M=6YT*"1P87)A;7,M/G!A<F%M<RD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8V]U;G0[("1I*RLI('L*("`@("`@("`D<&%R86T@/2`D<&%R86US+3YG9710
M87)A;2@D:2D["B`@("`@("`@:68@*"%834Q?4E!#7U9A;'5E.CII<U9A;'5E
M*"1P87)A;2DI('L*("`@("`@("`@("`@)&]U="`N/2`B<&%R86UE=&5R("1I
M('=A<R!E<G)O<CH@)'!A<F%M7&XB.PH@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("!]"B`@("`@("`@)&=O="`](%A-3%]24$-?1&5C;V1E*"1P87)A
M;2D["B`@("`@("`@)&]U="`N/2`B<&%R86T@)&DZ("(@+B!V87)?97AP;W)T
M*"1G;W0L('1R=64I("X@(EQN(CL*("`@('T*("`@("1V86P@/2!N97<@6$U,
M7U)00U]686QU92@D;W5T+"`G<W1R:6YG)RD["B`@("!R971U<FX@;F5W(%A-
M3%]24$-?4F5S<&]N<V4H)'9A;"D["GT*"B1S97)V97(@/2!N97<@6$U,7U)0
M0U]397)V97(H"B`@("!A<G)A>2@*("`@("`@("`G86QL9V]T)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G<F5T=7)N06QL1V]T)RP*
M("`@("`@("`I+`H@("`@*0HI.PH*)&=O="`](&]B7V=E=%]C;&5A;B@I.PH*
M:68@*"1G;W0@/3T@)&5X<&5C="D@>PH@("`@96-H;R`B<&%S<V5D7&XB.PI]
M(&5L<V4@>PH@("`@96-H;R`B1D%)3$5$7&XB.PH@("`@96-H;R`B17AP96-T
M960Z7&XD97AP96-T7&XB.PH@("`@96-H;R`B1V]T.EQN)&=O=%QN(CL*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]834Q?4E!#+W1E<W1S+V5M<'1Y+79A;'5E+7-T<G5C="YP:'``````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-3`V-``Q,#4Q-30S,3`U-P`P,C4S,C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J*@H@*B!4
M97-T<R!H;W<@=&AE(%A-3%]24$,@<V5R=F5R(&AA;F1L97,@82!P87)A;65T
M97(@=VET:"!A;B!E;7!T>2!S=')U8W0@=VET:&]U=`H@*B!A;GD@<W!A8V5S
M(&EN('1H92!834P@869T97(@=&AE(&5M<'1Y('9A;'5E+@H@*@H@*B!)9B!Y
M;W4@87)E(')U;FYI;F<@=&AI<R!T97-T(&9R;VT@82!#5E,@8VAE8VMO=70L
M('EO=2!M=7-T(')E;F%M92!T:&4@=V]R:VEN9PH@*B!D:7)E8W1O<GD@9G)O
M;2`B6$U,7U)00R(@=&\@(EA-3"(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A
M8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@96UP='DM=F%L=64M<W1R=6-T+G!H<"QV(#$N,2`R,#`U+S$P
M+S$U(#(P.C(Y.C0V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N-`H@*B\*"B\J
M"B`J($EF('1H92!P86-K86=E('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN
M('1H92!L969T(&AA;F0*("H@<&]R=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S
M:6]N(&)E;&]W+"!T:&%T(&UE86YS('1H:7,@9FEL92!H87,*("H@8V]M92!F
M<F]M('1H92!014%2(&EN<W1A;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=&5S
M="!T:&4*("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC:"!S
M:&]U;&0@8F4@:6X@=&AE(&EN8VQU9&4@<&%T:"X*("H@"B`J($EF('1H92!V
M97)S:6]N(&AA<R!N;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E
M>'!R97-S:6]N+`H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@
M82!#5E,@8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N"B`J(%1H97)E9F]R92P@
M=V4G;&P@87-S=6UE('1H92!T97-T<R!S:&]U;&0@=7-E('1H92!V97)S:6]N
M(&]F"B`J(%A-3%]24$,@=&AA="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E
M;&PN"B`J+PII9B`H)S$N-"XX)R`A/2`G0"<N)W!A8VMA9V5?=F5R<VEO;B<N
M)T`G*2!["B`@("`O*BH*("`@("`J($=E="!T:&4@;F5E9&5D(&-L87-S(&9R
M;VT@=&AE(%!%05(@:6YS=&%L;&%T:6]N"B`@("`@*B\*("`@(')E<75I<F5?
M;VYC92`G6$U,+U)00R]397)V97(N<&AP)SL*?2!E;'-E('L*("`@(&EF("AS
M=6)S='(H9&ER;F%M92A?7T9)3$5?7RDL("TY+"`M-BD@(3T@)UA-3"<I('L*
M("`@("`@("!E8VAO(")4:&4@<&%R96YT(&1I<F5C=&]R>2!M=7-T(&)E(&YA
M;65D("=834PG+EQN(CL*("`@("`@("!E>&ET.PH@("`@?0H*("`@(&EN:5]S
M970H)VEN8VQU9&5?<&%T:"<L("<N+B\N+B\G"B`@("`@("`@("`@("X@4$%4
M2%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@
M("`N(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PH*("`@("\J*@H@
M("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I
M<F5C=&]R>0H@("`@("HO"B`@("!R97%U:7)E7V]N8V4@)RXN+U-E<G9E<BYP
M:'`G.PI]"@HD1TQ/0D%,4ULG2%144%]205=?4$]35%]$051!)UT@/2`\/#Q%
M3U!/4U0*/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CQM971H;V1#86QL/@H@/&UE
M=&AO9$YA;64^86QL9V]T/"]M971H;V1.86UE/@H@(#QP87)A;7,^"B`@(#QP
M87)A;3X*("`@(#QV86QU93X*("`@("`\<W1R=6-T/@H@("`@("`\;65M8F5R
M/@H@("`@("`\;F%M93YF;&0Q/"]N86UE/CQV86QU93X\+W9A;'5E/CPO;65M
M8F5R/CPO<W1R=6-T/CPO=F%L=64^"B`@(#PO<&%R86T^"B`@/"]P87)A;7,^
M"B`\+VUE=&AO9$-A;&P^"D5/4$]35#L*"B1E>'!E8W0@/2`\/#Q%3T584`H\
M/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M."(_/@H\;65T:&]D
M4F5S<&]N<V4^"CQP87)A;7,^"CQP87)A;3X*/'9A;'5E/CQS=')I;F<^<&%R
M86T@,#H@87)R87D@*`H@("=F;&0Q)R`])F=T.R`G)RP**0H\+W-T<FEN9SX\
M+W9A;'5E/@H\+W!A<F%M/@H\+W!A<F%M<SX*/"]M971H;V1297-P;VYS93X*
M14]%6%`["@II;F-L=61E("<N+V%L;&=O="YI;F,G.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R\`````````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#4W`#`Q-S(R-P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O3&]G+W1E<W1S+P``````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(P,S<Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O8V]M<&]S:71E+G!H
M<'0````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,30U,@`Q,#4Q-30S,3`U-P`P
M,C,R-C<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+2U415-4+2T*3&]G.B!#;VUP;W-I=&4@2&%N9&QE<@HM+49)3$4M+0H\
M/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH
M)VQI;F5&;W)M870G(#T^("<E,B1S(%LE,R1S72`E-"1S)RD["B1C;VYS;VQE
M,2`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G0T].4T],13$G
M+"`D8V]N9BD["B1C;VYS;VQE,B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L
M92<L("<G+"`G0T].4T],13(G+"`D8V]N9BD["@HD8V]M<&]S:71E(#T@)DQO
M9SHZ<VEN9VQE=&]N*"=C;VUP;W-I=&4G*3L*)&-O;7!O<VET92T^861D0VAI
M;&0H)&-O;G-O;&4Q*3L*)&-O;7!O<VET92T^861D0VAI;&0H)&-O;G-O;&4R
M*3L*"B1C;VUP;W-I=&4M/FQO9R@G5&AI<R!E=F5N="!W:6QL(&)E(&QO9V=E
M9"!T;R!B;W1H(&AA;F1L97)S+B<I.PH*)&-O;7!O<VET92T^<V5T261E;G0H
M)TE$14Y4)RD["F5C:&\@)&-O;7!O<VET92T^9V5T261E;G0H*2`N(")<;B([
M"@HD8V]M<&]S:71E+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B92!L;V=G960@
M=&\@8F]T:"!H86YD;&5R<RXG*3L*"BTM15A014-4+2T*0T].4T],13$@6VEN
M9F]=(%1H:7,@979E;G0@=VEL;"!B92!L;V=G960@=&\@8F]T:"!H86YD;&5R
M<RX*0T].4T],13(@6VEN9F]=(%1H:7,@979E;G0@=VEL;"!B92!L;V=G960@
M=&\@8F]T:"!H86YD;&5R<RX*241%3E0*241%3E0@6VEN9F]=(%1H:7,@979E
M;G0@=VEL;"!B92!L;V=G960@=&\@8F]T:"!H86YD;&5R<RX*241%3E0@6VEN
M9F]=(%1H:7,@979E;G0@=VEL;"!B92!L;V=G960@=&\@8F]T:"!H86YD;&5R
M<RX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O9&ES<&QA
M>2YP:'!T````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`W,@`Q,#4Q-30S
M,3`U-P`P,C(W,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*3&]G.B!$:7-P;&%Y($AA;F1L97(*+2U&24Q%
M+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R
M<F%Y*"=E<G)O<E]P<F5P96YD)R`]/B`G/'1T/B<L"B`@("`@("`@("`@("`@
M)V5R<F]R7V%P<&5N9"<@(#T^("<\+W1T/B<L"B`@("`@("`@("`@("`@)VQI
M;F5B<F5A:R<@("`@(#T^("(\8G(@+SX\8G(@+SY<;B(I.PHD;&]G9V5R(#T@
M)DQO9SHZ<VEN9VQE=&]N*"=D:7-P;&%Y)RP@)R<L("<G+"`D8V]N9BD["F9O
M<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI('L*"21L;V=G97(M/FQO9R@B3&]G
M(&5N=')Y("1I(BD["GT*)&QO9V=E<BT^;&]G*")-=6QT:5QN3&EN95QN16YT
M<GDB*3L*"BTM15A014-4+2T*/'1T/CQB/DEN9F\\+V(^.B!,;V<@96YT<GD@
M,#PO='0^/&)R("\^/&)R("\^"CQT=#X\8CY);F9O/"]B/CH@3&]G(&5N=')Y
M(#$\+W1T/CQB<B`O/CQB<B`O/@H\='0^/&(^26YF;SPO8CXZ($QO9R!E;G1R
M>2`R/"]T=#X\8G(@+SX\8G(@+SX*/'1T/CQB/DEN9F\\+V(^.B!-=6QT:3QB
M<B`O/@I,:6YE/&)R("\^"D5N=')Y/"]T=#X\8G(@+SX\8G(@+SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O
M97)R;W)?;&]G+G!H<'0`````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0R,P`Q
M,#4Q-30S,3`U-P`P,C,R-30`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*3&]G.B!%<G)O<E],;V<@2&%N9&QE
M<@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1L
M;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V5R<F]R7VQO9R<L(%!%05)?3$]'
M7U194$5?4UE35$5-+"`G:61E;G0G*3L*9F]R("@D:2`](#`[("1I(#P@,SL@
M)&DK*RD@>PH))&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H*+2U%
M6%!%0U0M+0II9&5N=#H@3&]G(&5N=')Y(#`*:61E;G0Z($QO9R!E;G1R>2`Q
M"FED96YT.B!,;V<@96YT<GD@,@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V5X=')A8W0N<&AP
M=```````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-3$`,3`U,34T,S$P-3<`
M,#(R-S,V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM5$535"TM"DQO9SH@7V5X=')A8W1-97-S86=E*"D@6UIE;F0@16YG
M:6YE(#%="BTM4TM)4$E&+2T*/#]P:'`@:68@*'9E<G-I;VY?8V]M<&%R92AZ
M96YD7W9E<G-I;VXH*2P@(C(N,"XP(BP@(CX](BDI(&1I92@G<VMI<"<I.R`_
M/@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C
M;VYF(#T@87)R87DH)VQI;F5&;W)M870G(#T^("<E,B1S(%LE,R1S72`E-"1S
M)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@
M)VED96YT)RP@)&-O;F8I.PH*+RH@3&]G9VEN9R!A(')E9W5L87(@<W1R:6YG
M+B`J+PHD;&]G9V5R+3YL;V<H)U-T<FEN9R<I.PH*+RH@3&]G9VEN9R!A(&)A
M<F4@;V)J96-T+B`J+PIC;&%S<R!"87)E3V)J96-T('M]"B1L;V=G97(M/FQO
M9RAN97<@0F%R94]B:F5C="@I*3L*"B\J($QO9V=I;F<@86X@;V)J96-T('=I
M=&@@82!G971-97-S86=E*"D@;65T:&]D+B`J+PIC;&%S<R!'971-97-S86=E
M3V)J96-T('L@9G5N8W1I;VX@9V5T365S<V%G92@I('L@<F5T=7)N(")G971-
M97-S86=E(CL@?2!]"B1L;V=G97(M/FQO9RAN97<@1V5T365S<V%G94]B:F5C
M="@I*3L*"B\J($QO9V=I;F<@86X@;V)J96-T('=I=&@@82!T;U-T<FEN9R@I
M(&UE=&AO9"X@*B\*8VQA<W,@5&]3=')I;F=/8FIE8W0@>R!F=6YC=&EO;B!T
M;U-T<FEN9R@I('L@<F5T=7)N(")T;U-T<FEN9R([('T@?0HD;&]G9V5R+3YL
M;V<H;F5W(%1O4W1R:6YG3V)J96-T*"DI.PH*+RH@3&]G9VEN9R!A(%!%05)?
M17)R;W(@;V)J96-T+B`J+PIR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*)&QO
M9V=E<BT^;&]G*&YE=R!014%27T5R<F]R*"=014%27T5R<F]R(&]B:F5C="<L
M(#$P,"DI.PH*+RH@3&]G9VEN9R!A;B!A<G)A>2X@*B\*)&QO9V=E<BT^;&]G
M*&%R<F%Y*#$L(#(L("=T:')E92<@/3X@,RDI.PH*+RH@3&]G9VEN9R!A;B!A
M<G)A>2!W:71H(&$@)VUE<W-A9V4G(&ME>2X@*B\*)&QO9V=E<BT^;&]G*&%R
M<F%Y*"=M97-S86=E)R`]/B`G365S<V%G92!+97DG*2D["@HM+4584$5#5"TM
M"FED96YT(%MI;F9O72!3=')I;F<*:61E;G0@6VEN9F]=(&)A<F5O8FIE8W0@
M3V)J96-T"B@**0H*:61E;G0@6VEN9F]=(&=E=$UE<W-A9V4*:61E;G0@6VEN
M9F]=('1O4W1R:6YG"FED96YT(%MI;F9O72!014%27T5R<F]R(&]B:F5C=`II
M9&5N="!;:6YF;UT@07)R87D**`H@("`@6S!=(#T^(#$*("`@(%LQ72`]/B`R
M"B`@("!;=&AR965=(#T^(#,**0H*:61E;G0@6VEN9F]=($UE<W-A9V4@2V5Y
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R],;V<O=&5S=',O97AT<F%C=#(N<&AP=```````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C8V,0`Q,#4Q-30S,3`U-P`P,C,P,C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*3&]G.B!?97AT
M<F%C=$UE<W-A9V4H*2!;6F5N9"!%;F=I;F4@,ET*+2U32TE0248M+0H\/W!H
M<"!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I+"`B,BXP+C`B
M+"`B/"(I*2!D:64H)W-K:7`G*3L@/SX*+2U&24Q%+2T*/#]P:'`*"G)E<75I
M<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=L:6YE1F]R;6%T
M)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=I9&5N="<L("1C;VYF*3L*"B\J($QO
M9V=I;F<@82!R96=U;&%R('-T<FEN9RX@*B\*)&QO9V=E<BT^;&]G*"=3=')I
M;F<G*3L*"B\J($QO9V=I;F<@82!B87)E(&]B:F5C="X@*B\*8VQA<W,@0F%R
M94]B:F5C="![?0HD;&]G9V5R+3YL;V<H;F5W($)A<F5/8FIE8W0H*2D["@HO
M*B!,;V=G:6YG(&%N(&]B:F5C="!W:71H(&$@9V5T365S<V%G92@I(&UE=&AO
M9"X@*B\*8VQA<W,@1V5T365S<V%G94]B:F5C="![(&9U;F-T:6]N(&=E=$UE
M<W-A9V4H*2![(')E='5R;B`B9V5T365S<V%G92([('T@?0HD;&]G9V5R+3YL
M;V<H;F5W($=E=$UE<W-A9V5/8FIE8W0H*2D["@HO*B!,;V=G:6YG(&%N(&]B
M:F5C="!W:71H(&$@=&]3=')I;F<H*2!M971H;V0N("HO"F-L87-S(%1O4W1R
M:6YG3V)J96-T('L@9G5N8W1I;VX@=&]3=')I;F<H*2![(')E='5R;B`B=&]3
M=')I;F<B.R!]('T*)&QO9V=E<BT^;&]G*&YE=R!4;U-T<FEN9T]B:F5C="@I
M*3L*"B\J($QO9V=I;F<@86X@;V)J96-T('=I=&@@82!?7W1O4W1R:6YG*"D@
M;65T:&]D('5S:6YG(&-A<W1I;F<N("HO"F-L87-S($-A<W1A8FQE3V)J96-T
M('L@9G5N8W1I;VX@7U]T;U-T<FEN9R@I('L@<F5T=7)N(")?7W1O4W1R:6YG
M(CL@?2!]"B1L;V=G97(M/FQO9RAN97<@0V%S=&%B;&5/8FIE8W0H*2D["@HO
M*B!,;V=G:6YG(&$@4$5!4E]%<G)O<B!O8FIE8W0N("HO"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PHD;&]G9V5R+3YL;V<H;F5W(%!%05)?17)R;W(H)U!%
M05)?17)R;W(@;V)J96-T)RP@,3`P*2D["@HO*B!,;V=G:6YG(&%N(&%R<F%Y
M+B`J+PHD;&]G9V5R+3YL;V<H87)R87DH,2P@,BP@)W1H<F5E)R`]/B`S*2D[
M"@HO*B!,;V=G:6YG(&%N(&%R<F%Y('=I=&@@82`G;65S<V%G92<@:V5Y+B`J
M+PHD;&]G9V5R+3YL;V<H87)R87DH)VUE<W-A9V4G(#T^("=-97-S86=E($ME
M>2<I*3L*"BTM15A014-4+2T*:61E;G0@6VEN9F]=(%-T<FEN9PII9&5N="!;
M:6YF;UT@0F%R94]B:F5C="!/8FIE8W0**`HI"@II9&5N="!;:6YF;UT@9V5T
M365S<V%G90II9&5N="!;:6YF;UT@=&]3=')I;F<*:61E;G0@6VEN9F]=($]B
M:F5C="!I9"`C,@II9&5N="!;:6YF;UT@4$5!4E]%<G)O<B!O8FIE8W0*:61E
M;G0@6VEN9F]=($%R<F%Y"B@*("`@(%LP72`]/B`Q"B`@("!;,5T@/3X@,@H@
M("`@6W1H<F5E72`]/B`S"BD*"FED96YT(%MI;F9O72!-97-S86=E($ME>0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]F86-T;W)Y+G!H
M<'0``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C(U`#$P-3$U-#,Q,#4W
M`#`R,C<S-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+51%4U0M+0I,;V<Z($9A8W1O<GD*+2U&24Q%+2T*/#]P:'`*"G)E
M<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N<V]L93$@/2`F3&]G.CIF86-T
M;W)Y*"=C;VYS;VQE)RD["B1C;VYS;VQE,B`]("9,;V<Z.F9A8W1O<GDH)V-O
M;G-O;&4G*3L*"FEF("AI<U]A*"1C;VYS;VQE,2P@)TQO9U]C;VYS;VQE)RD@
M)B8@:7-?82@D8V]N<V]L93(L("=,;V=?8V]N<V]L92<I*0I["@EE8VAO(")4
M=V\@3&]G7V-O;G-O;&4@;V)J96-T<RY<;B(["GT*"FEF("@D8V]N<V]L93$M
M/E]I9"`A/2`D8V]N<V]L93(M/E]I9"D@>PH)96-H;R`B5&AE(&]B:F5C=',@
M:&%V92!D:69F97)E;G0@241S+EQN(CL*?0H*+2U%6%!%0U0M+0I4=V\@3&]G
M7V-O;G-O;&4@;V)J96-T<RX*5&AE(&]B:F5C=',@:&%V92!D:69F97)E;G0@
M241S+@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R],;V<O=&5S=',O9FEL92YP:'!T````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3$V,@`Q,#4Q-30S,3`U-P`P,C(R,#(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*3&]G.B!&:6QE($AA;F1L97(*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?
M;VYC92`G3&]G+G!H<"<["@HD9FEL96YA;64@/2!D:7)N86UE*%]?1DE,15]?
M*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G=&5S="YL;V<G.PII9B`H9FEL
M95]E>&ES=',H)&9I;&5N86UE*2D@=6YL:6YK*"1F:6QE;F%M92D["@HO*B!7
M<FET92!S;VUE(&5N=')I97,@=&\@=&AE(&QO9R!F:6QE+B`J+PHD8V]N9B`]
M(&%R<F%Y*"=L:6YE1F]R;6%T)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<I.PHD
M;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=F:6QE)RP@)&9I;&5N86UE+"`G
M)RP@)&-O;F8I.PH*9F]R("@D:2`](#`[("1I(#P@,SL@)&DK*RD@>PH))&QO
M9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0HD;&]G9V5R+3YC;&]S92@I
M.PH*+RH@1'5M<"!T:&4@8V]N=&5N=',@;V8@=&AE(&QO9R!F:6QE+B`J+PIE
M8VAO(&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92D["@HO*B!#;&5A;B!U
M<"X@*B\*:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('5N;&EN:R@D9FEL
M96YA;64I.PH*+2U%6%!%0U0M+0H@6VEN9F]=($QO9R!E;G1R>2`P"B!;:6YF
M;UT@3&]G(&5N=')Y(#$*(%MI;F9O72!,;V<@96YT<GD@,@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O;&5V96QS+G!H<'0`````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,34W-``Q,#4Q-30S,3`U-P`P,C(U
M-C0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2U415-4+2T*3&]G.B!,979E;',*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?
M;VYC92`G3&]G+G!H<"<["@IF=6YC=&EO;B!V97)I9GDH)&5X<"P@)&US9RD*
M>PH@("`@96-H;R`D;7-G("X@)SH@)SL*("`@(&5C:&\@*"1E>'`I(#\@)W!A
M<W,G(#H@)V9A:6PG.PH@("`@96-H;R`B7&XB.PI]"@IF=6YC=&EO;B!T97-T
M3&5V96QS*"1M87-K*0I["B`@("!E8VAO(")-87-K.B`D;6%S:UQN(CL*"B`@
M("!F;W(@*"1P<FEO<FET>2`](%!%05)?3$]'7T5-15)'.R`D<')I;W)I='D@
M/#T@4$5!4E],3T=?1$5"54<[("1P<FEO<FET>2LK*2!["B`@("`@("`@)&UA
M<VME9"`]("A,;V<Z.DU!4TLH)'!R:6]R:71Y*2`F("1M87-K*3L*("`@("`@
M("!E8VAO(")0<FEO<FET>2`D<')I;W)I='DZ("(["B`@("`@("`@96-H;R@D
M;6%S:V5D*2`_(")M87-K961<;B(@.B`B=6YM87-K961<;B(["B`@("!]"GT*
M"G1E<W1,979E;',H3&]G.CI-24XH4$5!4E],3T=?5T%23DE.1RDI.PIE8VAO
M(")<;B(["G1E<W1,979E;',H3&]G.CI-05@H4$5!4E],3T=?5T%23DE.1RDI
M.PH*+2U%6%!%0U0M+0I-87-K.B`R-#`*4')I;W)I='D@,#H@=6YM87-K960*
M4')I;W)I='D@,3H@=6YM87-K960*4')I;W)I='D@,CH@=6YM87-K960*4')I
M;W)I='D@,SH@=6YM87-K960*4')I;W)I='D@-#H@;6%S:V5D"E!R:6]R:71Y
M(#4Z(&UA<VME9`I0<FEO<FET>2`V.B!M87-K960*4')I;W)I='D@-SH@;6%S
M:V5D"@I-87-K.B`S,0I0<FEO<FET>2`P.B!M87-K960*4')I;W)I='D@,3H@
M;6%S:V5D"E!R:6]R:71Y(#(Z(&UA<VME9`I0<FEO<FET>2`S.B!M87-K960*
M4')I;W)I='D@-#H@;6%S:V5D"E!R:6]R:71Y(#4Z('5N;6%S:V5D"E!R:6]R
M:71Y(#8Z('5N;6%S:V5D"E!R:6]R:71Y(#<Z('5N;6%S:V5D"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O;G5L;"YP:'!T
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(V,0`Q,#4Q-30S,3`U
M-P`P,C(R,S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2U415-4+2T*3&]G.B!.=6QL($AA;F1L97(*+2U&24Q%+2T*/#]P
M:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD;&]G9V5R(#T@)DQO9SHZ
M<VEN9VQE=&]N*"=N=6QL)RD["F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI
M('L*"21L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*"BTM15A014-4
M+2T*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+W!R:6]R:71Y+G!H<'0`````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$S,C<`,3`U,34T,S$P-3<`,#(S,30W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM5$53
M5"TM"DQO9SH@4')I;W)I=&EE<PHM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O
M;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)VQI;F5&;W)M870G(#T^
M("=;)3,D<UT@)30D<R<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C
M;VYS;VQE)RP@)R<L("=I9&5N="<L("1C;VYF*3L*"B\J($QO9R!A="!T:&4@
M9&5F875L="!014%27TQ/1U])3D9/(&QE=F5L+B`J+PHD;&]G9V5R+3YL;V<H
M)TQO9R!M97-S86=E)RD["@HO*B!3970@=&AE(&1E9F%U;'0@<')I;W)I='D@
M=&\@4$5!4E],3T=?1$5"54<N("HO"B1L;V=G97(M/G-E=%!R:6]R:71Y*%!%
M05)?3$]'7T1%0E5'*3L*)&QO9V=E<BT^;&]G*"=,;V<@;65S<V%G92<I.PH*
M+RH@5F5R:69Y('1H870@=&AE(&=E=%!R:6]R:71Y*"D@;65T:&]D(&%L<V\@
M=&AI;F=S('=E)W)E(&%T(%!%05)?3$]'7T1%0E5'+B`J+PHD<')I;W)I='D@
M/2`D;&]G9V5R+3YP<FEO<FET>51O4W1R:6YG*"1L;V=G97(M/F=E=%!R:6]R
M:71Y*"DI.PIE8VAO("(D<')I;W)I='E<;B(["@HO*B!697)I9GD@=&AA="!S
M=')I;F=4;U!R:6]R:71Y*"D@8V%N(&-O;G9E<G0@8F%C:R!T;R!A(&-O;G-T
M86YT+B`J+PHD<')I;W)I='D@/2`D;&]G9V5R+3YS=')I;F=4;U!R:6]R:71Y
M*"1P<FEO<FET>2D["F5C:&\@(B1P<FEO<FET>5QN(CL*"BTM15A014-4+2T*
M6VEN9F]=($QO9R!M97-S86=E"EMD96)U9UT@3&]G(&UE<W-A9V4*9&5B=6<*
M-PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+W-I;F=L971O;BYP:'!T
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,C<`,3`U,34T,S$P-3<`,#(S
M,C<R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"DQO9SH@4VEN9VQE=&]N"BTM1DE,12TM"CP_<&AP"@IR97%U
M:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&-O;G-O;&4Q(#T@)DQO9SHZ<VEN9VQE
M=&]N*"=C;VYS;VQE)RD["B1C;VYS;VQE,B`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<I.PH*:68@*&ES7V$H)&-O;G-O;&4Q+"`G3&]G7V-O;G-O;&4G
M*2`F)B!I<U]A*"1C;VYS;VQE,BP@)TQO9U]C;VYS;VQE)RDI"GL*"65C:&\@
M(E1W;R!,;V=?8V]N<V]L92!O8FIE8W1S+EQN(CL*?0H*:68@*"1C;VYS;VQE
M,2T^7VED(#T]("1C;VYS;VQE,BT^7VED*2!["@EE8VAO(")4:&4@;V)J96-T
M<R!H879E('1H92!S86UE($E$+EQN(CL*?0H*+2U%6%!%0U0M+0I4=V\@3&]G
M7V-O;G-O;&4@;V)J96-T<RX*5&AE(&]B:F5C=',@:&%V92!T:&4@<V%M92!)
M1"X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+TQO9R]T97-T<R]S<6QI=&4N<&AP=```````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,C4W`#$P-3$U-#,Q,#4W`#`R,C4W,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+51%4U0M+0I,
M;V<Z(%-Q;&ET92!(86YD;&5R"BTM4TM)4$E&+2T*/#]P:'`@:68@*"%F=6YC
M=&EO;E]E>&ES=',H)W-Q;&ET95]O<&5N)RDI(&1I92@B<VMI<%QN(BD[(#\^
M"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&9I
M;&5N86UE(#T@9&ER;F%M92A?7T9)3$5?7RD@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)W-Q;&ET92UL;V<N9&(G.PII9B`H9FEL95]E>&ES=',H)&9I;&5N
M86UE*2D@=6YL:6YK*"1F:6QE;F%M92D["@HD9&(@/2!S<6QI=&5?;W!E;B@D
M9FEL96YA;64L(#`V-C8L("1E<G)O<BD["B1I9&5N="`]('1I;64H*3L*)&UE
M<W-A9V4@/2`G;&]G9VEN9R!A;B!E=F5N="<["B1L;V=G97(@/28@3&]G.CIF
M86-T;W)Y*"=S<6QI=&4G+"`G;&]G7W1A8FQE)RP@)&ED96YT+"`D9&(I.PHD
M;&]G9V5R+3YL;V<H)&UE<W-A9V4L(%!%05)?3$]'7U=!4DY)3D<I.PH*)'$@
M/2`B4T5,14-4(&UE<W-A9V4@1E)/32!L;V=?=&%B;&4@5TA%4D4@:61E;G0]
M)R1I9&5N="<B.PHD<F5S(#T@<W%L:71E7W%U97)Y*"1D8BP@)'$I.PII9B`H
M<W%L:71E7V9E=&-H7W-T<FEN9R@D<F5S*2`]/2`D;65S<V%G92D@>PH)96-H
M;R`G;VLG.PI]"@IS<6QI=&5?8VQO<V4H)&1B*3L*:68@*&9I;&5?97AI<W1S
M*"1F:6QE;F%M92DI('5N;&EN:R@D9FEL96YA;64I.PH*+2U%6%!%0U0M+0IO
M:PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]S<6Q?:61E;G0N<&AP=```````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S$R`#$P-3$U-#,Q,#4W`#`R,S(T-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+51%
M4U0M+0I,;V<Z(%-13"!S971)9&5N="@I"BTM4TM)4$E&+2T*/#]P:'`*"G)E
M<75I<F5?;VYC92`G4$5!4B]296=I<W1R>2YP:'`G.PHD<F5G:7-T<GD@/2`F
M;F5W(%!%05)?4F5G:7-T<GDH*3L*"FEF("@A)')E9VES=')Y+3YP86-K86=E
M17AI<W1S*"=$0B<I*2!D:64H(G-K:7!<;B(I.PHM+49)3$4M+0H\/W!H<`H*
M<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1I9&5N="`]("<Q,C,T-38W.#DP
M,3(S-#4V-S@Y,"<["@HD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=S<6PG
M+"`G;&]G7W1A8FQE)RP@)&ED96YT+"!A<G)A>2@G9'-N)R`]/B`G)RDI.PIE
M8VAO("1L;V=G97(M/F=E=$ED96YT*"D@+B`B7&XB.PH*)&QO9V=E<BT^<V5T
M261E;G0H)&ED96YT*3L*96-H;R`D;&]G9V5R+3YG971)9&5N="@I("X@(EQN
M(CL*"BTM15A014-4+2T*,3(S-#4V-S@Y,#$R,S0U-@HQ,C,T-38W.#DP,3(S
M-#4V"@``````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R],;V<O=&5S=',O8V]N<V]L92YP:'!T````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C$W-P`Q,#4Q-30S,3`U-P`P,C(W,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*3&]G.B!#
M;VYS;VQE($AA;F1L97(*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G
M3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=L:6YE1F]R;6%T)R`]/B`G)3(D
M<R!;)3,D<UT@)30D<R<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C
M;VYS;VQE)RP@)R<L("=I9&5N="<L("1C;VYF*3L*9F]R("@D:2`](#`[("1I
M(#P@,SL@)&DK*RD@>PH))&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*
M?0H*96-H;R`B7&Y;0G5F9F5R:6YG("\@1FQU<V@@5&5S=%U<;B(["B1C;VYF
M(#T@87)R87DH)VQI;F5&;W)M870G(#T^("<E,B1S(%LE,R1S72`E-"1S)RP@
M)V)U9F9E<FEN9R<@/3X@=')U92D["B1B=69F97)E9%]L;V=G97(@/2`F3&]G
M.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)V)U9F9E<F5D)RP@)&-O;F8I
M.PIF;W(@*"1I(#T@,#L@)&D@/"`S.R`D:2LK*2!["B`@("`D8G5F9F5R961?
M;&]G9V5R+3YL;V<H(E!R92UF;'5S:"!B=69F97)E9"!L;V<@96YT<GD@)&DB
M*3L*?0IE8VAO(")0<F4M9FQU<VA<;B(["B1B=69F97)E9%]L;V=G97(M/F9L
M=7-H*"D["F5C:&\@(E!O<W0M9FQU<VA<;B(["F9O<B`H)&D@/2`P.R`D:2`\
M(#,[("1I*RLI('L*("`@("1B=69F97)E9%]L;V=G97(M/FQO9R@B4&]S="UF
M;'5S:"!B=69F97)E9"!L;V<@96YT<GD@)&DB*3L*?0IE8VAO(")3:'5T9&]W
M;EQN(CL*)&)U9F9E<F5D7VQO9V=E<BT^8VQO<V4H*3L*"BTM15A014-4+2T*
M:61E;G0@6VEN9F]=($QO9R!E;G1R>2`P"FED96YT(%MI;F9O72!,;V<@96YT
M<GD@,0II9&5N="!;:6YF;UT@3&]G(&5N=')Y(#(*"EM"=69F97)I;F<@+R!&
M;'5S:"!497-T70I0<F4M9FQU<V@*8G5F9F5R960@6VEN9F]=(%!R92UF;'5S
M:"!B=69F97)E9"!L;V<@96YT<GD@,`IB=69F97)E9"!;:6YF;UT@4')E+69L
M=7-H(&)U9F9E<F5D(&QO9R!E;G1R>2`Q"F)U9F9E<F5D(%MI;F9O72!0<F4M
M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y(#(*4&]S="UF;'5S:`I3:'5T9&]W
M;@IB=69F97)E9"!;:6YF;UT@4&]S="UF;'5S:"!B=69F97)E9"!L;V<@96YT
M<GD@,`IB=69F97)E9"!;:6YF;UT@4&]S="UF;'5S:"!B=69F97)E9"!L;V<@
M96YT<GD@,0IB=69F97)E9"!;:6YF;UT@4&]S="UF;'5S:"!B=69F97)E9"!L
M;V<@96YT<GD@,@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q
M,#4W`#`Q-S,V,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1&%T92]T97-T<R\`````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-3<`,#(P-3(U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V-A;&,N<&AP+F]R:6<`````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`T-#0W,``Q,#4Q-30S,3`U-P`P,C,Q,#4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30@<V]F='1A8G-T;W`]-#H@*B\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#4@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/B`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS92P@5&AA="!I
M<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H("`@("`@?`HO
M+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@
M?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@?"!P96%R+61E
M=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<CH@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\J*@H@*B!497-T<R!F;W(@=&AE($1A
M=&5?0V%L8R!C;&%S<PH@*@H@*B!!;GD@:6YD:79I9'5A;"!T97-T<R!T:&%T
M(&9A:6P@=VEL;"!H879E('1H96ER(&YA;64L(&5X<&5C=&5D(')E<W5L=`H@
M*B!A;F0@86-T=6%L(')E<W5L="!P<FEN=&5D(&]U="X@(%-O('-E96EN9R!N
M;R!O=71P=70@=VAE;B!E>&5C=71I;F<*("H@=&AI<R!F:6QE(&ES(&$@9V]O
M9"!T:&EN9RX*("H*("H@0V%N(&)E(')U;B!V:6$@0TQ)(&]R(&$@=V5B('-E
M<G9E<BX*("H*("H@5&AI<R!T97-T('-E;G-E<R!W:&5T:&5R(&ET(&ES(&9R
M;VT@86X@:6YS=&%L;&%T:6]N(&]F(%!%05(Z.D1A=&4@;W(@:68*("H@:70G
M<R!F<F]M($-64R!O<B!A("YT87(@9FEL92X@($EF(&ET)W,@86X@:6YS=&%L
M;&5D('9E<G-I;VXL('5S92!T:&4*("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@
M1&%T95]#86QC+B`@3W1H97)W:7-E+"!U<V4@=&AE(&QO8V%L(&1E=F5L;W!M
M96YT"B`J(&-O<'D@;V8@1&%T95]#86QC+@H@*@H@*B!`8V%T96=O<GD@("!$
M871E(&%N9"!4:6UE"B`J($!P86-K86=E("`@($1A=&4*("H@0&%U=&AO<B`@
M("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P
M>7)I9VAT("`R,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&-A;&,N<&AP+'8@,2XX(#(P,#4O
M,3$O,34@,#`Z,38Z-#`@<&%J;WEE($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XU"B`J+PH*:68@*"<O
M:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA<F4O<&AP)R`A/2`G0"<N)VEN8VQU
M9&5?<&%T:"<N)T`G*2!["B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!I
M;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@("`@("`@("`N(%!!5$A?4T50
M05)!5$]2("X@)RXG"B`@("`I.PI](&5L<V4@>PH@("`@:6YI7W-E="@G:6YC
M;'5D95]P871H)RP@<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M+R<I"B`@("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(
M7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN:5]G970H)VEN8VQU9&5?<&%T
M:"<I"B`@("`I.PI]"@HO*BH*("H@1V5T('1H92!N965D960@8VQA<W,*("HO
M"G)E<75I<F5?;VYC92`G1&%T92]#86QC+G!H<"<["@HO*BH*("H@0V]M<&%R
M92!T:&4@=&5S="!R97-U;'0@=&\@=&AE(&5X<&5C=&5D(')E<W5L=`H@*@H@
M*B!)9B!T:&4@=&5S="!F86EL<RP@96-H;R!O=70@=&AE(')E<W5L=',N"B`J
M"B`J($!P87)A;2!M:7AE9"`@)&5X<&5C="`@("`@=&AE('-C86QA<B!O<B!A
M<G)A>2!Y;W4@97AP96-T(&9R;VT@=&AE('1E<W0*("H@0'!A<F%M(&UI>&5D
M("`D86-T=6%L("`@("!T:&4@<V-A;&%R(&]R(&%R<F%Y(')E<W5L=',@9G)O
M;2!T:&4@=&5S=`H@*B!`<&%R86T@<W1R:6YG("1T97-T7VYA;64@('1H92!N
M86UE(&]F('1H92!T97-T"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I
M;VX@8V]M<&%R92@D97AP96-T+"`D86-T=6%L+"`D=&5S=%]N86UE*2!["B`@
M("!I9B`H:7-?87)R87DH)&5X<&5C="DI('L*("`@("`@("!I9B`H8V]U;G0H
M87)R87E?9&EF9B@D86-T=6%L+"`D97AP96-T*2DI('L*("`@("`@("`@("`@
M96-H;R`B)'1E<W1?;F%M92!F86EL960N("!%>'!E8W0Z7&XB.PH@("`@("`@
M("`@("!P<FEN=%]R*"1E>'!E8W0I.PH@("`@("`@("`@("!E8VAO(")!8W1U
M86PZ7&XB.PH@("`@("`@("`@("!P<FEN=%]R*"1A8W1U86PI.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@:68@*"1E>'!E8W0@(3T@)&%C='5A
M;"D@>PH@("`@("`@("`@("!E8VAO("(D=&5S=%]N86UE(&9A:6QE9"X@($5X
M<&5C=#H@)&5X<&5C="X@($%C='5A;#H@)&%C='5A;%QN(CL*("`@("`@("!]
M"B`@("!]"GT*"FEF("AP:'!?<V%P:5]N86UE*"D@(3T@)V-L:2<I('L*("`@
M(&5C:&\@(CQP<F4^7&XB.PI]"@H*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E
M7T-A;&,Z.F1A=&5&;W)M870H,C(L(#$Q+"`R,#`P+"`G)5DE;25D)RDL("=D
M871E1F]R;6%T)RD["F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CID
M871E1F]R;6%T*"<R,B<L("<Q,2<L("<R,#`P)RP@)R59)6TE9"<I+"`G9&%T
M949O<FUA="!S='(G*3L*"F-O;7!A<F4H)S(P,#$G+"!$871E7T-A;&,Z.F1E
M9F%U;'1#96YT=7)Y*"<Q)RDL("=D969A=6QT0V5N='5R>2`Q('-T<B<I.PIC
M;VUP87)E*"<R,#`Q)RP@1&%T95]#86QC.CID969A=6QT0V5N='5R>2@Q*2P@
M)V1E9F%U;'1#96YT=7)Y(#$G*3L*8V]M<&%R92@G,3DV,"<L($1A=&5?0V%L
M8SHZ9&5F875L=$-E;G1U<GDH-C`I+"`G9&5F875L=$-E;G1U<GD@,B<I.PIC
M;VUP87)E*"<R,#$P)RP@1&%T95]#86QC.CID969A=6QT0V5N='5R>2@Q,"DL
M("=D969A=6QT0V5N='5R>2`S)RD["@IC;VUP87)E*#(T-3$X-S$L($1A=&5?
M0V%L8SHZ9&%T951O1&%Y<R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G9&%T951O
M1&%Y<R!S='(G*3L*8V]M<&%R92@R-#4Q.#<Q+"!$871E7T-A;&,Z.F1A=&54
M;T1A>7,H,C(L(#$Q+"`R,#`P*2P@)V1A=&54;T1A>7,G*3L*8V]M<&%R92@G
M,C`P,#$Q,C(G+"!$871E7T-A;&,Z.F1A>7-4;T1A=&4H,C0U,3@W,2DL("=D
M87ES5&]$871E)RD["@IC;VUP87)E*"<R,#`P+30W+3,G+"!$871E7T-A;&,Z
M.F=R96=O<FEA;E1O25-/*"<R,B<L("<Q,2<L("<R,#`P)RDL("=G<F5G;W)I
M86Y4;TE33R!S='(G*3L*8V]M<&%R92@G,C`P,"TT-RTS)RP@1&%T95]#86QC
M.CIG<F5G;W)I86Y4;TE33R@R,BP@,3$L(#(P,#`I+"`G9W)E9V]R:6%N5&])
M4T\G*3L*8V]M<&%R92@R-#4Q-S$V+C4V-S8W+"!$871E7T-A;&,Z.F1A=&53
M96%S;VXH)U-534U%4E-/3%-424-%)RP@,C`P,"DL("=D871E4V5A<V]N)RD[
M"@IC;VUP87)E*&1A=&4H)UEM9"<I+"!$871E7T-A;&,Z.F1A=&5.;W<H*2P@
M)V1A=&5.;W<G*3L*8V]M<&%R92AD871E*"=9)RDL($1A=&5?0V%L8SHZ9V5T
M665A<B@I+"`G9V5T665A<B<I.PIC;VUP87)E*&1A=&4H)VTG*2P@1&%T95]#
M86QC.CIG971-;VYT:"@I+"`G9V5T36]N=&@G*3L*8V]M<&%R92AD871E*"=D
M)RDL($1A=&5?0V%L8SHZ9V5T1&%Y*"DL("=G971$87DG*3L*"F-O;7!A<F4H
M,S(W+"!$871E7T-A;&,Z.FIU;&EA;D1A=&4H,C(L(#$Q+"`R,#`P*2P@)VIU
M;&EA;D1A=&4G*3L*8V]M<&%R92@G3F]V96UB97(G+"!$871E7T-A;&,Z.F=E
M=$UO;G1H1G5L;&YA;64H,3$I+"`G9V5T36]N=&A&=6QL;F%M92<I.PIC;VUP
M87)E*"=.;W8G+"!$871E7T-A;&,Z.F=E=$UO;G1H06)B<FYA;64H,3$I+"`G
M9V5T36]N=&A!8F)R;F%M92<I.PIC;VUP87)E*"=3871U<F1A>2<L($1A=&5?
M0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE*#$L(#$L(#(P,#4I+"`G9V5T5V5E
M:V1A>49U;&QN86UE)RD["F-O;7!A<F4H)U-A="<L($1A=&5?0V%L8SHZ9V5T
M5V5E:V1A>4%B8G)N86UE*#$L(#$L(#(P,#4I+"`G9V5T5V5E:V1A>4%B8G)N
M86UE)RD["F-O;7!A<F4H,3$L($1A=&5?0V%L8SHZ9V5T36]N=&A&<F]M1G5L
M;$YA;64H)TYO=F5M8F5R)RDL("=G971-;VYT:$9R;VU&=6QL3F%M92<I.PH*
M8V]M<&%R92@S,C<L($1A=&5?0V%L8SHZ:G5L:6%N1&%T92@G,C(G+"`G,3$G
M+"`G,C`P,"<I+"`G:G5L:6%N1&%T92!S='(G*3L*8V]M<&%R92@G3F]V96UB
M97(G+"!$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H)S$Q)RDL("=G971-
M;VYT:$9U;&QN86UE('-T<B<I.PIC;VUP87)E*"=.;W8G+"!$871E7T-A;&,Z
M.F=E=$UO;G1H06)B<FYA;64H)S$Q)RDL("=G971-;VYT:$%B8G)N86UE('-T
M<B<I.PIC;VUP87)E*"=3871U<F1A>2<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A
M>49U;&QN86UE*"<P,2<L("<P,2<L("<R,#`U)RDL("=G9717965K9&%Y1G5L
M;&YA;64@<W1R)RD["F-O;7!A<F4H)U-A="<L($1A=&5?0V%L8SHZ9V5T5V5E
M:V1A>4%B8G)N86UE*"<P,2<L("<P,2<L("<R,#`U)RDL("=G9717965K9&%Y
M06)B<FYA;64@<W1R)RD["@HD97AP(#T@87)R87DH"B`@("`G2F%N=6%R>2<L
M"B`@("`G1F5B<G5A<GDG+`H@("`@)TUA<F-H)RP*("`@("=!<')I;"<L"B`@
M("`G36%Y)RP*("`@("=*=6YE)RP*("`@("=*=6QY)RP*("`@("=!=6=U<W0G
M+`H@("`@)U-E<'1E;6)E<B<L"B`@("`G3V-T;V)E<B<L"B`@("`G3F]V96UB
M97(G+`H@("`@)T1E8V5M8F5R)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L
M8SHZ9V5T36]N=&A.86UE<R@I+"`G9V5T36]N=&A.86UE<R<I.PH*)&5X<"`]
M(&%R<F%Y*`H@("`@)TUO;F1A>2<L"B`@("`G5'5E<V1A>2<L"B`@("`G5V5D
M;F5S9&%Y)RP*("`@("=4:'5R<V1A>2<L"B`@("`G1G)I9&%Y)RP*("`@("=3
M871U<F1A>2<L"B`@("`G4W5N9&%Y)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?
M0V%L8SHZ9V5T5V5E:T1A>7,H*2P@)V=E=%=E96M$87ES)RD["@IC;VUP87)E
M*#,L($1A=&5?0V%L8SHZ9&%Y3V97965K*#(R+"`Q,2P@,C`P,"DL("=D87E/
M9E=E96LG*3L*8V]M<&%R92@T-RP@1&%T95]#86QC.CIW965K3V9996%R*#(R
M+"`Q,2P@,C`P,"DL("=W965K3V9996%R)RD["F-O;7!A<F4H-"P@1&%T95]#
M86QC.CIQ=6%R=&5R3V9996%R*#(R+"`Q,2P@,C`P,"DL("=Q=6%R=&5R3V99
M96%R)RD["@IC;VUP87)E*#,L($1A=&5?0V%L8SHZ9&%Y3V97965K*"<R,B<L
M("<Q,2<L("<R,#`P)RDL("=D87E/9E=E96L@<W1R)RD["F-O;7!A<F4H-#<L
M($1A=&5?0V%L8SHZ=V5E:T]F665A<B@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G
M=V5E:T]F665A<B!S='(G*3L*8V]M<&%R92@T+"!$871E7T-A;&,Z.G%U87)T
M97)/9EEE87(H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)W%U87)T97)/9EEE87(@
M<W1R)RD["@IC;VUP87)E*#(X+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L
M(#$Y,#`I+"`G9&%Y<TEN36]N=&@@,2<I.PIC;VUP87)E*#(Y+"!$871E7T-A
M;&,Z.F1A>7-);DUO;G1H*#(L(#$Y.38I+"`G9&%Y<TEN36]N=&@@,B<I.PIC
M;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L(#(P,#`I+"`G
M9&%Y<TEN36]N=&@@,R<I.PIC;VUP87)E*#(X+"!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*#(L(#(P,#$I+"`G9&%Y<TEN36]N=&@@-"<I.PIC;VUP87)E*#,P
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#$Q+"`R,#`P*2P@)V1A>7-);DUO
M;G1H(#4G*3L*"F-O;7!A<F4H,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H
M)S`R)RP@,3DP,"DL("=D87ES26Y-;VYT:"`Q('-T<B<I.PIC;VUP87)E*#(Y
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<P,B<L(#$Y.38I+"`G9&%Y<TEN
M36]N=&@@,B!S='(G*3L*8V]M<&%R92@R.2P@1&%T95]#86QC.CID87ES26Y-
M;VYT:"@G,#(G+"`R,#`P*2P@)V1A>7-);DUO;G1H(#,@<W1R)RD["F-O;7!A
M<F4H,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)S`R)RP@,C`P,2DL("=D
M87ES26Y-;VYT:"`T('-T<B<I.PIC;VUP87)E*#,P+"!$871E7T-A;&,Z.F1A
M>7-);DUO;G1H*"<Q,2<L("<R,#`P)RDL("=D87ES26Y-;VYT:"`U('-T<B<I
M.PH*8V]M<&%R92@U+"!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@Q,2P@,C`P
M,"DL("=W965K<TEN36]N=&@G*3L*8V]M<&%R92@U+"!$871E7T-A;&,Z.G=E
M96MS26Y-;VYT:"@G,3$G+"`G,C`P,"<I+"`G=V5E:W-);DUO;G1H('-T<B<I
M.PH*"B1E>'`@/2!A<G)A>2@*("`@("<Q.3`P,#(R-B<L"B`@("`G,3DP,#`R
M,C<G+`H@("`@)S$Y,#`P,C(X)RP*("`@("<Q.3`P,#,P,2<L"B`@("`G,3DP
M,#`S,#(G+`H@("`@)S$Y,#`P,S`S)RP*("`@("<Q.3`P,#,P-"<L"BD["F-O
M;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE;F1A<E=E96LH,C<L(#(L
M(#$Y,#`I+"`G9V5T0V%L96YD87)7965K(#$G*3L*"B1E>'`@/2!A<G)A>2@*
M("`@("<R,#`P,#(R."<L"B`@("`G,C`P,#`R,CDG+`H@("`@)S(P,#`P,S`Q
M)RP*("`@("<R,#`P,#,P,B<L"B`@("`G,C`P,#`S,#,G+`H@("`@)S(P,#`P
M,S`T)RP*("`@("<R,#`P,#,P-2<L"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#
M86QC.CIG971#86QE;F1A<E=E96LH,C@L(#(L(#(P,#`I+"`G9V5T0V%L96YD
M87)7965K(#(G*3L*"B1E>'`@/2!A<G)A>2@*("`@("<R,#`P,3$R-R<L"B`@
M("`G,C`P,#$Q,C@G+`H@("`@)S(P,#`Q,3(Y)RP*("`@("<R,#`P,3$S,"<L
M"B`@("`G,C`P,#$R,#$G+`H@("`@)S(P,#`Q,C`R)RP*("`@("<R,#`P,3(P
M,R<**3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R5V5E
M:R@R-RP@,3$L(#(P,#`I+"`G9V5T0V%L96YD87)7965K(#,G*3L*8V]M<&%R
M92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R5V5E:R@G,C<G+"`G,3$G
M+"`G,C`P,"<I+"`G9V5T0V%L96YD87)7965K(#,@<W1R)RD["@HD97AP(#T@
M87)R87DH"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$P,S`G+`H@("`@("`@
M("<R,#`P,3`S,2<L"B`@("`@("`@)S(P,#`Q,3`Q)RP*("`@("`@("`G,C`P
M,#$Q,#(G+`H@("`@("`@("<R,#`P,3$P,R<L"B`@("`@("`@)S(P,#`Q,3`T
M)RP*("`@("DL"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$Q,#4G+`H@("`@
M("`@("<R,#`P,3$P-B<L"B`@("`@("`@)S(P,#`Q,3`W)RP*("`@("`@("`G
M,C`P,#$Q,#@G+`H@("`@("`@("<R,#`P,3$P.2<L"B`@("`@("`@)S(P,#`Q
M,3$P)RP*("`@("`@("`G,C`P,#$Q,3$G+`H@("`@*2P*("`@(&%R<F%Y*`H@
M("`@("`@("<R,#`P,3$Q,B<L"B`@("`@("`@)S(P,#`Q,3$S)RP*("`@("`@
M("`G,C`P,#$Q,30G+`H@("`@("`@("<R,#`P,3$Q-2<L"B`@("`@("`@)S(P
M,#`Q,3$V)RP*("`@("`@("`G,C`P,#$Q,3<G+`H@("`@("`@("<R,#`P,3$Q
M."<L"B`@("`I+`H@("`@87)R87DH"B`@("`@("`@)S(P,#`Q,3$Y)RP*("`@
M("`@("`G,C`P,#$Q,C$G+`H@("`@("`@("<R,#`P,3$R,B<L"B`@("`@("`@
M)S(P,#`Q,3(S)RP*("`@("`@("`G,C`P,#$Q,C0G+`H@("`@("`@("<R,#`P
M,3$R-2<L"B`@("`@("`@)S(P,#`Q,3(V)RP*("`@("DL"B`@("!A<G)A>2@*
M("`@("`@("`G,C`P,#$Q,C<G+`H@("`@("`@("<R,#`P,3$R."<L"B`@("`@
M("`@)S(P,#`Q,3(Y)RP*("`@("`@("`G,C`P,#$Q,S`G+`H@("`@("`@("<R
M,#`P,3(P,2<L"B`@("`@("`@)S(P,#`Q,C`R)RP*("`@("`@("`G,C`P,#$R
M,#,G"B`@("`I"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE
M;F1A<DUO;G1H*#$Q+"`R,#`P*2P@)V=E=$-A;&5N9&%R36]N=&@G*3L*8V]M
M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R36]N=&@H)S$Q)RP@
M)S(P,#`G*2P@)V=E=$-A;&5N9&%R36]N=&@@<W1R)RD["@HO+R!)(&1O;B=T
M(&9E96P@;&EK92!D96%L:6YG('=I=&@@=&AI<R!R:6=H="!N;W<N+BX*+R]C
M;VUP87)E*"<G+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R665A<B@R,#`P*2P@
M)V=E=$-A;&5N9&%R665A<B<I.PH*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E
M7T-A;&,Z.G!R979$87DH,C(L(#$Q+"`R,#`P*2P@)W!R979$87DG*3L*8V]M
M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$87DH,C(L(#$Q+"`R
M,#`P*2P@)VYE>'1$87DG*3L*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A
M;&,Z.G!R979$87DH,C(L(#$Q+"`R,#`P*2P@)W!R979$87D@<W1R)RD["F-O
M;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y*"<R,B<L("<Q
M,2<L("<R,#`P)RDL("=N97AT1&%Y('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q
M,3<G+"!$871E7T-A;&,Z.G!R9797965K9&%Y*"<Q.2<L("<Q,2<L("<R,#`P
M)RDL("=P<F5V5V5E:V1A>2`Q('-T<B<I.PIC;VUP87)E*"<R,#`P,3$Q-R<L
M($1A=&5?0V%L8SHZ<')E=E=E96MD87DH,3DL(#$Q+"`R,#`P*2P@)W!R9797
M965K9&%Y(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R
M9797965K9&%Y*#(R+"`Q,2P@,C`P,"DL("=P<F5V5V5E:V1A>2`R)RD["F-O
M;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT5V5E:V1A>2@R,BP@
M,3$L(#(P,#`I+"`G;F5X=%=E96MD87D@,2<I.PIC;VUP87)E*"<R,#`P,3$R
M-R<L($1A=&5?0V%L8SHZ;F5X=%=E96MD87DH,C0L(#$Q+"`R,#`P*2P@)VYE
M>'17965K9&%Y(#(G*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z
M.FYE>'17965K9&%Y*"<R-"<L("<Q,2<L("<R,#`P)RDL("=N97AT5V5E:V1A
M>2`R('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R
M979$87E/9E=E96LH)S(G+"`G,C(G+"`G,3$G+"`G,C`P,"<I+"`G<')E=D1A
M>4]F5V5E:R`Q('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L
M8SHZ<')E=D1A>4]F5V5E:R@R+"`R,BP@,3$L(#(P,#`I+"`G<')E=D1A>4]F
M5V5E:R`Q)RD["F-O;7!A<F4H)S(P,#`Q,3$U)RP@1&%T95]#86QC.CIP<F5V
M1&%Y3V97965K*#,L(#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y3V97965K(#(G
M*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.G!R979$87E/9E=E
M96LH,RP@,C(L(#$Q+"`R,#`P+"`G)5DE;25D)RP@=')U92DL("=P<F5V1&%Y
M3V97965K(#,G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.FYE
M>'1$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P+"`G)5DE;25D)RP@=')U92DL
M("=N97AT1&%Y3V97965K(#$G*3L*8V]M<&%R92@G,C`P,#$Q,CDG+"!$871E
M7T-A;&,Z.FYE>'1$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P*2P@)VYE>'1$
M87E/9E=E96L@,B<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ
M;F5X=$1A>4]F5V5E:R@T+"`R,BP@,3$L(#(P,#`I+"`G;F5X=$1A>4]F5V5E
M:R`S)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y
M3V97965K*"<T)RP@)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)VYE>'1$87E/9E=E
M96L@,R!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP
M<F5V1&%Y3V97965K3VY/<D)E9F]R92@G,B<L("<R,B<L("<Q,2<L("<R,#`P
M)RDL("=P<F5V1&%Y3V97965K3VY/<D)E9F]R92`Q('-T<B<I.PIC;VUP87)E
M*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:T]N3W)"969O
M<F4H,BP@,C(L(#$Q+"`R,#`P*2P@)W!R979$87E/9E=E96M/;D]R0F5F;W)E
M(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.G!R979$87E/
M9E=E96M/;D]R0F5F;W)E*#,L(#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y3V97
M965K3VY/<D)E9F]R92`R)RD["F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#
M86QC.CIN97AT1&%Y3V97965K3VY/<D%F=&5R*#,L(#(R+"`Q,2P@,C`P,"DL
M("=N97AT1&%Y3V97965K3VY/<D%F=&5R(#$G*3L*8V]M<&%R92@G,C`P,#$Q
M,C,G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96M/;D]R069T97(H-"P@,C(L
M(#$Q+"`R,#`P*2P@)VYE>'1$87E/9E=E96M/;D]R069T97(@,B<I.PIC;VUP
M87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:T]N3W)!
M9G1E<B@G-"<L("<R,B<L("<Q,2<L("<R,#`P)RDL("=N97AT1&%Y3V97965K
M3VY/<D%F=&5R(#(@<W1R)RD["@IC;VUP87)E*"<R,#`P,3$R,"<L($1A=&5?
M0V%L8SHZ8F5G:6Y/9E=E96LH)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN
M3V97965K('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R,"<L($1A=&5?0V%L8SHZ
M8F5G:6Y/9E=E96LH,C(L(#$Q+"`R,#`P*2P@)V)E9VEN3V97965K)RD["F-O
M;7!A<F4H)S(P,#`Q,3(V)RP@1&%T95]#86QC.CIE;F1/9E=E96LH,C(L(#$Q
M+"`R,#`P*2P@)V5N9$]F5V5E:R<I.PIC;VUP87)E*"<R,#`P,3$R-B<L($1A
M=&5?0V%L8SHZ96YD3V97965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=E;F1/
M9E=E96L@<W1R)RD["@IC;VUP87)E*"<R,#`P,3$Q,R<L($1A=&5?0V%L8SHZ
M8F5G:6Y/9E!R9797965K*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F4')E=E=E
M96LG*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z.F)E9VEN3V9.
M97AT5V5E:R@R,BP@,3$L(#(P,#`I+"`G8F5G:6Y/9DYE>'17965K)RD["F-O
M;7!A<F4H)S(P,#`Q,3$S)RP@1&%T95]#86QC.CIB96=I;D]F4')E=E=E96LH
M)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V90<F5V5V5E:R!S='(G*3L*
M8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z.F)E9VEN3V9.97AT5V5E
M:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9DYE>'17965K('-T<B<I
M.PH*8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT
M:"@Q,2P@,C`P,"DL("=B96=I;D]F36]N=&@G*3L*8V]M<&%R92@G,C`P,#$Q
M,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:"@G,3$G+"`G,C`P,"<I+"`G
M8F5G:6Y/9DUO;G1H('-T<B<I.PH*8V]M<&%R92@G,C`P,#$P,#$G+"!$871E
M7T-A;&,Z.F)E9VEN3V90<F5V36]N=&@H,C(L(#$Q+"`R,#`P*2P@)V)E9VEN
M3V90<F5V36]N=&@G*3L*8V]M<&%R92@G,C`P,#$P,S$G+"!$871E7T-A;&,Z
M.F5N9$]F4')E=DUO;G1H*#(R+"`Q,2P@,C`P,"DL("=E;F1/9E!R979-;VYT
M:"<I.PIC;VUP87)E*"<R,#`P,3`P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9E!R
M979-;VYT:"@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9E!R979-;VYT
M:"!S='(G*3L*8V]M<&%R92@G,C`P,#$P,S$G+"!$871E7T-A;&,Z.F5N9$]F
M4')E=DUO;G1H*"<R,B<L("<Q,2<L("<R,#`P)RDL("=E;F1/9E!R979-;VYT
M:"!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,C`Q)RP@1&%T95]#86QC.CIB96=I
M;D]F3F5X=$UO;G1H*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F3F5X=$UO;G1H
M)RD["F-O;7!A<F4H)S(P,#`Q,C,Q)RP@1&%T95]#86QC.CIE;F1/9DYE>'1-
M;VYT:"@R,BP@,3$L(#(P,#`I+"`G96YD3V9.97AT36]N=&@G*3L*8V]M<&%R
M92@G,C`P,#$R,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9.97AT36]N=&@H)S(R
M)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V9.97AT36]N=&@@<W1R)RD["F-O
M;7!A<F4H)S(P,#`Q,C,Q)RP@1&%T95]#86QC.CIE;F1/9DYE>'1-;VYT:"@G
M,C(G+"`G,3$G+"`G,C`P,"<I+"`G96YD3V9.97AT36]N=&@@<W1R)RD["@IC
M;VUP87)E*"<Q.3DY,3`P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3
M<&%N*"TQ,RP@,3$L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#$G*3L*
M8V]M<&%R92@G,C`P,#$P,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y
M4W!A;B@M,2P@,3$L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#(G*3L*
M8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y
M4W!A;B@P+"`Q,2P@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@,R<I.PIC
M;VUP87)E*"<R,#`P,3(P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3
M<&%N*#$L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`T)RD["F-O
M;7!A<F4H)S(P,#$Q,C`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P
M86XH,3,L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`U)RD["@IC
M;VUP87)E*"<Q.3DY,#$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3
M<&%N*"<M,3,G+"`G,#(G+"`G,C`P,"<I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N
M(#8@<W1R)RD["F-O;7!A<F4H)S$Y.3DP,3`Q)RP@1&%T95]#86QC.CIB96=I
M;D]F36]N=&A">5-P86XH+3$S+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y
M4W!A;B`V)RD["F-O;7!A<F4H)S(P,#`P,3`Q)RP@1&%T95]#86QC.CIB96=I
M;D]F36]N=&A">5-P86XH+3$L(#(L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3
M<&%N(#<G*3L*8V]M<&%R92@G,C`P,#`R,#$G+"!$871E7T-A;&,Z.F)E9VEN
M3V9-;VYT:$)Y4W!A;B@P+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A
M;B`X)RD["F-O;7!A<F4H)S(P,#`P,S`Q)RP@1&%T95]#86QC.CIB96=I;D]F
M36]N=&A">5-P86XH,2P@,BP@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@
M.2<I.PIC;VUP87)E*"<R,#`Q,#,P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H0GE3<&%N*#$S+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`Q
M,"<I.PIC;VUP87)E*"<R,#`Q,#,P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H0GE3<&%N*"<Q,R<L("<P,B<L("<R,#`P)RDL("=B96=I;D]F36]N=&A"
M>5-P86X@,3`@<W1R)RD["@IC;VUP87)E*"<Q.3DY,3`S,2<L($1A=&5?0V%L
M8SHZ96YD3V9-;VYT:$)Y4W!A;B@M,3,L(#$Q+"`R,#`P*2P@)V5N9$]F36]N
M=&A">5-P86X@,2<I.PIC;VUP87)E*"<R,#`P,3`S,2<L($1A=&5?0V%L8SHZ
M96YD3V9-;VYT:$)Y4W!A;B@M,2P@,3$L(#(P,#`I+"`G96YD3V9-;VYT:$)Y
M4W!A;B`R)RD["F-O;7!A<F4H)S(P,#`Q,3,P)RP@1&%T95]#86QC.CIE;F1/
M9DUO;G1H0GE3<&%N*#`L(#$Q+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@
M,R<I.PIC;VUP87)E*"<R,#`P,3(S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT
M:$)Y4W!A;B@Q+"`Q,2P@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#0G*3L*
M8V]M<&%R92@G,C`P,3$R,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P
M86XH,3,L(#$Q+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@-2<I.PH*8V]M
M<&%R92@G,3DY.3`Q,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH
M)RTQ,R<L("<P,B<L("<R,#`P)RDL("=E;F1/9DUO;G1H0GE3<&%N(#8@<W1R
M)RD["F-O;7!A<F4H)S$Y.3DP,3,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H
M0GE3<&%N*"TQ,RP@,BP@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#8G*3L*
M8V]M<&%R92@G,C`P,#`Q,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P
M86XH+3$L(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`W)RD["F-O;7!A
M<F4H)S(P,#`P,C(Y)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#`L
M(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`X)RD["F-O;7!A<F4H)S(P
M,#`P,S,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#$L(#(L(#(P
M,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`Y)RD["F-O;7!A<F4H)S(P,#$P,S,Q
M)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#$S+"`R+"`R,#`P*2P@
M)V5N9$]F36]N=&A">5-P86X@,3`G*3L*8V]M<&%R92@G,C`P,3`S,S$G+"!$
M871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH)S$S)RP@)S`R)RP@)S(P,#`G
M*2P@)V5N9$]F36]N=&A">5-P86X@,3`@<W1R)RD["@IC;VUP87)E*#,L($1A
M=&5?0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A>2@Q,2P@,C`P,"DL("=F:7)S
M=$]F36]N=&A7965K9&%Y)RD["F-O;7!A<F4H,RP@1&%T95]#86QC.CIF:7)S
M=$]F36]N=&A7965K9&%Y*"<Q,2<L("<R,#`P)RDL("=F:7)S=$]F36]N=&A7
M965K9&%Y('-T<B<I.PH*8V]M<&%R92@G,C`P-3`Q,#$G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@Q+"`V+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-
M;VYT:"`Q-C$G*3L*8V]M<&%R92@G,C`P-3`Q,#(G+"!$871E7T-A;&,Z.DY7
M965K9&%Y3V9-;VYT:"@Q+"`P+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT
M:"`Q,#$G*3L*8V]M<&%R92@G,C`P-3`Q,#,G+"!$871E7T-A;&,Z.DY7965K
M9&%Y3V9-;VYT:"@Q+"`Q+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q
M,3$G*3L*8V]M<&%R92@G,C`P-3`Q,#0G+"!$871E7T-A;&,Z.DY7965K9&%Y
M3V9-;VYT:"@Q+"`R+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q,C$G
M*3L*8V]M<&%R92@G,C`P-3`Q,#4G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-
M;VYT:"@Q+"`S+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q,S$G*3L*
M8V]M<&%R92@G,C`P-3`Q,#8G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT
M:"@Q+"`T+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q-#$G*3L*8V]M
M<&%R92@G,C`P-3`Q,#<G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q
M+"`U+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q-3$G*3L*"F-O;7!A
M<F4H)S(P,#4P,3`X)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G
M+"`G-B<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C8Q)RD[
M"F-O;7!A<F4H)S(P,#4P,3`Y)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N
M=&@H)S(G+"`G,"<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@
M,C`Q)RD["F-O;7!A<F4H)S(P,#4P,3$P)RP@1&%T95]#86QC.CI.5V5E:V1A
M>4]F36]N=&@H)S(G+"`G,2<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F
M36]N=&@@,C$Q)RD["F-O;7!A<F4H)S(P,#4P,3$Q)RP@1&%T95]#86QC.CI.
M5V5E:V1A>4]F36]N=&@H)S(G+"`G,B<L("<P,2<L("<R,#`U)RDL("=.5V5E
M:V1A>4]F36]N=&@@,C(Q)RD["F-O;7!A<F4H)S(P,#4P,3$R)RP@1&%T95]#
M86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G,R<L("<P,2<L("<R,#`U)RDL
M("=.5V5E:V1A>4]F36]N=&@@,C,Q)RD["F-O;7!A<F4H)S(P,#4P,3$S)RP@
M1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G-"<L("<P,2<L("<R
M,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C0Q)RD["F-O;7!A<F4H)S(P,#4P
M,3$T)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G-2<L("<P
M,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C4Q)RD["@IC;VUP87)E
M*"<R,#`U,#$S,2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T
M)RP@,2P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#$Q)RD["F-O;7!A
M<F4H)S(P,#4P,3,P)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA
M<W0G+"`P+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,#$G*3L*8V]M
M<&%R92@G,C`P-3`Q,CDG+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G
M;&%S="<L(#8L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PV,2<I.PIC
M;VUP87)E*"<R,#`U,#$R."<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H
M*"=L87-T)RP@-2P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#4Q)RD[
M"F-O;7!A<F4H)S(P,#4P,3(W)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N
M=&@H)VQA<W0G+"`T+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-#$G
M*3L*8V]M<&%R92@G,C`P-3`Q,C8G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-
M;VYT:"@G;&%S="<L(#,L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PS
M,2<I.PIC;VUP87)E*"<R,#`U,#$R-2<L($1A=&5?0V%L8SHZ3E=E96MD87E/
M9DUO;G1H*"=L87-T)RP@,BP@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@
M;#(Q)RD["@IC;VUP87)E*"<R,#`U,#,S,2<L($1A=&5?0V%L8SHZ3E=E96MD
M87E/9DUO;G1H*"=L87-T)RP@-"P@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N
M=&@@;#0S)RD["F-O;7!A<F4H)S(P,#4P,S,P)RP@1&%T95]#86QC.CI.5V5E
M:V1A>4]F36]N=&@H)VQA<W0G+"`S+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-
M;VYT:"!L,S,G*3L*8V]M<&%R92@G,C`P-3`S,CDG+"!$871E7T-A;&,Z.DY7
M965K9&%Y3V9-;VYT:"@G;&%S="<L(#(L(#,L(#(P,#4I+"`G3E=E96MD87E/
M9DUO;G1H(&PR,R<I.PIC;VUP87)E*"<R,#`U,#,R."<L($1A=&5?0V%L8SHZ
M3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,2P@,RP@,C`P-2DL("=.5V5E:V1A
M>4]F36]N=&@@;#$S)RD["F-O;7!A<F4H)S(P,#4P,S(W)RP@1&%T95]#86QC
M.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`P+"`S+"`R,#`U*2P@)TY7965K
M9&%Y3V9-;VYT:"!L,#,G*3L*8V]M<&%R92@G,C`P-3`S,C8G+"!$871E7T-A
M;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#8L(#,L(#(P,#4I+"`G3E=E
M96MD87E/9DUO;G1H(&PV,R<I.PIC;VUP87)E*"<R,#`U,#,R-2<L($1A=&5?
M0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-2P@,RP@,C`P-2DL("=.
M5V5E:V1A>4]F36]N=&@@;#4S)RD["@H*8V]M<&%R92AF86QS92P@1&%T95]#
M86QC.CII<U9A;&ED1&%T92@R.2P@,BP@,3DP,"DL("=I<U9A;&ED1&%T92`Q
M)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<U9A;&ED1&%T92@R.2P@
M,BP@,C`P,"DL("=I<U9A;&ED1&%T92`R)RD["F-O;7!A<F4H=')U92P@1&%T
M95]#86QC.CII<U9A;&ED1&%T92@G,CDG+"`G,#(G+"`G,C`P,"<I+"`G:7-6
M86QI9$1A=&4@,B!S='(G*3L*"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ
M:7-,96%P665A<B@Q.3`P*2P@)VES3&5A<%EE87(@,2<I.PIC;VUP87)E*'1R
M=64L($1A=&5?0V%L8SHZ:7-,96%P665A<B@Q.3DV*2P@)VES3&5A<%EE87(@
M,B<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-,96%P665A<B@R,#`P
M*2P@)VES3&5A<%EE87(@,R<I.PIC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z
M.FES3&5A<%EE87(H,C`P,2DL("=I<TQE87!996%R(#0G*3L*8V]M<&%R92AF
M86QS92P@1&%T95]#86QC.CII<TQE87!996%R*"<R,#`Q)RDL("=I<TQE87!9
M96%R(#0@<W1R)RD["@IC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES1G5T
M=7)E1&%T92@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G:7-&=71U<F5$871E(#$@
M<W1R)RD["F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-&=71U<F5$871E
M*#(R+"`Q,2P@,C`P,"DL("=I<T9U='5R941A=&4@,2<I.PIC;VUP87)E*'1R
M=64L($1A=&5?0V%L8SHZ:7-&=71U<F5$871E*#(R+"`Q,2P@9&%T92@G62<I
M("L@,2DL("=I<T9U='5R941A=&4@,B<I.PH*8V]M<&%R92AF86QS92P@1&%T
M95]#86QC.CII<U!A<W1$871E*#(R+"`Q,2P@9&%T92@G62<I("L@,2DL("=I
M<U!A<W1$871E(#$G*3L*8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES4&%S
M=$1A=&4H,C(L(#$Q+"`R,#`P*2P@)VES4&%S=$1A=&4@,B<I.PIC;VUP87)E
M*'1R=64L($1A=&5?0V%L8SHZ:7-087-T1&%T92@G,C(G+"`G,3$G+"`G,C`P
M,"<I+"`G:7-087-T1&%T92`R('-T<B<I.PH*8V]M<&%R92@Q,"P@1&%T95]#
M86QC.CID871E1&EF9B@R,BP@,3$L(#(P,#`L(#$R+"`Q,2P@,C`P,"DL("=D
M871E1&EF9B`Q)RD["F-O;7!A<F4H,3`L($1A=&5?0V%L8SHZ9&%T941I9F8H
M,3(L(#$Q+"`R,#`P+"`R,BP@,3$L(#(P,#`I+"`G9&%T941I9F8@,B<I.PIC
M;VUP87)E*#8Q+"!$871E7T-A;&,Z.F1A=&5$:69F*#(R+"`Q,2P@,C`P,"P@
M,C(L(#$L(#(P,#$I+"`G9&%T941I9F8@,R<I.PIC;VUP87)E*#8Q+"!$871E
M7T-A;&,Z.F1A=&5$:69F*"<R,B<L("<Q,2<L("<R,#`P)RP@)S(R)RP@)S`Q
M)RP@)S(P,#$G*2P@)V1A=&5$:69F(#,@<W1R)RD["@IC;VUP87)E*"TQ+"!$
M871E7T-A;&,Z.F-O;7!A<F5$871E<R@Q,BP@,3$L(#(P,#`L(#(R+"`Q,2P@
M,C`P,"DL("=C;VUP87)E1&%T97,@,2<I.PIC;VUP87)E*#`L($1A=&5?0V%L
M8SHZ8V]M<&%R941A=&5S*#(R+"`Q,2P@,C`P,"P@,C(L(#$Q+"`R,#`P*2P@
M)V-O;7!A<F5$871E<R`R)RD["F-O;7!A<F4H,2P@1&%T95]#86QC.CIC;VUP
M87)E1&%T97,H,C(L(#$Q+"`R,#`P+"`Q,BP@,3$L(#(P,#`I+"`G8V]M<&%R
M941A=&5S(#,G*3L*8V]M<&%R92@Q+"!$871E7T-A;&,Z.F-O;7!A<F5$871E
M<R@G,C(G+"`G,3$G+"`G,C`P,"<L("<Q,B<L("<Q,2<L("<R,#`P)RDL("=C
M;VUP87)E1&%T97,@,R!S='(G*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B
M=6<W,C=?,BYP:'``````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-C``,3`U
M,34T,S$P-3<`,#(R-#8W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J"B`J(%1E<W1S(&9O<B!W965K<TEN36]N
M=&@L(&9E8G)U87)Y('=I=&@@-"!W965K<PH@*B!3=6YD87D@87,@,7-T(&1A
M>2!O9B!W965K"B`J+PID969I;F4H)T1!5$5?0T%,0U]"14=)3E]7145+1$%9
M)RP@,"D["G)E<75I<F5?;VYC92`B1&%T92]#86QC+G!H<"(["@HO*BH*("H@
M5&5S="!D871E<R!F<F]M(#$Y-S`@=&\@,C`R.0H@*B!$871A(&9R;VTZ(&AT
M='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K+W=K;F]T97-T+G1X=`H@*B!/
M=&AE<G,@=7-E9G5L;"!D871A<R!A=F%I;&%B;&4@9G)O;3H*("H@:'1T<#HO
M+W=W=RYM97)L>6XN9&5M;VXN8V\N=6LO(V1A=`H@*B\*)&1A=&%P871H(#T@
M9&ER;F%M92@@7U]&24Q%7U\I.PH*)&9A:6QE9%]T97-T7V1A=&$@("`](&9A
M;'-E.PHD9&%T97,@("`](&9I;&4H)&1A=&%P871H("X@)R]W965K<VEN;6]N
M=&A?-%]S=6YD87DN='AT)RD["B1C;G0@("`@(#T@<VEZ96]F*"1D871E<RD[
M"B1V86QI9',@/2!A<G)A>2@I.PIF;W(H("1I/3`[)&D\)&-N=#LD:2LK("E[
M"B`@("`D<&%R=',@("`@("`](&5X<&QO9&4H)R\G+"1D871E<ULD:5TI.PH@
M("`@)'9A;&ED<ULD<&%R='-;,%U=(#T@87)R87DH)'!A<G1S6S%=/3XH:6YT
M*7-T<E]R97!L86-E*")<;B(L)R<L)'!A<G1S6S)=*2D["GT*=6YS970H)&1A
M=&5S*3L*9F]R96%C:"@D=F%L:61S(&%S("1Y96%R(#T^("1M;VYT:',I>PH@
M("`@9F]R96%C:"`H)&UO;G1H<R!A<R`D;6]N=&@]/B1V86QI9%]W965K<RD@
M>PH@("`@("`@("1C86QC7W=E96MS(#T@1&%T95]#86QC.CIW965K<TEN36]N
M=&@H)&UO;G1H+"1Y96%R*3L*("`@("`@("!I9B@D8V%L8U]W965K<R$])'9A
M;&ED7W=E96MS*7L*("`@("`@("`@("`@)&9A:6QE9%]T97-T7V1A=&$@("`]
M('1R=64["B`@("`@("`@("`@(&5C:&\@(D)U9R`C-S(W+"!P87-S(#,Z("1Y
M96%R+R1M;VYT:"!F86EL960N($5X<&5C=#HD=F%L:61?=V5E:W,@1V]T.B1C
M86QC7W=E96MS7&XB.PH@("`@("`@('T*("`@('T*?0II9B`H(21F86EL961?
M=&5S=%]D871A*2!["@EE8VAO(")"=6<@(S<R-RP@<&%S<R`R.B!/2UQN(CL*
M?0H_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S<R-U\S+G!H<```````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,3`U-P`P,C(T-C<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH*
M("H@5&5S=',@9F]R('=E96MS26Y-;VYT:"P@(G)A;F1O;2(*("H@4W5N9&%Y
M(&%S(#%S="!D87D@;V8@=V5E:PH@*B\*9&5F:6YE*"=$051%7T-!3$-?0D5'
M24Y?5T5%2T1!62<L(#`I.PIR97%U:7)E7V]N8V4@(D1A=&4O0V%L8RYP:'`B
M.PH*+RHJ"B`J(%1E<W0@9&%T97,@9G)O;2`Q.3<P('1O(#(P,CD*("H@1&%T
M82!F<F]M.B!H='1P.B\O=W=W+FUE<FQY;BYD96UO;BYC;RYU:R]W:VYO=&5S
M="YT>'0*("H@3W1H97)S('5S969U;&P@9&%T87,@879A:6QA8FQE(&9R;VTZ
M"B`J(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K+R-D870*("HO"B1D
M871A<&%T:"`](&1I<FYA;64H(%]?1DE,15]?*3L*"B1F86EL961?=&5S=%]D
M871A("`@/2!F86QS93L*)&1A=&5S("`@/2!F:6QE*"1D871A<&%T:"`N("<O
M=V5E:W-I;FUO;G1H7W)D;5]S=6YD87DN='AT)RD["B1C;G0@("`@(#T@<VEZ
M96]F*"1D871E<RD["B1V86QI9',@/2!A<G)A>2@I.PIF;W(H("1I/3`[)&D\
M)&-N=#LD:2LK("E["B`@("`D<&%R=',@("`@("`](&5X<&QO9&4H)R\G+"1D
M871E<ULD:5TI.PH@("`@)'9A;&ED<ULD<&%R='-;,%U=(#T@87)R87DH)'!A
M<G1S6S%=/3XH:6YT*7-T<E]R97!L86-E*")<;B(L)R<L)'!A<G1S6S)=*2D[
M"GT*=6YS970H)&1A=&5S*3L*9F]R96%C:"@D=F%L:61S(&%S("1Y96%R(#T^
M("1M;VYT:',I>PH@("`@9F]R96%C:"`H)&UO;G1H<R!A<R`D;6]N=&@]/B1V
M86QI9%]W965K<RD@>PH@("`@("`@("1C86QC7W=E96MS(#T@1&%T95]#86QC
M.CIW965K<TEN36]N=&@H)&UO;G1H+"1Y96%R*3L*("`@("`@("!I9B@D8V%L
M8U]W965K<R$])'9A;&ED7W=E96MS*7L*("`@("`@("`@("`@)&9A:6QE9%]T
M97-T7V1A=&$@("`]('1R=64["B`@("`@("`@("`@(&5C:&\@(D)U9R`C-S(W
M+"!P87-S(#,Z("1Y96%R+R1M;VYT:"!F86EL960N($5X<&5C=#HD=F%L:61?
M=V5E:W,@1V]T.B1C86QC7W=E96MS7&XB.PH@("`@("`@('T*("`@('T*?0II
M9B`H(21F86EL961?=&5S=%]D871A*2!["B`@("!E8VAO(")"=6<@(S<R-RP@
M<&%S<R`S.B!/2UQN(CL*?0H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O
M8G5G-S(W7S0N<&AP````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0W`#$P
M-3$U-#,Q,#4W`#`R,C0W-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*@H@*B!497-T<R!F;W(@=V5E:W-);DUO
M;G1H+"`B<F%N9&]M(@H@*B!-;VYD87D@87,@,7-T(&1A>2!O9B!W965K"B`J
M+PID969I;F4H)T1!5$5?0T%,0U]"14=)3E]7145+1$%9)RP@,2D["G)E<75I
M<F5?;VYC92`B1&%T92]#86QC+G!H<"(["@HO*BH*("H@5&5S="!D871E<R!F
M<F]M(#$Y-S`@=&\@,C`R.0H@*B!$871A(&9R;VTZ(&AT='`Z+R]W=W<N;65R
M;'EN+F1E;6]N+F-O+G5K+W=K;F]T97-T+G1X=`H@*B!/=&AE<G,@=7-E9G5L
M;"!D871A<R!A=F%I;&%B;&4@9G)O;3H*("H@:'1T<#HO+W=W=RYM97)L>6XN
M9&5M;VXN8V\N=6LO(V1A=`H@*B\*)&1A=&%P871H(#T@9&ER;F%M92@@7U]&
M24Q%7U\I.PH*)&9A:6QE9%]T97-T7V1A=&$@("`](&9A;'-E.PHD9&%T97,@
M("`](&9I;&4H)&1A=&%P871H("X@)R]W965K<VEN;6]N=&A?<F1M7VUO;F1A
M>2YT>'0G*3L*)&-N="`@("`@/2!S:7IE;V8H)&1A=&5S*3L*)'9A;&ED<R`]
M(&%R<F%Y*"D["F9O<B@@)&D],#LD:3PD8VYT.R1I*RL@*7L*("`@("1P87)T
M<R`@("`@(#T@97AP;&]D92@G+R<L)&1A=&5S6R1I72D["B`@("`D=F%L:61S
M6R1P87)T<ULP75T@/2!A<G)A>2@D<&%R='-;,5T]/BAI;G0I<W1R7W)E<&QA
M8V4H(EQN(BPG)RPD<&%R='-;,ETI*3L*?0IU;G-E="@D9&%T97,I.PIF;W)E
M86-H*"1V86QI9',@87,@)'EE87(@/3X@)&UO;G1H<RE["B`@("!F;W)E86-H
M("@D;6]N=&AS(&%S("1M;VYT:#T^)'9A;&ED7W=E96MS*2!["B`@("`@("`@
M)&-A;&-?=V5E:W,@/2!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@D;6]N=&@L
M)'EE87(I.PH@("`@("`@(&EF*"1C86QC7W=E96MS(3TD=F%L:61?=V5E:W,I
M>PH@("`@("`@("`@("`D9F%I;&5D7W1E<W1?9&%T82`@(#T@=')U93L*("`@
M("`@("`@("`@96-H;R`B0G5G(#<R-RP@<&%S<R`T.B`D>65A<B\D;6]N=&@@
M9F%I;&5D+B!%>'!E8W0Z)'9A;&ED7W=E96MS($=O=#HD8V%L8U]W965K<UQN
M(CL*("`@("`@("!]"B`@("!]"GT*:68@*"$D9F%I;&5D7W1E<W1?9&%T82D@
M>PH@("`@96-H;R`B0G5G(",W,C<L('!A<W,@-#H@3TM<;B(["GT*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<Y-C<N<&AP````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`V,34`,3`U,34T,S$P-3<`,#(R,C8P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"G)E
M<75I<F5?;VYC92`G1&%T92YP:'`G.PHD7T1!5$5?5$E-15I/3D5?1$5&055,
M5"`]("=086-I9FEC+T-H871H86TG.PHD='H@/2!$871E7U1I;65:;VYE.CIG
M971$969A=6QT*"D["FEF("@D='HM/FED(3TD7T1!5$5?5$E-15I/3D5?1$5&
M055,5"`F)B`D='HM/FED(3TG4&%C:69I8R]#:&%T:&%M)RD@>PH@("`@96-H
M;R`B<V5T1&5F875L="!&86EL961<;B(["GT*1&%T95]4:6UE6F]N93HZ<V5T
M1&5F875L="@G0U-4)RD["B1D969A=6QT(#T@)T535"<["B1T>B`]($1A=&5?
M5&EM95IO;F4Z.F=E=$1E9F%U;'0H*3L*:68@*"1T>BT^:60A/21?1$%415]4
M24U%6D].15]$149!54Q4("8F("1T>BT^:60A/2=%4U0G*2!["B`@("!E8VAO
M(")S971$969A=6QT($9A:6QE9%QN(CL*?0H_/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1A=&4O=&5S=',O8V%L8RYP:'``````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#0T-#8V`#$P-3$U-#,Q,#4W`#`R,C$U,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT
M.B`J+PHO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-2!$86YI96P@0V]N=FES<V]R(#QD86YI
M96QC0'!H<"YN970^("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!T:&4@3F5W($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@
M?"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@879A:6QA8FQE('1H<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O
M;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W
M($)31&QI8V5N<V4@86YD(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+RHJ"B`J(%1E<W1S(&9O<B!T:&4@1&%T95]#86QC(&-L87-S"B`J
M"B`J($%N>2!I;F1I=FED=6%L('1E<W1S('1H870@9F%I;"!W:6QL(&AA=F4@
M=&AE:7(@;F%M92P@97AP96-T960@<F5S=6QT"B`J(&%N9"!A8W1U86P@<F5S
M=6QT('!R:6YT960@;W5T+B`@4V\@<V5E:6YG(&YO(&]U='!U="!W:&5N(&5X
M96-U=&EN9PH@*B!T:&ES(&9I;&4@:7,@82!G;V]D('1H:6YG+@H@*@H@*B!#
M86X@8F4@<G5N('9I82!#3$D@;W(@82!W96(@<V5R=F5R+@H@*@H@*B!4:&ES
M('1E<W0@<V5N<V5S('=H971H97(@:70@:7,@9G)O;2!A;B!I;G-T86QL871I
M;VX@;V8@4$5!4CHZ1&%T92!O<B!I9@H@*B!I="=S(&9R;VT@0U93(&]R(&$@
M+G1A<B!F:6QE+B`@268@:70G<R!A;B!I;G-T86QL960@=F5R<VEO;BP@=7-E
M('1H90H@*B!I;G-T86QL960@=F5R<VEO;B!O9B!$871E7T-A;&,N("!/=&AE
M<G=I<V4L('5S92!T:&4@;&]C86P@9&5V96QO<&UE;G0*("H@8V]P>2!O9B!$
M871E7T-A;&,N"B`J"B`J($!C871E9V]R>2`@($1A=&4@86YD(%1I;64*("H@
M0'!A8VMA9V4@("`@1&%T90H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@8V%L8RYP:'`L=B`Q+C@@,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P
M86IO>64@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+T1A=&4*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C4*("HO"@II9B`H)R]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R)R`A/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2!["B`@
M("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!I;FE?9V5T*"=I;F-L=61E7W!A
M=&@G*0H@("`@("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG"B`@("`I
M.PI](&5L<V4@>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@<F5A;'!A
M=&@H9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+R<I"B`@("`@("`@("`@("X@
M4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@
M("`@("`N(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PI]"@HO*BH*
M("H@1V5T('1H92!N965D960@8VQA<W,*("HO"G)E<75I<F5?;VYC92`G1&%T
M92]#86QC+G!H<"<["@HO*BH*("H@0V]M<&%R92!T:&4@=&5S="!R97-U;'0@
M=&\@=&AE(&5X<&5C=&5D(')E<W5L=`H@*@H@*B!)9B!T:&4@=&5S="!F86EL
M<RP@96-H;R!O=70@=&AE(')E<W5L=',N"B`J"B`J($!P87)A;2!M:7AE9"`@
M)&5X<&5C="`@("`@=&AE('-C86QA<B!O<B!A<G)A>2!Y;W4@97AP96-T(&9R
M;VT@=&AE('1E<W0*("H@0'!A<F%M(&UI>&5D("`D86-T=6%L("`@("!T:&4@
M<V-A;&%R(&]R(&%R<F%Y(')E<W5L=',@9G)O;2!T:&4@=&5S=`H@*B!`<&%R
M86T@<W1R:6YG("1T97-T7VYA;64@('1H92!N86UE(&]F('1H92!T97-T"B`J
M"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@8V]M<&%R92@D97AP96-T
M+"`D86-T=6%L+"`D=&5S=%]N86UE*2!["B`@("!I9B`H:7-?87)R87DH)&5X
M<&5C="DI('L*("`@("`@("!I9B`H8V]U;G0H87)R87E?9&EF9B@D86-T=6%L
M+"`D97AP96-T*2DI('L*("`@("`@("`@("`@96-H;R`B)'1E<W1?;F%M92!F
M86EL960N("!%>'!E8W0Z7&XB.PH@("`@("`@("`@("!P<FEN=%]R*"1E>'!E
M8W0I.PH@("`@("`@("`@("!E8VAO(")!8W1U86PZ7&XB.PH@("`@("`@("`@
M("!P<FEN=%]R*"1A8W1U86PI.PH@("`@("`@('T*("`@('T@96QS92!["B`@
M("`@("`@:68@*"1E>'!E8W0@(3T@)&%C='5A;"D@>PH@("`@("`@("`@("!E
M8VAO("(D=&5S=%]N86UE(&9A:6QE9"X@($5X<&5C=#H@)&5X<&5C="X@($%C
M='5A;#H@)&%C='5A;%QN(CL*("`@("`@("!]"B`@("!]"GT*"FEF("AP:'!?
M<V%P:5]N86UE*"D@(3T@)V-L:2<I('L*("`@(&5C:&\@(CQP<F4^7&XB.PI]
M"@H*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.F1A=&5&;W)M870H
M,C(L(#$Q+"`R,#`P+"`G)5DE;25D)RDL("=D871E1F]R;6%T)RD["F-O;7!A
M<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CID871E1F]R;6%T*"<R,B<L("<Q
M,2<L("<R,#`P)RP@)R59)6TE9"<I+"`G9&%T949O<FUA="!S='(G*3L*"F-O
M;7!A<F4H)S(P,#$G+"!$871E7T-A;&,Z.F1E9F%U;'1#96YT=7)Y*"<Q)RDL
M("=D969A=6QT0V5N='5R>2`Q('-T<B<I.PIC;VUP87)E*"<R,#`Q)RP@1&%T
M95]#86QC.CID969A=6QT0V5N='5R>2@Q*2P@)V1E9F%U;'1#96YT=7)Y(#$G
M*3L*8V]M<&%R92@G,3DV,"<L($1A=&5?0V%L8SHZ9&5F875L=$-E;G1U<GDH
M-C`I+"`G9&5F875L=$-E;G1U<GD@,B<I.PIC;VUP87)E*"<R,#$P)RP@1&%T
M95]#86QC.CID969A=6QT0V5N='5R>2@Q,"DL("=D969A=6QT0V5N='5R>2`S
M)RD["@IC;VUP87)E*#(T-3$X-S$L($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@G
M,C(G+"`G,3$G+"`G,C`P,"<I+"`G9&%T951O1&%Y<R!S='(G*3L*8V]M<&%R
M92@R-#4Q.#<Q+"!$871E7T-A;&,Z.F1A=&54;T1A>7,H,C(L(#$Q+"`R,#`P
M*2P@)V1A=&54;T1A>7,G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A
M;&,Z.F1A>7-4;T1A=&4H,C0U,3@W,2DL("=D87ES5&]$871E)RD["@IC;VUP
M87)E*"<R,#`P+30W+3,G+"!$871E7T-A;&,Z.F=R96=O<FEA;E1O25-/*"<R
M,B<L("<Q,2<L("<R,#`P)RDL("=G<F5G;W)I86Y4;TE33R!S='(G*3L*8V]M
M<&%R92@G,C`P,"TT-RTS)RP@1&%T95]#86QC.CIG<F5G;W)I86Y4;TE33R@R
M,BP@,3$L(#(P,#`I+"`G9W)E9V]R:6%N5&])4T\G*3L*8V]M<&%R92@R-#4Q
M-S$V+C4V-S8W+"!$871E7T-A;&,Z.F1A=&5396%S;VXH)U-534U%4E-/3%-4
M24-%)RP@,C`P,"DL("=D871E4V5A<V]N)RD["@IC;VUP87)E*&1A=&4H)UEM
M9"<I+"!$871E7T-A;&,Z.F1A=&5.;W<H*2P@)V1A=&5.;W<G*3L*8V]M<&%R
M92AD871E*"=9)RDL($1A=&5?0V%L8SHZ9V5T665A<B@I+"`G9V5T665A<B<I
M.PIC;VUP87)E*&1A=&4H)VTG*2P@1&%T95]#86QC.CIG971-;VYT:"@I+"`G
M9V5T36]N=&@G*3L*8V]M<&%R92AD871E*"=D)RDL($1A=&5?0V%L8SHZ9V5T
M1&%Y*"DL("=G971$87DG*3L*"F-O;7!A<F4H,S(W+"!$871E7T-A;&,Z.FIU
M;&EA;D1A=&4H,C(L(#$Q+"`R,#`P*2P@)VIU;&EA;D1A=&4G*3L*8V]M<&%R
M92@G3F]V96UB97(G+"!$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H,3$I
M+"`G9V5T36]N=&A&=6QL;F%M92<I.PIC;VUP87)E*"=.;W8G+"!$871E7T-A
M;&,Z.F=E=$UO;G1H06)B<FYA;64H,3$I+"`G9V5T36]N=&A!8F)R;F%M92<I
M.PIC;VUP87)E*"=3871U<F1A>2<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A>49U
M;&QN86UE*#$L(#$L(#(P,#4I+"`G9V5T5V5E:V1A>49U;&QN86UE)RD["F-O
M;7!A<F4H)U-A="<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE*#$L
M(#$L(#(P,#4I+"`G9V5T5V5E:V1A>4%B8G)N86UE)RD["F-O;7!A<F4H,3$L
M($1A=&5?0V%L8SHZ9V5T36]N=&A&<F]M1G5L;$YA;64H)TYO=F5M8F5R)RDL
M("=G971-;VYT:$9R;VU&=6QL3F%M92<I.PH*8V]M<&%R92@S,C<L($1A=&5?
M0V%L8SHZ:G5L:6%N1&%T92@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G:G5L:6%N
M1&%T92!S='(G*3L*8V]M<&%R92@G3F]V96UB97(G+"!$871E7T-A;&,Z.F=E
M=$UO;G1H1G5L;&YA;64H)S$Q)RDL("=G971-;VYT:$9U;&QN86UE('-T<B<I
M.PIC;VUP87)E*"=.;W8G+"!$871E7T-A;&,Z.F=E=$UO;G1H06)B<FYA;64H
M)S$Q)RDL("=G971-;VYT:$%B8G)N86UE('-T<B<I.PIC;VUP87)E*"=3871U
M<F1A>2<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE*"<P,2<L("<P
M,2<L("<R,#`U)RDL("=G9717965K9&%Y1G5L;&YA;64@<W1R)RD["F-O;7!A
M<F4H)U-A="<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE*"<P,2<L
M("<P,2<L("<R,#`U)RDL("=G9717965K9&%Y06)B<FYA;64@<W1R)RD["@HD
M97AP(#T@87)R87DH"B`@("`G2F%N=6%R>2<L"B`@("`G1F5B<G5A<GDG+`H@
M("`@)TUA<F-H)RP*("`@("=!<')I;"<L"B`@("`G36%Y)RP*("`@("=*=6YE
M)RP*("`@("=*=6QY)RP*("`@("=!=6=U<W0G+`H@("`@)U-E<'1E;6)E<B<L
M"B`@("`G3V-T;V)E<B<L"B`@("`G3F]V96UB97(G+`H@("`@)T1E8V5M8F5R
M)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T36]N=&A.86UE<R@I
M+"`G9V5T36]N=&A.86UE<R<I.PH*)&5X<"`](&%R<F%Y*`H@("`@)TUO;F1A
M>2<L"B`@("`G5'5E<V1A>2<L"B`@("`G5V5D;F5S9&%Y)RP*("`@("=4:'5R
M<V1A>2<L"B`@("`G1G)I9&%Y)RP*("`@("=3871U<F1A>2<L"B`@("`G4W5N
M9&%Y)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T5V5E:T1A>7,H
M*2P@)V=E=%=E96M$87ES)RD["@IC;VUP87)E*#,L($1A=&5?0V%L8SHZ9&%Y
M3V97965K*#(R+"`Q,2P@,C`P,"DL("=D87E/9E=E96LG*3L*8V]M<&%R92@T
M-RP@1&%T95]#86QC.CIW965K3V9996%R*#(R+"`Q,2P@,C`P,"DL("=W965K
M3V9996%R)RD["F-O;7!A<F4H-"P@1&%T95]#86QC.CIQ=6%R=&5R3V9996%R
M*#(R+"`Q,2P@,C`P,"DL("=Q=6%R=&5R3V9996%R)RD["@IC;VUP87)E*#,L
M($1A=&5?0V%L8SHZ9&%Y3V97965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=D
M87E/9E=E96L@<W1R)RD["F-O;7!A<F4H-#<L($1A=&5?0V%L8SHZ=V5E:T]F
M665A<B@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G=V5E:T]F665A<B!S='(G*3L*
M8V]M<&%R92@T+"!$871E7T-A;&,Z.G%U87)T97)/9EEE87(H)S(R)RP@)S$Q
M)RP@)S(P,#`G*2P@)W%U87)T97)/9EEE87(@<W1R)RD["@IC;VUP87)E*#(X
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L(#$Y,#`I+"`G9&%Y<TEN36]N
M=&@@,2<I.PIC;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L
M(#$Y.38I+"`G9&%Y<TEN36]N=&@@,B<I.PIC;VUP87)E*#(Y+"!$871E7T-A
M;&,Z.F1A>7-);DUO;G1H*#(L(#(P,#`I+"`G9&%Y<TEN36]N=&@@,R<I.PIC
M;VUP87)E*#(X+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L(#(P,#$I+"`G
M9&%Y<TEN36]N=&@@-"<I.PIC;VUP87)E*#,P+"!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*#$Q+"`R,#`P*2P@)V1A>7-);DUO;G1H(#4G*3L*"F-O;7!A<F4H
M,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)S`R)RP@,3DP,"DL("=D87ES
M26Y-;VYT:"`Q('-T<B<I.PIC;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*"<P,B<L(#$Y.38I+"`G9&%Y<TEN36]N=&@@,B!S='(G*3L*8V]M
M<&%R92@R.2P@1&%T95]#86QC.CID87ES26Y-;VYT:"@G,#(G+"`R,#`P*2P@
M)V1A>7-);DUO;G1H(#,@<W1R)RD["F-O;7!A<F4H,C@L($1A=&5?0V%L8SHZ
M9&%Y<TEN36]N=&@H)S`R)RP@,C`P,2DL("=D87ES26Y-;VYT:"`T('-T<B<I
M.PIC;VUP87)E*#,P+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<Q,2<L("<R
M,#`P)RDL("=D87ES26Y-;VYT:"`U('-T<B<I.PH*8V]M<&%R92@U+"!$871E
M7T-A;&,Z.G=E96MS26Y-;VYT:"@Q,2P@,C`P,"DL("=W965K<TEN36]N=&@G
M*3L*8V]M<&%R92@U+"!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@G,3$G+"`G
M,C`P,"<I+"`G=V5E:W-);DUO;G1H('-T<B<I.PH*"B1E>'`@/2!A<G)A>2@*
M("`@("<Q.3`P,#(R-B<L"B`@("`G,3DP,#`R,C<G+`H@("`@)S$Y,#`P,C(X
M)RP*("`@("<Q.3`P,#,P,2<L"B`@("`G,3DP,#`S,#(G+`H@("`@)S$Y,#`P
M,S`S)RP*("`@("<Q.3`P,#,P-"<L"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#
M86QC.CIG971#86QE;F1A<E=E96LH,C<L(#(L(#$Y,#`I+"`G9V5T0V%L96YD
M87)7965K(#$G*3L*"B1E>'`@/2!A<G)A>2@*("`@("<R,#`P,#(R."<L"B`@
M("`G,C`P,#`R,CDG+`H@("`@)S(P,#`P,S`Q)RP*("`@("<R,#`P,#,P,B<L
M"B`@("`G,C`P,#`S,#,G+`H@("`@)S(P,#`P,S`T)RP*("`@("<R,#`P,#,P
M-2<L"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE;F1A<E=E
M96LH,C@L(#(L(#(P,#`I+"`G9V5T0V%L96YD87)7965K(#(G*3L*"B1E>'`@
M/2!A<G)A>2@*("`@("<R,#`P,3$R-R<L"B`@("`G,C`P,#$Q,C@G+`H@("`@
M)S(P,#`Q,3(Y)RP*("`@("<R,#`P,3$S,"<L"B`@("`G,C`P,#$R,#$G+`H@
M("`@)S(P,#`Q,C`R)RP*("`@("<R,#`P,3(P,R<**3L*8V]M<&%R92@D97AP
M+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R5V5E:R@R-RP@,3$L(#(P,#`I+"`G
M9V5T0V%L96YD87)7965K(#,G*3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z
M.F=E=$-A;&5N9&%R5V5E:R@G,C<G+"`G,3$G+"`G,C`P,"<I+"`G9V5T0V%L
M96YD87)7965K(#,@<W1R)RD["@HD97AP(#T@87)R87DH"B`@("!A<G)A>2@*
M("`@("`@("`G,C`P,#$P,S`G+`H@("`@("`@("<R,#`P,3`S,2<L"B`@("`@
M("`@)S(P,#`Q,3`Q)RP*("`@("`@("`G,C`P,#$Q,#(G+`H@("`@("`@("<R
M,#`P,3$P,R<L"B`@("`@("`@)S(P,#`Q,3`T)RP*("`@("DL"B`@("!A<G)A
M>2@*("`@("`@("`G,C`P,#$Q,#4G+`H@("`@("`@("<R,#`P,3$P-B<L"B`@
M("`@("`@)S(P,#`Q,3`W)RP*("`@("`@("`G,C`P,#$Q,#@G+`H@("`@("`@
M("<R,#`P,3$P.2<L"B`@("`@("`@)S(P,#`Q,3$P)RP*("`@("`@("`G,C`P
M,#$Q,3$G+`H@("`@*2P*("`@(&%R<F%Y*`H@("`@("`@("<R,#`P,3$Q,B<L
M"B`@("`@("`@)S(P,#`Q,3$S)RP*("`@("`@("`G,C`P,#$Q,30G+`H@("`@
M("`@("<R,#`P,3$Q-2<L"B`@("`@("`@)S(P,#`Q,3$V)RP*("`@("`@("`G
M,C`P,#$Q,3<G+`H@("`@("`@("<R,#`P,3$Q."<L"B`@("`I+`H@("`@87)R
M87DH"B`@("`@("`@)S(P,#`Q,3$Y)RP*("`@("`@("`G,C`P,#$Q,C$G+`H@
M("`@("`@("<R,#`P,3$R,B<L"B`@("`@("`@)S(P,#`Q,3(S)RP*("`@("`@
M("`G,C`P,#$Q,C0G+`H@("`@("`@("<R,#`P,3$R-2<L"B`@("`@("`@)S(P
M,#`Q,3(V)RP*("`@("DL"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$Q,C<G
M+`H@("`@("`@("<R,#`P,3$R."<L"B`@("`@("`@)S(P,#`Q,3(Y)RP*("`@
M("`@("`G,C`P,#$Q,S`G+`H@("`@("`@("<R,#`P,3(P,2<L"B`@("`@("`@
M)S(P,#`Q,C`R)RP*("`@("`@("`G,C`P,#$R,#,G"B`@("`I"BD["F-O;7!A
M<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE;F1A<DUO;G1H*#$Q+"`R,#`P
M*2P@)V=E=$-A;&5N9&%R36]N=&@G*3L*8V]M<&%R92@D97AP+"!$871E7T-A
M;&,Z.F=E=$-A;&5N9&%R36]N=&@H)S$Q)RP@)S(P,#`G*2P@)V=E=$-A;&5N
M9&%R36]N=&@@<W1R)RD["@HO+R!)(&1O;B=T(&9E96P@;&EK92!D96%L:6YG
M('=I=&@@=&AI<R!R:6=H="!N;W<N+BX*+R]C;VUP87)E*"<G+"!$871E7T-A
M;&,Z.F=E=$-A;&5N9&%R665A<B@R,#`P*2P@)V=E=$-A;&5N9&%R665A<B<I
M.PH*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87DH,C(L
M(#$Q+"`R,#`P*2P@)W!R979$87DG*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$
M871E7T-A;&,Z.FYE>'1$87DH,C(L(#$Q+"`R,#`P*2P@)VYE>'1$87DG*3L*
M8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87DH,C(L(#$Q
M+"`R,#`P*2P@)W!R979$87D@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@
M1&%T95]#86QC.CIN97AT1&%Y*"<R,B<L("<Q,2<L("<R,#`P)RDL("=N97AT
M1&%Y('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q,3<G+"!$871E7T-A;&,Z.G!R
M9797965K9&%Y*"<Q.2<L("<Q,2<L("<R,#`P)RDL("=P<F5V5V5E:V1A>2`Q
M('-T<B<I.PIC;VUP87)E*"<R,#`P,3$Q-R<L($1A=&5?0V%L8SHZ<')E=E=E
M96MD87DH,3DL(#$Q+"`R,#`P*2P@)W!R9797965K9&%Y(#$G*3L*8V]M<&%R
M92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R9797965K9&%Y*#(R+"`Q,2P@
M,C`P,"DL("=P<F5V5V5E:V1A>2`R)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@
M1&%T95]#86QC.CIN97AT5V5E:V1A>2@R,BP@,3$L(#(P,#`I+"`G;F5X=%=E
M96MD87D@,2<I.PIC;VUP87)E*"<R,#`P,3$R-R<L($1A=&5?0V%L8SHZ;F5X
M=%=E96MD87DH,C0L(#$Q+"`R,#`P*2P@)VYE>'17965K9&%Y(#(G*3L*8V]M
M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z.FYE>'17965K9&%Y*"<R-"<L
M("<Q,2<L("<R,#`P)RDL("=N97AT5V5E:V1A>2`R('-T<B<I.PH*8V]M<&%R
M92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96LH)S(G+"`G
M,C(G+"`G,3$G+"`G,C`P,"<I+"`G<')E=D1A>4]F5V5E:R`Q('-T<B<I.PIC
M;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:R@R
M+"`R,BP@,3$L(#(P,#`I+"`G<')E=D1A>4]F5V5E:R`Q)RD["F-O;7!A<F4H
M)S(P,#`Q,3$U)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K*#,L(#(R+"`Q
M,2P@,C`P,"DL("=P<F5V1&%Y3V97965K(#(G*3L*8V]M<&%R92@G,C`P,#$Q
M,C(G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P
M+"`G)5DE;25D)RP@=')U92DL("=P<F5V1&%Y3V97965K(#,G*3L*8V]M<&%R
M92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96LH,RP@,C(L
M(#$Q+"`R,#`P+"`G)5DE;25D)RP@=')U92DL("=N97AT1&%Y3V97965K(#$G
M*3L*8V]M<&%R92@G,C`P,#$Q,CDG+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E
M96LH,RP@,C(L(#$Q+"`R,#`P*2P@)VYE>'1$87E/9E=E96L@,B<I.PIC;VUP
M87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:R@T+"`R
M,BP@,3$L(#(P,#`I+"`G;F5X=$1A>4]F5V5E:R`S)RD["F-O;7!A<F4H)S(P
M,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y3V97965K*"<T)RP@)S(R)RP@
M)S$Q)RP@)S(P,#`G*2P@)VYE>'1$87E/9E=E96L@,R!S='(G*3L*"F-O;7!A
M<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K3VY/<D)E
M9F]R92@G,B<L("<R,B<L("<Q,2<L("<R,#`P)RDL("=P<F5V1&%Y3V97965K
M3VY/<D)E9F]R92`Q('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?
M0V%L8SHZ<')E=D1A>4]F5V5E:T]N3W)"969O<F4H,BP@,C(L(#$Q+"`R,#`P
M*2P@)W!R979$87E/9E=E96M/;D]R0F5F;W)E(#$G*3L*8V]M<&%R92@G,C`P
M,#$Q,C(G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96M/;D]R0F5F;W)E*#,L
M(#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y3V97965K3VY/<D)E9F]R92`R)RD[
M"F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CIN97AT1&%Y3V97965K
M3VY/<D%F=&5R*#,L(#(R+"`Q,2P@,C`P,"DL("=N97AT1&%Y3V97965K3VY/
M<D%F=&5R(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE
M>'1$87E/9E=E96M/;D]R069T97(H-"P@,C(L(#$Q+"`R,#`P*2P@)VYE>'1$
M87E/9E=E96M/;D]R069T97(@,B<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A
M=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:T]N3W)!9G1E<B@G-"<L("<R,B<L("<Q
M,2<L("<R,#`P)RDL("=N97AT1&%Y3V97965K3VY/<D%F=&5R(#(@<W1R)RD[
M"@IC;VUP87)E*"<R,#`P,3$R,"<L($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH
M)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V97965K('-T<B<I.PIC;VUP
M87)E*"<R,#`P,3$R,"<L($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH,C(L(#$Q
M+"`R,#`P*2P@)V)E9VEN3V97965K)RD["F-O;7!A<F4H)S(P,#`Q,3(V)RP@
M1&%T95]#86QC.CIE;F1/9E=E96LH,C(L(#$Q+"`R,#`P*2P@)V5N9$]F5V5E
M:R<I.PIC;VUP87)E*"<R,#`P,3$R-B<L($1A=&5?0V%L8SHZ96YD3V97965K
M*"<R,B<L("<Q,2<L("<R,#`P)RDL("=E;F1/9E=E96L@<W1R)RD["@IC;VUP
M87)E*"<R,#`P,3$Q,R<L($1A=&5?0V%L8SHZ8F5G:6Y/9E!R9797965K*#(R
M+"`Q,2P@,C`P,"DL("=B96=I;D]F4')E=E=E96LG*3L*8V]M<&%R92@G,C`P
M,#$Q,C<G+"!$871E7T-A;&,Z.F)E9VEN3V9.97AT5V5E:R@R,BP@,3$L(#(P
M,#`I+"`G8F5G:6Y/9DYE>'17965K)RD["F-O;7!A<F4H)S(P,#`Q,3$S)RP@
M1&%T95]#86QC.CIB96=I;D]F4')E=E=E96LH)S(R)RP@)S$Q)RP@)S(P,#`G
M*2P@)V)E9VEN3V90<F5V5V5E:R!S='(G*3L*8V]M<&%R92@G,C`P,#$Q,C<G
M+"!$871E7T-A;&,Z.F)E9VEN3V9.97AT5V5E:R@G,C(G+"`G,3$G+"`G,C`P
M,"<I+"`G8F5G:6Y/9DYE>'17965K('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q
M,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:"@Q,2P@,C`P,"DL("=B96=I
M;D]F36]N=&@G*3L*8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E7T-A;&,Z.F)E
M9VEN3V9-;VYT:"@G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9DUO;G1H('-T<B<I
M.PH*8V]M<&%R92@G,C`P,#$P,#$G+"!$871E7T-A;&,Z.F)E9VEN3V90<F5V
M36]N=&@H,C(L(#$Q+"`R,#`P*2P@)V)E9VEN3V90<F5V36]N=&@G*3L*8V]M
M<&%R92@G,C`P,#$P,S$G+"!$871E7T-A;&,Z.F5N9$]F4')E=DUO;G1H*#(R
M+"`Q,2P@,C`P,"DL("=E;F1/9E!R979-;VYT:"<I.PIC;VUP87)E*"<R,#`P
M,3`P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9E!R979-;VYT:"@G,C(G+"`G,3$G
M+"`G,C`P,"<I+"`G8F5G:6Y/9E!R979-;VYT:"!S='(G*3L*8V]M<&%R92@G
M,C`P,#$P,S$G+"!$871E7T-A;&,Z.F5N9$]F4')E=DUO;G1H*"<R,B<L("<Q
M,2<L("<R,#`P)RDL("=E;F1/9E!R979-;VYT:"!S='(G*3L*"F-O;7!A<F4H
M)S(P,#`Q,C`Q)RP@1&%T95]#86QC.CIB96=I;D]F3F5X=$UO;G1H*#(R+"`Q
M,2P@,C`P,"DL("=B96=I;D]F3F5X=$UO;G1H)RD["F-O;7!A<F4H)S(P,#`Q
M,C,Q)RP@1&%T95]#86QC.CIE;F1/9DYE>'1-;VYT:"@R,BP@,3$L(#(P,#`I
M+"`G96YD3V9.97AT36]N=&@G*3L*8V]M<&%R92@G,C`P,#$R,#$G+"!$871E
M7T-A;&,Z.F)E9VEN3V9.97AT36]N=&@H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@
M)V)E9VEN3V9.97AT36]N=&@@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,C,Q)RP@
M1&%T95]#86QC.CIE;F1/9DYE>'1-;VYT:"@G,C(G+"`G,3$G+"`G,C`P,"<I
M+"`G96YD3V9.97AT36]N=&@@<W1R)RD["@IC;VUP87)E*"<Q.3DY,3`P,2<L
M($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"TQ,RP@,3$L(#(P,#`I
M+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#$G*3L*8V]M<&%R92@G,C`P,#$P,#$G
M+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@M,2P@,3$L(#(P,#`I
M+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#(G*3L*8V]M<&%R92@G,C`P,#$Q,#$G
M+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@P+"`Q,2P@,C`P,"DL
M("=B96=I;D]F36]N=&A">5-P86X@,R<I.PIC;VUP87)E*"<R,#`P,3(P,2<L
M($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#$L(#$Q+"`R,#`P*2P@
M)V)E9VEN3V9-;VYT:$)Y4W!A;B`T)RD["F-O;7!A<F4H)S(P,#$Q,C`Q)RP@
M1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH,3,L(#$Q+"`R,#`P*2P@
M)V)E9VEN3V9-;VYT:$)Y4W!A;B`U)RD["@IC;VUP87)E*"<Q.3DY,#$P,2<L
M($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"<M,3,G+"`G,#(G+"`G
M,C`P,"<I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#8@<W1R)RD["F-O;7!A<F4H
M)S$Y.3DP,3`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH+3$S
M+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`V)RD["F-O;7!A<F4H
M)S(P,#`P,3`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH+3$L
M(#(L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#<G*3L*8V]M<&%R92@G
M,C`P,#`R,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@P+"`R
M+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`X)RD["F-O;7!A<F4H)S(P
M,#`P,S`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH,2P@,BP@
M,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@.2<I.PIC;VUP87)E*"<R,#`Q
M,#,P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#$S+"`R+"`R
M,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`Q,"<I.PIC;VUP87)E*"<R,#`Q
M,#,P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"<Q,R<L("<P
M,B<L("<R,#`P)RDL("=B96=I;D]F36]N=&A">5-P86X@,3`@<W1R)RD["@IC
M;VUP87)E*"<Q.3DY,3`S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A
M;B@M,3,L(#$Q+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@,2<I.PIC;VUP
M87)E*"<R,#`P,3`S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@M
M,2P@,3$L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`R)RD["F-O;7!A<F4H
M)S(P,#`Q,3,P)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#`L(#$Q
M+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@,R<I.PIC;VUP87)E*"<R,#`P
M,3(S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@Q+"`Q,2P@,C`P
M,"DL("=E;F1/9DUO;G1H0GE3<&%N(#0G*3L*8V]M<&%R92@G,C`P,3$R,S$G
M+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH,3,L(#$Q+"`R,#`P*2P@
M)V5N9$]F36]N=&A">5-P86X@-2<I.PH*8V]M<&%R92@G,3DY.3`Q,S$G+"!$
M871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH)RTQ,R<L("<P,B<L("<R,#`P
M)RDL("=E;F1/9DUO;G1H0GE3<&%N(#8@<W1R)RD["F-O;7!A<F4H)S$Y.3DP
M,3,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"TQ,RP@,BP@,C`P
M,"DL("=E;F1/9DUO;G1H0GE3<&%N(#8G*3L*8V]M<&%R92@G,C`P,#`Q,S$G
M+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH+3$L(#(L(#(P,#`I+"`G
M96YD3V9-;VYT:$)Y4W!A;B`W)RD["F-O;7!A<F4H)S(P,#`P,C(Y)RP@1&%T
M95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#`L(#(L(#(P,#`I+"`G96YD3V9-
M;VYT:$)Y4W!A;B`X)RD["F-O;7!A<F4H)S(P,#`P,S,Q)RP@1&%T95]#86QC
M.CIE;F1/9DUO;G1H0GE3<&%N*#$L(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y
M4W!A;B`Y)RD["F-O;7!A<F4H)S(P,#$P,S,Q)RP@1&%T95]#86QC.CIE;F1/
M9DUO;G1H0GE3<&%N*#$S+"`R+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@
M,3`G*3L*8V]M<&%R92@G,C`P,3`S,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N
M=&A">5-P86XH)S$S)RP@)S`R)RP@)S(P,#`G*2P@)V5N9$]F36]N=&A">5-P
M86X@,3`@<W1R)RD["@IC;VUP87)E*#,L($1A=&5?0V%L8SHZ9FER<W1/9DUO
M;G1H5V5E:V1A>2@Q,2P@,C`P,"DL("=F:7)S=$]F36]N=&A7965K9&%Y)RD[
M"F-O;7!A<F4H,RP@1&%T95]#86QC.CIF:7)S=$]F36]N=&A7965K9&%Y*"<Q
M,2<L("<R,#`P)RDL("=F:7)S=$]F36]N=&A7965K9&%Y('-T<B<I.PH*8V]M
M<&%R92@G,C`P-3`Q,#$G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q
M+"`V+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q-C$G*3L*8V]M<&%R
M92@G,C`P-3`Q,#(G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`P
M+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q,#$G*3L*8V]M<&%R92@G
M,C`P-3`Q,#,G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`Q+"`Q
M+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q,3$G*3L*8V]M<&%R92@G,C`P
M-3`Q,#0G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`R+"`Q+"`R
M,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q,C$G*3L*8V]M<&%R92@G,C`P-3`Q
M,#4G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`S+"`Q+"`R,#`U
M*2P@)TY7965K9&%Y3V9-;VYT:"`Q,S$G*3L*8V]M<&%R92@G,C`P-3`Q,#8G
M+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`T+"`Q+"`R,#`U*2P@
M)TY7965K9&%Y3V9-;VYT:"`Q-#$G*3L*8V]M<&%R92@G,C`P-3`Q,#<G+"!$
M871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`U+"`Q+"`R,#`U*2P@)TY7
M965K9&%Y3V9-;VYT:"`Q-3$G*3L*"F-O;7!A<F4H)S(P,#4P,3`X)RP@1&%T
M95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G-B<L("<P,2<L("<R,#`U
M)RDL("=.5V5E:V1A>4]F36]N=&@@,C8Q)RD["F-O;7!A<F4H)S(P,#4P,3`Y
M)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G,"<L("<P,2<L
M("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C`Q)RD["F-O;7!A<F4H)S(P
M,#4P,3$P)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G,2<L
M("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C$Q)RD["F-O;7!A
M<F4H)S(P,#4P,3$Q)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G
M+"`G,B<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C(Q)RD[
M"F-O;7!A<F4H)S(P,#4P,3$R)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N
M=&@H)S(G+"`G,R<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@
M,C,Q)RD["F-O;7!A<F4H)S(P,#4P,3$S)RP@1&%T95]#86QC.CI.5V5E:V1A
M>4]F36]N=&@H)S(G+"`G-"<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F
M36]N=&@@,C0Q)RD["F-O;7!A<F4H)S(P,#4P,3$T)RP@1&%T95]#86QC.CI.
M5V5E:V1A>4]F36]N=&@H)S(G+"`G-2<L("<P,2<L("<R,#`U)RDL("=.5V5E
M:V1A>4]F36]N=&@@,C4Q)RD["@IC;VUP87)E*"<R,#`U,#$S,2<L($1A=&5?
M0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,2P@,2P@,C`P-2DL("=.
M5V5E:V1A>4]F36]N=&@@;#$Q)RD["F-O;7!A<F4H)S(P,#4P,3,P)RP@1&%T
M95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`P+"`Q+"`R,#`U*2P@
M)TY7965K9&%Y3V9-;VYT:"!L,#$G*3L*8V]M<&%R92@G,C`P-3`Q,CDG+"!$
M871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#8L(#$L(#(P,#4I
M+"`G3E=E96MD87E/9DUO;G1H(&PV,2<I.PIC;VUP87)E*"<R,#`U,#$R."<L
M($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-2P@,2P@,C`P
M-2DL("=.5V5E:V1A>4]F36]N=&@@;#4Q)RD["F-O;7!A<F4H)S(P,#4P,3(W
M)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`T+"`Q+"`R
M,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-#$G*3L*8V]M<&%R92@G,C`P-3`Q
M,C8G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#,L(#$L
M(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PS,2<I.PIC;VUP87)E*"<R,#`U
M,#$R-2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,BP@
M,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#(Q)RD["@IC;VUP87)E*"<R
M,#`U,#,S,2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@
M-"P@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#0S)RD["F-O;7!A<F4H
M)S(P,#4P,S,P)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G
M+"`S+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,S,G*3L*8V]M<&%R
M92@G,C`P-3`S,CDG+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S
M="<L(#(L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PR,R<I.PIC;VUP
M87)E*"<R,#`U,#,R."<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L
M87-T)RP@,2P@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#$S)RD["F-O
M;7!A<F4H)S(P,#4P,S(W)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H
M)VQA<W0G+"`P+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,#,G*3L*
M8V]M<&%R92@G,C`P-3`S,C8G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT
M:"@G;&%S="<L(#8L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PV,R<I
M.PIC;VUP87)E*"<R,#`U,#,R-2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO
M;G1H*"=L87-T)RP@-2P@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#4S
M)RD["@H*8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII<U9A;&ED1&%T92@R
M.2P@,BP@,3DP,"DL("=I<U9A;&ED1&%T92`Q)RD["F-O;7!A<F4H=')U92P@
M1&%T95]#86QC.CII<U9A;&ED1&%T92@R.2P@,BP@,C`P,"DL("=I<U9A;&ED
M1&%T92`R)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<U9A;&ED1&%T
M92@G,CDG+"`G,#(G+"`G,C`P,"<I+"`G:7-686QI9$1A=&4@,B!S='(G*3L*
M"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-,96%P665A<B@Q.3`P*2P@
M)VES3&5A<%EE87(@,2<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-,
M96%P665A<B@Q.3DV*2P@)VES3&5A<%EE87(@,B<I.PIC;VUP87)E*'1R=64L
M($1A=&5?0V%L8SHZ:7-,96%P665A<B@R,#`P*2P@)VES3&5A<%EE87(@,R<I
M.PIC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES3&5A<%EE87(H,C`P,2DL
M("=I<TQE87!996%R(#0G*3L*8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII
M<TQE87!996%R*"<R,#`Q)RDL("=I<TQE87!996%R(#0@<W1R)RD["@IC;VUP
M87)E*&9A;'-E+"!$871E7T-A;&,Z.FES1G5T=7)E1&%T92@G,C(G+"`G,3$G
M+"`G,C`P,"<I+"`G:7-&=71U<F5$871E(#$@<W1R)RD["F-O;7!A<F4H9F%L
M<V4L($1A=&5?0V%L8SHZ:7-&=71U<F5$871E*#(R+"`Q,2P@,C`P,"DL("=I
M<T9U='5R941A=&4@,2<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-&
M=71U<F5$871E*#(R+"`Q,2P@9&%T92@G62<I("L@,2DL("=I<T9U='5R941A
M=&4@,B<I.PH*8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII<U!A<W1$871E
M*#(R+"`Q,2P@9&%T92@G62<I("L@,2DL("=I<U!A<W1$871E(#$G*3L*8V]M
M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES4&%S=$1A=&4H,C(L(#$Q+"`R,#`P
M*2P@)VES4&%S=$1A=&4@,B<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ
M:7-087-T1&%T92@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G:7-087-T1&%T92`R
M('-T<B<I.PH*8V]M<&%R92@Q,"P@1&%T95]#86QC.CID871E1&EF9B@R,BP@
M,3$L(#(P,#`L(#$R+"`Q,2P@,C`P,"DL("=D871E1&EF9B`Q)RD["F-O;7!A
M<F4H,3`L($1A=&5?0V%L8SHZ9&%T941I9F8H,3(L(#$Q+"`R,#`P+"`R,BP@
M,3$L(#(P,#`I+"`G9&%T941I9F8@,B<I.PIC;VUP87)E*#8Q+"!$871E7T-A
M;&,Z.F1A=&5$:69F*#(R+"`Q,2P@,C`P,"P@,C(L(#$L(#(P,#$I+"`G9&%T
M941I9F8@,R<I.PIC;VUP87)E*#8Q+"!$871E7T-A;&,Z.F1A=&5$:69F*"<R
M,B<L("<Q,2<L("<R,#`P)RP@)S(R)RP@)S`Q)RP@)S(P,#$G*2P@)V1A=&5$
M:69F(#,@<W1R)RD["@IC;VUP87)E*"TQ+"!$871E7T-A;&,Z.F-O;7!A<F5$
M871E<R@Q,BP@,3$L(#(P,#`L(#(R+"`Q,2P@,C`P,"DL("=C;VUP87)E1&%T
M97,@,2<I.PIC;VUP87)E*#`L($1A=&5?0V%L8SHZ8V]M<&%R941A=&5S*#(R
M+"`Q,2P@,C`P,"P@,C(L(#$Q+"`R,#`P*2P@)V-O;7!A<F5$871E<R`R)RD[
M"F-O;7!A<F4H,2P@1&%T95]#86QC.CIC;VUP87)E1&%T97,H,C(L(#$Q+"`R
M,#`P+"`Q,BP@,3$L(#(P,#`I+"`G8V]M<&%R941A=&5S(#,G*3L*8V]M<&%R
M92@Q+"!$871E7T-A;&,Z.F-O;7!A<F5$871E<R@G,C(G+"`G,3$G+"`G,C`P
M,"<L("<Q,B<L("<Q,2<L("<R,#`P)RDL("=C;VUP87)E1&%T97,@,R!S='(G
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E<W1U;FET+G!H<```````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<T,P`Q,#4Q-30S,3`U-P`P,C,Q,C``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(
M4"!V97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#4@($UA<G-H
M86QL(%)O8V@@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS92P@5&AA="!I
M<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H("`@("`@?`HO
M+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@
M?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@?"!P96%R+61E
M=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<G,Z($UA<G-H86QL(%)O8V@@/&UR;V-H0'!H<"YN
M970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=&5S='5N:70N<&AP
M+'8@,2XR(#(P,#4O,3$O,34@,#`Z,38Z-#`@<&%J;WEE($5X<"`D"@HO*BH*
M("H@1&ES<&QA>7,@86QL('1E<W0@8V%S97,@;VX@=&AE('-A;64@<&%G90H@
M*@H@*B!`<&%C:V%G92!$871E"B`J($!A=71H;W(@36%R<VAA;&P@4F]C:"`\
M;7)O8VA`<&AP+FYE=#X*("HO"@H*96-H;R`B/'!R93XB.PIR97%U:7)E7V]N
M8V4@)U!(4%5N:70N<&AP)SL*<F5Q=6ER95]O;F-E("=T97-T=6YI=%]D871E
M+G!H<"<["G)E<75I<F5?;VYC92`G=&5S='5N:71?9&%T95]S<&%N+G!H<"<[
M"F5C:&\@(CPO<')E/B(["C\^"@``````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O
M=&5S=',O=&5S='5N:71?9&%T92YP:'``````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P
M,#4T`#$P-3$U-#,Q,#4W`#`R-#$Q,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+R!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-O9G1T86)S=&]P/30@<VAI9G1W:61T:#TT.@HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S($UA<G-H86QL(%)O8V@@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE9"`@
M?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U<F-E
M+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@?"!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES=',N<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W(Z($UA<G-H86QL(%)O8V@@/&UR;V-H0'!H<"YN970^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z('1E<W1U;FET7V1A=&4N<&AP+'8@,2XS
M(#(P,#4O,3$O,34@,#`Z,38Z-#`@<&%J;WEE($5X<"`D"B\O"@IR97%U:7)E
M7V]N8V4@)T1A=&4N<&AP)SL*<F5Q=6ER95]O;F-E("=02%!5;FET+G!H<"<[
M"@IC;&%S<R!M>41A=&4@97AT96YD<R!$871E('L*("`@(&9U;F-T:6]N(&UY
M1&%T92@D9&%T92D*("`@('L*("`@("`@("`D=&AI<RT^1&%T92@D9&%T92D[
M"B`@("!]"GT*"B\J*@H@*B!497-T(&-A<V4@9F]R($1A=&4*("H*("H@0'!A
M8VMA9V4@1&%T90H@*B!`875T:&]R($UA<G-H86QL(%)O8V@@/&UR;V-H0'!H
M<"YN970^"B`J+PIC;&%S<R!$871E7U1E<W0@97AT96YD<R!02%!5;FET7U1E
M<W1#87-E('L*"B`@("!V87(@)'1I;64["@H@("`@9G5N8W1I;VX@1&%T95]4
M97-T*"1N86UE*0H@("`@>PH@("`@("`@("1T:&ES+3Y02%!5;FET7U1E<W1#
M87-E*"1N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!S9715<"@I"B`@("![
M"B`@("`@("`@)'1H:7,M/G1I;64@/2!N97<@1&%T92@B,C`P,RTQ,"TP-"`Q
M-#HP,SHR-"(I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E87)$;W=N*"D*("`@
M('L*("`@("`@("!U;G-E="@D=&AI<RT^=&EM92D["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5S=$1A=&5.=6QL*"D*("`@('L*("`@("`@("`D=&EM92`](&YE
M=R!$871E*"D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@
M("`@("`@9&%T92@G62UM+60@2#II.G,G*2P*("`@("`@("`@("`@<W!R:6YT
M9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@
M("`@("`@)'1I;64M/GEE87(L("1T:6UE+3YM;VYT:"P@)'1I;64M/F1A>2P*
M("`@("`@("`@("`@("`@("1T:6UE+3YH;W5R+"`D=&EM92T^;6EN=71E+"`D
M=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&5S=$%B<W1R86-T:6]N*"D*("`@('L*("`@("`@("`D9"`](&YE=R!$871E
M*"D["B`@("`@("`@)&UY(#T@;F5W(&UY1&%T92@D9"D["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@D9"T^9V5T1&%T92@I+"1M>2T^9V5T1&%T92@I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1&%T94-O<'DH*0H@("`@>PH@
M("`@("`@("1T96UP(#T@;F5W($1A=&4H)'1H:7,M/G1I;64I.PH@("`@("`@
M("1T:&ES+3YA<W-E<G1%<75A;',H)'1E;7`L("1T:&ES+3YT:6UE*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!T97-T1&%T94E33R@I"B`@("!["B`@("`@("`@
M)'1E;7`@/2!N97<@1&%T92@B,C`P,RTQ,"TP-"`Q-#HP,SHR-"(I.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P
M+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D
M+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1E;7`M
M/GEE87(L("1T96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*("`@("`@("`@("`@
M("`@("1T96UP+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D=&5M<"T^<V5C;VYD
M*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$1A=&5)4T]"
M87-I8R@I"B`@("!["B`@("`@("`@)'1E;7`@/2!N97<@1&%T92@B,C`P,S$P
M,#14,30P,S(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@
M("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@("!S
M<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@
M("`@("`@("`@("`D=&5M<"T^>65A<BP@)'1E;7`M/FUO;G1H+"`D=&5M<"T^
M9&%Y+`H@("`@("`@("`@("`@("`@)'1E;7`M/FAO=7(L("1T96UP+3YM:6YU
M=&4L("1T96UP+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!T97-T1&%T94E33T5X=&5N9&5D*"D*("`@('L*("`@("`@("`D=&5M
M<"`](&YE=R!$871E*"(R,#`S+3$P+3`T5#$T.C`S.C(T(BD["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@
M,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R
M9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&5M<"T^>65A
M<BP@)'1E;7`M/FUO;G1H+"`D=&5M<"T^9&%Y+`H@("`@("`@("`@("`@("`@
M)'1E;7`M/FAO=7(L("1T96UP+3YM:6YU=&4L("1T96UP+3YS96-O;F0I"B`@
M("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1&%T94E33U1I;65S
M=&%M<"@I"B`@("!["B`@("`@("`@)'1E;7`@/2!N97<@1&%T92@B,C`P,S$P
M,#0Q-#`S,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@
M("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P
M<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@
M("`@("`@("`@("1T96UP+3YY96%R+"`D=&5M<"T^;6]N=&@L("1T96UP+3YD
M87DL"B`@("`@("`@("`@("`@("`D=&5M<"T^:&]U<BP@)'1E;7`M/FUI;G5T
M92P@)'1E;7`M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W1$871E56YI>'1I;64H*0H@("`@>PH@("`@("`@("1T96UP(#T@
M;F5W($1A=&4H<W1R=&]T:6UE*"(R,#`S+3$P+3`T(#$T.C`S.C(T(BDI.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S
M+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE
M,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1E
M;7`M/GEE87(L("1T96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*("`@("`@("`@
M("`@("`@("1T96UP+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D=&5M<"T^<V5C
M;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E=$1A
M=&5)4T\H*0H@("`@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971$871E*"(R
M,#`S+3$P+3`T(#$T.C`S.C(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q
M=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@
M("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R
M9"<L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^>65A<BP@)'1H:7,M
M/G1I;64M/FUO;G1H+"`D=&AI<RT^=&EM92T^9&%Y+`H@("`@("`@("`@("`@
M("`@)'1H:7,M/G1I;64M/FAO=7(L("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T
M:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!T97-T4V5T1&%T94E33T)A<VEC*"D*("`@('L*("`@("`@("`D=&AI
M<RT^=&EM92T^<V5T1&%T92@B,C`P,S$P,#14,30P,S(T(BD["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@
M,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R
M9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM
M92T^>65A<BP@)'1H:7,M/G1I;64M/FUO;G1H+"`D=&AI<RT^=&EM92T^9&%Y
M+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FAO=7(L("1T:&ES+3YT
M:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1&%T94E33T5X=&5N9&5D*"D*
M("`@('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T1&%T92@B,C`P,RTQ,"TP
M-%0Q-#HP,SHR-"(I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@
M("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@
M<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@
M("`@("`@("`@("`@)'1H:7,M/G1I;64M/GEE87(L("1T:&ES+3YT:6UE+3YM
M;VYT:"P@)'1H:7,M/G1I;64M/F1A>2P*("`@("`@("`@("`@("`@("1T:&ES
M+3YT:6UE+3YH;W5R+"`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM
M92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S
M=%-E=$1A=&54:6UE<W1A;7`H*0H@("`@>PH@("`@("`@("1T:&ES+3YT:6UE
M+3YS971$871E*"(R,#`S,3`P-#$T,#,R-"(I.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T
M)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE
M,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/GEE87(L
M("1T:&ES+3YT:6UE+3YM;VYT:"P@)'1H:7,M/G1I;64M/F1A>2P*("`@("`@
M("`@("`@("`@("1T:&ES+3YT:6UE+3YH;W5R+"`D=&AI<RT^=&EM92T^;6EN
M=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@
M("`@9G5N8W1I;VX@=&5S=%-E=$1A=&55;FEX=&EM92@I"B`@("!["B`@("`@
M("`@)'1H:7,M/G1I;64M/G-E=$1A=&4H<W1R=&]T:6UE*"(R,#`S+3$P+3`T
M(#$T.C`S.C(T(BDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@
M("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@
M<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@
M("`@("`@("`@("`@)'1H:7,M/G1I;64M/GEE87(L("1T:&ES+3YT:6UE+3YM
M;VYT:"P@)'1H:7,M/G1I;64M/F1A>2P*("`@("`@("`@("`@("`@("1T:&ES
M+3YT:6UE+3YH;W5R+"`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM
M92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S
M=$=E=$1A=&5)4T\H*0H@("`@>PH@("`@("`@("1D871E(#T@)'1H:7,M/G1I
M;64M/F=E=$1A=&4H1$%415]&3U)-051?25-/*3L*("`@("`@("`D=&AI<RT^
M87-S97)T17%U86QS*"<R,#`S+3$P+3`T(#$T.C`S.C(T)RP@)&1A=&4I.PH@
M("`@?0H*("`@(&9U;F-T:6]N('1E<W1'971$871E25-/0F%S:6,H*0H@("`@
M>PH@("`@("`@("1D871E(#T@)'1H:7,M/G1I;64M/F=E=$1A=&4H1$%415]&
M3U)-051?25-/7T)!4TE#*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*"<R,#`S,3`P-%0Q-#`S,C1:)RP@)&1A=&4I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W1'971$871E25-/17AT96YD960H*0H@("`@>PH@("`@("`@("1D
M871E(#T@)'1H:7,M/G1I;64M/F=E=$1A=&4H1$%415]&3U)-051?25-/7T58
M5$5.1$5$*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<R,#`S+3$P
M+3`T5#$T.C`S.C(T6B<L("1D871E*3L*("`@('T*"B`@("!F=6YC=&EO;B!T
M97-T1V5T1&%T951I;65S=&%M<"@I"B`@("!["B`@("`@("`@)&1A=&4@/2`D
M=&AI<RT^=&EM92T^9V5T1&%T92A$051%7T9/4DU!5%]424U%4U1!35`I.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S(P,#,Q,#`T,30P,S(T)RP@
M)&1A=&4I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1'971$871E56YI>'1I
M;64H*0H@("`@>PH@("`@("`@("1D871E(#T@)'1H:7,M/G1I;64M/F=E=$1A
M=&4H1$%415]&3U)-051?54Y)6%1)344I.PH@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H<W1R=&]T:6UE*"<R,#`S+3$P+3`T(#$T.C`S.C(T)RDL("1D
M871E*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1F]R;6%T*"D*("`@('L*
M("`@("`@("`D8V]D97,@/2!A<G)A>2@*("`@("`@("`@("`@)V$G(#T^("=3
M870G+`H@("`@("`@("`@("`G02<@/3X@)U-A='5R9&%Y)RP*("`@("`@("`@
M("`@)V(G(#T^("=/8W0G+`H@("`@("`@("`@("`G0B<@/3X@)T]C=&]B97(G
M+`H@("`@("`@("`@("`G0R<@/3X@)S(P)RP*("`@("`@("`@("`@)V0G(#T^
M("<P-"<L"B`@("`@("`@("`@("=$)R`]/B`G,3`O,#0O,C`P,R<L"B`@("`@
M("`@("`@("=E)R`]/B`G-"<L"B`@("`@("`@("`@("=()R`]/B`G,30G+`H@
M("`@("`@("`@("`G22<@/3X@)S`R)RP*("`@("`@("`@("`@)VHG(#T^("<R
M-S<G+`H@("`@("`@("`@("`G;2<@/3X@)S$P)RP*("`@("`@("`@("`@)TTG
M(#T^("<P,R<L"B`@("`@("`@("`@("=N)R`]/B`B7&XB+`H@("`@("`@("`@
M("`G3R<@/3X@)RLP,#HP,"<L"B`@("`@("`@("`@("=O)R`]/B`G*S`P.C`P
M)RP*("`@("`@("`@("`@)W`G(#T^("=P;2<L"B`@("`@("`@("`@("=0)R`]
M/B`G4$TG+`H@("`@("`@("`@("`G<B<@/3X@)S`R.C`S.C(T(%!-)RP*("`@
M("`@("`@("`@)U(G(#T^("<Q-#HP,R<L"B`@("`@("`@("`@("=3)R`]/B`G
M,C0G+`H@("`@("`@("`@("`G="<@/3X@(EQT(BP*("`@("`@("`@("`@)U0G
M(#T^("<Q-#HP,SHR-"<L"B`@("`@("`@("`@("=W)R`]/B`G-B<L"B`@("`@
M("`@("`@("=5)R`]/B`G-#`G+`H@("`@("`@("`@("`G>2<@/3X@)S`S)RP*
M("`@("`@("`@("`@)UDG(#T^("<R,#`S)RP*("`@("`@("`@("`@)R4G(#T^
M("<E)PH@("`@("`@("D["@H@("`@("`@(&9O<F5A8V@@*"1C;V1E<R!A<R`D
M8V]D92`]/B`D97AP96-T960I('L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@*("`@("`@("`@("`@("`@("(D8V]D93H@)&5X<&5C=&5D(BP@
M)'1H:7,M/G1I;64M/F9O<FUA="@B)&-O9&4Z("4D8V]D92(I"B`@("`@("`@
M("`@("D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('1E<W14;U54
M0V)Y3V9F<V5T*"D*("`@('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T5%IB
M>4E$*"=%4U0G*3L*("`@("`@("`D=&AI<RT^=&EM92T^=&]55$,H*3L*("`@
M("`@("`D=&5M<"`](&YE=R!$871E*"(R,#`S+3$P+3`T(#$T.C`S.C(T(BD[
M"B`@("`@("`@)'1E;7`M/G1O551#8GE/9F9S970H(BTP-3HP,"(I.PH*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T96UP+"`D=&AI<RT^=&EM92D[
M"B`@("!]"@I]"@HO+R!R=6YS('1H92!T97-T<PHD<W5I=&4@/2!N97<@4$A0
M56YI=%]497-T4W5I=&4H(D1A=&5?5&5S="(I.PHD<F5S=6QT(#T@4$A056YI
M=#HZ<G5N*"1S=6ET92D["B\O('!R:6YT<R!T:&4@=&5S=',*96-H;R`D<F5S
M=6QT+3YT;U-T<FEN9R@I.PH*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S
M='5N:71?9&%T95]S<&%N+G!H<```````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-S<U`#$P-3$U
M-#,Q,#4W`#`R-3$T-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y
M.3<M,C`P,R!,96%N9')O($QU8V%R96QL82`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@3F5W($)31"!L
M:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@?"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE('1H
M<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI
M8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!,96%N9')O($QU8V%R
M96QL82`\;&QU8V%X0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!T97-T=6YI=%]D871E7W-P86XN<&AP+'8@,2XT(#(P,#4O,3$O,34@,#`Z
M,38Z-#`@<&%J;WEE($5X<"`D"B\O"@IR97%U:7)E7V]N8V4@)T1A=&4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=$871E+U-P86XN<&AP)SL*<F5Q=6ER95]O;F-E
M("=02%!5;FET+G!H<"<["@HO*BH*("H@5&5S="!C87-E(&9O<B!$871E7U-P
M86X*("H*("H@0'!A8VMA9V4@1&%T90H@*B!`875T:&]R($QE86YD<F\@3'5C
M87)E;&QA(#QL;'5C87A`<&AP+FYE=#X*("HO"F-L87-S($1A=&5?4W!A;E1E
M<W0@97AT96YD<R!02%!5;FET7U1E<W1#87-E('L*"B`@("!V87(@)'1I;64[
M"@H@("`@9G5N8W1I;VX@1&%T95]3<&%N5&5S="@D;F%M92D@>PH@("`@("`@
M("1T:&ES+3Y02%!5;FET7U1E<W1#87-E*"1N86UE*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!S9715<"@I('L*("`@("`@("`D=&AI<RT^=&EM92`](&YE=R!$
M871E7U-P86XH.3<U,S$I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E87)$;W=N
M*"D@>PH@("`@("`@('5N<V5T*"1T:&ES+3YT:6UE*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!T97-T4V5T1G)O;4%R<F%Y*"D@>PH@("`@("`@("1T:&ES+3YT
M:6UE+3YS971&<F]M07)R87DH87)R87DH-2P@-#@N-2P@,C@N-2P@,S$I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G-SHP
M.C4Y.C$G+`H@("`@("`@("`@("!S<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T
M:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH;W5R+`H@("`@("`@("`@
M("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N
M9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13971&<F]M
M4W1R:6YG*"D@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971&<F]M4W1R:6YG
M*"<U.C`P.C4Y.C,Q)RD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*
M("`@("`@("`@("`@)S4Z,#HU.3HS,2<L"B`@("`@("`@("`@('-P<FEN=&8H
M)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I;64M
M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E+"`D
M=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5S=%-E=$9R;VU396-O;F1S*"D@>PH@("`@("`@("1T:&ES+3YT
M:6UE+3YS971&<F]M4V5C;VYD<R@T,S0S-#0I.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H"B`@("`@("`@("`@("<U.C`Z,SDZ-"<L"B`@("`@("`@
M("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@
M)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM
M92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@
M("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E=$9R;VU-:6YU=&5S*"D@>PH@("`@
M("`@("1T:&ES+3YT:6UE+3YS971&<F]M36EN=71E<R@W.#8P+C`Q-C8V-C8V
M-C8I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@
M("<U.C$Q.C`Z,2<L"B`@("`@("`@("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D
M)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@
M("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^
M<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E
M=$9R;VU(;W5R<R@I('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T1G)O;4AO
M=7)S*#4P+C$R,S0U*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@
M("`@("`@("`@("`G,CHR.C<Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E
M9#HE9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH
M;W5R+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H
M:7,M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W13971&<F]M1&%Y<R@I('L*("`@("`@("`D=&AI<RT^=&EM92T^
M<V5T1G)O;41A>7,H<&DH*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@*("`@("`@("`@("`@)S,Z,SHR,SHU-"<L"B`@("`@("`@("`@('-P<FEN
M=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I
M;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E
M+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@
M9G5N8W1I;VX@=&5S=%-E=$9R;VU$871E1&EF9B@I('L*("`@("`@("`D=&AI
M<RT^=&EM92T^<V5T1G)O;41A=&5$:69F*`H@("`@("`@("`@("!N97<@1&%T
M92@G,C`P-"TP,RTQ,"`P,3HQ-3HU.2<I+`H@("`@("`@("`@("!N97<@1&%T
M92@G,C`P,RTP,RTQ,"`P,#HQ,#HU,"<I"B`@("`@("`@*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,S8V.C$Z-3HY)RP*
M("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM
M92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@("1T
M:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@
M("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T0V]P>2@I('L*("`@("`@
M("`D=&EM92`](&YE=R!$871E7U-P86XH*3L*("`@("`@("`D=&EM92T^8V]P
M>2@D=&AI<RT^=&EM92D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*
M("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM
M92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@("1T
M:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I+`H@("`@
M("`@("`@("!S<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T:6UE+3YD87DL("1T
M:6UE+3YH;W5R+`H@("`@("`@("`@("`@("`@)'1I;64M/FUI;G5T92P@)'1I
M;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E
M<W1&;W)M870H*2!["B`@("`@("`@)&-O9&5S(#T@87)R87DH"B`@("`@("`@
M("`@("=#)R`]/B`G,2P@,#,Z,#4Z,S$G+`H@("`@("`@("`@("`G9"<@/3X@
M)S$N,3(X.#,Q,#$X-3$X-2<L"B`@("`@("`@("`@("=$)R`]/B`G,2<L"B`@
M("`@("`@("`@("=E)R`]/B`G,C<N,#DQ.30T-#0T-#0T)RP*("`@("`@("`@
M("`@)V8G(#T^("<Q-C(U+C4Q-C8V-C8V-C<G+`H@("`@("`@("`@("`G9R<@
M/3X@)SDW-3,Q)RP*("`@("`@("`@("`@)V@G(#T^("<S)RP*("`@("`@("`@
M("`@)T@G(#T^("<P,R<L"B`@("`@("`@("`@("=I)R`]/B`G,R<L"B`@("`@
M("`@("`@("=))R`]/B`G,#,G+`H@("`@("`@("`@("`G;2<@/3X@)S4G+`H@
M("`@("`@("`@("`G32<@/3X@)S`U)RP*("`@("`@("`@("`@)VXG(#T^(")<
M;B(L"B`@("`@("`@("`@("=P)R`]/B`G86TG+`H@("`@("`@("`@("`G4"<@
M/3X@)T%-)RP*("`@("`@("`@("`@)W(G(#T^("<P,SHP-3HS,2!A;2<L"B`@
M("`@("`@("`@("=2)R`]/B`G,#,Z,#4G+`H@("`@("`@("`@("`G<R<@/3X@
M)S,Q)RP*("`@("`@("`@("`@)U,G(#T^("<S,2<L"B`@("`@("`@("`@("=T
M)R`]/B`B7'0B+`H@("`@("`@("`@("`G5"<@/3X@)S`S.C`U.C,Q)RP*("`@
M("`@("`@("`@)R4G(#T^("<E)RP*("`@("`@("`I.PH@("`@("`@(&9O<F5A
M8V@@*"1C;V1E<R!A<R`D8V]D92`]/B`D97AP96-T960I('L*("`@("`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@("`@("(D8V]D
M93H@)&5X<&5C=&5D(BP@)'1H:7,M/G1I;64M/F9O<FUA="@B)&-O9&4Z("4D
M8V]D92(I"B`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N('1E<W1!9&0H*2!["B`@("`@("`@)'1H:7,M/G1I;64M/F%D9"AN
M97<@1&%T95]3<&%N*#8P,#`I*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/G1I;64M/G1O4V5C;VYD<R@I.PH@("`@("`@("1E>'!E8W1E9"`](#$P,S4S
M,3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1E>'!E8W1E9"P@)')E
M<W5L="D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-U8G1R86-T*"D@>PH@
M("`@("`@("1T:&ES+3YT:6UE+3YS=6)T<F%C="AN97<@1&%T95]3<&%N*#8P
M,#`I*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G1I;64M/G1O4V5C;VYD
M<R@I.PH@("`@("`@("1E>'!E8W1E9"`](#DQ-3,Q.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)&5X<&5C=&5D+"`D<F5S=6QT*3L*("`@('T*"GT*
M"B\O(')U;G,@=&AE('1E<W1S"B1S=6ET92`](&YE=R!02%!5;FET7U1E<W13
M=6ET92@B1&%T95]3<&%N5&5S="(I.PHD<F5S=6QT(#T@4$A056YI=#HZ<G5N
M*"1S=6ET92D["B\O('!R:6YT<R!T:&4@=&5S=',*96-H;R`D<F5S=6QT+3YT
M;U-T<FEN9R@I.PH*/SX*````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S=%]C86QC+G!H<```````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-#(T`#$P-3$U-#,Q,#4W`#`R,S$W-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`IR97%U
M:7)E7V]N8V4@(D1A=&4O0V%L8RYP:'`B.PH*+RHJ"B`J(%1E<W0@9&%T97,@
M9G)O;2`Q.3<P('1O(#(P,CD*("H@1&%T82!F<F]M.B!H='1P.B\O=W=W+FUE
M<FQY;BYD96UO;BYC;RYU:R]W:VYO=&5S="YT>'0*("H@3W1H97)S('5S969U
M;&P@9&%T87,@879A:6QA8FQE(&9R;VTZ"B`J(&AT='`Z+R]W=W<N;65R;'EN
M+F1E;6]N+F-O+G5K+R-D870*("HO"B1F86EL961?=&5S=%]D871A("`@/2!F
M86QS93L*)'=K;F\@("`](&9I;&4H)W=K;F]T97-T+G1X="<I.PHD8VYT("`@
M(#T@<VEZ96]F*"1W:VYO*3L*9F]R*"`D:3TP.R1I/"1C;G0[)&DK*R`I>PH@
M("`@)'!A<G1S("`@("`@/2!E>'!L;V1E*"<Z)RPD=VMN;ULD:5TI.PH@("`@
M)'=E96MS;F];)'!A<G1S6S!=72`]('-T<E]R97!L86-E*")<;B(L)R<L)'!A
M<G1S6S%=*3L*?0IU;G-E="@D=VMN;RD["F9O<F5A8V@H)'=E96MS;F\@87,@
M)&1A=&4]/B1I<V\I>PH@("`@)'EE87(@("`@("`@/2!S=6)S='(H)&1A=&4L
M,"PT*3L*("`@("1M;VYT:"`@("`@(#T@<W5B<W1R*"1D871E+#0L,BD["B`@
M("`D9&%Y("`@("`@("`]('-U8G-T<B@D9&%T92PV*3L*("`@("1I<V\Y-C`Q
M(#T@1&%T95]#86QC.CIG<F5G;W)I86Y4;TE33R@D9&%Y+"1M;VYT:"PD>65A
M<BD["B`@("!I9B@D:7-O.38P,2$])&ES;RE["B`@("`@("`@)&9A:6QE9%]T
M97-T7V1A=&$@("`]('1R=64["B`@("`@("`@96-H;R`D9&%T92`N("<H)R`N
M("1I<V\@+B`G*2`]/B<@+B`D>65A<BXG+2<N)&UO;G1H+B<M)RXD9&%Y("XG
M/3XG("X@)&ES;SDV,#$@+B`B(#H@9F%I;&5D7&XB.PH@("`@?0I]"@HO*BH*
M("H@0G5G<R`C,3DW.#@*("HO"B1F86EL961?=&5S=%\Q.3<X."`@/2!F86QS
M93L*)'!A<W,Q("`](#(]/41A=&5?0V%L8SHZ=V5E:T]F665A<B@U+#$L,3DY
M."D_=')U93IF86QS93L*)'!A<W,R("`](#(]/41A=&5?0V%L8SHZ=V5E:T]F
M665A<B@V+#$L,3DY."D_=')U93IF86QS93L*)'!A<W,S("`](#(]/41A=&5?
M0V%L8SHZ=V5E:T]F665A<B@U+#$L,C`P-"D_=')U93IF86QS93L*)'!A<W,T
M("`](#(]/41A=&5?0V%L8SHZ=V5E:T]F665A<B@V+#$L,C`P-"D_=')U93IF
M86QS93L*:68H("$H)'!A<W,Q("8F("1P87-S,B`F)B`D<&%S<S,@)B8@)'!A
M<W,T*2`I>PH@("`@)&9A:6QE9%]T97-T7S$Y-S@X("`@/2!T<G5E.PI]"@II
M9B@D9F%I;&5D7W1E<W1?,3DW.#@@?'P@)&9A:6QE9%]T97-T7V1A=&$I>PH@
M("`@96-H;R`B0G5G(",Q.3<X.#H@9F%I;&5D7&XB.PI](&5L<V4@>PH@("`@
M96-H;R`B0G5G(",Q.3<X.#H@3TM<;B(["GT*/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T
M97-T7V1A=&5?;65T:&]D<U]S<&%N+G!H<```````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4R,S<`,3`U
M,34T,S$P-3<`,#(U-S8R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`U("!,96%N9')O($QU8V%R96QL82`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('1H92!.97<@0E-$
M(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@=V]R;&0M=VED92UW96(@870@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!N97<@0E-$;&EC96YS92!A
M;F0@87)E('5N86)L92`@('P*+R\@?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("!\"B\O('P@<&5A<BUD979`;&ES=',N<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($QE86YD<F\@3'5C
M87)E;&QA(#QL;'5C87A`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D
M260Z('1E<W1?9&%T95]M971H;V1S7W-P86XN<&AP+'8@,2XR(#(P,#4O,3$O
M,34@,#`Z,38Z-#`@<&%J;WEE($5X<"`D"B\O"@H*<F5Q=6ER95]O;F-E("=$
M871E+G!H<"<["G)E<75I<F5?;VYC92`G1&%T92]3<&%N+G!H<"<["@HD9&%T
M92`](&YE=R!$871E*"D["B1T;7`@/2!N97<@1&%T92@D9&%T92D["@IP<FEN
M=&8H(D%C='5A;"!D871E.B`E<UQN(BP@)&1A=&4M/F=E=$1A=&4H1$%415]&
M3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^<W5B=')A
M8W13<&%N*&YE=R!$871E7U-P86XH)S`Z,#`Z,#`Z,#4G*2D["G!R:6YT9B@B
M4W5B=')A8W1I;F<@-2!S96-O;F1S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$
M051%7T9/4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YS
M=6)T<F%C=%-P86XH;F5W($1A=&5?4W!A;B@G,#HP,#HR,#HP,"<I*3L*<')I
M;G1F*")3=6)T<F%C=&EN9R`R,"!M:6YU=&5S.B`E<UQN(BP@)'1M<"T^9V5T
M1&%T92A$051%7T9/4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD
M=&UP+3YS=6)T<F%C=%-P86XH;F5W($1A=&5?4W!A;B@G,#HQ,#HP,#HP,"<I
M*3L*<')I;G1F*")3=6)T<F%C=&EN9R`Q,"!H;W5R<SH@)7-<;B(L("1T;7`M
M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E
M*3L*)'1M<"T^<W5B=')A8W13<&%N*&YE=R!$871E7U-P86XH)S,Z,#`Z,#`Z
M,#`G*2D["G!R:6YT9B@B4W5B=')A8W1I;F<@,R!D87ES.B`E<UQN(BP@)'1M
M<"T^9V5T1&%T92A$051%7T9/4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A
M=&4I.PHD=&UP+3YS=6)T<F%C=%-P86XH;F5W($1A=&5?4W!A;B@G,SHQ,#HR
M,#HP-2<I*3L*<')I;G1F*")3=6)T<F%C=&EN9R`S(&1A>7,L(#$P(&AO=7)S
M+"`R,"!M:6YU=&5S(&%N9"`U('-E8V]N9',Z("5S7&XB+"`D=&UP+3YG971$
M871E*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T
M;7`M/F%D9%-P86XH;F5W($1A=&5?4W!A;B@G,#HP,#HP,#HP-2<I*3L*<')I
M;G1F*")!9&1I;F<@-2!S96-O;F1S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$
M051%7T9/4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YA
M9&13<&%N*&YE=R!$871E7U-P86XH)S`Z,#`Z,C`Z,#`G*2D["G!R:6YT9B@B
M061D:6YG(#(P(&UI;G5T97,Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?
M1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/F%D9%-P
M86XH;F5W($1A=&5?4W!A;B@G,#HQ,#HP,#HP,"<I*3L*<')I;G1F*")!9&1I
M;F<@,3`@:&]U<G,Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%4
M7TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/F%D9%-P86XH;F5W
M($1A=&5?4W!A;B@G,SHP,#HP,#HP,"<I*3L*<')I;G1F*")!9&1I;F<@,R!D
M87ES.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$051%7T9/4DU!5%])4T\I*3L*
M"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YA9&13<&%N*&YE=R!$871E7U-P
M86XH)S,Z,3`Z,C`Z,#4G*2D["G!R:6YT9B@B061D:6YG(#,@9&%Y<RP@,3`@
M:&]U<G,L(#(P(&UI;G5T97,@86YD(#4@<V5C;VYD<SH@)7-<;B(L("1T;7`M
M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@H_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W=E96MS:6YM;VYT:%\T7VUO
M;F1A>2YT>'0````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(V-``Q,#4Q-30S,3`U-P`P,C4U-S(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````,3DY
M.2\R+S0*,C`Q,"\R+S0*,C`R,2\R+S0*,C`R-R\R+S0*,3DS-R\R+S0*,3DT
M,R\R+S0*,3@P,B\R+S0*,3@Q,R\R+S0*,3@Q.2\R+S0*,3@S,"\R+S0*,3@T
M,2\R+S0*,3@T-R\R+S0*,3@U."\R+S0*,3@V.2\R+S0*,3@W-2\R+S0*,3@X
M-B\R+S0*,3@Y-R\R+S0*,3DP.2\R+S0*,3DQ-2\R+S0*,3DR-B\R+S0*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N=&A?-%]S=6YD87DN='AT````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`R-C0`,3`U,34T,S$P-3<`,#(U-C`V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#(P,#DO,B\T"C(P,34O
M,B\T"C(P,C8O,B\T"C(P,S<O,B\T"C$Y,S$O,B\T"C$Y-#(O,B\T"C$X,#$O
M,B\T"C$X,#<O,B\T"C$X,3@O,B\T"C$X,CDO,B\T"C$X,S4O,B\T"C$X-#8O
M,B\T"C$X-3<O,B\T"C$X-C,O,B\T"C$X-S0O,B\T"C$X.#4O,B\T"C$X.3$O
M,B\T"C$Y,#,O,B\T"C$Y,30O,B\T"C$Y,C4O,B\T"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O
M=&5S=',O=V5E:W-I;FUO;G1H7W)D;5]M;VYD87DN='AT````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W
M,C$V`#$P-3$U-#,Q,#4W`#`R-C(Q-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````Q.3DY+S@O-@HR,#`P+S$P+S8*,C`P,2\Q
M,B\V"C(P,#(O,3(O-@HR,#`S+S8O-@HR,#`T+S@O-@HR,#`U+S$P+S8*,C`P
M-B\Q,"\V"C(P,#<O,3(O-@HR,#`X+S8O-@HR,#`Y+S$Q+S8*,C`Q,"\X+S8*
M,C`Q,2\Q,"\V"C(P,3(O,3(O-@HR,#$S+S$R+S8*,C`Q-"\V+S8*,C`Q-2\Q
M,2\V"C(P,38O,3`O-@HR,#$W+S$P+S8*,C`Q."\Q,B\V"C(P,3DO,3(O-@HR
M,#(P+S$Q+S8*,C`R,2\X+S8*,C`R,B\Q,"\V"C(P,C,O,3`O-@HR,#(T+S$R
M+S8*,C`R-2\V+S8*,C`R-B\Q,2\V"C(P,C<O."\V"C(P,C@O,3`O-@HR,#(Y
M+S$R+S8*,C`S,"\Q,B\V"C(P,S$O-B\V"C(P,S(O."\V"C(P,S,O,3`O-@HR
M,#,T+S$P+S8*,C`S-2\Q,B\V"C(P,S8O-B\V"C(P,S<O,3$O-@HQ.3,P+S8O
M-@HQ.3,Q+S$Q+S8*,3DS,B\Q,"\V"C$Y,S,O,3`O-@HQ.3,T+S$R+S8*,3DS
M-2\Q,B\V"C$Y,S8O,3$O-@HQ.3,W+S@O-@HQ.3,X+S$P+S8*,3DS.2\Q,"\V
M"C$Y-#`O,3(O-@HQ.30Q+S8O-@HQ.30R+S$Q+S8*,3DT,R\X+S8*,3DT-"\Q
M,"\V"C$Y-#4O,3(O-@HQ.30V+S$R+S8*,3DT-R\V+S8*,3DT."\X+S8*,3DT
M.2\Q,"\V"C$X,#`O-B\V"C$X,#$O,3$O-@HQ.#`R+S@O-@HQ.#`S+S$P+S8*
M,3@P-"\Q,B\V"C$X,#4O,3(O-@HQ.#`V+S8O-@HQ.#`W+S$Q+S8*,3@P."\Q
M,"\V"C$X,#DO,3`O-@HQ.#$P+S$R+S8*,3@Q,2\Q,B\V"C$X,3(O,3$O-@HQ
M.#$S+S@O-@HQ.#$T+S$P+S8*,3@Q-2\Q,"\V"C$X,38O,3(O-@HQ.#$W+S8O
M-@HQ.#$X+S$Q+S8*,3@Q.2\X+S8*,3@R,"\Q,"\V"C$X,C$O,3(O-@HQ.#(R
M+S$R+S8*,3@R,R\V+S8*,3@R-"\X+S8*,3@R-2\Q,"\V"C$X,C8O,3`O-@HQ
M.#(W+S$R+S8*,3@R."\V+S8*,3@R.2\Q,2\V"C$X,S`O."\V"C$X,S$O,3`O
M-@HQ.#,R+S$R+S8*,3@S,R\Q,B\V"C$X,S0O-B\V"C$X,S4O,3$O-@HQ.#,V
M+S$P+S8*,3@S-R\Q,"\V"C$X,S@O,3(O-@HQ.#,Y+S$R+S8*,3@T,"\Q,2\V
M"C$X-#$O."\V"C$X-#(O,3`O-@HQ.#0S+S$P+S8*,3@T-"\Q,B\V"C$X-#4O
M-B\V"C$X-#8O,3$O-@HQ.#0W+S@O-@HQ.#0X+S$P+S8*,3@T.2\Q,B\V"C$X
M-3`O,3(O-@HQ.#4Q+S8O-@HQ.#4R+S@O-@HQ.#4S+S$P+S8*,3@U-"\Q,"\V
M"C$X-34O,3(O-@HQ.#4V+S8O-@HQ.#4W+S$Q+S8*,3@U."\X+S8*,3@U.2\Q
M,"\V"C$X-C`O,3(O-@HQ.#8Q+S$R+S8*,3@V,B\V+S8*,3@V,R\Q,2\V"C$X
M-C0O,3`O-@HQ.#8U+S$P+S8*,3@V-B\Q,B\V"C$X-C<O,3(O-@HQ.#8X+S$Q
M+S8*,3@V.2\X+S8*,3@W,"\Q,"\V"C$X-S$O,3`O-@HQ.#<R+S$R+S8*,3@W
M,R\V+S8*,3@W-"\Q,2\V"C$X-S4O."\V"C$X-S8O,3`O-@HQ.#<W+S$R+S8*
M,3@W."\Q,B\V"C$X-SDO-B\V"C$X.#`O."\V"C$X.#$O,3`O-@HQ.#@R+S$P
M+S8*,3@X,R\Q,B\V"C$X.#0O-B\V"C$X.#4O,3$O-@HQ.#@V+S@O-@HQ.#@W
M+S$P+S8*,3@X."\Q,B\V"C$X.#DO,3(O-@HQ.#DP+S8O-@HQ.#DQ+S$Q+S8*
M,3@Y,B\Q,"\V"C$X.3,O,3`O-@HQ.#DT+S$R+S8*,3@Y-2\Q,B\V"C$X.38O
M,3$O-@HQ.#DW+S@O-@HQ.#DX+S$P+S8*,3@Y.2\Q,"\V"C$Y,#`O,3(O-@HQ
M.3`Q+S$R+S8*,3DP,B\V+S8*,3DP,R\Q,2\V"C$Y,#0O,3`O-@HQ.3`U+S$P
M+S8*,3DP-B\Q,B\V"C$Y,#<O,3(O-@HQ.3`X+S$Q+S8*,3DP.2\X+S8*,3DQ
M,"\Q,"\V"C$Y,3$O,3`O-@HQ.3$R+S$R+S8*,3DQ,R\V+S8*,3DQ-"\Q,2\V
M"C$Y,34O."\V"C$Y,38O,3`O-@HQ.3$W+S$R+S8*,3DQ."\Q,B\V"C$Y,3DO
M-B\V"C$Y,C`O."\V"C$Y,C$O,3`O-@HQ.3(R+S$P+S8*,3DR,R\Q,B\V"C$Y
M,C0O-B\V"C$Y,C4O,3$O-@HQ.3(V+S@O-@HQ.3(W+S$P+S8*,3DR."\Q,B\V
M"C$Y,CDO,3(O-@HQ.3DY+S$R+S4*,C`P,"\Q,B\U"C(P,#$O,3$O-0HR,#`R
M+S$Q+S4*,C`P,R\Q,B\U"C(P,#0O,3(O-0HR,#`U+S$R+S4*,C`P-B\Q,B\U
M"C(P,#<O,3$O-0HR,#`X+S$R+S4*,C`P.2\Q,B\U"C(P,3`O,3(O-0HR,#$Q
M+S$R+S4*,C`Q,B\Q,2\U"C(P,3,O,3$O-0HR,#$T+S$R+S4*,C`Q-2\Q,B\U
M"C(P,38O,3(O-0HR,#$W+S$R+S4*,C`Q."\Q,2\U"C(P,3DO,3$O-0HR,#(P
M+S$R+S4*,C`R,2\Q,B\U"C(P,C(O,3(O-0HR,#(S+S$R+S4*,C`R-"\Q,2\U
M"C(P,C4O,3(O-0HR,#(V+S$R+S4*,C`R-R\Q,B\U"C(P,C@O,3(O-0HR,#(Y
M+S$Q+S4*,C`S,"\Q,2\U"C(P,S$O,3(O-0HR,#,R+S$R+S4*,C`S,R\Q,B\U
M"C(P,S0O,3(O-0HR,#,U+S$Q+S4*,C`S-B\Q,B\U"C(P,S<O,3(O-0HQ.3,P
M+S$R+S4*,3DS,2\Q,B\U"C$Y,S(O,3(O-0HQ.3,S+S$R+S4*,3DS-"\Q,2\U
M"C$Y,S4O,3$O-0HQ.3,V+S$R+S4*,3DS-R\Q,B\U"C$Y,S@O,3(O-0HQ.3,Y
M+S$R+S4*,3DT,"\Q,2\U"C$Y-#$O,3(O-0HQ.30R+S$R+S4*,3DT,R\Q,B\U
M"C$Y-#0O,3(O-0HQ.30U+S$Q+S4*,3DT-B\Q,2\U"C$Y-#<O,3(O-0HQ.30X
M+S$R+S4*,3DT.2\Q,B\U"C$X,#`O,3(O-0HQ.#`Q+S$R+S4*,3@P,B\Q,B\U
M"C$X,#,O,3(O-0HQ.#`T+S$Q+S4*,3@P-2\Q,2\U"C$X,#8O,3(O-0HQ.#`W
M+S$R+S4*,3@P."\Q,B\U"C$X,#DO,3(O-0HQ.#$P+S$Q+S4*,3@Q,2\Q,2\U
M"C$X,3(O,3(O-0HQ.#$S+S$R+S4*,3@Q-"\Q,B\U"C$X,34O,3(O-0HQ.#$V
M+S$Q+S4*,3@Q-R\Q,B\U"C$X,3@O,3(O-0HQ.#$Y+S$R+S4*,3@R,"\Q,B\U
M"C$X,C$O,3$O-0HQ.#(R+S$Q+S4*,3@R,R\Q,B\U"C$X,C0O,3(O-0HQ.#(U
M+S$R+S4*,3@R-B\Q,B\U"C$X,C<O,3$O-0HQ.#(X+S$R+S4*,3@R.2\Q,B\U
M"C$X,S`O,3(O-0HQ.#,Q+S$R+S4*,3@S,B\Q,2\U"C$X,S,O,3$O-0HQ.#,T
M+S$R+S4*,3@S-2\Q,B\U"C$X,S8O,3(O-0HQ.#,W+S$R+S4*,3@S."\Q,2\U
M"C$X,SDO,3$O-0HQ.#0P+S$R+S4*,3@T,2\Q,B\U"C$X-#(O,3(O-0HQ.#0S
M+S$R+S4*,3@T-"\Q,2\U"C$X-#4O,3(O-0HQ.#0V+S$R+S4*,3@T-R\Q,B\U
M"C$X-#@O,3(O-0HQ.#0Y+S$Q+S4*,3@U,"\Q,2\U"C$X-3$O,3(O-0HQ.#4R
M+S$R+S4*,3@U,R\Q,B\U"C$X-30O,3(O-0HQ.#4U+S$Q+S4*,3@U-B\Q,B\U
M"C$X-3<O,3(O-0HQ.#4X+S$R+S4*,3@U.2\Q,B\U"C$X-C`O,3$O-0HQ.#8Q
M+S$Q+S4*,3@V,B\Q,B\U"C$X-C,O,3(O-0HQ.#8T+S$R+S4*,3@V-2\Q,B\U
M"C$X-C8O,3$O-0HQ.#8W+S$Q+S4*,3@V."\Q,B\U"C$X-CDO,3(O-0HQ.#<P
M+S$R+S4*,3@W,2\Q,B\U"C$X-S(O,3$O-0HQ.#<S+S$R+S4*,3@W-"\Q,B\U
M"C$X-S4O,3(O-0HQ.#<V+S$R+S4*,3@W-R\Q,2\U"C$X-S@O,3$O-0HQ.#<Y
M+S$R+S4*,3@X,"\Q,B\U"C$X.#$O,3(O-0HQ.#@R+S$R+S4*,3@X,R\Q,2\U
M"C$X.#0O,3(O-0HQ.#@U+S$R+S4*,3@X-B\Q,B\U"C$X.#<O,3(O-0HQ.#@X
M+S$Q+S4*,3@X.2\Q,2\U"C$X.3`O,3(O-0HQ.#DQ+S$R+S4*,3@Y,B\Q,B\U
M"C$X.3,O,3(O-0HQ.#DT+S$Q+S4*,3@Y-2\Q,2\U"C$X.38O,3(O-0HQ.#DW
M+S$R+S4*,3@Y."\Q,B\U"C$X.3DO,3(O-0HQ.3`P+S$Q+S4*,3DP,2\Q,2\U
M"C$Y,#(O,3(O-0HQ.3`S+S$R+S4*,3DP-"\Q,B\U"C$Y,#4O,3(O-0HQ.3`V
M+S$Q+S4*,3DP-R\Q,2\U"C$Y,#@O,3(O-0HQ.3`Y+S$R+S4*,3DQ,"\Q,B\U
M"C$Y,3$O,3(O-0HQ.3$R+S$Q+S4*,3DQ,R\Q,B\U"C$Y,30O,3(O-0HQ.3$U
M+S$R+S4*,3DQ-B\Q,B\U"C$Y,3<O,3$O-0HQ.3$X+S$Q+S4*,3DQ.2\Q,B\U
M"C$Y,C`O,3(O-0HQ.3(Q+S$R+S4*,3DR,B\Q,B\U"C$Y,C,O,3$O-0HQ.3(T
M+S$R+S4*,3DR-2\Q,B\U"C$Y,C8O,3(O-0HQ.3(W+S$R+S4*,3DR."\Q,2\U
M"C$Y,CDO,3$O-0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=V5E:W-I;FUO;G1H7W)D;5]S=6YD
M87DN='AT`````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`W,C$V`#$P-3$U-#,Q,#4W`#`R-C(S,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````Q.3DY+S$R
M+S4*,C`P,"\Q,2\U"C(P,#$O,3$O-0HR,#`R+S$R+S4*,C`P,R\Q,B\U"C(P
M,#0O,3(O-0HR,#`U+S$R+S4*,C`P-B\Q,2\U"C(P,#<O,3$O-0HR,#`X+S$R
M+S4*,C`P.2\Q,B\U"C(P,3`O,3(O-0HR,#$Q+S$R+S4*,C`Q,B\Q,2\U"C(P
M,3,O,3(O-0HR,#$T+S$R+S4*,C`Q-2\Q,B\U"C(P,38O,3(O-0HR,#$W+S$Q
M+S4*,C`Q."\Q,2\U"C(P,3DO,3(O-0HR,#(P+S$R+S4*,C`R,2\Q,B\U"C(P
M,C(O,3(O-0HR,#(S+S$Q+S4*,C`R-"\Q,B\U"C(P,C4O,3(O-0HR,#(V+S$R
M+S4*,C`R-R\Q,B\U"C(P,C@O,3$O-0HR,#(Y+S$Q+S4*,C`S,"\Q,B\U"C(P
M,S$O,3(O-0HR,#,R+S$R+S4*,C`S,R\Q,B\U"C(P,S0O,3$O-0HR,#,U+S$Q
M+S4*,C`S-B\Q,B\U"C(P,S<O,3(O-0HQ.3,P+S$R+S4*,3DS,2\Q,B\U"C$Y
M,S(O,3(O-0HQ.3,S+S$Q+S4*,3DS-"\Q,2\U"C$Y,S4O,3(O-0HQ.3,V+S$R
M+S4*,3DS-R\Q,B\U"C$Y,S@O,3(O-0HQ.3,Y+S$Q+S4*,3DT,"\Q,B\U"C$Y
M-#$O,3(O-0HQ.30R+S$R+S4*,3DT,R\Q,B\U"C$Y-#0O,3$O-0HQ.30U+S$Q
M+S4*,3DT-B\Q,B\U"C$Y-#<O,3(O-0HQ.30X+S$R+S4*,3DT.2\Q,B\U"C$X
M,#`O,3(O-0HQ.#`Q+S$R+S4*,3@P,B\Q,B\U"C$X,#,O,3(O-0HQ.#`T+S$Q
M+S4*,3@P-2\Q,B\U"C$X,#8O,3(O-0HQ.#`W+S$R+S4*,3@P."\Q,B\U"C$X
M,#DO,3$O-0HQ.#$P+S$Q+S4*,3@Q,2\Q,B\U"C$X,3(O,3(O-0HQ.#$S+S$R
M+S4*,3@Q-"\Q,B\U"C$X,34O,3$O-0HQ.#$V+S$R+S4*,3@Q-R\Q,B\U"C$X
M,3@O,3(O-0HQ.#$Y+S$R+S4*,3@R,"\Q,2\U"C$X,C$O,3$O-0HQ.#(R+S$R
M+S4*,3@R,R\Q,B\U"C$X,C0O,3(O-0HQ.#(U+S$R+S4*,3@R-B\Q,2\U"C$X
M,C<O,3$O-0HQ.#(X+S$R+S4*,3@R.2\Q,B\U"C$X,S`O,3(O-0HQ.#,Q+S$R
M+S4*,3@S,B\Q,2\U"C$X,S,O,3(O-0HQ.#,T+S$R+S4*,3@S-2\Q,B\U"C$X
M,S8O,3(O-0HQ.#,W+S$Q+S4*,3@S."\Q,2\U"C$X,SDO,3(O-0HQ.#0P+S$R
M+S4*,3@T,2\Q,B\U"C$X-#(O,3(O-0HQ.#0S+S$Q+S4*,3@T-"\Q,B\U"C$X
M-#4O,3(O-0HQ.#0V+S$R+S4*,3@T-R\Q,B\U"C$X-#@O,3$O-0HQ.#0Y+S$Q
M+S4*,3@U,"\Q,B\U"C$X-3$O,3(O-0HQ.#4R+S$R+S4*,3@U,R\Q,B\U"C$X
M-30O,3$O-0HQ.#4U+S$Q+S4*,3@U-B\Q,B\U"C$X-3<O,3(O-0HQ.#4X+S$R
M+S4*,3@U.2\Q,B\U"C$X-C`O,3$O-0HQ.#8Q+S$R+S4*,3@V,B\Q,B\U"C$X
M-C,O,3(O-0HQ.#8T+S$R+S4*,3@V-2\Q,2\U"C$X-C8O,3$O-0HQ.#8W+S$R
M+S4*,3@V."\Q,B\U"C$X-CDO,3(O-0HQ.#<P+S$R+S4*,3@W,2\Q,2\U"C$X
M-S(O,3(O-0HQ.#<S+S$R+S4*,3@W-"\Q,B\U"C$X-S4O,3(O-0HQ.#<V+S$Q
M+S4*,3@W-R\Q,2\U"C$X-S@O,3(O-0HQ.#<Y+S$R+S4*,3@X,"\Q,B\U"C$X
M.#$O,3(O-0HQ.#@R+S$Q+S4*,3@X,R\Q,2\U"C$X.#0O,3(O-0HQ.#@U+S$R
M+S4*,3@X-B\Q,B\U"C$X.#<O,3(O-0HQ.#@X+S$Q+S4*,3@X.2\Q,B\U"C$X
M.3`O,3(O-0HQ.#DQ+S$R+S4*,3@Y,B\Q,B\U"C$X.3,O,3$O-0HQ.#DT+S$Q
M+S4*,3@Y-2\Q,B\U"C$X.38O,3(O-0HQ.#DW+S$R+S4*,3@Y."\Q,B\U"C$X
M.3DO,3$O-0HQ.3`P+S$Q+S4*,3DP,2\Q,B\U"C$Y,#(O,3(O-0HQ.3`S+S$R
M+S4*,3DP-"\Q,B\U"C$Y,#4O,3$O-0HQ.3`V+S$Q+S4*,3DP-R\Q,B\U"C$Y
M,#@O,3(O-0HQ.3`Y+S$R+S4*,3DQ,"\Q,B\U"C$Y,3$O,3$O-0HQ.3$R+S$R
M+S4*,3DQ,R\Q,B\U"C$Y,30O,3(O-0HQ.3$U+S$R+S4*,3DQ-B\Q,2\U"C$Y
M,3<O,3$O-0HQ.3$X+S$R+S4*,3DQ.2\Q,B\U"C$Y,C`O,3(O-0HQ.3(Q+S$R
M+S4*,3DR,B\Q,2\U"C$Y,C,O,3$O-0HQ.3(T+S$R+S4*,3DR-2\Q,B\U"C$Y
M,C8O,3(O-0HQ.3(W+S$R+S4*,3DR."\Q,2\U"C$Y,CDO,3(O-0HQ.3DY+S$P
M+S8*,C`P,"\Q,B\V"C(P,#$O,3(O-@HR,#`R+S8O-@HR,#`S+S$Q+S8*,C`P
M-"\Q,"\V"C(P,#4O,3`O-@HR,#`V+S$R+S8*,C`P-R\Q,B\V"C(P,#@O,3$O
M-@HR,#`Y+S@O-@HR,#$P+S$P+S8*,C`Q,2\Q,"\V"C(P,3(O,3(O-@HR,#$S
M+S8O-@HR,#$T+S$Q+S8*,C`Q-2\X+S8*,C`Q-B\Q,"\V"C(P,3<O,3(O-@HR
M,#$X+S$R+S8*,C`Q.2\V+S8*,C`R,"\X+S8*,C`R,2\Q,"\V"C(P,C(O,3`O
M-@HR,#(S+S$R+S8*,C`R-"\V+S8*,C`R-2\Q,2\V"C(P,C8O."\V"C(P,C<O
M,3`O-@HR,#(X+S$R+S8*,C`R.2\Q,B\V"C(P,S`O-B\V"C(P,S$O,3$O-@HR
M,#,R+S$P+S8*,C`S,R\Q,"\V"C(P,S0O,3(O-@HR,#,U+S$R+S8*,C`S-B\Q
M,2\V"C(P,S<O."\V"C$Y,S`O,3$O-@HQ.3,Q+S@O-@HQ.3,R+S$P+S8*,3DS
M,R\Q,B\V"C$Y,S0O,3(O-@HQ.3,U+S8O-@HQ.3,V+S@O-@HQ.3,W+S$P+S8*
M,3DS."\Q,"\V"C$Y,SDO,3(O-@HQ.30P+S8O-@HQ.30Q+S$Q+S8*,3DT,B\X
M+S8*,3DT,R\Q,"\V"C$Y-#0O,3(O-@HQ.30U+S$R+S8*,3DT-B\V+S8*,3DT
M-R\Q,2\V"C$Y-#@O,3`O-@HQ.30Y+S$P+S8*,3@P,"\Q,2\V"C$X,#$O."\V
M"C$X,#(O,3`O-@HQ.#`S+S$P+S8*,3@P-"\Q,B\V"C$X,#4O-B\V"C$X,#8O
M,3$O-@HQ.#`W+S@O-@HQ.#`X+S$P+S8*,3@P.2\Q,B\V"C$X,3`O,3(O-@HQ
M.#$Q+S8O-@HQ.#$R+S@O-@HQ.#$S+S$P+S8*,3@Q-"\Q,"\V"C$X,34O,3(O
M-@HQ.#$V+S8O-@HQ.#$W+S$Q+S8*,3@Q."\X+S8*,3@Q.2\Q,"\V"C$X,C`O
M,3(O-@HQ.#(Q+S$R+S8*,3@R,B\V+S8*,3@R,R\Q,2\V"C$X,C0O,3`O-@HQ
M.#(U+S$P+S8*,3@R-B\Q,B\V"C$X,C<O,3(O-@HQ.#(X+S$Q+S8*,3@R.2\X
M+S8*,3@S,"\Q,"\V"C$X,S$O,3`O-@HQ.#,R+S$R+S8*,3@S,R\V+S8*,3@S
M-"\Q,2\V"C$X,S4O."\V"C$X,S8O,3`O-@HQ.#,W+S$R+S8*,3@S."\Q,B\V
M"C$X,SDO-B\V"C$X-#`O."\V"C$X-#$O,3`O-@HQ.#0R+S$P+S8*,3@T,R\Q
M,B\V"C$X-#0O-B\V"C$X-#4O,3$O-@HQ.#0V+S@O-@HQ.#0W+S$P+S8*,3@T
M."\Q,B\V"C$X-#DO,3(O-@HQ.#4P+S8O-@HQ.#4Q+S$Q+S8*,3@U,B\Q,"\V
M"C$X-3,O,3`O-@HQ.#4T+S$R+S8*,3@U-2\Q,B\V"C$X-38O,3$O-@HQ.#4W
M+S@O-@HQ.#4X+S$P+S8*,3@U.2\Q,"\V"C$X-C`O,3(O-@HQ.#8Q+S8O-@HQ
M.#8R+S$Q+S8*,3@V,R\X+S8*,3@V-"\Q,"\V"C$X-C4O,3(O-@HQ.#8V+S$R
M+S8*,3@V-R\V+S8*,3@V."\X+S8*,3@V.2\Q,"\V"C$X-S`O,3`O-@HQ.#<Q
M+S$R+S8*,3@W,B\V+S8*,3@W,R\Q,2\V"C$X-S0O."\V"C$X-S4O,3`O-@HQ
M.#<V+S$R+S8*,3@W-R\Q,B\V"C$X-S@O-B\V"C$X-SDO,3$O-@HQ.#@P+S$P
M+S8*,3@X,2\Q,"\V"C$X.#(O,3(O-@HQ.#@S+S$R+S8*,3@X-"\Q,2\V"C$X
M.#4O."\V"C$X.#8O,3`O-@HQ.#@W+S$P+S8*,3@X."\Q,B\V"C$X.#DO-B\V
M"C$X.3`O,3$O-@HQ.#DQ+S@O-@HQ.#DR+S$P+S8*,3@Y,R\Q,B\V"C$X.30O
M,3(O-@HQ.#DU+S8O-@HQ.#DV+S@O-@HQ.#DW+S$P+S8*,3@Y."\Q,"\V"C$X
M.3DO,3(O-@HQ.3`P+S$R+S8*,3DP,2\V+S8*,3DP,B\Q,2\V"C$Y,#,O."\V
M"C$Y,#0O,3`O-@HQ.3`U+S$R+S8*,3DP-B\Q,B\V"C$Y,#<O-B\V"C$Y,#@O
M."\V"C$Y,#DO,3`O-@HQ.3$P+S$P+S8*,3DQ,2\Q,B\V"C$Y,3(O-B\V"C$Y
M,3,O,3$O-@HQ.3$T+S@O-@HQ.3$U+S$P+S8*,3DQ-B\Q,B\V"C$Y,3<O,3(O
M-@HQ.3$X+S8O-@HQ.3$Y+S$Q+S8*,3DR,"\Q,"\V"C$Y,C$O,3`O-@HQ.3(R
M+S$R+S8*,3DR,R\Q,B\V"C$Y,C0O,3$O-@HQ.3(U+S@O-@HQ.3(V+S$P+S8*
M,3DR-R\Q,"\V"C$Y,C@O,3(O-@HQ.3(Y+S8O-@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=VMN
M;W1E<W0N='AT````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P-S`T`#$P-3$U
M-#,Q,#4W`#`R,S$T-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````Q.3DY,3(R-SHQ.3DY+34R+3$*,3DY.3$R,C@Z,3DY.2TU
M,BTR"C$Y.3DQ,C(Y.C$Y.3DM-3(M,PHQ.3DY,3(S,#HQ.3DY+34R+30*,3DY
M.3$R,S$Z,3DY.2TU,BTU"C(P,#`P,3`Q.C$Y.3DM-3(M-@HR,#`P,#$P,CHQ
M.3DY+34R+3<*,C`P,#`Q,#,Z,C`P,"TP,2TQ"C(P,#`P,3`T.C(P,#`M,#$M
M,@HR,#`P,#$P-3HR,#`P+3`Q+3,*,C`P,#`Q,#8Z,C`P,"TP,2TT"C(P,#`P
M,3`W.C(P,#`M,#$M-0HR,#`P,#$P.#HR,#`P+3`Q+38*,C`P,#`Q,#DZ,C`P
M,"TP,2TW"C(P,#`Q,C(U.C(P,#`M-3(M,0HR,#`P,3(R-CHR,#`P+34R+3(*
M,C`P,#$R,C<Z,C`P,"TU,BTS"C(P,#`Q,C(X.C(P,#`M-3(M-`HR,#`P,3(R
M.3HR,#`P+34R+34*,C`P,#$R,S`Z,C`P,"TU,BTV"C(P,#`Q,C,Q.C(P,#`M
M-3(M-PHR,#`Q,#$P,3HR,#`Q+3`Q+3$*,C`P,3`Q,#(Z,C`P,2TP,2TR"C(P
M,#$P,3`S.C(P,#$M,#$M,PHR,#`Q,#$P-#HR,#`Q+3`Q+30*,C`P,3`Q,#4Z
M,C`P,2TP,2TU"C(P,#$P,3`V.C(P,#$M,#$M-@HR,#`Q,#$P-SHR,#`Q+3`Q
M+3<*,C`P,3$R,C0Z,C`P,2TU,BTQ"C(P,#$Q,C(U.C(P,#$M-3(M,@HR,#`Q
M,3(R-CHR,#`Q+34R+3,*,C`P,3$R,C<Z,C`P,2TU,BTT"C(P,#$Q,C(X.C(P
M,#$M-3(M-0HR,#`Q,3(R.3HR,#`Q+34R+38*,C`P,3$R,S`Z,C`P,2TU,BTW
M"C(P,#$Q,C,Q.C(P,#(M,#$M,0HR,#`R,#$P,3HR,#`R+3`Q+3(*,C`P,C`Q
M,#(Z,C`P,BTP,2TS"C(P,#(P,3`S.C(P,#(M,#$M-`HR,#`R,#$P-#HR,#`R
M+3`Q+34*,C`P,C`Q,#4Z,C`P,BTP,2TV"C(P,#(P,3`V.C(P,#(M,#$M-PHR
M,#`R,3(R,SHR,#`R+34R+3$*,C`P,C$R,C0Z,C`P,BTU,BTR"C(P,#(Q,C(U
M.C(P,#(M-3(M,PHR,#`R,3(R-CHR,#`R+34R+30*,C`P,C$R,C<Z,C`P,BTU
M,BTU"C(P,#(Q,C(X.C(P,#(M-3(M-@HR,#`R,3(R.3HR,#`R+34R+3<*,C`P
M,C$R,S`Z,C`P,RTP,2TQ"C(P,#(Q,C,Q.C(P,#,M,#$M,@HR,#`S,#$P,3HR
M,#`S+3`Q+3,*,C`P,S`Q,#(Z,C`P,RTP,2TT"C(P,#,P,3`S.C(P,#,M,#$M
M-0HR,#`S,#$P-#HR,#`S+3`Q+38*,C`P,S`Q,#4Z,C`P,RTP,2TW"C(P,#,Q
M,C(R.C(P,#,M-3(M,0HR,#`S,3(R,SHR,#`S+34R+3(*,C`P,S$R,C0Z,C`P
M,RTU,BTS"C(P,#,Q,C(U.C(P,#,M-3(M-`HR,#`S,3(R-CHR,#`S+34R+34*
M,C`P,S$R,C<Z,C`P,RTU,BTV"C(P,#,Q,C(X.C(P,#,M-3(M-PHR,#`S,3(R
M.3HR,#`T+3`Q+3$*,C`P,S$R,S`Z,C`P-"TP,2TR"C(P,#,Q,C,Q.C(P,#0M
M,#$M,PHR,#`T,#$P,3HR,#`T+3`Q+30*,C`P-#`Q,#(Z,C`P-"TP,2TU"C(P
M,#0P,3`S.C(P,#0M,#$M-@HR,#`T,#$P-#HR,#`T+3`Q+3<*,C`P-#$R,C`Z
M,C`P-"TU,BTQ"C(P,#0Q,C(Q.C(P,#0M-3(M,@HR,#`T,3(R,CHR,#`T+34R
M+3,*,C`P-#$R,C,Z,C`P-"TU,BTT"C(P,#0Q,C(T.C(P,#0M-3(M-0HR,#`T
M,3(R-3HR,#`T+34R+38*,C`P-#$R,C8Z,C`P-"TU,BTW"C(P,#0Q,C(W.C(P
M,#0M-3,M,0HR,#`T,3(R.#HR,#`T+34S+3(*,C`P-#$R,CDZ,C`P-"TU,RTS
M"C(P,#0Q,C,P.C(P,#0M-3,M-`HR,#`T,3(S,3HR,#`T+34S+34*,C`P-3`Q
M,#$Z,C`P-"TU,RTV"C(P,#4P,3`R.C(P,#0M-3,M-PHR,#`U,#$P,SHR,#`U
M+3`Q+3$*,C`P-3`Q,#0Z,C`P-2TP,2TR"C(P,#4P,3`U.C(P,#4M,#$M,PHR
M,#`U,#$P-CHR,#`U+3`Q+30*,C`P-3`Q,#<Z,C`P-2TP,2TU"C(P,#4P,3`X
M.C(P,#4M,#$M-@HR,#`U,#$P.3HR,#`U+3`Q+3<*,C`P-3$R,C8Z,C`P-2TU
M,BTQ"C(P,#4Q,C(W.C(P,#4M-3(M,@HR,#`U,3(R.#HR,#`U+34R+3,*,C`P
M-3$R,CDZ,C`P-2TU,BTT"C(P,#4Q,C,P.C(P,#4M-3(M-0HR,#`U,3(S,3HR
M,#`U+34R+38*,C`P-C`Q,#$Z,C`P-2TU,BTW"C(P,#8P,3`R.C(P,#8M,#$M
M,0HR,#`V,#$P,SHR,#`V+3`Q+3(*,C`P-C`Q,#0Z,C`P-BTP,2TS"C(P,#8P
M,3`U.C(P,#8M,#$M-`HR,#`V,#$P-CHR,#`V+3`Q+34*,C`P-C`Q,#<Z,C`P
M-BTP,2TV"C(P,#8P,3`X.C(P,#8M,#$M-PHR,#`V,3(R-3HR,#`V+34R+3$*
M,C`P-C$R,C8Z,C`P-BTU,BTR"C(P,#8Q,C(W.C(P,#8M-3(M,PHR,#`V,3(R
M.#HR,#`V+34R+30*,C`P-C$R,CDZ,C`P-BTU,BTU"C(P,#8Q,C,P.C(P,#8M
M-3(M-@HR,#`V,3(S,3HR,#`V+34R+3<*,C`P-S`Q,#$Z,C`P-RTP,2TQ"C(P
M,#<P,3`R.C(P,#<M,#$M,@HR,#`W,#$P,SHR,#`W+3`Q+3,*,C`P-S`Q,#0Z
M,C`P-RTP,2TT"C(P,#<P,3`U.C(P,#<M,#$M-0HR,#`W,#$P-CHR,#`W+3`Q
M+38*,C`P-S`Q,#<Z,C`P-RTP,2TW"C(P,#<Q,C(T.C(P,#<M-3(M,0HR,#`W
M,3(R-3HR,#`W+34R+3(*,C`P-S$R,C8Z,C`P-RTU,BTS"C(P,#<Q,C(W.C(P
M,#<M-3(M-`HR,#`W,3(R.#HR,#`W+34R+34*,C`P-S$R,CDZ,C`P-RTU,BTV
M"C(P,#<Q,C,P.C(P,#<M-3(M-PHR,#`W,3(S,3HR,#`X+3`Q+3$*,C`P.#`Q
M,#$Z,C`P."TP,2TR"C(P,#@P,3`R.C(P,#@M,#$M,PHR,#`X,#$P,SHR,#`X
M+3`Q+30*,C`P.#`Q,#0Z,C`P."TP,2TU"C(P,#@P,3`U.C(P,#@M,#$M-@HR
M,#`X,#$P-CHR,#`X+3`Q+3<*,C`P.#$R,C(Z,C`P."TU,BTQ"C(P,#@Q,C(S
M.C(P,#@M-3(M,@HR,#`X,3(R-#HR,#`X+34R+3,*,C`P.#$R,C4Z,C`P."TU
M,BTT"C(P,#@Q,C(V.C(P,#@M-3(M-0HR,#`X,3(R-SHR,#`X+34R+38*,C`P
M.#$R,C@Z,C`P."TU,BTW"C(P,#@Q,C(Y.C(P,#DM,#$M,0HR,#`X,3(S,#HR
M,#`Y+3`Q+3(*,C`P.#$R,S$Z,C`P.2TP,2TS"C(P,#DP,3`Q.C(P,#DM,#$M
M-`HR,#`Y,#$P,CHR,#`Y+3`Q+34*,C`P.3`Q,#,Z,C`P.2TP,2TV"C(P,#DP
M,3`T.C(P,#DM,#$M-PHR,#`Y,3(R,3HR,#`Y+34R+3$*,C`P.3$R,C(Z,C`P
M.2TU,BTR"C(P,#DQ,C(S.C(P,#DM-3(M,PHR,#`Y,3(R-#HR,#`Y+34R+30*
M,C`P.3$R,C4Z,C`P.2TU,BTU"C(P,#DQ,C(V.C(P,#DM-3(M-@HR,#`Y,3(R
M-SHR,#`Y+34R+3<*,C`P.3$R,C@Z,C`P.2TU,RTQ"C(P,#DQ,C(Y.C(P,#DM
M-3,M,@HR,#`Y,3(S,#HR,#`Y+34S+3,*,C`P.3$R,S$Z,C`P.2TU,RTT"C(P
M,3`P,3`Q.C(P,#DM-3,M-0HR,#$P,#$P,CHR,#`Y+34S+38*,C`Q,#`Q,#,Z
M,C`P.2TU,RTW"C(P,3`P,3`T.C(P,3`M,#$M,0HR,#$P,#$P-3HR,#$P+3`Q
M+3(*,C`Q,#`Q,#8Z,C`Q,"TP,2TS"C(P,3`P,3`W.C(P,3`M,#$M-`HR,#$P
M,#$P.#HR,#$P+3`Q+34*,C`Q,#`Q,#DZ,C`Q,"TP,2TV"C(P,3`P,3$P.C(P
M,3`M,#$M-PHR,#$P,3(R-SHR,#$P+34R+3$*,C`Q,#$R,C@Z,C`Q,"TU,BTR
M"C(P,3`Q,C(Y.C(P,3`M-3(M,PHR,#$P,3(S,#HR,#$P+34R+30*,C`Q,#$R
M,S$Z,C`Q,"TU,BTU"C(P,3$P,3`Q.C(P,3`M-3(M-@HR,#$Q,#$P,CHR,#$P
M+34R+3<*,C`Q,3`Q,#,Z,C`Q,2TP,2TQ"C(P,3$P,3`T.C(P,3$M,#$M,@HR
M,#$Q,#$P-3HR,#$Q+3`Q+3,*,C`Q,3`Q,#8Z,C`Q,2TP,2TT"C(P,3$P,3`W
M.C(P,3$M,#$M-0HR,#$Q,#$P.#HR,#$Q+3`Q+38*,C`Q,3`Q,#DZ,C`Q,2TP
M,2TW"C(P,3$Q,C(V.C(P,3$M-3(M,0HR,#$Q,3(R-SHR,#$Q+34R+3(*,C`Q
M,3$R,C@Z,C`Q,2TU,BTS"C(P,3$Q,C(Y.C(P,3$M-3(M-`HR,#$Q,3(S,#HR
M,#$Q+34R+34*,C`Q,3$R,S$Z,C`Q,2TU,BTV"C(P,3(P,3`Q.C(P,3$M-3(M
M-PHR,#$R,#$P,CHR,#$R+3`Q+3$*,C`Q,C`Q,#,Z,C`Q,BTP,2TR"C(P,3(P
M,3`T.C(P,3(M,#$M,PHR,#$R,#$P-3HR,#$R+3`Q+30*,C`Q,C`Q,#8Z,C`Q
M,BTP,2TU"C(P,3(P,3`W.C(P,3(M,#$M-@HR,#$R,#$P.#HR,#$R+3`Q+3<*
M,C`Q,C$R,C0Z,C`Q,BTU,BTQ"C(P,3(Q,C(U.C(P,3(M-3(M,@HR,#$R,3(R
M-CHR,#$R+34R+3,*,C`Q,C$R,C<Z,C`Q,BTU,BTT"C(P,3(Q,C(X.C(P,3(M
M-3(M-0HR,#$R,3(R.3HR,#$R+34R+38*,C`Q,C$R,S`Z,C`Q,BTU,BTW"C(P
M,3(Q,C,Q.C(P,3,M,#$M,0HR,#$S,#$P,3HR,#$S+3`Q+3(*,C`Q,S`Q,#(Z
M,C`Q,RTP,2TS"C(P,3,P,3`S.C(P,3,M,#$M-`HR,#$S,#$P-#HR,#$S+3`Q
M+34*,C`Q,S`Q,#4Z,C`Q,RTP,2TV"C(P,3,P,3`V.C(P,3,M,#$M-PHR,#$S
M,3(R,SHR,#$S+34R+3$*,C`Q,S$R,C0Z,C`Q,RTU,BTR"C(P,3,Q,C(U.C(P
M,3,M-3(M,PHR,#$S,3(R-CHR,#$S+34R+30*,C`Q,S$R,C<Z,C`Q,RTU,BTU
M"C(P,3,Q,C(X.C(P,3,M-3(M-@HR,#$S,3(R.3HR,#$S+34R+3<*,C`Q,S$R
M,S`Z,C`Q-"TP,2TQ"C(P,3,Q,C,Q.C(P,30M,#$M,@HR,#$T,#$P,3HR,#$T
M+3`Q+3,*,C`Q-#`Q,#(Z,C`Q-"TP,2TT"C(P,30P,3`S.C(P,30M,#$M-0HR
M,#$T,#$P-#HR,#$T+3`Q+38*,C`Q-#`Q,#4Z,C`Q-"TP,2TW"C(P,30Q,C(R
M.C(P,30M-3(M,0HR,#$T,3(R,SHR,#$T+34R+3(*,C`Q-#$R,C0Z,C`Q-"TU
M,BTS"C(P,30Q,C(U.C(P,30M-3(M-`HR,#$T,3(R-CHR,#$T+34R+34*,C`Q
M-#$R,C<Z,C`Q-"TU,BTV"C(P,30Q,C(X.C(P,30M-3(M-PHR,#$T,3(R.3HR
M,#$U+3`Q+3$*,C`Q-#$R,S`Z,C`Q-2TP,2TR"C(P,30Q,C,Q.C(P,34M,#$M
M,PHR,#$U,#$P,3HR,#$U+3`Q+30*,C`Q-3`Q,#(Z,C`Q-2TP,2TU"C(P,34P
M,3`S.C(P,34M,#$M-@HR,#$U,#$P-#HR,#$U+3`Q+3<*,C`Q-3$R,C$Z,C`Q
M-2TU,BTQ"C(P,34Q,C(R.C(P,34M-3(M,@HR,#$U,3(R,SHR,#$U+34R+3,*
M,C`Q-3$R,C0Z,C`Q-2TU,BTT"C(P,34Q,C(U.C(P,34M-3(M-0HR,#$U,3(R
M-CHR,#$U+34R+38*,C`Q-3$R,C<Z,C`Q-2TU,BTW"C(P,34Q,C(X.C(P,34M
M-3,M,0HR,#$U,3(R.3HR,#$U+34S+3(*,C`Q-3$R,S`Z,C`Q-2TU,RTS"C(P
M,34Q,C,Q.C(P,34M-3,M-`HR,#$V,#$P,3HR,#$U+34S+34*,C`Q-C`Q,#(Z
M,C`Q-2TU,RTV"C(P,38P,3`S.C(P,34M-3,M-PHR,#$V,#$P-#HR,#$V+3`Q
M+3$*,C`Q-C`Q,#4Z,C`Q-BTP,2TR"C(P,38P,3`V.C(P,38M,#$M,PHR,#$V
M,#$P-SHR,#$V+3`Q+30*,C`Q-C`Q,#@Z,C`Q-BTP,2TU"C(P,38P,3`Y.C(P
M,38M,#$M-@HR,#$V,#$Q,#HR,#$V+3`Q+3<*,C`Q-C$R,C8Z,C`Q-BTU,BTQ
M"C(P,38Q,C(W.C(P,38M-3(M,@HR,#$V,3(R.#HR,#$V+34R+3,*,C`Q-C$R
M,CDZ,C`Q-BTU,BTT"C(P,38Q,C,P.C(P,38M-3(M-0HR,#$V,3(S,3HR,#$V
M+34R+38*,C`Q-S`Q,#$Z,C`Q-BTU,BTW"C(P,3<P,3`R.C(P,3<M,#$M,0HR
M,#$W,#$P,SHR,#$W+3`Q+3(*,C`Q-S`Q,#0Z,C`Q-RTP,2TS"C(P,3<P,3`U
M.C(P,3<M,#$M-`HR,#$W,#$P-CHR,#$W+3`Q+34*,C`Q-S`Q,#<Z,C`Q-RTP
M,2TV"C(P,3<P,3`X.C(P,3<M,#$M-PHR,#$W,3(R-3HR,#$W+34R+3$*,C`Q
M-S$R,C8Z,C`Q-RTU,BTR"C(P,3<Q,C(W.C(P,3<M-3(M,PHR,#$W,3(R.#HR
M,#$W+34R+30*,C`Q-S$R,CDZ,C`Q-RTU,BTU"C(P,3<Q,C,P.C(P,3<M-3(M
M-@HR,#$W,3(S,3HR,#$W+34R+3<*,C`Q.#`Q,#$Z,C`Q."TP,2TQ"C(P,3@P
M,3`R.C(P,3@M,#$M,@HR,#$X,#$P,SHR,#$X+3`Q+3,*,C`Q.#`Q,#0Z,C`Q
M."TP,2TT"C(P,3@P,3`U.C(P,3@M,#$M-0HR,#$X,#$P-CHR,#$X+3`Q+38*
M,C`Q.#`Q,#<Z,C`Q."TP,2TW"C(P,3@Q,C(T.C(P,3@M-3(M,0HR,#$X,3(R
M-3HR,#$X+34R+3(*,C`Q.#$R,C8Z,C`Q."TU,BTS"C(P,3@Q,C(W.C(P,3@M
M-3(M-`HR,#$X,3(R.#HR,#$X+34R+34*,C`Q.#$R,CDZ,C`Q."TU,BTV"C(P
M,3@Q,C,P.C(P,3@M-3(M-PHR,#$X,3(S,3HR,#$Y+3`Q+3$*,C`Q.3`Q,#$Z
M,C`Q.2TP,2TR"C(P,3DP,3`R.C(P,3DM,#$M,PHR,#$Y,#$P,SHR,#$Y+3`Q
M+30*,C`Q.3`Q,#0Z,C`Q.2TP,2TU"C(P,3DP,3`U.C(P,3DM,#$M-@HR,#$Y
M,#$P-CHR,#$Y+3`Q+3<*,C`Q.3$R,C,Z,C`Q.2TU,BTQ"C(P,3DQ,C(T.C(P
M,3DM-3(M,@HR,#$Y,3(R-3HR,#$Y+34R+3,*,C`Q.3$R,C8Z,C`Q.2TU,BTT
M"C(P,3DQ,C(W.C(P,3DM-3(M-0HR,#$Y,3(R.#HR,#$Y+34R+38*,C`Q.3$R
M,CDZ,C`Q.2TU,BTW"C(P,3DQ,C,P.C(P,C`M,#$M,0HR,#$Y,3(S,3HR,#(P
M+3`Q+3(*,C`R,#`Q,#$Z,C`R,"TP,2TS"C(P,C`P,3`R.C(P,C`M,#$M-`HR
M,#(P,#$P,SHR,#(P+3`Q+34*,C`R,#`Q,#0Z,C`R,"TP,2TV"C(P,C`P,3`U
M.C(P,C`M,#$M-PHR,#(P,3(R,3HR,#(P+34R+3$*,C`R,#$R,C(Z,C`R,"TU
M,BTR"C(P,C`Q,C(S.C(P,C`M-3(M,PHR,#(P,3(R-#HR,#(P+34R+30*,C`R
M,#$R,C4Z,C`R,"TU,BTU"C(P,C`Q,C(V.C(P,C`M-3(M-@HR,#(P,3(R-SHR
M,#(P+34R+3<*,C`R,#$R,C@Z,C`R,"TU,RTQ"C(P,C`Q,C(Y.C(P,C`M-3,M
M,@HR,#(P,3(S,#HR,#(P+34S+3,*,C`R,#$R,S$Z,C`R,"TU,RTT"C(P,C$P
M,3`Q.C(P,C`M-3,M-0HR,#(Q,#$P,CHR,#(P+34S+38*,C`R,3`Q,#,Z,C`R
M,"TU,RTW"C(P,C$P,3`T.C(P,C$M,#$M,0HR,#(Q,#$P-3HR,#(Q+3`Q+3(*
M,C`R,3`Q,#8Z,C`R,2TP,2TS"C(P,C$P,3`W.C(P,C$M,#$M-`HR,#(Q,#$P
M.#HR,#(Q+3`Q+34*,C`R,3`Q,#DZ,C`R,2TP,2TV"C(P,C$P,3$P.C(P,C$M
M,#$M-PHR,#(Q,3(R-SHR,#(Q+34R+3$*,C`R,3$R,C@Z,C`R,2TU,BTR"C(P
M,C$Q,C(Y.C(P,C$M-3(M,PHR,#(Q,3(S,#HR,#(Q+34R+30*,C`R,3$R,S$Z
M,C`R,2TU,BTU"C(P,C(P,3`Q.C(P,C$M-3(M-@HR,#(R,#$P,CHR,#(Q+34R
M+3<*,C`R,C`Q,#,Z,C`R,BTP,2TQ"C(P,C(P,3`T.C(P,C(M,#$M,@HR,#(R
M,#$P-3HR,#(R+3`Q+3,*,C`R,C`Q,#8Z,C`R,BTP,2TT"C(P,C(P,3`W.C(P
M,C(M,#$M-0HR,#(R,#$P.#HR,#(R+3`Q+38*,C`R,C`Q,#DZ,C`R,BTP,2TW
M"C(P,C(Q,C(V.C(P,C(M-3(M,0HR,#(R,3(R-SHR,#(R+34R+3(*,C`R,C$R
M,C@Z,C`R,BTU,BTS"C(P,C(Q,C(Y.C(P,C(M-3(M-`HR,#(R,3(S,#HR,#(R
M+34R+34*,C`R,C$R,S$Z,C`R,BTU,BTV"C(P,C,P,3`Q.C(P,C(M-3(M-PHR
M,#(S,#$P,CHR,#(S+3`Q+3$*,C`R,S`Q,#,Z,C`R,RTP,2TR"C(P,C,P,3`T
M.C(P,C,M,#$M,PHR,#(S,#$P-3HR,#(S+3`Q+30*,C`R,S`Q,#8Z,C`R,RTP
M,2TU"C(P,C,P,3`W.C(P,C,M,#$M-@HR,#(S,#$P.#HR,#(S+3`Q+3<*,C`R
M,S$R,C4Z,C`R,RTU,BTQ"C(P,C,Q,C(V.C(P,C,M-3(M,@HR,#(S,3(R-SHR
M,#(S+34R+3,*,C`R,S$R,C@Z,C`R,RTU,BTT"C(P,C,Q,C(Y.C(P,C,M-3(M
M-0HR,#(S,3(S,#HR,#(S+34R+38*,C`R,S$R,S$Z,C`R,RTU,BTW"C(P,C0P
M,3`Q.C(P,C0M,#$M,0HR,#(T,#$P,CHR,#(T+3`Q+3(*,C`R-#`Q,#,Z,C`R
M-"TP,2TS"C(P,C0P,3`T.C(P,C0M,#$M-`HR,#(T,#$P-3HR,#(T+3`Q+34*
M,C`R-#`Q,#8Z,C`R-"TP,2TV"C(P,C0P,3`W.C(P,C0M,#$M-PHR,#(T,3(R
M,SHR,#(T+34R+3$*,C`R-#$R,C0Z,C`R-"TU,BTR"C(P,C0Q,C(U.C(P,C0M
M-3(M,PHR,#(T,3(R-CHR,#(T+34R+30*,C`R-#$R,C<Z,C`R-"TU,BTU"C(P
M,C0Q,C(X.C(P,C0M-3(M-@HR,#(T,3(R.3HR,#(T+34R+3<*,C`R-#$R,S`Z
M,C`R-2TP,2TQ"C(P,C0Q,C,Q.C(P,C4M,#$M,@HR,#(U,#$P,3HR,#(U+3`Q
M+3,*,C`R-3`Q,#(Z,C`R-2TP,2TT"C(P,C4P,3`S.C(P,C4M,#$M-0HR,#(U
M,#$P-#HR,#(U+3`Q+38*,C`R-3`Q,#4Z,C`R-2TP,2TW"C(P,C4Q,C(R.C(P
M,C4M-3(M,0HR,#(U,3(R,SHR,#(U+34R+3(*,C`R-3$R,C0Z,C`R-2TU,BTS
M"C(P,C4Q,C(U.C(P,C4M-3(M-`HR,#(U,3(R-CHR,#(U+34R+34*,C`R-3$R
M,C<Z,C`R-2TU,BTV"C(P,C4Q,C(X.C(P,C4M-3(M-PHR,#(U,3(R.3HR,#(V
M+3`Q+3$*,C`R-3$R,S`Z,C`R-BTP,2TR"C(P,C4Q,C,Q.C(P,C8M,#$M,PHR
M,#(V,#$P,3HR,#(V+3`Q+30*,C`R-C`Q,#(Z,C`R-BTP,2TU"C(P,C8P,3`S
M.C(P,C8M,#$M-@HR,#(V,#$P-#HR,#(V+3`Q+3<*,C`R-C$R,C$Z,C`R-BTU
M,BTQ"C(P,C8Q,C(R.C(P,C8M-3(M,@HR,#(V,3(R,SHR,#(V+34R+3,*,C`R
M-C$R,C0Z,C`R-BTU,BTT"C(P,C8Q,C(U.C(P,C8M-3(M-0HR,#(V,3(R-CHR
M,#(V+34R+38*,C`R-C$R,C<Z,C`R-BTU,BTW"C(P,C8Q,C(X.C(P,C8M-3,M
M,0HR,#(V,3(R.3HR,#(V+34S+3(*,C`R-C$R,S`Z,C`R-BTU,RTS"C(P,C8Q
M,C,Q.C(P,C8M-3,M-`HR,#(W,#$P,3HR,#(V+34S+34*,C`R-S`Q,#(Z,C`R
M-BTU,RTV"C(P,C<P,3`S.C(P,C8M-3,M-PHR,#(W,#$P-#HR,#(W+3`Q+3$*
M,C`R-S`Q,#4Z,C`R-RTP,2TR"C(P,C<P,3`V.C(P,C<M,#$M,PHR,#(W,#$P
M-SHR,#(W+3`Q+30*,C`R-S`Q,#@Z,C`R-RTP,2TU"C(P,C<P,3`Y.C(P,C<M
M,#$M-@HR,#(W,#$Q,#HR,#(W+3`Q+3<*,C`R-S$R,C<Z,C`R-RTU,BTQ"C(P
M,C<Q,C(X.C(P,C<M-3(M,@HR,#(W,3(R.3HR,#(W+34R+3,*,C`R-S$R,S`Z
M,C`R-RTU,BTT"C(P,C<Q,C,Q.C(P,C<M-3(M-0HR,#(X,#$P,3HR,#(W+34R
M+38*,C`R.#`Q,#(Z,C`R-RTU,BTW"C(P,C@P,3`S.C(P,C@M,#$M,0HR,#(X
M,#$P-#HR,#(X+3`Q+3(*,C`R.#`Q,#4Z,C`R."TP,2TS"C(P,C@P,3`V.C(P
M,C@M,#$M-`HR,#(X,#$P-SHR,#(X+3`Q+34*,C`R.#`Q,#@Z,C`R."TP,2TV
M"C(P,C@P,3`Y.C(P,C@M,#$M-PHR,#(X,3(R-3HR,#(X+34R+3$*,C`R.#$R
M,C8Z,C`R."TU,BTR"C(P,C@Q,C(W.C(P,C@M-3(M,PHR,#(X,3(R.#HR,#(X
M+34R+30*,C`R.#$R,CDZ,C`R."TU,BTU"C(P,C@Q,C,P.C(P,C@M-3(M-@HR
M,#(X,3(S,3HR,#(X+34R+3<*,C`R.3`Q,#$Z,C`R.2TP,2TQ"C(P,CDP,3`R
M.C(P,CDM,#$M,@HR,#(Y,#$P,SHR,#(Y+3`Q+3,*,C`R.3`Q,#0Z,C`R.2TP
M,2TT"C(P,CDP,3`U.C(P,CDM,#$M-0HR,#(Y,#$P-CHR,#(Y+3`Q+38*,C`R
M.3`Q,#<Z,C`R.2TP,2TW````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8G5G-C<T+G!H<```
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S<T`#$P-3$U-#,Q,#4W`#`R
M,C(U-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`IR97%U:7)E7V]N8V4@)T1A=&4N<&AP)SL*)&5R<F]R(#T@9F%L
M<V4["B1D871E<R`](&%R<F%Y("@*("`@(&%R<F%Y*"!A<G)A>2@R,#`S+#,L
M,3<I+"<R,#`S,#,R,R<L)S(P,#,P,S$W)RPG,C`P,S`S,C0G+"<R,#`S,#,Q
M,"<I+`H@("`@87)R87DH(&%R<F%Y*#(P,#,L,RPR,"DL)S(P,#,P,S(S)RPG
M,C`P,S`S,3<G+"<R,#`S,#,R-"<L)S(P,#,P,S$P)RDL"B`@("!A<G)A>2@@
M87)R87DH,C`P,RPS+#(S*2PG,C`P,S`S,C,G+"<R,#`S,#,Q-R<L)S(P,#,P
M,S(T)RPG,C`P,S`S,3`G*0HI.PIF;W)E86-H("@D9&%T97,@87,@)&0I('L*
M("`@("1D871E(#T@)&1;,%T["B`@("`D<F5S(#T@1&%T95]#86QC.CIE;F1/
M9E=E96LH)&1A=&5;,ETL)&1A=&5;,5TL)&1A=&5;,%TI.PH@("`@:68@*"1R
M97,A/21D6S%=*2!["B`@("`@("`@96-H;R`B0G5G(#8W-"!E;W<Z("(@+B`D
M9&%T95LP72XD9&%T95LQ72XD9&%T95LR72XB(&9A:6QE9%QN(CL*("`@("`@
M("`D97)R;W(@/2!T<G5E.PH@("`@?0I]"@IF;W)E86-H("@D9&%T97,@87,@
M)&0I('L*("`@("1D871E(#T@)&1;,%T["B`@("`D<F5S(#T@1&%T95]#86QC
M.CIB96=I;D]F5V5E:R@D9&%T95LR72PD9&%T95LQ72PD9&%T95LP72D["B`@
M("!I9B`H)')E<R$])&1;,ETI('L*("`@("`@("!E8VAO(")"=6<@-C<T(&)O
M=SH@(B`N("1D871E6S!=+B1D871E6S%=+B1D871E6S)=+B(@9F%I;&5D7&XB
M.PH@("`@("`@("1E<G)O<B`]('1R=64["B`@("!]"GT*"@IF;W)E86-H("@D
M9&%T97,@87,@)&0I('L*("`@("1D871E(#T@)&1;,%T["B`@("`D<F5S(#T@
M1&%T95]#86QC.CIB96=I;D]F3F5X=%=E96LH)&1A=&5;,ETL)&1A=&5;,5TL
M)&1A=&5;,%TI.PH@("`@:68@*"1R97,A/21D6S-=*2!["B`@("`@("`@96-H
M;R`B0G5G(#8W-"!B;VYW.B`B("X@)&1A=&5;,%TN)&1A=&5;,5TN)&1A=&5;
M,ETN(B!F86EL961<;B(["B`@("`@("`@)&5R<F]R(#T@=')U93L*("`@('T*
M?0H*"F9O<F5A8V@@*"1D871E<R!A<R`D9"D@>PH@("`@)&1A=&4@/2`D9%LP
M73L*("`@("1R97,@/2!$871E7T-A;&,Z.F)E9VEN3V90<F5V5V5E:R@D9&%T
M95LR72PD9&%T95LQ72PD9&%T95LP72D["B`@("!I9B`H)')E<R$])&1;-%TI
M('L*("`@("`@("!E8VAO(")"=6<@-C<T(&)O<'<Z("(@+B`D9&%T95LP72XD
M9&%T95LQ72XD9&%T95LR72XB(&9A:6QE9%QN(CL*("`@("`@("`D97)R;W(@
M/2!T<G5E.PH@("`@?0I]"@II9B`H(21E<G)O<BD@>PH@("`@96-H;R`B0G5G
M(#8W-#H@3TM<;B(["GT*"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1&%T92]T97-T<R]B=6<W,C=?,2YP:'``````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-C``,3`U,34T,S$P-3<`,#(R-#8V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J"B`J(%1E<W1S(&9O
M<B!W965K<TEN36]N=&@L(&9E8G)U87)Y('=I=&@@-"!W965K<PH@*B!-;VYD
M87D@87,@,7-T(&1A>2!O9B!W965K"B`J+PID969I;F4H)T1!5$5?0T%,0U]"
M14=)3E]7145+1$%9)RP@,2D["G)E<75I<F5?;VYC92`B1&%T92]#86QC+G!H
M<"(["@HO*BH*("H@5&5S="!D871E<R!F<F]M(#$Y-S`@=&\@,C`R.0H@*B!$
M871A(&9R;VTZ(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K+W=K;F]T
M97-T+G1X=`H@*B!/=&AE<G,@=7-E9G5L;"!D871A<R!A=F%I;&%B;&4@9G)O
M;3H*("H@:'1T<#HO+W=W=RYM97)L>6XN9&5M;VXN8V\N=6LO(V1A=`H@*B\*
M)&1A=&%P871H(#T@9&ER;F%M92@@7U]&24Q%7U\I.PH*)&9A:6QE9%]T97-T
M7V1A=&$@("`](&9A;'-E.PHD9&%T97,@("`](&9I;&4H)&1A=&%P871H("X@
M)R]W965K<VEN;6]N=&A?-%]M;VYD87DN='AT)RD["B1C;G0@("`@(#T@<VEZ
M96]F*"1D871E<RD["B1V86QI9',@/2!A<G)A>2@I.PIF;W(H("1I/3`[)&D\
M)&-N=#LD:2LK("E["B`@("`D<&%R=',@("`@("`](&5X<&QO9&4H)R\G+"1D
M871E<ULD:5TI.PH@("`@)'9A;&ED<ULD<&%R='-;,%U=(#T@87)R87DH)'!A
M<G1S6S%=/3XH:6YT*7-T<E]R97!L86-E*")<;B(L)R<L)'!A<G1S6S)=*2D[
M"GT*=6YS970H)&1A=&5S*3L*9F]R96%C:"@D=F%L:61S(&%S("1Y96%R(#T^
M("1M;VYT:',I>PH@("`@9F]R96%C:"`H)&UO;G1H<R!A<R`D;6]N=&@]/B1V
M86QI9%]W965K<RD@>PH@("`@("`@("1C86QC7W=E96MS(#T@1&%T95]#86QC
M.CIW965K<TEN36]N=&@H)&UO;G1H+"1Y96%R*3L*("`@("`@("!I9B@D8V%L
M8U]W965K<R$])'9A;&ED7W=E96MS*7L*("`@("`@("`@("`@)&9A:6QE9%]T
M97-T7V1A=&$@("`]('1R=64["B`@("`@("`@("`@(&5C:&\@(D)U9R`C-S(W
M+"!P87-S(#$Z("1Y96%R+R1M;VYT:"!F86EL960N($5X<&5C=#HD=F%L:61?
M=V5E:W,@1V]T.B1C86QC7W=E96MS7&XB.PH@("`@("`@('T*("`@('T*?0II
M9B`H(21F86EL961?=&5S=%]D871A*2!["@EE8VAO(")"=6<@(S<R-RP@<&%S
M<R`Q.B!/2UQN(CL*?0H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+P``````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P
M,3<S-C4`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O
M=&5S=',O````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#4W`#`R,#4R-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#(Q,38R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P
M,#$N<&AP=```````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$U,0`Q,#4Q-30S
M,3`U-P`P,C(S-3,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*1FEL95]#4U8@5&5S="!#87-E(#`P,3H@1FEE
M;&1S(&-O=6YT(&QE<W,@=&AA;B!E>'!E8W1E9`HM+49)3$4M+0H\/W!H<`HO
M+R`D260Z(#`P,2YP:'!T+'8@,2XR(#(P,#4O,#(O,3@@,3$Z,3DZ,S,@9'5F
M=7H@17AP("0*+RHJ"B`J(%1E<W0@9F]R.@H@*B`M($9I;&5?0U-6.CID:7-C
M;W9E<D9O<FUA="@I"B`J("T@1FEL95]#4U8Z.G)E860H*0H@*B\*"G)E<75I
M<F5?;VYC92`G1FEL92]#4U8N<&AP)SL*"B1F:6QE(#T@)S`P,2YC<W8G.PHD
M8V]N9B`]($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@D9FEL92D["@IP<FEN
M="`B1F]R;6%T.EQN(CL*<')I;G1?<B@D8V]N9BD["G!R:6YT(")<;B(["@HD
M9&%T82`](&%R<F%Y*"D["G=H:6QE("@D<F5S(#T@1FEL95]#4U8Z.G)E860H
M)&9I;&4L("1C;VYF*2D@>PH@("`@)&1A=&%;72`]("1R97,["GT*"G!R:6YT
M(")$871A.EQN(CL*<')I;G1?<B@D9&%T82D["C\^"BTM15A014-4+2T*1F]R
M;6%T.@I!<G)A>0HH"B`@("!;9FEE;&1S72`]/B`T"B`@("!;<V5P72`]/B`L
M"B`@("!;<75O=&5=(#T^("(**0H*1&%T83H*07)R87D**`H@("`@6S!=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,2TQ
M"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`Q+3(*("`@("`@("`@("`@6S)=
M(#T^($9I96QD(#$M,PH@("`@("`@("`@("!;,UT@/3X@1FEE;&0@,2TT"B`@
M("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@
M("`@6S!=(#T^($9I96QD(#(M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@
M,BTR"B`@("`@("`@("`@(%LR72`]/B!&:65L9"`R+3,*("`@("`@("`@("`@
M6S-=(#T^(`H@("`@("`@("D*"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H
M"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`S+3$*("`@("`@("`@("`@6S%=
M(#T^($9I96QD(#,M,@H@("`@("`@("`@("!;,ET@/3X@"B`@("`@("`@("`@
M(%LS72`]/B`*("`@("`@("`I"@H@("`@6S-=(#T^($%R<F%Y"B`@("`@("`@
M*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@-"TQ"B`@("`@("`@("`@(%LQ
M72`]/B`*("`@("`@("`@("`@6S)=(#T^(`H@("`@("`@("`@("!;,UT@/3X@
M"B`@("`@("`@*0H**0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P,BYP:'!T````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,38R`#$P-3$U-#,Q,#4W`#`R,C,U-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+51%4U0M+0I&:6QE
M7T-35B!497-T($-A<V4@,#`R.B!&:65L9',@8V]U;G0@;6]R92!T:&%N(&5X
M<&5C=&5D"BTM1DE,12TM"CP_<&AP"B\O("1)9#H@,#`R+G!H<'0L=B`Q+C(@
M,C`P-2\P,B\Q."`Q,3HQ.3HS,R!D=69U>B!%>'`@)`HO*BH*("H@5&5S="!F
M;W(Z"B`J("T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"D*("H@+2!&:6QE
M7T-35CHZ<F5A9"@I"B`J+PH*<F5Q=6ER95]O;F-E("=&:6QE+T-35BYP:'`G
M.PH*)&9I;&4@/2`G,#`R+F-S=B<["B1C;VYF(#T@1FEL95]#4U8Z.F1I<V-O
M=F5R1F]R;6%T*"1F:6QE*3L*"G!R:6YT(")&;W)M870Z7&XB.PIP<FEN=%]R
M*"1C;VYF*3L*<')I;G0@(EQN(CL*"B1D871A(#T@87)R87DH*3L*=VAI;&4@
M*"1R97,@/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I*2!["B`@("`D
M9&%T85M=(#T@)')E<SL*?0H*<')I;G0@(D1A=&$Z7&XB.PIP<FEN=%]R*"1D
M871A*3L*/SX*+2U%6%!%0U0M+0I&;W)M870Z"D%R<F%Y"B@*("`@(%MF:65L
M9'-=(#T^(#0*("`@(%MS97!=(#T^("P*("`@(%MQ=6]T95T@/3X@(@HI"@I$
M871A.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@
M("`@("`@(%LP72`]/B!&:65L9"`Q+3$*("`@("`@("`@("`@6S%=(#T^($9I
M96QD(#$M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,2TS"B`@("`@("`@
M("`@(%LS72`]/B!&:65L9"`Q+30*("`@("`@("`I"@H@("`@6S%=(#T^($%R
M<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,BTQ"B`@
M("`@("`@("`@(%LQ72`]/B!&:65L9"`R+3(*("`@("`@("`@("`@6S)=(#T^
M($9I96QD(#(M,PH@("`@("`@("`@("!;,UT@/3X@1FEE;&0@,BTT"B`@("`@
M("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@
M6S!=(#T^($9I96QD(#,M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,RTR
M"B`@("`@("`@("`@(%LR72`]/B`*("`@("`@("`@("`@6S-=(#T^(`H@("`@
M("`@("D*"B`@("!;,UT@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@
M(%LP72`]/B!&:65L9"`T+3$*("`@("`@("`@("`@6S%=(#T^(`H@("`@("`@
M("`@("!;,ET@/3X@"B`@("`@("`@("`@(%LS72`]/B`*("`@("`@("`I"@HI
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O
M,#`R+F-S=@``````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,S(`,3`U,34T
M,S$P-3<`,#(R,3<R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````")&:65L9"`Q+3$B+"`B1FEE;&0@,2TR(BP@(D9I96QD(#$M
M,R(L(")&:65L9"`Q+30B"B)&:65L9"`R+3$B+"`B1FEE;&0@,BTR(BP@(D9I
M96QD(#(M,R(L(")&:65L9"`R+30B+"`B17AT<F$@1FEE;&0B"B)&:65L9"`S
M+3$B+"`B1FEE;&0@,RTR(@HB1FEE;&0@-"TQ(@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P,RYP:'!T````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S8R`#$P-3$U-#,Q,#4W`#`R,C,V
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I&:6QE7T-35B!497-T($-A<V4@,#`S.B!7:6YD;W=S($5/3`HM
M+49)3$4M+0H\/W!H<`HO+R`D260Z(#`P,RYP:'!T+'8@,2XR(#(P,#4O,#(O
M,3@@,3$Z,3DZ,S,@9'5F=7H@17AP("0*+RHJ"B`J(%1E<W0@9F]R.@H@*B`M
M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@I"B`J("T@1FEL95]#4U8Z.G)E
M860H*0H@*B\*"G)E<75I<F5?;VYC92`G1FEL92]#4U8N<&AP)SL*"B1F:6QE
M(#T@)S`P,RYC<W8G.PHD8V]N9B`]($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA
M="@D9FEL92D["@IP<FEN="`B1F]R;6%T.EQN(CL*<')I;G1?<B@D8V]N9BD[
M"G!R:6YT(")<;B(["@HD9&%T82`](&%R<F%Y*"D["G=H:6QE("@D<F5S(#T@
M1FEL95]#4U8Z.G)E860H)&9I;&4L("1C;VYF*2D@>PH@("`@)&1A=&%;72`]
M("1R97,["GT*"G!R:6YT(")$871A.EQN(CL*<')I;G1?<B@D9&%T82D["C\^
M"BTM15A014-4+2T*1F]R;6%T.@I!<G)A>0HH"B`@("!;9FEE;&1S72`]/B`T
M"B`@("!;<V5P72`]/B`L"B`@("!;<75O=&5=(#T^("(**0H*1&%T83H*07)R
M87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;
M,%T@/3X@1FEE;&0@,2TQ"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`Q+3(*
M("`@("`@("`@("`@6S)=(#T^($9I96QD(#$M,PH@("`@("`@("`@("!;,UT@
M/3X@1FEE;&0@,2TT"B`@("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@
M("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#(M,0H@("`@("`@("`@
M("!;,5T@/3X@1FEE;&0@,BTR"B`@("`@("`@("`@(%LR72`]/B!&:65L9"`R
M+3,*("`@("`@("`@("`@6S-=(#T^($DG;2!M=6QT:6QI;F4*1FEE;&0*("`@
M("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@
M("!;,%T@/3X@1FEE;&0@,RTQ"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`S
M+3(*("`@("`@("`@("`@6S)=(#T^($9I96QD(#,M,PH@("`@("`@("`@("!;
M,UT@/3X@"B`@("`@("`@*0H**0``````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P,RYC
M<W8``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C(R`#$P-3$U-#,Q,#4W
M`#`R,C$W,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````B1FEE;&0@,2TQ(BPB1FEE;&0@,2TR(BPB1FEE;&0@,2TS(BPB1FEE
M;&0@,2TT(@T*(D9I96QD(#(M,2(L(D9I96QD(#(M,B(L(D9I96QD(#(M,R(L
M(DDG;2!M=6QT:6QI;F4-"D9I96QD(@T*(D9I96QD(#,M,2(L(D9I96QD(#,M
M,B(L(D9I96QD(#,M,R(-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#0N<&AP=```````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3<U-P`Q,#4Q-30S,3`U-P`P,C(S-S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*1FEL95]#4U8@5&5S="!#87-E(#`P-#H@56YI>"!%3TP*+2U&24Q%+2T*
M/#]P:'`*+R\@)$ED.B`P,#0N<&AP="QV(#$N,B`R,#`U+S`R+S$X(#$Q.C$Y
M.C,S(&1U9G5Z($5X<"`D"B\J*@H@*B!497-T(&9O<CH*("H@+2!&:6QE7T-3
M5CHZ9&ES8V]V97)&;W)M870H*0H@*B`M($9I;&5?0U-6.CIR96%D*"D*("HO
M"@IR97%U:7)E7V]N8V4@)T9I;&4O0U-6+G!H<"<["@HD9FEL92`]("<P,#0N
M8W-V)SL*)&-O;F8@/2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H)&9I;&4I
M.PH*<')I;G0@(D9O<FUA=#I<;B(["G!R:6YT7W(H)&-O;F8I.PIP<FEN="`B
M7&XB.PH*)&1A=&$@/2!A<G)A>2@I.PIW:&EL92`H)')E<R`]($9I;&5?0U-6
M.CIR96%D*"1F:6QE+"`D8V]N9BDI('L*("`@("1D871A6UT@/2`D<F5S.PI]
M"@IP<FEN="`B1&%T83I<;B(["G!R:6YT7W(H)&1A=&$I.PH_/@HM+4584$5#
M5"TM"D9O<FUA=#H*07)R87D**`H@("`@6V9I96QD<UT@/3X@-`H@("`@6W-E
M<%T@/3X@+`H@("`@6W%U;W1E72`]/B`B"BD*"D1A=&$Z"D%R<F%Y"B@*("`@
M(%LP72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I
M96QD(#$M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,2TR"B`@("`@("`@
M("`@(%LR72`]/B!&:65L9"`Q+3,*("`@("`@("`@("`@6S-=(#T^($9I96QD
M(#$M-`H@("`@("`@("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@
M("`@("`@("`@(%LP72`]/B!&:65L9"`R+3$*("`@("`@("`@("`@6S%=(#T^
M($9I96QD(#(M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,BTS"B`@("`@
M("`@("`@(%LS72`]/B!))VT@;75L=&EL:6YE"D9I96QD"B`@("`@("`@*0H*
M("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^
M($9I96QD(#,M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,RTR"B`@("`@
M("`@("`@(%LR72`]/B!&:65L9"`S+3,*("`@("`@("`@("`@6S-=(#T^(`H@
M("`@("`@("D*"BD``````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#0N8W-V````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(Q-@`Q,#4Q-30S,3`U-P`P,C(Q
M-S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(D9I96QD(#$M,2(L(D9I96QD(#$M,B(L(D9I96QD(#$M,R(L(D9I96QD(#$M
M-"(*(D9I96QD(#(M,2(L(D9I96QD(#(M,B(L(D9I96QD(#(M,R(L(DDG;2!M
M=6QT:6QI;F4*1FEE;&0B"B)&:65L9"`S+3$B+")&:65L9"`S+3(B+")&:65L
M9"`S+3,B"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`U+G!H<'0`````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(W,3(`,3`U,34T,S$P-3<`,#(R,S8R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM5$535"TM"D9I
M;&5?0U-6(%1E<W0@0V%S92`P,#4Z($UA8R!%3TP*+2U&24Q%+2T*/#]P:'`*
M+R\@)$ED.B`P,#4N<&AP="QV(#$N,R`R,#`U+S`R+S$Y(#$R.C(S.C(X(&1U
M9G5Z($5X<"`D"B\J*@H@*B!497-T(&9O<CH*("H@+2!&:6QE7T-35CHZ9&ES
M8V]V97)&;W)M870H*0H@*B`M($9I;&5?0U-6.CIR96%D*"D*("HO"@IR97%U
M:7)E7V]N8V4@)T9I;&4O0U-6+G!H<"<["@HD9FEL92`]("<P,#4N8W-V)SL*
M)&-O;F8@/2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H)&9I;&4I.PH*<')I
M;G0@(D9O<FUA=#I<;B(["G!R:6YT7W(H)&-O;F8I.PIP<FEN="`B7&XB.PH*
M)&1A=&$@/2!A<G)A>2@I.PIW:&EL92`H)')E<R`]($9I;&5?0U-6.CIR96%D
M*"1F:6QE+"`D8V]N9BDI('L*("`@("1D871A6UT@/2`D<F5S.PI]"@IF=6YC
M=&EO;B!?9&)G0G5F9B@D9&%T82D*>PH@("`@9F]R96%C:"`H)&1A=&$@87,@
M)&ME>2`]/B`D<F]W*2!["B`@("`@("`@:68@*'-T<G!O<R@D<F]W+"`B7'(B
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)')O=R`]('-T<E]R97!L86-E
M*")<<B(L(")?<E\B+"`D<F]W*3L*("`@("`@("!]"B`@("`@("`@:68@*'-T
M<G!O<R@D<F]W+"`B7&XB*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'-T
M<B`]('-T<E]R97!L86-E*")<;B(L(")?;E\B+"`D<F]W*3L*("`@("`@("!]
M"B`@("`@("`@:68@*'-T<G!O<R@D<F]W+"`B7'0B*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)')O=R`]('-T<E]R97!L86-E*")<="(L(")?=%\B+"`D
M<F]W*3L*("`@("`@("!]"B`@("`@("`@)&1A=&%;)&ME>5T@/2`D<F]W.PH@
M("`@?0H@("`@<F5T=7)N("1D871A.PI]"@HD9&%T82`](&%R<F%Y7VUA<"@G
M7V1B9T)U9F8G+"`D9&%T82D["@IP<FEN="`B1&%T83I<;B(["G!R:6YT7W(H
M)&1A=&$I.PH_/@HM+4584$5#5"TM"D9O<FUA=#H*07)R87D**`H@("`@6V9I
M96QD<UT@/3X@-`H@("`@6W-E<%T@/3X@+`H@("`@6W%U;W1E72`]/B`B"BD*
M"D1A=&$Z"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A>0H@("`@("`@("@*("`@
M("`@("`@("`@6S!=(#T^($9I96QD(#$M,0H@("`@("`@("`@("!;,5T@/3X@
M1FEE;&0@,2TR"B`@("`@("`@("`@(%LR72`]/B!&:65L9"`Q+3,*("`@("`@
M("`@("`@6S-=(#T^($9I96QD(#$M-`H@("`@("`@("D*"B`@("!;,5T@/3X@
M07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`R+3$*
M("`@("`@("`@("`@6S%=(#T^($9I96QD(#(M,@H@("`@("`@("`@("!;,ET@
M/3X@1FEE;&0@,BTS"B`@("`@("`@("`@(%LS72`]/B!))VT@;75L=&EL:6YE
M7W)?1FEE;&0*("`@("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@
M*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,RTQ"B`@("`@("`@("`@(%LQ
M72`]/B!&:65L9"`S+3(*("`@("`@("`@("`@6S)=(#T^($9I96QD(#,M,PH@
M("`@("`@("`@("!;,UT@/3X@"B`@("`@("`@*0H**0``````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-3
M5B\P,#4N8W-V````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(Q-@`Q,#4Q
M-30S,3`U-P`P,C(Q-S<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(D9I96QD(#$M,2(L(D9I96QD(#$M,B(L(D9I96QD(#$M
M,R(L(D9I96QD(#$M-"(-(D9I96QD(#(M,2(L(D9I96QD(#(M,B(L(D9I96QD
M(#(M,R(L(DDG;2!M=6QT:6QI;F4-1FEE;&0B#2)&:65L9"`S+3$B+")&:65L
M9"`S+3(B+")&:65L9"`S+3,B#0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`V+G!H<'0`
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,C<`,3`U,34T,S$P-3<`,#(R
M,S8V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"D9I;&5?0U-6(%1E<W0@0V%S92`P,#8Z($]N92!F:65L9"!Q
M=6]T92!A=71O9&ES8V]V97)Y"BTM1DE,12TM"CP_<&AP"B\O("1)9#H@,#`V
M+G!H<'0L=B`Q+C$@,C`P-2\P-2\R,2`P-CHR-CHT."!D=69U>B!%>'`@)`HO
M*BH*("H@5&5S="!F;W(Z"B`J("T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T
M*"D*("HO"@IR97%U:7)E7V]N8V4@)T9I;&4O0U-6+G!H<"<["@HD9FEL92`]
M("<P,#8N8W-V)SL*)&-O;F8@/2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H
M)&9I;&4I.PH*<')I;G0@(D9O<FUA=#I<;B(["G!R:6YT7W(H)&-O;F8I.PIP
M<FEN="`B7&XB.PH_/@HM+4584$5#5"TM"D9O<FUA=#H*07)R87D**`H@("`@
M6V9I96QD<UT@/3X@,0H@("`@6W-E<%T@/3X@+`H@("`@6W%U;W1E72`]/B`B
M"BD*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-BYC<W8`````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,34P`#$P-3$U-#,Q,#4W`#`R,C$W-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````B4V%M<&QE($1A
M=&$@3&EN92`Q(@HB4V%M<&QE($1A=&$@3&EN92`R(@HB4V%M<&QE($1A=&$@
M3&EN92`S(@HB4V%M<&QE($1A=&$@3&EN92`T(@HB4V%M<&QE($1A=&$@3&EN
M92`U(@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&
M:6QE+W1E<W1S+T-35B]T97-T<RYT>'0`````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3$P-@`Q,#4Q-30S,3`U-P`P,C,P-C``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1FEL95]#4U8@5&5S="!#87-E"CT]
M/3T]/3T]/3T]/3T]/3T]/0H*("`@("!#87-E("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!#;W9E<F5D("!.;W1E<PHM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HP,#$@($9I96QD<R!C;W5N="!L97-S
M('1H86X@97AP96-T960@("`@("`@(%MX70HP,#(@($9I96QD<R!C;W5N="!M
M;W)E('1H86X@97AP96-T960@("`@("`@(%MX72`@("`@($AI9V@@<FES:R!P
M;W-S:6)I;&ET>0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&1I<V-O=F5R960@9FEE;&1S(&-O=6YT"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=W)O;F<*,#`S("!7:6YD;W=S($5/3"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!;>%T*,#`T("!5;FEX($5/3"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!;>%T*,#`U("!-86,@14],("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!;>%T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]&:6QE+W1E<W1S+T-35B\P,#$N8W-V````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#$W-@`Q,#4Q-30S,3`U-P`P,C(R,#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(D9I96QD(#$M,2(L(")&
M:65L9"`Q+3(B+"`B1FEE;&0@,2TS(BP@(D9I96QD(#$M-"(*(D9I96QD(#(M
M,2(L(")&:65L9"`R+3(B+"`B1FEE;&0@,BTS(@HB1FEE;&0@,RTQ(BP@(D9I
M96QD(#,M,B(*(D9I96QD(#0M,2(*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T
M97-T<R]T97-T+F-S=@``````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P
M,S$`,3`U,34T,S$P-3<`,#(R,C$S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````&8Q"68R"68S"68T"F=O;V0Q"6=O;V0R"6=O
M;V0S"6=O;V0T"CL[.SL["3L[.SL["3L[.SL["3L[.SL["CH@.B`Z"3L@.R`B
M"2(N"2().CHZ.CL[.SLB"FYO(G%U;W1E"6YO(G%U(F]T90EN(G%U;W1E(@EN
M(G$B=2)O(G0B"B)Q=6]T93$B"2)Q=6]T93(B"6YO<75O=&4S(@EN;W%U;W1E
M-`IT97-T,0DB;&]N9PIT97-T,B()(FQO;F<@=&5S=#,)=VET:`ES97!S(@DB
M22=M"@D)"0D)<VEL;'D*"0D)"0EL;VYG(@IL97-S,0DB;&5S<S()+B();&5S
M<S,*:7-V86QI9#$):7-V86QI9#():7-V86QI9#,):7-V86QI9#0*;6]R93(Q
M"2)M;W)E,C()"2XB"6UO<F4R,PEM;W)E,C0);6]R93(U"6UO<F4R-@II<W9A
M;&ED,C$):7-V86QI9#(R"6ES=F%L:60R,PEI<W9A;&ED,C0*;&5S<VYO<3,Q
M"6QE<W-N;W$S,@EL97-S;F]Q,S,*:7-V86QI9#,Q"6ES=F%L:60S,@EI<W9A
M;&ED,S,):7-V86QI9#,T"FUO<F5N;W$T,0EM;W)E;F]Q-#();6]R96YO<30S
M"6UO<F5N;W$T-`EM;W)E;F]Q-#4*:7-V86QI9#0Q"6ES=F%L:60T,@EI<W9A
M;&ED-#,):7-V86QI9#0T"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1FEL92]T97-T<R]&:6QE5&5S="YP:'``````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,C$Q,3$`,3`U,34T,S$P-3<`,#(R-S4P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO+R!N965D960@9F]R
M(&QO8VMI;F<@=&5S=`ID969I;F4H)T9)3$5?3$]#2U-?0DQ/0TLG+"!F86QS
M92P@=')U92D["@IR97%U:7)E7V]N8V4@)U!(4%5N:70N<&AP)SL*<F5Q=6ER
M95]O;F-E("=&:6QE+G!H<"<["@IC;&%S<R!&:6QE5&5S="!E>'1E;F1S(%!(
M4%5N:71?5&5S=$-A<V4@"GL*("`@(&9U;F-T:6]N($9I;&5497-T*"1N86UE
M(#T@)T9I;&5497-T)RD*("`@('L*("`@("`@("`D=&AI<RT^4$A056YI=%]4
M97-T0V%S92@D;F%M92D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5&5S=%-T
M<FEN9R@I"B`@("!["B`@("`@("`@<W1A=&EC("1S='(["B`@("`@("`@:7-S
M970H)'-T<BD@;W(@)'-T<B`]('-T<E]R97!E870H<W1R7W)E<&5A="@B,#$R
M,S0U-C<X.2(L(#$P,#`I+B)<;B(L(#$P,"D["B`@("`@("`@<F5T=7)N("1S
M='(["B`@("!]"B`@("`*("`@(&9U;F-T:6]N(&=E=%1E<W1,:6YE*"D*("`@
M('L*("`@("`@("!S=&%T:6,@)'-T<CL*("`@("`@("!I<W-E="@D<W1R*2!O
M<B`D<W1R(#T@<W1R7W)E<&5A="@B,#$R,S0U-C<X.2(L(#$P,#`I.PH@("`@
M("`@(')E='5R;B`D<W1R.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!S9715
M<"@I"B`@("!["B`@("`@("`@)'1H:7,M/G1E87)$;W=N*"D["B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&4@/2!&:6QE.CIW<FET92@G=&5S="YT>'0G
M+"`D=&AI<RT^9V5T5&5S=%-T<FEN9R@I+"!&24Q%7TU/1$5?5U))5$4I*2D@
M>PH@("`@("`@("`@("!D:64H(D-A;FYO="!S=&%R="!T97-T.B`B+B!S=')?
M<F5P;&%C92@D=&AI<RT^9V5T5&5S=%-T<FEN9R@I+"<N+BXG+"`D92T^9V5T
M365S<V%G92@I*2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('1E
M87)$;W=N*"D*("`@('L*("`@("`@("!&:6QE.CIC;&]S94%L;"@I.PH@("`@
M("`@(&9I;&5?97AI<W1S*"=T97-T+G1X="<I(&%N9"!U;FQI;FLH)W1E<W0N
M='AT)RD["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=&QO8VMI;F<H*0H@("`@
M>PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I
M;&4Z.G=R:71E*"=T97-T+G1X="<L("=A8F,G+"!&24Q%7TU/1$5?05!014Y$
M+"!T<G5E*2DI.PH@("`@("`@("1T:&ES+3YA<W-E<G14<G5E*%!%05(Z.FES
M17)R;W(H1FEL93HZ=W)I=&4H)W1E<W0N='AT)RP@)V1E9B<L($9)3$5?34]$
M15]74DE412P@=')U92DI*3L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H
M4$5!4CHZ:7-%<G)O<BA&:6QE.CIU;FQO8VLH)W1E<W0N='AT)RP@1DE,15]-
M3T1%7T%04$5.1"DI*3L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!
M4CHZ:7-%<G)O<BA&:6QE.CIU;FQO8VLH)W1E<W0N='AT)RP@1DE,15]-3T1%
M7U=2251%*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1C;&]S92@I"B`@
M("!["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H
M1FEL93HZ8VQO<V4H)W1E<W0N='AT)RP@1DE,15]-3T1%7U=2251%*2DI.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I;&4Z
M.F-L;W-E*"=T97-T+G1X="<L($9)3$5?34]$15]!4%!%3D0I*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H1FEL93HZ8VQO
M<V4H)W1E<W0N='AT)RP@1DE,15]-3T1%7U)%040I*2D["B`@("!]"@H@("`@
M9G5N8W1I;VX@=&5S=')E861!;&PH*0H@("`@>PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W13=')I;F<H*2P@1FEL93HZ<F5A
M9$%L;"@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@D=&AI<RT^9V5T5&5S=%-T<FEN9R@I+"!&:6QE.CIR96%D06QL*"=T97-T
M+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG
M971497-T4W1R:6YG*"DL($9I;&4Z.G)E861!;&PH)W1E<W0N='AT)RDI.PH@
M("`@?0H*("`@(&9U;F-T:6]N('1E<W1R96%D*"D*("`@('L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE
M.CIR96%D*"=T97-T+G1X="<L(#$P,#`P*2D["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@B7&XB+"!&:6QE.CIR96%D*"=T97-T+G1X="<L(#$I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<P,3(S-#4V-S@Y)RP@1FEL
M93HZ<F5A9"@G=&5S="YT>'0G+"`Q,"DI.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E<W1W<FET92@I"B`@("!["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E
M*%!%05(Z.FES17)R;W(H)&)Y=&5S(#T@1FEL93HZ=W)I=&4H)W1E<W0N='AT
M)RP@)S`Q,C,T-38W.#DG*2DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H,3`L("1B>71E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=')E861#
M:&%R*"D*("`@('L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ
M:7-%<G)O<BA&:6QE.CIR97=I;F0H)W1E<W0N='AT)RP@1DE,15]-3T1%7U)%
M040I*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,"<L($9I;&4Z
M.G)E861#:&%R*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*"<Q)RP@1FEL93HZ<F5A9$-H87(H)W1E<W0N='AT)RDI.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S(G+"!&:6QE.CIR96%D0VAA<B@G
M=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,R<L
M($9I;&4Z.G)E861#:&%R*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^
M87-S97)T17%U86QS*"<T)RP@1FEL93HZ<F5A9$-H87(H)W1E<W0N='AT)RDI
M.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S4G+"!&:6QE.CIR96%D
M0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@G-B<L($9I;&4Z.G)E861#:&%R*"=T97-T+G1X="<I*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"<W)RP@1FEL93HZ<F5A9$-H87(H)W1E<W0N
M='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S@G+"!&:6QE
M.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@G.2<L($9I;&4Z.G)E861#:&%R*"=T97-T+G1X="<I*3L*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*"<P)RP@1FEL93HZ<F5A9$-H87(H
M)W1E<W0N='AT)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1W<FET94-H
M87(H*0H@("`@>PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H,2P@1FEL
M93HZ=W)I=&5#:&%R*"=T97-T+G1X="<L("=A)RDI.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H,2P@1FEL93HZ=W)I=&5#:&%R*"=T97-T+G1X="<L
M("=B)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H,2P@1FEL93HZ
M=W)I=&5#:&%R*"=T97-T+G1X="<L("=C)RDI.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H,2P@1FEL93HZ=W)I=&5#:&%R*"=T97-T+G1X="<L("=D
M)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H,2P@1FEL93HZ=W)I
M=&5#:&%R*"=T97-T+G1X="<L("=E)RDI.PH@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H,2P@1FEL93HZ=W)I=&5#:&%R*"=T97-T+G1X="<L("=F)RDI
M.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H,2P@1FEL93HZ=W)I=&5#
M:&%R*"=T97-T+G1X="<L("=G)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H,2P@1FEL93HZ=W)I=&5#:&%R*"=T97-T+G1X="<L("=H)RDI.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H,2P@1FEL93HZ=W)I=&5#:&%R
M*"=T97-T+G1X="<L("=I)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H,2P@1FEL93HZ=W)I=&5#:&%R*"=T97-T+G1X="<L("=J)RDI.PH@("`@
M?0H*("`@(&9U;F-T:6]N('1E<W1R96%D3&EN92@I"B`@("!["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H1FEL93HZ<F5W:6YD
M*"=T97-T+G1X="<L($9)3$5?34]$15]214%$*2DI.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E
M861,:6YE*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U
M86QS*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE.CIR96%D3&EN92@G=&5S
M="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^
M9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI;F4H)W1E<W0N='AT)RDI.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE
M*"DL($9I;&4Z.G)E861,:6YE*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE.CIR
M96%D3&EN92@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q
M=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI;F4H)W1E
M<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H:7,M
M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,:6YE*"=T97-T+G1X="<I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG971497-T3&EN
M92@I+"!&:6QE.CIR96%D3&EN92@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ
M<F5A9$QI;F4H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,:6YE*"=T
M97-T+G1X="<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T=W)I=&5,:6YE
M*"D*("`@('L*("`@("`@("`D;&EN92`]("1T:&ES+3YG971497-T3&EN92@I
M.PH@("`@("`@("1L96YG=&@@/2!S=')L96XH)&QI;F4I("L@,3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN
M92@G=&5S="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L("1L
M:6YE*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H+"!&
M:6QE.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN92@G
M=&5S="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L("1L:6YE
M*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H+"!&:6QE
M.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN92@G=&5S
M="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L("1L:6YE*2D[
M"B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H+"!&:6QE.CIW
M<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*("`@("`@("`D=&AI<RT^
M87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN92@G=&5S="YT
M>'0G+"`D;&EN92DI.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1R97=I;F0H
M*0H@("`@>PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R
M<F]R*$9I;&4Z.G)E=VEN9"@G=&5S="YT>'0G+"!&24Q%7TU/1$5?5U))5$4I
M*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H
M1FEL93HZ<F5W:6YD*"=T97-T+G1X="<L($9)3$5?34]$15]214%$*2DI.PH@
M("`@?0H*("`@(&9U;F-T:6]N('1E<W1B=6EL9%!A=&@H*0H@("`@>PH@("`@
M("`@("1P871H(#T@87)R87DH"B`@("`@("`@("`@("=S;VUE)RP*("`@("`@
M("`@("`@1$E214-43U)97U-%4$%2051/4BP*("`@("`@("`@("`@1$E214-4
M3U)97U-%4$%2051/4BP*("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/
M4BP*("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4BP*("`@("`@("`@
M("`@)W=E:7)D)RY$25)%0U1/4EE?4T5005)!5$]2+`H@("`@("`@("`@("!$
M25)%0U1/4EE?4T5005)!5$]2+`H@("`@("`@("`@("!$25)%0U1/4EE?4T50
M05)!5$]2+`H@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2+`H@("`@
M("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2+B=P871H)RY$25)%0U1/4EE?
M4T5005)!5$]2+D1)4D5#5$]265]315!!4D%43U(L"B`@("`@("`@*3L*("`@
M("`@("`D8G5I;'0@/2!I;7!L;V1E*$1)4D5#5$]265]315!!4D%43U(L(&%R
M<F%Y*"=S;VUE)RPG=V5I<F0G+"=P871H)RPG)RPG)RDI.PH@("`@("`@("1T
M:&ES+3YA<W-E<G1%<75A;',H)&)U:6QT+"!&:6QE.CIB=6EL9%!A=&@H)'!A
M=&@I*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T<VMI<%)O;W0H*0H@("`@
M>PH@("`@("`@(&EF("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)U=)3D1/5U,G+"!&:6QE.CIS:VEP4F]O="@G0SI<
M7%=)3D1/5U,G*2D["B`@("`@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M)U=)3D1/5U,G+"!&:6QE.CIS:VEP4F]O="@G0SI<7%Q<5TE.1$]74R<I*3L*
M("`@("`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G5TE.1$]74R<L($9I
M;&4Z.G-K:7!2;V]T*"=#.B]724Y$3U=3)RDI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)W5S<B]S:&%R92]P
M96%R)RP@1FEL93HZ<VMI<%)O;W0H)R]U<W(O<VAA<F4O<&5A<B<I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=&=E=%1E;7!$:7(H*0H@
M("`@>PH@("`@("`@("1D:7(@/2!&:6QE.CIG971496UP1&ER*"D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=%1R=64H:7-?9&ER*"1D:7(I+"`B:7-?9&ER*"1D
M:7(I(BD["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=&=E=%1E;7!&:6QE*"D*
M("`@('L*("`@("`@("`D=&UP(#T@1FEL93HZ9V5T5&5M<$9I;&4H*3L*("`@
M("`@("`D=&AI<RT^87-S97)T5')U92AF:6QE7V5X:7-T<R@D=&UP*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@=&5S=&ES06)S;VQU=&4H*0H@("`@>PH@("`@
M("`@("1T:&ES+3YA<W-E<G1&86QS92A&:6QE.CII<T%B<V]L=71E*"=A8G)A
M+RXN+V-A9&%B<F$G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*$9I
M;&4Z.FES06)S;VQU=&4H)V1A=&$O9&ER)RDI.PH@("`@("`@(&EF("A/4U]7
M24Y$3U=3*2!["B`@("`@("`@("`@("1T:&ES+3YA<W-E<G14<G5E*$9I;&4Z
M.FES06)S;VQU=&4H)T,Z7%Q<7&1A=&$G*2D["B`@("`@("`@("`@("1T:&ES
M+3YA<W-E<G14<G5E*$9I;&4Z.FES06)S;VQU=&4H)V0Z+V1A=&$G*2D["B`@
M("`@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A&:6QE.CII<T%B<V]L=71E
M*"=<7"<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M87-S97)T5')U92A&:6QE.CII<T%B<V]L=71E*"<O)RDI.PH@("`@("`@("`@
M("`D=&AI<RT^87-S97)T1F%L<V4H1FEL93HZ:7-!8G-O;'5T92@G7%PG*2D[
M"B`@("`@("`@("`@("1T:&ES+3YA<W-E<G14<G5E*$9I;&4Z.FES06)S;VQU
M=&4H)WYM:6ME+V)I;B<I*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@=&5S=')E;&%T:79E4&%T:"@I"B`@("!["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@G=&5S=',O1FEL92<L($9I;&4Z.G)E;&%T:79E4&%T:"@G
M+W5S<B]S:&%R92]P96%R+W1E<W1S+T9I;&4G+"`G+W5S<B]S:&%R92]P96%R
M)RP@)R\G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G+BXO971C
M)RP@1FEL93HZ<F5L871I=F50871H*"<O971C)RP@)R]U<W(G+"`G+R<I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"=$.EQ<1&%T82<L($9I;&4Z
M.G)E;&%T:79E4&%T:"@G1#I<7$1A=&$G+"`G0SI<7$1A=&$G+"`G7%PG*2D[
M"B`@("`@("`@:68@*$]37U=)3D1/5U,I('L*("`@("`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@G9&%T85Q<9&ER)RP@1FEL93HZ<F5L871I=F50871H
M*"<O=F%R+V1A=&$O9&ER)RP@)R]V87(G*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G9&%T82]D:7(G+"!&
M:6QE.CIR96QA=&EV95!A=&@H)R]V87(O9&%T82]D:7(G+"`G+W9A<B<I*3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G+BXO)RP@
M1FEL93HZ<F5L871I=F50871H*"=D871A)RP@)V1A=&$O9&ER)RP@)R\G*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=')E86QP871H*"D*("`@('L*("`@
M("`@("`D9')I=F4@/2!/4U]724Y$3U=3(#\@<W5B<W1R*&=E=&-W9"@I+#`L
M(#(I(#HG)SL*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1D<FEV92`N
M("<O82]W96ER9"]P871H+VES)RP@1FEL93HZ<F5A;'!A=&@H)R]A7%QW96ER
M9"\O<&%T:%QI<R]T:&%T+RXO+BXO)RP@)R\G*2D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@D9')I=F4@+B`G+V$O=V5I<F0O<&%T:"]I<R]T:&%T
M)RP@1FEL93HZ<F5A;'!A=&@H)R]A7%QW96ER9"\O<&%T:%QI<R]T:&%T+RXO
M+BXO=&AA="\N)RP@)R\G*2D["B`@("!]"GT*"B1R97-U;'0@/2`F4$A056YI
M=#HZ<G5N*&YE=R!02%!5;FET7U1E<W13=6ET92@G1FEL951E<W0G*2D["F5C
M:&\@)')E<W5L="T^=&]3=')I;F<H*3L*"C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]&:6QE+W1E<W1S+W!A<G-E<BYP:'``````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3(P,``Q,#4Q-30S,3`U-P`P,C(U,C(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*)'!A=&@@
M/2!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*3L*:6YI7W-E="@G:6YC;'5D95]P
M871H)RP@<F5A;'!A=&@H)RXN+R<I("X@(CHD<&%T:"(I.PIR97%U:7)E7V]N
M8V4@)T9I;&4O0U-6+G!H<"<["@HO*B]%>&%M<&QE(&-O;F8Z"B1C;VYF(#T@
M87)R87DH"B`@("`G9FEE;&1S)R`]/B`T+`H@("`@)W-E<"<@("`@/3X@(EQT
M(BP*("`@("=Q=6]T92<@(#T^("<B)RP*("`@("=H96%D97(G(#T^(&9A;'-E
M"BD["B\O*B\*;V)?:6UP;&EC:71?9FQU<V@H=')U92D["B1A<F=V(#T@)%]3
M15)615);)V%R9W8G73L*)&9I;&4@/2`D87)G=ELQ73L*)'=R:71E(#T@*&ES
M<V5T*"1A<F=V6S)=*2D@/R`D87)G=ELR72`Z(&9A;'-E.PI014%2.CIS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0L(")W87)N:6YG.B`E<UQN
M(BD["@HD8V]N9B`]($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@D9FEL92D[
M"G=H:6QE("@D9FEE;&1S(#T@1FEL95]#4U8Z.G)E860H)&9I;&4L("1C;VYF
M*2D@>PH@("`@:68@*"1W<FET92D@>PH@("`@("`@($9I;&5?0U-6.CIW<FET
M92@D=W)I=&4L("1F:65L9',L("1C;VYF*3L*("`@('T*("`@('!R:6YT7W(H
M)&9I96QD<RD["GT*"G9A<E]D=6UP*"1C;VYF*3L*96-H;R`B7&XB"@H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B](5%10+P``````````````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`U-P`P,38Q,C,`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TA45%`O4F5Q=65S="\`````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#4W`#`Q-S4U,P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O2%14
M4"]297%U97-T+TQI<W1E;F5R+G!H<```````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#<R-3``,3`U,34T,S$P-3<`,#(R,#4R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M
M,C`P,RP@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!2961I<W1R:6)U=&EO
M;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R
M('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E
M9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\
M"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F
M('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@
M("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P*+R\@?"!O
M(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C
M92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES
M(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I
M;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE
M<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP*
M+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S
M960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`HO+R!\("`@<')O9'5C
M=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I
M8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%1(
M25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$
M15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O('P@(D%3($E3(B!!3D0@04Y9
M($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)5
M5"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)2
M04Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@?`HO
M+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.
M3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\"B\O('P@3U=.15(@3U(@
M0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%
M0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2
M($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@
M("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\"B\O('P@1$%4
M02P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@?"!42$5/4ED@3T8@3$E!0DE,
M2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/
M4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%
M4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\"B\O
M('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!0
M3U-324))3$E462!/1B!354-(($1!34%'12X@('P*+R\@?"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R.B!!;&5X97D@0F]R>F]V(#QA=F)`<&AP+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@3&ES=&5N97(N<&AP
M+'8@,2XR(#(P,#,O,3`O,C8@,3`Z,C@Z,CD@879B($5X<"`D"B\O"@HO*BH*
M("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H92!/8G-E<G9E<B!P87)T(&]F
M(&$@4W5B:F5C="U/8G-E<G9E<@H@*B!D97-I9VX@<&%T=&5R;BX@270@;&ES
M=&5N<R!T;R!T:&4@979E;G1S('-E;G0@8GD@82`*("H@2%144%]297%U97-T
M(&]R($A45%!?4F5S<&]N<V4@:6YS=&%N8V4N"B`J"B`J($!P86-K86=E($A4
M5%!?4F5Q=65S=`H@*B!`875T:&]R("!!;&5X97D@0F]R>F]V(#QA=F)`<&AP
M+FYE=#X*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C(@)`H@*B\*8VQA<W,@
M2%144%]297%U97-T7TQI<W1E;F5R(`I["B`@("\J*@H@("`@*B!!(&QI<W1E
M;F5R)W,@:61E;G1I9FEE<@H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@
M('9A<B`D7VED.PH*("`@+RHJ"B`@("`J($-O;G-T<G5C=&]R+"!S971S('1H
M92!O8FIE8W0G<R!I9&5N=&EF:65R"B`@("`J"B`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@2%144%]297%U97-T7TQI<W1E;F5R
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*'5N:7%I9"@G:'1T
M<%]R97%U97-T7R<L(#$I*3L*("`@('T*"@H@("`O*BH*("`@("H@4F5T=7)N
M<R!T:&4@;&ES=&5N97(G<R!I9&5N=&EF:65R"B`@("`J"B`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`J($!R971U<FX@<W1R:6YG"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T260H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VED
M.PH@("`@?0H*"B`@("\J*@H@("`@*B!4:&ES(&UE=&AO9"!I<R!C86QL960@
M=VAE;B!,:7-T96YE<B!I<R!N;W1I9FEE9"!O9B!A;B!E=F5N=`H@("`@*@H@
M("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!O8FIE8W0@
M(&%N(&]B:F5C="!T:&4@;&ES=&5N97(@:7,@871T86-H960@=&\*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@179E;G0@;F%M90H@("`@*B!`<&%R86T@("`@
M;6EX960@("!!9&1I=&EO;F%L(&1A=&$*("`@("H@0&%B<W1R86-T"B`@("`J
M+PH@("`@9G5N8W1I;VX@=7!D871E*"8D<W5B:F5C="P@)&5V96YT+"`D9&%T
M82`](&YU;&PI"B`@("!["B`@("`@("`@96-H;R`B3F]T:69I960@;V8@979E
M;G0Z("<D979E;G0G7&XB.PH@("`@("`@(&EF("AN=6QL("$]/2`D9&%T82D@
M>PH@("`@("`@("`@("!E8VAO(")!9&1I=&EO;F%L(&1A=&$Z("(["B`@("`@
M("`@("`@('9A<E]D=6UP*"1D871A*3L*("`@("`@("!]"B`@("!]"GT*/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O2%144"]297%U97-T+G!H<```````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3$R-S$`,3`U,34T,S$P-3<`,#(P
M,C8T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,RP@4FEC:&%R9"!(97EE<R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S
M97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@
M4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H
M92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@
M9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO
M+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N
M=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T
M:&4@9&ES=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T
M:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@
M("`@?`HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A
M<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P
M97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@
M5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O
M('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y4
M2453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/
M+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!
M3D0@1DE43D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4
M("!\"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-5
M4D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@
M3T8@55-%+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@
M24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@
M?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!3
M5%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@
M3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/
M550@3T8@5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)
M1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@
M('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!2:6-H87)D($AE
M>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z(%)E<75E<W0N<&AP+'8@,2XT,R`R,#`U+S$Q+S`V(#$X.C(Y.C$T
M(&%V8B!%>'`@)`HO+PHO+R!(5%107U)E<75E<W0@0VQA<W,*+R\*+R\@4VEM
M<&QE(&5X86UP;&4L("A&971C:&5S('EA:&]O+F-O;2!A;F0@9&ES<&QA>7,@
M:70I.@HO+PHO+R`D82`]("9N97<@2%144%]297%U97-T*"=H='1P.B\O=W=W
M+GEA:&]O+F-O;2\G*3L*+R\@)&$M/G-E;F1297%U97-T*"D["B\O(&5C:&\@
M)&$M/F=E=%)E<W!O;G-E0F]D>2@I.PHO+PH*<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<["G)E<75I<F5?;VYC92`G3F5T+U-O8VME="YP:'`G.PIR97%U:7)E
M7V]N8V4@)TYE="]54DPN<&AP)SL*"F1E9FEN92@G2%144%]215%515-47TU%
M5$A/1%]'150G+"`@("`@)T=%5"<L("`@("!T<G5E*3L*9&5F:6YE*"=(5%10
M7U)%455%4U1?34542$]$7TA%040G+"`@("`G2$5!1"<L("`@('1R=64I.PID
M969I;F4H)TA45%!?4D5154535%]-151(3T1?4$]35"<L("`@("=03U-4)RP@
M("`@=')U92D["F1E9FEN92@G2%144%]215%515-47TU%5$A/1%]0550G+"`@
M("`@)U!55"<L("`@("!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?3454
M2$]$7T1%3$5412<L("`G1$5,151%)RP@('1R=64I.PID969I;F4H)TA45%!?
M4D5154535%]-151(3T1?3U!424].4R<L("=/4%1)3TY3)RP@=')U92D["F1E
M9FEN92@G2%144%]215%515-47TU%5$A/1%]44D%#12<L("`@)U1204-%)RP@
M("!T<G5E*3L*"F1E9FEN92@G2%144%]215%515-47TA45%!?5D527S%?,"<L
M("<Q+C`G+"!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?2%144%]615)?
M,5\Q)RP@)S$N,2<L('1R=64I.PH*8VQA<W,@2%144%]297%U97-T('L*"B`@
M("`O*BH*("`@("H@26YS=&%N8V4@;V8@3F5T7U523`H@("`@*B!`=F%R(&]B
M:F5C="!.971?55),"B`@("`J+PH@("`@=F%R("1?=7)L.PH*("`@("\J*@H@
M("`@*B!4>7!E(&]F(')E<75E<W0*("`@("H@0'9A<B!S=')I;F<*("`@("HO
M"B`@("!V87(@)%]M971H;V0["@H@("`@+RHJ"B`@("`J($A45%`@5F5R<VEO
M;@H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7VAT='`["@H@
M("`@+RHJ"B`@("`J(%)E<75E<W0@:&5A9&5R<PH@("`@*B!`=F%R(&%R<F%Y
M"B`@("`J+PH@("`@=F%R("1?<F5Q=65S=$AE861E<G,["@H@("`@+RHJ"B`@
M("`J($)A<VEC($%U=&@@57-E<FYA;64*("`@("H@0'9A<B!S=')I;F<*("`@
M("HO"B`@("!V87(@)%]U<V5R.PH@("`@"B`@("`O*BH*("`@("H@0F%S:6,@
M075T:"!087-S=V]R9`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A
M<B`D7W!A<W,["@H@("`@+RHJ"B`@("`J(%-O8VME="!O8FIE8W0*("`@("H@
M0'9A<B!O8FIE8W0@3F5T7U-O8VME=`H@("`@*B\*("`@('9A<B`D7W-O8VL[
M"B`@("`*("`@("\J*@H@("`@*B!0<F]X>2!S97)V97(*("`@("H@0'9A<B!S
M=')I;F<*("`@("HO"B`@("!V87(@)%]P<F]X>5]H;W-T.PH@("`@"B`@("`O
M*BH*("`@("H@4')O>'D@<&]R=`H@("`@*B!`=F%R(&EN=&5G97(*("`@("HO
M"B`@("!V87(@)%]P<F]X>5]P;W)T.PH@("`@"B`@("`O*BH*("`@("H@4')O
M>'D@=7-E<FYA;64*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@
M)%]P<F]X>5]U<V5R.PH@("`@"B`@("`O*BH*("`@("H@4')O>'D@<&%S<W=O
M<F0*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]P<F]X>5]P
M87-S.PH*("`@("\J*@H@("`@*B!0;W-T(&1A=&$*("`@("H@0'9A<B!A<G)A
M>0H@("`@*B\*("`@('9A<B`D7W!O<W1$871A.PH*("`@+RHJ"B`@("`J(%)E
M<75E<W0@8F]D>2`@"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R
M("1?8F]D>3L*"B`@("\J*@H@("`@*B!!(&QI<W0@;V8@;65T:&]D<R!T:&%T
M($U54U0@3D]4(&AA=F4@82!R97%U97-T(&)O9'DL('!E<B!21D,@,C8Q-@H@
M("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?8F]D>41I<V%L;&]W
M960@/2!A<G)A>2@G5%)!0T4G*3L*"B`@("\J*@H@("`@*B!&:6QE<R!T;R!P
M;W-T(`H@("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?<&]S=$9I
M;&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("H@0V]N;F5C=&EO;B!T:6UE
M;W5T+@H@("`@*B!`=F%R(&9L;V%T"B`@("`J+PH@("`@=F%R("1?=&EM96]U
M=#L*("`@(`H@("`@+RHJ"B`@("`J($A45%!?4F5S<&]N<V4@;V)J96-T"B`@
M("`J($!V87(@;V)J96-T($A45%!?4F5S<&]N<V4*("`@("HO"B`@("!V87(@
M)%]R97-P;VYS93L*("`@(`H@("`@+RHJ"B`@("`J(%=H971H97(@=&\@86QL
M;W<@<F5D:7)E8W1S"B`@("`J($!V87(@8F]O;&5A;@H@("`@*B\*("`@('9A
M<B`D7V%L;&]W4F5D:7)E8W1S.PH@("`@"B`@("`O*BH*("`@("H@36%X:6UU
M;2!R961I<F5C=',@86QL;W=E9`H@("`@*B!`=F%R(&EN=&5G97(*("`@("HO
M"B`@("!V87(@)%]M87A2961I<F5C=',["B`@("`*("`@("\J*@H@("`@*B!#
M=7)R96YT(&YU;6)E<B!O9B!R961I<F5C=',*("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`J+PH@("`@=F%R("1?<F5D:7)E8W1S.PH*("`@+RHJ"B`@("`J(%=H
M971H97(@=&\@87!P96YD(&)R86-K971S(%M=('1O(&%R<F%Y('9A<FEA8FQE
M<PH@("`@*B!`=F%R(&)O;VP*("`@("HO"B`@("!V87(@)%]U<V5"<F%C:V5T
M<R`]('1R=64["@H@("`O*BH*("`@("H@071T86-H960@;&ES=&5N97)S"B`@
M("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]L:7-T96YE<G,@/2!A
M<G)A>2@I.PH*("`@+RHJ"B`@("`J(%=H971H97(@=&\@<V%V92!R97-P;VYS
M92!B;V1Y(&EN(')E<W!O;G-E(&]B:F5C="!P<F]P97)T>2`@"B`@("`J($!V
M87(@8F]O;`H@("`@*B\*("`@('9A<B`D7W-A=F5";V1Y(#T@=')U93L*"B`@
M("\J*@H@("`@*B!4:6UE;W5T(&9O<B!R96%D:6YG(&9R;VT@<V]C:V5T("AA
M<G)A>2AS96-O;F1S+"!M:6-R;W-E8V]N9',I*0H@("`@*B!`=F%R(&%R<F%Y
M"B`@("`J+PH@("`@=F%R("1?<F5A9%1I;65O=70@/2!N=6QL.PH*("`@+RHJ
M"B`@("`J($]P=&EO;G,@=&\@<&%S<R!T;R!.971?4V]C:V5T.CIC;VYN96-T
M+B!3964@<W1R96%M7V-O;G1E>'1?8W)E871E"B`@("`J($!V87(@87)R87D*
M("`@("HO"B`@("!V87(@)%]S;V-K971/<'1I;VYS(#T@;G5L;#L*"B`@("`O
M*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*("`@("H@4V5T<R!U<"!T:&4@
M;V)J96-T"B`@("`J($!P87)A;2`@("!S=')I;F<@(%1H92!U<FP@=&\@9F5T
M8V@O86-C97-S"B`@("`J($!P87)A;2`@("!A<G)A>2`@($%S<V]C:6%T:79E
M(&%R<F%Y(&]F('!A<F%M971E<G,@=VAI8V@@8V%N(&AA=F4@=&AE(&9O;&QO
M=VEN9R!K97ES.@H@("`@*B`\=6P^"B`@("`J("`@/&QI/FUE=&AO9"`@("`@
M("`@("T@365T:&]D('1O('5S92P@1T54+"!03U-4(&5T8R`H<W1R:6YG*3PO
M;&D^"B`@("`J("`@/&QI/FAT='`@("`@("`@("`@("T@2%144"!697)S:6]N
M('1O('5S92P@,2XP(&]R(#$N,2`H<W1R:6YG*3PO;&D^"B`@("`J("`@/&QI
M/G5S97(@("`@("`@("`@("T@0F%S:6,@075T:"!U<V5R;F%M92`H<W1R:6YG
M*3PO;&D^"B`@("`J("`@/&QI/G!A<W,@("`@("`@("`@("T@0F%S:6,@075T
M:"!P87-S=V]R9"`H<W1R:6YG*3PO;&D^"B`@("`J("`@/&QI/G!R;WAY7VAO
M<W0@("`@("T@4')O>'D@<V5R=F5R(&AO<W0@*'-T<FEN9RD\+VQI/@H@("`@
M*B`@(#QL:3YP<F]X>5]P;W)T("`@("`M(%!R;WAY('-E<G9E<B!P;W)T("AI
M;G1E9V5R*3PO;&D^"B`@("`J("`@/&QI/G!R;WAY7W5S97(@("`@("T@4')O
M>'D@875T:"!U<V5R;F%M92`H<W1R:6YG*3PO;&D^"B`@("`J("`@/&QI/G!R
M;WAY7W!A<W,@("`@("T@4')O>'D@875T:"!P87-S=V]R9"`H<W1R:6YG*3PO
M;&D^"B`@("`J("`@/&QI/G1I;65O=70@("`@("`@("T@0V]N;F5C=&EO;B!T
M:6UE;W5T(&EN('-E8V]N9',@*&9L;V%T*3PO;&D^"B`@("`J("`@/&QI/F%L
M;&]W4F5D:7)E8W1S("T@5VAE=&AE<B!T;R!F;VQL;W<@<F5D:7)E8W1S(&]R
M(&YO="`H8F]O;"D\+VQI/@H@("`@*B`@(#QL:3YM87A2961I<F5C=',@("`M
M($UA>"!N=6UB97(@;V8@<F5D:7)E8W1S('1O(&9O;&QO=R`H:6YT96=E<BD\
M+VQI/@H@("`@*B`@(#QL:3YU<V5"<F%C:V5T<R`@("`M(%=H971H97(@=&\@
M87!P96YD(%M=('1O(&%R<F%Y('9A<FEA8FQE(&YA;65S("AB;V]L*3PO;&D^
M"B`@("`J("`@/&QI/G-A=F5";V1Y("`@("`@("T@5VAE=&AE<B!T;R!S879E
M(')E<W!O;G-E(&)O9'D@:6X@<F5S<&]N<V4@;V)J96-T('!R;W!E<G1Y("AB
M;V]L*3PO;&D^"B`@("`J("`@/&QI/G)E8614:6UE;W5T("`@("T@5&EM96]U
M="!F;W(@<F5A9&EN9R`O('=R:71I;F<@9&%T82!O=F5R('1H92!S;V-K970@
M*&%R<F%Y("AS96-O;F1S+"!M:6-R;W-E8V]N9',I*3PO;&D^"B`@("`J("`@
M/&QI/G-O8VME=$]P=&EO;G,@("T@3W!T:6]N<R!T;R!P87-S('1O($YE=%]3
M;V-K970@;V)J96-T("AA<G)A>2D\+VQI/@H@("`@*B`\+W5L/@H@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N($A45%!?4F5Q=65S
M="@D=7)L(#T@)R<L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<V]C:R`@("`@("`@("`@/2`F;F5W($YE=%]3;V-K970H*3L*
M("`@("`@("`D=&AI<RT^7VUE=&AO9"`@("`@("`@(#T@($A45%!?4D515453
M5%]-151(3T1?1T54.PH@("`@("`@("1T:&ES+3Y?:'1T<"`@("`@("`@("`@
M/2`@2%144%]215%515-47TA45%!?5D527S%?,3L*("`@("`@("`D=&AI<RT^
M7W)E<75E<W1(96%D97)S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W!O
M<W1$871A("`@("`@(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V)O9'D@
M("`@("`@("`@(#T@;G5L;#L*"B`@("`@("`@)'1H:7,M/E]U<V5R(#T@;G5L
M;#L*("`@("`@("`D=&AI<RT^7W!A<W,@/2!N=6QL.PH*("`@("`@("`D=&AI
M<RT^7W!R;WAY7VAO<W0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?<')O>'E?
M<&]R="`](&YU;&P["B`@("`@("`@)'1H:7,M/E]P<F]X>5]U<V5R(#T@;G5L
M;#L*("`@("`@("`D=&AI<RT^7W!R;WAY7W!A<W,@/2!N=6QL.PH*("`@("`@
M("`D=&AI<RT^7V%L;&]W4F5D:7)E8W1S(#T@9F%L<V4["B`@("`@("`@)'1H
M:7,M/E]M87A2961I<F5C=',@("`](#,["B`@("`@("`@)'1H:7,M/E]R961I
M<F5C=',@("`@("`](#`["@H@("`@("`@("1T:&ES+3Y?=&EM96]U="`@/2!N
M=6QL.PH@("`@("`@("1T:&ES+3Y?<F5S<&]N<V4@/2!N=6QL.PH*("`@("`@
M("!F;W)E86-H("@D<&%R86US(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1T:&ES+3Y[)U\G("X@)&ME>7T@/2`D=F%L=64["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(65M<'1Y*"1U<FPI*2!["B`@("`@("`@("`@("1T
M:&ES+3YS97154DPH)'5R;"D["B`@("`@("`@?0H*("`@("`@("`O+R!$969A
M=6QT('5S97)A9V5N=`H@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U5S97(M
M06=E;G0G+"`G4$5!4B!(5%107U)E<75E<W0@8VQA<W,@*"!H='1P.B\O<&5A
M<BYP:'`N;F5T+R`I)RD["@H@("`@("`@("\O($UA:V4@<W5R92!K965P86QI
M=F5S(&1O;G0@:VYO8F)L92!U<PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H
M)T-O;FYE8W1I;VXG+"`G8VQO<V4G*3L*"B`@("`@("`@+R\@0F%S:6,@875T
M:&5N=&EC871I;VX*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?=7-E<BDI
M('L*("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G075T:&]R:7IA=&EO
M;B<L("="87-I8R`G("X@8F%S938T7V5N8V]D92@D=&AI<RT^7W5S97(@+B`G
M.B<@+B`D=&AI<RT^7W!A<W,I*3L*("`@("`@("!]"@H@("`@("`@("\O(%5S
M92!G>FEP(&5N8V]D:6YG(&EF('!O<W-I8FQE"B`@("`@("`@+R\@079O:60@
M9WII<"!E;F-O9&EN9R!I9B!U<VEN9R!M=6QT:6)Y=&4@9G5N8W1I;VYS("AS
M964@(S$W.#$I"B`@("`@("`@:68@*$A45%!?4D5154535%](5%107U9%4E\Q
M7S$@/3T@)'1H:7,M/E]H='1P("8F(&5X=&5N<VEO;E]L;V%D960H)WIL:6(G
M*2`F)@H@("`@("`@("`@("`P(#T]("@R("8@:6YI7V=E="@G;6)S=')I;F<N
M9G5N8U]O=F5R;&]A9"<I*2D@>PH*("`@("`@("`@("`@)'1H:7,M/F%D9$AE
M861E<B@G06-C97!T+45N8V]D:6YG)RP@)V=Z:7`G*3L*("`@("`@("!]"B`@
M("!]"B`@("`*("`@("\J*@H@("`@*B!'96YE<F%T97,@82!(;W-T(&AE861E
M<B!F;W(@2%144"\Q+C$@<F5Q=65S=',*("`@("H*("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`J($!R971U<FX@<W1R:6YG"B`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E;F5R871E2&]S=$AE861E<B@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3Y?=7)L+3YP;W)T("$](#@P($%.1"!S=')C87-E8VUP*"1T:&ES+3Y?
M=7)L+3YP<F]T;V-O;"P@)VAT='`G*2`]/2`P*2!["B`@("`@("`@("`@("1H
M;W-T(#T@)'1H:7,M/E]U<FPM/FAO<W0@+B`G.B<@+B`D=&AI<RT^7W5R;"T^
M<&]R=#L*"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?=7)L+3YP;W)T("$]
M(#0T,R!!3D0@<W1R8V%S96-M<"@D=&AI<RT^7W5R;"T^<')O=&]C;VPL("=H
M='1P<R<I(#T](#`I('L*("`@("`@("`@("`@)&AO<W0@/2`D=&AI<RT^7W5R
M;"T^:&]S="`N("<Z)R`N("1T:&ES+3Y?=7)L+3YP;W)T.PH*("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/E]U<FPM/G!O<G0@/3T@-#0S($%.1"!S=')C87-E
M8VUP*"1T:&ES+3Y?=7)L+3YP<F]T;V-O;"P@)VAT='!S)RD@/3T@,"!!3D0@
M<W1R<&]S*"1T:&ES+3Y?=7)L+3YU<FPL("<Z-#0S)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1H;W-T(#T@)'1H:7,M/E]U<FPM/FAO<W0@+B`G.B<@
M+B`D=&AI<RT^7W5R;"T^<&]R=#L*("`@("`@("`*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D:&]S="`]("1T:&ES+3Y?=7)L+3YH;W-T.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1H;W-T.PH@("`@?0H@("`@"B`@("`O
M*BH*("`@("H@4F5S971S('1H92!O8FIE8W0@=&\@:71S(&EN:71I86P@<W1A
M=&4@*$1%4%)%0T%4140I+@H@("`@*B!486ME<R!T:&4@<V%M92!P87)A;65T
M97)S(&%S('1H92!C;VYS=')U8W1O<BX*("`@("H*("`@("H@0'!A<F%M("!S
M=')I;F<@)'5R;"`@("!4:&4@=7)L('1O(&)E(')E<75E<W1E9`H@("`@*B!`
M<&%R86T@(&%R<F%Y("`D<&%R86US($%S<V]C:6%T:79E(&%R<F%Y(&]F('!A
M<F%M971E<G,*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`H<V5E(&-O
M;G-T<G5C=&]R(&9O<B!D971A:6QS*0H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*B!`9&5P<F5C871E9"!D97!R96-A=&5D('-I;F-E(#$N,BP@8V%L;"!T
M:&4@8V]N<W1R=6-T;W(@:68@=&AI<R!I<R!N96-E<W-A<GD*("`@("HO"B`@
M("!F=6YC=&EO;B!R97-E="@D=7)L+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D=&AI<RT^2%144%]297%U97-T*"1U<FPL("1P87)A;7,I
M.PH@("`@?0H*("`@("\J*@H@("`@*B!3971S('1H92!54DP@=&\@8F4@<F5Q
M=65S=&5D"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG(%1H92!U<FP@=&\@
M8F4@<F5Q=65S=&5D"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T55),*"1U<FPI"B`@("!["B`@("`@("`@)'1H:7,M/E]U
M<FP@/2`F;F5W($YE=%]54DPH)'5R;"P@)'1H:7,M/E]U<V5"<F%C:V5T<RD[
M"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]U<FPM/G5S97(I('Q\("%E
M;7!T>2@D=&AI<RT^7W5R;"T^<&%S<RDI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=$)A<VEC075T:"@D=&AI<RT^7W5R;"T^=7-E<BP@)'1H:7,M/E]U<FPM
M/G!A<W,I.PH@("`@("`@('T*"B`@("`@("`@:68@*$A45%!?4D5154535%](
M5%107U9%4E\Q7S$@/3T@)'1H:7,M/E]H='1P*2!["B`@("`@("`@("`@("1T
M:&ES+3YA9&1(96%D97(H)TAO<W0G+"`D=&AI<RT^7V=E;F5R871E2&]S=$AE
M861E<B@I*3L*("`@("`@("!]"B`@("!]"B`@("`*("`@("\J*@H@("`@*B!3
M971S(&$@<')O>'D@=&\@8F4@=7-E9`H@("`@*@H@("`@*B!`<&%R86T@<W1R
M:6YG("`@("!0<F]X>2!H;W-T"B`@("`J($!P87)A;2!I;G0@("`@("`@(%!R
M;WAY('!O<G0*("`@("H@0'!A<F%M('-T<FEN9R`@("`@4')O>'D@=7-E<FYA
M;64*("`@("H@0'!A<F%M('-T<FEN9R`@("`@4')O>'D@<&%S<W=O<F0*("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S9710<F]X
M>2@D:&]S="P@)'!O<G0@/2`X,#@P+"`D=7-E<B`](&YU;&PL("1P87-S(#T@
M;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W!R;WAY7VAO<W0@/2`D:&]S
M=#L*("`@("`@("`D=&AI<RT^7W!R;WAY7W!O<G0@/2`D<&]R=#L*("`@("`@
M("`D=&AI<RT^7W!R;WAY7W5S97(@/2`D=7-E<CL*("`@("`@("`D=&AI<RT^
M7W!R;WAY7W!A<W,@/2`D<&%S<SL*"B`@("`@("`@:68@*"%E;7!T>2@D=7-E
M<BDI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G4')O>'DM075T
M:&]R:7IA=&EO;B<L("="87-I8R`G("X@8F%S938T7V5N8V]D92@D=7-E<B`N
M("<Z)R`N("1P87-S*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M*B!3971S(&)A<VEC(&%U=&AE;G1I8V%T:6]N('!A<F%M971E<G,*("`@("H*
M("`@("H@0'!A<F%M('-T<FEN9R`@("`@57-E<FYA;64*("`@("H@0'!A<F%M
M('-T<FEN9R`@("`@4&%S<W=O<F0*("`@("HO"B`@("!F=6YC=&EO;B!S971"
M87-I8T%U=&@H)'5S97(L("1P87-S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M=7-E<B`]("1U<V5R.PH@("`@("`@("1T:&ES+3Y?<&%S<R`]("1P87-S.PH*
M("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=!=71H;W)I>F%T:6]N)RP@)T)A
M<VEC("<@+B!B87-E-C1?96YC;V1E*"1U<V5R("X@)SHG("X@)'!A<W,I*3L*
M("`@('T*"B`@("`O*BH*("`@("H@4V5T<R!T:&4@;65T:&]D('1O(&)E('5S
M960L($=%5"P@4$]35"!E=&,N"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@
M("`@($UE=&AO9"!T;R!U<V4N(%5S92!T:&4@9&5F:6YE9"!C;VYS=&%N=',@
M9F]R('1H:7,*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC
M=&EO;B!S971-971H;V0H)&UE=&AO9"D*("`@('L*("`@("`@("`D=&AI<RT^
M7VUE=&AO9"`]("1M971H;V0["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E=',@
M=&AE($A45%`@=F5R<VEO;B!T;R!U<V4L(#$N,"!O<B`Q+C$*("`@("H*("`@
M("H@0'!A<F%M('-T<FEN9R`@("`@5F5R<VEO;B!T;R!U<V4N(%5S92!T:&4@
M9&5F:6YE9"!C;VYS=&%N=',@9F]R('1H:7,*("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("HO"B`@("!F=6YC=&EO;B!S971(='1P5F5R*"1H='1P*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?:'1T<"`]("1H='1P.PH@("`@?0H*("`@("\J
M*@H@("`@*B!!9&1S(&$@<F5Q=65S="!H96%D97(*("`@("H*("`@("H@0'!A
M<F%M('-T<FEN9R`@("`@2&5A9&5R(&YA;64*("`@("H@0'!A<F%M('-T<FEN
M9R`@("`@2&5A9&5R('9A;'5E"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J
M+PH@("`@9G5N8W1I;VX@861D2&5A9&5R*"1N86UE+"`D=F%L=64I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]R97%U97-T2&5A9&5R<UMS=')T;VQO=V5R*"1N
M86UE*5T@/2`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E;6]V97,@
M82!R97%U97-T(&AE861E<@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@
M("!(96%D97(@;F%M92!T;R!R96UO=F4*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5(96%D97(H)&YA;64I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<F5Q=65S=$AE861E<G-;<W1R
M=&]L;W=E<B@D;F%M92E=*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M7W)E<75E<W1(96%D97)S6W-T<G1O;&]W97(H)&YA;64I72D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@*B!!9&1S(&$@<75E<GES=')I;F<@<&%R
M86UE=&5R"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@("`@(%%U97)Y<W1R
M:6YG('!A<F%M971E<B!N86UE"B`@("`J($!P87)A;2!S=')I;F<@("`@(%%U
M97)Y<W1R:6YG('!A<F%M971E<B!V86QU90H@("`@*B!`<&%R86T@8F]O;"`@
M("`@("!7:&5T:&5R('1H92!V86QU92!I<R!A;')E861Y('5R;&5N8V]D960@
M;W(@;F]T+"!D969A=6QT(#T@;F]T"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J+PH@("`@9G5N8W1I;VX@861D475E<GE3=')I;F<H)&YA;64L("1V86QU
M92P@)'!R965N8V]D960@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^
M7W5R;"T^861D475E<GE3=')I;F<H)&YA;64L("1V86QU92P@)'!R965N8V]D
M960I.PH@("`@?2`@("`*("`@(`H@("`@+RHJ"B`@("`J(%-E=',@=&AE('%U
M97)Y<W1R:6YG('1O(&QI=&5R86QL>2!W:&%T('EO=2!S=7!P;'D*("`@("H*
M("`@("H@0'!A<F%M('-T<FEN9R`@("`@5&AE('%U97)Y<W1R:6YG(&1A=&$N
M(%-H;W5L9"!B92!O9B!T:&4@9F]R;6%T(&9O;SUB87(F>#UY(&5T8PH@("`@
M*B!`<&%R86T@8F]O;"`@("`@("!7:&5T:&5R(&1A=&$@:7,@86QR96%D>2!U
M<FQE;F-O9&5D(&]R(&YO="P@9&5F875L="`](&%L<F5A9'D@96YC;V1E9`H@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&%D9%)A
M=U%U97)Y4W1R:6YG*"1Q=65R>7-T<FEN9RP@)'!R965N8V]D960@/2!T<G5E
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=7)L+3YA9&1287=1=65R>5-T<FEN
M9R@D<75E<GES=')I;F<L("1P<F5E;F-O9&5D*3L*("`@('T*"B`@("`O*BH*
M("`@("H@061D<R!P;W-T9&%T82!I=&5M<PH@("`@*@H@("`@*B!`<&%R86T@
M<W1R:6YG("`@("!0;W-T(&1A=&$@;F%M90H@("`@*B!`<&%R86T@<W1R:6YG
M("`@("!0;W-T(&1A=&$@=F%L=64*("`@("H@0'!A<F%M(&)O;VP@("`@("`@
M5VAE=&AE<B!D871A(&ES(&%L<F5A9'D@=7)L96YC;V1E9"!O<B!N;W0L(&1E
M9F%U;'0@/2!N;W0*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F
M=6YC=&EO;B!A9&10;W-T1&%T82@D;F%M92P@)'9A;'5E+"`D<')E96YC;V1E
M9"`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D<')E96YC;V1E9"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W!O<W1$871A6R1N86UE72`]("1V86QU93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W!O<W1$871A
M6R1N86UE72`]("1T:&ES+3Y?87)R87E-87!296-U<G-I=F4H)W5R;&5N8V]D
M92<L("1V86QU92D["B`@("`@("`@?0H@("`@?0H*("`@+RHJ"B`@("`J(%)E
M8W5R<VEV96QY(&%P<&QI97,@=&AE(&-A;&QB86-K(&9U;F-T:6]N('1O('1H
M92!V86QU90H@("`@*B`*("`@("H@0'!A<F%M("`@(&UI>&5D("`@0V%L;&)A
M8VL@9G5N8W1I;VX*("`@("H@0'!A<F%M("`@(&UI>&5D("`@5F%L=64@=&\@
M<')O8V5S<PH@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<F5T=7)N
M("`@;6EX960@("!0<F]C97-S960@=F%L=64*("`@("HO"B`@("!F=6YC=&EO
M;B!?87)R87E-87!296-U<G-I=F4H)&-A;&QB86-K+"`D=F%L=64I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@
M(')E='5R;B!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("1V86QU92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UA<"`](&%R<F%Y*"D["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:R`]/B`D=BD@>PH@("`@
M("`@("`@("`@("`@)&UA<%LD:UT@/2`D=&AI<RT^7V%R<F%Y36%P4F5C=7)S
M:79E*"1C86QL8F%C:RP@)'8I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B`D;6%P.PH@("`@("`@('T*("`@('T*"B`@("\J*@H@("`@*B!!
M9&1S(&$@9FEL92!T;R!U<&QO860*("`@("H@"B`@("`J(%1H:7,@86QS;R!C
M:&%N9V5S(&-O;G1E;G0M='EP92!T;R`G;75L=&EP87)T+V9O<FTM9&%T82<@
M9F]R('!R;W!E<B!U<&QO860*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J($!P87)A;2`@<W1R:6YG("`@(&YA;64@;V8@9FEL92UU<&QO860@
M9FEE;&0*("`@("H@0'!A<F%M("!M:7AE9"`@("`@9FEL92!N86UE*',I"B`@
M("`J($!P87)A;2`@;6EX960@("`@(&-O;G1E;G0M='EP92AS*2!O9B!F:6QE
M*',I(&)E:6YG('5P;&]A9&5D"B`@("`J($!R971U<FX@8F]O;"`@("`@('1R
M=64@;VX@<W5C8V5S<PH@("`@*B!`=&AR;W=S(%!%05)?17)R;W(*("`@("HO
M"B`@("!F=6YC=&EO;B!A9&1&:6QE*"1I;G!U=$YA;64L("1F:6QE3F%M92P@
M)&-O;G1E;G14>7!E(#T@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<I"B`@
M("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D9FEL94YA;64I("8F("%I<U]R
M96%D86)L92@D9FEL94YA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*")&:6QE("=[)&9I;&5.86UE?2<@:7,@;F]T(')E861A
M8FQE(BD["B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1F:6QE3F%M92DI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5.86UE(&%S("1N86UE*2![
M"B`@("`@("`@("`@("`@("!I9B`H(6ES7W)E861A8FQE*"1N86UE*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&
M:6QE("=[)&YA;65])R!I<R!N;W0@<F5A9&%B;&4B*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^
M861D2&5A9&5R*"=#;VYT96YT+51Y<&4G+"`G;75L=&EP87)T+V9O<FTM9&%T
M82<I.PH@("`@("`@("1T:&ES+3Y?<&]S=$9I;&5S6R1I;G!U=$YA;65=(#T@
M87)R87DH"B`@("`@("`@("`@("=N86UE)R`]/B`D9FEL94YA;64L"B`@("`@
M("`@("`@("=T>7!E)R`]/B`D8V]N=&5N=%1Y<&4*("`@("`@("`I.PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@*B!!9&1S(')A
M=R!P;W-T9&%T82`H1$504D5#051%1"D*("`@("H*("`@("H@0'!A<F%M('-T
M<FEN9R`@("`@5&AE(&1A=&$*("`@("H@0'!A<F%M(&)O;VP@("`@("`@5VAE
M=&AE<B!D871A(&ES('!R965N8V]D960@;W(@;F]T+"!D969A=6QT(#T@86QR
M96%D>2!E;F-O9&5D"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!D97!R
M96-A=&5D("`@("`@(&1E<')E8V%T960@<VEN8V4@,2XS+C`L(&UE=&AO9"!A
M9&1";V1Y*"D@<VAO=6QD(&)E('5S960@:6YS=&5A9`H@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9%)A=U!O<W1$871A*"1P;W-T9&%T82P@)'!R965N8V]D960@
M/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8F]D>2`]("1P<F5E;F-O
M9&5D(#\@)'!O<W1D871A(#H@=7)L96YC;V1E*"1P;W-T9&%T82D["B`@("!]
M"@H@("`O*BH*("`@("H@4V5T<R!T:&4@<F5Q=65S="!B;V1Y("AF;W(@4$]3
M5"P@4%54(&%N9"!S:6UI;&%R(')E<75E<W1S*0H@("`@*@H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("!297%U97-T(&)O9'D*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N('-E=$)O9'DH)&)O9'DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]B;V1Y(#T@)&)O9'D["B`@("!]"@H@("`@+RHJ
M"B`@("`J($-L96%R<R!A;GD@<&]S=&1A=&$@=&AA="!H87,@8F5E;B!A9&1E
M9"`H1$504D5#051%1"DN(`H@("`@*B`*("`@("H@57-E9G5L(&9O<B!M=6QT
M:7!L92!R97%U97-T('-C96YA<FEO<RX*("`@("H*("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("H@0&1E<')E8V%T960@9&5P<F5C871E9"!S:6YC92`Q+C(*
M("`@("HO"B`@("!F=6YC=&EO;B!C;&5A<E!O<W1$871A*"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W!O<W1$871A(#T@;G5L;#L*("`@('T*"B`@("`O*BH*
M("`@("H@07!P96YD<R!A(&-O;VMI92!T;R`B0V]O:VEE.B(@:&5A9&5R"B`@
M("`J(`H@("`@*B!`<&%R86T@<W1R:6YG("1N86UE(&-O;VMI92!N86UE"B`@
M("`J($!P87)A;2!S=')I;F<@)'9A;'5E(&-O;VMI92!V86QU90H@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;VMI92@D
M;F%M92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1C;V]K:65S(#T@:7-S970H
M)'1H:7,M/E]R97%U97-T2&5A9&5R<ULG8V]O:VEE)UTI(#\@)'1H:7,M/E]R
M97%U97-T2&5A9&5R<ULG8V]O:VEE)UTN("<[("<@.B`G)SL*("`@("`@("`D
M=&AI<RT^861D2&5A9&5R*"=#;V]K:64G+"`D8V]O:VEE<R`N("1N86UE("X@
M)STG("X@)'9A;'5E*3L*("`@('T*("`@(`H@("`@+RHJ"B`@("`J($-L96%R
M<R!A;GD@8V]O:VEE<R!T:&%T(&AA=F4@8F5E;B!A9&1E9"`H1$504D5#051%
M1"DN(`H@("`@*B`*("`@("H@57-E9G5L(&9O<B!M=6QT:7!L92!R97%U97-T
M('-C96YA<FEO<PH@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`
M9&5P<F5C871E9"!D97!R96-A=&5D('-I;F-E(#$N,@H@("`@*B\*("`@(&9U
M;F-T:6]N(&-L96%R0V]O:VEE<R@I"B`@("!["B`@("`@("`@)'1H:7,M/G)E
M;6]V94AE861E<B@G0V]O:VEE)RD["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E
M;F1S('1H92!R97%U97-T"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J($!P87)A;2`@8F]O;"`@(%=H971H97(@=&\@<W1O<F4@<F5S<&]N<V4@
M8F]D>2!I;B!297-P;VYS92!O8FIE8W0@<')O<&5R='DL"B`@("`J("`@("`@
M("`@("`@("`@('-E="!T:&ES('1O(&9A;'-E(&EF(&1O=VYL;V%D:6YG(&$@
M3$%21T4@9FEL92!A;F0@=7-I;F<@82!,:7-T96YE<@H@("`@*B!`<F5T=7)N
M(&UI>&5D("!014%2(&5R<F]R(&]N(&5R<F]R+"!T<G5E(&]T:&5R=VES90H@
M("`@*B\*("`@(&9U;F-T:6]N('-E;F1297%U97-T*"1S879E0F]D>2`]('1R
M=64I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1T:&ES+3Y?=7)L+"`G3F5T
M7U523"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=.;R!54DP@9VEV96XN)RD["B`@("`@("`@?0H*("`@("`@("`D:&]S="`]
M(&ES<V5T*"1T:&ES+3Y?<')O>'E?:&]S="D@/R`D=&AI<RT^7W!R;WAY7VAO
M<W0@.B`D=&AI<RT^7W5R;"T^:&]S=#L*("`@("`@("`D<&]R="`](&ES<V5T
M*"1T:&ES+3Y?<')O>'E?<&]R="D@/R`D=&AI<RT^7W!R;WAY7W!O<G0@.B`D
M=&AI<RT^7W5R;"T^<&]R=#L*"B`@("`@("`@+R\@-"XS+C`@<W5P<&]R=',@
M4U-,(&-O;FYE8W1I;VYS('5S:6YG($]P96Y34TPN(%1H92!F=6YC=&EO;B!T
M97-T(&1E=&5R;6EN97,*("`@("`@("`O+R!W92!R=6YN:6YG(&]N(&%T(&QE
M87-T(#0N,RXP"B`@("`@("`@:68@*'-T<F-A<V5C;7`H)'1H:7,M/E]U<FPM
M/G!R;W1O8V]L+"`G:'1T<',G*2`]/2`P($%.1"!F=6YC=&EO;E]E>&ES=',H
M)V9I;&5?9V5T7V-O;G1E;G1S)RD@04Y$(&5X=&5N<VEO;E]L;V%D960H)V]P
M96YS<VPG*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F]X
M>5]H;W-T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)TA45%!3('!R;WAI97,@87)E(&YO="!S=7!P;W)T960N)RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&AO<W0@/2`G<W-L.B\O)R`N("1H
M;W-T.PH@("`@("`@('T*"B`@("`@("`@+R\@;6%G:6,@<75O=&5S(&UA>2!F
M=6-K('5P(&9I;&4@=7!L;V%D<R!A;F0@8VAU;FME9"!R97-P;VYS92!P<F]C
M97-S:6YG"B`@("`@("`@)&UA9VEC475O=&5S(#T@:6YI7V=E="@G;6%G:6-?
M<75O=&5S7W)U;G1I;64G*3L*("`@("`@("!I;FE?<V5T*"=M86=I8U]Q=6]T
M97-?<G5N=&EM92<L(&9A;'-E*3L*"B`@("`@("`@+R\@268@=&AI<R!I<R!A
M('-E8V]N9"!R97%U97-T+"!W92!M87D@9V5T(&%W87D@=VET:&]U=`H@("`@
M("`@("\O(')E+6-O;FYE8W1I;F<@:68@=&AE>2=R92!O;B!T:&4@<V%M92!S
M97)V97(*("`@("`@("`D97)R(#T@)'1H:7,M/E]S;V-K+3YC;VYN96-T*"1H
M;W-T+"`D<&]R="P@;G5L;"P@)'1H:7,M/E]T:6UE;W5T+"`D=&AI<RT^7W-O
M8VME=$]P=&EO;G,I.PH@("`@("`@(%!%05(Z.FES17)R;W(H)&5R<BD@;W(@
M)&5R<B`]("1T:&ES+3Y?<V]C:RT^=W)I=&4H)'1H:7,M/E]B=6EL9%)E<75E
M<W0H*2D["@H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<F5A9%1I;65O=70I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O8VLM/G-E=%1I;65O=70H)'1H
M:7,M/E]R96%D5&EM96]U=%LP72P@)'1H:7,M/E]R96%D5&EM96]U=%LQ72D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?;F]T:69Y*"=S
M96YT4F5Q=65S="<I.PH*("`@("`@("`@("`@+R\@4F5A9"!T:&4@<F5S<&]N
M<V4*("`@("`@("`@("`@)'1H:7,M/E]R97-P;VYS92`]("9N97<@2%144%]2
M97-P;VYS92@D=&AI<RT^7W-O8VLL("1T:&ES+3Y?;&ES=&5N97)S*3L*("`@
M("`@("`@("`@)&5R<B`]("1T:&ES+3Y?<F5S<&]N<V4M/G!R;V-E<W,H)'1H
M:7,M/E]S879E0F]D>2`F)B`D<V%V94)O9'DI.PH@("`@("`@('T*"B`@("`@
M("`@:6YI7W-E="@G;6%G:6-?<75O=&5S7W)U;G1I;64G+"`D;6%G:6-1=6]T
M97,I.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("!]"@H*("`@("`@("`O+R!#
M:&5C:R!F;W(@<F5D:7)E8W1I;VX*("`@("`@("!I9B`H("`@("1T:&ES+3Y?
M86QL;W=2961I<F5C=',*("`@("`@("`@("`@04Y$("1T:&ES+3Y?<F5D:7)E
M8W1S(#P]("1T:&ES+3Y?;6%X4F5D:7)E8W1S"B`@("`@("`@("`@($%.1"`D
M=&AI<RT^9V5T4F5S<&]N<V5#;V1E*"D@/B`S,#`*("`@("`@("`@("`@04Y$
M("1T:&ES+3YG971297-P;VYS94-O9&4H*2`\(#,Y.0H@("`@("`@("`@("!!
M3D0@(65M<'1Y*"1T:&ES+3Y?<F5S<&]N<V4M/E]H96%D97)S6R=L;V-A=&EO
M;B==*2D@>PH*("`@("`@("`@("`@"B`@("`@("`@("`@("1R961I<F5C="`]
M("1T:&ES+3Y?<F5S<&]N<V4M/E]H96%D97)S6R=L;V-A=&EO;B==.PH*("`@
M("`@("`@("`@+R\@06)S;VQU=&4@55),"B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7FAT='!S/SI<+UPO+VDG+"`D<F5D:7)E8W0I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W5R;"`]("9N97<@3F5T7U523"@D<F5D:7)E
M8W0I.PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G2&]S="<L
M("1T:&ES+3Y?9V5N97)A=&5(;W-T2&5A9&5R*"DI.PH@("`@("`@("`@("`O
M+R!!8G-O;'5T92!P871H"B`@("`@("`@("`@('T@96QS96EF("@D<F5D:7)E
M8W1[,'T@/3T@)R\G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W5R;"T^
M<&%T:"`]("1R961I<F5C=#L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O
M(%)E;&%T:79E('!A=&@*("`@("`@("`@("`@?2!E;'-E:68@*'-U8G-T<B@D
M<F5D:7)E8W0L(#`L(#,I(#T]("<N+B\G($]2('-U8G-T<B@D<F5D:7)E8W0L
M(#`L(#(I(#T]("<N+R<I('L*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H
M)'1H:7,M/E]U<FPM/G!A=&@L("TQ*2`]/2`G+R<I('L*("`@("`@("`@("`@
M("`@("`@("`D<F5D:7)E8W0@/2`D=&AI<RT^7W5R;"T^<&%T:"`N("1R961I
M<F5C=#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)')E9&ER96-T(#T@9&ER;F%M92@D=&AI<RT^7W5R;"T^<&%T:"D@
M+B`G+R<@+B`D<F5D:7)E8W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<F5D:7)E8W0@/2!.971?55),.CIR97-O;'9E4&%T:"@D<F5D
M:7)E8W0I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]U<FPM/G!A=&@@/2`D
M<F5D:7)E8W0["B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@+R\@1FEL
M96YA;64L(&YO('!A=&@*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&EF("AS=6)S='(H)'1H:7,M/E]U<FPM/G!A=&@L("TQ*2`]/2`G
M+R<I('L*("`@("`@("`@("`@("`@("`@("`D<F5D:7)E8W0@/2`D=&AI<RT^
M7W5R;"T^<&%T:"`N("1R961I<F5C=#L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)')E9&ER96-T(#T@9&ER;F%M92@D
M=&AI<RT^7W5R;"T^<&%T:"D@+B`G+R<@+B`D<F5D:7)E8W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7W5R;"T^<&%T:"`]
M("1R961I<F5C=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M
M/E]R961I<F5C=',K*SL*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS96YD
M4F5Q=65S="@D<V%V94)O9'DI.PH*("`@("`@("`O+R!4;V\@;6%N>2!R961I
M<F5C=',*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]A;&QO=U)E9&ER96-T
M<R!!3D0@)'1H:7,M/E]R961I<F5C=',@/B`D=&AI<RT^7VUA>%)E9&ER96-T
M<RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G5&]O
M(&UA;GD@<F5D:7)E8W1S)RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7W-O8VLM/F1I<V-O;FYE8W0H*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(')E<W!O;G-E(&-O9&4*
M("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0')E='5R;B!M:7AE
M9"`@("`@4F5S<&]N<V4@8V]D92P@9F%L<V4@:68@;F]T('-E=`H@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E0V]D92@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<F5S<&]N<V4M/E]C;V1E*2`_("1T:&ES
M+3Y?<F5S<&]N<V4M/E]C;V1E(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@
M("`J(%)E='5R;G,@96ET:&5R('1H92!N86UE9"!H96%D97(@;W(@86QL(&EF
M(&YO(&YA;64@9VEV96X*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("H@0'!A<F%M('-T<FEN9R`@("`@5&AE(&AE861E<B!N86UE('1O(')E='5R
M;BP@9&\@;F]T('-E="!T;R!G970@86QL(&AE861E<G,*("`@("H@0')E='5R
M;B!M:7AE9"`@("`@96ET:&5R('1H92!V86QU92!O9B`D:&5A9&5R;F%M92`H
M9F%L<V4@:68@:&5A9&5R(&ES(&YO="!P<F5S96YT*0H@("`@*B`@("`@("`@
M("`@("`@("`@("!O<B!A;B!A<G)A>2!O9B!A;&P@:&5A9&5R<PH@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E2&5A9&5R*"1H96%D97)N86UE(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1H96%D97)N86UE*2D@
M>PH@("`@("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]R97-P;VYS92T^
M7VAE861E<G,I/R`D=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<SH@87)R87DH
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:&5A9&5R;F%M92`]
M('-T<G1O;&]W97(H)&AE861E<FYA;64I.PH@("`@("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]R97-P;VYS92T^7VAE861E<G-;)&AE861E<FYA;65=
M*2`_("1T:&ES+3Y?<F5S<&]N<V4M/E]H96%D97)S6R1H96%D97)N86UE72`Z
M(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("H@4F5T=7)N
M<R!T:&4@8F]D>2!O9B!T:&4@<F5S<&]N<V4*("`@("H*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("H@0')E='5R;B!M:7AE9"`@("`@<F5S<&]N<V4@8F]D
M>2P@9F%L<V4@:68@;F]T('-E=`H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E
M<W!O;G-E0F]D>2@I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3Y?<F5S<&]N<V4M/E]B;V1Y*2`_("1T:&ES+3Y?<F5S<&]N<V4M/E]B;V1Y
M(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@8V]O:VEE
M<R!S970@:6X@<F5S<&]N<V4*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J($!R971U<FX@;6EX960@("`@(&%R<F%Y(&]F(')E<W!O;G-E(&-O
M;VMI97,L(&9A;'-E(&EF(&YO;F4@87)E('!R97-E;G0*("`@("HO"B`@("!F
M=6YC=&EO;B!G971297-P;VYS94-O;VMI97,H*0H@("`@>PH@("`@("`@(')E
M='5R;B!I<W-E="@D=&AI<RT^7W)E<W!O;G-E+3Y?8V]O:VEE<RD@/R`D=&AI
M<RT^7W)E<W!O;G-E+3Y?8V]O:VEE<R`Z(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@*B!"=6EL9',@=&AE(')E<75E<W0@<W1R:6YG"B`@("`J"B`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@<F5Q
M=65S="!S=')I;F<*("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&1297%U97-T
M*"D*("`@('L*("`@("`@("`D<V5P87)A=&]R(#T@:6YI7V=E="@G87)G7W-E
M<&%R871O<BYO=71P=70G*3L*("`@("`@("!I;FE?<V5T*"=A<F=?<V5P87)A
M=&]R+F]U='!U="<L("<F)RD["B`@("`@("`@)'%U97)Y<W1R:6YG(#T@*"1Q
M=65R>7-T<FEN9R`]("1T:&ES+3Y?=7)L+3YG9711=65R>5-T<FEN9R@I*2`_
M("<_)R`N("1Q=65R>7-T<FEN9R`Z("<G.PH@("`@("`@(&EN:5]S970H)V%R
M9U]S97!A<F%T;W(N;W5T<'5T)RP@)'-E<&%R871O<BD["@H@("`@("`@("1H
M;W-T(#T@:7-S970H)'1H:7,M/E]P<F]X>5]H;W-T*2`_("1T:&ES+3Y?=7)L
M+3YP<F]T;V-O;"`N("<Z+R\G("X@)'1H:7,M/E]U<FPM/FAO<W0@.B`G)SL*
M("`@("`@("`D<&]R="`]("AI<W-E="@D=&AI<RT^7W!R;WAY7VAO<W0I($%.
M1"`D=&AI<RT^7W5R;"T^<&]R="`A/2`X,"D@/R`G.B<@+B`D=&AI<RT^7W5R
M;"T^<&]R="`Z("<G.PH@("`@("`@("1P871H(#T@*&5M<'1Y*"1T:&ES+3Y?
M=7)L+3YP871H*3\@)R\G.B`D=&AI<RT^7W5R;"T^<&%T:"D@+B`D<75E<GES
M=')I;F<["B`@("`@("`@)'5R;"`@/2`D:&]S="`N("1P;W)T("X@)'!A=&@[
M"@H@("`@("`@("1R97%U97-T(#T@)'1H:7,M/E]M971H;V0@+B`G("<@+B`D
M=7)L("X@)R!(5%10+R<@+B`D=&AI<RT^7VAT='`@+B`B7')<;B(["@H@("`@
M("`@(&EF("AI;E]A<G)A>2@D=&AI<RT^7VUE=&AO9"P@)'1H:7,M/E]B;V1Y
M1&ES86QL;W=E9"D@?'P*("`@("`@("`@("`@*$A45%!?4D5154535%]-151(
M3T1?4$]35"`A/2`D=&AI<RT^7VUE=&AO9"`F)B!E;7!T>2@D=&AI<RT^7V)O
M9'DI*2!\?`H@("`@("`@("`@("`H2%144%]215%515-47TU%5$A/1%]03U-4
M("$]("1T:&ES+3Y?;65T:&]D("8F(&5M<'1Y*"1T:&ES+3Y?<&]S=$1A=&$I
M("8F(&5M<'1Y*"1T:&ES+3Y?<&]S=$9I;&5S*2DI('L*"B`@("`@("`@("`@
M("1T:&ES+3YR96UO=F5(96%D97(H)T-O;G1E;G0M5'EP92<I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W)E<75E
M<W1(96%D97)S6R=C;VYT96YT+71Y<&4G72DI('L*("`@("`@("`@("`@("`@
M("\O($%D9"!D969A=6QT(&-O;G1E;G0M='EP90H@("`@("`@("`@("`@("`@
M)'1H:7,M/F%D9$AE861E<B@G0V]N=&5N="U4>7!E)RP@)V%P<&QI8V%T:6]N
M+W@M=W=W+69O<FTM=7)L96YC;V1E9"<I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)VUU;'1I<&%R="]F;W)M+61A=&$G(#T]("1T:&ES+3Y?<F5Q=65S=$AE
M861E<G-;)V-O;G1E;G0M='EP92==*2!["B`@("`@("`@("`@("`@("`D8F]U
M;F1A<GD@/2`G2%144%]297%U97-T7R<@+B!M9#4H=6YI<6ED*"=R97%U97-T
M)RD@+B!M:6-R;W1I;64H*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^861D
M2&5A9&5R*"=#;VYT96YT+51Y<&4G+"`G;75L=&EP87)T+V9O<FTM9&%T83L@
M8F]U;F1A<GD])R`N("1B;W5N9&%R>2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O(%)E<75E<W0@2&5A9&5R<PH@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]R97%U97-T2&5A9&5R<RDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]R97%U97-T2&5A9&5R<R!A<R`D;F%M92`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@("`@("1C86YO;FEC86Q.86UE(#T@:6UP
M;&]D92@G+2<L(&%R<F%Y7VUA<"@G=6-F:7)S="<L(&5X<&QO9&4H)RTG+"`D
M;F%M92DI*3L*("`@("`@("`@("`@("`@("1R97%U97-T("`@("`@+CT@)&-A
M;F]N:6-A;$YA;64@+B`G.B`G("X@)'9A;'5E("X@(EQR7&XB.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!.;R!P;W-T(&1A=&$@;W(@
M=W)O;F<@;65T:&]D+"!S;R!S:6UP;'D@861D(&$@9FEN86P@0U),1@H@("`@
M("`@(&EF("AI;E]A<G)A>2@D=&AI<RT^7VUE=&AO9"P@)'1H:7,M/E]B;V1Y
M1&ES86QL;W=E9"D@?'P@"B`@("`@("`@("`@("A(5%107U)%455%4U1?3454
M2$]$7U!/4U0@(3T@)'1H:7,M/E]M971H;V0@)B8@96UP='DH)'1H:7,M/E]B
M;V1Y*2DI('L*"B`@("`@("`@("`@("1R97%U97-T("X](")<<EQN(CL*"B`@
M("`@("`@+R\@4&]S="!D871A(&EF(&ET)W,@86X@87)R87D*("`@("`@("!]
M(&5L<V5I9B`H2%144%]215%515-47TU%5$A/1%]03U-4(#T]("1T:&ES+3Y?
M;65T:&]D("8F(`H@("`@("`@("`@("`@("`@("`H(65M<'1Y*"1T:&ES+3Y?
M<&]S=$1A=&$I('Q\("%E;7!T>2@D=&AI<RT^7W!O<W1&:6QE<RDI*2!["@H@
M("`@("`@("`@("`O+R`B;F]R;6%L(B!03U-4(')E<75E<W0*("`@("`@("`@
M("`@:68@*"%I<W-E="@D8F]U;F1A<GDI*2!["B`@("`@("`@("`@("`@("`D
M<&]S=&1A=&$@/2!I;7!L;V1E*"<F)RP@87)R87E?;6%P*`H@("`@("`@("`@
M("`@("`@("`@(&-R96%T95]F=6YC=&EO;B@G)&$G+"`G<F5T=7)N("1A6S!=
M("X@7"<]7"<@+B`D85LQ73LG*2P@"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]F;&%T=&5N07)R87DH)R<L("1T:&ES+3Y?<&]S=$1A=&$I"B`@("`@
M("`@("`@("`@("`I*3L*"B`@("`@("`@("`@("\O(&UU;'1I<&%R="!R97%U
M97-T+"!P<F]B86)L>2!W:71H(&9I;&4@=7!L;V%D<PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'!O<W1D871A(#T@)R<["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&]S=$1A=&$I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&9L871$871A(#T@)'1H:7,M/E]F;&%T=&5N
M07)R87DH)R<L("1T:&ES+3Y?<&]S=$1A=&$I.PH@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1F;&%T1&%T82!A<R`D:71E;2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]S=&1A=&$@+CT@)RTM)R`N("1B;W5N9&%R>2`N
M(")<<EQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@)'!O<W1D871A("X]
M("=#;VYT96YT+41I<W!O<VET:6]N.B!F;W)M+61A=&$[(&YA;64](B<@+B`D
M:71E;5LP72`N("<B)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'!O<W1D
M871A("X](")<<EQN7')<;B(@+B!U<FQD96-O9&4H)&ET96U;,5TI("X@(EQR
M7&XB.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&]S=$9I;&5S(&%S
M("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=F%L=65;)VYA;64G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64@("`@("`@/2`D;F%M92`N("@D=&AI<RT^7W5S94)R
M86-K971S/R`G6UTG.B`G)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@("`@("`@/2`D
M;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=N86UE)UT@
M/2!A<G)A>2@D=F%L=65;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU95LG;F%M92==
M(&%S("1K97D@/3X@)&9I;&5N86UE*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1F<"`@(#T@9F]P96XH)&9I;&5N86UE+"`G<B<I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@9FEL97-I>F4H)&9I
M;&5N86UE*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D8F%S96YA;64@/2!B87-E;F%M
M92@D9FEL96YA;64I.PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`@
M("`@/2!I<U]A<G)A>2@D=F%L=65;)W1Y<&4G72D_($`D=F%L=65;)W1Y<&4G
M75LD:V5Y73H@)'9A;'5E6R=T>7!E)UT["@H@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]S=&1A=&$@+CT@)RTM)R`N("1B;W5N9&%R>2`N(")<<EQN(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O<W1D871A("X]("=#;VYT96YT
M+41I<W!O<VET:6]N.B!F;W)M+61A=&$[(&YA;64](B<@+B`D=F%R;F%M92`N
M("<B.R!F:6QE;F%M93TB)R`N("1B87-E;F%M92`N("<B)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O<W1D871A("X](")<<EQN0V]N=&5N="U4>7!E
M.B`B("X@)'1Y<&4["B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T
M82`N/2`B7')<;EQR7&XB("X@)&1A=&$@+B`B7')<;B(["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'!O<W1D871A("X]("<M+2<@+B`D8F]U;F1A<GD@+B`B+2U<<EQN(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<F5Q=65S="`N/2`G0V]N=&5N="U,
M96YG=&@Z("<@+B!S=')L96XH)'!O<W1D871A*2`N(")<<EQN7')<;B(["B`@
M("`@("`@("`@("1R97%U97-T("X]("1P;W-T9&%T83L*"B`@("`@("`@+R\@
M17AP;&EC:71L>2!S970@<F5Q=65S="!B;V1Y"B`@("`@("`@?2!E;'-E:68@
M*"%E;7!T>2@D=&AI<RT^7V)O9'DI*2!["@H@("`@("`@("`@("`D<F5Q=65S
M="`N/2`G0V]N=&5N="U,96YG=&@Z("<@+B!S=')L96XH)'1H:7,M/E]B;V1Y
M*2`N(")<<EQN7')<;B(["B`@("`@("`@("`@("1R97%U97-T("X]("1T:&ES
M+3Y?8F]D>3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1R
M97%U97-T.PH@("`@?0H*("`@+RHJ"B`@("`J($AE;'!E<B!F=6YC=&EO;B!T
M;R!C:&%N9V4@=&AE("AP<F]B86)L>2!M=6QT:61I;65N<VEO;F%L*2!A<W-O
M8VEA=&EV92!A<G)A>0H@("`@*B!I;G1O('1H92!S:6UP;&4@;VYE+@H@("`@
M*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!N86UE(&9O<B!I=&5M"B`@("`J
M($!P87)A;2`@("!M:7AE9"`@(&ET96TG<R!V86QU97,*("`@("H@0')E='5R
M;B`@(&%R<F%Y("`@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&ET96US.B!A
M<G)A>2@G:71E;2!N86UE)RP@)VET96T@=F%L=64G*3L*("`@("HO"B`@("!F
M=6YC=&EO;B!?9FQA='1E;D%R<F%Y*"1N86UE+"`D=F%L=65S*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?87)R87DH)'9A;'5E<RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*&%R<F%Y*"1N86UE+"`D=F%L=65S*2D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1V86QU97,@87,@)&L@/3X@)'8I('L*("`@("`@("`@
M("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@("`@("`@
M("`D;F5W3F%M92`]("1K.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T
M:&ES+3Y?=7-E0G)A8VME=',I('L*("`@("`@("`@("`@("`@("`@("`D;F5W
M3F%M92`]("1N86UE("X@)ULG("X@)&L@+B`G72<["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1N97=.86UE(#T@)&YA
M;64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T(#T@
M87)R87E?;65R9V4H)')E="P@)'1H:7,M/E]F;&%T=&5N07)R87DH)&YE=TYA
M;64L("1V*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R
M970["B`@("`@("`@?0H@("`@?0H*"B`@("\J*@H@("`@*B!!9&1S(&$@3&ES
M=&5N97(@=&\@=&AE(&QI<W0@;V8@;&ES=&5N97)S('1H870@87)E(&YO=&EF
M:65D(&]F"B`@("`J('1H92!O8FIE8W0G<R!E=F5N=',*("`@("H@"B`@("`J
M($!P87)A;2`@("!O8FIE8W0@("!(5%107U)E<75E<W1?3&ES=&5N97(@:6YS
M=&%N8V4@=&\@871T86-H"B`@("`J($!R971U<FX@("!B;V]L96%N("!W:&5T
M:&5R('1H92!L:7-T96YE<B!W87,@<W5C8V5S<V9U;&QY(&%T=&%C:&5D"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!A='1A
M8V@H)B1L:7-T96YE<BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&QI<W1E
M;F5R+"`G2%144%]297%U97-T7TQI<W1E;F5R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VQI<W1E
M;F5R<ULD;&ES=&5N97(M/F=E=$ED*"E=(#TF("1L:7-T96YE<CL*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"@H@("`O*BH*("`@("H@4F5M;W9E<R!A
M($QI<W1E;F5R(&9R;VT@=&AE(&QI<W0@;V8@;&ES=&5N97)S(`H@("`@*B`*
M("`@("H@0'!A<F%M("`@(&]B:F5C="`@($A45%!?4F5Q=65S=%],:7-T96YE
M<B!I;G-T86YC92!T;R!D971A8V@*("`@("H@0')E='5R;B`@(&)O;VQE86X@
M('=H971H97(@=&AE(&QI<W1E;F5R('=A<R!S=6-C97-S9G5L;'D@9&5T86-H
M960*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N
M(&1E=&%C:"@F)&QI<W1E;F5R*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M;&ES=&5N97(L("=(5%107U)E<75E<W1?3&ES=&5N97(G*2!\?"`*("`@("`@
M("`@("`@(6ES<V5T*"1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<BT^9V5T
M260H*5TI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@=6YS970H)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R+3YG
M971)9"@I72D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H*("`@+RHJ
M"B`@("`J($YO=&EF:65S(&%L;"!R96=I<W1E<F5D(&QI<W1E;F5R<R!O9B!A
M;B!E=F5N="X*("`@("H@"B`@("`J($5V96YT<R!S96YT(&)Y($A45%!?4F5Q
M=65S="!O8FIE8W0*("`@("H@)W-E;G1297%U97-T)SH@869T97(@=&AE(')E
M<75E<W0@=V%S('-E;G0*("`@("H@179E;G1S('-E;G0@8GD@2%144%]297-P
M;VYS92!O8FIE8W0*("`@("H@)V=O=$AE861E<G,G.B!A9G1E<B!R96-E:79I
M;F<@<F5S<&]N<V4@:&5A9&5R<R`H:&5A9&5R<R!A<F4@<&%S<V5D(&EN("1D
M871A*0H@("`@*B`G=&EC:R<Z(&]N(')E8V5I=FEN9R!A('!A<G0@;V8@<F5S
M<&]N<V4@8F]D>2`H=&AE('!A<G0@:7,@<&%S<V5D(&EN("1D871A*0H@("`@
M*B`G9WI4:6-K)SH@;VX@<F5C96EV:6YG(&$@9WII<"UE;F-O9&5D('!A<G0@
M;V8@<F5S<&]N<V4@8F]D>2`H9&ET=&\I"B`@("`J("=G;W1";V1Y)SH@869T
M97(@<F5C96EV:6YG('1H92!R97-P;VYS92!B;V1Y("AP87-S97,@=&AE(&1E
M8V]D960@8F]D>2!I;B`D9&%T82!I9B!I="!W87,@9WII<'!E9"D*("`@("H@
M"B`@("`J($!P87)A;2`@("!S=')I;F<@($5V96YT(&YA;64*("`@("H@0'!A
M<F%M("`@(&UI>&5D("`@061D:71I;VYA;"!D871A"B`@("`J($!A8V-E<W,@
M("!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I;VX@7VYO=&EF>2@D979E;G0L
M("1D871A(#T@;G5L;"D*("`@('L*("`@("`@("!F;W)E86-H("AA<G)A>5]K
M97ES*"1T:&ES+3Y?;&ES=&5N97)S*2!A<R`D:60I('L*("`@("`@("`@("`@
M)'1H:7,M/E]L:7-T96YE<G-;)&ED72T^=7!D871E*"1T:&ES+"`D979E;G0L
M("1D871A*3L*("`@("`@("!]"B`@("!]"GT*"@HO*BH**B!297-P;VYS92!C
M;&%S<R!T;R!C;VUP;&5M96YT('1H92!297%U97-T(&-L87-S"BHO"F-L87-S
M($A45%!?4F5S<&]N<V4*>PH@("`@+RHJ"B`@("`J(%-O8VME="!O8FIE8W0*
M("`@("H@0'9A<B!O8FIE8W0*("`@("HO"B`@("!V87(@)%]S;V-K.PH*("`@
M("\J*@H@("`@*B!0<F]T;V-O;`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*
M("`@('9A<B`D7W!R;W1O8V]L.PH@("`@"B`@("`O*BH*("`@("H@4F5T=7)N
M(&-O9&4*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]C;V1E
M.PH@("`@"B`@("`O*BH*("`@("H@4F5S<&]N<V4@:&5A9&5R<PH@("`@*B!`
M=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?:&5A9&5R<SL*"B`@("`O*BH*
M("`@("H@0V]O:VEE<R!S970@:6X@<F5S<&]N<V4@(`H@("`@*B!`=F%R(&%R
M<F%Y"B`@("`J+PH@("`@=F%R("1?8V]O:VEE<SL*"B`@("`O*BH*("`@("H@
M4F5S<&]N<V4@8F]D>0H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A
M<B`D7V)O9'D@/2`G)SL*"B`@("\J*@H@("`@*B!5<V5D(&)Y(%]R96%D0VAU
M;FME9"@I.B!R96UA:6YI;F<@;&5N9W1H(&]F('1H92!C=7)R96YT(&-H=6YK
M"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?8VAU;FM,96YG
M=&@@/2`P.PH*("`@+RHJ"B`@("`J($%T=&%C:&5D(&QI<W1E;F5R<PH@("`@
M*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?;&ES=&5N97)S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*("`@("H@
M0'!A<F%M("!O8FIE8W0@3F5T7U-O8VME="`@("`@<V]C:V5T('1O(')E860@
M=&AE(')E<W!O;G-E(&9R;VT*("`@("H@0'!A<F%M("!A<G)A>2`@("`@("`@
M("`@("`@("`@;&ES=&5N97)S(&%T=&%C:&5D('1O(')E<75E<W0*("`@("H@
M0')E='5R;B!M:7AE9"!014%2($5R<F]R(&]N(&5R<F]R+"!T<G5E(&]T:&5R
M=VES90H@("`@*B\*("`@(&9U;F-T:6]N($A45%!?4F5S<&]N<V4H)B1S;V-K
M+"`F)&QI<W1E;F5R<RD*("`@('L*("`@("`@("`D=&AI<RT^7W-O8VL@("`@
M("`])B`D<V]C:SL*("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<R`])B`D;&ES
M=&5N97)S.PH@("`@?0H*"B`@("\J*@H@("`@*B!0<F]C97-S97,@82!(5%10
M(')E<W!O;G-E"B`@("`J(`H@("`@*B!4:&ES(&5X=')A8W1S(')E<W!O;G-E
M(&-O9&4L(&AE861E<G,L(&-O;VMI97,@86YD(&1E8V]D97,@8F]D>2!I9B!I
M="`*("`@("H@=V%S(&5N8V]D960@:6X@<V]M92!W87D*("`@("H*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M("!B;V]L("`@("`@5VAE=&AE
M<B!T;R!S=&]R92!R97-P;VYS92!B;V1Y(&EN(&]B:F5C="!P<F]P97)T>2P@
M<V5T"B`@("`J("`@("`@("`@("`@("`@("`@('1H:7,@=&\@9F%L<V4@:68@
M9&]W;FQO861I;F<@82!,05)'12!F:6QE(&%N9"!U<VEN9R!A($QI<W1E;F5R
M+@H@("`@*B`@("`@("`@("`@("`@("`@("!4:&ES(&ES(&%S<W5M960@=&\@
M8F4@=')U92!I9B!B;V1Y(&ES(&=Z:7`M96YC;V1E9"X*("`@("H@0'1H<F]W
M<R!014%27T5R<F]R"B`@("`J($!R971U<FX@;6EX960@("`@('1R=64@;VX@
M<W5C8V5S<RP@4$5!4E]%<G)O<B!I;B!C87-E(&]F(&UA;&9O<FUE9"!R97-P
M;VYS90H@("`@*B\*("`@(&9U;F-T:6]N('!R;V-E<W,H)'-A=F5";V1Y(#T@
M=')U92D*("`@('L*("`@("`@("!D;R!["B`@("`@("`@("`@("1L:6YE(#T@
M)'1H:7,M/E]S;V-K+3YR96%D3&EN92@I.PH@("`@("`@("`@("!I9B`H<W-C
M86YF*"1L:6YE+"`G2%144"\E<R`E<R<L("1H='1P7W9E<G-I;VXL("1R971U
M<FYC;V1E*2`A/2`R*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G36%L9F]R;65D(')E<W!O;G-E+B<I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F]T;V-O;"`]
M("=(5%10+R<@+B`D:'1T<%]V97)S:6]N.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C;V1E("`@("`](&EN='9A;"@D<F5T=7)N8V]D92D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@=VAI;&4@*"<G("$]/2`H)&AE861E<B`]("1T
M:&ES+3Y?<V]C:RT^<F5A9$QI;F4H*2DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<')O8V5S<TAE861E<B@D:&5A9&5R*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@=VAI;&4@*#$P,"`]/2`D=&AI<RT^7V-O9&4I.PH*("`@("`@
M("`D=&AI<RT^7VYO=&EF>2@G9V]T2&5A9&5R<R<L("1T:&ES+3Y?:&5A9&5R
M<RD["@H@("`@("`@("\O($EF(')E<W!O;G-E(&)O9'D@:7,@<')E<V5N="P@
M<F5A9"!I="!A;F0@9&5C;V1E"B`@("`@("`@)&-H=6YK960@/2!I<W-E="@D
M=&AI<RT^7VAE861E<G-;)W1R86YS9F5R+65N8V]D:6YG)UTI("8F("@G8VAU
M;FME9"<@/3T@)'1H:7,M/E]H96%D97)S6R=T<F%N<V9E<BUE;F-O9&EN9R==
M*3L*("`@("`@("`D9WII<'!E9"`](&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULG
M8V]N=&5N="UE;F-O9&EN9R==*2`F)B`H)V=Z:7`G(#T]("1T:&ES+3Y?:&5A
M9&5R<ULG8V]N=&5N="UE;F-O9&EN9R==*3L*("`@("`@("`D:&%S0F]D>2`]
M(&9A;'-E.PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]H96%D97)S6R=C
M;VYT96YT+6QE;F=T:"==*2!\?"`P("$]("1T:&ES+3Y?:&5A9&5R<ULG8V]N
M=&5N="UL96YG=&@G72D@>PH@("`@("`@("`@("!W:&EL92`H(21T:&ES+3Y?
M<V]C:RT^96]F*"DI('L*("`@("`@("`@("`@("`@(&EF("@D8VAU;FME9"D@
M>PH@("`@("`@("`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]R96%D0VAU
M;FME9"@I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D9&%T82`]("1T:&ES+3Y?<V]C:RT^<F5A9"@T,#DV*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@G)R`]/2`D9&%T
M82D@>PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:&%S0F]D>2`]('1R
M=64["B`@("`@("`@("`@("`@("`@("`@:68@*"1S879E0F]D>2!\?"`D9WII
M<'!E9"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V)O9'D@
M+CT@)&1A=&$["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;F]T:69Y*"1G>FEP<&5D/R`G9WI4:6-K)SH@)W1I
M8VLG+"`D9&%T82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@:68@*"1H87-";V1Y*2!["B`@("`@("`@("`@
M("\O(%5N8V]M<')E<W,@=&AE(&)O9'D@:68@;F5E9&5D"B`@("`@("`@("`@
M(&EF("@D9WII<'!E9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B;V1Y
M(#T@9WII;F9L871E*'-U8G-T<B@D=&AI<RT^7V)O9'DL(#$P*2D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VYO=&EF>2@G9V]T0F]D>2<L("1T:&ES+3Y?
M8F]D>2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYO=&EF>2@G9V]T0F]D>2<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("\J*@H@("`@
M*B!0<F]C97-S97,@=&AE(')E<W!O;G-E(&AE861E<@H@("`@*@H@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("H@0'!A<F%M("!S=')I;F<@("`@2%144"!H
M96%D97(*("`@("HO"B`@("!F=6YC=&EO;B!?<')O8V5S<TAE861E<B@D:&5A
M9&5R*0H@("`@>PH@("`@("`@(&QI<W0H)&AE861E<FYA;64L("1H96%D97)V
M86QU92D@/2!E>'!L;V1E*"<Z)RP@)&AE861E<BP@,BD["B`@("`@("`@)&AE
M861E<FYA;64@(#T@<W1R=&]L;W=E<B@D:&5A9&5R;F%M92D["B`@("`@("`@
M)&AE861E<G9A;'5E(#T@;'1R:6TH)&AE861E<G9A;'5E*3L*("`@("`@("`*
M("`@("`@("!I9B`H)W-E="UC;V]K:64G("$]("1H96%D97)N86UE*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)&AE861E<FYA
M;65=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R1H96%D
M97)N86UE72`N/2`G+"<@+B`D:&5A9&5R=F%L=64["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)&AE861E
M<FYA;65=("`]("1H96%D97)V86QU93L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5#;V]K:64H)&AE
M861E<G9A;'5E*3L*("`@("`@("!]"B`@("!]"@H*("`@+RHJ"B`@("`J(%!A
M<G-E(&$@4V5T+4-O;VMI92!H96%D97(@=&\@9FEL;"`D7V-O;VMI97,@87)R
M87D*("`@("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!P87)A;2`@
M<W1R:6YG("`@('9A;'5E(&]F(%-E="U#;V]K:64@:&5A9&5R"B`@("`J+PH@
M("`@9G5N8W1I;VX@7W!A<G-E0V]O:VEE*"1H96%D97)V86QU92D*("`@('L*
M("`@("`@("`D8V]O:VEE(#T@87)R87DH"B`@("`@("`@("`@("=E>'!I<F5S
M)R`]/B!N=6QL+`H@("`@("`@("`@("`G9&]M86EN)R`@/3X@;G5L;"P*("`@
M("`@("`@("`@)W!A=&@G("`@(#T^(&YU;&PL"B`@("`@("`@("`@("=S96-U
M<F4G("`]/B!F86QS90H@("`@("`@("D["@H@("`@("`@("\O($]N;'D@82!N
M86UE/79A;'5E('!A:7(*("`@("`@("!I9B`H(7-T<G!O<R@D:&5A9&5R=F%L
M=64L("<[)RDI('L*("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D:&5A9&5R
M=F%L=64L("<])RD["B`@("`@("`@("`@("1C;V]K:65;)VYA;64G72`@/2!T
M<FEM*'-U8G-T<B@D:&5A9&5R=F%L=64L(#`L("1P;W,I*3L*("`@("`@("`@
M("`@)&-O;VMI95LG=F%L=64G72`]('1R:6TH<W5B<W1R*"1H96%D97)V86QU
M92P@)'!O<R`K(#$I*3L*"B`@("`@("`@+R\@4V]M92!O<'1I;VYA;"!P87)A
M;65T97)S(&%R92!S=7!P;&EE9`H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1E;&5M96YT<R`](&5X<&QO9&4H)SLG+"`D:&5A9&5R=F%L=64I.PH@
M("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1E;&5M96YT<ULP72P@)STG*3L*
M("`@("`@("`@("`@)&-O;VMI95LG;F%M92==("`]('1R:6TH<W5B<W1R*"1E
M;&5M96YT<ULP72P@,"P@)'!O<RDI.PH@("`@("`@("`@("`D8V]O:VEE6R=V
M86QU92==(#T@=')I;2AS=6)S='(H)&5L96UE;G1S6S!=+"`D<&]S("L@,2DI
M.PH*("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@8V]U;G0H)&5L96UE
M;G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*&9A;'-E(#T]/2!S
M=')P;W,H)&5L96UE;G1S6R1I72P@)STG*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1E;$YA;64@(#T@=')I;2@D96QE;65N='-;)&E=*3L*("`@("`@("`@
M("`@("`@("`@("`D96Q686QU92`](&YU;&P["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0@*"1E;$YA;64L("1E
M;%9A;'5E*2`](&%R<F%Y7VUA<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D96QE
M;65N='-;)&E=*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D96Q.86UE(#T@<W1R=&]L;W=E<B@D96Q.86UE*3L*("`@("`@("`@("`@
M("`@(&EF("@G<V5C=7)E)R`]/2`D96Q.86UE*2!["B`@("`@("`@("`@("`@
M("`@("`@)&-O;VMI95LG<V5C=7)E)UT@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"=E>'!I<F5S)R`]/2`D96Q.86UE*2!["B`@("`@("`@
M("`@("`@("`@("`@)&-O;VMI95LG97AP:7)E<R==(#T@<W1R7W)E<&QA8V4H
M)R(G+"`G)RP@)&5L5F%L=64I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"=P871H)R`]/2`D96Q.86UE('Q\("=D;VUA:6XG(#T]("1E;$YA;64I('L*
M("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R1E;$YA;65=(#T@=7)L9&5C
M;V1E*"1E;%9A;'5E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&-O;VMI95LD96Q.86UE72`]("1E;%9A;'5E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?8V]O:VEE<UM=(#T@)&-O;VMI93L*("`@('T*"@H@("`O
M*BH*("`@("H@4F5A9"!A('!A<G0@;V8@<F5S<&]N<V4@8F]D>2!E;F-O9&5D
M('=I=&@@8VAU;FME9"!4<F%N<V9E<BU%;F-O9&EN9PH@("`@*B`*("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`J($!R971U<FX@<W1R:6YG"B`@("`J+PH@
M("`@9G5N8W1I;VX@7W)E861#:'5N:V5D*"D*("`@('L*("`@("`@("`O+R!A
M="!S=&%R="!O9B!T:&4@;F5X="!C:'5N:S\*("`@("`@("!I9B`H,"`]/2`D
M=&AI<RT^7V-H=6YK3&5N9W1H*2!["B`@("`@("`@("`@("1L:6YE(#T@)'1H
M:7,M/E]S;V-K+3YR96%D3&EN92@I.PH@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UXH6S`M.6$M9ETK*2]I)RP@)&QI;F4L("1M871C:&5S*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C:'5N:TQE;F=T:"`](&AE>&1E8R@D
M;6%T8VAE<ULQ72D[(`H@("`@("`@("`@("`@("`@+R\@0VAU;FL@=VET:"!Z
M97)O(&QE;F=T:"!I;F1I8V%T97,@=&AE(&5N9`H@("`@("`@("`@("`@("`@
M:68@*#`@/3T@)'1H:7,M/E]C:'5N:TQE;F=T:"D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<V]C:RT^<F5A9$QI;F4H*3L@+R\@;6%K92!T:&ES
M(&%N(&5O9B@I"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1D871A(#T@)'1H:7,M/E]S;V-K+3YR96%D*"1T:&ES+3Y?8VAU;FM,
M96YG=&@I.PH@("`@("`@("1T:&ES+3Y?8VAU;FM,96YG=&@@+3T@<W1R;&5N
M*"1D871A*3L*("`@("`@("!I9B`H,"`]/2`D=&AI<RT^7V-H=6YK3&5N9W1H
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V]C:RT^<F5A9$QI;F4H*3L@+R\@
M5')A:6QI;F<@0U),1@H@("`@("`@('T*("`@("`@("!R971U<FX@)&1A=&$[
M"B`@("!]"@H*("`@+RHJ"B`@("`J($YO=&EF:65S(&%L;"!R96=I<W1E<F5D
M(&QI<W1E;F5R<R!O9B!A;B!E=F5N="X*("`@("H@"B`@("`J($!P87)A;2`@
M("!S=')I;F<@($5V96YT(&YA;64*("`@("H@0'!A<F%M("`@(&UI>&5D("`@
M061D:71I;VYA;"!D871A"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J
M($!S964@2%144%]297%U97-T.CI?;F]T:69Y*"D*("`@("HO"B`@("!F=6YC
M=&EO;B!?;F]T:69Y*"1E=F5N="P@)&1A=&$@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]L:7-T96YE<G,I(&%S
M("1I9"D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD:61=+3YU
M<&1A=&4H)'1H:7,L("1E=F5N="P@)&1A=&$I.PH@("`@("`@('T*("`@('T*
M?2`O+R!%;F0@8VQA<W,@2%144%]297-P;VYS90H_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O36%I;"\`````````````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-3<`,#$V,C(V`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]-86EL+VUI;65$96-O9&4N<&AP````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`W-#8U-@`Q,#4Q-30S,3`U-P`P,C$P,3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S("!2:6-H87)D($AE>65S("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@0V]P>7)I9VAT
M("AC*2`R,#`S+3(P,#4@(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@4F5D
M:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M
M<RP@=VET:"!O<B!W:71H;W5T("`@('P*+R\@?"!M;V1I9FEC871I;VXL(&%R
M92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I
M=&EO;G,@("`@?`HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!O(%)E9&ES=')I
M8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@
M8V]P>7)I9VAT("`@("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@
M("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S
M="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P*+R\@?"`@(&YO
M=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<B!I;B!T:&4@?`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A
M;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R
M:6)U=&EO;BY\"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y
M(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P*+R\@
M?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO
M=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO
M;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!9
M4DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`HO+R!\(")!4R!)
M4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#
M3%5$24Y'+"!"550@3D]4("`@("!\"B\O('P@3$E-251%1"!43RP@5$A%($E-
M4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%
M4U,@1D]2('P*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!
M24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`HO+R!\
M($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%
M0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%
M35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@
M0E54($Y/5"`@("`@('P*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/
M1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@
M?`HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E50
M5$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\"B\O('P@5$A%3U)9
M($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)
M04))3$E462P@3U(@5$]25"`@('P*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.
M0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(
M12!54T4@?`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%
M1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC
M:&%R9$!P:'!G=7)U+F]R9SX@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PH*+RHJ"BH@("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2!)35!/4E1!3E0@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHJ("!\(%5S86=E(&]F('1H:7,@8VQA<W,@8V]M<&%R960@=&\@;F%T
M:79E('!H<"!E>'1E;G-I;VYS('-U8V@@87,@("`@("`@('P**B`@?"!M86EL
M<&%R<V4@;W(@:6UA<"P@:7,@<VQO=R!A;F0@;6%Y(&)E(&9E871U<F4@9&5F
M:6-I96YT+B!)9B!A=F%I;&%B;&5\"BH@('P@>6]U(&%R92!35%)/3D=,62!R
M96-O;6UE;F1E9"!T;R!U<V4@=&AE('!H<"!E>'1E;G-I;VYS+B`@("`@("`@
M("`@("`@?`HJ("`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L**@HJ($UI
M;64@1&5C;V1I;F<@8VQA<W,**@HJ(%1H:7,@8VQA<W,@=VEL;"!P87)S92!A
M(')A=R!M:6UE(&5M86EL(&%N9"!R971U<FX**B!T:&4@<W1R=6-T=7)E+B!2
M971U<FYE9"!S=')U8W1U<F4@:7,@<VEM:6QA<B!T;PHJ('1H870@<F5T=7)N
M960@8GD@:6UA<%]F971C:'-T<G5C='5R92@I+@HJ"BH@55-!1T4Z("AA<W-U
M;64@)&EN<'5T(&ES('EO=7(@<F%W(&5M86EL*0HJ"BH@)&1E8V]D92`](&YE
M=R!-86EL7VUI;65$96-O9&4H)&EN<'5T+"`B7')<;B(I.PHJ("1S=')U8W1U
M<F4@/2`D9&5C;V1E+3YD96-O9&4H*3L**B!P<FEN=%]R*"1S=')U8W1U<F4I
M.PHJ"BH@3W(@<W1A=&EC86QL>3H**@HJ("1P87)A;7-;)VEN<'5T)UT@/2`D
M:6YP=70["BH@)'-T<G5C='5R92`]($UA:6Q?;6EM941E8V]D93HZ9&5C;V1E
M*"1P87)A;7,I.PHJ('!R:6YT7W(H)'-T<G5C='5R92D["BH**B!43T1/.@HJ
M("!O($EM<&QE;65N="!M=6QT:7!A<G0O87!P;&5D;W5B;&4**B`@;R!55$8X
M.B`_/S\*"@D)/B`T+B!792!H879E(&%L<V\@9F]U;F0@82!S;VQU=&EO;B!F
M;W(@9&5C;V1I;F<@=&AE(%541BTX(`H)"3X@:&5A9&5R<RX@5&AE<F5F;W)E
M($D@;6%D92!T:&4@9F]L;&]W:6YG(&9U;F-T:6]N.@H)"3X@"@D)/B!F=6YC
M=&EO;B!D96-O9&5?=71F."@D='AT*2!["@D)/B`D=')A;G,]87)R87DH(L4F
M(S@R,38[(CT^(L.U(BPBQ;$B/3XBP[LB+"+%D"(]/B+#)B,X,C(V.R(L(L6P
M(@H)"3T^(L,F(S@R-3`[(BD["@D)/B`D='AT/7-T<G1R*"1T>'0L)'1R86YS
M*3L*"0D^(')E='5R;BAU=&8X7V1E8V]D92@D='AT*2D["@D)/B!]"@D)/B`*
M"0D^($%N9"!)(&AA=F4@:6YS97)T960@=&AE(&9O;&QO=VEN9R!L:6YE('1O
M('1H92!C;&%S<SH*"0D^(`H)"3X@:68@*'-T<G1O;&]W97(H)&-H87)S970I
M/3TB=71F+3@B*2`D=&5X=#UD96-O9&5?=71F."@D=&5X="D["@D)/B`*"0D^
M("XN+B!B969O<F4@=&AE(&9O;&QO=VEN9R!O;F4@:6X@=&AE(")?9&5C;V1E
M2&5A9&5R(B!F=6YC=&EO;CH*"0D^(`H)"3X@)&EN<'5T(#T@<W1R7W)E<&QA
M8V4H)&5N8V]D960L("1T97AT+"`D:6YP=70I.PH)"3X@"@D)/B!4:&ES('=A
M>2!F<F]M(&YO=R!O;B!I="!C86X@96%S:6QY(&1E8V]D92!T:&4@551&+3@@
M:&5A9&5R<R!T;V\N"@HJ"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC
M:&%R9$!P:'!G=7)U+F]R9SX**B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N-#8@
M)`HJ($!P86-K86=E($UA:6P**B\*8VQA<W,@36%I;%]M:6UE1&5C;V1E(&5X
M=&5N9',@4$5!4@I["B`@("`O*BH*("`@("`J(%1H92!R87<@96UA:6P@=&\@
M9&5C;V1E"B`@("`@*B!`=F%R("`@('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]I;G!U=#L*"B`@("`O*BH*("`@("`J(%1H92!H96%D97(@<&%R="!O9B!T
M:&4@:6YP=70*("`@("`J($!V87(@("`@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7VAE861E<CL*"B`@("`O*BH*("`@("`J(%1H92!B;V1Y('!A<G0@;V8@
M=&AE(&EN<'5T"B`@("`@*B!`=F%R("`@('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]B;V1Y.PH*("`@("\J*@H@("`@("H@268@86X@97)R;W(@;V-C=7)S
M+"!T:&ES(&ES('5S960@=&\@<W1O<F4@=&AE(&UE<W-A9V4*("`@("`J($!V
M87(@("`@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5R<F]R.PH*("`@("\J
M*@H@("`@("H@1FQA9R!T;R!D971E<FUI;F4@=VAE=&AE<B!T;R!I;F-L=61E
M(&)O9&EE<R!I;B!T:&4*("`@("`J(')E='5R;F5D(&]B:F5C="X*("`@("`J
M($!V87(@("`@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]I;F-L=61E7V)O
M9&EE<SL*"B`@("`O*BH*("`@("`J($9L86<@=&\@9&5T97)M:6YE('=H971H
M97(@=&\@9&5C;V1E(&)O9&EE<PH@("`@("H@0'9A<B`@("!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7V1E8V]D95]B;V1I97,["@H@("`@+RHJ"B`@("`@
M*B!&;&%G('1O(&1E=&5R;6EN92!W:&5T:&5R('1O(&1E8V]D92!H96%D97)S
M"B`@("`@*B!`=F%R("`@(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?9&5C
M;V1E7VAE861E<G,["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!3971S('5P('1H92!O8FIE8W0L(&EN:71I86QI<V4@=&AE
M('9A<FEA8FQE<RP@86YD('-P;&ET<R!A;F0*("`@("`J('-T;W)E<R!T:&4@
M:&5A9&5R(&%N9"!B;V1Y(&]F('1H92!I;G!U="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG(%1H92!I;G!U="!T;R!D96-O9&4*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($UA:6Q?;6EM941E8V]D
M92@D:6YP=70I"B`@("!["B`@("`@("`@;&ES="@D:&5A9&5R+"`D8F]D>2D@
M("`]("1T:&ES+3Y?<W!L:71";V1Y2&5A9&5R*"1I;G!U="D["@H@("`@("`@
M("1T:&ES+3Y?:6YP=70@("`@("`@("`@/2`D:6YP=70["B`@("`@("`@)'1H
M:7,M/E]H96%D97(@("`@("`@("`]("1H96%D97(["B`@("`@("`@)'1H:7,M
M/E]B;V1Y("`@("`@("`@("`]("1B;V1Y.PH@("`@("`@("1T:&ES+3Y?9&5C
M;V1E7V)O9&EE<R`@/2!F86QS93L*("`@("`@("`D=&AI<RT^7VEN8VQU9&5?
M8F]D:65S(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($)E9VEN<R!T
M:&4@9&5C;V1I;F<@<')O8V5S<RX@268@8V%L;&5D('-T871I8V%L;'D*("`@
M("`J(&ET('=I;&P@8W)E871E(&%N(&]B:F5C="!A;F0@8V%L;"!T:&4@9&5C
M;V1E*"D@;65T:&]D"B`@("`@*B!O9B!I="X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@06X@87)R87D@;V8@=F%R:6]U<R!P87)A;65T97)S('1H870@
M9&5T97)M:6YE"B`@("`@*B`@("`@("`@("`@("`@=F%R:6]U<R!T:&EN9W,Z
M"B`@("`@*B`@("`@("`@("`@("`@:6YC;'5D95]B;V1I97,@+2!7:&5T:&5R
M('1O(&EN8VQU9&4@=&AE(&)O9'D@:6X@=&AE(')E='5R;F5D"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*B`@
M("`@("`@("`@("`@9&5C;V1E7V)O9&EE<R`@+2!7:&5T:&5R('1O(&1E8V]D
M92!T:&4@8F]D:65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!O9B!T:&4@<&%R=',N("A4<F%N<V9E<B!E;F-O9&EN9RD*("`@("`J
M("`@("`@("`@("`@("!D96-O9&5?:&5A9&5R<R`M(%=H971H97(@=&\@9&5C
M;V1E(&AE861E<G,*("`@("`J("`@("`@("`@("`@("!I;G!U="`@("`@("`@
M("`M($EF(&-A;&QE9"!S=&%T:6-A;&QY+"!T:&ES('=I;&P@8F4@=')E871E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87,@=&AE
M(&EN<'5T"B`@("`@*B!`<F5T=7)N(&]B:F5C="!$96-O9&5D(')E<W5L=',*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E
M8V]D92@D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("`O+R!D971E<FUI
M;F4@:68@=&AI<R!M971H;V0@:&%S(&)E96X@8V%L;&5D('-T871I8V%L;'D*
M("`@("`@("`D:7-3=&%T:6,@/2`A*&ES<V5T*"1T:&ES*2`F)B!G971?8VQA
M<W,H)'1H:7,I(#T](%]?0TQ!4U-?7RD["@H@("`@("`@("\O($AA=F4@=V4@
M8F5E;B!C86QL960@<W1A=&EC86QL>3\*"2\O($EF('-O+"!C<F5A=&4@86X@
M;V)J96-T(&%N9"!P87-S(&1E=&%I;',@=&\@=&AA="X*("`@("`@("!I9B`H
M)&ES4W1A=&EC($%.1"!I<W-E="@D<&%R86US6R=I;G!U="==*2D@>PH*("`@
M("`@("`@("`@)&]B:B`](&YE=R!-86EL7VUI;65$96-O9&4H)'!A<F%M<ULG
M:6YP=70G72D["B`@("`@("`@("`@("1S=')U8W1U<F4@/2`D;V)J+3YD96-O
M9&4H)'!A<F%M<RD["@H@("`@("`@("\O($-A;&QE9"!S=&%T:6-A;&QY(&)U
M="!N;R!I;G!U=`H@("`@("`@('T@96QS96EF("@D:7-3=&%T:6,I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-A;&QE9"!S=&%T
M:6-A;&QY(&%N9"!N;R!I;G!U="!G:79E;B<I.PH*("`@("`@("`O+R!#86QL
M960@=FEA(&%N(&]B:F5C=`H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3Y?:6YC;'5D95]B;V1I97,@/2!I<W-E="@D<&%R86US6R=I;F-L
M=61E7V)O9&EE<R==*2`_"@D@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;7-;)VEN8VQU9&5?8F]D:65S)UT@.B!F86QS93L*("`@("`@("`@
M("`@)'1H:7,M/E]D96-O9&5?8F]D:65S("`](&ES<V5T*"1P87)A;7-;)V1E
M8V]D95]B;V1I97,G72D@/PH)("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%R86US6R=D96-O9&5?8F]D:65S)UT@(#H@9F%L<V4["B`@("`@("`@
M("`@("1T:&ES+3Y?9&5C;V1E7VAE861E<G,@/2!I<W-E="@D<&%R86US6R=D
M96-O9&5?:&5A9&5R<R==*2`_"@D@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;7-;)V1E8V]D95]H96%D97)S)UT@.B!F86QS93L*"B`@("`@
M("`@("`@("1S=')U8W1U<F4@/2`D=&AI<RT^7V1E8V]D92@D=&AI<RT^7VAE
M861E<BP@)'1H:7,M/E]B;V1Y*3L*("`@("`@("`@("`@:68@*"1S=')U8W1U
M<F4@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E(#T@
M)'1H:7,M/G)A:7-E17)R;W(H)'1H:7,M/E]E<G)O<BD["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<W1R=6-T=7)E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4&5R9F]R;7,@=&AE(&1E8V]D:6YG+B!$96-O
M9&5S('1H92!B;V1Y('-T<FEN9R!P87-S960@=&\@:70*("`@("`J($EF(&ET
M(&9I;F1S(&-E<G1A:6X@8V]N=&5N="UT>7!E<R!I="!W:6QL(&-A;&P@:71S
M96QF(&EN(&$*("`@("`J(')E8W5R<VEV92!F87-H:6]N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R!(96%D97(@<V5C=&EO;@H@("`@("H@0'!A<F%M
M('-T<FEN9R!";V1Y('-E8W1I;VX*("`@("`J($!R971U<FX@;V)J96-T(%)E
M<W5L=',@;V8@9&5C;V1I;F<@<')O8V5S<PH@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-O9&4H)&AE861E<G,L("1B
M;V1Y+"`D9&5F875L=%]C='EP92`]("=T97AT+W!L86EN)RD*("`@('L*("`@
M("`@("`D<F5T=7)N(#T@;F5W('-T9$-L87-S.PH@("`@("`@("1R971U<FXM
M/FAE861E<G,@/2!A<G)A>2@I.PH@("`@("`@("1H96%D97)S(#T@)'1H:7,M
M/E]P87)S94AE861E<G,H)&AE861E<G,I.PH*("`@("`@("!F;W)E86-H("@D
M:&5A9&5R<R!A<R`D=F%L=64I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1R
M971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;)VYA;64G72E=*2!!
M3D0@(6ES7V%R<F%Y*"1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L
M=65;)VYA;64G72E=*2D@>PH@("`@("`@("`@("`@("`@)')E='5R;BT^:&5A
M9&5R<UMS=')T;VQO=V5R*"1V86QU95LG;F%M92==*5T@("`](&%R<F%Y*"1R
M971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;)VYA;64G72E=*3L*
M("`@("`@("`@("`@("`@("1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D
M=F%L=65;)VYA;64G72E=6UT@/2`D=F%L=65;)W9A;'5E)UT["@H@("`@("`@
M("`@("!](&5L<V5I9B`H:7-S970H)')E='5R;BT^:&5A9&5R<UMS=')T;VQO
M=V5R*"1V86QU95LG;F%M92==*5TI*2!["B`@("`@("`@("`@("`@("`D<F5T
M=7)N+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI75M=(#T@
M)'9A;'5E6R=V86QU92==.PH*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;
M)VYA;64G72E=(#T@)'9A;'5E6R=V86QU92==.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R97-E="@D:&5A9&5R<RD["B`@("`@("`@=VAI
M;&4@*&QI<W0H)&ME>2P@)'9A;'5E*2`](&5A8V@H)&AE861E<G,I*2!["B`@
M("`@("`@("`@("1H96%D97)S6R1K97E=6R=N86UE)UT@/2!S=')T;VQO=V5R
M*"1H96%D97)S6R1K97E=6R=N86UE)UTI.PH@("`@("`@("`@("!S=VET8V@@
M*"1H96%D97)S6R1K97E=6R=N86UE)UTI('L*"B`@("`@("`@("`@("`@("!C
M87-E("=C;VYT96YT+71Y<&4G.@H@("`@("`@("`@("`@("`@("`@("1C;VYT
M96YT7W1Y<&4@/2`D=&AI<RT^7W!A<G-E2&5A9&5R5F%L=64H)&AE861E<G-;
M)&ME>5U;)W9A;'5E)UTI.PH*("`@("`@("`@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+RA;,"TY82UZ*RXM72LI7"\H6S`M.6$M>BLN+5TK*2]I)RP@
M)&-O;G1E;G1?='EP95LG=F%L=64G72P@)')E9W,I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1R971U<FXM/F-T>7!E7W!R:6UA<GD@("`]("1R96=S
M6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3YC='EP95]S
M96-O;F1A<GD@/2`D<F5G<ULR73L*("`@("`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8V]N=&5N=%]T>7!E6R=O
M=&AE<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!W:&EL92`H;&ES
M="@D<%]N86UE+"`D<%]V86QU92D@/2!E86-H*"1C;VYT96YT7W1Y<&5;)V]T
M:&5R)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N
M+3YC='EP95]P87)A;65T97)S6R1P7VYA;65=(#T@)'!?=F%L=64["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`G8V]N=&5N="UD:7-P;W-I=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G1?9&ES<&]S:71I;VX@/2`D=&AI<RT^7W!A<G-E2&5A9&5R5F%L
M=64H)&AE861E<G-;)&ME>5U;)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@
M("`@("1R971U<FXM/F1I<W!O<VET:6]N("`@/2`D8V]N=&5N=%]D:7-P;W-I
M=&EO;ELG=F%L=64G73L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&-O;G1E;G1?9&ES<&]S:71I;VY;)V]T:&5R)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@('=H:6QE("AL:7-T*"1P7VYA;64L("1P7W9A;'5E*2`]
M(&5A8V@H)&-O;G1E;G1?9&ES<&]S:71I;VY;)V]T:&5R)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3YD7W!A<F%M971E<G-;
M)'!?;F%M95T@/2`D<%]V86QU93L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=C;VYT96YT+71R86YS9F5R
M+65N8V]D:6YG)SH*("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=%]T<F%N
M<V9E<E]E;F-O9&EN9R`]("1T:&ES+3Y?<&%R<V5(96%D97)686QU92@D:&5A
M9&5R<ULD:V5Y75LG=F%L=64G72D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E
M="@D8V]N=&5N=%]T>7!E*2D@>PH@("`@("`@("`@("!S=VET8V@@*'-T<G1O
M;&]W97(H)&-O;G1E;G1?='EP95LG=F%L=64G72DI('L*("`@("`@("`@("`@
M("`@(&-A<V4@)W1E>'0O<&QA:6XG.@H@("`@("`@("`@("`@("`@("`@("1E
M;F-O9&EN9R`](&ES<V5T*"1C;VYT96YT7W1R86YS9F5R7V5N8V]D:6YG*2`_
M("1C;VYT96YT7W1R86YS9F5R7V5N8V]D:6YG6R=V86QU92==(#H@)S=B:70G
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YC;'5D95]B;V1I97,@
M/R`D<F5T=7)N+3YB;V1Y(#T@*"1T:&ES+3Y?9&5C;V1E7V)O9&EE<R`_("1T
M:&ES+3Y?9&5C;V1E0F]D>2@D8F]D>2P@)&5N8V]D:6YG*2`Z("1B;V1Y*2`Z
M(&YU;&P["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G=&5X="]H=&UL)SH*("`@("`@("`@("`@("`@("`@("`D
M96YC;V1I;F<@/2!I<W-E="@D8V]N=&5N=%]T<F%N<V9E<E]E;F-O9&EN9RD@
M/R`D8V]N=&5N=%]T<F%N<V9E<E]E;F-O9&EN9ULG=F%L=64G72`Z("<W8FET
M)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S
M(#\@)')E='5R;BT^8F]D>2`]("@D=&AI<RT^7V1E8V]D95]B;V1I97,@/R`D
M=&AI<RT^7V1E8V]D94)O9'DH)&)O9'DL("1E;F-O9&EN9RD@.B`D8F]D>2D@
M.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@(&-A<V4@)VUU;'1I<&%R="]P87)A;&QE;"<Z"B`@("`@("`@("`@
M("`@("!C87-E("=M=6QT:7!A<G0O<F5P;W)T)SH@+R\@4D9#,3@Y,@H@("`@
M("`@("`@("`@("`@8V%S92`G;75L=&EP87)T+W-I9VYE9"<Z("\O(%!'4`H@
M("`@("`@("`@("`@("`@8V%S92`G;75L=&EP87)T+V1I9V5S="<Z"B`@("`@
M("`@("`@("`@("!C87-E("=M=6QT:7!A<G0O86QT97)N871I=F4G.@H@("`@
M("`@("`@("`@("`@8V%S92`G;75L=&EP87)T+W)E;&%T960G.@H@("`@("`@
M("`@("`@("`@8V%S92`G;75L=&EP87)T+VUI>&5D)SH*("`@("`@("`@("`@
M("`@("`@("!I9B@A:7-S970H)&-O;G1E;G1?='EP95LG;W1H97(G75LG8F]U
M;F1A<GDG72DI>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R
M<F]R(#T@)TYO(&)O=6YD87)Y(&9O=6YD(&9O<B`G("X@)&-O;G1E;G1?='EP
M95LG=F%L=64G72`N("<@<&%R="<["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("1D969A=6QT7V-T>7!E(#T@*'-T<G1O;&]W97(H)&-O
M;G1E;G1?='EP95LG=F%L=64G72D@/3T]("=M=6QT:7!A<G0O9&EG97-T)RD@
M/R`G;65S<V%G92]R9F,X,C(G(#H@)W1E>'0O<&QA:6XG.PH*("`@("`@("`@
M("`@("`@("`@("`D<&%R=',@/2`D=&AI<RT^7V)O=6YD87)Y4W!L:70H)&)O
M9'DL("1C;VYT96YT7W1Y<&5;)V]T:&5R)UU;)V)O=6YD87)Y)UTI.PH@("`@
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1P87)T
M<RD[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D<&%R
M=%]H96%D97(L("1P87)T7V)O9'DI(#T@)'1H:7,M/E]S<&QI=$)O9'E(96%D
M97(H)'!A<G1S6R1I72D["B`@("`@("`@("`@("`@("`@("`@("`@("1P87)T
M(#T@)'1H:7,M/E]D96-O9&4H)'!A<G1?:&5A9&5R+"`D<&%R=%]B;V1Y+"`D
M9&5F875L=%]C='EP92D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF*"1P
M87)T(#T]/2!F86QS92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)T(#T@)'1H:7,M/G)A:7-E17)R;W(H)'1H:7,M/E]E<G)O<BD["B`@("`@
M("`@("`@("`@("`@("`@("`@("1R971U<FXM/G!A<G1S6UT@/2`D<&%R=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G;65S<V%G92]R9F,X,C(G.@H@
M("`@("`@("`@("`@("`@("`@("1O8FH@/2`F;F5W($UA:6Q?;6EM941E8V]D
M92@D8F]D>2D["B`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^<&%R='-;
M72`]("1O8FHM/F1E8V]D92AA<G)A>2@G:6YC;'5D95]B;V1I97,G(#T^("1T
M:&ES+3Y?:6YC;'5D95]B;V1I97,L"@D)"0D)("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5C;V1E7V)O9&EE<R<@(#T^("1T:&ES
M+3Y?9&5C;V1E7V)O9&EE<RP*"0D)"0D)"0D)"0D)"0D@("=D96-O9&5?:&5A
M9&5R<R<@/3X@)'1H:7,M/E]D96-O9&5?:&5A9&5R<RDI.PH@("`@("`@("`@
M("`@("`@("`@('5N<V5T*"1O8FHI.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("`@("`@:68H(6ES<V5T*"1C;VYT96YT7W1R86YS9F5R7V5N8V]D:6YG6R=V
M86QU92==*2D*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1?=')A
M;G-F97)?96YC;V1I;F=;)W9A;'5E)UT@/2`G-V)I="<["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I;F-L=61E7V)O9&EE<R`_("1R971U<FXM/F)O
M9'D@/2`H)'1H:7,M/E]D96-O9&5?8F]D:65S(#\@)'1H:7,M/E]D96-O9&5"
M;V1Y*"1B;V1Y+"`D8V]N=&5N=%]T<F%N<V9E<E]E;F-O9&EN9ULG=F%L=64G
M72D@.B`D8F]D>2D@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!]"@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1C='EP92`](&5X<&QO9&4H)R\G+"`D9&5F875L=%]C='EP92D["B`@("`@
M("`@("`@("1R971U<FXM/F-T>7!E7W!R:6UA<GD@("`]("1C='EP95LP73L*
M("`@("`@("`@("`@)')E='5R;BT^8W1Y<&5?<V5C;VYD87)Y(#T@)&-T>7!E
M6S%=.PH@("`@("`@("`@("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S(#\@)')E
M='5R;BT^8F]D>2`]("@D=&AI<RT^7V1E8V]D95]B;V1I97,@/R`D=&AI<RT^
M7V1E8V]D94)O9'DH)&)O9'DI(#H@)&)O9'DI(#H@;G5L;#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1VEV96X@=&AE(&]U='!U="!O9B!T:&4@86)O=F4@9G5N8W1I;VXL('1H
M:7,@=VEL;"!R971U<FX@86X*("`@("`J(&%R<F%Y(&]F(')E9F5R96YC97,@
M=&\@=&AE('!A<G1S+"!I;F1E>&5D(&)Y(&UI;64@;G5M8F5R+@H@("`@("H*
M("`@("`J($!P87)A;2`@;V)J96-T("1S=')U8W1U<F4@("!4:&4@<W1R=6-T
M=7)E('1O(&=O('1H<F]U9V@*("`@("`J($!P87)A;2`@<W1R:6YG("1M:6UE
M7VYU;6)E<B!);G1E<FYA;"!U<V4@;VYL>2X*("`@("`J($!R971U<FX@87)R
M87D@("`@("`@("`@("`@("!-:6UE(&YU;6)E<G,*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F=E=$UI;65.=6UB97)S*"8D<W1R=6-T=7)E+"`D;F]?<F5F<R`]
M(&9A;'-E+"`D;6EM95]N=6UB97(@/2`G)RP@)'!R97!E;F0@/2`G)RD*("`@
M('L*("`@("`@("`D<F5T=7)N(#T@87)R87DH*3L*("`@("`@("!I9B`H(65M
M<'1Y*"1S=')U8W1U<F4M/G!A<G1S*2D@>PH@("`@("`@("`@("!I9B`H)&UI
M;65?;G5M8F5R("$]("<G*2!["B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E
M+3YM:6UE7VED(#T@)'!R97!E;F0@+B`D;6EM95]N=6UB97(["B`@("`@("`@
M("`@("`@("`D<F5T=7)N6R1P<F5P96YD("X@)&UI;65?;G5M8F5R72`]("8D
M<W1R=6-T=7)E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1S=')U8W1U<F4M/G!A<G1S*3L@)&DK*RD@>PH*
M("`@("`@("`@("`@"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1S=')U
M8W1U<F4M/FAE861E<G-;)V-O;G1E;G0M='EP92==*2!!3D0@<W5B<W1R*'-T
M<G1O;&]W97(H)'-T<G5C='5R92T^:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI
M+"`P+"`X*2`]/2`G;65S<V%G92\G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'!R97!E;F0@("`@("`]("1P<F5P96YD("X@)&UI;65?;G5M8F5R("X@)RXG
M.PH@("`@("`@("`@("`@("`@("`@("1?;6EM95]N=6UB97(@/2`G)SL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)%]M
M:6UE7VYU;6)E<B`]("@D;6EM95]N=6UB97(@/3T@)R<@/R`D:2`K(#$@.B!S
M<')I;G1F*"<E<RXE<R<L("1M:6UE7VYU;6)E<BP@)&D@*R`Q*2D["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%R<B`]("9-86EL7VUI
M;65$96-O9&4Z.F=E=$UI;65.=6UB97)S*"1S=')U8W1U<F4M/G!A<G1S6R1I
M72P@)&YO7W)E9G,L("1?;6EM95]N=6UB97(L("1P<F5P96YD*3L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1A<G(@87,@)&ME>2`]/B`D=F%L*2!["B`@
M("`@("`@("`@("`@("`@("`@)&YO7W)E9G,@/R`D<F5T=7)N6R1K97E=(#T@
M)R<@.B`D<F5T=7)N6R1K97E=(#T@)B1A<G);)&ME>5T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)&UI;65?;G5M8F5R(#T]("<G*2!["B`@("`@("`@("`@("`@
M("`D;6EM95]N=6UB97(@/2`G,2<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-T<G5C='5R92T^;6EM95]I9"`]("1P<F5P96YD("X@)&UI;65?;G5M
M8F5R.PH@("`@("`@("`@("`D;F]?<F5F<R`_("1R971U<FY;)'!R97!E;F0@
M+B`D;6EM95]N=6UB97)=(#T@)R<@.B`D<F5T=7)N6R1P<F5P96YD("X@)&UI
M;65?;G5M8F5R72`]("8D<W1R=6-T=7)E.PH@("`@("`@('T*("`@("`@("`*
M("`@("`@("!R971U<FX@)')E='5R;CL*("`@('T*"B`@("`O*BH*("`@("`J
M($=I=F5N(&$@<W1R:6YG(&-O;G1A:6YI;F<@82!H96%D97(@86YD(&)O9'D*
M("`@("`J('-E8W1I;VXL('1H:7,@9G5N8W1I;VX@=VEL;"!S<&QI="!T:&5M
M("AA="!T:&4@9FER<W0*("`@("`J(&)L86YK(&QI;F4I(&%N9"!R971U<FX@
M=&AE;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG($EN<'5T('1O('-P
M;&ET(&%P87)T"B`@("`@*B!`<F5T=7)N(&%R<F%Y($-O;G1A:6YS(&AE861E
M<B!A;F0@8F]D>2!S96-T:6]N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-P;&ET0F]D>4AE861E<B@D:6YP=70I"B`@
M("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>*"XJ/RE<<C]<;EQR/UQN
M*"XJ*2]S(BP@)&EN<'5T+"`D;6%T8V@I*2!["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@D;6%T8VA;,5TL("1M871C:%LR72D["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?97)R;W(@/2`G0V]U;&0@;F]T('-P;&ET(&AE861E<B!A
M;F0@8F]D>2<["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4&%R<V4@:&5A9&5R<R!G:79E;B!I;B`D:6YP=70@86YD(')E
M='5R;@H@("`@("H@87,@87-S;V,@87)R87DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R!(96%D97)S('1O('!A<G-E"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y($-O;G1A:6YS('!A<G-E9"!H96%D97)S"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E2&5A9&5R<R@D:6YP
M=70I"B`@("!["@H@("`@("`@(&EF("@D:6YP=70@(3T]("<G*2!["B`@("`@
M("`@("`@("\O(%5N9F]L9"!T:&4@:6YP=70*("`@("`@("`@("`@)&EN<'5T
M("`@/2!P<F5G7W)E<&QA8V4H(B]<<C]<;B\B+"`B7')<;B(L("1I;G!U="D[
M"B`@("`@("`@("`@("1I;G!U="`@(#T@<')E9U]R97!L86-E*"(O7')<;BA<
M='P@*2LO(BP@)R`G+"`D:6YP=70I.PH@("`@("`@("`@("`D:&5A9&5R<R`]
M(&5X<&QO9&4H(EQR7&XB+"!T<FEM*"1I;G!U="DI.PH*("`@("`@("`@("`@
M9F]R96%C:"`H)&AE861E<G,@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@
M("`D:&1R7VYA;64@/2!S=6)S='(H)'9A;'5E+"`P+"`D<&]S(#T@<W1R<&]S
M*"1V86QU92P@)SHG*2D["B`@("`@("`@("`@("`@("`D:&1R7W9A;'5E(#T@
M<W5B<W1R*"1V86QU92P@)'!O<RLQ*3L*("`@("`@("`@("`@("`@(&EF*"1H
M9')?=F%L=65;,%T@/3T@)R`G*0H@("`@("`@("`@("`@("`@("`@("1H9')?
M=F%L=64@/2!S=6)S='(H)&AD<E]V86QU92P@,2D["@H@("`@("`@("`@("`@
M("`@)')E='5R;EM=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;F%M92<@(#T^("1H9')?;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'1H:7,M/E]D96-O
M9&5?:&5A9&5R<R`_("1T:&ES+3Y?9&5C;V1E2&5A9&5R*"1H9')?=F%L=64I
M(#H@)&AD<E]V86QU90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E='5R;B`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)')E='5R;CL*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O
M('!A<G-E(&$@:&5A9&5R('9A;'5E+`H@("`@("H@97AT<F%C="!F:7)S="!P
M87)T+"!A;F0@86YY('-E8V]N9&%R>0H@("`@("H@<&%R=',@*&%F=&5R(#LI
M(%1H:7,@9G5N8W1I;VX@:7,@;F]T(&%S"B`@("`@*B!R;V)U<W0@87,@:70@
M8V]U;&0@8F4N($5G+B!H96%D97(@8V]M;65N=',*("`@("`J(&EN('1H92!W
M<F]N9R!P;&%C92!W:6QL('!R;V)A8FQY(&)R96%K(&ET+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@2&5A9&5R('9A;'5E('1O('!A<G-E"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y($-O;G1A:6YS('!A<G-E9"!R97-U;'0*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5(
M96%D97)686QU92@D:6YP=70I"B`@("!["@H@("`@("`@(&EF("@H)'!O<R`]
M('-T<G!O<R@D:6YP=70L("<[)RDI("$]/2!F86QS92D@>PH*("`@("`@("`@
M("`@)')E='5R;ELG=F%L=64G72`]('1R:6TH<W5B<W1R*"1I;G!U="P@,"P@
M)'!O<RDI.PH@("`@("`@("`@("`D:6YP=70@/2!T<FEM*'-U8G-T<B@D:6YP
M=70L("1P;W,K,2DI.PH*("`@("`@("`@("`@:68@*'-T<FQE;B@D:6YP=70I
M(#X@,"D@>PH*("`@("`@("`@("`@("`@("\O(%1H:7,@<W!L:71S(&]N(&$@
M<V5M:2UC;VQO;BP@:68@=&AE<F4G<R!N;R!P<F5C965D:6YG(&)A8VMS;&%S
M:`H@("`@("`@("`@("`@("`@+R\@3F]W('=O<FMS('=I=&@@<75O=&5D('9A
M;'5E<SL@:&%D('1O(&=L=64@=&AE(%P[(&)R96%K<R!I;B!02%`*("`@("`@
M("`@("`@("`@("\O('1H92!R96=E>"!I<R!A;')E861Y(&)O<F1E<FEN9R!O
M;B!I;F-O;7!R96AE;G-I8FQE"B`@("`@("`@("`@("`@("`D<W!L:71296=E
M>"`]("<O*%M>.UPG(ETJ6UPG(ETH6UY<)R)=*BA;7EPG(ETJ*2HI6UPG(EU;
M7CM<)R)=*GPH6UX[72LI*2@[?"0I+R<["B`@("`@("`@("`@("`@("!P<F5G
M7VUA=&-H7V%L;"@D<W!L:71296=E>"P@)&EN<'5T+"`D;6%T8VAE<RD["B`@
M("`@("`@("`@("`@("`D<&%R86UE=&5R<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("!F;W(@*"1I/3`[("1I/&-O=6YT*"1M871C:&5S6S!=*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@("`@("1P87)A;2`]("1M871C:&5S6S!=
M6R1I73L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H<W5B<W1R*"1P87)A
M;2P@+3(I(#T]("=<.R<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M("X]("1M871C:&5S6S!=6RLK)&E=.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D<&%R86UE=&5R<UM=(#T@)'!A<F%M
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1P87)A;65T97)S*3L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("1P87)A;5]N86UE("`]('1R:6TH<W5B<W1R*"1P87)A
M;65T97)S6R1I72P@,"P@)'!O<R`]('-T<G!O<R@D<&%R86UE=&5R<ULD:5TL
M("<])RDI+"`B)UPB.UQT7%P@(BD["B`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M7W9A;'5E(#T@=')I;2AS=')?<F5P;&%C92@G7#LG+"`G.R<L('-U8G-T
M<B@D<&%R86UE=&5R<ULD:5TL("1P;W,@*R`Q*2DL("(G7"([7'1<7"`B*3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M7W9A;'5E6S!=(#T]("<B
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86U?=F%L=64@/2!S
M=6)S='(H)'!A<F%M7W9A;'5E+"`Q+"`M,2D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1R971U<FY;)V]T:&5R)UU;)'!A
M<F%M7VYA;65=(#T@)'!A<F%M7W9A;'5E.PH@("`@("`@("`@("`@("`@("`@
M("1R971U<FY;)V]T:&5R)UU;<W1R=&]L;W=E<B@D<&%R86U?;F%M92E=(#T@
M)'!A<F%M7W9A;'5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E='5R;ELG=F%L=64G
M72`]('1R:6TH)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5T=7)N.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!S
M<&QI=',@=&AE(&EN<'5T(&)A<V5D"B`@("`@*B!O;B!T:&4@9VEV96X@8F]U
M;F1A<GD*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG($EN<'5T('1O('!A
M<G-E"B`@("`@*B!`<F5T=7)N(&%R<F%Y($-O;G1A:6YS(&%R<F%Y(&]F(')E
M<W5L=&EN9R!M:6UE('!A<G1S"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V)O=6YD87)Y4W!L:70H)&EN<'5T+"`D8F]U
M;F1A<GDI"B`@("!["B`@("`@("`@)'!A<G1S(#T@87)R87DH*3L*"B`@("`@
M("`@)&)S7W!O<W-I8FQE(#T@<W5B<W1R*"1B;W5N9&%R>2P@,BP@+3(I.PH@
M("`@("`@("1B<U]C:&5C:R`]("=<(B<@+B`D8G-?<&]S<VEB;&4@+B`G7"(G
M.PH*("`@("`@("!I9B`H)&)O=6YD87)Y(#T]("1B<U]C:&5C:RD@>PH@("`@
M("`@("`@("`D8F]U;F1A<GD@/2`D8G-?<&]S<VEB;&4["B`@("`@("`@?0H*
M("`@("`@("`D=&UP(#T@97AP;&]D92@G+2TG("X@)&)O=6YD87)Y+"`D:6YP
M=70I.PH*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"!C;W5N="@D=&UP*2`M
M(#$[("1I*RLI('L*("`@("`@("`@("`@)'!A<G1S6UT@/2`D=&UP6R1I73L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R=',["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!':79E;B!A(&AE861E<BP@=&AI<R!F=6YC=&EO;B!W:6QL
M(&1E8V]D92!I=`H@("`@("H@86-C;W)D:6YG('1O(%)&0S(P-#<N(%!R;V)A
M8FQY(&YO="`J97AA8W1L>2H*("`@("`J(&-O;F9O<FUA;G0L(&)U="!I="!D
M;V5S('!A<W,@86QL('1H92!G:79E;@H@("`@("H@97AA;7!L97,@*&EN(%)&
M0S(P-#<I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@26YP=70@:&5A
M9&5R('9A;'5E('1O(&1E8V]D90H@("`@("H@0')E='5R;B!S=')I;F<@1&5C
M;V1E9"!H96%D97(@=F%L=64*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E2&5A9&5R*"1I;G!U="D*("`@('L*
M("`@("`@("`O+R!296UO=F4@=VAI=&4@<W!A8V4@8F5T=V5E;B!E;F-O9&5D
M+7=O<F1S"B`@("`@("`@)&EN<'5T(#T@<')E9U]R97!L86-E*"<O*#U</UM>
M/UTK7#\H<7QB*5P_6UX_72I</STI*%QS*2L]7#\O:2<L("=<,3T_)RP@)&EN
M<'5T*3L*"B`@("`@("`@+R\@1F]R(&5A8V@@96YC;V1E9"UW;W)D+BXN"B`@
M("`@("`@=VAI;&4@*'!R96=?;6%T8V@H)R\H/5P_*%M>/UTK*5P_*'%\8BE<
M/RA;7C]=*BE</STI+VDG+"`D:6YP=70L("1M871C:&5S*2D@>PH*("`@("`@
M("`@("`@)&5N8V]D960@(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("1C
M:&%R<V5T("`]("1M871C:&5S6S)=.PH@("`@("`@("`@("`D96YC;V1I;F<@
M/2`D;6%T8VAE<ULS73L*("`@("`@("`@("`@)'1E>'0@("`@(#T@)&UA=&-H
M97-;-%T["@H@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)&5N8V]D
M:6YG*2D@>PH@("`@("`@("`@("`@("`@8V%S92`G8B<Z"B`@("`@("`@("`@
M("`@("`@("`@)'1E>'0@/2!B87-E-C1?9&5C;V1E*"1T97AT*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=Q
M)SH*("`@("`@("`@("`@("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"=?
M)RP@)R`G+"`D=&5X="D["B`@("`@("`@("`@("`@("`@("`@<')E9U]M871C
M:%]A;&PH)R\]*%MA+68P+3E=>S)]*2]I)RP@)'1E>'0L("1M871C:&5S*3L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"1M871C:&5S6S%=(&%S("1V
M86QU92D*("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0@/2!S=')?<F5P
M;&%C92@G/2<N)'9A;'5E+"!C:'(H:&5X9&5C*"1V86QU92DI+"`D=&5X="D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1I;G!U="`]('-T<E]R97!L86-E*"1E;F-O9&5D+"`D=&5X
M="P@)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YP=70[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(&)O9'D@<W1R:6YG(&%N
M9"!A;B!E;F-O9&EN9R!T>7!E+`H@("`@("H@=&AI<R!F=6YC=&EO;B!W:6QL
M(&1E8V]D92!A;F0@<F5T=7)N(&ET+@H@("`@("H*("`@("`J($!P87)A;2`@
M<W1R:6YG($EN<'5T(&)O9'D@=&\@9&5C;V1E"B`@("`@*B!`<&%R86T@('-T
M<FEN9R!%;F-O9&EN9R!T>7!E('1O('5S92X*("`@("`J($!R971U<FX@<W1R
M:6YG($1E8V]D960@8F]D>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]D96-O9&5";V1Y*"1I;G!U="P@)&5N8V]D:6YG
M(#T@)S=B:70G*0H@("`@>PH@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<B@D
M96YC;V1I;F<I*2!["B`@("`@("`@("`@(&-A<V4@)S=B:70G.@H@("`@("`@
M("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G<75O=&5D+7!R:6YT86)L92<Z"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]Q=6]T9610<FEN=&%B;&5$96-O
M9&4H)&EN<'5T*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G8F%S938T)SH*("`@("`@("`@("`@("`@(')E='5R;B!B87-E
M-C1?9&5C;V1E*"1I;G!U="D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@)&EN
M<'5T.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@
M<75O=&5D+7!R:6YT86)L92!S=')I;F<L('1H:7,*("`@("`J(&9U;F-T:6]N
M('=I;&P@9&5C;V1E(&%N9"!R971U<FX@:70N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!S=')I;F<@26YP=70@8F]D>2!T;R!D96-O9&4*("`@("`J($!R971U
M<FX@<W1R:6YG($1E8V]D960@8F]D>0H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]Q=6]T9610<FEN=&%B;&5$96-O9&4H
M)&EN<'5T*0H@("`@>PH@("`@("`@("\O(%)E;6]V92!S;V9T(&QI;F4@8G)E
M86MS"B`@("`@("`@)&EN<'5T(#T@<')E9U]R97!L86-E*"(O/5QR/UQN+R(L
M("<G+"`D:6YP=70I.PH*("`@("`@("`O+R!297!L86-E(&5N8V]D960@8VAA
M<F%C=&5R<PH)"21I;G!U="`]('!R96=?<F5P;&%C92@G+STH6V$M9C`M.5U[
M,GTI+VEE)RP@(F-H<BAH97AD96,H)UQ<,2<I*2(L("1I;G!U="D["@H@("`@
M("`@(')E='5R;B`D:6YP=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:W,@=&AE(&EN<'5T(&9O<B!U=65N8V]D960@9FEL97,@86YD(')E='5R;G,*
M("`@("`J(&%N(&%R<F%Y(&]F('1H96TN($-A;B!B92!C86QL960@<W1A=&EC
M86QL>2P@96<Z"B`@("`@*@H@("`@("H@)&9I;&5S(#TF($UA:6Q?;6EM941E
M8V]D93HZ=75D96-O9&4H)'-O;65?=&5X="D["B`@("`@*@H@("`@("H@270@
M=VEL;"!C:&5C:R!F;W(@=&AE(&)E9VEN(#8V-B`N+BX@96YD('-Y;G1A>`H@
M("`@("H@:&]W979E<B!A;F0@=V]N)W0@:G5S="!B;&EN9&QY(&1E8V]D92!W
M:&%T979E<B!Y;W4*("`@("`J('!A<W,@:70N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!S=')I;F<@26YP=70@8F]D>2!T;R!L;V]K(&9O<B!A='1A:&-M96YT
M<R!I;@H@("`@("H@0')E='5R;B!A<G)A>2`@1&5C;V1E9"!B;V1I97,L(&9I
M;&5N86UE<R!A;F0@<&5R;6ES<VEO;G,*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`875T:&]R(%5N:VYO=VX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G5U9&5C;V1E*"1I;G!U="D*("`@('L*("`@("`@("`O+R!&:6YD(&%L;"!U
M=65N8V]D960@<V5C=&EO;G,*("`@("`@("!P<F5G7VUA=&-H7V%L;"@B+V)E
M9VEN("A;,"TW77LS?2D@*"XK*5QR/UQN*"XK*5QR/UQN96YD+U5S(BP@)&EN
M<'5T+"`D;6%T8VAE<RD["@H@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\(&-O
M=6YT*"1M871C:&5S6S-=*3L@)&HK*RD@>PH*("`@("`@("`@("`@)'-T<B`@
M("`@(#T@)&UA=&-H97-;,UU;)&I=.PH@("`@("`@("`@("`D9FEL96YA;64@
M/2`D;6%T8VAE<ULR75LD:ET["B`@("`@("`@("`@("1F:6QE<&5R;2`]("1M
M871C:&5S6S%=6R1J73L*"B`@("`@("`@("`@("1F:6QE(#T@)R<["B`@("`@
M("`@("`@("1S='(@/2!P<F5G7W-P;&ET*"(O7'(_7&XO(BP@=')I;2@D<W1R
M*2D["B`@("`@("`@("`@("1S=')L96X@/2!C;W5N="@D<W1R*3L*"B`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1S=')L96X[("1I*RLI('L*("`@
M("`@("`@("`@("`@("1P;W,@/2`Q.PH@("`@("`@("`@("`@("`@)&0@/2`P
M.PH@("`@("`@("`@("`@("`@)&QE;CTH:6YT*2@H*&]R9"AS=6)S='(H)'-T
M<ELD:5TL,"PQ*2D@+3,R*2`M("<@)RD@)B`P-S<I.PH*("`@("`@("`@("`@
M("`@('=H:6QE("@H)&0@*R`S(#P]("1L96XI($%.1"`H)'!O<R`K(#0@/#T@
M<W1R;&5N*"1S=');)&E=*2DI('L*("`@("`@("`@("`@("`@("`@("`D8S`@
M/2`H;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S+#$I*2!>(#!X,C`I.PH@("`@
M("`@("`@("`@("`@("`@("1C,2`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P
M;W,K,2PQ*2D@7B`P>#(P*3L*("`@("`@("`@("`@("`@("`@("`D8S(@/2`H
M;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S*S(L,2DI(%X@,'@R,"D["B`@("`@
M("`@("`@("`@("`@("`@)&,S(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL)'!O
M<RLS+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@("`@("`@("1F:6QE("X]
M(&-H<B@H*"@D8S`@+2`G("<I("8@,#<W*2`\/"`R*2!\("@H*"1C,2`M("<@
M)RD@)B`P-S<I(#X^(#0I*3L*"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@
M+CT@8VAR*"@H*"1C,2`M("<@)RD@)B`P-S<I(#P\(#0I('P@*"@H)&,R("T@
M)R`G*2`F(#`W-RD@/CX@,BDI.PH*("`@("`@("`@("`@("`@("`@("`D9FEL
M92`N/2!C:'(H*"@H)&,R("T@)R`G*2`F(#`W-RD@/#P@-BD@?"`@*"@D8S,@
M+2`G("<I("8@,#<W*2D["@H@("`@("`@("`@("`@("`@("`@("1P;W,@*ST@
M-#L*("`@("`@("`@("`@("`@("`@("`D9"`K/2`S.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@(&EF("@H)&0@*R`R(#P]("1L96XI("8F
M("@D<&]S("L@,R`\/2!S=')L96XH)'-T<ELD:5TI*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1C,"`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,L,2DI
M(%X@,'@R,"D["B`@("`@("`@("`@("`@("`@("`@)&,Q(#T@*&]R9"AS=6)S
M='(H)'-T<ELD:5TL)'!O<RLQ+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@
M("`@("`@("1C,B`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,K,BPQ*2D@
M7B`P>#(P*3L*("`@("`@("`@("`@("`@("`@("`D9FEL92`N/2!C:'(H*"@H
M)&,P("T@)R`G*2`F(#`W-RD@/#P@,BD@?"`H*"@D8S$@+2`G("<I("8@,#<W
M*2`^/B`T*2D["@H@("`@("`@("`@("`@("`@("`@("1F:6QE("X](&-H<B@H
M*"@D8S$@+2`G("<I("8@,#<W*2`\/"`T*2!\("@H*"1C,B`M("<@)RD@)B`P
M-S<I(#X^(#(I*3L*"B`@("`@("`@("`@("`@("`@("`@)'!O<R`K/2`S.PH@
M("`@("`@("`@("`@("`@("`@("1D("L](#(["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@:68@*"@D9"`K(#$@/#T@)&QE;BD@)B8@*"1P
M;W,@*R`R(#P]('-T<FQE;B@D<W1R6R1I72DI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&,P(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL)'!O<RPQ*2D@7B`P
M>#(P*3L*("`@("`@("`@("`@("`@("`@("`D8S$@/2`H;W)D*'-U8G-T<B@D
M<W1R6R1I72PD<&]S*S$L,2DI(%X@,'@R,"D["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&4@+CT@8VAR*"@H*"1C,"`M("<@)RD@)B`P-S<I(#P\(#(I('P@
M*"@H)&,Q("T@)R`G*2`F(#`W-RD@/CX@-"DI.PH*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FEL97-;72`](&%R<F%Y
M*"=F:6QE;F%M92<@/3X@)&9I;&5N86UE+"`G9FEL97!E<FTG(#T^("1F:6QE
M<&5R;2P@)V9I;&5D871A)R`]/B`D9FEL92D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&9I;&5S.PH@("`@?0H*("`@("\J*@H@("`@("H@9V5T4V5N
M9$%R<F%Y*"D@<F5T=7)N<R!T:&4@87)G=6UE;G1S(')E<75I<F5D(&9O<B!-
M86EL.CIS96YD*"D*("`@("`J('5S960@=&\@8G5I;&0@=&AE(&%R9W5M96YT
M<R!F;W(@82!M86EL.CIS96YD*"D@8V%L;"`*("`@("`J"B`@("`@*B!5<V%G
M93H*("`@("`J("1M86EL=&5X="`]($9U;&P@96UA:6P@*&9O<B!E>&%M<&QE
M(&=E;F5R871E9"!B>2!A('1E;7!L871E*0H@("`@("H@)&1E8V]D97(@/2!N
M97<@36%I;%]M:6UE1&5C;V1E*"1M86EL=&5X="D["B`@("`@*B`D<&%R=',@
M/2`@)&1E8V]D97(M/F=E=%-E;F1!<G)A>2@I.PH@("`@("H@:68@*"%014%2
M.CII<T5R<F]R*"1P87)T<RD@>PH@("`@("H@("`@(&QI<W0H)')E8VEP96YT
M<RPD:&5A9&5R<RPD8F]D>2D@/2`D<&%R=',["B`@("`@*B`@("`@)&UA:6P@
M/2!-86EL.CIF86-T;W)Y*"=S;71P)RD["B`@("`@*B`@("`@)&UA:6PM/G-E
M;F0H)')E8VEP96YT<RPD:&5A9&5R<RPD8F]D>2D["B`@("`@*B!](&5L<V4@
M>PH@("`@("H@("`@(&5C:&\@)'!A<G1S+3YM97-S86=E.PH@("`@("H@?0H@
M("`@("H@0')E='5R;B!M:7AE9"`@(&%R<F%Y(&]F(')E8VEP96EN="P@:&5A
M9&5R<RQB;V1Y(&]R(%!E87)?17)R;W(*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`875T:&]R($%L86X@2VYO=VQE<R`\86QA;D!A:V)K:&]M92YC
M;VT^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E;F1!<G)A>2@I"B`@("![
M"B`@("`@("`@+R\@<')E=F5N="!W87)N:6YG(&EF('1H:7,@:7,@;F]T('-E
M=`H@("`@("`@("1T:&ES+3Y?9&5C;V1E7VAE861E<G,@/2!&04Q313L*("`@
M("`@("`D:&5A9&5R;&ES="`])'1H:7,M/E]P87)S94AE861E<G,H)'1H:7,M
M/E]H96%D97(I.PH@("`@("`@("1T;R`]("(B.PH@("`@("`@(&EF("@A)&AE
M861E<FQI<W0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")-97-S86=E(&1I9"!N;W0@8V]N=&%I;B!H96%D97)S(BD["B`@("`@
M("`@?0H@("`@("`@(&9O<F5A8V@H)&AE861E<FQI<W0@87,@)&ET96TI('L*
M("`@("`@("`@("`@)&AE861E<ELD:71E;5LG;F%M92==72`]("1I=&5M6R=V
M86QU92==.PH@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)&ET96U;
M)VYA;64G72DI('L*("`@("`@("`@("`@("`@(&-A<V4@(G1O(CH*("`@("`@
M("`@("`@("`@(&-A<V4@(F-C(CH*("`@("`@("`@("`@("`@(&-A<V4@(F)C
M8R(Z"B`@("`@("`@("`@("`@("`@("`@)'1O(#T@(BPB+B1I=&5M6R=V86QU
M92==.PH@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&\@/3T@(B(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")-97-S86=E(&1I9"!N;W0@8V]N=&%I;B!A;GD@<F5C:7!E;G1S
M(BD["B`@("`@("`@?0H@("`@("`@("1T;R`]('-U8G-T<B@D=&\L,2D["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"1T;RPD:&5A9&5R+"1T:&ES+3Y?8F]D>2D[
M"B`@("!](`H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('AM;"!C;W!Y(&]F
M('1H92!O=71P=70@;V8*("`@("`J($UA:6Q?;6EM941E8V]D93HZ9&5C;V1E
M+B!087-S('1H92!O=71P=70@:6X@87,@=&AE"B`@("`@*B!A<F=U;65N="X@
M5&AI<R!F=6YC=&EO;B!C86X@8F4@8V%L;&5D('-T871I8V%L;'DN($5G.@H@
M("`@("H*("`@("`J("1O=71P=70@/2`D;V)J+3YD96-O9&4H*3L*("`@("`J
M("1X;6P@("`@/2!-86EL7VUI;65$96-O9&4Z.F=E=%A-3"@D;W5T<'5T*3L*
M("`@("`J"B`@("`@*B!4:&4@1%1$('5S960@9F]R('1H:7,@<VAO=6QD(&AA
M=F4@8F5E;B!I;B!T:&4@<&%C:V%G92X@3W(*("`@("`J(&%L=&5R;F%T:79E
M;'D@>6]U(&-A;B!G970@:70@9G)O;2!C=G,L(&]R(&AE<F4Z"B`@("`@*B!H
M='1P.B\O=W=W+G!H<&=U<G4N;W)G+WAM86EL+WAM86EL+F1T9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&]B:F5C="!);G!U="!T;R!C;VYV97)T('1O('AM
M;"X@5&AI<R!S:&]U;&0@8F4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!O
M=71P=70@;V8@=&AE($UA:6Q?;6EM941E8V]D93HZ9&5C;V1E(&9U;F-T:6]N
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!834P@=F5R<VEO;B!O9B!I;G!U=`H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M6$U,*"1I;G!U="D*("`@('L*("`@("`@("`D8W)L9B`@("`]("`B7')<;B([
M"B`@("`@("`@)&]U='!U="`@/2`G/#]X;6P@=F5R<VEO;CU<)S$N,%PG/SXG
M("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("`@)SPA1$]#5%E012!E;6%I
M;"!365-414T@(FAT='`Z+R]W=W<N<&AP9W5R=2YO<F<O>&UA:6PO>&UA:6PN
M9'1D(CXG("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("`@)SQE;6%I;#XG
M("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("`@36%I;%]M:6UE1&5C;V1E
M.CI?9V5T6$U,*"1I;G!U="D@+@H@("`@("`@("`@("`@("`@("`@)SPO96UA
M:6P^)SL*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&=6YC=&EO;B!T:&%T(&1O97,@=&AE(&%C='5A;"!C;VYV97)S
M:6]N('1O('AM;"X@1&]E<R!A('-I;F=L90H@("`@("H@;6EM97!A<G0@870@
M82!T:6UE+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T("!);G!U="!T
M;R!C;VYV97)T('1O('AM;"X@5&AI<R!I<R!A(&UI;65P87)T(&]B:F5C="X*
M("`@("`J("`@("`@("`@("`@("`@("!)="!M87D@;W(@;6%Y(&YO="!C;VYT
M86EN('-U8G!A<G1S+@H@("`@("H@0'!A<F%M("!I;G1E9V5R($YU;6)E<B!O
M9B!T86)S('1O(&EN9&5N=`H@("`@("H@0')E='5R;B!S=')I;F<@(%A-3"!V
M97)S:6]N(&]F(&EN<'5T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=%A-3"@D:6YP=70L("1I;F1E;G0@/2`Q*0H@
M("`@>PH@("`@("`@("1H=&%B("`@(#T@(")<="(["B`@("`@("`@)&-R;&8@
M("`@/2`@(EQR7&XB.PH@("`@("`@("1O=71P=70@(#T@("<G.PH@("`@("`@
M("1H96%D97)S(#T@0"AA<G)A>2DD:6YP=70M/FAE861E<G,["@H@("`@("`@
M(&9O<F5A8V@@*"1H96%D97)S(&%S("1H9')?;F%M92`]/B`D:&1R7W9A;'5E
M*2!["@H@("`@("`@("`@("`O+R!-=6QT:7!L92!H96%D97)S('=I=&@@=&AI
M<R!N86UE"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D:&5A9&5R<ULD:&1R
M7VYA;65=*2D@>PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&AD<E]V86QU92D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]($UA:6Q?;6EM941E8V]D93HZ7V=E=%A-3%]H96QP97(H
M)&AD<E]N86UE+"`D:&1R7W9A;'5E6R1I72P@)&EN9&5N="D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!/;FQY(&]N92!H96%D97(@;V8@
M=&AI<R!S;W)T"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]($UA:6Q?;6EM941E8V]D93HZ7V=E=%A-3%]H96QP97(H
M)&AD<E]N86UE+"`D:&1R7W9A;'5E+"`D:6YD96YT*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D:6YP=70M/G!A<G1S
M*2D@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D:6YP
M=70M/G!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D8W)L9B`N('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)SQM:6UE
M<&%R=#XG("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("!-
M86EL7VUI;65$96-O9&4Z.E]G971834PH)&EN<'5T+3YP87)T<ULD:5TL("1I
M;F1E;G0K,2D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')?<F5P
M96%T*"1H=&%B+"`D:6YD96YT*2`N("<\+VUI;65P87)T/B<@+B`D8W)L9CL*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("AI<W-E="@D:6YP=70M
M/F)O9'DI*2!["B`@("`@("`@("`@("1O=71P=70@+CT@)&-R;&8@+B!S=')?
M<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N("<\8F]D>3X\(5M#1$%405LG("X*
M("`@("`@("`@("`@("`@("`@("`@("`D:6YP=70M/F)O9'D@+B`G75T^/"]B
M;V1Y/B<@+B`D8W)L9CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T
M<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@2&5L<&5R(&9U;F-T:6]N('1O
M(%]G971834PH*2X@4F5T=7)N<R!X;6P@;V8@82!H96%D97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!S=')I;F<@($YA;64@;V8@:&5A9&5R"B`@("`@*B!`
M<&%R86T@('-T<FEN9R`@5F%L=64@;V8@:&5A9&5R"B`@("`@*B!`<&%R86T@
M(&EN=&5G97(@3G5M8F5R(&]F('1A8G,@=&\@:6YD96YT"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@6$U,('9E<G-I;VX@;V8@:6YP=70*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T6$U,7VAE;'!E
M<B@D:&1R7VYA;64L("1H9')?=F%L=64L("1I;F1E;G0I"B`@("!["B`@("`@
M("`@)&AT86(@("`](")<="(["B`@("`@("`@)&-R;&8@("`](")<<EQN(CL*
M("`@("`@("`D<F5T=7)N(#T@)R<["@H@("`@("`@("1N97=?:&1R7W9A;'5E
M(#T@*"1H9')?;F%M92`A/2`G<F5C96EV960G*2`_($UA:6Q?;6EM941E8V]D
M93HZ7W!A<G-E2&5A9&5R5F%L=64H)&AD<E]V86QU92D@.B!A<G)A>2@G=F%L
M=64G(#T^("1H9')?=F%L=64I.PH@("`@("`@("1N97=?:&1R7VYA;64@(#T@
M<W1R7W)E<&QA8V4H)R`G+"`G+2<L('5C=V]R9',H<W1R7W)E<&QA8V4H)RTG
M+"`G("<L("1H9')?;F%M92DI*3L*"B`@("`@("`@+R\@4V]R="!O=70@86YY
M('!A<F%M971E<G,*("`@("`@("!I9B`H(65M<'1Y*"1N97=?:&1R7W9A;'5E
M6R=O=&AE<B==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;F5W7VAD<E]V
M86QU95LG;W1H97(G72!A<R`D<&%R86UN86UE(#T^("1P87)A;79A;'5E*2![
M"B`@("`@("`@("`@("`@("`D<&%R86US6UT@/2!S=')?<F5P96%T*"1H=&%B
M+"`D:6YD96YT*2`N("1H=&%B("X@)SQP87)A;65T97(^)R`N("1C<FQF("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<E]R97!E870H)&AT86(L
M("1I;F1E;G0I("X@)&AT86(@+B`D:'1A8B`N("<\<&%R86UN86UE/B<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1P87)A;6YA;64I("X@)SPO<&%R86UN86UE/B<@
M+B`D8W)L9B`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')?<F5P
M96%T*"1H=&%B+"`D:6YD96YT*2`N("1H=&%B("X@)&AT86(@+B`G/'!A<F%M
M=F%L=64^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'!A<F%M=F%L=64I("X@)SPO
M<&%R86UV86QU93XG("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@+B`D:'1A8B`N("<\
M+W!A<F%M971E<CXG("X@)&-R;&8["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1P87)A;7,@/2!I;7!L;V1E*"<G+"`D<&%R86US*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<&%R86US(#T@)R<["B`@("`@("`@?0H*
M("`@("`@("`D<F5T=7)N(#T@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@
M+B`G/&AE861E<CXG("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("!S=')?
M<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N("1H=&%B("X@)SQH96%D97)N86UE
M/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1N97=?:&1R7VYA;64I("X@)SPO:&5A
M9&5R;F%M93XG("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("!S=')?<F5P
M96%T*"1H=&%B+"`D:6YD96YT*2`N("1H=&%B("X@)SQH96%D97)V86QU93XG
M("X@:'1M;'-P96-I86QC:&%R<R@D;F5W7VAD<E]V86QU95LG=F%L=64G72D@
M+B`G/"]H96%D97)V86QU93XG("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@
M("`D<&%R86US("X*("`@("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D:'1A
M8BP@)&EN9&5N="D@+B`G/"]H96%D97(^)R`N("1C<FQF.PH*("`@("`@("!R
M971U<FX@)')E='5R;CL*("`@('T*"GT@+R\@16YD(&]F(&-L87-S"C\^"@``
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O36%I;"]S96YD;6%I;"YP:'``````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,S-C8`,3`U,34T,S$P
M-3<`,#(P-30Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HO*BH*("H@4V5N9&UA
M:6P@:6UP;&5M96YT871I;VX@;V8@=&AE(%!%05(@36%I;#HZ(&EN=&5R9F%C
M92X*("H@0&%C8V5S<R!P=6)L:6,*("H@0'!A8VMA9V4@36%I;`H@*B!`=F5R
M<VEO;B`D4F5V:7-I;VXZ(#$N,3,@)`H@*B\*8VQA<W,@36%I;%]S96YD;6%I
M;"!E>'1E;F1S($UA:6P@>PH*"2\J*@H@("`@("H@5&AE(&QO8V%T:6]N(&]F
M('1H92!S96YD;6%I;"!O<B!S96YD;6%I;"!W<F%P<&5R(&)I;F%R>2!O;B!T
M:&4*("`@("`J(&9I;&5S>7-T96TN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)'-E;F1M86EL7W!A=&@@/2`G+W5S<B]S8FEN+W-E;F1M
M86EL)SL*"@DO*BH*("`@("`J($%N>2!E>'1R82!C;VUM86YD+6QI;F4@<&%R
M86UE=&5R<R!T;R!P87-S('1O('1H92!S96YD;6%I;"!O<@H@("`@("H@<V5N
M9&UA:6P@=W)A<'!E<B!B:6YA<GDN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)'-E;F1M86EL7V%R9W,@/2`G)SL*"@DO*BH*("`@("`J
M($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($EN<W1A;G1I871E<R!A(&YE
M=R!-86EL7W-E;F1M86EL.CH@;V)J96-T(&)A<V5D(&]N('1H92!P87)A;65T
M97)S"B`@("`@*B!P87-S960@:6XN($ET(&QO;VMS(&9O<B!T:&4@9F]L;&]W
M:6YG('!A<F%M971E<G,Z"B`@("`@*B`@("`@<V5N9&UA:6Q?<&%T:"`@("!4
M:&4@;&]C871I;VX@;V8@=&AE('-E;F1M86EL(&)I;F%R>2!O;B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@(&9I;&5S>7-T96TN($1E9F%U;'1S
M('1O("<O=7-R+W-B:6XO<V5N9&UA:6PG+@H@("`@("H*("`@("`J("`@("!S
M96YD;6%I;%]A<F=S("`@($%N>2!E>'1R82!P87)A;65T97)S('1O('!A<W,@
M=&\@=&AE('-E;F1M86EL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!O
M<B!S96YD;6%I;"!W<F%P<&5R(&)I;F%R>2X*("`@("`J"B`@("`@*B!)9B!A
M('!A<F%M971E<B!I<R!P<F5S96YT(&EN('1H92`D<&%R86US(&%R<F%Y+"!I
M="!R97!L86-E<R!T:&4*("`@("`J(&1E9F%U;'0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@2&%S:"!C;VYT86EN:6YG(&%N>2!P87)A
M;65T97)S(&1I9F9E<F5N="!F<F]M('1H90H@("`@("H@("`@("`@("`@("`@
M(&1E9F%U;'1S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@36%I;%]S96YD;6%I;"@D<&%R86US*0H@("`@>PH@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=S96YD;6%I;%]P871H)UTI*2`D=&AI<RT^
M<V5N9&UA:6Q?<&%T:"`]("1P87)A;7-;)W-E;F1M86EL7W!A=&@G73L*("`@
M("`@("!I9B`H:7-S970H)'!A<F%M<ULG<V5N9&UA:6Q?87)G<R==*2D@)'1H
M:7,M/G-E;F1M86EL7V%R9W,@/2`D<&%R86US6R=S96YD;6%I;%]A<F=S)UT[
M"@H@("`@("`@("\J"B`@("`@("`@("H@0F5C875S92!W92!N965D('1O('!A
M<W,@;65S<V%G92!H96%D97)S('1O('1H92!S96YD;6%I;"!P<F]G<F%M(&]N
M"B`@("`@("`@("H@=&AE(&-O;6UA;F1L:6YE+"!W92!C86XG="!G=6%R86YT
M964@=&AE('5S92!O9B!T:&4@<W1A;F1A<F0@(EQR7&XB"B`@("`@("`@("H@
M<V5P87)A=&]R+B`@26YS=&5A9"P@=V4@=7-E('1H92!S>7-T96TG<R!N871I
M=F4@;&EN92!S97!A<F%T;W(N"B`@("`@("`@("HO"B`@("`@("`@:68@*&1E
M9FEN960H4$A07T5/3"DI('L*("`@("`@("`@("`@)'1H:7,M/G-E<"`](%!(
M4%]%3TP["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G-E
M<"`]("AS=')P;W,H4$A07T]3+"`G5TE.)RD@/3T](&9A;'-E*2`_(")<;B(@
M.B`B7')<;B(["B`@("`@("`@?0H@("`@?0H*"2\J*@H@("`@("H@26UP;&5M
M96YT<R!-86EL.CIS96YD*"D@9G5N8W1I;VX@=7-I;F<@=&AE('-E;F1M86EL
M"B`@("`@*B!C;VUM86YD+6QI;F4@8FEN87)Y+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D<F5C:7!I96YT<R!%:71H97(@82!C;VUM82US97!E<F%T
M960@;&ES="!O9B!R96-I<&EE;G1S"B`@("`@*B`@("`@("`@("`@("`@*%)&
M0S@R,B!C;VUP;&EA;G0I+"!O<B!A;B!A<G)A>2!O9B!R96-I<&EE;G1S+`H@
M("`@("H@("`@("`@("`@("`@(&5A8V@@4D9#.#(R('9A;&ED+B!4:&ES(&UA
M>2!C;VYT86EN(')E8VEP:65N=',@;F]T"B`@("`@*B`@("`@("`@("`@("`@
M<W!E8VEF:65D(&EN('1H92!H96%D97)S+"!F;W(@0F-C.BP@<F5S96YD:6YG
M"B`@("`@*B`@("`@("`@("`@("`@;65S<V%G97,L(&5T8RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&AE861E<G,@5&AE(&%R<F%Y(&]F(&AE861E
M<G,@=&\@<V5N9"!W:71H('1H92!M86EL+"!I;B!A;@H@("`@("H@("`@("`@
M("`@("`@(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T:&4@87)R87D@:V5Y
M(&ES('1H90H@("`@("H@("`@("`@("`@("`@(&AE861E<B!N86UE("AI92P@
M)U-U8FIE8W0G*2P@86YD('1H92!A<G)A>2!V86QU90H@("`@("H@("`@("`@
M("`@("`@(&ES('1H92!H96%D97(@=F%L=64@*&EE+"`G=&5S="<I+B!4:&4@
M:&5A9&5R"B`@("`@*B`@("`@("`@("`@("`@<')O9'5C960@9G)O;2!T:&]S
M92!V86QU97,@=V]U;&0@8F4@)U-U8FIE8W0Z"B`@("`@*B`@("`@("`@("`@
M("`@=&5S="<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]D>2!4
M:&4@9G5L;"!T97AT(&]F('1H92!M97-S86=E(&)O9'DL(&EN8VQU9&EN9R!A
M;GD*("`@("`J("`@("`@("`@("`@("`@36EM92!P87)T<RP@971C+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!T<G5E(&]N('-U8V-E
M<W,L(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("!C;VYT
M86EN:6YG(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S<V%G92!O;@H@("`@("H@
M("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5N9"@D<F5C:7!I96YT<RP@)&AE861E
M<G,L("1B;V1Y*0H@("`@>PH@("`@("`@("1R96-I<&EE;G1S(#T@)'1H:7,M
M/G!A<G-E4F5C:7!I96YT<R@D<F5C:7!I96YT<RD["B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)')E8VEP:65N=',I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5C:7!I96YT<SL*("`@("`@("!]"B`@("`@("`@)')E8VEP:65N=',@
M/2!E<V-A<&53:&5L;$-M9"AI;7!L;V1E*"<@)RP@)')E8VEP:65N=',I*3L*
M"B`@("`@("`@)&AE861E<D5L96UE;G1S(#T@)'1H:7,M/G!R97!A<F5(96%D
M97)S*"1H96%D97)S*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:&5A
M9&5R16QE;65N=',I*2!["B`@("`@("`@("`@(')E='5R;B`D:&5A9&5R16QE
M;65N=',["B`@("`@("`@?0H@("`@("`@(&QI<W0H)&9R;VTL("1T97AT7VAE
M861E<G,I(#T@)&AE861E<D5L96UE;G1S.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1F<F]M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G3F\@9G)O;2!A9&1R97-S(&=I=F5N+B<I.PH@("`@("`@('T@96QS96EF
M("AS=')P;W,H)&9R;VTL("<@)RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@
M("`@("`@('-T<G!O<R@D9G)O;2P@)SLG*2`A/3T@9F%L<V4@?'P*("`@("`@
M("`@("`@("`@("`@<W1R<&]S*"1F<F]M+"`G)B<I("$]/2!F86QS92!\?`H@
M("`@("`@("`@("`@("`@("!S=')P;W,H)&9R;VTL("=@)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&<F]M
M(&%D9')E<W,@<W!E8VEF:65D('=I=&@@9&%N9V5R;W5S(&-H87)A8W1E<G,N
M)RD["B`@("`@("`@?0H*("`@("`@("`D9G)O;2`](&5S8V%P95-H96QL0VUD
M*"1F<F]M*3L*("`@("`@("`D;6%I;"`]($!P;W!E;B@D=&AI<RT^<V5N9&UA
M:6Q?<&%T:"`N("@A96UP='DH)'1H:7,M/G-E;F1M86EL7V%R9W,I(#\@)R`G
M("X@)'1H:7,M/G-E;F1M86EL7V%R9W,@.B`G)RD@+B`B("UF)&9R;VT@+2T@
M)')E8VEP:65N=',B+"`G=R<I.PH@("`@("`@(&EF("@A)&UA:6PI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!O
M<&5N('-E;F1M86EL(%LG("X@)'1H:7,M/G-E;F1M86EL7W!A=&@@+B`G72!F
M;W(@97AE8W5T:6]N+B<I.PH@("`@("`@('T*"B`@("`@("`@9G!U=',H)&UA
M:6PL("1T97AT7VAE861E<G,I.PH@("`@("`@(&9P=71S*"1M86EL+"`D=&AI
M<RT^<V5P*3L@("\O(&YE=VQI;F4@=&\@96YD('1H92!H96%D97)S('-E8W1I
M;VX*("`@("`@("!F<'5T<R@D;6%I;"P@)&)O9'DI.PH@("`@("`@("1R97-U
M;'0@/2!P8VQO<V4H)&UA:6PI.PH@("`@("`@(&EF("AV97)S:6]N7V-O;7!A
M<F4H<&AP=F5R<VEO;B@I+"`G-"XR+C,G*2`]/2`M,2D@>PH@("`@("`@("`@
M("`O+R!7:71H(&]L9&5R('!H<"!V97)S:6]N<RP@=V4@;F5E9"!T;R!S:&EF
M="!T:&4@<&-L;W-E"B`@("`@("`@("`@("\O(')E<W5L="!T;R!G970@=&AE
M(&5X:70@8V]D92X*("`@("`@("`@("`@)')E<W5L="`]("1R97-U;'0@/CX@
M."`F(#!X1D8["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E<W5L="`A/2`P
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=S96YD
M;6%I;"!R971U<FYE9"!E<G)O<B!C;V1E("<@+B`D<F5S=6QT+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]-86EL+W-M='`N<&AP````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,#`T-@`Q,#4Q-30S,3`U-P`P
M,3<W,C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4
M:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(
M4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T
M:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@
M("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@075T:&]R<SH@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M("`@("`@("`@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"@HO*BH@17)R;W(Z($9A:6QE9"!T;R!C<F5A=&4@82!.
M971?4TU44"!O8FIE8W0@*B\*9&5F:6YE*"=014%27TU!24Q?4TU44%]%4E)/
M4E]#4D5!5$4G+"`Q,#`P,"D["@HO*BH@17)R;W(Z($9A:6QE9"!T;R!C;VYN
M96-T('1O(%--5%`@<V5R=F5R("HO"F1E9FEN92@G4$5!4E]-04E,7U--5%!?
M15)23U)?0T].3D5#5"<L(#$P,#`Q*3L*"B\J*B!%<G)O<CH@4TU44"!A=71H
M96YT:6-A=&EO;B!F86EL=7)E("HO"F1E9FEN92@G4$5!4E]-04E,7U--5%!?
M15)23U)?05542"<L(#$P,#`R*3L*"B\J*B!%<G)O<CH@3F\@1G)O;3H@861D
M<F5S<R!H87,@8F5E;B!P<F]V:61E9"`J+PID969I;F4H)U!%05)?34%)3%]3
M35107T524D]27T923TTG+"`Q,#`P,RD["@HO*BH@17)R;W(Z($9A:6QE9"!T
M;R!S970@<V5N9&5R("HO"F1E9FEN92@G4$5!4E]-04E,7U--5%!?15)23U)?
M4T5.1$52)RP@,3`P,#0I.PH*+RHJ($5R<F]R.B!&86EL960@=&\@861D(')E
M8VEP:65N="`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]27U)%0TE0
M245.5"<L(#$P,#`U*3L*"B\J*B!%<G)O<CH@1F%I;&5D('1O('-E;F0@9&%T
M82`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]27T1!5$$G+"`Q,#`P
M-BD["@HO*BH*("H@4TU44"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@4$5!4B!-
M86EL(&EN=&5R9F%C92X@4F5Q=6ER97,@=&AE($YE=%]33510(&-L87-S+@H@
M*B!`86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!-86EL"B`J($!V97)S:6]N
M("12979I<VEO;CH@,2XR-B`D"B`J+PIC;&%S<R!-86EL7W-M='`@97AT96YD
M<R!-86EL('L*"B`@("`O*BH*("`@("`J(%--5%`@8V]N;F5C=&EO;B!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]S;71P(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J(%1H92!33510(&AO<W0@=&\@8V]N;F5C="!T;RX*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:&]S="`]("=L;V-A;&AO
M<W0G.PH*("`@("\J*@H@("`@("H@5&AE('!O<G0@=&AE(%--5%`@<V5R=F5R
M(&ES(&]N+@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M<&]R="`](#(U.PH*("`@("\J*@H@("`@("H@4VAO=6QD(%--5%`@875T:&5N
M=&EC871I;VX@8F4@=7-E9#\*("`@("`J"B`@("`@*B!4:&ES('9A;'5E(&UA
M>2!B92!S970@=&\@=')U92P@9F%L<V4@;W(@=&AE(&YA;64@;V8@82!S<&5C
M:69I8PH@("`@("H@875T:&5N=&EC871I;VX@;65T:&]D+@H@("`@("H*("`@
M("`J($EF('1H92!V86QU92!I<R!S970@=&\@=')U92P@=&AE($YE=%]33510
M('!A8VMA9V4@=VEL;"!A='1E;7!T('1O('5S90H@("`@("H@=&AE(&)E<W0@
M875T:&5N=&EC871I;VX@;65T:&]D(&%D=F5R=&ES960@8GD@=&AE(')E;6]T
M92!33510('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&UI>&5D"B`@("`@
M*B\*("`@('9A<B`D875T:"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE
M('5S97)N86UE('1O('5S92!I9B!T:&4@4TU44"!S97)V97(@<F5Q=6ER97,@
M875T:&5N=&EC871I;VXN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)'5S97)N86UE(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@<&%S
M<W=O<F0@=&\@=7-E(&EF('1H92!33510('-E<G9E<B!R97%U:7)E<R!A=71H
M96YT:6-A=&EO;BX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D<&%S<W=O<F0@/2`G)SL*"B`@("`O*BH*("`@("`J($AO<W1N86UE(&]R
M(&1O;6%I;B!T:&%T('=I;&P@8F4@<V5N="!T;R!T:&4@<F5M;W1E(%--5%`@
M<V5R=F5R(&EN('1H90H@("`@("H@2$5,3R`O($5(3$\@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&QO8V%L
M:&]S="`]("=L;V-A;&AO<W0G.PH*("`@("\J*@H@("`@("H@4TU44"!C;VYN
M96-T:6]N('1I;65O=70@=F%L=64N("!.54Q,(&EN9&EC871E<R!N;R!T:6UE
M;W5T+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V
M87(@)'1I;65O=70@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!T
M;R!U<V4@5D524"!O<B!N;W0N($EF(&YO="!A(&)O;VQE86XL('1H92!S=')I
M;F<@=F%L=64*("`@("`J('=I;&P@8F4@=7-E9"!A<R!T:&4@5D524"!S97!A
M<F%T;W)S+@H@("`@("H*("`@("`J($!V87(@;6EX960@8F]O;&5A;B!O<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1V97)P(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!4=7)N(&]N($YE=%]33510(&1E8G5G9VEN9S\*("`@("`J"B`@
M("`@*B!`=F%R(&)O;VQE86X@)&1E8G5G"B`@("`@*B\*("`@('9A<B`D9&5B
M=6<@/2!F86QS93L*"B`@("`O*BH*("`@("`J($EN9&EC871E<R!W:&5T:&5R
M(&]R(&YO="!T:&4@4TU44"!C;VYN96-T:6]N('-H;W5L9"!P97)S:7-T(&]V
M97(*("`@("`J(&UU;'1I<&QE(&-A;&QS('1O('1H92!S96YD*"D@;65T:&]D
M+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)'!E<G-I<W0@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R
M+@H@("`@("H*("`@("`J($EN<W1A;G1I871E<R!A(&YE=R!-86EL7W-M='`Z
M.B!O8FIE8W0@8F%S960@;VX@=&AE('!A<F%M971E<G,*("`@("`J('!A<W-E
M9"!I;BX@270@;&]O:W,@9F]R('1H92!F;VQL;W=I;F<@<&%R86UE=&5R<SH*
M("`@("`J("`@("!H;W-T("`@("`@("!4:&4@<V5R=F5R('1O(&-O;FYE8W0@
M=&\N($1E9F%U;'1S('1O(&QO8V%L:&]S="X*("`@("`J("`@("!P;W)T("`@
M("`@("!4:&4@<&]R="!T;R!C;VYN96-T('1O+B!$969A=6QT<R!T;R`R-2X*
M("`@("`J("`@("!A=71H("`@("`@("!33510(&%U=&AE;G1I8V%T:6]N+B`@
M1&5F875L=',@=&\@;F]N92X*("`@("`J("`@("!U<V5R;F%M92`@("!4:&4@
M=7-E<FYA;64@=&\@=7-E(&9O<B!33510(&%U=&@N($YO(&1E9F%U;'0N"B`@
M("`@*B`@("`@<&%S<W=O<F0@("`@5&AE('!A<W-W;W)D('1O('5S92!F;W(@
M4TU44"!A=71H+B!.;R!D969A=6QT+@H@("`@("H@("`@(&QO8V%L:&]S="`@
M(%1H92!L;V-A;"!H;W-T;F%M92`O(&1O;6%I;BX@1&5F875L=',@=&\@;&]C
M86QH;W-T+@H@("`@("H@("`@('1I;65O=70@("`@(%1H92!33510(&-O;FYE
M8W1I;VX@=&EM96]U="X@1&5F875L=',@=&\@;F]N92X*("`@("`J("`@("!V
M97)P("`@("`@("!7:&5T:&5R('1O('5S92!615)0(&]R(&YO="X@1&5F875L
M=',@=&\@9F%L<V4N"B`@("`@*B`@("`@9&5B=6<@("`@("`@06-T:79A=&4@
M4TU44"!D96)U9R!M;V1E/R!$969A=6QT<R!T;R!F86QS92X*("`@("`J("`@
M("!P97)S:7-T("`@("!3:&]U;&0@=&AE(%--5%`@8V]N;F5C=&EO;B!P97)S
M:7-T/PH@("`@("H*("`@("`J($EF(&$@<&%R86UE=&5R(&ES('!R97-E;G0@
M:6X@=&AE("1P87)A;7,@87)R87DL(&ET(')E<&QA8V5S('1H90H@("`@("H@
M9&5F875L="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@2&%S:"!C;VYT
M86EN:6YG(&%N>2!P87)A;65T97)S(&1I9F9E<F5N="!F<F]M('1H90H@("`@
M("H@("`@("`@("`@("`@(&1E9F%U;'1S+@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@36%I;%]S;71P*"1P87)A;7,I"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)VAO<W0G72DI("1T:&ES
M+3YH;W-T(#T@)'!A<F%M<ULG:&]S="==.PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=P;W)T)UTI*2`D=&AI<RT^<&]R="`]("1P87)A;7-;)W!O<G0G
M73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG875T:"==*2D@)'1H:7,M
M/F%U=&@@/2`D<&%R86US6R=A=71H)UT["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)W5S97)N86UE)UTI*2`D=&AI<RT^=7-E<FYA;64@/2`D<&%R86US
M6R=U<V5R;F%M92==.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=P87-S
M=V]R9"==*2D@)'1H:7,M/G!A<W-W;W)D(#T@)'!A<F%M<ULG<&%S<W=O<F0G
M73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG;&]C86QH;W-T)UTI*2`D
M=&AI<RT^;&]C86QH;W-T(#T@)'!A<F%M<ULG;&]C86QH;W-T)UT["B`@("`@
M("`@:68@*&ES<V5T*"1P87)A;7-;)W1I;65O=70G72DI("1T:&ES+3YT:6UE
M;W5T(#T@)'!A<F%M<ULG=&EM96]U="==.PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=V97)P)UTI*2`D=&AI<RT^=F5R<"`]("1P87)A;7-;)W9E<G`G
M73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG9&5B=6<G72DI("1T:&ES
M+3YD96)U9R`]("AB;V]L96%N*21P87)A;7-;)V1E8G5G)UT["B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;7-;)W!E<G-I<W0G72DI("1T:&ES+3YP97)S:7-T
M(#T@*&)O;VQE86XI)'!A<F%M<ULG<&5R<VES="==.PH*("`@("`@("!R96=I
M<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?36%I;%]S
M;71P)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S=')U8W1O<B!I;7!L
M96UE;G1A=&EO;B!T;R!E;G-U<F4@=&AA="!W92!D:7-C;VYN96-T(&9R;VT@
M86YY"B`@("`@*B!P;W1E;G1I86QL>2UA;&EV92!P97)S:7-T96YT(%--5%`@
M8V]N;F5C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]-86EL7W-M='`H
M*0H@("`@>PH@("`@("`@("1T:&ES+3YD:7-C;VYN96-T*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!);7!L96UE;G1S($UA:6PZ.G-E;F0H*2!F=6YC=&EO
M;B!U<VEN9R!33510+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D<F5C
M:7!I96YT<R!%:71H97(@82!C;VUM82US97!E<F%T960@;&ES="!O9B!R96-I
M<&EE;G1S"B`@("`@*B`@("`@("`@("`@("`@*%)&0S@R,B!C;VUP;&EA;G0I
M+"!O<B!A;B!A<G)A>2!O9B!R96-I<&EE;G1S+`H@("`@("H@("`@("`@("`@
M("`@(&5A8V@@4D9#.#(R('9A;&ED+B!4:&ES(&UA>2!C;VYT86EN(')E8VEP
M:65N=',@;F]T"B`@("`@*B`@("`@("`@("`@("`@<W!E8VEF:65D(&EN('1H
M92!H96%D97)S+"!F;W(@0F-C.BP@<F5S96YD:6YG"B`@("`@*B`@("`@("`@
M("`@("`@;65S<V%G97,L(&5T8RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&AE861E<G,@5&AE(&%R<F%Y(&]F(&AE861E<G,@=&\@<V5N9"!W:71H
M('1H92!M86EL+"!I;B!A;@H@("`@("H@("`@("`@("`@("`@(&%S<V]C:6%T
M:79E(&%R<F%Y+"!W:&5R92!T:&4@87)R87D@:V5Y(&ES('1H90H@("`@("H@
M("`@("`@("`@("`@(&AE861E<B!N86UE("AE+F<N+"`G4W5B:F5C="<I+"!A
M;F0@=&AE(&%R<F%Y('9A;'5E"B`@("`@*B`@("`@("`@("`@("`@:7,@=&AE
M(&AE861E<B!V86QU92`H92YG+BP@)W1E<W0G*2X@5&AE(&AE861E<@H@("`@
M("H@("`@("`@("`@("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L=65S('=O
M=6QD(&)E("=3=6)J96-T.@H@("`@("H@("`@("`@("`@("`@('1E<W0G+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U;&P@=&5X
M="!O9B!T:&4@;65S<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@("`@*B`@
M("`@("`@("`@("`@($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O<B!A(%!%
M05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN9R!A(&1E
M<V-R:7!T:79E(&5R<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@("`@("`@
M("`@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H96%D97)S+"`D8F]D>2D*
M("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@)TYE="]33510+G!H<"<["@H@
M("`@("`@("\J($EF('=E(&1O;B=T(&%L<F5A9'D@:&%V92!A;B!33510(&]B
M:F5C="P@8W)E871E(&]N92X@*B\*("`@("`@("!I9B`H:7-?;V)J96-T*"1T
M:&ES+3Y?<VUT<"D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<VUT<"`])B!N97<@3F5T7U--5%`H)'1H:7,M/FAO<W0L("1T:&ES+3YP;W)T
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V-A;&AO<W0I.PH*("`@("`@("`@("`@+RH@268@=V4@<W1I;&P@
M9&]N)W0@:&%V92!A;B!33510(&]B:F5C="!A="!T:&ES('!O:6YT+"!F86EL
M+B`J+PH@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1T:&ES+3Y?<VUT<"D@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G1F%I;&5D('1O(&-R96%T92!A($YE=%]33510(&]B:F5C="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%2
M7TU!24Q?4TU44%]%4E)/4E]#4D5!5$4I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!#;VYF:6=U<F4@=&AE(%--5%`@8V]N;F5C=&EO;BX@*B\*
M("`@("`@("`@("`@:68@*"1T:&ES+3YD96)U9RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S;71P+3YS971$96)U9RAT<G5E*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@071T96UP="!T;R!C;VYN96-T('1O('1H92!C
M;VYF:6=U<F5D(%--5%`@<V5R=F5R+B`J+PH@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<F5S(#T@)'1H:7,M/E]S;71P+3YC;VYN96-T*"1T:&ES
M+3YT:6UE;W5T*2DI('L*("`@("`@("`@("`@("`@("1E<G)O<B`]("1T:&ES
M+3Y?97)R;W(H)T9A:6QE9"!T;R!C;VYN96-T('1O("<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]S="`N("<Z
M)R`N("1T:&ES+3YP;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5S*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"1E<G)O<BP@4$5!4E]-04E,7U--5%!?15)23U)?0T].
M3D5#5"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($%T=&5M<'0@
M=&\@875T:&5N=&EC871E(&EF(&%U=&AE;G1I8V%T:6]N(&AA<R!B965N(&5N
M86)L960N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^875T:"D@>PH@("`@
M("`@("`@("`@("`@)&UE=&AO9"`](&ES7W-T<FEN9R@D=&AI<RT^875T:"D@
M/R`D=&AI<RT^875T:"`Z("<G.PH*("`@("`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7W-M='`M/F%U=&@H)'1H:7,M/G5S
M97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%S<W=O<F0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1M971H;V0I*2D@>PH@("`@("`@("`@("`@("`@("`@("1E
M<G)O<B`]("1T:&ES+3Y?97)R;W(H(B1M971H;V0@875T:&5N=&EC871I;VX@
M9F%I;'5R92(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5S*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-M
M='`M/G)S970H*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@D97)R;W(L(%!%05)?34%)3%]335107T524D]27T%55$@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D:&5A9&5R16QE;65N=',@/2`D=&AI<RT^<')E<&%R94AE861E
M<G,H)&AE861E<G,I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1H96%D
M97)%;&5M96YT<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]S;71P+3YR<V5T
M*"D["B`@("`@("`@("`@(')E='5R;B`D:&5A9&5R16QE;65N=',["B`@("`@
M("`@?0H@("`@("`@(&QI<W0H)&9R;VTL("1T97AT2&5A9&5R<RD@/2`D:&5A
M9&5R16QE;65N=',["@H@("`@("`@("\J(%-I;F-E(&9E=R!-5$%S(&%R92!G
M;VEN9R!T;R!A;&QO=R!T:&ES(&AE861E<B!T;R!B92!F;W)G960*("`@("`@
M("`@*B!U;FQE<W,@:70G<R!I;B!T:&4@34%)3"!&4D]-.B!E>&-H86YG92P@
M=V4G;&P@=7-E"B`@("`@("`@("H@4F5T=7)N+5!A=&@@:6YS=&5A9"!O9B!&
M<F]M.B!I9B!I="=S('-E="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1H96%D
M97)S6R=2971U<FXM4&%T:"==*2D@>PH@("`@("`@("`@("`D9G)O;2`]("1H
M96%D97)S6R=2971U<FXM4&%T:"==.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D9G)O;2DI('L*("`@("`@("`@("`@)'1H:7,M/E]S;71P+3YR
M<V5T*"D["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.
M;R!&<F]M.B!A9&1R97-S(&AA<R!B965N('!R;W9I9&5D)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]-04E,7U--5%!?15)2
M3U)?1E)/32D["B`@("`@("`@?0H*("`@("`@("`D87)G<ULG=F5R<"==(#T@
M)'1H:7,M/G9E<G`["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]
M("1T:&ES+3Y?<VUT<"T^;6%I;$9R;VTH)&9R;VTL("1A<F=S*2DI('L*("`@
M("`@("`@("`@)&5R<F]R(#T@)'1H:7,M/E]E<G)O<B@B1F%I;&5D('1O('-E
M="!S96YD97(Z("1F<F]M(BP@)')E<RD["B`@("`@("`@("`@("1T:&ES+3Y?
M<VUT<"T^<G-E="@I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@D97)R;W(L(%!%05)?34%)3%]335107T524D]27U-%3D1%4BD["B`@
M("`@("`@?0H*("`@("`@("`D<F5C:7!I96YT<R`]("1T:&ES+3YP87)S95)E
M8VEP:65N=',H)')E8VEP:65N=',I.PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1R96-I<&EE;G1S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-M='`M
M/G)S970H*3L*("`@("`@("`@("`@<F5T=7)N("1R96-I<&EE;G1S.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)')E8VEP:65N=',@87,@)')E8VEP
M:65N="D@>PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S(#T@
M)'1H:7,M/E]S;71P+3YR8W!T5&\H)')E8VEP:65N="DI*2!["B`@("`@("`@
M("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V5R<F]R*")&86EL960@=&\@861D
M(')E8VEP:65N=#H@)')E8VEP:65N="(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R97,I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S;71P+3YR<V5T*"D["B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@D97)R;W(L(%!%05)?34%)3%]335107T524D]27U)%
M0TE0245.5"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M(%-E;F0@=&AE(&UE<W-A9V4G<R!H96%D97)S(&%N9"!T:&4@8F]D>2!A<R!3
M3510(&1A=&$N("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]
M("1T:&ES+3Y?<VUT<"T^9&%T82@B)'1E>'1(96%D97)S7')<;B1B;V1Y(BDI
M*2!["B`@("`@("`@("`@("1E<G)O<B`]("1T:&ES+3Y?97)R;W(H)T9A:6QE
M9"!T;R!S96YD(&1A=&$G+"`D<F5S*3L*("`@("`@("`@("`@)'1H:7,M/E]S
M;71P+3YR<V5T*"D["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"1E<G)O<BP@4$5!4E]-04E,7U--5%!?15)23U)?1$%402D["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!P97)S:7-T96YT(&-O;FYE8W1I;VYS(&%R
M92!D:7-A8FQE9"P@9&5S=')O>2!O=7(@4TU44"!O8FIE8W0N("HO"B`@("`@
M("`@:68@*"1T:&ES+3YP97)S:7-T(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`D=&AI<RT^9&ES8V]N;F5C="@I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T(&%N
M9"!D97-T<F]Y('1H92!C=7)R96YT(%--5%`@8V]N;F5C=&EO;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5')U92!I9B!T:&4@4TU44"!C;VYN
M96-T:6]N(&YO(&QO;F=E<B!E>&ES=',N"B`@("`@*@H@("`@("H@0'-I;F-E
M("`Q+C$N.0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@+RH@268@=V4@:&%V
M92!A;B!33510(&]B:F5C="P@9&ES8V]N;F5C="!A;F0@9&5S=')O>2!I="X@
M*B\*("`@("`@("!I9B`H:7-?;V)J96-T*"1T:&ES+3Y?<VUT<"D@)B8@)'1H
M:7,M/E]S;71P+3YD:7-C;VYN96-T*"DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]S;71P(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("\J(%=E(&%R92!D
M:7-C;VYN96-T960@:68@=V4@;F\@;&]N9V5R(&AA=F4@86X@4TU44"!O8FIE
M8W0N("HO"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7W-M='`@/3T](&YU;&PI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@82!S=&%N9&%R9&EZ960@
M<W1R:6YG(&1E<V-R:6)I;F<@=&AE(&-U<G)E;G0@4TU44"!E<G)O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!#=7-T;VT@<W1R:6YG
M(&1E<V-R:6)I;F<@=&AE(&5R<F]R(&-O;G1E>'0N"B`@("`@*B!`<&%R86T@
M;V)J96-T("1E<G)O<B!2969E<F5N8V4@=&\@=&AE(&-U<G)E;G0@4$5!4E]%
M<G)O<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("`@
M("`@02!S=')I;F<@9&5S8W)I8FEN9R!T:&4@8W5R<F5N="!33510(&5R<F]R
M+@H@("`@("H*("`@("`J($!S:6YC92`@,2XQ+C<*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?97)R;W(H)'1E>'0L("8D
M97)R;W(I"B`@("!["B`@("`@("`@+RH@4W!L:70@=&AE(%--5%`@<F5S<&]N
M<V4@:6YT;R!A(&-O9&4@86YD(&$@<F5S<&]N<V4@<W1R:6YG+B`J+PH@("`@
M("`@(&QI<W0H)&-O9&4L("1R97-P;VYS92D@/2`D=&AI<RT^7W-M='`M/F=E
M=%)E<W!O;G-E*"D["@H@("`@("`@("\J($)U:6QD(&]U<B!S=&%N9&%R9&EZ
M960@97)R;W(@<W1R:6YG+B`J+PH@("`@("`@("1M<V<@/2`D=&5X=#L*("`@
M("`@("`D;7-G("X]("<@6U--5%`Z("<@+B`D97)R;W(M/F=E=$UE<W-A9V4H
M*3L*("`@("`@("`D;7-G("X]("(@*&-O9&4Z("1C;V1E+"!R97-P;VYS93H@
M)')E<W!O;G-E*5TB.PH*("`@("`@("!R971U<FX@)&US9SL*("`@('T*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O36%I;"]21D,X,C(N<&AP````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-S8V,C,`,3`U,34T,S$P-3<`,#$W-C(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#(P,#$M,C`P,BP@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!2
M961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O
M<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@
M87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N
M9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T
M<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V
M92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@
M("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M
M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@
M;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N
M(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES
M=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M
M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`HO
M+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET
M:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P97)M:7-S
M:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/
M4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O('P@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/+"!42$4@
M24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#
M3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\"B\O
M('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4
M($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%
M+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)2
M55!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@?"!42$5/
M4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@
M3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@
M5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)
M4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4FEC:&%R9"!(97EE<R`\
M<FEC:&%R9$!P:'!G=7)U+F]R9SX@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"`@("`@("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HO*BH*("H@4D9#(#@R,B!%;6%I;"!A
M9&1R97-S(&QI<W0@=F%L:61A=&EO;B!5=&EL:71Y"B`J"B`J(%=H870@:7,@
M:70_"B`J"B`J(%1H:7,@8VQA<W,@=VEL;"!T86ME(&%N(&%D9')E<W,@<W1R
M:6YG+"!A;F0@<&%R<V4@:70@:6YT;R!I="=S(&-O;G-I='5E;G0*("H@<&%R
M=',L(&)E('1H870@96ET:&5R(&%D9')E<W-E<RP@9W)O=7!S+"!O<B!C;VUB
M:6YA=&EO;G,N($YE<W1E9"!G<F]U<',*("H@87)E(&YO="!S=7!P;W)T960N
M(%1H92!S=')U8W1U<F4@:70@<F5T=7)N<R!I<R!P<F5T='D@<W1R86EG:'0@
M9F]R=V%R9"P*("H@86YD(&ES('-I;6EL87(@=&\@=&AA="!P<F]V:61E9"!B
M>2!T:&4@:6UA<%]R9F,X,C)?<&%R<V5?861R;&ES="@I+B!5<V4*("H@<')I
M;G1?<B@I('1O('9I97<@=&AE('-T<G5C='5R92X*("H*("H@2&]W(&1O($D@
M=7-E(&ET/PH@*@H@*B`D861D<F5S<U]S=')I;F<@/2`G37D@1W)O=7`Z(")2
M:6-H87)D(B`\<FEC:&%R9$!L;V-A;&AO<W0^("A!(&-O;6UE;G0I+"!T961`
M97AA;7!L92YC;VT@*%1E9"!";&]G9W,I+"!"87)N97D[)SL*("H@)'-T<G5C
M='5R92`]($UA:6Q?4D9#.#(R.CIP87)S94%D9')E<W-,:7-T*"1A9&1R97-S
M7W-T<FEN9RP@)V5X86UP;&4N8V]M)RP@=')U92D*("H@<')I;G1?<B@D<W1R
M=6-T=7)E*3L*("H*("H@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R
M9$!P:'!G=7)U+F]R9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!V97)S:6]N("12979I<VEO;CH@,2XR,B`D
M"B`J($!L:6-E;G-E($)31`H@*B!`<&%C:V%G92!-86EL"B`J+PIC;&%S<R!-
M86EL7U)&0S@R,B!["@H@("`@+RHJ"B`@("`@*B!4:&4@861D<F5S<R!B96EN
M9R!P87)S960@8GD@=&AE(%)&0S@R,B!O8FIE8W0N"B`@("`@*B!`=F%R('-T
M<FEN9R`D861D<F5S<PH@("`@("HO"B`@("!V87(@)&%D9')E<W,@/2`G)SL*
M"B`@("`O*BH*("`@("`J(%1H92!D969A=6QT(&1O;6%I;B!T;R!U<V4@9F]R
M('5N<75A;&EF:65D(&%D9')E<W-E<RX*("`@("`J($!V87(@<W1R:6YG("1D
M969A=6QT7V1O;6%I;@H@("`@("HO"B`@("!V87(@)&1E9F%U;'1?9&]M86EN
M(#T@)VQO8V%L:&]S="<["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@=V4@<F5T
M=7)N(&$@;F5S=&5D(&%R<F%Y('-H;W=I;F<@9W)O=7!S+"!O<B!F;&%T=&5N
M(&5V97)Y=&AI;F<_"B`@("`@*B!`=F%R(&)O;VQE86X@)&YE<W1'<F]U<',*
M("`@("`J+PH@("`@=F%R("1N97-T1W)O=7!S(#T@=')U93L*"B`@("`O*BH*
M("`@("`J(%=H971H97(@;W(@;F]T('1O('9A;&ED871E(&%T;VUS(&9O<B!N
M;VXM87-C:6D@8VAA<F%C=&5R<RX*("`@("`J($!V87(@8F]O;&5A;B`D=F%L
M:61A=&4*("`@("`J+PH@("`@=F%R("1V86QI9&%T92`]('1R=64["@H@("`@
M+RHJ"B`@("`@*B!4:&4@87)R87D@;V8@<F%W(&%D9')E<W-E<R!B=6EL="!U
M<"!A<R!W92!P87)S92X*("`@("`J($!V87(@87)R87D@)&%D9')E<W-E<PH@
M("`@("HO"B`@("!V87(@)&%D9')E<W-E<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!4:&4@9FEN86P@87)R87D@;V8@<&%R<V5D(&%D9')E<W,@:6YF
M;W)M871I;VX@=&AA="!W92!B=6EL9"!U<"X*("`@("`J($!V87(@87)R87D@
M)'-T<G5C='5R90H@("`@("HO"B`@("!V87(@)'-T<G5C='5R92`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!E<G)O<B!M97-S86=E
M+"!I9B!A;GDN"B`@("`@*B!`=F%R('-T<FEN9R`D97)R;W(*("`@("`J+PH@
M("`@=F%R("1E<G)O<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!!;B!I;G1E
M<FYA;"!C;W5N=&5R+W!O:6YT97(N"B`@("`@*B!`=F%R(&EN=&5G97(@)&EN
M9&5X"B`@("`@*B\*("`@('9A<B`D:6YD97@@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE(&YU;6)E<B!O9B!G<F]U<',@=&AA="!H879E(&)E96X@9F]U
M;F0@:6X@=&AE(&%D9')E<W,@;&ES="X*("`@("`J($!V87(@:6YT96=E<B`D
M;G5M7V=R;W5P<PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M=F%R("1N=6U?9W)O=7!S(#T@,#L*"B`@("`O*BH*("`@("`J($$@=F%R:6%B
M;&4@<V\@=&AA="!W92!C86X@=&5L;"!W:&5T:&5R(&]R(&YO="!W92=R92!I
M;G-I9&4@80H@("`@("H@36%I;%]21D,X,C(@;V)J96-T+@H@("`@("H@0'9A
M<B!B;V]L96%N("1M86EL4D9#.#(R"B`@("`@*B\*("`@('9A<B`D;6%I;%)&
M0S@R,B`]('1R=64["@H@("`@+RHJ"B`@("`J($$@;&EM:70@869T97(@=VAI
M8V@@<')O8V5S<VEN9R!S=&]P<PH@("`@*B!`=F%R(&EN="`D;&EM:70*("`@
M("HO"B`@("!V87(@)&QI;6ET(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%-E
M=',@=7`@=&AE(&]B:F5C="X@5&AE(&%D9')E<W,@;75S="!E:71H97(@8F4@
M<V5T(&AE<F4@;W(@=VAE;@H@("`@("H@8V%L;&EN9R!P87)S94%D9')E<W-,
M:7-T*"DN($]N92!O<B!T:&4@;W1H97(N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!P87)A;2!S=')I;F<@("1A9&1R97-S("`@("`@
M("`@5&AE(&%D9')E<W,H97,I('1O('9A;&ED871E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&1E9F%U;'1?9&]M86EN("!$969A=6QT(&1O;6%I;B]H;W-T
M(&5T8RX@268@;F]T('-U<'!L:65D+"!W:6QL(&)E('-E="!T;R!L;V-A;&AO
M<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;F5S=%]G<F]U<',@("`@(%=H
M971H97(@=&\@<F5T=7)N('1H92!S=')U8W1U<F4@=VET:"!G<F]U<',@;F5S
M=&5D(&9O<B!E87-I97(@=FEE=VEN9RX*("`@("`J($!P87)A;2!B;V]L96%N
M("1V86QI9&%T92`@("`@("`@5VAE=&AE<B!T;R!V86QI9&%T92!A=&]M<RX@
M5'5R;B!T:&ES(&]F9B!I9B!Y;W4@;F5E9"!T;R!R=6X@861D<F5S<V5S('1H
M<F]U9V@@8F5F;W)E(&5N8V]D:6YG('1H92!P97)S;VYA;"!N86UE<RP@9F]R
M(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T($UA:6Q?
M4D9#.#(R($$@;F5W($UA:6Q?4D9#.#(R(&]B:F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@36%I;%]21D,X,C(H)&%D9')E<W,@/2!N=6QL+"`D9&5F875L
M=%]D;VUA:6X@/2!N=6QL+"`D;F5S=%]G<F]U<',@/2!N=6QL+"`D=F%L:61A
M=&4@/2!N=6QL+"`D;&EM:70@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI
M<W-E="@D861D<F5S<RDI("`@("`@("`D=&AI<RT^861D<F5S<R`@("`@("`@
M/2`D861D<F5S<SL*("`@("`@("!I9B`H:7-S970H)&1E9F%U;'1?9&]M86EN
M*2D@)'1H:7,M/F1E9F%U;'1?9&]M86EN(#T@)&1E9F%U;'1?9&]M86EN.PH@
M("`@("`@(&EF("AI<W-E="@D;F5S=%]G<F]U<',I*2`@("`D=&AI<RT^;F5S
M=$=R;W5P<R`@("`@/2`D;F5S=%]G<F]U<',["B`@("`@("`@:68@*&ES<V5T
M*"1V86QI9&%T92DI("`@("`@("1T:&ES+3YV86QI9&%T92`@("`@("`]("1V
M86QI9&%T93L*("`@("`@("!I9B`H:7-S970H)&QI;6ET*2D@("`@("`@("`@
M)'1H:7,M/FQI;6ET("`@("`@("`@(#T@)&QI;6ET.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W1A<G1S('1H92!W:&]L92!P<F]C97-S+B!4:&4@861D<F5S
M<R!M=7-T(&5I=&AE<B!B92!S970@:&5R90H@("`@("H@;W(@=VAE;B!C<F5A
M=&EN9R!T:&4@;V)J96-T+B!/;F4@;W(@=&AE(&]T:&5R+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("`D861D
M<F5S<R`@("`@("`@(%1H92!A9&1R97-S*&5S*2!T;R!V86QI9&%T92X*("`@
M("`J($!P87)A;2!S=')I;F<@("1D969A=6QT7V1O;6%I;B`@1&5F875L="!D
M;VUA:6XO:&]S="!E=&,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;F5S=%]G
M<F]U<',@("`@(%=H971H97(@=&\@<F5T=7)N('1H92!S=')U8W1U<F4@=VET
M:"!G<F]U<',@;F5S=&5D(&9O<B!E87-I97(@=FEE=VEN9RX*("`@("`J($!P
M87)A;2!B;V]L96%N("1V86QI9&%T92`@("`@("`@5VAE=&AE<B!T;R!V86QI
M9&%T92!A=&]M<RX@5'5R;B!T:&ES(&]F9B!I9B!Y;W4@;F5E9"!T;R!R=6X@
M861D<F5S<V5S('1H<F]U9V@@8F5F;W)E(&5N8V]D:6YG('1H92!P97)S;VYA
M;"!N86UE<RP@9F]R(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@02!S=')U8W1U<F5D(&%R<F%Y(&]F(&%D9')E<W-E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<&%R<V5!9&1R97-S3&ES="@D861D<F5S<R`](&YU
M;&PL("1D969A=6QT7V1O;6%I;B`](&YU;&PL("1N97-T7V=R;W5P<R`](&YU
M;&PL("1V86QI9&%T92`](&YU;&PL("1L:6UI="`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RD@?'P@(6ES<V5T*"1T:&ES+3YM86EL
M4D9#.#(R*2D@>PH@("`@("`@("`@("`D;V)J(#T@;F5W($UA:6Q?4D9#.#(R
M*"1A9&1R97-S+"`D9&5F875L=%]D;VUA:6XL("1N97-T7V=R;W5P<RP@)'9A
M;&ED871E+"`D;&EM:70I.PH@("`@("`@("`@("!R971U<FX@)&]B:BT^<&%R
M<V5!9&1R97-S3&ES="@I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1A9&1R97-S*2D@("`@("`@("1T:&ES+3YA9&1R97-S("`@("`@("`]("1A
M9&1R97-S.PH@("`@("`@(&EF("AI<W-E="@D9&5F875L=%]D;VUA:6XI*2`D
M=&AI<RT^9&5F875L=%]D;VUA:6X@/2`D9&5F875L=%]D;VUA:6X["B`@("`@
M("`@:68@*&ES<V5T*"1N97-T7V=R;W5P<RDI("`@("1T:&ES+3YN97-T1W)O
M=7!S("`@("`]("1N97-T7V=R;W5P<SL*("`@("`@("!I9B`H:7-S970H)'9A
M;&ED871E*2D@("`@("`@)'1H:7,M/G9A;&ED871E("`@("`@(#T@)'9A;&ED
M871E.PH@("`@("`@(&EF("AI<W-E="@D;&EM:70I*2`@("`@("`@("`D=&AI
M<RT^;&EM:70@("`@("`@("`@/2`D;&EM:70["@H@("`@("`@("1T:&ES+3YS
M=')U8W1U<F4@(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^861D<F5S<V5S
M("`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/F5R<F]R("`@("`@/2!N=6QL
M.PH@("`@("`@("1T:&ES+3YI;F1E>"`@("`@(#T@;G5L;#L*"B`@("`@("`@
M+R\@56YF;VQD(&%N>2!L;VYG(&QI;F5S(&EN("1T:&ES+3YA9&1R97-S+@H@
M("`@("`@("1T:&ES+3YA9&1R97-S(#T@<')E9U]R97!L86-E*"<O7'(_7&XO
M)RP@(EQR7&XB+"`D=&AI<RT^861D<F5S<RD["B`@("`@("`@)'1H:7,M/F%D
M9')E<W,@/2!P<F5G7W)E<&QA8V4H)R]<<EQN*%QT?"`I*R\G+"`G("<L("1T
M:&ES+3YA9&1R97-S*3L*"B`@("`@("`@=VAI;&4@*"1T:&ES+3YA9&1R97-S
M(#T@)'1H:7,M/E]S<&QI=$%D9')E<W-E<R@D=&AI<RT^861D<F5S<RDI.PH*
M("`@("`@("!I9B`H)'1H:7,M/F%D9')E<W,@/3T](&9A;'-E('Q\(&ES<V5T
M*"1T:&ES+3YE<G)O<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1T:&ES+3YE<G)O<BD["B`@("`@("`@?0H*("`@("`@("`O+R!686QI9&%T
M92!E86-H(&%D9')E<W,@:6YD:79I9'5A;&QY+B`@268@=V4@96YC;W5N=&5R
M(&%N(&EN=F%L:60*("`@("`@("`O+R!A9&1R97-S+"!S=&]P(&ET97)A=&EN
M9R!A;F0@<F5T=7)N(&%N(&5R<F]R(&EM;65D:6%T96QY+@H@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YA9&1R97-S97,@87,@)&%D9')E<W,I('L*("`@("`@
M("`@("`@)'9A;&ED(#T@)'1H:7,M/E]V86QI9&%T94%D9')E<W,H)&%D9')E
M<W,I.PH*("`@("`@("`@("`@:68@*"1V86QI9"`]/3T@9F%L<V4@?'P@:7-S
M970H)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@D=&AI<RT^97)R;W(I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(21T:&ES+3YN97-T1W)O=7!S*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<W1R=6-T=7)E(#T@87)R87E?;65R9V4H)'1H:7,M/G-T
M<G5C='5R92P@)'9A;&ED*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS=')U8W1U<F5;72`]("1V86QI9#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YS=')U
M8W1U<F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3<&QI=',@86X@861D<F5S
M<R!I;G1O('-E<&%R871E(&%D9')E<W-E<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@5&AE
M(&%D9')E<W-E<R!T;R!S<&QI="X*("`@("`J($!R971U<FX@8F]O;&5A;B!3
M=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S<&QI
M=$%D9')E<W-E<R@D861D<F5S<RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3YL:6UI="D@)B8@8V]U;G0H)'1H:7,M/F%D9')E<W-E<RD@/3T@
M)'1H:7,M/FQI;6ET*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"@H@("`@("`@(&EF("@D=&AI<RT^7VES1W)O=7`H)&%D9')E<W,I("8F
M("%I<W-E="@D=&AI<RT^97)R;W(I*2!["B`@("`@("`@("`@("1S<&QI=%]C
M:&%R(#T@)SLG.PH@("`@("`@("`@("`D:7-?9W)O=7`@("`]('1R=64["B`@
M("`@("`@?2!E;'-E:68@*"%I<W-E="@D=&AI<RT^97)R;W(I*2!["B`@("`@
M("`@("`@("1S<&QI=%]C:&%R(#T@)RPG.PH@("`@("`@("`@("`D:7-?9W)O
M=7`@("`](&9A;'-E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^
M97)R;W(I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\O(%-P;&ET('1H92!S=')I;F<@8F%S960@;VX@=&AE(&%B
M;W9E('1E;B!O<B!S;R!L:6YE<RX*("`@("`@("`D<&%R=',@(#T@97AP;&]D
M92@D<W!L:71?8VAA<BP@)&%D9')E<W,I.PH@("`@("`@("1S=')I;F<@/2`D
M=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`D<W!L:71?8VAA<BD["@H@("`@
M("`@("\O($EF(&$@9W)O=7`N+BX*("`@("`@("!I9B`H)&ES7V=R;W5P*2![
M"B`@("`@("`@("`@("\O($EF("1S=')I;F<@9&]E<R!N;W0@8V]N=&%I;B!A
M(&-O;&]N(&]U='-I9&4@;V8*("`@("`@("`@("`@+R\@8G)A8VME=',O<75O
M=&5S(&5T8R!T:&5N('-O;65T:&EN9R=S(&9U8F%R+@H*("`@("`@("`@("`@
M+R\@1FER<W0@8VAE8VL@=&AE<F4G<R!A(&-O;&]N(&%T(&%L;#H*("`@("`@
M("`@("`@:68@*'-T<G!O<R@D<W1R:6YG+"`G.B<I(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R(#T@)TEN=F%L:60@861D<F5S
M<SH@)R`N("1S=')I;F<["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($YO=R!C:&5C:R!I="=S
M(&]U='-I9&4@;V8@8G)A8VME=',O<75O=&5S.@H@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?<W!L:71#:&5C:RAE>'!L;V1E*"<Z)RP@)'-T<FEN9RDL("<Z
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@5V4@;75S="!H879E(&$@9W)O=7`@870@
M=&AI<R!P;VEN="P@<V\@:6YC<F5A<V4@=&AE(&-O=6YT97(Z"B`@("`@("`@
M("`@("1T:&ES+3YN=6U?9W)O=7!S*RL["B`@("`@("`@?0H*("`@("`@("`O
M+R`D<W1R:6YG(&YO=R!C;VYT86EN<R!T:&4@9FER<W0@9G5L;"!A9&1R97-S
M+V=R;W5P+@H@("`@("`@("\O($%D9"!T;R!T:&4@861D<F5S<V5S(&%R<F%Y
M+@H@("`@("`@("1T:&ES+3YA9&1R97-S97-;72`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9&1R97-S)R`]/B!T<FEM
M*"1S=')I;F<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=G<F]U<"<@("`]/B`D:7-?9W)O=7`*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("`@("`O+R!296UO=F4@=&AE(&YO=R!S
M=&]R960@861D<F5S<R!F<F]M('1H92!I;FET:6%L(&QI;F4L('1H92`K,0H@
M("`@("`@("\O(&ES('1O(&%C8V]U;G0@9F]R('1H92!E>'!L;V1E(&-H87)A
M8W1E<BX*("`@("`@("`D861D<F5S<R`]('1R:6TH<W5B<W1R*"1A9&1R97-S
M+"!S=')L96XH)'-T<FEN9RD@*R`Q*2D["@H@("`@("`@("\O($EF('1H92!N
M97AT(&-H87(@:7,@82!C;VUM82!A;F0@=&AI<R!W87,@82!G<F]U<"P@=&AE
M;@H@("`@("`@("\O('1H97)E(&%R92!M;W)E(&%D9')E<W-E<RP@;W1H97)W
M:7-E+"!I9B!T:&5R92!A<F4@86YY(&UO<F4*("`@("`@("`O+R!C:&%R<RP@
M=&AE;B!T:&5R92!I<R!A;F]T:&5R(&%D9')E<W,N"B`@("`@("`@:68@*"1I
M<U]G<F]U<"`F)B!S=6)S='(H)&%D9')E<W,L(#`L(#$I(#T]("<L)RE["B`@
M("`@("`@("`@("1A9&1R97-S(#T@=')I;2AS=6)S='(H)&%D9')E<W,L(#$I
M*3L*("`@("`@("`@("`@<F5T=7)N("1A9&1R97-S.PH*("`@("`@("!](&5L
M<V5I9B`H<W1R;&5N*"1A9&1R97-S*2`^(#`I('L*("`@("`@("`@("`@<F5T
M=7)N("1A9&1R97-S.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!Y;W4@9V]T(&AE
M<F4@=&AE;B!S;VUE=&AI;F<G<R!O9F8*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@9F]R(&$@9W)O=7`@870@
M=&AE('-T87)T(&]F('1H92!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R97-S(%1H92!A
M9&1R97-S('1O(&-H96-K+@H@("`@("H@0')E='5R;B!B;V]L96%N(%=H971H
M97(@;W(@;F]T('1H97)E(&ES(&$@9W)O=7`@870@=&AE('-T87)T(&]F('1H
M92!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I<T=R;W5P*"1A9&1R
M97-S*0H@("`@>PH@("`@("`@("\O($9I<G-T(&-O;6UA(&YO="!I;B!Q=6]T
M97,L(&%N9VQE<R!O<B!E<V-A<&5D.@H@("`@("`@("1P87)T<R`@/2!E>'!L
M;V1E*"<L)RP@)&%D9')E<W,I.PH@("`@("`@("1S=')I;F<@/2`D=&AI<RT^
M7W-P;&ET0VAE8VLH)'!A<G1S+"`G+"<I.PH*("`@("`@("`O+R!.;W<@=V4@
M:&%V92!T:&4@9FER<W0@861D<F5S<RP@=V4@8V%N(')E;&EA8FQY(&-H96-K
M(&9O<B!A"B`@("`@("`@+R\@9W)O=7`@8GD@<V5A<F-H:6YG(&9O<B!A(&-O
M;&]N('1H870G<R!N;W0@97-C87!E9"!O<B!I;@H@("`@("`@("\O('%U;W1E
M<R!O<B!A;F=L92!B<F%C:V5T<RX*("`@("`@("!I9B`H8V]U;G0H)'!A<G1S
M(#T@97AP;&]D92@G.B<L("1S=')I;F<I*2`^(#$I('L*("`@("`@("`@("`@
M)'-T<FEN9S(@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G.B<I.PH@
M("`@("`@("`@("!R971U<FX@*"1S=')I;F<R("$]/2`D<W1R:6YG*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@02!C;VUM;VX@9G5N8W1I;VX@
M=&AA="!W:6QL(&-H96-K(&%N(&5X<&QO9&5D('-T<FEN9RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M=',@5&AE(&5X;&]D960@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VAA<B`@5&AE(&-H87(@=&AA="!W87,@97AP;&]D960@;VXN"B`@("`@*B!`
M<F5T=7)N(&UI>&5D($9A;'-E(&EF('1H92!S=')I;F<@8V]N=&%I;G,@=6YC
M;&]S960@<75O=&5S+V)R86-K971S+"!O<B!T:&4@<W1R:6YG(&]N('-U8V-E
M<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S<&QI=$-H96-K*"1P87)T<RP@
M)&-H87(I"B`@("!["B`@("`@("`@)'-T<FEN9R`]("1P87)T<ULP73L*"B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'!A<G1S*3L@)&DK*RD@
M>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]H87-5;F-L;W-E9%%U;W1E<R@D
M<W1R:6YG*0H@("`@("`@("`@("`@("`@?'P@)'1H:7,M/E]H87-5;F-L;W-E
M9$)R86-K971S*"1S=')I;F<L("<\/B<I"B`@("`@("`@("`@("`@("!\?"`D
M=&AI<RT^7VAA<U5N8VQO<V5D0G)A8VME=',H)'-T<FEN9RP@)UM=)RD*("`@
M("`@("`@("`@("`@('Q\("1T:&ES+3Y?:&%S56YC;&]S961"<F%C:V5T<R@D
M<W1R:6YG+"`G*"DG*0H@("`@("`@("`@("`@("`@?'P@<W5B<W1R*"1S=')I
M;F<L("TQ*2`]/2`G7%PG*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'!A<G1S6R1I("L@,5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'-T<FEN
M9R`]("1S=')I;F<@+B`D8VAA<B`N("1P87)T<ULD:2`K(#%=.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M97)R;W(@/2`G26YV86QI9"!A9&1R97-S('-P96,N(%5N8VQO<V5D(&)R86-K
M970@;W(@<75O=&5S)SL*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^:6YD97@@/2`D:3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'-T<FEN9SL*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I
M9B!A('-T<FEN9R!H87,@86X@=6YC;&]S960@<75O=&5S(&]R(&YO="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I
M;F<@)'-T<FEN9R!4:&4@<W1R:6YG('1O(&-H96-K+@H@("`@("H@0')E='5R
M;B!B;V]L96%N(%1R=64@:68@=&AE<F4@87)E('5N8VQO<V5D('%U;W1E<R!I
M;G-I9&4@=&AE('-T<FEN9RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?:&%S56YC;&]S9611=6]T97,H)'-T<FEN9RD*("`@('L*
M("`@("`@("`D<W1R:6YG("`@("`](&5X<&QO9&4H)R(G+"`D<W1R:6YG*3L*
M("`@("`@("`D<W1R:6YG7V-N="`](&-O=6YT*"1S=')I;F<I.PH*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`H8V]U;G0H)'-T<FEN9RD@+2`Q*3L@)&DK
M*RD*("`@("`@("`@("`@:68@*'-U8G-T<B@D<W1R:6YG6R1I72P@+3$I(#T]
M("=<7"<I"B`@("`@("`@("`@("`@("`D<W1R:6YG7V-N="TM.PH*("`@("`@
M("!R971U<FX@*"1S=')I;F=?8VYT("4@,B`]/3T@,"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@:68@82!S=')I;F<@:&%S(&%N('5N8VQO<V5D
M(&)R86-K971S(&]R(&YO="X@24U03U)404Y4.@H@("`@("H@5&AI<R!F=6YC
M=&EO;B!H86YD;&5S(&)O=&@@86YG;&4@8G)A8VME=',@86YD('-Q=6%R92!B
M<F%C:V5T<SL*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M($!P87)A;2!S=')I;F<@)'-T<FEN9R!4:&4@<W1R:6YG('1O(&-H96-K+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G,@(%1H92!C:&%R86-T97)S('1O
M(&-H96-K(&9O<BX*("`@("`J($!R971U<FX@8F]O;&5A;B!4<G5E(&EF('1H
M97)E(&%R92!U;F-L;W-E9"!B<F%C:V5T<R!I;G-I9&4@=&AE('-T<FEN9RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&%S56YC
M;&]S961"<F%C:V5T<R@D<W1R:6YG+"`D8VAA<G,I"B`@("!["B`@("`@("`@
M)&YU;5]A;F=L95]S=&%R="`]('-U8G-T<E]C;W5N="@D<W1R:6YG+"`D8VAA
M<G-;,%TI.PH@("`@("`@("1N=6U?86YG;&5?96YD("`@/2!S=6)S=')?8V]U
M;G0H)'-T<FEN9RP@)&-H87)S6S%=*3L*"B`@("`@("`@)'1H:7,M/E]H87-5
M;F-L;W-E9$)R86-K971S4W5B*"1S=')I;F<L("1N=6U?86YG;&5?<W1A<G0L
M("1C:&%R<ULP72D["B`@("`@("`@)'1H:7,M/E]H87-5;F-L;W-E9$)R86-K
M971S4W5B*"1S=')I;F<L("1N=6U?86YG;&5?96YD+"`D8VAA<G-;,5TI.PH*
M("`@("`@("!I9B`H)&YU;5]A;F=L95]S=&%R="`\("1N=6U?86YG;&5?96YD
M*2!["B`@("`@("`@("`@("1T:&ES+3YE<G)O<B`]("=);G9A;&ED(&%D9')E
M<W,@<W!E8RX@56YM871C:&5D('%U;W1E(&]R(&)R86-K970@*"<@+B`D8VAA
M<G,@+B`G*2<["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@*"1N=6U?86YG;&5?<W1A<G0@
M/B`D;G5M7V%N9VQE7V5N9"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4W5B(&9U;F-T:6]N('1H870@:7,@=7-E9"!O;FQY(&)Y(&AA<U5N
M8VQO<V5D0G)A8VME=',H*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R!4:&4@<W1R:6YG('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)B1N=6T@("`@5&AE(&YU
M;6)E<B!O9B!O8V-U<F5N8V5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA
M<B`@(%1H92!C:&%R86-T97(@=&\@8V]U;G0N"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@5&AE(&YU;6)E<B!O9B!O8V-U<F5N8V5S(&]F("1C:&%R(&EN("1S
M=')I;F<L(&%D:G5S=&5D(&9O<B!B86-K<VQA<VAE<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7VAA<U5N8VQO<V5D0G)A8VME='-3=6(H)'-T<FEN9RP@)B1N
M=6TL("1C:&%R*0H@("`@>PH@("`@("`@("1P87)T<R`](&5X<&QO9&4H)&-H
M87(L("1S=')I;F<I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1P87)T<RD[("1I*RLI>PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1P87)T
M<ULD:5TL("TQ*2`]/2`G7%PG('Q\("1T:&ES+3Y?:&%S56YC;&]S9611=6]T
M97,H)'!A<G1S6R1I72DI"B`@("`@("`@("`@("`@("`D;G5M+2T["B`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%R='-;)&D@*R`Q72DI"B`@("`@("`@("`@
M("`@("`D<&%R='-;)&D@*R`Q72`]("1P87)T<ULD:5T@+B`D8VAA<B`N("1P
M87)T<ULD:2`K(#%=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1N=6T[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!B96=I;B!C:&5C
M:VEN9R!T:&4@861D<F5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@5&AE(&%D9')E<W,@
M=&\@=F%L:61A=&4N"B`@("`@*B!`<F5T=7)N(&UI>&5D($9A;'-E(&]N(&9A
M:6QU<F4L(&]R(&$@<W1R=6-T=7)E9"!A<G)A>2!O9B!A9&1R97-S(&EN9F]R
M;6%T:6]N(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI
M9&%T94%D9')E<W,H)&%D9')E<W,I"B`@("!["B`@("`@("`@)&ES7V=R;W5P
M(#T@9F%L<V4["B`@("`@("`@)&%D9')E<W-E<R`](&%R<F%Y*"D["@H@("`@
M("`@(&EF("@D861D<F5S<ULG9W)O=7`G72D@>PH@("`@("`@("`@("`D:7-?
M9W)O=7`@/2!T<G5E.PH*("`@("`@("`@("`@+R\@1V5T('1H92!G<F]U<"!P
M87)T(&]F('1H92!N86UE"B`@("`@("`@("`@("1P87)T<R`@("`@/2!E>'!L
M;V1E*"<Z)RP@)&%D9')E<W-;)V%D9')E<W,G72D["B`@("`@("`@("`@("1G
M<F]U<&YA;64@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G.B<I.PH@
M("`@("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH*3L*"B`@("`@("`@("`@
M("\O($%N9"!V86QI9&%T92!T:&4@9W)O=7`@<&%R="!O9B!T:&4@;F%M92X*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E4&AR87-E*"1G<F]U
M<&YA;64I*7L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<B`]("='<F]U
M<"!N86UE(&1I9"!N;W0@=F%L:61A=&4N)SL*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\O($1O;B=T(&EN8VQU9&4@9W)O=7!S(&EF('=E(&%R92!N;W0@;F5S
M=&EN9PH@("`@("`@("`@("`@("`@+R\@=&AE;2X@5&AI<R!A=F]I9',@<F5T
M=7)N:6YG(&EN=F%L:60@861D<F5S<V5S+@H@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YN97-T1W)O=7!S*2!["B`@("`@("`@("`@("`@("`@("`@)'-T
M<G5C='5R92`](&YE=R!S=&1#;&%S<SL*("`@("`@("`@("`@("`@("`@("`D
M<W1R=6-T=7)E+3YG<F]U<&YA;64@/2`D9W)O=7!N86UE.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D861D<F5S<ULG
M861D<F5S<R==(#T@;'1R:6TH<W5B<W1R*"1A9&1R97-S6R=A9&1R97-S)UTL
M('-T<FQE;B@D9W)O=7!N86UE("X@)SHG*2DI.PH@("`@("`@('T*"B`@("`@
M("`@+R\@268@82!G<F]U<"!T:&5N('-P;&ET(&]N(&-O;6UA(&%N9"!P=70@
M:6YT;R!A;B!A<G)A>2X*("`@("`@("`O+R!/=&AE<G=I<V4L($IU<W0@<'5T
M('1H92!W:&]L92!A9&1R97-S(&EN(&%N(&%R<F%Y+@H@("`@("`@(&EF("@D
M:7-?9W)O=7`I('L*("`@("`@("`@("`@=VAI;&4@*'-T<FQE;B@D861D<F5S
M<ULG861D<F5S<R==*2`^(#`I('L*("`@("`@("`@("`@("`@("1P87)T<R`@
M("`@("`](&5X<&QO9&4H)RPG+"`D861D<F5S<ULG861D<F5S<R==*3L*("`@
M("`@("`@("`@("`@("1A9&1R97-S97-;72`]("1T:&ES+3Y?<W!L:71#:&5C
M:R@D<&%R=',L("<L)RD["B`@("`@("`@("`@("`@("`D861D<F5S<ULG861D
M<F5S<R==(#T@=')I;2AS=6)S='(H)&%D9')E<W-;)V%D9')E<W,G72P@<W1R
M;&5N*&5N9"@D861D<F5S<V5S*2`N("<L)RDI*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A9&1R97-S97-;72`]("1A
M9&1R97-S6R=A9&1R97-S)UT["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C
M:R!T:&%T("1A9&1R97-S97,@:7,@<V5T+"!I9B!A9&1R97-S(&QI:V4@=&AI
M<SH*("`@("`@("`O+R!'<F]U<&YA;64Z.PH@("`@("`@("\O(%1H96X@97)R
M;W)S('=E<F4@87!P96%R:6YG+@H@("`@("`@(&EF("@A8V]U;G0H)&%D9')E
M<W-E<RDI>PH@("`@("`@("`@("`D=&AI<RT^97)R;W(@/2`G16UP='D@9W)O
M=7`N)SL*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+R\@5')I;2!T:&4@=VAI=&5S<&%C92!F<F]M(&%L;"!O9B!T:&4@
M861D<F5S<R!S=')I;F=S+@H@("`@("`@(&%R<F%Y7VUA<"@G=')I;2<L("1A
M9&1R97-S97,I.PH*("`@("`@("`O+R!686QI9&%T92!E86-H(&UA:6QB;W@N
M"B`@("`@("`@+R\@1F]R;6%T(&-O=6QD(&)E(&]N92!O9CH@;F%M92`\9V5E
M>F5R0&1O;6%I;BYC;VT^"B`@("`@("`@+R\@("`@("`@("`@("`@("`@("`@
M("`@("`@9V5E>F5R0&1O;6%I;BYC;VT*("`@("`@("`O+R`@("`@("`@("`@
M("`@("`@("`@("`@("!G965Z97(*("`@("`@("`O+R`N+BX@;W(@86YY(&]T
M:&5R(&9O<FUA="!V86QI9"!B>2!21D,@.#(R+@H@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1A9&1R97-S97,I.R`D:2LK*2!["B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/G9A;&ED871E36%I;&)O>"@D861D<F5S<V5S6R1I
M72DI('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^97)R;W(I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R(#T@)U9A;&ED
M871I;VX@9F%I;&5D(&9O<CH@)R`N("1A9&1R97-S97-;)&E=.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!.97-T960@9F]R;6%T
M"B`@("`@("`@:68@*"1T:&ES+3YN97-T1W)O=7!S*2!["B`@("`@("`@("`@
M(&EF("@D:7-?9W)O=7`I('L*("`@("`@("`@("`@("`@("1S=')U8W1U<F4M
M/F%D9')E<W-E<R`]("1A9&1R97-S97,["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E(#T@)&%D9')E<W-E<ULP73L*
M("`@("`@("`@("`@?0H*("`@("`@("`O+R!&;&%T(&9O<FUA=`H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@D:7-?9W)O=7`I('L*("`@("`@
M("`@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>5]M97)G92@D<W1R=6-T=7)E
M+"`D861D<F5S<V5S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1S=')U8W1U<F4@/2`D861D<F5S<V5S.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-T<G5C='5R93L*("`@('T*
M"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('9A;&ED871E(&$@<&AR87-E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&AR87-E(%1H92!P:')A<V4@=&\@8VAE8VLN"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?=F%L:61A=&50:')A<V4H)'!H<F%S92D*("`@('L*("`@
M("`@("`O+R!3<&QI=',@;VX@;VYE(&]R(&UO<F4@5&%B(&]R('-P86-E+@H@
M("`@("`@("1P87)T<R`]('!R96=?<W!L:70H)R];(%Q<>#`Y72LO)RP@)'!H
M<F%S92P@+3$L(%!214=?4U!,251?3D]?14U05%DI.PH*("`@("`@("`D<&AR
M87-E7W!A<G1S(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H8V]U;G0H)'!A
M<G1S*2`^(#`I>PH@("`@("`@("`@("`D<&AR87-E7W!A<G1S6UT@/2`D=&AI
M<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G("<I.PH@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D=&AI<RT^:6YD97@@*R`Q.R`D:2LK*0H@("`@("`@
M("`@("`@("`@87)R87E?<VAI9G0H)'!A<G1S*3L*("`@("`@("!]"@H@("`@
M("`@(&9O<F5A8V@@*"1P:')A<V5?<&%R=',@87,@)'!A<G0I('L*("`@("`@
M("`@("`@+R\@268@<75O=&5D('-T<FEN9SH*("`@("`@("`@("`@:68@*'-U
M8G-T<B@D<&%R="P@,"P@,2D@/3T@)R(G*2!["B`@("`@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?=F%L:61A=&51=6]T9613=')I;F<H)'!A<G0I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O($]T:&5R=VES92!I="=S(&%N(&%T;VTZ"B`@("`@
M("`@("`@(&EF("@A)'1H:7,M/E]V86QI9&%T94%T;VTH)'!A<G0I*2!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('9A;&ED871E(&%N(&%T
M;VT@=VAI8V@@9G)O;2!R9F,X,C(@:7,Z"B`@("`@*B!A=&]M(#T@,2H\86YY
M($-(05(@97AC97!T('-P96-I86QS+"!34$%#12!A;F0@0U1,<SX*("`@("`J
M"B`@("`@*B!)9B!V86QI9&%T:6]N("@D=&AI<RT^=F%L:61A=&4I(&AA<R!B
M965N('1U<FYE9"!O9F8L('1H96X*("`@("`J('9A;&ED871E071O;2@I(&1O
M97-N)W0@86-T=6%L;'D@8VAE8VL@86YY=&AI;F<N(%1H:7,@:7,@<V\@=&AA
M="!Y;W4*("`@("`J(&-A;B!S<&QI="!A(&QI<W0@;V8@861D<F5S<V5S('5P
M(&)E9F]R92!E;F-O9&EN9R!P97)S;VYA;"!N86UE<PH@("`@("H@*'5M;&%U
M=',L(&5T8RXI+"!F;W(@97AA;7!L92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)&%T;VT@5&AE('-T<FEN
M9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O;&5A;B!3=6-C97-S(&]R
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T94%T;VTH
M)&%T;VTI"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^=F%L:61A=&4I('L*
M("`@("`@("`@("`@+R\@5F%L:61A=&EO;B!H87,@8F5E;B!T=7)N960@;V9F
M.R!A<W-U;64@=&AE(&%T;VT@:7,@;VMA>2X*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@86YY(&-H
M87(@9G)O;2!!4T-)22`P("T@05-#24D@,3(W"B`@("`@("`@:68@*"%P<F5G
M7VUA=&-H*"<O7EM<7'@P,"U<7'@W15TK)"]I)RP@)&%T;VTL("1M871C:&5S
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O+R!#:&5C:R!F;W(@<W!E8VEA;',Z"B`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R];75LH*3P^0"P[7%PZ(BX@72\G+"`D871O;2DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE
M8VL@9F]R(&-O;G1R;VP@8VAA<F%C=&5R<R`H05-#24D@,"TS,2DZ"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R];7%QX,#`M7%QX,49=*R\G+"`D871O;2DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO
M;B!T;R!V86QI9&%T92!Q=6]T960@<W1R:6YG+"!W:&EC:"!I<SH*("`@("`J
M('%U;W1E9"US=')I;F<@/2`\(CX@*BAQ=&5X="]Q=6]T960M<&%I<BD@/"(^
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1Q<W1R:6YG(%1H92!S=')I;F<@=&\@8VAE8VL*("`@("`J($!R
M971U<FX@8F]O;&5A;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]V86QI9&%T95%U;W1E9%-T<FEN9R@D<7-T<FEN9RD*("`@
M('L*("`@("`@("`O+R!,96%D:6YG(&%N9"!T<F%I;&EN9R`B"B`@("`@("`@
M)'%S=')I;F<@/2!S=6)S='(H)'%S=')I;F<L(#$L("TQ*3L*"B`@("`@("`@
M+R\@4&5R9F]R;2!C:&5C:RP@<F5M;W9I;F<@<75O=&5D(&-H87)A8W1E<G,@
M9FER<W0N"B`@("`@("`@<F5T=7)N("%P<F5G7VUA=&-H*"<O6UQX,$1<7%Q<
M(ETO)RP@<')E9U]R97!L86-E*"<O7%Q<7"XO)RP@)R<L("1Q<W1R:6YG*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A
M(&UA:6QB;W@L('=H:6-H(&ES.@H@("`@("H@;6%I;&)O>"`]("`@861D<BUS
M<&5C("`@("`@("`@.R!S:6UP;&4@861D<F5S<PH@("`@("H@("`@("`@("`@
M("\@<&AR87-E(')O=71E+6%D9'(@.R!N86UE(&%N9"!R;W5T92UA9&1R"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!S=')I
M;F<@)B1M86EL8F]X(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!V86QI9&%T94UA:6QB;W@H)B1M86EL8F]X*0H@("`@>PH@("`@
M("`@("\O($$@8V]U<&QE(&]F(&1E9F%U;'1S+@H@("`@("`@("1P:')A<V4@
M(#T@)R<["B`@("`@("`@)&-O;6UE;G0@/2`G)SL*("`@("`@("`D8V]M;65N
M=',@/2!A<G)A>2@I.PH*("`@("`@("`O+R!#871C:"!A;GD@4D9#.#(R(&-O
M;6UE;G1S(&%N9"!S=&]R92!T:&5M('-E<&%R871E;'DN"B`@("`@("`@)%]M
M86EL8F]X(#T@)&UA:6QB;W@["B`@("`@("`@=VAI;&4@*'-T<FQE;BAT<FEM
M*"1?;6%I;&)O>"DI(#X@,"D@>PH@("`@("`@("`@("`D<&%R=',@/2!E>'!L
M;V1E*"<H)RP@)%]M86EL8F]X*3L*("`@("`@("`@("`@)&)E9F]R95]C;VUM
M96YT(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)R@G*3L*("`@("`@
M("`@("`@:68@*"1B969O<F5?8V]M;65N="`A/2`D7VUA:6QB;W@I('L*("`@
M("`@("`@("`@("`@("\O($9I<G-T(&-H87(@<VAO=6QD(&)E(&$@*"X*("`@
M("`@("`@("`@("`@("1C;VUM96YT("`@(#T@<W5B<W1R*'-T<E]R97!L86-E
M*"1B969O<F5?8V]M;65N="P@)R<L("1?;6%I;&)O>"DL(#$I.PH@("`@("`@
M("`@("`@("`@)'!A<G1S("`@("`@/2!E>'!L;V1E*"<I)RP@)&-O;6UE;G0I
M.PH@("`@("`@("`@("`@("`@)&-O;6UE;G0@("`@/2`D=&AI<RT^7W-P;&ET
M0VAE8VLH)'!A<G1S+"`G*2<I.PH@("`@("`@("`@("`@("`@)&-O;6UE;G1S
M6UT@/2`D8V]M;65N=#L*"B`@("`@("`@("`@("`@("`O+R`K,2!I<R!F;W(@
M=&AE('1R86EL:6YG("D*("`@("`@("`@("`@("`@("1?;6%I;&)O>"`@(#T@
M<W5B<W1R*"1?;6%I;&)O>"P@<W1R<&]S*"1?;6%I;&)O>"P@)&-O;6UE;G0I
M*W-T<FQE;B@D8V]M;65N="DK,2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@9F]R96%C:"`H)&-O;6UE;G1S(&%S("1C;VUM96YT*2!["B`@
M("`@("`@("`@("1M86EL8F]X(#T@<W1R7W)E<&QA8V4H(B@D8V]M;65N="DB
M+"`G)RP@)&UA:6QB;W@I.PH@("`@("`@('T*"B`@("`@("`@)&UA:6QB;W@@
M/2!T<FEM*"1M86EL8F]X*3L*"B`@("`@("`@+R\@0VAE8VL@9F]R(&YA;64@
M*R!R;W5T92UA9&1R"B`@("`@("`@:68@*'-U8G-T<B@D;6%I;&)O>"P@+3$I
M(#T]("<^)R`F)B!S=6)S='(H)&UA:6QB;W@L(#`L(#$I("$]("<\)RD@>PH@
M("`@("`@("`@("`D<&%R=',@(#T@97AP;&]D92@G/"<L("1M86EL8F]X*3L*
M("`@("`@("`@("`@)&YA;64@("`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R
M=',L("<\)RD["@H@("`@("`@("`@("`D<&AR87-E("`@("`]('1R:6TH)&YA
M;64I.PH@("`@("`@("`@("`D<F]U=&5?861D<B`]('1R:6TH<W5B<W1R*"1M
M86EL8F]X+"!S=')L96XH)&YA;64N)SPG*2P@+3$I*3L*"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W9A;&ED871E4&AR87-E*"1P:')A<V4I(#T]/2!F86QS
M92!\?"`H)')O=71E7V%D9'(@/2`D=&AI<RT^7W9A;&ED871E4F]U=&5!9&1R
M*"1R;W5T95]A9&1R*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@+R\@3VYL>2!G
M;W0@861D<BUS<&5C"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M1FER<W0@<VYI<"!A;F=L92!B<F%C:V5T<R!I9B!P<F5S96YT+@H@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1M86EL8F]X+"`P+"`Q*2`]/2`G/"<@)B8@<W5B
M<W1R*"1M86EL8F]X+"`M,2D@/3T@)SXG*2!["B`@("`@("`@("`@("`@("`D
M861D<E]S<&5C(#T@<W5B<W1R*"1M86EL8F]X+"`Q+"`M,2D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D861D<E]S<&5C(#T@)&UA
M:6QB;W@["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@H)&%D9')?
M<W!E8R`]("1T:&ES+3Y?=F%L:61A=&5!9&1R4W!E8R@D861D<E]S<&5C*2D@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-O;G-T<G5C="!T
M:&4@;V)J96-T('1H870@=VEL;"!B92!R971U<FYE9"X*("`@("`@("`D;6)O
M>"`](&YE=R!S=&1#;&%S<R@I.PH*("`@("`@("`O+R!!9&0@=&AE('!H<F%S
M92`H979E;B!I9B!E;7!T>2D@86YD(&-O;6UE;G1S"B`@("`@("`@)&UB;W@M
M/G!E<G-O;F%L(#T@)'!H<F%S93L*("`@("`@("`D;6)O>"T^8V]M;65N="`@
M/2!I<W-E="@D8V]M;65N=',I(#\@)&-O;6UE;G1S(#H@87)R87DH*3L*"B`@
M("`@("`@:68@*&ES<V5T*"1R;W5T95]A9&1R*2D@>PH@("`@("`@("`@("`D
M;6)O>"T^;6%I;&)O>"`]("1R;W5T95]A9&1R6R=L;V-A;%]P87)T)UT["B`@
M("`@("`@("`@("1M8F]X+3YH;W-T("`@(#T@)')O=71E7V%D9');)V1O;6%I
M;B==.PH@("`@("`@("`@("`D<F]U=&5?861D<ELG861L)UT@(3T]("<G(#\@
M)&UB;W@M/F%D;"`]("1R;W5T95]A9&1R6R=A9&PG72`Z("<G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1M8F]X+3YM86EL8F]X(#T@)&%D9')?
M<W!E8ULG;&]C86Q?<&%R="==.PH@("`@("`@("`@("`D;6)O>"T^:&]S="`@
M("`]("1A9&1R7W-P96-;)V1O;6%I;B==.PH@("`@("`@('T*"B`@("`@("`@
M)&UA:6QB;W@@/2`D;6)O>#L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@=F%L:61A=&5S(&$@<F]U
M=&4M861D<B!W:&EC:"!I<SH*("`@("`J(')O=71E+6%D9'(@/2`B/"(@6W)O
M=71E72!A9&1R+7-P96,@(CXB"B`@("`@*@H@("`@("H@06YG;&4@8G)A8VME
M=',@:&%V92!A;')E861Y(&)E96X@<F5M;W9E9"!A="!T:&4@<&]I;G0@;V8*
M("`@("`J(&=E='1I;F<@=&\@=&AI<R!F=6YC=&EO;BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)')O=71E
M7V%D9'(@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@;6EX
M960@1F%L<V4@;VX@9F%I;'5R92P@;W(@86X@87)R87D@8V]N=&%I;FEN9R!V
M86QI9&%T960@861D<F5S<R]R;W5T92!I;F9O<FUA=&EO;B!O;B!S=6-C97-S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&52;W5T94%D9'(H)')O
M=71E7V%D9'(I"B`@("!["B`@("`@("`@+R\@0VAE8VL@9F]R(&-O;&]N+@H@
M("`@("`@(&EF("AS=')P;W,H)')O=71E7V%D9'(L("<Z)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)SHG+"`D<F]U=&5?
M861D<BD["B`@("`@("`@("`@("1R;W5T92`]("1T:&ES+3Y?<W!L:71#:&5C
M:R@D<&%R=',L("<Z)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)')O=71E(#T@)')O=71E7V%D9'(["B`@("`@("`@?0H*("`@("`@("`O+R!)
M9B`D<F]U=&4@:7,@<V%M92!A<R`D<F]U=&5?861D<B!T:&5N('1H92!C;VQO
M;B!W87,@:6X*("`@("`@("`O+R!Q=6]T97,@;W(@8G)A8VME=',@;W(L(&]F
M(&-O=7)S92P@;F]N(&5X:7-T96YT+@H@("`@("`@(&EF("@D<F]U=&4@/3T]
M("1R;W5T95]A9&1R*7L*("`@("`@("`@("`@=6YS970H)')O=71E*3L*("`@
M("`@("`@("`@)&%D9')?<W!E8R`]("1R;W5T95]A9&1R.PH@("`@("`@("`@
M("!I9B`H*"1A9&1R7W-P96,@/2`D=&AI<RT^7W9A;&ED871E061D<E-P96,H
M)&%D9')?<W!E8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@5F%L:61A=&4@<F]U=&4@<&%R="X*("`@("`@("`@("`@
M:68@*"@D<F]U=&4@/2`D=&AI<RT^7W9A;&ED871E4F]U=&4H)')O=71E*2D@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1A9&1R7W-P96,@/2!S=6)S='(H
M)')O=71E7V%D9'(L('-T<FQE;B@D<F]U=&4@+B`G.B<I*3L*"B`@("`@("`@
M("`@("\O(%9A;&ED871E(&%D9'(M<W!E8R!P87)T+@H@("`@("`@("`@("!I
M9B`H*"1A9&1R7W-P96,@/2`D=&AI<RT^7W9A;&ED871E061D<E-P96,H)&%D
M9')?<W!E8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)')O=71E*2D@>PH@("`@("`@("`@("`D<F5T=7)N6R=A9&PG72`]
M("1R;W5T93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5T=7)N
M6R=A9&PG72`]("<G.PH@("`@("`@('T*"B`@("`@("`@)')E='5R;B`](&%R
M<F%Y7VUE<F=E*"1R971U<FXL("1A9&1R7W-P96,I.PH@("`@("`@(')E='5R
M;B`D<F5T=7)N.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@
M=F%L:61A=&4@82!R;W5T92P@=VAI8V@@:7,Z"B`@("`@*B!R;W5T92`](#$C
M*")`(B!D;VUA:6XI("(Z(@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'!A<F%M('-T<FEN9R`D<F]U=&4@5&AE('-T<FEN9R!T;R!C
M:&5C:RX*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@9F%I;'5R92P@
M;W(@=&AE('9A;&ED871E9"`D<F]U=&4@;VX@<W5C8V5S<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W9A;&ED871E4F]U=&4H)')O=71E*0H@("`@>PH@("`@
M("`@("\O(%-P;&ET(&]N(&-O;6UA+@H@("`@("`@("1D;VUA:6YS(#T@97AP
M;&]D92@G+"<L('1R:6TH)')O=71E*2D["@H@("`@("`@(&9O<F5A8V@@*"1D
M;VUA:6YS(&%S("1D;VUA:6XI('L*("`@("`@("`@("`@)&1O;6%I;B`]('-T
M<E]R97!L86-E*"=`)RP@)R<L('1R:6TH)&1O;6%I;BDI.PH@("`@("`@("`@
M("!I9B`H(21T:&ES+3Y?=F%L:61A=&5$;VUA:6XH)&1O;6%I;BDI(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F]U=&4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A(&1O
M;6%I;BP@=&AO=6=H('1H:7,@:7,@;F]T('%U:71E('=H870*("`@("`J('EO
M=2!E>'!E8W0@;V8@82!S=')I8W0@:6YT97)N970@9&]M86EN+@H@("`@("H*
M("`@("`J(&1O;6%I;B`]('-U8BUD;VUA:6X@*B@B+B(@<W5B+61O;6%I;BD*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S
M=')I;F<@)&1O;6%I;B!4:&4@<W1R:6YG('1O(&-H96-K+@H@("`@("H@0')E
M='5R;B!M:7AE9"!&86QS92!O;B!F86EL=7)E+"!O<B!T:&4@=F%L:61A=&5D
M(&1O;6%I;B!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L
M:61A=&5$;VUA:6XH)&1O;6%I;BD*("`@('L*("`@("`@("`O+R!.;W1E('1H
M92!D:69F97)E;G0@=7-E(&]F("1S=6)D;VUA:6YS(&%N9"`D<W5B7V1O;6%I
M;G,*("`@("`@("`D<W5B9&]M86EN<R`](&5X<&QO9&4H)RXG+"`D9&]M86EN
M*3L*"B`@("`@("`@=VAI;&4@*&-O=6YT*"1S=6)D;VUA:6YS*2`^(#`I('L*
M("`@("`@("`@("`@)'-U8E]D;VUA:6YS6UT@/2`D=&AI<RT^7W-P;&ET0VAE
M8VLH)'-U8F1O;6%I;G,L("<N)RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1T:&ES+3YI;F1E>"`K(#$[("1I*RLI"B`@("`@("`@("`@("`@
M("!A<G)A>5]S:&EF="@D<W5B9&]M86EN<RD["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D<W5B7V1O;6%I;G,@87,@)'-U8E]D;VUA:6XI('L*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E4W5B9&]M86EN*'1R:6TH
M)'-U8E]D;VUA:6XI*2D*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("\O($UA;F%G960@=&\@9V5T(&AE<F4L('-O
M(')E='5R;B!I;G!U="X*("`@("`@("!R971U<FX@)&1O;6%I;CL*("`@('T*
M"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('9A;&ED871E(&$@<W5B9&]M
M86EN.@H@("`@("H@("!S=6)D;VUA:6X@/2!D;VUA:6XM<F5F("\@9&]M86EN
M+6QI=&5R86P*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M($!P87)A;2!S=')I;F<@)'-U8F1O;6%I;B!4:&4@<W1R:6YG('1O(&-H96-K
M+@H@("`@("H@0')E='5R;B!B;V]L96%N(%-U8V-E<W,@;W(@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E4W5B9&]M86EN*"1S=6)D
M;VUA:6XI"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>7%LH+BHI
M721\)RP@)'-U8F1O;6%I;BP@)&%R<BDI>PH@("`@("`@("`@("!I9B`H(21T
M:&ES+3Y?=F%L:61A=&5$;&ET97)A;"@D87)R6S%=*2D@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]V
M86QI9&%T94%T;VTH)'-U8F1O;6%I;BDI(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\O($=O="!H97)E+"!S;R!R971U<FX@<W5C8V5S<V9U
M;"X*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($9U;F-T:6]N('1O('9A;&ED871E(&$@9&]M86EN(&QI=&5R86PZ"B`@("`@
M*B`@(&1O;6%I;BUL:71E<F%L(#T@(");(B`J*&1T97AT("\@<75O=&5D+7!A
M:7(I(")=(@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&QI=&5R86P@5&AE('-T<FEN9R!T;R!C:&5C:RX*
M("`@("`J($!R971U<FX@8F]O;&5A;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T941L:71E<F%L*"1D;&ET97)A
M;"D*("`@('L*("`@("`@("!R971U<FX@(7!R96=?;6%T8V@H)R\H+BE;75M<
M>#!$7%Q<7%TO)RP@)&1L:71E<F%L+"`D;6%T8VAE<RD@)B8@)&UA=&-H97-;
M,5T@(3T@)UQ<)SL*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O
M('9A;&ED871E(&%N(&%D9'(M<W!E8RX*("`@("`J"B`@("`@*B!A9&1R+7-P
M96,@/2!L;V-A;"UP87)T(")`(B!D;VUA:6X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')?<W!E8R!4
M:&4@<W1R:6YG('1O(&-H96-K+@H@("`@("H@0')E='5R;B!M:7AE9"!&86QS
M92!O;B!F86EL=7)E+"!O<B!T:&4@=F%L:61A=&5D(&%D9'(M<W!E8R!O;B!S
M=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&5!9&1R4W!E
M8R@D861D<E]S<&5C*0H@("`@>PH@("`@("`@("1A9&1R7W-P96,@/2!T<FEM
M*"1A9&1R7W-P96,I.PH*("`@("`@("`O+R!3<&QI="!O;B!`('-I9VX@:68@
M=&AE<F4@:7,@;VYE+@H@("`@("`@(&EF("AS=')P;W,H)&%D9')?<W!E8RP@
M)T`G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'!A<G1S("`@("`@/2!E
M>'!L;V1E*"=`)RP@)&%D9')?<W!E8RD["B`@("`@("`@("`@("1L;V-A;%]P
M87)T(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)T`G*3L*("`@("`@
M("`@("`@)&1O;6%I;B`@("`@/2!S=6)S='(H)&%D9')?<W!E8RP@<W1R;&5N
M*"1L;V-A;%]P87)T("X@)T`G*2D["@H@("`@("`@("\O($YO($`@<VEG;B!S
M;R!A<W-U;64@=&AE(&1E9F%U;'0@9&]M86EN+@H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1L;V-A;%]P87)T(#T@)&%D9')?<W!E8SL*("`@("`@
M("`@("`@)&1O;6%I;B`@("`@/2`D=&AI<RT^9&5F875L=%]D;VUA:6X["B`@
M("`@("`@?0H*("`@("`@("!I9B`H*"1L;V-A;%]P87)T(#T@)'1H:7,M/E]V
M86QI9&%T94QO8V%L4&%R="@D;&]C86Q?<&%R="DI(#T]/2!F86QS92D@<F5T
M=7)N(&9A;'-E.PH@("`@("`@(&EF("@H)&1O;6%I;B`@("`@/2`D=&AI<RT^
M7W9A;&ED871E1&]M86EN*"1D;VUA:6XI*2`]/3T@9F%L<V4I(')E='5R;B!F
M86QS93L*"B`@("`@("`@+R\@1V]T(&AE<F4@<V\@<F5T=7)N('-U8V-E<W-F
M=6PN"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=L;V-A;%]P87)T)R`]/B`D;&]C
M86Q?<&%R="P@)V1O;6%I;B<@/3X@)&1O;6%I;BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!T:&4@;&]C86P@<&%R="!O
M9B!A;B!A9&1R97-S.@H@("`@("H@("!L;V-A;"UP87)T(#T@=V]R9"`J*"(N
M(B!W;W)D*0H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;&]C86Q?<&%R=`H@("`@("H@0')E='5R;B!M:7AE
M9"!&86QS92!O;B!F86EL=7)E+"!O<B!T:&4@=F%L:61A=&5D(&QO8V%L('!A
M<G0@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E
M3&]C86Q087)T*"1L;V-A;%]P87)T*0H@("`@>PH@("`@("`@("1P87)T<R`]
M(&5X<&QO9&4H)RXG+"`D;&]C86Q?<&%R="D["B`@("`@("`@)'=O<F1S(#T@
M87)R87DH*3L*"B`@("`@("`@+R\@4W!L:70@=&AE(&QO8V%L7W!A<G0@:6YT
M;R!W;W)D<RX*("`@("`@("!W:&EL92`H8V]U;G0H)'!A<G1S*2`^(#`I>PH@
M("`@("`@("`@("`D=V]R9'-;72`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R
M=',L("<N)RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1T:&ES
M+3YI;F1E>"`K(#$[("1I*RLI('L*("`@("`@("`@("`@("`@(&%R<F%Y7W-H
M:69T*"1P87)T<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\O(%9A;&ED871E(&5A8V@@=V]R9"X*("`@("`@("!F;W)E86-H("@D=V]R
M9',@87,@)'=O<F0I('L*("`@("`@("`@("`@+R\@268@=&AI<R!W;W)D(&-O
M;G1A:6YS(&%N('5N<75O=&5D('-P86-E+"!I="!I<R!I;G9A;&ED+B`H-BXR
M+C0I"B`@("`@("`@("`@(&EF("AS=')P;W,H)'=O<F0L("<@)RD@)B8@)'=O
M<F1;,%T@(3T]("<B)RD*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]V86QI9&%T95!H<F%S92AT<FEM*"1W;W)D*2D@/3T](&9A;'-E
M*2!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!-86YA9V5D
M('1O(&=E="!H97)E+"!S;R!R971U<FX@=&AE(&EN<'5T+@H@("`@("`@(')E
M='5R;B`D;&]C86Q?<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@86X@87!P<F]X:6UA=&4@8V]U;G0@;V8@:&]W(&UA;GD@861D<F5S<V5S
M(&%R92!I;B!T:&4*("`@("`J(&=I=F5N('-T<FEN9RX@5&AI<R!I<R!!4%!2
M3UA)34%412!A<R!I="!O;FQY('-P;&ET<R!B87-E9"!O;B!A"B`@("`@*B!C
M;VUM82!W:&EC:"!H87,@;F\@<')E8V5D:6YG(&)A8VMS;&%S:"X@0V]U;&0@
M8F4@=7-E9G5L(&%S"B`@("`@*B!L87)G92!A;6]U;G1S(&]F(&%D9')E<W-E
M<R!W:6QL(&5N9"!U<"!P<F]D=6-I;F<@*FQA<F=E*@H@("`@("H@<W1R=6-T
M=7)E<R!W:&5N('5S960@=VET:"!P87)S94%D9')E<W-,:7-T*"DN"B`@("`@
M*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&1A=&$@061D<F5S<V5S('1O(&-O
M=6YT"B`@("`@*B!`<F5T=7)N(&EN="`@("`@("`@("!!<'!R;WAI;6%T92!C
M;W5N=`H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!R;WAI;6%T94-O=6YT*"1D
M871A*0H@("`@>PH@("`@("`@(')E='5R;B!C;W5N="AP<F5G7W-P;&ET*"<O
M*#\\(5Q<7%PI+"\G+"`D9&%T82DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5&AI<R!I<R!A(&5M86EL('9A;&ED871I;F<@9G5N8W1I;VX@<V5P87)A=&4@
M=&\@=&AE(')E<W0@;V8@=&AE"B`@("`@*B!C;&%S<RX@270@<VEM<&QY('9A
M;&ED871E<R!W:&5T:&5R(&%N(&5M86EL(&ES(&]F('1H92!C;VUM;VX*("`@
M("`J(&EN=&5R;F5T(&9O<FTZ(#QU<V5R/D`\9&]M86EN/BX@5&AI<R!C86X@
M8F4@<W5F9FEC:65N="!F;W(@;6]S=`H@("`@("H@<&5O<&QE+B!/<'1I;VYA
M;"!S=')I8W1E<B!M;V1E(&-A;B!B92!U=&EL:7-E9"!W:&EC:"!R97-T<FEC
M=',*("`@("`J(&UA:6QB;W@@8VAA<F%C=&5R<R!A;&QO=V5D('1O(&%L<&AA
M;G5M97)I8RP@9G5L;"!S=&]P+"!H>7!H96X*("`@("`J(&%N9"!U;F1E<G-C
M;W)E+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D9&%T82`@($%D
M9')E<W,@=&\@8VAE8VL*("`@("`J($!P87)A;2`@8F]O;&5A;B`D<W1R:6-T
M($]P=&EO;F%L('-T<FEC=&5R(&UO9&4*("`@("`J($!R971U<FX@;6EX960@
M("`@("`@("`@($9A;'-E(&EF(&ET(&9A:6QS+"!A;B!I;F1E>&5D(&%R<F%Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!U<V5R;F%M92]D;VUA
M:6X@:68@:70@;6%T8VAE<PH@("`@("HO"B`@("!F=6YC=&EO;B!I<U9A;&ED
M26YE=$%D9')E<W,H)&1A=&$L("1S=')I8W0@/2!F86QS92D*("`@('L*("`@
M("`@("`D<F5G97@@/2`D<W1R:6-T(#\@)R]>*%LN,"TY82UZ7RLM72LI0"@H
M6S`M.6$M>BU=*UPN*2M;,"TY82UZ77LR+#1]*20O:2<@.B`G+UXH6RHK(2XF
M(R1\7"=<7"5<+S`M.6$M>EY?8'M]/3]^.BU=*RE`*"A;,"TY82UZ+5TK7"XI
M*ULP+3EA+7I=>S(L-'TI)"]I)SL*("`@("`@("!I9B`H<')E9U]M871C:"@D
M<F5G97@L('1R:6TH)&1A=&$I+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"1M871C:&5S6S%=+"`D;6%T8VAE<ULR72D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]-86EL+VUI;65087)T+G!H<```````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,3$Q,``Q,#4Q-30S,3`U-P`P
M,C`U,#8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@(%)I8VAA<F0@2&5Y97,@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!!;&P@
M<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`T*
M+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA
M="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`T*+R\@?"!A<F4@;65T
M.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?`T*+R\@
M?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?`T*+R\@?"!O(%)E9&ES=')I
M8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O
M=F4@8V]P>7)I9VAT("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T
M:&4@?`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R
M:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?`T*+R\@?"!O
M(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@
M96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`T*+R\@?"`@('!R;V1U8W1S(&1E
M<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B`@?`T*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!42$E3
M(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$52
M4R!!3D0@0T].5%))0E543U)3("`@?`T*+R\@?"`B05,@25,B($%.1"!!3ED@
M15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54
M($Y/5"`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)2
M04Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@?`T*
M+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@
M3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`T*+R\@?"!/5TY%4B!/
M4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)
M4D5#5"P@24Y#241%3E1!3"P@?`T*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL
M($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4
M("`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)3
M5$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`T*+R\@
M?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`T*+R\@?"!42$5/4ED@3T8@
M3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,
M2519+"!/4B!43U)4("`@?`T*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@
M3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!5
M4T4@?`T*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@
M3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?`T*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I
M8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*#0HO*BH-"BH-
M"BH@(%)A=R!M:6UE(&5N8V]D:6YG(&-L87-S#0HJ#0HJ(%=H870@:7,@:70_
M#0HJ("`@5&AI<R!C;&%S<R!E;F%B;&5S('EO=2!T;R!M86YI<'5L871E(&%N
M9"!B=6EL9`T**B`@(&$@;6EM92!E;6%I;"!F<F]M('1H92!G<F]U;F0@=7`N
M#0HJ#0HJ(%=H>2!U<V4@=&AI<R!I;G-T96%D(&]F(&UI;64N<&AP/PT**B`@
M(&UI;64N<&AP(&ES(&$@=7-E<F9R:65N9&QY(&%P:2!T;R!T:&ES(&-L87-S
M(&9O<@T**B`@('!E;W!L92!W:&\@87)E;B=T(&EN=&5R97-T960@:6X@=&AE
M(&EN=&5R;F%L<R!O9@T**B`@(&UI;64@;6%I;"X@5&AI<R!C;&%S<R!H;W=E
M=F5R(&%L;&]W<R!F=6QL(&-O;G1R;VP-"BH@("!O=F5R('1H92!E;6%I;"X-
M"BH-"BH@16<N#0HJ#0HJ("\O(%-I;F-E(&UU;'1I<&%R="]M:7AE9"!H87,@
M;F\@<F5A;"!B;V1Y+"`H=&AE(&)O9'D@:7,-"BH@+R\@=&AE('-U8G!A<G0I
M+"!W92!S970@=&AE(&)O9'D@87)G=6UE;G0@=&\@8FQA;FLN#0HJ#0HJ("1P
M87)A;7-;)V-O;G1E;G1?='EP92==(#T@)VUU;'1I<&%R="]M:7AE9"<[#0HJ
M("1E;6%I;"`](&YE=R!-86EL7VUI;65087)T*"<G+"`D<&%R86US*3L-"BH-
M"BH@+R\@2&5R92!W92!A9&0@82!T97AT('!A<G0@=&\@=&AE(&UU;'1I<&%R
M="!W92!H879E#0HJ("\O(&%L<F5A9'DN($%S<W5M92`D8F]D>2!C;VYT86EN
M<R!P;&%I;B!T97AT+@T**@T**B`D<&%R86US6R=C;VYT96YT7W1Y<&4G72`]
M("=T97AT+W!L86EN)SL-"BH@)'!A<F%M<ULG96YC;V1I;F<G72`@("`@/2`G
M-V)I="<[#0HJ("1T97AT(#T@)&5M86EL+3YA9&13=6)087)T*"1B;V1Y+"`D
M<&%R86US*3L-"BH-"BH@+R\@3F]W(&%D9"!A;B!A='1A8VAM96YT+B!!<W-U
M;64@)&%T=&%C:"!I<PT**B!T:&4@8V]N=&5N=',@;V8@=&AE(&%T=&%C:&UE
M;G0-"BH-"BH@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G87!P;&EC871I
M;VXO>FEP)SL-"BH@)'!A<F%M<ULG96YC;V1I;F<G72`@("`@/2`G8F%S938T
M)SL-"BH@)'!A<F%M<ULG9&ES<&]S:71I;VXG72`@/2`G871T86-H;65N="<[
M#0HJ("1P87)A;7-;)V1F:6QE;F%M92==("`@(#T@)V5X86UP;&4N>FEP)SL-
M"BH@)&%T=&%C:"`])B`D96UA:6PM/F%D9%-U8E!A<G0H)&)O9'DL("1P87)A
M;7,I.PT**@T**B`O+R!.;W<@8G5I;&0@=&AE(&5M86EL+B!.;W1E('1H870@
M=&AE(&5N8V]D90T**B`O+R!F=6YC=&EO;B!R971U<FYS(&%N(&%S<V]C:6%T
M:79E(&%R<F%Y(&-O;G1A:6YI;F<@='=O#0HJ("\O(&5L96UE;G1S+"!B;V1Y
M(&%N9"!H96%D97)S+B!9;W4@=VEL;"!N965D('1O(&%D9"!E>'1R80T**B`O
M+R!H96%D97)S+"`H96<N($UI;64M5F5R<VEO;BD@8F5F;W)E('-E;F1I;F<N
M#0HJ#0HJ("1E;6%I;"`]("1M97-S86=E+3YE;F-O9&4H*3L-"BH@)&5M86EL
M6R=H96%D97)S)UU;72`]("=-:6UE+59E<G-I;VXZ(#$N,"<[#0HJ#0HJ#0HJ
M($9U<G1H97(@97AA;7!L97,@87)E(&%V86EL86)L92!A="!H='1P.B\O=W=W
M+G!H<&=U<G4N;W)G#0HJ#0HJ(%1/1$\Z#0HJ("`M(%-E="!E;F-O9&4H*2!T
M;R!R971U<FX@=&AE("1O8FHM/F5N8V]D960@:68@96YC;V1E*"D-"BH@("`@
M:&%S(&%L<F5A9'D@8F5E;B!R=6XN(%5N;&5S<R!A(&9L86<@:7,@<&%S<V5D
M('1O('-P96-I9FEC86QL>0T**B`@("!R92UB=6EL9"!T:&4@;65S<V%G92X-
M"BH-"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U
M+F]R9SX-"BH@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C$S("0-"BH@0'!A8VMA
M9V4@36%I;`T**B\-"@T*8VQA<W,@36%I;%]M:6UE4&%R="![#0H-"B`@("\J
M*@T*("`@("H@5&AE(&5N8V]D:6YG('1Y<&4@;V8@=&AI<R!P87)T#0H@("`@
M*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1?96YC;V1I;F<[#0H-
M"B`@("\J*@T*("`@("H@06X@87)R87D@;V8@<W5B<&%R=',-"B`@("`J($!V
M87(@87)R87D-"B`@("`J+PT*("`@('9A<B`D7W-U8G!A<G1S.PT*#0H@("`O
M*BH-"B`@("`J(%1H92!O=71P=70@;V8@=&AI<R!P87)T(&%F=&5R(&)E:6YG
M(&)U:6QT#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1?
M96YC;V1E9#L-"@T*("`@+RHJ#0H@("`@*B!(96%D97)S(&9O<B!T:&ES('!A
M<G0-"B`@("`J($!V87(@87)R87D-"B`@("`J+PT*("`@('9A<B`D7VAE861E
M<G,[#0H-"B`@("\J*@T*("`@("H@5&AE(&)O9'D@;V8@=&AI<R!P87)T("AN
M;W0@96YC;V1E9"D-"B`@("`J($!V87(@<W1R:6YG#0H@("`@*B\-"B`@("!V
M87(@)%]B;V1Y.PT*#0H@("`@+RHJ#0H@("`@("H@0V]N<W1R=6-T;W(N#0H@
M("`@("H-"B`@("`@*B!3971S('5P('1H92!O8FIE8W0N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@)&)O9'D@("`M(%1H92!B;V1Y(&]F('1H92!M:6UE('!A
M<G0@:68@86YY+@T*("`@("`J($!P87)A;2`D<&%R86US("T@06X@87-S;V-I
M871I=F4@87)R87D@;V8@<&%R86UE=&5R<SH-"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&-O;G1E;G1?='EP92`M(%1H92!C;VYT96YT('1Y<&4@9F]R('1H
M:7,@<&%R="!E9R!M=6QT:7!A<G0O;6EX960-"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&5N8V]D:6YG("`@("`M(%1H92!E;F-O9&EN9R!T;R!U<V4L(#=B
M:70L(#AB:70L(&)A<V4V-"P@;W(@<75O=&5D+7!R:6YT86)L90T*("`@("`J
M("`@("`@("`@("`@("`@("`@8VED("`@("`@("`@("T@0V]N=&5N="!)1"!T
M;R!A<'!L>0T*("`@("`J("`@("`@("`@("`@("`@("`@9&ES<&]S:71I;VX@
M("T@0V]N=&5N="!D:7-P;W-I=&EO;BP@:6YL:6YE(&]R(&%T=&%C:&UE;G0-
M"B`@("`@*B`@("`@("`@("`@("`@("`@(&1F:6QE;F%M92`@("`M($]P=&EO
M;F%L(&9I;&5N86UE('!A<F%M971E<B!F;W(@8V]N=&5N="!D:7-P;W-I=&EO
M;@T*("`@("`J("`@("`@("`@("`@("`@("`@9&5S8W)I<'1I;VX@("T@0V]N
M=&5N="!D97-C<FEP=&EO;@T*("`@("`J("`@("`@("`@("`@("`@("`@8VAA
M<G-E="`@("`@("T@0VAA<F%C=&5R('-E="!T;R!U<V4-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N($UA:6Q?;6EM95!A
M<G0H)&)O9'D@/2`G)RP@)'!A<F%M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@
M("`@("!I9B`H(61E9FEN960H)TU!24Q?34E-15!!4E1?0U),1B<I*2![#0H@
M("`@("`@("`@("!D969I;F4H)TU!24Q?34E-15!!4E1?0U),1B<L(&1E9FEN
M960H)TU!24Q?34E-15]#4DQ&)RD@/R!-04E,7TU)345?0U),1B`Z(")<<EQN
M(BP@5%)512D[#0H@("`@("`@('T-"@T*("`@("`@("!F;W)E86-H("@D<&%R
M86US(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@("!S=VET8V@@
M*"1K97DI('L-"B`@("`@("`@("`@("`@("!C87-E("=C;VYT96YT7W1Y<&4G
M.@T*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R<ULG0V]N=&5N="U4>7!E
M)UT@/2`D=F%L=64@+B`H:7-S970H)&-H87)S970I(#\@)SL@8VAA<G-E=#TB
M)R`N("1C:&%R<V5T("X@)R(G(#H@)R<I.PT*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@(&-A<V4@)V5N8V]D:6YG)SH-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E;F-O9&EN9R`]("1V86QU
M93L-"B`@("`@("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<G72`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("!C87-E("=C:60G.@T*("`@
M("`@("`@("`@("`@("`@("`D:&5A9&5R<ULG0V]N=&5N="U)1"==(#T@)SPG
M("X@)'9A;'5E("X@)SXG.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"@T*("`@("`@("`@("`@("`@(&-A<V4@)V1I<W!O<VET:6]N)SH-"B`@("`@
M("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M1&ES<&]S:71I;VXG
M72`]("1V86QU92`N("AI<W-E="@D9&9I;&5N86UE*2`_("<[(&9I;&5N86UE
M/2(G("X@)&1F:6QE;F%M92`N("<B)R`Z("<G*3L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("!C87-E("=D9FEL96YA
M;64G.@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&AE861E<G-;
M)T-O;G1E;G0M1&ES<&]S:71I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1H96%D97)S6R=#;VYT96YT+41I<W!O<VET:6]N)UT@+CT@)SL@
M9FEL96YA;64](B<@+B`D=F%L=64@+B`G(B<[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&9I;&5N
M86UE(#T@)'9A;'5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("`@("`@8V%S92`G
M9&5S8W)I<'1I;VXG.@T*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R<ULG
M0V]N=&5N="U$97-C<FEP=&EO;B==(#T@)'9A;'5E.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@(&-A<V4@)V-H87)S
M970G.@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&AE861E<G-;
M)T-O;G1E;G0M5'EP92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&AE861E<G-;)T-O;G1E;G0M5'EP92==("X]("<[(&-H87)S970](B<@+B`D
M=F%L=64@+B`G(B<[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D8VAA<G-E="`]("1V86QU93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O($1E
M9F%U;'0@8V]N=&5N="UT>7!E#0H@("`@("`@(&EF("@A:7-S970H)&AE861E
M<G-;)T-O;G1E;G0M5'EP92==*2D@>PT*("`@("`@("`@("`@)&AE861E<G-;
M)T-O;G1E;G0M5'EP92==(#T@)W1E>'0O<&QA:6XG.PT*("`@("`@("!]#0H-
M"B`@("`@("`@+R]$969A=6QT(&5N8V]D:6YG#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]E;F-O9&EN9RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M96YC;V1I;F<@/2`G-V)I="<[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!!
M<W-I9VX@<W1U9F8@=&\@;65M8F5R('9A<FEA8FQE<PT*("`@("`@("`D=&AI
M<RT^7V5N8V]D960@(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M/E]H96%D
M97)S("`]("1H96%D97)S.PT*("`@("`@("`D=&AI<RT^7V)O9'D@("`@(#T@
M)&)O9'D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@96YC;V1E*"D-"B`@
M("`@*@T*("`@("`J($5N8V]D97,@86YD(')E='5R;G,@=&AE(&5M86EL+B!!
M;'-O('-T;W)E<PT*("`@("`J(&ET(&EN('1H92!E;F-O9&5D(&UE;6)E<B!V
M87)I86)L90T*("`@("`J#0H@("`@("H@0')E='5R;B!!;B!A<W-O8VEA=&EV
M92!A<G)A>2!C;VYT86EN:6YG('1W;R!E;&5M96YT<RP-"B`@("`@*B`@("`@
M("`@(&)O9'D@86YD(&AE861E<G,N(%1H92!H96%D97)S(&5L96UE;G0@:7,@
M:71S96QF#0H@("`@("H@("`@("`@("!A;B!I;F1E>&5D(&%R<F%Y+@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@96YC
M;V1E*"D-"B`@("![#0H@("`@("`@("1E;F-O9&5D(#TF("1T:&ES+3Y?96YC
M;V1E9#L-"@T*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<W5B<&%R=',I
M*2![#0H@("`@("`@("`@("!S<F%N9"@H9&]U8FQE*6UI8W)O=&EM92@I*C$P
M,#`P,#`I.PT*("`@("`@("`@("`@)&)O=6YD87)Y(#T@)SU?)R`N(&UD-2AR
M86YD*"D@+B!M:6-R;W1I;64H*2D[#0H@("`@("`@("`@("`D=&AI<RT^7VAE
M861E<G-;)T-O;G1E;G0M5'EP92==("X]("<[)R`N($U!24Q?34E-15!!4E1?
M0U),1B`N(")<="(@+B`G8F]U;F1A<GD](B<@+B`D8F]U;F1A<GD@+B`G(B<[
M#0H-"B`@("`@("`@("`@("\O($%D9"!B;V1Y('!A<G1S('1O("1S=6)P87)T
M<PT*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1H:7,M
M/E]S=6)P87)T<RD[("1I*RLI('L-"B`@("`@("`@("`@("`@("`D:&5A9&5R
M<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@)'1M<"`]("1T:&ES+3Y?
M<W5B<&%R='-;)&E=+3YE;F-O9&4H*3L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=&UP6R=H96%D97)S)UT@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@
M("`@("`@("`@("`@("`@("`@)&AE861E<G-;72`]("1K97D@+B`G.B`G("X@
M)'9A;'5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M<W5B<&%R='-;72`](&EM<&QO9&4H34%)3%]-24U%4$%25%]#4DQ&+"`D:&5A
M9&5R<RD@+B!-04E,7TU)345005)47T-23$8@+B!-04E,7TU)345005)47T-2
M3$8@+B`D=&UP6R=B;V1Y)UT[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@
M("`@("1E;F-O9&5D6R=B;V1Y)UT@/2`G+2TG("X@)&)O=6YD87)Y("X@34%)
M3%]-24U%4$%25%]#4DQ&("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L;V1E*"<M+2<@+B`D8F]U;F1A<GD@+B!-04E,7TU)345005)4
M7T-23$8L("1S=6)P87)T<RD@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<M+2<@+B`D8F]U;F1A<GDN)RTM)R`N($U!24Q?34E-15!!4E1?
M0U),1CL-"@T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&5N8V]D
M961;)V)O9'DG72`]("1T:&ES+3Y?9V5T16YC;V1E9$1A=&$H)'1H:7,M/E]B
M;V1Y+"`D=&AI<RT^7V5N8V]D:6YG*2`N($U!24Q?34E-15!!4E1?0U),1CL-
M"B`@("`@("`@?0T*#0H@("`@("`@("\O($%D9"!H96%D97)S('1O("1E;F-O
M9&5D#0H@("`@("`@("1E;F-O9&5D6R=H96%D97)S)UT@/28@)'1H:7,M/E]H
M96%D97)S.PT*#0H@("`@("`@(')E='5R;B`D96YC;V1E9#L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B`F861D4W5B4&%R="@I#0H@("`@("H-"B`@("`@
M*B!!9&1S(&$@<W5B<&%R="!T;R!C=7)R96YT(&UI;64@<&%R="!A;F0@<F5T
M=7)N<PT*("`@("`J(&$@<F5F97)E;F-E('1O(&ET#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@)&)O9'D@("!4:&4@8F]D>2!O9B!T:&4@<W5B<&%R="P@:68@
M86YY+@T*("`@("`J($!P87)A;2`D<&%R86US(%1H92!P87)A;65T97)S(&9O
M<B!T:&4@<W5B<&%R="P@<V%M90T*("`@("`J("`@("`@("`@("`@("`@(&%S
M('1H92`D<&%R86US(&%R9W5M96YT(&9O<B!C;VYS=')U8W1O<BX-"B`@("`@
M*B!`<F5T=7)N($$@<F5F97)E;F-E('1O('1H92!P87)T('EO=2!J=7-T(&%D
M9&5D+B!)="!I<PT*("`@("`J("`@("`@("`@8W)U8VEA;"!I9B!U<VEN9R!M
M=6QT:7!A<G0O*B!I;B!Y;W5R('-U8G!A<G1S('1H870-"B`@("`@*B`@("`@
M("`@('EO=2!U<V4@/28@:6X@>6]U<B!S8W)I<'0@=VAE;B!C86QL:6YG('1H
M:7,@9G5N8W1I;VXL#0H@("`@("H@("`@("`@("!O=&AE<G=I<V4@>6]U('=I
M;&P@;F]T(&)E(&%B;&4@=&\@861D(&9U<G1H97(@<W5B<&%R=',N#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F861D
M4W5B4&%R="@D8F]D>2P@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<W5B<&%R='-;72`](&YE=R!-86EL7VUI;65087)T*"1B;V1Y+"`D<&%R
M86US*3L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W5B<&%R='-;8V]U;G0H
M)'1H:7,M/E]S=6)P87)T<RD@+2`Q73L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!?9V5T16YC;V1E9$1A=&$H*0T*("`@("`J#0H@("`@("H@4F5T=7)N
M<R!E;F-O9&5D(&1A=&$@8F%S960@=7!O;B!E;F-O9&EN9R!P87-S960@=&\@
M:70-"B`@("`@*@T*("`@("`J($!P87)A;2`D9&%T82`@("`@5&AE(&1A=&$@
M=&\@96YC;V1E+@T*("`@("`J($!P87)A;2`D96YC;V1I;F<@5&AE(&5N8V]D
M:6YG('1Y<&4@=&\@=7-E+"`W8FET+"!B87-E-C0L#0H@("`@("H@("`@("`@
M("`@("`@("`@("!O<B!Q=6]T960M<')I;G1A8FQE+@T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971%;F-O9&5D
M1&%T82@D9&%T82P@)&5N8V]D:6YG*0T*("`@('L-"B`@("`@("`@<W=I=&-H
M("@D96YC;V1I;F<I('L-"B`@("`@("`@("`@(&-A<V4@)SAB:70G.@T*("`@
M("`@("`@("`@8V%S92`G-V)I="<Z#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1D871A.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@
M("!C87-E("=Q=6]T960M<')I;G1A8FQE)SH-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]Q=6]T9610<FEN=&%B;&5%;F-O9&4H)&1A=&$I.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E("=B
M87-E-C0G.@T*("`@("`@("`@("`@("`@(')E='5R;B!R=')I;2AC:'5N:U]S
M<&QI="AB87-E-C1?96YC;V1E*"1D871A*2P@-S8L($U!24Q?34E-15!!4E1?
M0U),1BDI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@
M("!D969A=6QT.@T*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T83L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J('%U;W1E8610<FEN
M=&%B;&5%;F-O9&4H*0T*("`@("`J#0H@("`@("H@16YC;V1E<R!D871A('1O
M('%U;W1E9"UP<FEN=&%B;&4@<W1A;F1A<F0N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@)&EN<'5T("`@(%1H92!D871A('1O(&5N8V]D90T*("`@("`J($!P
M87)A;2`D;&EN95]M87@@3W!T:6]N86P@;6%X(&QI;F4@;&5N9W1H+B!3:&]U
M;&0-"B`@("`@*B`@("`@("`@("`@("`@("`@(&YO="!B92!M;W)E('1H86X@
M-S8@8VAA<G,-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]Q=6]T9610<FEN=&%B;&5%;F-O9&4H)&EN
M<'5T("P@)&QI;F5?;6%X(#T@-S8I#0H@("`@>PT*("`@("`@("`D;&EN97,@
M(#T@<')E9U]S<&QI="@B+UQR/UQN+R(L("1I;G!U="D[#0H@("`@("`@("1E
M;VP@("`@/2!-04E,7TU)345005)47T-23$8[#0H@("`@("`@("1E<V-A<&4@
M/2`G/2<[#0H@("`@("`@("1O=71P=70@/2`G)SL-"@T*("`@("`@("!W:&EL
M92AL:7-T*"P@)&QI;F4I(#T@96%C:"@D;&EN97,I*7L-"@T*("`@("`@("`@
M("`@)&QI;FQE;B`@("`@/2!S=')L96XH)&QI;F4I.PT*("`@("`@("`@("`@
M)&YE=VQI;F4@/2`G)SL-"@T*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)&QI;FQE;CL@)&DK*RD@>PT*("`@("`@("`@("`@("`@("1C:&%R(#T@
M<W5B<W1R*"1L:6YE+"`D:2P@,2D[#0H@("`@("`@("`@("`@("`@)&1E8R`@
M/2!O<F0H)&-H87(I.PT*#0H@("`@("`@("`@("`@("`@:68@*"@D9&5C(#T]
M(#,R*2!!3D0@*"1I(#T]("@D;&EN;&5N("T@,2DI*7L@("`@+R\@8V]N=F5R
M="!S<&%C92!A="!E;VP@;VYL>0T*("`@("`@("`@("`@("`@("`@("`D8VAA
M<B`]("<],C`G.PT*#0H@("`@("`@("`@("`@("`@?2!E;'-E:68H*"1D96,@
M/3T@.2D@04Y$("@D:2`]/2`H)&QI;FQE;B`M(#$I*2D@>R`@+R\@8V]N=F5R
M="!T86(@870@96]L(&]N;'D-"B`@("`@("`@("`@("`@("`@("`@)&-H87(@
M/2`G/3`Y)SL-"B`@("`@("`@("`@("`@("!](&5L<V5I9B@D9&5C(#T](#DI
M('L-"B`@("`@("`@("`@("`@("`@("`@.R`O+R!$;R!N;W1H:6YG(&EF(&$@
M=&%B+@T*("`@("`@("`@("`@("`@('T@96QS96EF*"@D9&5C(#T](#8Q*2!/
M4B`H)&1E8R`\(#,R("D@3U(@*"1D96,@/B`Q,C8I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1C:&%R(#T@)&5S8V%P92`N('-T<G1O=7!P97(H<W!R:6YT
M9B@G)3`R<R<L(&1E8VAE>"@D9&5C*2DI.PT*("`@("`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@("`@(&EF("@H<W1R;&5N*"1N97=L:6YE*2`K('-T
M<FQE;B@D8VAA<BDI(#X]("1L:6YE7VUA>"D@>R`@("`@("`@+R\@34%)3%]-
M24U%4$%25%]#4DQ&(&ES(&YO="!C;W5N=&5D#0H@("`@("`@("`@("`@("`@
M("`@("1O=71P=70@("X]("1N97=L:6YE("X@)&5S8V%P92`N("1E;VP[("`@
M("`@("`@("`@("`@("`@("`O+R!S;V9T(&QI;F4@8G)E86L[("(@/5QR7&XB
M(&ES(&]K87D-"B`@("`@("`@("`@("`@("`@("`@)&YE=VQI;F4@(#T@)R<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=L:6YE
M("X]("1C:&%R.PT*("`@("`@("`@("`@?2`O+R!E;F0@;V8@9F]R#0H@("`@
M("`@("`@("`D;W5T<'5T("X]("1N97=L:6YE("X@)&5O;#L-"B`@("`@("`@
M?0T*("`@("`@("`D;W5T<'5T(#T@<W5B<W1R*"1O=71P=70L(#`L("TQ("H@
M<W1R;&5N*"1E;VPI*3L@+R\@1&]N)W0@=V%N="!L87-T(&-R;&8-"B`@("`@
M("`@<F5T=7)N("1O=71P=70[#0H@("`@?0T*?2`O+R!%;F0@;V8@8VQA<W,-
M"C\^#0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL+VUI;64N<&AP````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,3`V,P`Q,#4Q
M-30S,3`U-P`P,3<V-S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,C`P
M,BTR,#`S("!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@0V]P>7)I9VAT("AC*2`R,#`S+3(P,#4@(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@
M('P*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@
M=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`HO+R!\(&%R92!M
M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?`HO+R!\
M("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@
M?`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS
M('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\"B\O('P@;R!4:&4@
M;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R
M<V4@;W(@<')O;6]T92`@("`@('P*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@
M9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I
M='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!42$E3(%-/1E1705)%
M($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].
M5%))0E543U)3("`@?`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2
M($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\
M"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!(%!!4E1)
M0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!
M3$P@5$A%($-/4%E224=(5"`@?`HO+R!\($]73D52($]2($-/3E1224)55$]2
M4R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.
M5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y4
M24%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P*+R\@?"!,
M24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2
M(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`HO+R!\($1!5$$L($]2(%!23T9)
M5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@
M04Y$($].($%.62!\"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%
M4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P*
M+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE3
M24Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?`HO+R!\($]&(%1(25,@
M4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@
M3T8@4U5#2"!$04U!1T4N("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R9SX@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("!4;VUA<R!6
M+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("AP;W)T('1O(%!%05(I("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+PHO+R`D260Z(&UI;64N<&AP+'8@,2XS.2`R,#`U+S`V+S$S(#(Q.C(T.C$V
M(&-I<')I($5X<"`D"@IR97%U:7)E7V]N8V4H)U!%05(N<&AP)RD["G)E<75I
M<F5?;VYC92@G36%I;"]M:6UE4&%R="YP:'`G*3L*"B\J*@H@*B!-:6UE(&UA
M:6P@8V]M<&]S97(@8VQA<W,N($-A;B!H86YD;&4Z('1E>'0@86YD(&AT;6P@
M8F]D:65S+"!E;6)E9&1E9"!H=&UL"B`J(&EM86=E<R!A;F0@871T86-H;65N
M=',N"B`J($1O8W5M96YT871I;VX@86YD(&5X86UP;&5S(&]F('1H:7,@8VQA
M<W,@87)E(&%V86EB;&4@:&5R93H*("H@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO"B`J"B`J($!N;W1E<R!4:&ES(&-L87-S(&ES(&)A<V5D(&]N($A4
M34P@36EM92!-86EL(&-L87-S(&9R;VT*("H@("!2:6-H87)D($AE>65S(#QR
M:6-H87)D0'!H<&=U<G4N;W)G/B!W:&EC:"!W87,@8F%S960@86QS;PH@*B`@
M(&EN('1H92!M:6UE7VUA:6PN8VQA<W,@8GD@5&]B:6%S(%)A='-C:&EL;&5R
M(#QT;V)I87-`9&YE="YI=#X@86YD"B`J("`@4V%S8VAA(%-C:'5M86YN(#QS
M87-C:&%`<V-H=6UA;FXN8W@^"B`J"B`J($!A=71H;W(@("!2:6-H87)D($AE
M>65S(#QR:6-H87)D+FAE>65S0&AE>65S+6-O;7!U=&EN9RYN970^"B`J($!A
M=71H;W(@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!P
M86-K86=E("!-86EL"B`J($!A8V-E<W,@("!P=6)L:6,*("HO"F-L87-S($UA
M:6Q?;6EM90I["B`@("`O*BH*("`@("`J($-O;G1A:6YS('1H92!P;&%I;B!T
M97AT('!A<G0@;V8@=&AE(&5M86EL"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]T>'1B;V1Y.PH@("`@+RHJ"B`@("`@*B!#;VYT86EN
M<R!T:&4@:'1M;"!P87)T(&]F('1H92!E;6%I;`H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?:'1M;&)O9'D["B`@("`O*BH*("`@("`J
M(&-O;G1A:6YS('1H92!M:6UE(&5N8V]D960@=&5X=`H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?;6EM93L*("`@("\J*@H@("`@("H@
M8V]N=&%I;G,@=&AE(&UU;'1I<&%R="!C;VYT96YT"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]M=6QT:7!A<G0["B`@("`O*BH*("`@
M("`J(&QI<W0@;V8@=&AE(&%T=&%C:&5D(&EM86=E<PH@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]H=&UL7VEM86=E<R`](&%R<F%Y*"D[
M"B`@("`O*BH*("`@("`J(&QI<W0@;V8@=&AE(&%T=&%C:&5M96YT<PH@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)T<R`](&%R<F%Y
M*"D["B`@("`O*BH*("`@("`J($)U:6QD('!A<F%M971E<G,*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8G5I;&1?<&%R86US(#T@87)R
M87DH*3L*("`@("\J*@H@("`@("H@2&5A9&5R<R!F;W(@=&AE(&UA:6P*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:&5A9&5R<R`](&%R
M<F%Y*"D["B`@("`O*BH*("`@("`J($5N9"!/9B!,:6YE('-E<75E;F-E("AF
M;W(@<V5R:6%L:7IE*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?96]L.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R(&9U;F-T
M:6]N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@36%I;%]M:6UE*"1C<FQF(#T@(EQR7&XB*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<V5T14],*"1C<FQF*3L*("`@("`@("`D=&AI<RT^7V)U
M:6QD7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1E>'1?96YC;V1I;F<G(#T^("<W8FET)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H=&UL7V5N8V]D:6YG
M)R`]/B`G<75O=&5D+7!R:6YT86)L92<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G-V)I=%]W<F%P)R`@("`@/3X@.3DX+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAT;6Q?8VAA<G-E
M="<@(#T^("=)4T\M.#@U.2TQ)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T97AT7V-H87)S970G("`]/B`G25-/+3@X-3DM,2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&5A9%]C
M:&%R<V5T)R`@/3X@)TE33RTX.#4Y+3$G"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!786ME
M=7`@*'5N<V5R:6%L:7IE*2`M(')E+7-E=',@14],(&-O;G-T86YT"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]?=V%K975P*"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$5/3"@D=&AI
M<RT^7V5O;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8V-E<W-O<B!F=6YC
M=&EO;B!T;R!S970@=&AE(&)O9'D@=&5X="X@0F]D>2!T97AT(&ES('5S960@
M:68*("`@("`J(&ET)W,@;F]T(&%N(&AT;6P@;6%I;"!B96EN9R!S96YT(&]R
M(&5L<V4@:7,@=7-E9"!T;R!F:6QL('1H90H@("`@("H@=&5X="]P;&%I;B!P
M87)T('1H870@96UA:6QS(&-L:65N=',@=VAO(&1O;B=T('-U<'!O<G0*("`@
M("`J(&AT;6P@<VAO=6QD('-H;W<N"B`@("`@*@H@("`@("H@0'!A<F%M("!S
M=')I;F<@("1D871A("`@16ET:&5R(&$@<W1R:6YG(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@9FEL92!N86UE('=I=&@@=&AE(&-O
M;G1E;G1S"B`@("`@*B!`<&%R86T@(&)O;VP@("`@)&ES9FEL92!)9B!T<G5E
M('1H92!F:7)S="!P87)A;2!S:&]U;&0@8F4@=')E871E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@87,@82!F:6QE(&YA;64L(&5L<V4@87,@
M82!S=')I;F<@*&1E9F%U;'0I"B`@("`@*B!`<&%R86T@(&)O;VP@("`@)&%P
M<&5N9"!)9B!T<G5E('1H92!T97AT(&]R(&9I;&4@:7,@87!P96YD960@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H92!E>&ES=&EN9R!B
M;V1Y+"!E;'-E('1H92!O;&0@8F]D>2!I<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@;W9E<G=R:71T96X*("`@("`J($!R971U<FX@;6EX960@
M("!T<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%185$)O
M9'DH)&1A=&$L("1I<V9I;&4@/2!F86QS92P@)&%P<&5N9"`](&9A;'-E*0H@
M("`@>PH@("`@("`@(&EF("@A)&ES9FEL92D@>PH@("`@("`@("`@("!I9B`H
M(21A<'!E;F0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?='AT8F]D>2`]
M("1D871A.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]T>'1B;V1Y("X]("1D871A.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;G0@/2`D=&AI<RT^7V9I;&4R
M<W1R*"1D871A*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-O
M;G0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&-O;G0["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"$D87!P96YD*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W1X=&)O9'D@/2`D8V]N=#L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?='AT8F]D>2`N/2`D8V]N
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!H=&UL('!A<G0@=&\@
M=&AE(&UA:6P*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&1A=&$@
M("!%:71H97(@82!S=')I;F<@;W(@=&AE(&9I;&4@;F%M92!W:71H('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&5N=',*("`@("`J
M($!P87)A;2`@8F]O;"`@("`D:7-F:6QE($EF('1R=64@=&AE(&9I<G-T('!A
M<F%M('-H;W5L9"!B92!T<F5A=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!A<R!A(&9I;&4@;F%M92P@96QS92!A<R!A('-T<FEN9R`H9&5F
M875L="D*("`@("`J($!R971U<FX@;6EX960@("!T<G5E(&]N('-U8V-E<W,@
M;W(@4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$A434Q";V1Y*"1D871A+"`D:7-F:6QE
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"$D:7-F:6QE*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?:'1M;&)O9'D@/2`D9&%T83L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8V]N="`]("1T:&ES+3Y?9FEL93)S='(H)&1A
M=&$I.PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N="DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D8V]N=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7VAT;6QB;V1Y(#T@)&-O;G0["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9',@86X@:6UA9V4@=&\@=&AE(&QI<W0@;V8@96UB961D960@:6UA9V5S
M+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D9FEL92`@("`@("!4
M:&4@:6UA9V4@9FEL92!N86UE($]2(&EM86=E(&1A=&$@:71S96QF"B`@("`@
M*B!`<&%R86T@('-T<FEN9R`@)&-?='EP92`@("`@5&AE(&-O;G1E;G0@='EP
M90H@("`@("H@0'!A<F%M("!S=')I;F<@("1N86UE("`@("`@(%1H92!F:6QE
M;F%M92!O9B!T:&4@:6UA9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@3VYL>2!U<V4@:68@)&9I;&4@:7,@=&AE(&EM86=E(&1A=&$*
M("`@("`J($!P87)A;2`@8F]O;"`@("`D:7-F:6QE;F%M92!7:&5T:&5R("1F
M:6QE(&ES(&$@9FEL96YA;64@;W(@;F]T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&5F875L=',@=&\@=')U90H@("`@("H@0')E='5R
M;B!M:7AE9"`@('1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]B:F5C
M=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D2%1-3$EM86=E*"1F:6QE+"`D8U]T>7!E/2=A<'!L:6-A=&EO;B]O8W1E
M="US=')E86TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M)R<L("1I<V9I;&5N86UE(#T@=')U92D*("`@('L*("`@("`@("`D9FEL961A
M=&$@/2`H)&ES9FEL96YA;64@/3T]('1R=64I(#\@)'1H:7,M/E]F:6QE,G-T
M<B@D9FEL92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@)&9I;&4["B`@("`@("`@:68@*"1I<V9I;&5N86UE(#T]/2!T
M<G5E*2!["B`@("`@("`@("`@("1F:6QE;F%M92`]("@D;F%M92`]/2`G)R`_
M(&)A<V5N86UE*"1F:6QE*2`Z(&)A<V5N86UE*"1N86UE*2D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&9I;&5N86UE(#T@8F%S96YA;64H)&YA
M;64I.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL
M961A=&$I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL961A=&$["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3Y?:'1M;%]I;6%G97-;72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B;V1Y)R`@
M(#T^("1F:6QE9&%T82P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@("`]/B`D9FEL96YA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V-?='EP92<@/3X@)&-?='EP92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8VED)R`@
M("`]/B!M9#4H=6YI<6ED*'1I;64H*2DI"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!A(&9I;&4@=&\@=&AE(&QI<W0@;V8@
M871T86-H;65N=',N"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@("1F
M:6QE("`@("`@(%1H92!F:6QE(&YA;64@;V8@=&AE(&9I;&4@=&\@871T86-H
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3U(@=&AE(&9I
M;&4@9&%T82!I='-E;&8*("`@("`J($!P87)A;2`@<W1R:6YG("`D8U]T>7!E
M("`@("!4:&4@8V]N=&5N="!T>7!E"B`@("`@*B!`<&%R86T@('-T<FEN9R`@
M)&YA;64@("`@("`@5&AE(&9I;&5N86UE(&]F('1H92!A='1A8VAM96YT"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3VYL>2!U<V4@:68@
M)&9I;&4@:7,@=&AE(&9I;&4@9&%T80H@("`@("H@0'!A<F%M("!B;V]L("`@
M("1I<T9I;&5N86UE(%=H971H97(@)&9I;&4@:7,@82!F:6QE;F%M92!O<B!N
M;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT
M<R!T;R!T<G5E"B`@("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S
M<R!O<B!014%27T5R<F]R(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D071T86-H;65N="@D9FEL92P@)&-?
M='EP92`]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F%M92`]("<G+"`D:7-F:6QE;F%M92`]('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F-O9&EN9R`]("=B
M87-E-C0G*0H@("`@>PH@("`@("`@("1F:6QE9&%T82`]("@D:7-F:6QE;F%M
M92`]/3T@=')U92D@/R`D=&AI<RT^7V9I;&4R<W1R*"1F:6QE*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`D9FEL93L*
M("`@("`@("!I9B`H)&ES9FEL96YA;64@/3T]('1R=64I('L*("`@("`@("`@
M("`@+R\@1F]R8V4@=&AE(&YA;64@=&AE('5S97(@<W5P<&QI960L(&]T:&5R
M=VES92!U<V4@)&9I;&4*("`@("`@("`@("`@)&9I;&5N86UE(#T@*"%E;7!T
M>2@D;F%M92DI(#\@)&YA;64@.B`D9FEL93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9FEL96YA;64@/2`D;F%M93L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H"B`@("`@("`@("`@("`@)U1H92!S=7!P;&EE
M9"!F:6QE;F%M92!F;W(@=&AE(&%T=&%C:&UE;G0@8V%N7"=T(&)E(&5M<'1Y
M)PH@("`@("`@("`@("`I.PH@("`@("`@('T*("`@("`@("`D9FEL96YA;64@
M/2!B87-E;F%M92@D9FEL96YA;64I.PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1F:6QE9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE9&%T
M83L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R='-;72`](&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B;V1Y)R`@("`@
M/3X@)&9I;&5D871A+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`@("`@/3X@)&9I;&5N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C7W1Y<&4G("`@/3X@)&-?='EP92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G96YC;V1I;F<G(#T^("1E;F-O9&EN
M9PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@8V]N
M=&5N=',@;V8@=&AE(&=I=F5N(&9I;&4@;F%M92!A<R!S=')I;F<*("`@("`J
M"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&9I;&5?;F%M92`@<&%T:"!O9B!F
M:6QE('1O('!R;V-E<W,*("`@("`J($!R971U<FX@<W1R:6YG("!C;VYT96YT
M<R!O9B`D9FEL95]N86UE"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@)E]F:6QE,G-T<B@D9FEL95]N86UE*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?<F5A9&%B;&4H)&9I;&5?;F%M92DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9I;&4@:7,@;F]T(')E
M861A8FQE("<@+B`D9FEL95]N86UE*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"$D9F0@/2!F;W!E;B@D9FEL95]N86UE+"`G<F(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&]P96X@)R`N
M("1F:6QE7VYA;64I.PH@("`@("`@('T*("`@("`@("`D9FEL97-I>F4@/2!F
M:6QE<VEZ92@D9FEL95]N86UE*3L*("`@("`@("!I9B`H)&9I;&5S:7IE(#T]
M(#`I>PH@("`@("`@("`@("`D8V]N="`]("`B(CL*("`@("`@("!]96QS97L*
M("`@("`@("`@("`@)&-O;G0@/2!F<F5A9"@D9F0L("1F:6QE<VEZ92D["B`@
M("`@("`@?0H@("`@("`@(&9C;&]S92@D9F0I.PH@("`@("`@(')E='5R;B`D
M8V]N=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!T97AT('-U8G!A
M<G0@=&\@=&AE(&UI;65087)T(&]B:F5C="!A;F0*("`@("`J(')E='5R;G,@
M:70@9'5R:6YG('1H92!B=6EL9"!P<F]C97-S+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`@("!4:&4@;V)J96-T('1O(&%D9"!T:&4@<&%R="!T;RP@
M;W(*("`@("`J("`@("`@("`@("`@("`@("!N=6QL(&EF(&$@;F5W(&]B:F5C
M="!I<R!T;R!B92!C<F5A=&5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`@(%1H
M92!T97AT('1O(&%D9"X*("`@("`J($!R971U<FX@;V)J96-T("!4:&4@=&5X
M="!M:6UE4&%R="!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B`F7V%D9%1E>'1087)T*"8D;V)J+"`D=&5X="D*
M("`@('L*("`@("`@("`D<&%R86US6R=C;VYT96YT7W1Y<&4G72`]("=T97AT
M+W!L86EN)SL*("`@("`@("`D<&%R86US6R=E;F-O9&EN9R==("`@("`]("1T
M:&ES+3Y?8G5I;&1?<&%R86US6R=T97AT7V5N8V]D:6YG)UT["B`@("`@("`@
M)'!A<F%M<ULG8VAA<G-E="==("`@("`@/2`D=&AI<RT^7V)U:6QD7W!A<F%M
M<ULG=&5X=%]C:&%R<V5T)UT["B`@("`@("`@:68@*&ES7V]B:F5C="@D;V)J
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&]B:BT^861D4W5B<&%R="@D=&5X
M="P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!-86EL7VUI;65087)T*"1T97AT+"`D<&%R86US*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@:'1M;"!S=6)P87)T
M('1O('1H92!M:6UE4&%R="!O8FIE8W0@86YD"B`@("`@*B!R971U<FYS(&ET
M(&1U<FEN9R!T:&4@8G5I;&0@<')O8V5S<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@(&UI>&5D("`@5&AE(&]B:F5C="!T;R!A9&0@=&AE('!A<G0@=&\L(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@;G5L;"!I9B!A(&YE=R!O8FIE8W0@
M:7,@=&\@8F4@8W)E871E9"X*("`@("`J($!R971U<FX@;V)J96-T("!4:&4@
M:'1M;"!M:6UE4&%R="!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B`F7V%D9$AT;6Q087)T*"8D;V)J*0H@("`@
M>PH@("`@("`@("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)W1E>'0O:'1M
M;"<["B`@("`@("`@)'!A<F%M<ULG96YC;V1I;F<G72`@("`@/2`D=&AI<RT^
M7V)U:6QD7W!A<F%M<ULG:'1M;%]E;F-O9&EN9R==.PH@("`@("`@("1P87)A
M;7-;)V-H87)S970G72`@("`@(#T@)'1H:7,M/E]B=6EL9%]P87)A;7-;)VAT
M;6Q?8VAA<G-E="==.PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&]B:BDI('L*
M("`@("`@("`@("`@<F5T=7)N("1O8FHM/F%D9%-U8G!A<G0H)'1H:7,M/E]H
M=&UL8F]D>2P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!-86EL7VUI;65087)T*"1T:&ES+3Y?:'1M;&)O9'DL
M("1P87)A;7,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R
M96%T97,@82!N97<@;6EM95!A<G0@;V)J96-T+"!U<VEN9R!M=6QT:7!A<G0O
M;6EX960@87,*("`@("`J('1H92!I;FET:6%L(&-O;G1E;G0M='EP92!A;F0@
M<F5T=7)N<R!I="!D=7)I;F<@=&AE"B`@("`@*B!B=6EL9"!P<F]C97-S+@H@
M("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!4:&4@;75L=&EP87)T+VUI
M>&5D(&UI;65087)T(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9?861D36EX961087)T*"D*("`@('L*("`@
M("`@("`D<&%R86US6R=C;VYT96YT7W1Y<&4G72`]("=M=6QT:7!A<G0O;6EX
M960G.PH@("`@("`@(')E='5R;B!N97<@36%I;%]M:6UE4&%R="@G)RP@)'!A
M<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;75L=&EP87)T
M+V%L=&5R;F%T:79E('!A<G0@=&\@82!M:6UE4&%R=`H@("`@("H@;V)J96-T
M("AO<B!C<F5A=&5S(&]N92DL(&%N9"!R971U<FYS(&ET(&1U<FEN9PH@("`@
M("H@=&AE(&)U:6QD('!R;V-E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M("!M
M:7AE9"`@(%1H92!O8FIE8W0@=&\@861D('1H92!P87)T('1O+"!O<@H@("`@
M("H@("`@("`@("`@("`@("`@(&YU;&P@:68@82!N97<@;V)J96-T(&ES('1O
M(&)E(&-R96%T960N"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&UU;'1I
M<&%R="]M:7AE9"!M:6UE4&%R="!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F7V%D9$%L=&5R;F%T:79E4&%R
M="@F)&]B:BD*("`@('L*("`@("`@("`D<&%R86US6R=C;VYT96YT7W1Y<&4G
M72`]("=M=6QT:7!A<G0O86QT97)N871I=F4G.PH@("`@("`@(&EF("AI<U]O
M8FIE8W0H)&]B:BDI('L*("`@("`@("`@("`@<F5T=7)N("1O8FHM/F%D9%-U
M8G!A<G0H)R<L("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!N97<@36%I;%]M:6UE4&%R="@G)RP@)'!A<F%M<RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&UU;'1I<&%R
M="]R96QA=&5D('!A<G0@=&\@82!M:6UE4&%R=`H@("`@("H@;V)J96-T("AO
M<B!C<F5A=&5S(&]N92DL(&%N9"!R971U<FYS(&ET(&1U<FEN9PH@("`@("H@
M=&AE(&)U:6QD('!R;V-E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("`@(%1H92!O8FIE8W0@=&\@861D('1H92!P87)T('1O+"!O<@H@("`@("H@
M("`@("`@("`@("`@("`@(&YU;&P@:68@82!N97<@;V)J96-T(&ES('1O(&)E
M(&-R96%T960*("`@("`J($!R971U<FX@;V)J96-T("!4:&4@;75L=&EP87)T
M+VUI>&5D(&UI;65087)T(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9?861D4F5L871E9%!A<G0H)B1O8FHI
M"B`@("!["B`@("`@("`@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G;75L
M=&EP87)T+W)E;&%T960G.PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&]B:BDI
M('L*("`@("`@("`@("`@<F5T=7)N("1O8FHM/F%D9%-U8G!A<G0H)R<L("1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N
M97<@36%I;%]M:6UE4&%R="@G)RP@)'!A<F%M<RD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!A;B!H=&UL(&EM86=E('-U8G!A<G0@
M=&\@82!M:6UE4&%R="!O8FIE8W0*("`@("`J(&%N9"!R971U<FYS(&ET(&1U
M<FEN9R!T:&4@8G5I;&0@<')O8V5S<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M(&]B:F5C="`@5&AE(&UI;65087)T('1O(&%D9"!T:&4@:6UA9V4@=&\*("`@
M("`J($!P87)A;2`@87)R87D@("!4:&4@:6UA9V4@:6YF;W)M871I;VX*("`@
M("`J($!R971U<FX@;V)J96-T("!4:&4@:6UA9V4@;6EM95!A<G0@;V)J96-T
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M)E]A9&1(=&UL26UA9V5087)T*"8D;V)J+"`D=F%L=64I"B`@("!["B`@("`@
M("`@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`D=F%L=65;)V-?='EP92==
M.PH@("`@("`@("1P87)A;7-;)V5N8V]D:6YG)UT@("`@(#T@)V)A<V4V-"<[
M"B`@("`@("`@)'!A<F%M<ULG9&ES<&]S:71I;VXG72`@/2`G:6YL:6YE)SL*
M("`@("`@("`D<&%R86US6R=D9FEL96YA;64G72`@("`]("1V86QU95LG;F%M
M92==.PH@("`@("`@("1P87)A;7-;)V-I9"==("`@("`@("`@(#T@)'9A;'5E
M6R=C:60G73L*("`@("`@("`D;V)J+3YA9&13=6)P87)T*"1V86QU95LG8F]D
M>2==+"`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@86X@
M871T86-H;65N="!S=6)P87)T('1O(&$@;6EM95!A<G0@;V)J96-T"B`@("`@
M*B!A;F0@<F5T=7)N<R!I="!D=7)I;F<@=&AE(&)U:6QD('!R;V-E<W,N"B`@
M("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@(%1H92!M:6UE4&%R="!T;R!A
M9&0@=&AE(&EM86=E('1O"B`@("`@*B!`<&%R86T@(&%R<F%Y("`@5&AE(&%T
M=&%C:&UE;G0@:6YF;W)M871I;VX*("`@("`J($!R971U<FX@;V)J96-T("!4
M:&4@:6UA9V4@;6EM95!A<G0@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A9&1!='1A8VAM96YT4&%R="@F
M)&]B:BP@)'9A;'5E*0H@("`@>PH@("`@("`@("1P87)A;7-;)V-O;G1E;G1?
M='EP92==(#T@)'9A;'5E6R=C7W1Y<&4G73L*("`@("`@("`D<&%R86US6R=E
M;F-O9&EN9R==("`@("`]("1V86QU95LG96YC;V1I;F<G73L*("`@("`@("`D
M<&%R86US6R=D:7-P;W-I=&EO;B==("`]("=A='1A8VAM96YT)SL*("`@("`@
M("`D<&%R86US6R=D9FEL96YA;64G72`@("`]("1V86QU95LG;F%M92==.PH@
M("`@("`@("1O8FHM/F%D9%-U8G!A<G0H)'9A;'5E6R=B;V1Y)UTL("1P87)A
M;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S('1H92!M=6QT:7!A
M<G0@;65S<V%G92!F<F]M('1H92!L:7-T("@D=&AI<RT^7W!A<G1S*2!A;F0*
M("`@("`J(')E='5R;G,@=&AE(&UI;64@8V]N=&5N="X*("`@("`J"B`@("`@
M*B!`<&%R86T@(&%R<F%Y("!"=6EL9"!P87)A;65T97)S('1H870@8VAA;F=E
M('1H92!W87D@=&AE(&5M86EL"B`@("`@*B`@("`@("`@("`@("`@("!I<R!B
M=6EL="X@4VAO=6QD(&)E(&%S<V]C:6%T:79E+B!#86X@8V]N=&%I;CH*("`@
M("`J("`@("`@("`@("`@("`@('1E>'1?96YC;V1I;F<@("T@(%=H870@96YC
M;V1I;F<@=&\@=7-E(&9O<B!P;&%I;B!T97AT"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT(&ES(#=B:70*("`@("`J
M("`@("`@("`@("`@("`@(&AT;6Q?96YC;V1I;F<@("T@(%=H870@96YC;V1I
M;F<@=&\@=7-E(&9O<B!H=&UL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!$969A=6QT(&ES('%U;W1E9"UP<FEN=&%B;&4*("`@
M("`J("`@("`@("`@("`@("`@(#=B:71?=W)A<"`@("`@("T@($YU;6)E<B!O
M9B!C:&%R86-T97)S(&)E9F]R92!T97AT(&ES"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!W<F%P<&5D(&EN(#=B:70@96YC;V1I
M;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E
M9F%U;'0@:7,@.3DX"B`@("`@*B`@("`@("`@("`@("`@("!H=&UL7V-H87)S
M970@("`M("!4:&4@8VAA<F%C=&5R('-E="!T;R!U<V4@9F]R(&AT;6PN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT
M(&ES(&ES;RTX.#4Y+3$*("`@("`J("`@("`@("`@("`@("`@('1E>'1?8VAA
M<G-E="`@("T@(%1H92!C:&%R86-T97(@<V5T('1O('5S92!F;W(@=&5X="X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U
M;'0@:7,@:7-O+3@X-3DM,0H@("`@("H@("`@("`@("`@("`@("`@:&5A9%]C
M:&%R<V5T("`@+2`@5&AE(&-H87)A8W1E<B!S970@=&\@=7-E(&9O<B!H96%D
M97)S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1&5F875L="!I<R!I<V\M.#@U.2TQ"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4
M:&4@;6EM92!C;VYT96YT"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B`F9V5T*"1B=6EL9%]P87)A;7,@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D8G5I;&1?<&%R86US*2D@>PH@("`@("`@
M("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L=64I(#T@96%C:"@D8G5I;&1?
M<&%R86US*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B=6EL9%]P87)A
M;7-;)&ME>5T@/2`D=F%L=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]H=&UL7VEM86=E<RD@04Y$(&ES
M<V5T*"1T:&ES+3Y?:'1M;&)O9'DI*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?:'1M;%]I;6%G97,@87,@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("`D<F5G97@@/2`G(RA<<RDH*#]I*7-R8WQB86-K9W)O=6YD?&AR968H
M/RUI*2E<<RH]7',J*%LB7"==/RDG("X@<')E9U]Q=6]T92@D=F%L=65;)VYA
M;64G72P@)R,G*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`G7#,C)SL*
M("`@("`@("`@("`@("`@("1R97`@/2`G7#%<,CU<,V-I9#HG("X@)'9A;'5E
M6R=C:60G72`N)UPS)SL*("`@("`@("`@("`@("`@("1T:&ES+3Y?:'1M;&)O
M9'D@/2!P<F5G7W)E<&QA8V4H)')E9V5X+"`D<F5P+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VAT;6QB;V1Y"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&YU;&P@("`@("`@(#T@;G5L;#L*
M("`@("`@("`D871T86-H;65N=',@/2`A96UP='DH)'1H:7,M/E]P87)T<RD@
M("`@("`@("`@("`@("`@/R!T<G5E(#H@9F%L<V4["B`@("`@("`@)&AT;6Q?
M:6UA9V5S(#T@(65M<'1Y*"1T:&ES+3Y?:'1M;%]I;6%G97,I("`@("`@("`@
M(#\@=')U92`Z(&9A;'-E.PH@("`@("`@("1H=&UL("`@("`@("`]("%E;7!T
M>2@D=&AI<RT^7VAT;6QB;V1Y*2`@("`@("`@("`@("`_('1R=64@.B!F86QS
M93L*("`@("`@("`D=&5X="`@("`@("`@/2`H(21H=&UL($%.1"`A96UP='DH
M)'1H:7,M/E]T>'1B;V1Y*2D@/R!T<G5E(#H@9F%L<V4["@H@("`@("`@('-W
M:71C:"`H=')U92D@>PH@("`@("`@(&-A<V4@)'1E>'0@04Y$("$D871T86-H
M;65N=',Z"B`@("`@("`@("`@("1M97-S86=E(#TF("1T:&ES+3Y?861D5&5X
M=%!A<G0H)&YU;&PL("1T:&ES+3Y?='AT8F]D>2D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("$D=&5X="!!3D0@(21H=&UL($%.1"`D871T
M86-H;65N=',Z"B`@("`@("`@("`@("1M97-S86=E(#TF("1T:&ES+3Y?861D
M36EX961087)T*"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O
M=6YT*"1T:&ES+3Y?<&%R=',I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%D9$%T=&%C:&UE;G1087)T*"1M97-S86=E+"`D=&AI<RT^7W!A
M<G1S6R1I72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)'1E>'0@04Y$("1A='1A8VAM96YT<SH*("`@("`@("`@
M("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1-:7AE9%!A<G0H*3L*("`@("`@
M("`@("`@)'1H:7,M/E]A9&1497AT4&%R="@D;65S<V%G92P@)'1H:7,M/E]T
M>'1B;V1Y*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H
M)'1H:7,M/E]P87)T<RD[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?861D071T86-H;65N=%!A<G0H)&UE<W-A9V4L("1T:&ES+3Y?<&%R='-;
M)&E=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`D:'1M;"!!3D0@(21A='1A8VAM96YT<R!!3D0@(21H=&UL7VEM
M86=E<SH*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?='AT8F]D>2DI
M('L*("`@("`@("`@("`@("`@("1M97-S86=E(#TF("1T:&ES+3Y?861D06QT
M97)N871I=F5087)T*"1N=6QL*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D5&5X=%!A<G0H)&UE<W-A9V4L("1T:&ES+3Y?='AT8F]D>2D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9$AT;6Q087)T*"1M97-S86=E*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M97-S86=E(#TF
M("1T:&ES+3Y?861D2'1M;%!A<G0H)&YU;&PI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("1H=&UL($%.1"`A)&%T
M=&%C:&UE;G1S($%.1"`D:'1M;%]I;6%G97,Z"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W1X=&)O9'DI*2!["B`@("`@("`@("`@("`@("`D;65S
M<V%G92`])B`D=&AI<RT^7V%D9$%L=&5R;F%T:79E4&%R="@D;G5L;"D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D9%1E>'1087)T*"1M97-S86=E+"`D
M=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@("`@("`@)')E;&%T960@/28@
M)'1H:7,M/E]A9&1296QA=&5D4&%R="@D;65S<V%G92D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^
M7V%D9%)E;&%T961087)T*"1N=6QL*3L*("`@("`@("`@("`@("`@("1R96QA
M=&5D(#TF("1M97-S86=E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T
M:&ES+3Y?861D2'1M;%!A<G0H)')E;&%T960I.PH@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7VAT;6Q?:6UA9V5S*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1(=&UL26UA9V5087)T
M*"1R96QA=&5D+"`D=&AI<RT^7VAT;6Q?:6UA9V5S6R1I72D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)&AT;6P@
M04Y$("1A='1A8VAM96YT<R!!3D0@(21H=&UL7VEM86=E<SH*("`@("`@("`@
M("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1-:7AE9%!A<G0H*3L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?='AT8F]D>2DI('L*("`@("`@("`@
M("`@("`@("1A;'0@/28@)'1H:7,M/E]A9&1!;'1E<FYA=&EV95!A<G0H)&UE
M<W-A9V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1497AT4&%R="@D
M86QT+"`D=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A9&1(=&UL4&%R="@D86QT*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?861D2'1M;%!A<G0H)&UE<W-A9V4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O
M=6YT*"1T:&ES+3Y?<&%R=',I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%D9$%T=&%C:&UE;G1087)T*"1M97-S86=E+"`D=&AI<RT^7W!A
M<G1S6R1I72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)&AT;6P@04Y$("1A='1A8VAM96YT<R!!3D0@)&AT;6Q?
M:6UA9V5S.@H@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D9$UI
M>&5D4&%R="@I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T>'1B
M;V1Y*2D@>PH@("`@("`@("`@("`@("`@)&%L="`])B`D=&AI<RT^7V%D9$%L
M=&5R;F%T:79E4&%R="@D;65S<V%G92D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%D9%1E>'1087)T*"1A;'0L("1T:&ES+3Y?='AT8F]D>2D["B`@("`@
M("`@("`@("`@("`D<F5L(#TF("1T:&ES+3Y?861D4F5L871E9%!A<G0H)&%L
M="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5L
M(#TF("1T:&ES+3Y?861D4F5L871E9%!A<G0H)&UE<W-A9V4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?861D2'1M;%!A<G0H)')E;"D[
M"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?
M:'1M;%]I;6%G97,I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%D9$AT;6Q);6%G95!A<G0H)')E;"P@)'1H:7,M/E]H=&UL7VEM86=E<ULD
M:5TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1T:&ES+3Y?<&%R=',I.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V%D9$%T=&%C:&UE;G1087)T*"1M97-S86=E+"`D=&AI
M<RT^7W!A<G1S6R1I72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1M97-S86=E*2D@
M>PH@("`@("`@("`@("`D;W5T<'5T(#T@)&UE<W-A9V4M/F5N8V]D92@I.PH@
M("`@("`@("`@("`D=&AI<RT^7VAE861E<G,@/2!A<G)A>5]M97)G92@D=&AI
M<RT^7VAE861E<G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=71;)VAE861E<G,G72D["B`@("`@("`@("`@(')E
M='5R;B`D;W5T<'5T6R=B;V1Y)UT["@H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y('=I=&@@=&AE(&AE861E<G,@;F5E
M9&5D('1O('!R97!E;F0@=&\@=&AE(&5M86EL"B`@("`@*B`H34E-12U697)S
M:6]N(&%N9"!#;VYT96YT+51Y<&4I+B!&;W)M870@;V8@87)G=6UE;G0@:7,Z
M"B`@("`@*B`D87)R87E;)VAE861E<BUN86UE)UT@/2`G:&5A9&5R+79A;'5E
M)SL*("`@("`J"B`@("`@*B!`<&%R86T@(&%R<F%Y("1X=')A7VAE861E<G,@
M07-S;V,@87)R87D@=VET:"!A;GD@97AT<F$@:&5A9&5R<RX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!/<'1I;VYA;"X*("`@("`J($!R
M971U<FX@87)R87D@07-S;V,@87)R87D@=VET:"!T:&4@;6EM92!H96%D97)S
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F
M:&5A9&5R<R@D>'1R85]H96%D97)S(#T@;G5L;"D*("`@('L*("`@("`@("`O
M+R!#;VYT96YT+51Y<&4@:&5A9&5R('-H;W5L9"!A;')E861Y(&)E('!R97-E
M;G0L"B`@("`@("`@+R\@4V\@:G5S="!A9&0@;6EM92!V97)S:6]N(&AE861E
M<@H@("`@("`@("1H96%D97)S6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH@
M("`@("`@(&EF("AI<W-E="@D>'1R85]H96%D97)S*2D@>PH@("`@("`@("`@
M("`D:&5A9&5R<R`](&%R<F%Y7VUE<F=E*"1H96%D97)S+"`D>'1R85]H96%D
M97)S*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]H96%D97)S(#T@87)R
M87E?;65R9V4H)&AE861E<G,L("1T:&ES+3Y?:&5A9&5R<RD["@H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V5N8V]D94AE861E<G,H)'1H:7,M/E]H96%D97)S
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@=&5X="!V97)S:6]N
M(&]F('1H92!H96%D97)S"B`@("`@*B`H=7-E9G5L;"!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AE(%!(4"!M86EL*"D@9G5N8W1I;VXI"B`@("`@*@H@("`@("H@
M0'!A<F%M("!A<G)A>2`@("1X=')A7VAE861E<G,@07-S;V,@87)R87D@=VET
M:"!A;GD@97AT<F$@:&5A9&5R<RX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($]P=&EO;F%L+@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%!L86EN('1E>'0@:&5A9&5R<PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@='AT2&5A9&5R<R@D>'1R85]H96%D97)S(#T@
M;G5L;"D*("`@('L*("`@("`@("`D:&5A9&5R<R`]("1T:&ES+3YH96%D97)S
M*"1X=')A7VAE861E<G,I.PH@("`@("`@("1R970@/2`G)SL*("`@("`@("!F
M;W)E86-H("@D:&5A9&5R<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@)')E="`N/2`B)&ME>3H@)'9A;"(@+B!-04E,7TU)345?0U),1CL*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!3=6)J96-T(&AE861E<@H@("`@("H*("`@("`J($!P
M87)A;2`@<W1R:6YG("1S=6)J96-T(%-T<FEN9R!T;R!S970@=&AE('-U8FIE
M8W0@=&\*("`@("`J(&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%-U8FIE8W0H)'-U8FIE8W0I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]H96%D97)S6R=3=6)J96-T)UT@/2`D<W5B:F5C=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!A;B!E;6%I;"!T;R!T:&4@1G)O;2`H=&AE('-E;F1E
M<BD@:&5A9&5R"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&5M86EL
M(%1H92!E;6%I;"!D:7)E8W1I;VX@=&\@861D"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&<F]M*"1E;6%I;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7VAE861E<G-;)T9R;VTG72`]("1E;6%I;#L*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;B!E;6%I;"!T;R!T:&4@0V,@
M*&-A<F)O;B!C;W!Y*2!H96%D97(*("`@("`J("AM=6QT:7!L92!C86QL<R!T
M;R!T:&ES(&UE=&AO9"!A<F4@86QL;W=E9"D*("`@("`J"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`D96UA:6P@5&AE(&5M86EL(&1I<F5C=&EO;B!T;R!A9&0*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$-C*"1E;6%I;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]H
M96%D97)S6R=#8R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;
M)T-C)UT@+CT@(BP@)&5M86EL(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7VAE861E<G-;)T-C)UT@/2`D96UA:6P["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&%N(&5M86EL('1O('1H92!"
M8V,@*&)L86YK(&-A<F)O;B!C;W!Y*2!H96%D97(*("`@("`J("AM=6QT:7!L
M92!C86QL<R!T;R!T:&ES(&UE=&AO9"!A<F4@86QL;W=E9"D*("`@("`J"B`@
M("`@*B!`<&%R86T@('-T<FEN9R`D96UA:6P@5&AE(&5M86EL(&1I<F5C=&EO
M;B!T;R!A9&0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$)C8R@D96UA:6PI"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?:&5A9&5R<ULG0F-C)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?:&5A9&5R<ULG0F-C)UT@+CT@(BP@)&5M86EL(CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)T)C8R==(#T@)&5M
M86EL.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5N8V]D97,@
M82!H96%D97(@87,@<&5R(%)&0S(P-#<*("`@("`J"B`@("`@*B!`<&%R86T@
M('-T<FEN9R`@)&EN<'5T(%1H92!H96%D97(@9&%T82!T;R!E;F-O9&4*("`@
M("`J($!R971U<FX@<W1R:6YG("!%;F-O9&5D(&1A=&$*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC;V1E2&5A9&5R
M<R@D:6YP=70I"B`@("!["B`@("`@("`@9F]R96%C:"`H)&EN<'5T(&%S("1H
M9')?;F%M92`]/B`D:&1R7W9A;'5E*2!["B`@("`@("`@("`@('!R96=?;6%T
M8VA?86QL*"<O*%QW*EM<>#@P+5QX1D9=*UQW*BDO)RP@)&AD<E]V86QU92P@
M)&UA=&-H97,I.PH@("`@("`@("`@("!F;W)E86-H("@D;6%T8VAE<ULQ72!A
M<R`D=F%L=64I('L*("`@("`@("`@("`@("`@("1R97!L86-E;65N="`]('!R
M96=?<F5P;&%C92@G+RA;7'@X,"U<>$9&72DO92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(](B`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]U<'!E
M<BAD96-H97@H;W)D*")<,2(I*2DG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QU92D["B`@("`@("`@("`@("`@
M("`D:&1R7W9A;'5E(#T@<W1R7W)E<&QA8V4H)'9A;'5E+"`G/3\G("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V)U:6QD7W!A<F%M<ULG:&5A9%]C:&%R<V5T)UT@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<_43\G("X@)')E<&QA8V5M
M96YT("X@)S\])RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:&1R7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D:6YP=71;)&AD<E]N86UE72`]("1H9')?=F%L=64["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&EN<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!O8FIE8W0G<R!E;F0M;V8M;&EN92!A;F0@9&5F:6YE('1H92!C
M;VYS=&%N="!I9B!A<'!L:6-A8FQE"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D96]L($5N9"!/9B!,:6YE('-E<75E;F-E"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$5/3"@D96]L*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?96]L(#T@)&5O;#L*("`@("`@("!I9B`H
M(61E9FEN960H)TU!24Q?34E-15]#4DQ&)RDI('L*("`@("`@("`@("`@9&5F
M:6YE*"=-04E,7TU)345?0U),1B<L("1T:&ES+3Y?96]L+"!T<G5E*3L*("`@
M("`@("!]"B`@("!]"@H@("`@"@I]("\O($5N9"!O9B!C;&%S<PH_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL+VUA
M:6PN<&AP````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,3<S-P`Q,#4Q-30S,3`U-P`P,3<V-C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\*+R\@)$ED.B!M86EL+G!H<"QV(#$N,34@,C`P-2\Q,"\Q,"`P-#HQ
M-CHR-B!J;VX@17AP("0*"B\J*@H@*B!I;G1E<FYA;"!02%`M;6%I;"@I(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!014%2($UA:6PZ.B!I;G1E<F9A8V4N"B`J
M($!P86-K86=E($UA:6P*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C$U("0*
M("HO"F-L87-S($UA:6Q?;6%I;"!E>'1E;F1S($UA:6P@>PH*("`@("\J*@H@
M("`@("H@06YY(&%R9W5M96YT<R!T;R!P87-S('1O('1H92!M86EL*"D@9G5N
M8W1I;VXN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P
M87)A;7,@/2`G)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($EN<W1A;G1I871E<R!A(&YE=R!-86EL7VUA:6PZ.B!O8FIE
M8W0@8F%S960@;VX@=&AE('!A<F%M971E<G,*("`@("`J('!A<W-E9"!I;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R!%>'1R82!A<F=U
M;65N=',@9F]R('1H92!M86EL*"D@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N($UA:6Q?;6%I;"@D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("`O*B!4:&4@;W1H97(@;6%I;"!I;7!L96UE;G1A=&EO;G,@86-C97!T('!A
M<F%M971E<G,@87,@87)R87ES+@H@("`@("`@("`J($EN('1H92!I;G1E<F5S
M="!O9B!B96EN9R!C;VYS:7-T96YT+"!E>'!L;V1E(&%N(&%R<F%Y(&EN=&\*
M("`@("`@("`@*B!A('-T<FEN9R!O9B!P87)A;65T97(@87)G=6UE;G1S+B`J
M+PH@("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`](&IO:6XH)R`G+"`D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A
M;7,["B`@("`@("`@?0H*("`@("`@("`O*B!"96-A=7-E('1H92!M86EL*"D@
M9G5N8W1I;VX@;6%Y('!A<W,@:&5A9&5R<R!A<R!C;VUM86YD"B`@("`@("`@
M("H@;&EN92!A<F=U;65N=',L('=E(&-A;B=T(&=U87)A;G1E92!T:&4@=7-E
M(&]F('1H92!S=&%N9&%R9`H@("`@("`@("`J(")<<EQN(B!S97!A<F%T;W(N
M("!);G-T96%D+"!W92!U<V4@=&AE('-Y<W1E;2=S(&YA=&EV92!L:6YE"B`@
M("`@("`@("H@<V5P87)A=&]R+B`J+PH@("`@("`@(&EF("AD969I;F5D*%!(
M4%]%3TPI*2!["B`@("`@("`@("`@("1T:&ES+3YS97`@/2!02%!?14],.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS97`@/2`H<W1R
M<&]S*%!(4%]/4RP@)U=)3B<I(#T]/2!F86QS92D@/R`B7&XB(#H@(EQR7&XB
M.PH@("`@("`@('T*("`@('T*"@DO*BH*("`@("`J($EM<&QE;65N=',@36%I
M;%]M86EL.CIS96YD*"D@9G5N8W1I;VX@=7-I;F<@<&AP)W,@8G5I;'0M:6X@
M;6%I;"@I"B`@("`@*B!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D<F5C:7!I96YT<R!%:71H97(@82!C;VUM82US97!E<F%T960@;&ES
M="!O9B!R96-I<&EE;G1S"B`@("`@*B`@("`@("`@("`@("`@*%)&0S@R,B!C
M;VUP;&EA;G0I+"!O<B!A;B!A<G)A>2!O9B!R96-I<&EE;G1S+`H@("`@("H@
M("`@("`@("`@("`@(&5A8V@@4D9#.#(R('9A;&ED+B!4:&ES(&UA>2!C;VYT
M86EN(')E8VEP:65N=',@;F]T"B`@("`@*B`@("`@("`@("`@("`@<W!E8VEF
M:65D(&EN('1H92!H96%D97)S+"!F;W(@0F-C.BP@<F5S96YD:6YG"B`@("`@
M*B`@("`@("`@("`@("`@;65S<V%G97,L(&5T8RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&AE861E<G,@5&AE(&%R<F%Y(&]F(&AE861E<G,@=&\@
M<V5N9"!W:71H('1H92!M86EL+"!I;B!A;@H@("`@("H@("`@("`@("`@("`@
M(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T:&4@87)R87D@:V5Y(&ES('1H
M90H@("`@("H@("`@("`@("`@("`@(&AE861E<B!N86UE("AI92P@)U-U8FIE
M8W0G*2P@86YD('1H92!A<G)A>2!V86QU90H@("`@("H@("`@("`@("`@("`@
M(&ES('1H92!H96%D97(@=F%L=64@*&EE+"`G=&5S="<I+B!4:&4@:&5A9&5R
M"B`@("`@*B`@("`@("`@("`@("`@<')O9'5C960@9G)O;2!T:&]S92!V86QU
M97,@=V]U;&0@8F4@)U-U8FIE8W0Z"B`@("`@*B`@("`@("`@("`@("`@=&5S
M="<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]D>2!4:&4@9G5L
M;"!T97AT(&]F('1H92!M97-S86=E(&)O9'DL(&EN8VQU9&EN9R!A;GD*("`@
M("`J("`@("`@("`@("`@("`@36EM92!P87)T<RP@971C+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(&]R
M(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("!C;VYT86EN:6YG
M(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S<V%G92!O;@H@("`@("H@("`@("`@
M("`@("`@("!F86EL=7)E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H96%D
M97)S+"`D8F]D>2D*("`@('L*("`@("`@("`O+R!)9B!W92=R92!P87-S960@
M86X@87)R87D@;V8@<F5C:7!I96YT<RP@:6UP;&]D92!I="X*("`@("`@("!I
M9B`H:7-?87)R87DH)')E8VEP:65N=',I*2!["B`@("`@("`@("`@("1R96-I
M<&EE;G1S(#T@:6UP;&]D92@G+"`G+"`D<F5C:7!I96YT<RD["B`@("`@("`@
M?0H*("`@("`@("`O+R!'970@=&AE(%-U8FIE8W0@;W5T(&]F('1H92!H96%D
M97)S(&%R<F%Y('-O('1H870@=V4@8V%N"B`@("`@("`@+R\@<&%S<R!I="!A
M<R!A('-E<&5R871E(&%R9W5M96YT('1O(&UA:6PH*2X*("`@("`@("`D<W5B
M:F5C="`]("<G.PH@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG4W5B:F5C
M="==*2D@>PH@("`@("`@("`@("`D<W5B:F5C="`]("1H96%D97)S6R=3=6)J
M96-T)UT["B`@("`@("`@("`@('5N<V5T*"1H96%D97)S6R=3=6)J96-T)UTI
M.PH@("`@("`@('T*"B`@("`@("`@+R\@1FQA='1E;B!T:&4@:&5A9&5R<R!O
M=70N"B`@("`@("`@)&AE861E<D5L96UE;G1S(#T@)'1H:7,M/G!R97!A<F5(
M96%D97)S*"1H96%D97)S*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M:&5A9&5R16QE;65N=',I*2!["B`@("`@("`@("`@(')E='5R;B`D:&5A9&5R
M16QE;65N=',["B`@("`@("`@?0H@("`@("`@(&QI<W0H+"`D=&5X=%]H96%D
M97)S*2`]("1H96%D97)%;&5M96YT<SL*"B`@("`@("`@+RH*("`@("`@("`@
M*B!792!O;FQY('5S92!M86EL*"DG<R!O<'1I;VYA;"!F:69T:"!P87)A;65T
M97(@:68@=&AE(&%D9&ET:6]N86P*("`@("`@("`@*B!P87)A;65T97)S(&AA
M=F4@8F5E;B!P<F]V:61E9"!A;F0@=V4G<F4@;F]T(')U;FYI;F<@:6X@<V%F
M92!M;V1E+@H@("`@("`@("`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M7W!A<F%M<RD@?'P@:6YI7V=E="@G<V%F95]M;V1E)RDI('L*("`@("`@("`@
M("`@)')E<W5L="`](&UA:6PH)')E8VEP:65N=',L("1S=6)J96-T+"`D8F]D
M>2P@)'1E>'1?:&5A9&5R<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E<W5L="`](&UA:6PH)')E8VEP:65N=',L("1S=6)J96-T+"`D8F]D
M>2P@)'1E>'1?:&5A9&5R<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@
M("`@*B!)9B!T:&4@;6%I;"@I(&9U;F-T:6]N(')E='5R;F5D(&9A:6QU<F4L
M('=E(&YE960@=&\@8W)E871E(&$*("`@("`@("`@*B!014%27T5R<F]R(&]B
M:F5C="!A;F0@<F5T=7)N(&ET(&EN<W1E860@;V8@=&AE(&)O;VQE86X@<F5S
M=6QT+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D<F5S=6QT(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M;6%I;"@I(')E='5R;F5D(&9A:6QU<F4G*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@?0H*?0H`````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M36%I;"]N=6QL+G!H<```````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#0W-S$`,3`U,34T,S$P-3<`,#$W-S$W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\O"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\
M"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L
M92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<CH@4&AI;"!+97)N:6-K(#QP:&EL:T!R;W1F;"YC;VTN874^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@;G5L;"YP:'`L=B`Q+C(@,C`P-"\P-"\P
M-B`P-3HQ.3HP,R!J;VX@17AP("0*+R\*"B\J*@H@*B!.=6QL(&EM<&QE;65N
M=&%T:6]N(&]F('1H92!014%2($UA:6PZ.B!I;G1E<F9A8V4N"B`J($!A8V-E
M<W,@<'5B;&EC"B`J($!P86-K86=E($UA:6P*("H@0'9E<G-I;VX@)%)E=FES
M:6]N.B`Q+C(@)`H@*B\*8VQA<W,@36%I;%]N=6QL(&5X=&5N9',@36%I;"![
M"@H@("`@+RHJ"B`@("`@*B!);7!L96UE;G1S($UA:6Q?;G5L;#HZ<V5N9"@I
M(&9U;F-T:6]N+B!3:6QE;G1L>2!D:7-C87)D<R!A;&P*("`@("`J(&UA:6PN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1R96-I<&EE;G1S($5I=&AE
M<B!A(&-O;6UA+7-E<&5R871E9"!L:7-T(&]F(')E8VEP:65N=',*("`@("`J
M("`@("`@("`@("`@("`H4D9#.#(R(&-O;7!L:6%N="DL(&]R(&%N(&%R<F%Y
M(&]F(')E8VEP:65N=',L"B`@("`@*B`@("`@("`@("`@("`@96%C:"!21D,X
M,C(@=F%L:60N(%1H:7,@;6%Y(&-O;G1A:6X@<F5C:7!I96YT<R!N;W0*("`@
M("`J("`@("`@("`@("`@("!S<&5C:69I960@:6X@=&AE(&AE861E<G,L(&9O
M<B!"8V,Z+"!R97-E;F1I;F<*("`@("`J("`@("`@("`@("`@("!M97-S86=E
M<RP@971C+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D:&5A9&5R<R!4
M:&4@87)R87D@;V8@:&5A9&5R<R!T;R!S96YD('=I=&@@=&AE(&UA:6PL(&EN
M(&%N"B`@("`@*B`@("`@("`@("`@("`@87-S;V-I871I=F4@87)R87DL('=H
M97)E('1H92!A<G)A>2!K97D@:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M:&5A9&5R(&YA;64@*&EE+"`G4W5B:F5C="<I+"!A;F0@=&AE(&%R<F%Y('9A
M;'5E"B`@("`@*B`@("`@("`@("`@("`@:7,@=&AE(&AE861E<B!V86QU92`H
M:64L("=T97-T)RDN(%1H92!H96%D97(*("`@("`J("`@("`@("`@("`@("!P
M<F]D=6-E9"!F<F]M('1H;W-E('9A;'5E<R!W;W5L9"!B92`G4W5B:F5C=#H*
M("`@("`J("`@("`@("`@("`@("!T97-T)RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1B;V1Y(%1H92!F=6QL('1E>'0@;V8@=&AE(&UE<W-A9V4@
M8F]D>2P@:6YC;'5D:6YG(&%N>0H@("`@("H@("`@("`@("`@("`@("!-:6UE
M('!A<G1S+"!E=&,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U
M<FYS('1R=64@;VX@<W5C8V5S<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@
M("`@("`@("`@("`@(&-O;G1A:6YI;F<@82!D97-C<FEP=&EV92!E<G)O<B!M
M97-S86=E(&]N"B`@("`@*B`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96YD*"1R
M96-I<&EE;G1S+"`D:&5A9&5R<RP@)&)O9'DI"B`@("!["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@I]"@`````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O3F5T+P``````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$V,#<R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O1E10+P``````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,3`U-P`P,38U,C,`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+TYE="]&5%`O3V)S97)V97(N<&AP````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`U-C(R`#$P-3$U-#,Q,#4W`#`R,3`R-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-#H@*B\*"B\J*@H@*B!.971?1E10(&]B<V5R=F5R+@H@*@H@*B!4
M:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($]B<V5R=F5R('!A<G0@;V8@82!3
M=6)J96-T+4]B<V5R=F5R"B`J(&1E<VEG;B!P871T97)N+B!)="!L:7-T96YS
M('1O('1H92!E=F5N=',@<V5N="!B>2!A($YE=%]&5%`@:6YS=&%N8V4N"B`J
M(%1H:7,@;6]D=6QE(&AA9"!M86YY(&EN9FQU96YC97,@9G)O;2!T:&4@3&]G
M7V]B<V5R=F5R(&-O9&4N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!.971W;W)K:6YG"B`J($!P86-K86=E("`@
M($944`H@*B!`875T:&]R("`@("!4;V)I87,@4V-H;&ET="`\=&]B>4!P:'`N
M;F5T/@H@*B!`875T:&]R("`@("!,875R96YT($QA=FEL;&4@/'!E87)`;&%U
M<F5N="UL879I;&QE+F]R9SX*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@3V)S97)V97(N<&AP+'8@,2XR(#(P,#4O,#(O
M,C,@,3(Z,3(Z,C,@=&]B>2!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O3F5T7T944`H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,"XQ"B`J+PH*+RHJ"B`J
M(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4@3V)S97)V97(@<&%R="!O9B!A
M(%-U8FIE8W0M3V)S97)V97(*("H@9&5S:6=N('!A='1E<FXN($ET(&QI<W1E
M;G,@=&\@=&AE(&5V96YT<R!S96YT(&)Y(&$@3F5T7T944"!I;G-T86YC92X*
M("H@5&AI<R!M;V1U;&4@:&%D(&UA;GD@:6YF;'5E;F-E<R!F<F]M('1H92!,
M;V=?;V)S97)V97(@8V]D92X*("H*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J
M($!C871E9V]R>2`@($YE='=O<FMI;F<*("H@0'!A8VMA9V4@("`@1E10"B`J
M($!A=71H;W(@("`@($QA=7)E;G0@3&%V:6QL92`\<&5A<D!L875R96YT+6QA
M=FEL;&4N;W)G/@H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@("`@5&]B:6%S(%-C:&QI='0@
M/'1O8GE`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!0
M2%`@1W)O=7`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C$*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TYE=%]&5%`*
M("H@0'-I;F-E("`@("`@,2XS+C`N,`H@*B!`86-C97-S("`@("!P=6)L:6,*
M("H*("H@0&5X86UP;&4@("`@;V)S97)V97)?=7!L;V%D+G!H<"`@("`@("`@
M("!!;B!E>&%M<&QE(&]F($YE=%]&5%!?3V)S97)V97(@:6UP;&5M96YT871I
M;VXN"B`J+PIC;&%S<R!.971?1E107T]B<V5R=F5R"GL*("`@("\J*@H@("`@
M("H@26YS=&%N8V4M<W!E8VEF:6,@=6YI<75E(&ED96YT:69I8V%T:6]N(&YU
M;6)E<BX*("`@("`J"B`@("`@*B!`=F%R("`@("`@("!I;G1E9V5R"B`@("`@
M*B!`<VEN8V4@("`@("`Q+C,N,`H@("`@("H@0&%C8V5S<R`@("`@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]I9#L*"B`@("`O*BH*("`@("`J($-R96%T
M97,@82!N97<@8F%S:6,@3F5T7T944%]/8G-E<G9E<B!I;G-T86YC92X*("`@
M("`J"B`@("`@*B!`<VEN8V4@("`@("`Q+C,N,`H@("`@("H@0&%C8V5S<R`@
M("`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%]&5%!?3V)S97)V
M97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE
M*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES=&5N
M97(G<R!I9&5N=&EF:65R"B`@("`@*@H@("`@("H@0')E='5R;B`@("`@<W1R
M:6YG"B`@("`@*B!`<VEN8V4@("`@("`Q+C,N,`H@("`@("H@0&%C8V5S<R`@
M("`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$ED*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]I9#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@:7,@82!S='5B(&UE=&AO9"!T;R!M86ME('-U<F4@=&AA="!.
M971?1E107T]B<V5R=F5R(&-L87-S97,@9&\*("`@("`J('-O;65T:&EN9R!W
M:&5N('1H97D@87)E(&YO=&EF:65D(&]F(&$@;65S<V%G92X@(%1H92!D969A
M=6QT(&)E:&%V:6]R"B`@("`@*B!I<R!T;R!J=7-T(&1O(&YO=&AI;F<N"B`@
M("`@*B!9;W4@<VAO=6QD(&]V97)R:61E('1H:7,@;65T:&]D+@H@("`@("H*
M("`@("`J($!P87)A;2`@("`@(&UI>&5D("`@("`D979E;G0@("`@("`@("!!
M(&AA<V@@9&5S8W)I8FEN9R!T:&4@;F5T(&5V96YT+@H@("`@("H*("`@("`J
M($!S:6YC92`@("`@(#$N,RXP"B`@("`@*B!`86-C97-S("`@("!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@;F]T:69Y*"1E=F5N="D*("`@('L*("`@
M("`@("!R971U<FX["B`@("!]"GT*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+U-O8VME="YP:'``
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S4W-S4`
M,3`U,34T,S$P-3<`,#(P,#4Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-T:6<@0F%K
M:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"`@("`@("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(%-O8VME="YP
M:'`L=B`Q+C(T(#(P,#4O,#(O,#,@,C`Z-#`Z,38@8VAA9V5N8G4@17AP("0*
M"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*9&5F:6YE*"=.151?4T]#2T54
M7U)%040G+"`@,2D["F1E9FEN92@G3D547U-/0TM%5%]74DE412<L(#(I.PID
M969I;F4H)TY%5%]33T-+151?15)23U(G+"`S*3L*"B\J*@H@*B!'96YE<F%L
M:7IE9"!3;V-K970@8VQA<W,N"B`J"B`J($!V97)S:6]N(#$N,0H@*B!`875T
M:&]R(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("HO"F-L87-S($YE=%]3
M;V-K970@97AT96YD<R!014%2('L*"B`@("`O*BH*("`@("`J(%-O8VME="!F
M:6QE('!O:6YT97(N"B`@("`@*B!`=F%R(')E<V]U<F-E("1F<`H@("`@("HO
M"B`@("!V87(@)&9P(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%=H971H97(@
M=&AE('-O8VME="!I<R!B;&]C:VEN9RX@1&5F875L=',@=&\@=')U92X*("`@
M("`J($!V87(@8F]O;&5A;B`D8FQO8VMI;F<*("`@("`J+PH@("`@=F%R("1B
M;&]C:VEN9R`]('1R=64["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H92!S
M;V-K970@:7,@<&5R<VES=&5N="X@1&5F875L=',@=&\@9F%L<V4N"B`@("`@
M*B!`=F%R(&)O;VQE86X@)'!E<G-I<W1E;G0*("`@("`J+PH@("`@=F%R("1P
M97)S:7-T96YT(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@25`@861D
M<F5S<R!T;R!C;VYN96-T('1O+@H@("`@("H@0'9A<B!S=')I;F<@)&%D9'(*
M("`@("`J+PH@("`@=F%R("1A9&1R(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<&]R="!N=6UB97(@=&\@8V]N;F5C="!T;RX*("`@("`J($!V87(@:6YT
M96=E<B`D<&]R=`H@("`@("HO"B`@("!V87(@)'!O<G0@/2`P.PH*("`@("\J
M*@H@("`@("H@3G5M8F5R(&]F('-E8V]N9',@=&\@=V%I="!O;B!S;V-K970@
M8V]N;F5C=&EO;G,@8F5F;W)E(&%S<W5M:6YG"B`@("`@*B!T:&5R92=S(&YO
M(&UO<F4@9&%T82X@1&5F875L=',@=&\@;F\@=&EM96]U="X*("`@("`J($!V
M87(@:6YT96=E<B`D=&EM96]U=`H@("`@("HO"B`@("!V87(@)'1I;65O=70@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O9B!B>71E<R!T;R!R
M96%D(&%T(&$@=&EM92!I;B!R96%D3&EN92@I(&%N9`H@("`@("H@<F5A9$%L
M;"@I+B!$969A=6QT<R!T;R`R,#0X+@H@("`@("H@0'9A<B!I;G1E9V5R("1L
M:6YE3&5N9W1H"B`@("`@*B\*("`@('9A<B`D;&EN94QE;F=T:"`](#(P-#@[
M"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!S<&5C:69I960@<&]R
M="X@268@8V%L;&5D('=H96X@=&AE('-O8VME="!I<PH@("`@("H@86QR96%D
M>2!C;VYN96-T960L(&ET(&1I<V-O;FYE8W1S(&%N9"!C;VYN96-T<R!A9V%I
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D861D<B`@("`@("`@
M25`@861D<F5S<R!O<B!H;W-T(&YA;64N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<&]R="`@("`@("`@5$-0('!O<G0@;G5M8F5R+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'!E<G-I<W1E;G0@("AO<'1I;VYA;"D@5VAE=&AE<B!T:&4@
M8V]N;F5C=&EO;B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('!E<G-I<W1E;G0@*&ME<'0@;W!E;B!B971W965N(')E<75E<W1S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8GD@=&AE('=E8B!S
M97)V97(I+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'1I;65O=70@("`@("AO
M<'1I;VYA;"D@2&]W(&QO;F<@=&\@=V%I="!F;W(@9&%T82X*("`@("`J($!P
M87)A;2!A<G)A>2`@("1O<'1I;VYS("`@("!3964@;W!T:6]N<R!F;W(@<W1R
M96%M7V-O;G1E>'1?8W)E871E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N('P@4$5!4E]%<G)O
M<B`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1A9&1R+"`D<&]R="`]
M(#`L("1P97)S:7-T96YT(#T@;G5L;"P@)'1I;65O=70@/2!N=6QL+"`D;W!T
M:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T
M:&ES+3YF<"DI('L*("`@("`@("`@("`@0&9C;&]S92@D=&AI<RT^9G`I.PH@
M("`@("`@("`@("`D=&AI<RT^9G`@/2!N=6QL.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"$D861D<BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)R1A9&1R(&-A;FYO="!B92!E;7!T>2<I.PH@("`@("`@('T@
M96QS96EF("AS=')S<&XH)&%D9'(L("<N,#$R,S0U-C<X.2<I(#T]('-T<FQE
M;B@D861D<BD@?'P*("`@("`@("`@("`@("`@("`@<W1R<W1R*"1A9&1R+"`G
M+R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^861D<B`]("1A
M9&1R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YA9&1R
M(#T@0&=E=&AO<W1B>6YA;64H)&%D9'(I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/G!O<G0@/2`D<&]R="`E(#8U-3,V.PH*("`@("`@("!I9B`H)'!E
M<G-I<W1E;G0@(3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/G!E<G-I
M<W1E;G0@/2`D<&5R<VES=&5N=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&EM96]U="`A/3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^=&EM96]U
M="`]("1T:6UE;W5T.PH@("`@("`@('T*"B`@("`@("`@)&]P96YF=6YC(#T@
M)'1H:7,M/G!E<G-I<W1E;G0@/R`G<&9S;V-K;W!E;B<@.B`G9G-O8VMO<&5N
M)SL*("`@("`@("`D97)R;F\@/2`P.PH@("`@("`@("1E<G)S='(@/2`G)SL*
M("`@("`@("!I9B`H)&]P=&EO;G,@)B8@9G5N8W1I;VY?97AI<W1S*"=S=')E
M86U?8V]N=&5X=%]C<F5A=&4G*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/G1I;65O=70I('L*("`@("`@("`@("`@("`@("1T:6UE;W5T(#T@)'1H:7,M
M/G1I;65O=70["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=&EM96]U="`](#`["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-O
M;G1E>'0@/2!S=')E86U?8V]N=&5X=%]C<F5A=&4H)&]P=&EO;G,I.PH@("`@
M("`@("`@("`D9G`@/2!`)&]P96YF=6YC*"1T:&ES+3YA9&1R+"`D=&AI<RT^
M<&]R="P@)&5R<FYO+"`D97)R<W1R+"`D=&EM96]U="P@)&-O;G1E>'0I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=&EM96]U
M="D@>PH@("`@("`@("`@("`@("`@)&9P(#T@0"1O<&5N9G5N8R@D=&AI<RT^
M861D<BP@)'1H:7,M/G!O<G0L("1E<G)N;RP@)&5R<G-T<BP@)'1H:7,M/G1I
M;65O=70I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&9P(#T@0"1O<&5N9G5N8R@D=&AI<RT^861D<BP@)'1H:7,M/G!O<G0L("1E
M<G)N;RP@)&5R<G-T<BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D97)R<W1R+"`D97)R;F\I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/F9P(#T@)&9P.PH*("`@("`@("!R971U<FX@)'1H:7,M/G-E=$)L
M;V-K:6YG*"1T:&ES+3YB;&]C:VEN9RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$:7-C;VYN96-T<R!F<F]M('1H92!P965R+"!C;&]S97,@=&AE('-O8VME
M="X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R
M;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@;W(@86X@97)R;W(@;V)J96-T(&]T
M:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@
M('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C
M=&5D)RD["B`@("`@("`@?0H*("`@("`@("!`9F-L;W-E*"1T:&ES+3YF<"D[
M"B`@("`@("`@)'1H:7,M/F9P(#T@;G5L;#L*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF('1H92!S;V-K
M970@:7,@:6X@8FQO8VMI;F<@;6]D92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N("!4:&4@8W5R<F5N="!B
M;&]C:VEN9R!M;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T)L;V-K:6YG
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F)L;V-K:6YG.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!W:&5T:&5R('1H92!S;V-K970@8V]N
M;F5C=&EO;B!S:&]U;&0@8F4@8FQO8VMI;F<@;W(*("`@("`J(&YO="X@02!R
M96%D(&-A;&P@=&\@82!N;VXM8FQO8VMI;F<@<V]C:V5T('=I;&P@<F5T=7)N
M(&EM;65D:6%T96QY"B`@("`@*B!I9B!T:&5R92!I<R!N;R!D871A(&%V86EL
M86)L92P@=VAE<F5A<R!I="!W:6QL(&)L;V-K('5N=&EL('1H97)E"B`@("`@
M*B!I<R!D871A(&9O<B!B;&]C:VEN9R!S;V-K971S+@H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1M;V1E("!4<G5E(&9O<B!B;&]C:VEN9R!S;V-K
M971S+"!F86QS92!F;W(@;F]N8FQO8VMI;F<N"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0')E='5R;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@;W(@
M86X@97)R;W(@;V)J96-T(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971";&]C:VEN9R@D;6]D92D*("`@('L*("`@("`@("!I9B`H(6ES7W)E
M<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^8FQO8VMI;F<@/2`D;6]D93L*("`@("`@("!S;V-K971?
M<V5T7V)L;V-K:6YG*"1T:&ES+3YF<"P@)'1H:7,M/F)L;V-K:6YG*3L*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE('1I;65O=70@=F%L=64@;VX@<V]C:V5T(&1E<V-R:7!T;W(L"B`@("`@
M*B!E>'!R97-S960@:6X@=&AE('-U;2!O9B!S96-O;F1S(&%N9"!M:6-R;W-E
M8V]N9',*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V5C;VYD<R`@
M4V5C;VYD<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1M:6-R;W-E8V]N9',@
M($UI8W)O<V5C;VYD<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<R!O<B!A;B!E<G)O<B!O8FIE
M8W0@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1I;65O=70H
M)'-E8V]N9',L("1M:6-R;W-E8V]N9',I"B`@("!["B`@("`@("`@:68@*"%I
M<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('-O8VME=%]S971?=&EM96]U="@D=&AI<RT^9G`L
M("1S96-O;F1S+"`D;6EC<F]S96-O;F1S*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@86X@97AI<W1I;F<@<V]C
M:V5T(')E<V]U<F-E+@H@("`@("H@0W5R<F5N=&QY(')E='5R;G,@9F]U<B!E
M;G1R:65S(&EN('1H92!R97-U;'0@87)R87DZ"B`@("`@*@H@("`@("H@/'`^
M"B`@("`@*B!T:6UE9%]O=70@*&)O;VPI("T@5&AE('-O8VME="!T:6UE9"!O
M=70@=V%I=&EN9R!F;W(@9&%T83QB<CX*("`@("`J(&)L;V-K960@*&)O;VPI
M("T@5&AE('-O8VME="!W87,@8FQO8VME9#QB<CX*("`@("`J(&5O9B`H8F]O
M;"D@+2!);F1I8V%T97,@14]&(&5V96YT/&)R/@H@("`@("H@=6YR96%D7V)Y
M=&5S("AI;G0I("T@3G5M8F5R(&]F(&)Y=&5S(&QE9G0@:6X@=&AE('-O8VME
M="!B=69F97(\8G(^"B`@("`@*B`\+W`^"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX960@07)R87D@8V]N=&%I;FEN
M9R!I;F9O<FUA=&EO;B!A8F]U="!E>&ES=&EN9R!S;V-K970@<F5S;W5R8V4@
M;W(@86X@97)R;W(@;V)J96-T(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9713=&%T=7,H*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R
M8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!S;V-K971?9V5T7W-T871U<R@D=&AI<RT^9G`I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T(&$@<W!E8VEF:65D(&QI;F4@;V8@9&%T80H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N("1S
M:7IE(&)Y=&5S(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O<B!A(%!%05)?
M17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T<R@D<VEZ92D*("`@('L*("`@("`@("!I9B`H
M(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@0&9G971S*"1T:&ES+3YF<"P@)'-I>F4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!A('-P96-I9FEE9"!A;6]U;G0@
M;V8@9&%T82X@5&AI<R!I<R!G=6%R86YT965D('1O(')E='5R;BP*("`@("`J
M(&%N9"!H87,@=&AE(&%D9&5D(&)E;F5F:70@;V8@9V5T=&EN9R!E=F5R>71H
M:6YG(&EN(&]N92!F<F5A9"@I"B`@("`@*B!C:'5N:SL@:68@>6]U(&MN;W<@
M=&AE('-I>F4@;V8@=&AE(&1A=&$@>6]U)W)E(&=E='1I;F<*("`@("`J(&)E
M9F]R96AA;F0L('1H:7,@:7,@9&5F:6YI=&5L>2!T:&4@=V%Y('1O(&=O+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S:7IE("!4:&4@;G5M8F5R
M(&]F(&)Y=&5S('1O(')E860@9G)O;2!T:&4@<V]C:V5T+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@)'-I>F4@8GET97,@;V8@9&%T
M82!F<F]M('1H92!S;V-K970L(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@
M("`@("`@("!N;W0@8V]N;F5C=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96%D*"1S:7IE*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H
M:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!`9G)E860H)'1H:7,M/F9P+"`D<VEZ92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!7<FET92!A('-P96-I9FEE9"!A;6]U;G0@;V8@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9&%T82`@("`@("!$871A('1O('=R
M:71E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&)L;V-K<VEZ92`@06UO=6YT
M(&]F(&1A=&$@=&\@=W)I=&4@870@;VYC92X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($Y53$P@;65A;G,@86QL(&%T(&]N8V4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX960@
M=')U92!O;B!S=6-C97-S(&]R(&%N(&5R<F]R(&]B:F5C="!O=&AE<G=I<V4*
M("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&1A=&$L("1B;&]C:W-I>F4@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M
M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N
M=6QL*"1B;&]C:W-I>F4I("8F("%/4U]724Y$3U=3*2!["B`@("`@("`@("`@
M(')E='5R;B!F=W)I=&4H)'1H:7,M/F9P+"`D9&%T82D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&)L;V-K<VEZ92DI('L*
M("`@("`@("`@("`@("`@("1B;&]C:W-I>F4@/2`Q,#(T.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<&]S(#T@,#L*("`@("`@("`@("`@)'-I>F4@
M/2!S=')L96XH)&1A=&$I.PH@("`@("`@("`@("!W:&EL92`H)'!O<R`\("1S
M:7IE*2!["B`@("`@("`@("`@("`@("`D=W)I='1E;B`]($!F=W)I=&4H)'1H
M:7,M/F9P+"!S=6)S='(H)&1A=&$L("1P;W,L("1B;&]C:W-I>F4I*3L*("`@
M("`@("`@("`@("`@(&EF("@D=W)I='1E;B`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D<&]S("L]("1W<FET=&5N.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!R971U<FX@)'!O<SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!7<FET92!A(&QI;F4@;V8@9&%T82!T;R!T:&4@
M<V]C:V5T+"!F;VQL;W=E9"!B>2!A('1R86EL:6YG(")<<EQN(BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!M:7AE9"!F
M<'5T<R!R97-U;'0L(&]R(&%N(&5R<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=R:71E3&EN92@D9&%T82D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U
M<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@9G=R:71E*"1T:&ES+3YF<"P@)&1A=&$@+B`B7')<;B(I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&5S=',@9F]R(&5N9"UO9BUF:6QE(&]N
M(&$@<V]C:V5T(&1E<V-R:7!T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!R971U<FX@8F]O;`H@("`@("HO"B`@("!F=6YC=&EO
M;B!E;V8H*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-?<F5S;W5R8V4H)'1H
M:7,M/F9P*2`F)B!F96]F*"1T:&ES+3YF<"DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5A9',@82!B>71E(&]F(&1A=&$*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0')E='5R;B`Q(&)Y=&4@;V8@9&%T82!F<F]M
M('1H92!S;V-K970L(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@("`@("`@
M("!N;W0@8V]N;F5C=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D0GET
M92@I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T
M(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&]R9"A`
M9G)E860H)'1H:7,M/F9P+"`Q*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96%D<R!A('=O<F0@;V8@9&%T80H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N(#$@=V]R9"!O9B!D871A(&9R;VT@=&AE('-O
M8VME="P@;W(@82!014%27T5R<F]R(&EF"B`@("`@*B`@("`@("`@(&YO="!C
M;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8617;W)D*"D*("`@
M('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C
M=&5D)RD["B`@("`@("`@?0H*("`@("`@("`D8G5F(#T@0&9R96%D*"1T:&ES
M+3YF<"P@,BD["B`@("`@("`@<F5T=7)N("AO<F0H)&)U9ELP72D@*R`H;W)D
M*"1B=69;,5TI(#P\(#@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E861S
M(&%N(&EN="!O9B!D871A"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!R971U<FX@:6YT96=E<B`@,2!I;G0@;V8@9&%T82!F<F]M('1H
M92!S;V-K970L(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@("`@("`@("`@
M("`@("`@("!N;W0@8V]N;F5C=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96%D26YT*"D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES
M+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@("`D8G5F(#T@
M0&9R96%D*"1T:&ES+3YF<"P@-"D["B`@("`@("`@<F5T=7)N("AO<F0H)&)U
M9ELP72D@*R`H;W)D*"1B=69;,5TI(#P\(#@I("L*("`@("`@("`@("`@("`@
M("AO<F0H)&)U9ELR72D@/#P@,38I("L@*&]R9"@D8G5F6S-=*2`\/"`R-"DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@82!Z97)O+71E<FUI;F%T
M960@<W1R:6YG(&]F(&1A=&$*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0')E='5R;B!S=')I;F<L(&]R(&$@4$5!4E]%<G)O<B!I9@H@
M("`@("H@("`@("`@("!N;W0@8V]N;F5C=&5D+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96%D4W1R:6YG*"D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U
M<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@
M("`D<W1R:6YG(#T@)R<["B`@("`@("`@=VAI;&4@*"@D8VAA<B`]($!F<F5A
M9"@D=&AI<RT^9G`L(#$I*2`A/2`B7'@P,"(I("!["B`@("`@("`@("`@("1S
M=')I;F<@+CT@)&-H87(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<W1R
M:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@86X@25`@061D<F5S
M<R!A;F0@<F5T=7)N<R!I="!I;B!A(&1O="!F;W)M871E9"!S=')I;F<*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!$;W0@
M9F]R;6%T960@<W1R:6YG+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@
M("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9$E0061D<F5S<R@I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D
M=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)&)U
M9B`]($!F<F5A9"@D=&AI<RT^9G`L(#0I.PH@("`@("`@(')E='5R;B!S<')I
M;G1F*"(E<RXE<RXE<RXE<R(L(&]R9"@D8G5F6S!=*2P@;W)D*"1B=69;,5TI
M+`H@("`@("`@("`@("`@("`@("`@("`@(&]R9"@D8G5F6S)=*2P@;W)D*"1B
M=69;,UTI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E860@=6YT:6P@96ET
M:&5R('1H92!E;F0@;V8@=&AE('-O8VME="!O<B!A(&YE=VQI;F4L('=H:6-H
M979E<@H@("`@("H@8V]M97,@9FER<W0N(%-T<FEP<R!T:&4@=')A:6QI;F<@
M;F5W;&EN92!F<F]M('1H92!R971U<FYE9"!D871A+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N($%L;"!A=F%I;&%B;&4@
M9&%T82!U<"!T;R!A(&YE=VQI;F4L('=I=&AO=70@=&AA=`H@("`@("H@("`@
M("`@("!N97=L:6YE+"!O<B!U;G1I;"!T:&4@96YD(&]F('1H92!S;V-K970L
M(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@("`@("`@("!N;W0@8V]N;F5C
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D3&EN92@I"B`@("!["B`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I
M.PH@("`@("`@('T*"B`@("`@("`@)&QI;F4@/2`G)SL*("`@("`@("`D=&EM
M96]U="`]('1I;64H*2`K("1T:&ES+3YT:6UE;W5T.PH@("`@("`@('=H:6QE
M("@A9F5O9B@D=&AI<RT^9G`I("8F("@A)'1H:7,M/G1I;65O=70@?'P@=&EM
M92@I(#P@)'1I;65O=70I*2!["B`@("`@("`@("`@("1L:6YE("X]($!F9V5T
M<R@D=&AI<RT^9G`L("1T:&ES+3YL:6YE3&5N9W1H*3L*("`@("`@("`@("`@
M:68@*'-U8G-T<B@D;&EN92P@+3$I(#T](")<;B(I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!R=')I;2@D;&EN92P@(EQR7&XB*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&QI;F4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296%D('5N=&EL('1H92!S;V-K970@8VQO<V5S+"!O<B!U
M;G1I;"!T:&5R92!I<R!N;R!M;W)E(&1A=&$@:6X*("`@("`J('1H92!I;FYE
M<B!02%`@8G5F9F5R+B!)9B!T:&4@:6YN97(@8G5F9F5R(&ES(&5M<'1Y+"!I
M;B!B;&]C:VEN9PH@("`@("H@;6]D92!W92!W86ET(&9O<B!A="!L96%S="`Q
M(&)Y=&4@;V8@9&%T82X@5&AE<F5F;W)E+"!I;@H@("`@("H@8FQO8VMI;F<@
M;6]D92P@:68@=&AE<F4@:7,@;F\@9&%T82!A="!A;&P@=&\@8F4@<F5A9"P@
M=&AI<PH@("`@("H@9G5N8W1I;VX@=VEL;"!N979E<B!E>&ET("AU;FQE<W,@
M=&AE('-O8VME="!I<R!C;&]S960@;VX@=&AE"B`@("`@*B!R96UO=&4@96YD
M*2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!!;&P@9&%T82!U;G1I;"!T:&4@<V]C:V5T(&-L
M;W-E<RP@;W(@82!014%27T5R<F]R(&EF"B`@("`@*B`@("`@("`@("`@("`@
M("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$%L
M;"@I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T
M(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*
M("`@("`@("!W:&EL92`H(69E;V8H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@
M("`D9&%T82`N/2!`9G)E860H)'1H:7,M/F9P+"`D=&AI<RT^;&EN94QE;F=T
M:"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)U;G,@=&AE(&5Q=6EV86QE;G0@;V8@=&AE('-E;&5C
M="@I('-Y<W1E;2!C86QL(&]N('1H92!S;V-K970*("`@("`J('=I=&@@82!T
M:6UE;W5T('-P96-I9FEE9"!B>2!T=E]S96,@86YD('1V7W5S96,N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T871E("`@(%=H:6-H(&]F(')E
M860O=W)I=&4O97)R;W(@=&\@8VAE8VL@9F]R+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'1V7W-E8R`@($YU;6)E<B!O9B!S96-O;F1S(&9O<B!T:6UE;W5T
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'1V7W5S96,@($YU;6)E<B!O9B!M
M:6-R;W-E8V]N9',@9F]R('1I;65O=70N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!R971U<FX@1F%L<V4@:68@<V5L96-T(&9A:6QS
M+"!I;G1E9V5R(&1E<V-R:6)I;F<@=VAI8V@@;V8@<F5A9"]W<FET92]E<G)O
M<@H@("`@("H@("`@("`@("!A<F4@<F5A9'DL(&]R(%!%05)?17)R;W(@:68@
M;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5L96-T*"1S
M=&%T92P@)'1V7W-E8RP@)'1V7W5S96,@/2`P*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@
M("!]"@H@("`@("`@("1R96%D(#T@;G5L;#L*("`@("`@("`D=W)I=&4@/2!N
M=6QL.PH@("`@("`@("1E>&-E<'0@/2!N=6QL.PH@("`@("`@(&EF("@D<W1A
M=&4@)B!.151?4T]#2T547U)%040I('L*("`@("`@("`@("`@)')E861;72`]
M("1T:&ES+3YF<#L*("`@("`@("!]"B`@("`@("`@:68@*"1S=&%T92`F($Y%
M5%]33T-+151?5U))5$4I('L*("`@("`@("`@("`@)'=R:71E6UT@/2`D=&AI
M<RT^9G`["B`@("`@("`@?0H@("`@("`@(&EF("@D<W1A=&4@)B!.151?4T]#
M2T547T524D]2*2!["B`@("`@("`@("`@("1E>&-E<'1;72`]("1T:&ES+3YF
M<#L*("`@("`@("!]"B`@("`@("`@:68@*&9A;'-E(#T]/2`H)'-R(#T@<W1R
M96%M7W-E;&5C="@D<F5A9"P@)'=R:71E+"`D97AC97!T+"`D='9?<V5C+"`D
M='9?=7-E8RDI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1R97-U;'0@/2`P.PH@("`@("`@(&EF("AC;W5N="@D
M<F5A9"DI('L*("`@("`@("`@("`@)')E<W5L="!\/2!.151?4T]#2T547U)%
M040["B`@("`@("`@?0H@("`@("`@(&EF("AC;W5N="@D=W)I=&4I*2!["B`@
M("`@("`@("`@("1R97-U;'0@?#T@3D547U-/0TM%5%]74DE413L*("`@("`@
M("!]"B`@("`@("`@:68@*&-O=6YT*"1E>&-E<'0I*2!["B`@("`@("`@("`@
M("1R97-U;'0@?#T@3D547U-/0TM%5%]%4E)/4CL*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("!]"@I]"@```"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B].970O4TU44"YP:'``````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W-#(R-0`Q,#4Q-30S,3`U-P`P
M,3<S-S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('-O9G1T86)S=&]P/30@
M=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\("`@("`@("`@($IO;B!087)I<V4@/&IO;D!P:'`N
M;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"`@("`@("`@("!$86UI86X@06QE:F%N9')O($9E<FYA;F1E>B!3;W-A(#QD
M86UL:7-T<T!C;F)A+G5B82YA<CX@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(%--5%`N<&AP+'8@,2XU-2`R,#`V
M+S`R+S`V(#`V.C`P.C(R(&IO;B!%>'`@)`H*<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<["G)E<75I<F5?;VYC92`G3F5T+U-O8VME="YP:'`G.PH*+RHJ"B`J
M(%!R;W9I9&5S(&%N(&EM<&QE;65N=&%T:6]N(&]F('1H92!33510('!R;W1O
M8V]L('5S:6YG(%!%05(G<PH@*B!.971?4V]C:V5T.CH@8VQA<W,N"B`J"B`J
M($!P86-K86=E($YE=%]33510"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ
M;VY`<&AP+FYE=#X*("H@0&%U=&AO<B`@1&%M:6%N($%L96IA;F1R;R!&97)N
M86YD97H@4V]S82`\9&%M;&ES='-`8VYB82YU8F$N87(^"B`J"B`J($!E>&%M
M<&QE(&)A<VEC+G!H<"`@($$@8F%S:6,@:6UP;&5M96YT871I;VX@;V8@=&AE
M($YE=%]33510('!A8VMA9V4N"B`J+PIC;&%S<R!.971?4TU44`I["B`@("`O
M*BH*("`@("`J(%1H92!S97)V97(@=&\@8V]N;F5C="!T;RX*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!V
M87(@)&AO<W0@/2`G;&]C86QH;W-T)SL*"B`@("`O*BH*("`@("`J(%1H92!P
M;W)T('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R(&EN=`H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@=F%R("1P;W)T(#T@,C4["@H@("`@
M+RHJ"B`@("`@*B!4:&4@=F%L=64@=&\@9VEV92!W:&5N('-E;F1I;F<@14A,
M3R!O<B!(14Q/+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@('9A<B`D;&]C86QH;W-T(#T@)VQO8V%L:&]S
M="<["@H@("`@+RHJ"B`@("`@*B!,:7-T(&]F('-U<'!O<G1E9"!A=71H96YT
M:6-A=&EO;B!M971H;V1S+"!I;B!P<F5F97)E;G1I86P@;W)D97(N"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!V87(@)&%U=&A?;65T:&]D<R`](&%R<F%Y*"=$24=%4U0M340U)RP@)T-2
M04TM340U)RP@)TQ/1TE.)RP@)U!,04E.)RD["@H@("`@+RHJ"B`@("`@*B!3
M:&]U;&0@9&5B=6=G:6YG(&]U='!U="!B92!E;F%B;&5D/PH@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?9&5B=6<@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!S;V-K
M970@<F5S;W5R8V4@8F5I;F<@=7-E9"!T;R!C;VYN96-T('1O('1H92!33510
M('-E<G9E<BX*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]S;V-K970@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@5&AE(&UO<W0@<F5C96YT('-E<G9E<B!R97-P;VYS92!C
M;V1E+@H@("`@("H@0'9A<B!I;G0*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]C;V1E(#T@+3$["@H@("`@+RHJ"B`@("`@*B!4
M:&4@;6]S="!R96-E;G0@<V5R=F5R(')E<W!O;G-E(&%R9W5M96YT<RX*("`@
M("`J($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]A<F=U;65N=',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@4W1O<F5S(&1E=&5C=&5D(&9E871U<F5S(&]F('1H92!33510('-E<G9E
M<BX*("`@("`J($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]E<VUT<"`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!);G-T86YT:6%T97,@82!N97<@3F5T7U--5%`@;V)J96-T+"!O=F5R
M<FED:6YG(&%N>2!D969A=6QT<PH@("`@("H@=VET:"!P87)A;65T97)S('1H
M870@87)E('!A<W-E9"!I;BX*("`@("`J"B`@("`@*B!)9B!Y;W4@:&%V92!3
M4TP@<W5P<&]R="!I;B!02%`L('EO=2!C86X@8V]N;F5C="!T;R!A('-E<G9E
M<@H@("`@("H@;W9E<B!34TP@=7-I;F<@86X@)W-S;#HO+R<@<')E9FEX.@H@
M("`@("H*("`@("`J("`@+R\@-#8U(&ES(&$@8V]M;6]N('-M='!S('!O<G0N
M"B`@("`@*B`@("1S;71P(#T@;F5W($YE=%]33510*"=S<VPZ+R]M86EL+FAO
M<W0N8V]M)RP@-#8U*3L*("`@("`J("`@)'-M='`M/F-O;FYE8W0H*3L*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:&]S="`@("`@("!4:&4@<V5R
M=F5R('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&]R
M="`@("`@("!4:&4@<&]R="!T;R!C;VYN96-T('1O+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&QO8V%L:&]S="`@5&AE('9A;'5E('1O(&=I=F4@=VAE;B!S
M96YD:6YG($5(3$\@;W(@2$5,3RX*("`@("`J"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J($!S:6YC92`@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!.971?4TU44"@D:&]S="`](&YU;&PL("1P;W)T(#T@;G5L;"P@)&QO8V%L
M:&]S="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1H;W-T*2D@
M)'1H:7,M/FAO<W0@/2`D:&]S=#L*("`@("`@("!I9B`H:7-S970H)'!O<G0I
M*2`D=&AI<RT^<&]R="`]("1P;W)T.PH@("`@("`@(&EF("AI<W-E="@D;&]C
M86QH;W-T*2D@)'1H:7,M/FQO8V%L:&]S="`]("1L;V-A;&AO<W0["@H@("`@
M("`@("1T:&ES+3Y?<V]C:V5T(#T@)FYE=R!.971?4V]C:V5T*"D["@H@("`@
M("`@("\J"B`@("`@("`@("H@26YC;'5D92!T:&4@075T:%]305-,('!A8VMA
M9V4N("!)9B!T:&4@<&%C:V%G92!I<R!N;W0@879A:6QA8FQE+`H@("`@("`@
M("`J('=E(&1I<V%B;&4@=&AE(&%U=&AE;G1I8V%T:6]N(&UE=&AO9',@=&AA
M="!D97!E;F0@=7!O;B!I="X*("`@("`@("`@*B\*("`@("`@("!I9B`H*$!I
M;F-L=61E7V]N8V4@)T%U=&@O4T%33"YP:'`G*2`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)'!O<R`](&%R<F%Y7W-E87)C:"@G1$E'15-4+4U$-2<L("1T
M:&ES+3YA=71H7VUE=&AO9',I.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M875T:%]M971H;V1S6R1P;W-=*3L*("`@("`@("`@("`@)'!O<R`](&%R<F%Y
M7W-E87)C:"@G0U)!32U-1#4G+"`D=&AI<RT^875T:%]M971H;V1S*3L*("`@
M("`@("`@("`@=6YS970H)'1H:7,M/F%U=&A?;65T:&]D<ULD<&]S72D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!V86QU92!O
M9B!T:&4@9&5B=6=G:6YG(&9L86<N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M8F]O;&5A;B`D9&5B=6<@("`@("!.97<@=F%L=64@9F]R('1H92!D96)U9V=I
M;F<@9FQA9RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1E8G5G
M*"1D96)U9RD*("`@('L*("`@("`@("`D=&AI<RT^7V1E8G5G(#T@)&1E8G5G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@9VEV96X@<W1R:6YG
M(&]F(&1A=&$@=&\@=&AE('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1D871A("`@("`@(%1H92!S=')I;F<@;V8@9&%T82!T;R!S
M96YD+@H@("`@("H*("`@("`J($!R971U<FX@(&UI>&5D("`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<VEN8V4@("`Q
M+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5N9"@D9&%T82D*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/E]D96)U9RD@>PH@("`@("`@("`@("!E8VAO
M(")$14)51SH@4V5N9#H@)&1A=&%<;B(["B`@("`@("`@?0H*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W-O8VME="T^=W)I
M=&4H)&1A=&$I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G1F%I;&5D('1O('=R:71E('1O('-O8VME=#H@)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<BT^9V5T365S<V%G
M92@I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5N9"!A(&-O;6UA;F0@=&\@=&AE('-E<G9E<B!W
M:71H(&%N(&]P=&EO;F%L('-T<FEN9R!O9@H@("`@("H@87)G=6UE;G1S+B`@
M02!C87)R:6%G92!R971U<FX@+R!L:6YE9F5E9"`H0U),1BD@<V5Q=65N8V4@
M=VEL;`H@("`@("H@8F4@87!P96YD960@=&\@96%C:"!C;VUM86YD('-T<FEN
M9R!B969O<F4@:70@:7,@<V5N="!T;R!T:&4*("`@("`J(%--5%`@<V5R=F5R
M("T@86X@97)R;W(@=VEL;"!B92!T:')O=VX@:68@=&AE(&-O;6UA;F0@<W1R
M:6YG"B`@("`@*B!A;')E861Y(&-O;G1A:6YS(&%N>2!N97=L:6YE(&-H87)A
M8W1E<G,N(%5S92!?<V5N9"@I(&9O<@H@("`@("H@8V]M;6%N9',@=&AA="!M
M=7-T(&-O;G1A:6X@;F5W;&EN97,N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D8V]M;6%N9"`@("!4:&4@4TU44"!C;VUM86YD('1O('-E;F0@
M=&\@=&AE('-E<G9E<BX*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&%R9W,@
M("`@("`@02!S=')I;F<@;V8@;W!T:6]N86P@87)G=6UE;G1S('1O(&%P<&5N
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!T:&4@
M8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%1H92!R
M97-U;'0@;V8@=&AE(%]S96YD*"D@8V%L;"X*("`@("`J"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B!`<VEN8V4@("`Q+C$N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<'5T*"1C;VUM86YD+"`D87)G<R`]("<G*0H@("`@>PH@
M("`@("`@(&EF("@A96UP='DH)&%R9W,I*2!["B`@("`@("`@("`@("1C;VUM
M86YD("X]("<@)R`N("1A<F=S.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T
M<F-S<&XH)&-O;6UA;F0L(")<<EQN(BD@(3T]('-T<FQE;B@D8V]M;6%N9"DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O;6UA
M;F1S(&-A;FYO="!C;VYT86EN(&YE=VQI;F5S)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]S96YD*"1C;VUM86YD("X@(EQR7&XB*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E860@82!R97!L>2!F<F]M('1H92!3
M3510('-E<G9E<BX@(%1H92!R97!L>2!C;VYS:7-T<R!O9B!A(')E<W!O;G-E
M"B`@("`@*B!C;V1E(&%N9"!A(')E<W!O;G-E(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@;6EX960@("`D=F%L:60@("`@("!4:&4@<V5T(&]F
M('9A;&ED(')E<W!O;G-E(&-O9&5S+B`@5&AE<V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;6%Y(&)E('-P96-I9FEE9"!A<R!A;B!A
M<G)A>2!O9B!I;G1E9V5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('9A;'5E<R!O<B!A<R!A('-I;F=L92!I;G1E9V5R('9A;'5E+@H@
M("`@("H*("`@("`J($!R971U<FX@(&UI>&5D("`@5')U92!I9B!T:&4@<V5R
M=F5R(')E='5R;F5D(&$@=F%L:60@<F5S<&]N<V4@8V]D92!O<@H@("`@("H@
M("`@("`@("`@("`@("`@("!A(%!%05)?17)R;W(@;V)J96-T(&ES(&%N(&5R
M<F]R(&-O;F1I=&EO;B!I<R!R96%C:&5D+@H@("`@("H*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J($!S:6YC92`@(#$N,2XP"B`@("`@*@H@("`@
M("H@0'-E92`@("`@9V5T4F5S<&]N<V4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!A<G-E4F5S<&]N<V4H)'9A;&ED*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8V]D92`]("TQ.PH@("`@("`@("1T:&ES+3Y?87)G=6UE;G1S(#T@87)R87DH
M*3L*"B`@("`@("`@=VAI;&4@*"1L:6YE(#T@)'1H:7,M/E]S;V-K970M/G)E
M861,:6YE*"DI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&5B=6<I('L*
M("`@("`@("`@("`@("`@(&5C:&\@(D1%0E5'.B!296-V.B`D;&EN95QN(CL*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@268@=V4@<F5C96EV92!A
M;B!E;7!T>2!L:6YE+"!T:&4@8V]N;F5C=&EO;B!H87,@8F5E;B!C;&]S960N
M("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D;&EN92DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V]N;F5C=&EO;B!W87,@=6YE>'!E
M8W1E9&QY(&-L;W-E9"<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!296%D('1H92!C;V1E(&%N9"!S=&]R92!T:&4@<F5S="!I;B!T:&4@87)G
M=6UE;G1S(&%R<F%Y+B`J+PH@("`@("`@("`@("`D8V]D92`]('-U8G-T<B@D
M;&EN92P@,"P@,RD["B`@("`@("`@("`@("1T:&ES+3Y?87)G=6UE;G1S6UT@
M/2!T<FEM*'-U8G-T<B@D;&EN92P@-"DI.PH*("`@("`@("`@("`@+RH@0VAE
M8VL@=&AE('-Y;G1A>"!O9B!T:&4@<F5S<&]N<V4@8V]D92X@*B\*("`@("`@
M("`@("`@:68@*&ES7VYU;65R:6,H)&-O9&4I*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-O9&4@/2`H:6YT*21C;V1E.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;V1E(#T@+3$["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+RH@268@=&AI<R!I<R!N;W0@82!M=6QT:6QI;F4@<F5S<&]N<V4L('=E)W)E
M(&1O;F4N("HO"B`@("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L(#,L(#$I
M("$]("<M)RD@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J($-O;7!A<F4@=&AE('-E<G9E<B=S
M(')E<W!O;G-E(&-O9&4@=VET:"!T:&4@=F%L:60@8V]D92X@*B\*("`@("`@
M("!I9B`H:7-?:6YT*"1V86QI9"D@)B8@*"1T:&ES+3Y?8V]D92`]/3T@)'9A
M;&ED*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@
M("`@("`@("\J($EF('=E('=E<F4@9VEV96X@86X@87)R87D@;V8@=F%L:60@
M<F5S<&]N<V4@8V]D97,L(&-H96-K(&5A8V@@;VYE+B`J+PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D=F%L:60I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86QI9"!A<R`D=F%L:61?8V]D92D@>PH@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?8V]D92`]/3T@)'9A;&ED7V-O9&4I('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)TEN=F%L:60@<F5S<&]N<V4@8V]D92!R96-E:79E9"!F<F]M('-E<G9E
M<B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@,BUT=7!L92!C
M;VYT86EN:6YG('1H92!L87-T(')E<W!O;G-E(&9R;VT@=&AE(%--5%`@<V5R
M=F5R+@H@("`@("H*("`@("`J($!R971U<FX@(&%R<F%Y("`@02!T=V\M96QE
M;65N="!A<G)A>3H@=&AE(&9I<G-T(&5L96UE;G0@8V]N=&%I;G,@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@(')E<W!O;G-E(&-O9&4@87,@86X@:6YT
M96=E<B!A;F0@=&AE('-E8V]N9"!E;&5M96YT"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&-O;G1A:6YS('1H92!R97-P;VYS92=S(&%R9W5M96YT<R!A<R!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O
M;G-E*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)'1H:7,M/E]C;V1E
M+"!J;VEN*")<;B(L("1T:&ES+3Y?87)G=6UE;G1S*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T('1O(&-O;FYE8W0@=&\@=&AE(%--5%`@<V5R
M=F5R+@H@("`@("H*("`@("`J($!P87)A;2`@(&EN="`@("`@)'1I;65O=70@
M("`@5&AE('1I;65O=70@=F%L=64@*&EN('-E8V]N9',I(&9O<B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<V]C:V5T(&-O;FYE
M8W1I;VXN"B`@("`@*B!`<&%R86T@("!B;V]L("`@("1P97)S:7-T96YT(%-H
M;W5L9"!A('!E<G-I<W1E;G0@<V]C:V5T(&-O;FYE8W1I;VX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8F4@=7-E9#\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@
M86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@
M:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]N;F5C="@D=&EM96]U="`](&YU;&PL("1P97)S:7-T96YT
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<V]C
M:V5T+3YC;VYN96-T*"1T:&ES+3YH;W-T+"`D=&AI<RT^<&]R="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<G-I<W1E
M;G0L("1T:6UE;W5T*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M1F%I;&5D('1O(&-O;FYE8W0@<V]C:V5T.B`G("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<W5L="T^9V5T365S<V%G92@I*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]
M("1T:&ES+3Y?<&%R<V5297-P;VYS92@R,C`I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7VYE9V]T:6%T92@I*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&1I<V-O
M;FYE8W0@9G)O;2!T:&4@4TU44"!S97)V97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R
M(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@
M9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=154E4)RDI*2!["B`@("`@("`@("`@
M(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@R,C$I*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W-O8VME="T^
M9&ES8V]N;F5C="@I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G1F%I;&5D('1O(&1I<V-O;FYE8W0@<V]C:V5T.B`G("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R+3YG971-
M97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O('-E;F0@=&AE($5(3$\@
M8V]M;6%N9"!A;F0@;V)T86EN(&$@;&ES="!O9B!%4TU44`H@("`@("H@97AT
M96YS:6]N<R!A=F%I;&%B;&4L(&%N9"!F86EL:6YG('1H870@:G5S="!S96YD
M($A%3$\N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@
M4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@
M*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S
M=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@
M0'-I;F-E("`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!?;F5G;W1I871E
M*"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@G14A,3R<L("1T:&ES+3YL;V-A;&AO<W0I*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2![
M"B`@("`@("`@("`@("\J($EF('=E(')E8V5I=F4@82`U,#,@<F5S<&]N<V4L
M('=E)W)E(&%L<F5A9'D@875T:&5N=&EC871E9"X@*B\*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8V]D92`]/3T@-3`S*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@268@
M=&AE($5(3$\@9F%I;&5D+"!T<GD@=&AE('-I;7!L97(@2$5,3R!C;VUM86YD
M+B`J+PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@G2$5,3R<L("1T:&ES+3YL;V-A;&AO<W0I*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7W!A<G-E4F5S<&]N
M<V4H,C4P*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=(14Q/('=A<R!N;W0@86-C97!T960Z("<L("1T:&ES+3Y?8V]D
M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A<F=U;65N=',@
M87,@)&%R9W5M96YT*2!["B`@("`@("`@("`@("1V97)B(#T@<W1R=&]K*"1A
M<F=U;65N="P@)R`G*3L*("`@("`@("`@("`@)&%R9W5M96YT<R`]('-U8G-T
M<B@D87)G=6UE;G0L('-T<FQE;B@D=F5R8BD@*R`Q+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<FQE;B@D87)G=6UE;G0I("T@<W1R;&5N
M*"1V97)B*2`M(#$I.PH@("`@("`@("`@("`D=&AI<RT^7V5S;71P6R1V97)B
M72`]("1A<F=U;65N=',["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YA;64@;V8@
M=&AE(&)E<W0@875T:&5N=&EC871I;VX@;65T:&]D('1H870@=&AE('-E<G9E
M<@H@("`@("H@:&%S(&%D=F5R=&ES960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@("!2971U<FYS(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA
M;64@;V8@=&AE(&)E<W0*("`@("`J("`@("`@("`@("`@("`@("`@<W5P<&]R
M=&5D(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!O<B!A(%!%05)?17)R;W(@;V)J
M96-T"B`@("`@*B`@("`@("`@("`@("`@("`@(&EF(&$@9F%I;'5R92!C;VYD
M:71I;VX@:7,@96YC;W5N=&5R960N"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=$)E<W1!=71H365T:&]D*"D*("`@('L*("`@("`@("`D879A:6QA8FQE7VUE
M=&AO9',@/2!E>'!L;V1E*"<@)RP@)'1H:7,M/E]E<VUT<%LG05542"==*3L*
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F%U=&A?;65T:&]D<R!A<R`D;65T
M:&]D*2!["B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D;65T:&]D+"`D879A
M:6QA8FQE7VUE=&AO9',I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&UE
M=&AO9#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)TYO('-U<'!O<G1E9"!A=71H96YT:6-A=&EO
M;B!M971H;V1S)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O
M(&1O(%--5%`@875T:&5N=&EC871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R!4:&4@=7-E<FED('1O(&%U=&AE;G1I8V%T92!A<RX*("`@("`J
M($!P87)A;2!S=')I;F<@5&AE('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T92!W
M:71H+@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@<F5Q=65S=&5D(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"X@($EF(&YO;F4@:7,*("`@("`J("`@("`@("`@
M("`@("`@<W!E8VEF:65D+"!T:&4@8F5S="!S=7!P;W)T960@;65T:&]D('=I
M;&P@8F4@=7-E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R
M;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*
M("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E
M(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I
M;F-E("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@875T:"@D=6ED+"`D<'=D
M("P@)&UE=&AO9"`]("<G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7V5S;71P6R=!551()UTI*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=33510('-E<G9E<B!D;V5S(&YO('-U<'!O<G0@875T
M:&5N=&EC871I;VXG*3L*("`@("`@("!]"@H@("`@("`@("\J($EF(&YO(&UE
M=&AO9"!H87,@8F5E;B!S<&5C:69I960L(&=E="!T:&4@;F%M92!O9B!T:&4@
M8F5S=`H@("`@("`@("`J('-U<'!O<G1E9"!M971H;V0@861V97)T:7-E9"!B
M>2!T:&4@4TU44"!S97)V97(N("HO"B`@("`@("`@:68@*&5M<'1Y*"1M971H
M;V0I*2!["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1M971H;V0@
M/2`D=&AI<RT^7V=E=$)E<W1!=71H365T:&]D*"DI*2!["B`@("`@("`@("`@
M("`@("`O*B!2971U<FX@=&AE(%!%05)?17)R;W(@;V)J96-T(&9R;VT@7V=E
M=$)E<W1!=71H365T:&]D*"DN("HO"B`@("`@("`@("`@("`@("!R971U<FX@
M)&UE=&AO9#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1M971H;V0@/2!S=')T;W5P<&5R*"1M971H;V0I.PH@("`@("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"1M971H;V0L("1T:&ES+3YA=71H7VUE=&AO
M9',I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B)&UE=&AO9"!I<R!N;W0@82!S=7!P;W)T960@875T:&5N=&EC871I;VX@
M;65T:&]D(BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('-W
M:71C:"`H)&UE=&AO9"D@>PH@("`@("`@("`@("!C87-E("=$24=%4U0M340U
M)SH*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V%U=&A$:6=E
M<W1?340U*"1U:60L("1P=V0I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@)T-204TM340U)SH*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V%U=&A#4D%-7TU$-2@D=6ED+"`D<'=D*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=,3T=)3B<Z
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]A=71H3&]G:6XH
M)'5I9"P@)'!W9"D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G4$Q!24XG.@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?875T:%!L86EN*"1U:60L("1P=V0I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@4$5!4CHZ<F%I<V5%<G)O<B@B)&UE=&AO9"!I<R!N;W0@82!S
M=7!P;W)T960@875T:&5N=&EC871I;VX@;65T:&]D(BD["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\J($EF(&%N(&5R<F]R
M('=A<R!E;F-O=6YT97)E9"P@<F5T=7)N('1H92!014%27T5R<F]R(&]B:F5C
M="X@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@075T:&5N=&EC
M871E<R!T:&4@=7-E<B!U<VEN9R!T:&4@1$E'15-4+4U$-2!M971H;V0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@=7-E<FED('1O(&%U=&AE
M;G1I8V%T92!A<RX*("`@("`J($!P87)A;2!S=')I;F<@5&AE('!A<W-W;W)D
M('1O(&%U=&AE;G1I8V%T92!W:71H+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S
M86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU
M<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'-I;F-E("`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!?
M875T:$1I9V5S=%]-1#4H)'5I9"P@)'!W9"D*("`@('L*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G05542"<L("=$
M24=%4U0M340U)RDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H@("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I
M;VX@<F5Q=65S="`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O
M<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@
M("`O*B`U,#,Z($5R<F]R.B!A;')E861Y(&%U=&AE;G1I8V%T960@*B\*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?8V]D92`]/3T@-3`S*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)&-H86QL96YG
M92`](&)A<V4V-%]D96-O9&4H)'1H:7,M/E]A<F=U;65N='-;,%TI.PH@("`@
M("`@("1D:6=E<W0@/2`F075T:%]305-,.CIF86-T;W)Y*"=D:6=E<W1M9#4G
M*3L*("`@("`@("`D875T:%]S='(@/2!B87-E-C1?96YC;V1E*"1D:6=E<W0M
M/F=E=%)E<W!O;G-E*"1U:60L("1P=V0L("1C:&%L;&5N9V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^:&]S="P@(G-M='`B*2D["@H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"1A=71H7W-T<BDI*2!["B`@
M("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@("\J
M(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I;VX@<F5Q=65S="`J+PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V52
M97-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*"B`@("`@("`@+RH@5V4@9&]N)W0@=7-E('1H92!P<F]T;V-O
M;"=S('1H:7)D('-T97`@8F5C875S92!33510(&1O97-N)W0*("`@("`@("`@
M*B!A;&QO=R!S=6)S97%U96YT(&%U=&AE;G1I8V%T:6]N+"!S;R!W92!J=7-T
M('-I;&5N=&QY(&EG;F]R90H@("`@("`@("`J(&ET+B`J+PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"<@)RDI*2![
M"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@
M("\J(#(S-3H@075T:&5N=&EC871I;VX@<W5C8V5S<V9U;"`J+PH@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P
M;VYS92@R,S4I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%U=&AE;G1I8V%T97,@=&AE
M('5S97(@=7-I;F<@=&AE($-204TM340U(&UE=&AO9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG(%1H92!U<V5R:60@=&\@875T:&5N=&EC871E(&%S
M+@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@<&%S<W=O<F0@=&\@875T:&5N
M=&EC871E('=I=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U
M<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY
M"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U
M92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<VEN8V4@(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H0U)!35]-
M1#4H)'5I9"P@)'!W9"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G05542"<L("=#4D%-+4U$-2<I*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@
M("`O*B`S,S0Z($-O;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E<75E<W0@*B\*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A
M<G-E4F5S<&]N<V4H,S,T*2DI('L*("`@("`@("`@("`@+RH@-3`S.B!%<G)O
M<CH@86QR96%D>2!A=71H96YT:6-A=&5D("HO"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V-O9&4@/3T](#4P,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"@H@("`@("`@("1C:&%L;&5N9V4@/2!B87-E-C1?9&5C
M;V1E*"1T:&ES+3Y?87)G=6UE;G1S6S!=*3L*("`@("`@("`D8W)A;2`]("9!
M=71H7U-!4TPZ.F9A8W1O<GDH)V-R86UM9#4G*3L*("`@("`@("`D875T:%]S
M='(@/2!B87-E-C1?96YC;V1E*"1C<F%M+3YG971297-P;VYS92@D=6ED+"`D
M<'=D+"`D8VAA;&QE;F=E*2D["@H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"1A=71H7W-T<BDI*2!["B`@("`@("`@
M("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`O*B`R,S4Z
M($%U=&AE;G1I8V%T:6]N('-U8V-E<W-F=6P@*B\*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C,U
M*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!=71H96YT:6-A=&5S('1H92!U<V5R('5S
M:6YG('1H92!,3T=)3B!M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!4:&4@=7-E<FED('1O(&%U=&AE;G1I8V%T92!A<RX*("`@("`J($!P
M87)A;2!S=')I;F<@5&AE('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T92!W:71H
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?
M17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@
M("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S
M<RX*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-I;F-E("`Q+C$N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:$QO9VEN*"1U:60L("1P=V0I
M"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H
M:7,M/E]P=70H)T%55$@G+"`G3$]'24XG*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@+RH@,S,T.B!#;VYT:6YU
M92!A=71H96YT:6-A=&EO;B!R97%U97-T("HO"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#,S-"DI
M*2!["B`@("`@("`@("`@("\J(#4P,SH@17)R;W(Z(&%L<F5A9'D@875T:&5N
M=&EC871E9"`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;V1E(#T]/2`U
M,#,I('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="AB
M87-E-C1?96YC;V1E*"1U:60I*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E
M<G)O<CL*("`@("`@("!]"B`@("`@("`@+RH@,S,T.B!#;VYT:6YU92!A=71H
M96YT:6-A=&EO;B!R97%U97-T("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#,S-"DI*2!["B`@
M("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="AB87-E-C1?
M96YC;V1E*"1P=V0I*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*
M("`@("`@("!]"@H@("`@("`@("\J(#(S-3H@075T:&5N=&EC871I;VX@<W5C
M8V5S<V9U;"`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]
M("1T:&ES+3Y?<&%R<V5297-P;VYS92@R,S4I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!=71H96YT:6-A=&5S('1H92!U<V5R
M('5S:6YG('1H92!03$%)3B!M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R!4:&4@=7-E<FED('1O(&%U=&AE;G1I8V%T92!A<RX*("`@("`J
M($!P87)A;2!S=')I;F<@5&AE('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T92!W
M:71H+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%
M05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@
M("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C
M8V5S<RX*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-I;F-E("`Q
M+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:%!L86EN*"1U:60L("1P
M=V0I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@
M)'1H:7,M/E]P=70H)T%55$@G+"`G4$Q!24XG*2DI('L*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@+RH@,S,T.B!#;VYT
M:6YU92!A=71H96YT:6-A=&EO;B!R97%U97-T("HO"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#,S
M-"DI*2!["B`@("`@("`@("`@("\J(#4P,SH@17)R;W(Z(&%L<F5A9'D@875T
M:&5N=&EC871E9"`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;V1E(#T]
M/2`U,#,I('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*
M("`@("`@("`D875T:%]S='(@/2!B87-E-C1?96YC;V1E*&-H<B@P*2`N("1U
M:60@+B!C:'(H,"D@+B`D<'=D*3L*"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)&%U=&A?<W1R*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("\J(#(S
M-3H@075T:&5N=&EC871I;VX@<W5C8V5S<V9U;"`J+PH@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@R
M,S4I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96YD('1H92!(14Q/(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!4:&4@9&]M86EN(&YA;64@=&\@<V%Y('=E(&%R92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@
M86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@
M:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@:&5L;R@D9&]M86EN*0H@("`@>PH@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=(14Q/)RP@)&1O;6%I
M;BDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R
M<V5297-P;VYS92@R-3`I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!396YD('1H92!-04E,($923TTZ(&-O;6UA;F0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5N9&5R("`@(%1H92!S96YD97(@
M*')E=F5R<V4@<&%T:"D@=&\@<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%R86US("`@(%-T<FEN9R!C;VYT86EN:6YG(&%D9&ET:6]N86P@34%)3"!P
M87)A;65T97)S+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('-U
M8V@@87,@=&AE($Y/5$E&62!F;&%G<R!D969I;F5D(&)Y(%)&0R`Q.#DQ"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@=&AE(%9%4E`@<')O
M=&]C;VPN"B`@("`@*@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M($EF("1P87)A;7,@:7,@86X@87)R87DL(&]N;'D@=&AE("=V97)P)R!O<'1I
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I<R!S=7!P;W)T
M960N("!)9B`G=F5R<"<@:7,@=')U92P@=&AE(%A615)0"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R(&ES(&%P<&5N9&5D('1O
M('1H92!-04E,(&-O;6UA;F0N("!)9@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H92`G=F5R<"<@=F%L=64@:7,@82!S=')I;F<L('1H92!F
M=6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@6%9%4E`]=F%L
M=64@<&%R86UE=&5R(&ES(&%P<&5N9&5D+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M
M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A
M:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!M
M86EL1G)O;2@D<V5N9&5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("`D87)G<R`](")&4D]-.CPD<V5N9&5R/B(["@H@("`@("`@("\J(%-U<'!O
M<G0@=&AE(&1E<')E8V%T960@87)R87D@9F]R;2!O9B`D<&%R86US+B`J+PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86US*2`F)B!I<W-E="@D<&%R86US
M6R=V97)P)UTI*2!["B`@("`@("`@("`@("\J(%A615)0("HO"B`@("`@("`@
M("`@(&EF("@D<&%R86US6R=V97)P)UT@/3T]('1R=64I('L*("`@("`@("`@
M("`@("`@("1A<F=S("X]("<@6%9%4E`G.PH*("`@("`@("`@("`@+RH@6%9%
M4E`]<V]M971H:6YG("HO"B`@("`@("`@("`@('T@96QS96EF("AT<FEM*"1P
M87)A;7-;)W9E<G`G72DI('L*("`@("`@("`@("`@("`@("1A<F=S("X]("<@
M6%9%4E`])R`N("1P87)A;7-;)W9E<G`G73L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("AI<U]S=')I;F<H)'!A<F%M<RDI('L*("`@("`@("`@
M("`@)&%R9W,@+CT@)R`G("X@)'!A<F%M<SL*("`@("`@("!]"@H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=-04E,
M)RP@)&%R9W,I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@
M("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI
M<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@4D-05"!43SH@8V]M;6%N9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96-I<&EE;G0@5&AE(')E
M8VEP:65N="`H9F]R=V%R9"!P871H*2!T;R!A9&0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87)A;7,@("`@4W1R:6YG(&-O;G1A:6YI;F<@861D:71I;VYA
M;"!20U!4('!A<F%M971E<G,L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W5C:"!A<R!T:&4@3D]42499(&9L86=S(&1E9FEN960@8GD@4D9#
M(#$X.3$N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@
M4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@
M*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S
M=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!R8W!T5&\H)')E8VEP
M:65N="P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)&%R9W,@/2`B
M5$\Z/"1R96-I<&EE;G0^(CL*("`@("`@("!I9B`H:7-?<W1R:6YG*"1P87)A
M;7,I*2!["B`@("`@("`@("`@("1A<F=S("X]("<@)R`N("1P87)A;7,["B`@
M("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@G4D-05"<L("1A<F=S*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*&%R<F%Y*#(U,"P@
M,C4Q*2DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%%U;W1E('1H92!D871A('-O('1H870@:70@;65E=',@4TU44"!S=&%N9&%R
M9',N"B`@("`@*@H@("`@("H@5&AI<R!I<R!P<F]V:61E9"!A<R!A('-E<&%R
M871E('!U8FQI8R!F=6YC=&EO;B!T;R!F86-I;&ET871E"B`@("`@*B!E87-I
M97(@;W9E<FQO861I;F<@9F]R('1H92!C87-E<R!W:&5R92!I="!I<R!D97-I
M<F%B;&4@=&\*("`@("`J(&-U<W1O;6EZ92!T:&4@<75O=&EN9R!B96AA=FEO
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("!4:&4@;65S
M<V%G92!T97AT('1O('%U;W1E+B!4:&4@<W1R:6YG(&UU<W0@8F4@<&%S<V5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!B>2!R969E<F5N8V4L(&%N
M9"!T:&4@=&5X="!W:6QL(&)E(&UO9&EF:65D(&EN('!L86-E+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,@H@("`@
M("HO"B`@("!F=6YC=&EO;B!Q=6]T961A=&$H)B1D871A*0H@("`@>PH@("`@
M("`@("\J($-H86YG92!5;FEX("A<;BD@86YD($UA8R`H7'(I(&QI;F5F965D
M<R!I;G1O"B`@("`@("`@("H@26YT97)N970M<W1A;F1A<F0@0U),1B`H7')<
M;BD@;&EN969E961S+B`J+PH@("`@("`@("1D871A(#T@<')E9U]R97!L86-E
M*&%R<F%Y*"<O*#\\(5QR*5QN+R<L)R]<<B@_(5QN*2\G*2P@(EQR7&XB+"`D
M9&%T82D["@H@("`@("`@("\J($)E8V%U<V4@82!S:6YG;&4@;&5A9&EN9R!P
M97)I;V0@*"XI('-I9VYI9FEE<R!A;B!E;F0@=&\@=&AE"B`@("`@("`@("H@
M9&%T82P@;&5G:71I;6%T92!L96%D:6YG('!E<FEO9',@;F5E9"!T;R!B92`B
M9&]U8FQE9"(*("`@("`@("`@*B`H92YG+B`G+BXG*2X@*B\*("`@("`@("`D
M9&%T82`]('-T<E]R97!L86-E*")<;BXB+"`B7&XN+B(L("1D871A*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE($1!5$$@8V]M;6%N9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("!4:&4@;65S<V%G92!B
M;V1Y('1O('-E;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U
M<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY
M"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U
M92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S
M:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A=&$H)&1A=&$I"B`@
M("!["B`@("`@("`@+RH@4D9#(#$X-S`L('-E8W1I;VX@,RP@<W5B<V5C=&EO
M;B`S('-T871E<R`B82!V86QU92!O9B!Z97)O"B`@("`@("`@("H@:6YD:6-A
M=&5S('1H870@;F\@9FEX960@;6%X:6UU;2!M97-S86=E('-I>F4@:7,@:6X@
M9F]R8V4B+@H@("`@("`@("`J($9U<G1H97)M;W)E+"!I="!S87ES('1H870@
M:68@(G1H92!P87)A;65T97(@:7,@;VUI='1E9"!N;PH@("`@("`@("`J(&EN
M9F]R;6%T:6]N(&ES(&-O;G9E>65D(&%B;W5T('1H92!S97)V97(G<R!F:7AE
M9"!M87AI;75M"B`@("`@("`@("H@;65S<V%G92!S:7IE(BX@*B\*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]E<VUT<%LG4TE:12==*2`F)B`H)'1H:7,M
M/E]E<VUT<%LG4TE:12==(#X@,"DI('L*("`@("`@("`@("`@:68@*'-T<FQE
M;B@D9&%T82D@/CT@)'1H:7,M/E]E<VUT<%LG4TE:12==*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TUE<W-A9V4@<VEZ92!E>&-E9&5S
M('1H92!S97)V97(@;&EM:70G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@475O=&4@=&AE(&1A=&$@8F%S960@;VX@=&AE(%--5%`@
M<W1A;F1A<F1S+B`J+PH@("`@("`@("1T:&ES+3YQ=6]T961A=&$H)&1A=&$I
M.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!U="@G1$%402<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!A<G-E4F5S<&]N<V4H,S4T*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1R97-U;'0@/2`D=&AI<RT^7W-E;F0H)&1A=&$@+B`B7')<;BY<<EQN
M(BDI*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A
M<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9"!T:&4@4T5.1"!&4D]-.B!C;VUM86YD+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE(')E=F5R<V4@<&%T:"!T;R!S
M96YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%
M05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@
M("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C
M8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N
M,BXV"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F1&<F]M*"1P871H*0H@("`@
M>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?
M<'5T*"=314Y$)RP@(D923TTZ/"1P871H/B(I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0F%C:W=A<F1S
M+6-O;7!A=&EB:6QI='D@=W)A<'!E<B!F;W(@<V5N9$9R;VTH*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@<V5N
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%2
M7T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@
M("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E
M<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@("`@('!U8FQI8PH@("`@("H@
M0'-I;F-E("`@("`@(#$N,`H@("`@("H@0&1E<')E8V%T960@(#$N,BXV"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E;F1?9G)O;2@D<&%T:"D*("`@('L*("`@
M("`@("!R971U<FX@<V5N9$9R;VTH)'!A=&@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5N9"!T:&4@4T]-3"!&4D]-.B!C;VUM86YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@5&AE(')E=F5R<V4@<&%T:"!T;R!S96YD+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R
M;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@
M("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,BXV"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-O;6Q&<F]M*"1P871H*0H@("`@>PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=3
M3TU,)RP@(D923TTZ/"1P871H/B(I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0F%C:W=A<F1S+6-O;7!A
M=&EB:6QI='D@=W)A<'!E<B!F;W(@<V]M;$9R;VTH*2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@<V5N9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R
M('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@
M("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@("`@('!U8FQI8PH@("`@("H@0'-I;F-E
M("`@("`@(#$N,`H@("`@("H@0&1E<')E8V%T960@(#$N,BXV"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-O;6Q?9G)O;2@D<&%T:"D*("`@('L*("`@("`@("!R
M971U<FX@<V]M;$9R;VTH)'!A=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5N9"!T:&4@4T%-3"!&4D]-.B!C;VUM86YD+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@5&AE(')E=F5R<V4@<&%T:"!T;R!S96YD+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET
M:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@
M("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,BXV"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-A;6Q&<F]M*"1P871H*0H@("`@>PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=304U,)RP@
M(D923TTZ/"1P871H/B(I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@
M/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0F%C:W=A<F1S+6-O;7!A=&EB:6QI
M='D@=W)A<'!E<B!F;W(@<V%M;$9R;VTH*2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@<V5N9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@
M86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@
M:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@("`@('!U8FQI8PH@("`@("H@0'-I;F-E("`@("`@
M(#$N,`H@("`@("H@0&1E<')E8V%T960@(#$N,BXV"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-A;6Q?9G)O;2@D<&%T:"D*("`@('L*("`@("`@("!R971U<FX@
M<V%M;$9R;VTH)'!A=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T
M:&4@4E-%5"!C;VUM86YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N
M(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R
M('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!R<V5T*"D*("`@
M('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!U="@G4E-%5"<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@5E)&62!C;VUM86YD+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('-T<FEN9R!T;R!V97)I
M9GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%2
M7T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@
M("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E
M<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@=G)F>2@D<W1R:6YG*0H@("`@>PH@("`@
M("`@("\J($YO=&4Z(#(U,2!I<R!A;'-O(&$@=F%L:60@<F5S<&]N<V4@8V]D
M92`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES
M+3Y?<'5T*"=64D99)RP@)'-T<FEN9RDI*2!["B`@("`@("`@("`@(')E='5R
M;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92AA<G)A>2@R-3`L(#(U
M,BDI*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96YD('1H92!.3T]0(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A
M9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R
M92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO;W`H
M*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T
M:&ES+3Y?<'5T*"=.3T]0)RDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O
M<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@R-3`I*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"86-K=V%R9',M8V]M<&%T:6)I
M;&ET>2!M971H;V0N("!I9&5N=&EF>5-E;F1E<B@I)W,@9G5N8W1I;VYA;&ET
M>2!I<PH@("`@("H@;F]W(&AA;F1L960@:6YT97)N86QL>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N("!B;V]L96%N("`@("!4:&ES(&UE=&AO9"!A;'=A>7,@
M<F5T=7)N('1R=64N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<VEN8V4@("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@:61E;G1I
M9GE396YD97(H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+U523"YP
M:'``````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,S(V,S0`,3`U,34T,S$P-3<`,#$W,C4R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`T
M+"!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\#0HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(%)E9&ES=')I8G5T:6]N
M(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@
M=VET:&]U="`@("!\#0HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E
M9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\
M#0HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS
M(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG
M:'0@("`@("!\#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\#0HO
M+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P
M<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\#0HO+R!\("`@;F]T:6-E
M+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D
M:7-C;&%I;65R(&EN('1H92!\#0HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O
M;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U
M=&EO;BY\#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N
M;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\#0HO+R!\
M("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U
M="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\#0HO+R!\("`@<&5R;6ES<VEO
M;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\#0HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/
M4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\#0HO+R!\(")!
M4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@
M24Y#3%5$24Y'+"!"550@3D]4("`@("!\#0HO+R!\($Q)34E4140@5$\L(%1(
M12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&
M251.15-3($9/4B!\#0HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$
M25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\
M#0HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.
M62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\#0HO+R!\(%-014-)
M04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@("`@("!\#0HO+R!\($Q)34E4140@5$\L(%!23T-5
M4D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@
M3T8@55-%+"!\#0HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3
M($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\#0HO
M+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L
M(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\#0HO+R!\("A)3D-,541)
M3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!
M62!/550@3T8@5$A%(%5312!\#0HO+R!\($]&(%1(25,@4T]&5%=!4D4L($56
M14X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!
M1T4N("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<CH@4FEC
M:&%R9"!(97EE<R`\<FEC:&%R9"!A="!P:'`@;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK#0HO+PT*+R\@)$ED.B!54DPN<&AP+'8@,2XS-B`R,#`T+S`V+S$Y(#$X
M.C4X.C4P(')I8VAA<F0@17AP("0-"B\O#0HO+R!.971?55),($-L87-S#0H-
M"F-L87-S($YE=%]54DP-"GL-"B`@("`O*BH-"B`@("`J($9U;&P@=7)L#0H@
M("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1U<FP[#0H-"B`@
M("`O*BH-"B`@("`J(%!R;W1O8V]L#0H@("`@*B!`=F%R('-T<FEN9PT*("`@
M("HO#0H@("`@=F%R("1P<F]T;V-O;#L-"@T*("`@("\J*@T*("`@("H@57-E
M<FYA;64-"B`@("`J($!V87(@<W1R:6YG#0H@("`@*B\-"B`@("!V87(@)'5S
M97)N86UE.PT*#0H@("`@+RHJ#0H@("`@*B!087-S=V]R9`T*("`@("H@0'9A
M<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D<&%S<W=O<F0[#0H-"B`@("`O
M*BH-"B`@("`J($AO<W0-"B`@("`J($!V87(@<W1R:6YG#0H@("`@*B\-"B`@
M("!V87(@)&AO<W0[#0H-"B`@("`O*BH-"B`@("`J(%!O<G0-"B`@("`J($!V
M87(@:6YT96=E<@T*("`@("HO#0H@("`@=F%R("1P;W)T.PT*#0H@("`@+RHJ
M#0H@("`@*B!0871H#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@
M=F%R("1P871H.PT*#0H@("`@+RHJ#0H@("`@*B!1=65R>2!S=')I;F<-"B`@
M("`J($!V87(@87)R87D-"B`@("`J+PT*("`@('9A<B`D<75E<GES=')I;F<[
M#0H-"B`@("`O*BH-"B`@("`J($%N8VAO<@T*("`@("H@0'9A<B!S=')I;F<-
M"B`@("`J+PT*("`@('9A<B`D86YC:&]R.PT*#0H@("`@+RHJ#0H@("`@*B!7
M:&5T:&5R('1O('5S92!;70T*("`@("H@0'9A<B!B;V]L#0H@("`@*B\-"B`@
M("!V87(@)'5S94)R86-K971S.PT*#0H@("`@+RHJ#0H@("`@*B!02%`T($-O
M;G-T<G5C=&]R#0H@("`@*@T*("`@("H@0'-E92!?7V-O;G-T<G5C="@I#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!.971?55),*"1U<FP@/2!N=6QL+"`D=7-E
M0G)A8VME=',@/2!T<G5E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]?8V]N
M<W1R=6-T*"1U<FPL("1U<V5"<F%C:V5T<RD[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@*B!02%`U($-O;G-T<G5C=&]R#0H@("`@*@T*("`@("H@4&%R<V5S
M('1H92!G:79E;B!U<FP@86YD('-T;W)E<R!T:&4@=F%R:6]U<R!P87)T<PT*
M("`@("H@1&5F875L=',@87)E('5S960@:6X@8V5R=&%I;B!C87-E<PT*("`@
M("H-"B`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("`@($]P=&EO;F%L
M(%523`T*("`@("H@0'!A<F%M(&)O;VP@("`D=7-E0G)A8VME=',@5VAE=&AE
M<B!T;R!U<V4@<W%U87)E(&)R86-K971S('=H96X-"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&UU;'1I<&QE('%U97)Y<W1R:6YG<R!W:71H
M('1H92!S86UE(&YA;64-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5X:7-T#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?7V-O;G-T<G5C="@D
M=7)L(#T@;G5L;"P@)'5S94)R86-K971S(#T@=')U92D-"B`@("![#0H@("`@
M("`@("1(5%107U-%4E9%4E]605)3("`]("%E;7!T>2@D7U-%4E9%4BD@/R`D
M7U-%4E9%4B`Z("1'3$]"04Q36R=(5%107U-%4E9%4E]605)3)UT[#0H-"B`@
M("`@("`@)'1H:7,M/G5S94)R86-K971S(#T@)'5S94)R86-K971S.PT*("`@
M("`@("`D=&AI<RT^=7)L("`@("`@("`@/2`D=7)L.PT*("`@("`@("`D=&AI
M<RT^=7-E<B`@("`@("`@/2`G)SL-"B`@("`@("`@)'1H:7,M/G!A<W,@("`@
M("`@(#T@)R<[#0H@("`@("`@("1T:&ES+3YH;W-T("`@("`@("`]("<G.PT*
M("`@("`@("`D=&AI<RT^<&]R="`@("`@("`@/2`X,#L-"B`@("`@("`@)'1H
M:7,M/G!A=&@@("`@("`@(#T@)R<[#0H@("`@("`@("1T:&ES+3YQ=65R>7-T
M<FEN9R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3YA;F-H;W(@("`@("`]
M("<G.PT*#0H@("`@("`@("\O($]N;'D@=7-E(&1E9F%U;'1S(&EF(&YO="!A
M;B!A8G-O;'5T92!54DP@9VEV96X-"B`@("`@("`@:68@*"%P<F5G7VUA=&-H
M*"<O7EMA+7HP+3E=*SI<+UPO+VDG+"`D=7)L*2D@>PT*#0H@("`@("`@("`@
M("`D=&AI<RT^<')O=&]C;VP@("`@/2`H0"1(5%107U-%4E9%4E]605)36R=(
M5%104R==(#T]("=O;B<@/R`G:'1T<',G(#H@)VAT='`G*3L-"@T*("`@("`@
M("`@("`@+RHJ#0H@("`@("`@("`@("`J($9I9W5R92!O=70@:&]S="]P;W)T
M#0H@("`@("`@("`@("`J+PT*("`@("`@("`@("`@:68@*"%E;7!T>2@D2%14
M4%]315)615)?5D%24ULG2%144%](3U-4)UTI($%.1"!P<F5G7VUA=&-H*"<O
M7B@N*BDH.BA;,"TY72LI*3\D+U4G+"`D2%144%]315)615)?5D%24ULG2%14
M4%](3U-4)UTL("1M871C:&5S*2D@>PT*("`@("`@("`@("`@("`@("1H;W-T
M(#T@)&UA=&-H97-;,5T[#0H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M;6%T8VAE<ULS72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!O<G0@/2`D
M;6%T8VAE<ULS73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D<&]R="`]("1T:&ES+3YG9713=&%N9&%R9%!O<G0H
M)'1H:7,M/G!R;W1O8V]L*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H-"B`@("`@("`@("`@("1T:&ES+3YU<V5R("`@("`@("`]("<G
M.PT*("`@("`@("`@("`@)'1H:7,M/G!A<W,@("`@("`@(#T@)R<[#0H@("`@
M("`@("`@("`D=&AI<RT^:&]S="`@("`@("`@/2`A96UP='DH)&AO<W0I(#\@
M)&AO<W0@.B`H:7-S970H)$A45%!?4T525D527U9!4E-;)U-%4E9%4E].04U%
M)UTI(#\@)$A45%!?4T525D527U9!4E-;)U-%4E9%4E].04U%)UT@.B`G;&]C
M86QH;W-T)RD[#0H@("`@("`@("`@("`D=&AI<RT^<&]R="`@("`@("`@/2`A
M96UP='DH)'!O<G0I(#\@)'!O<G0@.B`H:7-S970H)$A45%!?4T525D527U9!
M4E-;)U-%4E9%4E]03U)4)UTI(#\@)$A45%!?4T525D527U9!4E-;)U-%4E9%
M4E]03U)4)UT@.B`D=&AI<RT^9V5T4W1A;F1A<F10;W)T*"1T:&ES+3YP<F]T
M;V-O;"DI.PT*("`@("`@("`@("`@)'1H:7,M/G!A=&@@("`@("`@(#T@(65M
M<'1Y*"1(5%107U-%4E9%4E]605)36R=02%!?4T5,1B==*2`_("1(5%107U-%
M4E9%4E]605)36R=02%!?4T5,1B==(#H@)R\G.PT*("`@("`@("`@("`@)'1H
M:7,M/G%U97)Y<W1R:6YG(#T@:7-S970H)$A45%!?4T525D527U9!4E-;)U%5
M15)97U-44DE.1R==*2`_("1T:&ES+3Y?<&%R<V5287=1=65R>7-T<FEN9R@D
M2%144%]315)615)?5D%24ULG455%4EE?4U1224Y')UTI(#H@;G5L;#L-"B`@
M("`@("`@("`@("1T:&ES+3YA;F-H;W(@("`@("`]("<G.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@4&%R<V4@=&AE('5R;"!A;F0@<W1O<F4@=&AE('9A
M<FEO=7,@<&%R=',-"B`@("`@("`@:68@*"%E;7!T>2@D=7)L*2D@>PT*("`@
M("`@("`@("`@)'5R;&EN9F\@/2!P87)S95]U<FPH)'5R;"D[#0H-"B`@("`@
M("`@("`@("\O($1E9F%U;'0@<75E<GES=')I;F<-"B`@("`@("`@("`@("1T
M:&ES+3YQ=65R>7-T<FEN9R`](&%R<F%Y*"D[#0H-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1U<FQI;F9O(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@
M("`@("`@("`@<W=I=&-H("@D:V5Y*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W-C:&5M92<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<')O=&]C;VP@/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<&]R="`@("`@/2`D=&AI<RT^9V5T4W1A;F1A<F10;W)T*"1V
M86QU92D[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@
M("`@("`@("`@("`@("`@("!C87-E("=U<V5R)SH-"B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G<&%S<R<Z#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)VAO<W0G.@T*("`@("`@("`@("`@("`@("`@("!C87-E("=P;W)T)SH-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G<&%T:"<Z#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'9A;'5E>S!](#T]("<O)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YP871H(#T@)'9A;'5E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%T:"`](&1I<FYA;64H)'1H:7,M/G!A=&@I(#T]($1)4D5#5$]2
M65]315!!4D%43U(@/R`G)R`Z(&1I<FYA;64H)'1H:7,M/G!A=&@I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP871H(#T@<W!R:6YT
M9B@G)7,O)7,G+"`D<&%T:"P@)'9A;'5E*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)W%U97)Y)SH-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YQ=65R>7-T<FEN9R`]("1T:&ES+3Y?<&%R
M<V5287=1=65R>5-T<FEN9R@D=F%L=64I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G9G)A
M9VUE;G0G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%N8VAO
M<B`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\J*@T*("`@("H@4F5T=7)N<R!F=6QL('5R;`T*("`@
M("H-"B`@("`J($!R971U<FX@<W1R:6YG($9U;&P@=7)L#0H@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T55),*"D-"B`@
M("![#0H@("`@("`@("1Q=65R>7-T<FEN9R`]("1T:&ES+3YG9711=65R>5-T
M<FEN9R@I.PT*#0H@("`@("`@("1T:&ES+3YU<FP@/2`D=&AI<RT^<')O=&]C
M;VP@+B`G.B\O)PT*("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/G5S97(@
M+B`H(65M<'1Y*"1T:&ES+3YP87-S*2`_("<Z)R`Z("<G*0T*("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/G!A<W,@+B`H(65M<'1Y*"1T:&ES+3YU<V5R
M*2`_("=`)R`Z("<G*0T*("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/FAO
M<W0@+B`H)'1H:7,M/G!O<G0@/3T@)'1H:7,M/F=E=%-T86YD87)D4&]R="@D
M=&AI<RT^<')O=&]C;VPI(#\@)R<@.B`G.B<@+B`D=&AI<RT^<&]R="D-"B`@
M("`@("`@("`@("`@("`@("`N("1T:&ES+3YP871H#0H@("`@("`@("`@("`@
M("`@("`@+B`H(65M<'1Y*"1Q=65R>7-T<FEN9RD@/R`G/R<@+B`D<75E<GES
M=')I;F<@.B`G)RD-"B`@("`@("`@("`@("`@("`@("`N("@A96UP='DH)'1H
M:7,M/F%N8VAO<BD@/R`G(R<@+B`D=&AI<RT^86YC:&]R(#H@)R<I.PT*#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^=7)L.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("H@061D<R!A('%U97)Y<W1R:6YG(&ET96T-"B`@("`J#0H@("`@*B!`
M<&%R86T@('-T<FEN9R`D;F%M92`@("`@("!.86UE(&]F(&ET96T-"B`@("`J
M($!P87)A;2`@<W1R:6YG("1V86QU92`@("`@(%9A;'5E(&]F(&ET96T-"B`@
M("`J($!P87)A;2`@8F]O;"`@("1P<F5E;F-O9&5D(%=H971H97(@=F%L=64@
M:7,@=7)L96YC;V1E9"!O<B!N;W0L(&1E9F%U;'0@/2!N;W0-"B`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A9&11=65R>5-T
M<FEN9R@D;F%M92P@)'9A;'5E+"`D<')E96YC;V1E9"`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@:68@*"1P<F5E;F-O9&5D*2![#0H@("`@("`@("`@("`D
M=&AI<RT^<75E<GES=')I;F=;)&YA;65=(#T@)'9A;'5E.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/G%U97)Y<W1R:6YG6R1N86UE
M72`](&ES7V%R<F%Y*"1V86QU92D@/R!A<G)A>5]M87`H)W)A=W5R;&5N8V]D
M92<L("1V86QU92DZ(')A=W5R;&5N8V]D92@D=F%L=64I.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!296UO=F5S(&$@<75E<GES=')I
M;F<@:71E;0T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1N86UE($YA
M;64@;V8@:71E;0T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(')E;6]V95%U97)Y4W1R:6YG*"1N86UE*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YQ=65R>7-T<FEN9ULD;F%M95TI*2![
M#0H@("`@("`@("`@("!U;G-E="@D=&AI<RT^<75E<GES=')I;F=;)&YA;65=
M*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("H@4V5T<R!T
M:&4@<75E<GES=')I;F<@=&\@;&ET97)A;&QY('=H870@>6]U('-U<'!L>0T*
M("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1Q=65R>7-T<FEN9R!4:&4@
M<75E<GES=')I;F<@9&%T82X@4VAO=6QD(&)E(&]F('1H92!F;W)M870@9F]O
M/6)A<B9X/7D@971C#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@861D4F%W475E<GE3=')I;F<H)'%U97)Y<W1R:6YG*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/G%U97)Y<W1R:6YG(#T@)'1H:7,M/E]P
M87)S95)A=U%U97)Y4W1R:6YG*"1Q=65R>7-T<FEN9RD[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@*B!2971U<FYS(&9L870@<75E<GES=')I;F<-"B`@("`J
M#0H@("`@*B!`<F5T=7)N('-T<FEN9R!1=65R>7-T<FEN9PT*("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%%U97)Y4W1R
M:6YG*"D-"B`@("![#0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/G%U97)Y
M<W1R:6YG*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/G%U97)Y
M<W1R:6YG(&%S("1N86UE(#T^("1V86QU92D@>PT*("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D=F%L=64I*2![#0H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1V86QU92!A<R`D:R`]/B`D=BD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'%U97)Y<W1R:6YG6UT@/2`D=&AI<RT^=7-E0G)A8VME
M=',@/R!S<')I;G1F*"<E<ULE<UT])7,G+"`D;F%M92P@)&LL("1V*2`Z("@D
M;F%M92`N("<])R`N("1V*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T@96QS96EF("@A:7-?;G5L;"@D=F%L=64I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1Q=65R>7-T<FEN9UM=(#T@)&YA;64@+B`G
M/2<@+B`D=F%L=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@)'%U97)Y<W1R:6YG6UT@/2`D;F%M93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<75E
M<GES=')I;F<@/2!I;7!L;V1E*&EN:5]G970H)V%R9U]S97!A<F%T;W(N;W5T
M<'5T)RDL("1Q=65R>7-T<FEN9RD[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D<75E<GES=')I;F<@/2`G)SL-"B`@("`@("`@?0T*#0H@("`@
M("`@(')E='5R;B`D<75E<GES=')I;F<[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@*B!087)S97,@<F%W('%U97)Y<W1R:6YG(&%N9"!R971U<FYS(&%N(&%R
M<F%Y(&]F(&ET#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@("1Q=65R
M>7-T<FEN9R!4:&4@<75E<GES=')I;F<@=&\@<&%R<V4-"B`@("`J($!R971U
M<FX@87)R87D@("`@("`@("`@("`@("`@06X@87)R87D@;V8@=&AE('%U97)Y
M<W1R:6YG(&1A=&$-"B`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("HO#0H@
M("`@9G5N8W1I;VX@7W!A<G-E4F%W475E<GES=')I;F<H)'%U97)Y<W1R:6YG
M*0T*("`@('L-"B`@("`@("`@)'!A<G1S("`]('!R96=?<W!L:70H)R];)R`N
M('!R96=?<75O=&4H:6YI7V=E="@G87)G7W-E<&%R871O<BYI;G!U="<I+"`G
M+R<I("X@)UTO)RP@)'%U97)Y<W1R:6YG+"`M,2P@4%)%1U]34$Q)5%].3U]%
M35!462D[#0H@("`@("`@("1R971U<FX@/2!A<G)A>2@I.PT*#0H@("`@("`@
M(&9O<F5A8V@@*"1P87)T<R!A<R`D<&%R="D@>PT*("`@("`@("`@("`@:68@
M*'-T<G!O<R@D<&%R="P@)STG*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@
M("`@("`D=F%L=64@/2!S=6)S='(H)'!A<G0L('-T<G!O<R@D<&%R="P@)STG
M*2`K(#$I.PT*("`@("`@("`@("`@("`@("1K97D@("`]('-U8G-T<B@D<&%R
M="P@,"P@<W1R<&]S*"1P87)T+"`G/2<I*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@;G5L;#L-"B`@("`@("`@
M("`@("`@("`D:V5Y("`@/2`D<&%R=#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AS=6)S='(H)&ME>2P@+3(I(#T]("=;72<I('L-"B`@("`@
M("`@("`@("`@("`D:V5Y(#T@<W5B<W1R*"1K97DL(#`L("TR*3L-"B`@("`@
M("`@("`@("`@("!I9B`H0"%I<U]A<G)A>2@D<F5T=7)N6R1K97E=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=("`@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=6UT@/2`D=F%L
M=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)')E='5R;ELD:V5Y75M=(#T@)'9A;'5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T@96QS96EF("@A)'1H:7,M/G5S94)R86-K
M971S($%.1"`A96UP='DH)')E='5R;ELD:V5Y72DI('L-"B`@("`@("`@("`@
M("`@("`D<F5T=7)N6R1K97E=("`@/2`H87)R87DI)')E='5R;ELD:V5Y73L-
M"B`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=6UT@/2`D=F%L=64[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1R971U<FY;
M)&ME>5T@/2`D=F%L=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*
M("`@("`@("!R971U<FX@)')E='5R;CL-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`J(%)E<V]L=F5S("\O+"`N+B\@86YD("XO(&9R;VT@82!P871H(&%N9"!R
M971U<FYS#0H@("`@*B!T:&4@<F5S=6QT+B!%9SH-"B`@("`J#0H@("`@*B`O
M9F]O+V)A<B\N+B]B;V\N<&AP("`@(#T^("]F;V\O8F]O+G!H<`T*("`@("H@
M+V9O;R]B87(O+BXO+BXO8F]O+G!H<"`]/B`O8F]O+G!H<`T*("`@("H@+V9O
M;R]B87(O+BXO+B\O8F]O+G!H<"`]/B`O9F]O+V)O;RYP:'`-"B`@("`J#0H@
M("`@*B!4:&ES(&UE=&AO9"!C86X@86QS;R!B92!C86QL960@<W1A=&EC86QL
M>2X-"B`@("`J#0H@("`@*B!`<&%R86T@('-T<FEN9R`D=7)L(%523"!P871H
M('1O(')E<V]L=F4-"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@5&AE(')E
M<W5L=`T*("`@("HO#0H@("`@9G5N8W1I;VX@<F5S;VQV95!A=&@H)'!A=&@I
M#0H@("`@>PT*("`@("`@("`D<&%T:"`](&5X<&QO9&4H)R\G+"!S=')?<F5P
M;&%C92@G+R\G+"`G+R<L("1P871H*2D[#0H-"B`@("`@("`@9F]R("@D:3TP
M.R`D:3QC;W5N="@D<&%T:"D[("1I*RLI('L-"B`@("`@("`@("`@(&EF("@D
M<&%T:%LD:5T@/3T@)RXG*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'!A
M=&A;)&E=*3L-"B`@("`@("`@("`@("`@("`D<&%T:"`](&%R<F%Y7W9A;'5E
M<R@D<&%T:"D[#0H@("`@("`@("`@("`@("`@)&DM+3L-"@T*("`@("`@("`@
M("`@?2!E;'-E:68@*"1P871H6R1I72`]/2`G+BXG($%.1"`H)&D@/B`Q($]2
M("@D:2`]/2`Q($%.1"`D<&%T:%LP72`A/2`G)RD@*2`I('L-"B`@("`@("`@
M("`@("`@("!U;G-E="@D<&%T:%LD:5TI.PT*("`@("`@("`@("`@("`@('5N
M<V5T*"1P871H6R1I+3%=*3L-"B`@("`@("`@("`@("`@("`D<&%T:"`](&%R
M<F%Y7W9A;'5E<R@D<&%T:"D[#0H@("`@("`@("`@("`@("`@)&D@+3T@,CL-
M"@T*("`@("`@("`@("`@?2!E;'-E:68@*"1P871H6R1I72`]/2`G+BXG($%.
M1"`D:2`]/2`Q($%.1"`D<&%T:%LP72`]/2`G)RD@>PT*("`@("`@("`@("`@
M("`@('5N<V5T*"1P871H6R1I72D[#0H@("`@("`@("`@("`@("`@)'!A=&@@
M/2!A<G)A>5]V86QU97,H)'!A=&@I.PT*("`@("`@("`@("`@("`@("1I+2T[
M#0H-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!R
M971U<FX@:6UP;&]D92@G+R<L("1P871H*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`J(%)E='5R;G,@=&AE('-T86YD87)D('!O<G0@;G5M8F5R(&9O<B!A
M('!R;W1O8V]L#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@("1S8VAE
M;64@5&AE('!R;W1O8V]L('1O(&QO;VMU<`T*("`@("H@0')E='5R;B!I;G1E
M9V5R("`@("`@("`@4&]R="!N=6UB97(@;W(@3E5,3"!I9B!N;R!S8VAE;64@
M;6%T8VAE<PT*("`@("H-"B`@("`J($!A=71H;W(@4&AI;&EP<&4@2F%U<VEO
M;G,@/%!H:6QI<'!E+DIA=7-I;VYS0#$Q86)A8W5S+F-O;3X-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=%-T86YD87)D4&]R="@D<V-H96UE*0T*("`@('L-
M"B`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1S8VAE;64I*2![#0H@("`@
M("`@("`@("!C87-E("=H='1P)SH@("`@<F5T=7)N(#@P.PT*("`@("`@("`@
M("`@8V%S92`G:'1T<',G.B`@(')E='5R;B`T-#,[#0H@("`@("`@("`@("!C
M87-E("=F='`G.B`@("`@<F5T=7)N(#(Q.PT*("`@("`@("`@("`@8V%S92`G
M:6UA<"<Z("`@(')E='5R;B`Q-#,[#0H@("`@("`@("`@("!C87-E("=I;6%P
M<R<Z("`@<F5T=7)N(#DY,SL-"B`@("`@("`@("`@(&-A<V4@)W!O<#,G.B`@
M("!R971U<FX@,3$P.PT*("`@("`@("`@("`@8V%S92`G<&]P,W,G.B`@(')E
M='5R;B`Y.34[#0H@("`@("`@("`@("!D969A=6QT.B`@("`@("`@<F5T=7)N
M(&YU;&P[#0H@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("H@1F]R
M8V5S('1H92!54DP@=&\@82!P87)T:6-U;&%R('!R;W1O8V]L#0H@("`@*@T*
M("`@("H@0'!A<F%M('-T<FEN9R`@)'!R;W1O8V]L(%!R;W1O8V]L('1O(&9O
M<F-E('1H92!54DP@=&\-"B`@("`J($!P87)A;2!I;G1E9V5R("1P;W)T("`@
M("!/<'1I;VYA;"!P;W)T("AS=&%N9&%R9"!P;W)T(&ES('5S960@8GD@9&5F
M875L="D-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=%!R;W1O8V]L*"1P<F]T
M;V-O;"P@)'!O<G0@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)'1H:7,M/G!R
M;W1O8V]L(#T@)'!R;W1O8V]L.PT*("`@("`@("`D=&AI<RT^<&]R="`](&ES
M7VYU;&PH)'!O<G0I(#\@)'1H:7,M/F=E=%-T86YD87)D4&]R="@I(#H@)'!O
M<G0[#0H@("`@?0T*#0I]#0H_/@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B].970O1E10+G!H<```````````````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(Q,C$R-``Q,#4Q-30S,3`U-P`P
M,3<R,S,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF
M='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!.971?1E10(&UA
M:6X@9FEL92X*("H*("H@5&AI<R!F:6QE(&UU<W0@8F4@:6YC;'5D960@=&\@
M=7-E('1H92!.971?1E10('!A8VMA9V4N"B`J"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!.971W;W)K:6YG"B`J($!P
M86-K86=E("`@($944`H@*B!`875T:&]R("`@("!4;V)I87,@4V-H;&ET="`\
M=&]B>4!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z($944"YP:'`L=B`Q+C0R(#(P,#4O,#,O,S$@,C`Z,#<Z-3@@
M=&]B>2!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O3F5T7T944`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#`N,"XQ"B`J+PH*<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<["@HO*BH*("H@3W!T:6]N('1O(&QE="!T:&4@;',H*2!M971H;V0@
M<F5T=7)N(&]N;'D@9FEL97,N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@
M3D547T944%]&24Q%4U]/3DQ9"B`J($!S964@3F5T7T944#HZ;',H*0H@*B\*
M9&5F:6YE*"=.151?1E107T9)3$537T].3%DG+"`P+"!T<G5E*3L*"B\J*@H@
M*B!/<'1I;VX@=&\@;&5T('1H92!L<R@I(&UE=&AO9"!R971U<FX@;VYL>2!D
M:7)E8W1O<FEE<RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E10
M7T1)4E-?3TY,60H@*B!`<V5E($YE=%]&5%`Z.FQS*"D*("HO"F1E9FEN92@G
M3D547T944%]$25)37T].3%DG+"`Q+"!T<G5E*3L*"B\J*@H@*B!/<'1I;VX@
M=&\@;&5T('1H92!L<R@I(&UE=&AO9"!R971U<FX@9&ER96-T;W)I97,@86YD
M(&9I;&5S("AD969A=6QT*2X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107T1)4E-?1DE,15,*("H@0'-E92!.971?1E10.CIL<R@I"B`J+PID
M969I;F4H)TY%5%]&5%!?1$E24U]&24Q%4R<L(#(L('1R=64I.PH*+RHJ"B`J
M($]P=&EO;B!T;R!L970@=&AE(&QS*"D@;65T:&]D(')E='5R;B!T:&4@<F%W
M(&1I<F5C=&]R>2!L:7-T:6YG(&9R;VT@9G1P7W)A=VQI<W0H*2X*("H*("H@
M0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107U)!5TQ)4U0*("H@0'-E92!.
M971?1E10.CIL<R@I"B`J+PID969I;F4H)TY%5%]&5%!?4D%73$E35"<L(#,L
M('1R=64I.PH*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E(&$@9F%I
M;&5D(&-O;FYE8W1I;VX*("H@5&AI<R!E<G)O<B!C;V1E(&EN9&EC871E<RP@
M=&AA="!T:&4@8V]N;F5C=&EO;B!Y;W4@=')Y960@=&\@<V5T('5P"B`J(&-O
M=6QD(&YO="!B92!E<W1A8FQI<VAE9"X@0VAE8VL@>6]U<B!C;VYN96-T:6]N
M('-E='1I;F=S("AH;W-T("8@<&]R="DA"B`J"B`J($!S:6YC92`Q+C,*("H@
M0&YA;64@3D547T944%]%4E)?0T].3D5#5%]&04E,140*("H@0'-E92!.971?
M1E10.CIC;VYN96-T*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?0T].3D5#
M5%]&04E,140G+"`M,2D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T
M92!A(&9A:6QE9"!L;V=I;@H@*B!4:&ES(&5R<F]R(&-O9&4@:6YD:6-A=&5S
M+"!T:&%T('1H92!L;V=I;B!T;R!T:&4@1E10('-E<G9E<B!F86EL960N($-H
M96-K"B`J('EO=7(@=7-E<B!D871A("AU<V5R;F%M92`F('!A<W-W;W)D*2X*
M("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E],3T=)3E]&
M04E,140*("H@0'-E92!.971?1E10.CIL;V=I;B@I"B`J+PID969I;F4H)TY%
M5%]&5%!?15)27TQ/1TE.7T9!24Q%1"<L("TR*3L*"B\J*@H@*B!%<G)O<B!C
M;V1E('1O(&EN9&EC871E(&$@9F%I;&5D(&1I<F5C=&]R>2!C:&%N9V4*("H@
M5&AE(&-D*"D@;65T:&]D(&9A:6QE9"X@16YS=7)E('1H870@=&AE(&1I<F5C
M=&]R>2!Y;W4@=V%N=&5D('1O(&%C8V5S<R!E>&ES=',N"B`J"B`J($!S:6YC
M92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?1$E20TA!3D=%7T9!24Q%1`H@
M*B!`<V5E($YE=%]&5%`Z.F-D*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?
M1$E20TA!3D=%7T9!24Q%1"<L(#(I.R`O+R!#;VUP871I8FEL;&ET>2!R96%S
M;VYS(0H*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!.971?
M1E10(&-O=6QD(&YO="!D971E<FUI;F4@=&AE(&-U<G)E;G0@<&%T:`H@*B!4
M:&4@8W=D*"D@;65T:&]D(&9A:6QE9"!A;F0@8V]U;&0@;F]T(&1E=&5R;6EN
M92!T:&4@<&%T:"!Y;W4@8W5R<F5N=&QY(')E<VED90H@*B!I;B!O;B!T:&4@
M1E10('-E<G9E<BX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E10
M7T524E]$151%4DU)3D50051(7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.G!W
M9"@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T1%5$5234E.15!!5$A?1D%)
M3$5$)RP@-"D[("\O($-O;7!A=&EB:6QL:71Y(')E87-O;G,A"@HO*BH*("H@
M17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!C<F5A=&EO;B!O9B!A
M(&1I<F5C=&]R>2!F86EL960*("H@5&AE(&1I<F5C=&]R>2!Y;W4@=')Y960@
M=&\@8W)E871E(&-O=6QD(&YO="!B92!C<F5A=&5D+B!#:&5C:R!T:&4*("H@
M86-C97-S(')I9VAT<R!O;B!T:&4@<&%R96YT(&1I<F5C=&]R>2$*("H*("H@
M0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]#4D5!5$5$25)?1D%)
M3$5$"B`J($!S964@3F5T7T944#HZ;6MD:7(H*0H@*B\*9&5F:6YE*"=.151?
M1E107T524E]#4D5!5$5$25)?1D%)3$5$)RP@+30I.PH*+RHJ"B`J($5R<F]R
M(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@15A%0R!E>&5C=71I;VX@9F%I
M;&5D+@H@*B!4:&4@97AE8W5T:6]N(&]F(&$@8V]M;6%N9"!U<VEN9R!%6$5#
M(&9A:6QE9"X@16YS=7)E+"!T:&%T('EO=7(*("H@1E10('-E<G9E<B!S=7!P
M;W)T<R!T:&4@15A%0R!C;VUM86YD+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N
M86UE($Y%5%]&5%!?15)27T5814-?1D%)3$5$"B`J($!S964@3F5T7T944#HZ
M97AE8W5T92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T5814-?1D%)3$5$
M)RP@+34I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T
M:&4@4TE412!C;VUM86YD(&9A:6QE9"X*("H@5&AE(&5X96-U=&EO;B!O9B!A
M(&-O;6UA;F0@=7-I;F<@4TE412!F86EL960N($5N<W5R92P@=&AA="!Y;W5R
M"B`J($944"!S97)V97(@<W5P<&]R=',@=&AE(%-)5$4@8V]M;6%N9"X*("H*
M("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]3251%7T9!24Q%
M1`H@*B!`<V5E($YE=%]&5%`Z.G-I=&4H*0H@*B\*9&5F:6YE*"=.151?1E10
M7T524E]3251%7T9!24Q%1"<L("TV*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O
M(&EN9&EC871E('1H870@=&AE($-(34]$(&-O;6UA;F0@9F%I;&5D+@H@*B!4
M:&4@97AE8W5T:6]N(&]F($-(34]$(&9A:6QE9"X@16YS=7)E+"!T:&%T('EO
M=7(*("H@1E10('-E<G9E<B!S=7!P;W)T<R!T:&4@0TA-3T0@8V]M;6%N9"!A
M;F0@=&AA="!Y;W4@:&%V92!T:&4@87!P<F]P<FEA=&4*("H@86-C97-S(')I
M9VAT<R!T;R!U<V4@0TA-3T0N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@
M3D547T944%]%4E)?0TA-3T1?1D%)3$5$"B`J($!S964@3F5T7T944#HZ8VAM
M;V0H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]#2$U/1%]&04E,140G+"`M
M-RD["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T(&$@9FEL
M92!R96YA;64@9F%I;&5D"B`J(%1H92!R96YA;6EN9R!O9B!A(&9I;&4@;VX@
M=&AE('-E<G9E<B!F86EL960N($5N<W5R92!T:&%T('EO=2!H879E('1H90H@
M*B!A<'!R;W!R:6%T92!A8V-E<W,@<FEG:'1S('1O(')E;F%M92!T:&4@9FEL
M92X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]214Y!
M345?1D%)3$5$"B`J($!S964@3F5T7T944#HZ<F5N86UE*"D*("HO"F1E9FEN
M92@G3D547T944%]%4E)?4D5.04U%7T9!24Q%1"<L("TX*3L*"B\J*@H@*B!%
M<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE($U$5$T@8V]M;6%N9"!F
M86EL960*("H@5&AE($U$5$T@8V]M;6%N9"!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!D:7)E8W1O<FEE<RX@16YS=7)E('1H870@>6]U(&=A=F4*("H@82!F:6QE
M('!A=&@@=&\@=&AE(&UD=&TH*2!M971H;V0L(&YO="!A(&1I<F5C=&]R>2!P
M871H+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27TU$
M5$U$25)?54Y355!03U)4140*("H@0'-E92!.971?1E10.CIM9'1M*"D*("HO
M"F1E9FEN92@G3D547T944%]%4E)?3414341)4E]53E-54%!/4E1%1"<L("TY
M*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE($U$
M5$T@8V]M;6%N9"!F86EL960*("H@5&AE($U$5$T@8V]M;6%N9"!F86EL960N
M($5N<W5R92!T:&%T('EO=7(@<V5R=F5R('-U<'!O<G1S('1H92!-1%1-(&-O
M;6UA;F0N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?
M341435]&04E,140*("H@0'-E92!.971?1E10.CIM9'1M*"D*("HO"F1E9FEN
M92@G3D547T944%]%4E)?341435]&04E,140G+"`M,3`I.PH*+RHJ"B`J($5R
M<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!A(&1A=&4@<F5T=7)N960@8GD@
M=&AE('-E<G9E<B!W87,@;6ES9F]R;6%T960*("H@02!D871E('-T<FEN9R!R
M971U<FYE9"!B>2!Y;W5R('-E<G9E<B!S965M<R!T;R!B92!M:7-S9F]R;6%T
M960@86YD(&-O=6QD(&YO="!B90H@*B!P87)S960N($-H96-K('1H870@=&AE
M('-E<G9E<B!I<R!C;VYF:6=U<F5D(&-O<G)E8W1L>2X@268@>6]U)W)E('-U
M<F4L('!L96%S90H@*B!S96YD(&%N(&5M86EL('1O('1H92!A=6AT;W(@=VET
M:"!A(&1U;7!E9"!O=71P=70@;V8@)&9T<"T^;',H)RXO)RP@3D547T944%]2
M05=,25-4*3L*("H@=&\@9V5T('1H92!D871E(&9O<FUA="!S=7!P;W)T960N
M"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?1$%4149/
M4DU!5%]&04E,140*("H@0'-E92!.971?1E10.CIM9'1M*"DL($YE=%]&5%`Z
M.FQS*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?1$%4149/4DU!5%]&04E,
M140G+"`M,3$I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA
M="!T:&4@4TE:12!C;VUM86YD(&9A:6QE9`H@*B!4:&4@9&5T97)M:6YA=&EO
M;B!O9B!T:&4@9FEL97-I>F4@;V8@82!F:6QE(&9A:6QE9"X@16YS=7)E('1H
M870@>6]U<B!S97)V97(@<W5P<&]R=',@=&AE"B`J(%-)6D4@8V]M;6%N9"X*
M("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]325I%7T9!
M24Q%1`H@*B!`<V5E($YE=%]&5%`Z.G-I>F4H*0H@*B\*9&5F:6YE*"=.151?
M1E107T524E]325I%7T9!24Q%1"<L("TQ,BD["@HO*BH*("H@17)R;W(@8V]D
M92!T;R!I;F1I8V%T92!T:&%T(&$@;&]C86P@9FEL92!C;W5L9"!N;W0@8F4@
M;W9E<G=R:71T96X*("H@66]U('-P96-I9FEE9"!N;W0@=&\@;W9E<G=R:71E
M(&9I;&5S+B!4:&5R969O<F4@=&AE(&QO8V%L(&9I;&4@:&%S(&YO="!B965N
M"B`J(&]V97)W<FET96XN($EF('EO=2!W86YT('1O(&=E="!T:&4@9FEL92!O
M=F5R=W)I=&5N+"!P;&5A<V4@<V5T('1H92!O<'1I;VX@=&\*("H@9&\@<V\N
M"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?3U9%4E=2
M251%3$]#04Q&24Q%7T9/4D))1$1%3@H@*B!`<V5E($YE=%]&5%`Z.F=E="@I
M+"!.971?1E10.CIG971296-U<G-I=F4H*0H@*B\*9&5F:6YE*"=.151?1E10
M7T524E]/5D525U))5$5,3T-!3$9)3$5?1D]20DE$1$5.)RP@+3$S*3L*"B\J
M*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@82!L;V-A;"!F:6QE
M(&-O=6QD(&YO="!B92!O=F5R=W)I='1E;@H@*B!!;'-O('EO=2!S<&5C:69I
M960@=&\@;W9E<G=R:71E('1H92!L;V-A;"!F:6QE('EO=2!W86YT('1O(&1O
M=VYL;V%D('1O+`H@*B!I="!H87,@;F]T(&)E96X@<&]S<VEB;&4@=&\@9&\@
M<V\N($-H96-K('1H870@>6]U(&AA=F4@=&AE(&%P<')O<')I871E(&%C8V5S
M<PH@*B!R:6=H=',@;VX@=&AE(&QO8V%L(&9I;&4@=&\@;W9E<G=R:71E(&ET
M+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T]615)7
M4DE414Q/0T%,1DE,15]&04E,140*("H@0'-E92!.971?1E10.CIG970H*2P@
M3F5T7T944#HZ9V5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%
M4E)?3U9%4E=2251%3$]#04Q&24Q%7T9!24Q%1"<L("TQ-"D["@HO*BH*("H@
M17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!F:6QE('EO=2!W86YT
M960@=&\@=7!L;V%D(&1O97,@;F]T(&5X:7-T"B`J(%1H92!F:6QE('EO=2!T
M<FEE9"!T;R!U<&QO860@9&]E<R!N;W0@97AI<W0N($5N<W5R92!T:&%T(&ET
M(&5X:7-T<RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T52
M4E],3T-!3$9)3$5.3U1%6$E35`H@*B!`<V5E($YE=%]&5%`Z.G!U="@I+"!.
M971?1E10.CIP=71296-U<G-I=F4H*0H@*B\*9&5F:6YE*"=.151?1E107T52
M4E],3T-!3$9)3$5.3U1%6$E35"<L("TQ-2D["@HO*BH*("H@17)R;W(@8V]D
M92!T;R!I;F1I8V%T92!T:&%T(&$@<F5M;W1E(&9I;&4@8V]U;&0@;F]T(&)E
M(&]V97)W<FET=&5N"B`J(%EO=2!S<&5C:69I960@;F]T('1O(&]V97)W<FET
M92!F:6QE<RX@5&AE<F5F;W)E('1H92!R96UO=&4@9FEL92!H87,@;F]T(&)E
M96X*("H@;W9E<G=R:71E;BX@268@>6]U('=A;G0@=&\@9V5T('1H92!F:6QE
M(&]V97)W<FET96XL('!L96%S92!S970@=&AE(&]P=&EO;B!T;PH@*B!D;R!S
M;RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]/5D52
M5U))5$5214U/5$5&24Q%7T9/4D))1$1%3@H@*B!`<V5E($YE=%]&5%`Z.G!U
M="@I+"!.971?1E10.CIP=71296-U<G-I=F4H*0H@*B\*9&5F:6YE*"=.151?
M1E107T524E]/5D525U))5$5214U/5$5&24Q%7T9/4D))1$1%3B<L("TQ-BD[
M"@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!U<&QO
M860@;V8@82!F:6QE(&9A:6QE9`H@*B!4:&4@=7!L;V%D('EO=2!T<FEE9"!F
M86EL960N($5N<W5R92!T:&%T('EO=2!H879E(&%P<')O<')I871E(&%C8V5S
M<R!R:6=H=',*("H@=&\@=7!L;V%D('1H92!D97-I<F5D(&9I;&4N"B`J"B`J
M($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?55!,3T%$1DE,15]&
M04E,140*("H@0'-E92!.971?1E10.CIP=70H*2P@3F5T7T944#HZ<'5T4F5C
M=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?55!,3T%$1DE,15]&
M04E,140G+"`M,3<I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@
M=&AA="!Y;W4@<W!E8VEF:65D(&%N(&EN8V]R<F5C="!D:7)E8W1O<GD@<&%T
M:`H@*B!4:&4@<F5M;W1E('!A=&@@>6]U('-P96-I9FEE9"!S965M<R!N;W0@
M=&\@8F4@82!D:7)E8W1O<GDN($5N<W5R92!T:&%T"B`J('1H92!P871H('EO
M=2!S<&5C:69Y(&ES(&$@9&ER96-T;W)Y(&%N9"!T:&%T('1H92!P871H('-T
M<FEN9R!E;F1S('=I=&@*("H@82`O+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N
M86UE($Y%5%]&5%!?15)27U)%34]415!!5$A.3T1)4@H@*B!`<V5E($YE=%]&
M5%`Z.G!U=%)E8W5R<VEV92@I+"!.971?1E10.CIG971296-U<G-I=F4H*0H@
M*B\*9&5F:6YE*"=.151?1E107T524E]214U/5$50051(3D]$25(G+"`M,3@I
M.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!Y;W4@<W!E
M8VEF:65D(&%N(&EN8V]R<F5C="!D:7)E8W1O<GD@<&%T:`H@*B!4:&4@;&]C
M86P@<&%T:"!Y;W4@<W!E8VEF:65D('-E96US(&YO="!T;R!B92!A(&1I<F5C
M=&]R>2X@16YS=7)E('1H870*("H@=&AE('!A=&@@>6]U('-P96-I9GD@:7,@
M82!D:7)E8W1O<GD@86YD('1H870@=&AE('!A=&@@<W1R:6YG(&5N9',@=VET
M:`H@*B!A("\N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%
M4E)?3$]#04Q0051(3D]$25(*("H@0'-E92!.971?1E10.CIP=71296-U<G-I
M=F4H*2P@3F5T7T944#HZ9V5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D54
M7T944%]%4E)?3$]#04Q0051(3D]$25(G+"`M,3DI.PH*+RHJ"B`J($5R<F]R
M(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!A(&QO8V%L(&1I<F5C=&]R>2!F86EL
M960@=&\@8F4@8W)E871E9`H@*B!9;W4@=')I960@=&\@8W)E871E(&$@;&]C
M86P@9&ER96-T;W)Y('1H<F]U9V@@9V5T4F5C=7)S:79E*"D@;65T:&]D+`H@
M*B!W:&EC:"!H87,@9F%I;&5D+B!%;G-U<F4@=&AA="!Y;W4@:&%V92!T:&4@
M87!P<F]P<FEA=&4@86-C97-S(')I9VAT<PH@*B!T;R!C<F5A=&4@:70N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?0U)%051%3$]#
M04Q$25)?1D%)3$5$"B`J($!S964@3F5T7T944#HZ9V5T4F5C=7)S:79E*"D*
M("HO"F1E9FEN92@G3D547T944%]%4E)?0U)%051%3$]#04Q$25)?1D%)3$5$
M)RP@+3(P*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@
M=&AE('!R;W9I9&5D(&AO<W1N86UE('=A<R!I;F-O<G)E8W0*("H@5&AE(&AO
M<W1N86UE('EO=2!P<F]V:61E9"!W87,@:6YV86QI9"X@16YS=7)E('1O('!R
M;W9I9&4@96ET:&5R(&$*("H@9G5L;"!Q=6%L:69I960@9&]M86EN(&YA;64@
M;W(@86X@25`@861D<F5S<RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107T524E](3U-43D%-14Y/4U1224Y'"B`J($!S964@3F5T7T944#HZ
M<V5T2&]S=&YA;64H*0H@*B\*9&5F:6YE*"=.151?1E107T524E](3U-43D%-
M14Y/4U1224Y')RP@+3(Q*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC
M871E('1H870@=&AE('!R;W9I9&5D('!O<G0@=V%S(&EN8V]R<F5C=`H@*B!4
M:&4@<&]R="!N=6UB97(@>6]U('!R;W9I9&5D('=A<R!I;G9A;&ED+B!%;G-U
M<F4@=&\@<')O=FED92!E:71H97(@80H@*B!A(&YU;65R:6,@<&]R="!N=6UB
M97(@9W)E871E<B!Z97)O+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%
M5%]&5%!?15)27U!/4E1,15-36D523PH@*B!`<V5E($YE=%]&5%`Z.G-E=%!O
M<G0H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]03U)43$534UI%4D\G+"`M
M,C(I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!Y;W4@
M<')O=FED960@86X@:6YV86QI9"!M;V1E(&-O;G-T86YT"B`J(%1H92!M;V1E
M(&-O;G-T86YT('EO=2!P<F]V:61E9"!W87,@:6YV86QI9"X@66]U(&UA>2!O
M;FQY('!R;W9I9&4*("H@1E107T%30TE)(&]R($944%]"24Y!4EDN"B`J"B`J
M($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?3D]-3T1%0T].4U0*
M("H@0'-E92!.971?1E10.CIS971-;V1E*"D*("HO"F1E9FEN92@G3D547T94
M4%]%4E)?3D]-3T1%0T].4U0G+"`M,C,I.PH*+RHJ"B`J($5R<F]R(&-O9&4@
M=&\@:6YD:6-A=&4@=&AA="!Y;W4@<')O=FED960@86X@:6YV86QI9"!T:6UE
M;W5T"B`J(%1H92!T:6UE;W5T('EO=2!P<F]V:61E9"!W87,@:6YV86QI9"X@
M66]U(&AA=F4@=&\@<')O=FED92!A('1I;65O=70@9W)E871E<@H@*B!O<B!E
M<75A;"!T;R!Z97)O+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&
M5%!?15)27U1)345/551,15-36D523PH@*B!`<V5E($YE=%]&5%`Z.DYE=%]&
M5%`H*2P@3F5T7T944#HZ<V5T5&EM96]U="@I"B`J+PID969I;F4H)TY%5%]&
M5%!?15)27U1)345/551,15-36D523R<L("TR-"D["@HO*BH*("H@17)R;W(@
M8V]D92!T;R!I;F1I8V%T92!T:&%T('EO=2!P<F]V:61E9"!A;B!I;G9A;&ED
M('1I;65O=70*("H@06X@97)R;W(@;V-C=7)E9"!W:&EL92!S971T:6YG('1H
M92!T:6UE;W5T+B!%;G-U<F4@=&AA="!Y;W4@<')O=FED92!A"B`J('9A;&ED
M(&EN=&5G97(@9F]R('1H92!T:6UE;W5N="!A;F0@=&AA="!Y;W5R(%!(4"!I
M;G-T86QL871I;VX@=V]R:W,*("H@8V]R<F5C=&QY+@H@*@H@*B!`<VEN8V4@
M,2XS"B`J($!N86UE($Y%5%]&5%!?15)27U-%5%1)345/551?1D%)3$5$"B`J
M($!S964@3F5T7T944#HZ3F5T7T944"@I+"!.971?1E10.CIS9714:6UE;W5T
M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?4T545$E-14]55%]&04E,140G
M+"`M,C4I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T
M:&4@<')O=FED960@97AT96YS:6]N(&9I;&4@9&]E<VXG="!E>&ES=`H@*B!4
M:&4@<')O=FED960@97AT96YS:6]N(&9I;&4@9&]E<R!N;W0@97AI<W0N($5N
M<W5R92!T;R!P<F]V:61E9"!A;@H@*B!E>&ES=&%N="!E>'1E;G-I;VX@9FEL
M92X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]%6%1&
M24Q%3D]415A)4U0*("H@0'-E92!.971?1E10.CIG971%>'1E;G-I;VY&:6QE
M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?15A41DE,14Y/5$5825-4)RP@
M+3(V*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE
M('!R;W9I9&5D(&5X=&5N<VEO;B!F:6QE(&ES(&YO="!R96%D86)L90H@*B!4
M:&4@<')O=FED960@97AT96YS:6]N(&9I;&4@:7,@;F]T(')E861A8FQE+B!%
M;G-U<F4@=&\@:&%V92!S=69F:6-I96YT"B`J(&%C8V5S<R!R:6=H=',@9F]R
M(&ET+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T58
M5$9)3$5214%$7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F=E=$5X=&5N<VEO
M;D9I;&4H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]%6%1&24Q%4D5!1%]&
M04E,140G+"`M,C<I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@
M=&AA="!T:&4@9&5L971I;VX@;V8@82!F:6QE(&9A:6QE9`H@*B!4:&4@<W!E
M8VEF:65D(&9I;&4@8V]U;&0@;F]T(&)E(&1E;&5T960N($5N<W5R92!T;R!H
M879E('-U9F9I8VEE;G0*("H@86-C97-S(')I9VAT<R!T;R!D96QE=&4@=&AE
M(&9I;&4N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?
M15A41DE,15)%041?1D%)3$5$"B`J($!S964@3F5T7T944#HZ<FTH*0H@*B\*
M9&5F:6YE*"=.151?1E107T524E]$14Q%5$5&24Q%7T9!24Q%1"<L("TR."D[
M"@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!D96QE
M=&EO;B!O9B!A(&1I<F5C=&]R>2!F86EL9`H@*B!4:&4@<W!E8VEF:65D(&9I
M;&4@8V]U;&0@;F]T(&)E(&1E;&5T960N($5N<W5R92!T;R!H879E('-U9F9I
M8VEE;G0*("H@86-C97-S(')I9VAT<R!T;R!D96QE=&4@=&AE(&9I;&4N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?15A41DE,15)%
M041?1D%)3$5$"B`J($!S964@3F5T7T944#HZ<FTH*0H@*B\*9&5F:6YE*"=.
M151?1E107T524E]$14Q%5$5$25)?1D%)3$5$)RP@+3(Y*3L*"B\J*@H@*B!%
M<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE(&1I<F5C=&]R>2!L:7-T
M:6YG(&9A:6QE9`H@*B!02%`@8V]U;&0@;F]T(&QI<W0@=&AE(&1I<F5C=&]R
M>2!C;VYT96YT<R!O;B!T:&4@<V5R=F5R+B!%;G-U<F4*("H@=&AA="!Y;W5R
M('-E<G9E<B!I<R!C;VYF:6=U<F5D(&%P<')O<')I871E+@H@*@H@*B!`<VEN
M8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27U)!5T1)4DQ)4U1?1D%)3$5$
M"B`J($!S964@3F5T7T944#HZ;',H*0H@*B\*9&5F:6YE*"=.151?1E107T52
M4E]205=$25),25-47T9!24Q%1"<L("TS,"D["@HO*BH*("H@17)R;W(@8V]D
M92!T;R!I;F1I8V%T92!T:&%T('1H92!D:7)E8W1O<GD@;&ES=&EN9R!F86EL
M960*("H@5&AE(&1I<F5C=&]R>2!L:7-T:6YG(&9O<FUA="!Y;W5R('-E<G9E
M<B!U<V5S('-E96US(&YO="!T;PH@*B!B92!S=7!P;W)T960@8GD@3F5T7T94
M4"X@4&QE87-E('-E;F0@=&AE(&]U='!U="!O9B!T:&4*("H@8V%L;"!L<R@G
M+B\G+"!.151?1E107U)!5TQ)4U0I.R!T;R!T:&4@875T:&]R(&]F('1H:7,*
M("H@8VQA<W,@=&\@9V5T(&ET('-U<'!O<G1E9"X*("H*("H@0'-I;F-E(#$N
M,PH@*B!`;F%M92!.151?1E107T524E]$25),25-47U5.4U504$]25$5$"B`J
M($!S964@3F5T7T944#HZ;',H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]$
M25),25-47U5.4U504$]25$5$)RP@+3,Q*3L*"B\J*@H@*B!%<G)O<B!C;V1E
M('1O(&EN9&EC871E(&9A:6QE9"!D:7-C;VYN96-T:6YG"B`J(%1H:7,@97)R
M;W(@8V]D92!I;F1I8V%T97,L('1H870@9&ES8V]N;F5C=&EO;B!W87,@;F]T
M('!O<W-I8FQE+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?
M15)27T1)4T-/3DY%0U1?1D%)3$5$"B`J($!S964@3F5T7T944#HZ9&ES8V]N
M;F5C="@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T1)4T-/3DY%0U1?1D%)
M3$5$)RP@+3,R*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H
M870@=&AE('5S97)N86UE('EO=2!P<F]V:61E9"!W87,@:6YV86QI9"X*("H@
M0VAE8VL@=&AA="!Y;W4@<')O=FED960@82!N;VXM96UP='D@<W1R:6YG(&%S
M('1H92!U<V5R;F%M92X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?
M1E107T524E]54T523D%-14Y/4U1224Y'"B`J($!S964@3F5T7T944#HZ<V5T
M57-E<FYA;64H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]54T523D%-14Y/
M4U1224Y')RP@+3,S*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E
M('1H870@=&AE('5S97)N86UE('EO=2!P<F]V:61E9"!W87,@:6YV86QI9"X*
M("H@0VAE8VL@=&AA="!Y;W4@<')O=FED960@82!N;VXM96UP='D@<W1R:6YG
M(&%S('1H92!U<V5R;F%M92X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107T524E]005-35T]21$Y/4U1224Y'"B`J($!S964@3F5T7T944#HZ
M<V5T4&%S<W=O<F0H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]005-35T]2
M1$Y/4U1224Y')RP@+3,S*3L*"B\J*@H@*B!#;&%S<R!F;W(@8V]M9F]R=&%B
M;&4@1E10+6-O;6UU;FEC871I;VX*("H*("H@5&AI<R!C;&%S<R!P<F]V:61E
M<R!C;VUF;W)T86)L92!C;VUM=6YI8V%T:6]N('=I=&@@1E10+7-E<G9E<G,N
M(%EO=2!M87D@9&\@979E<GET:&EN9PH@*B!E;F%B;&5D(&)Y('1H92!02%`M
M1E10+65X=&5N<VEO;B!A;F0@9G5R=&AE<B!F=6YC=&EO;F%L:71I97,L(&QI
M:V4@<F5C=7)S:79E+61E;&5T:6]N+`H@*B`M=7`M(&%N9"`M9&]W;FQO860N
M($%N;W1H97(@9F5A='5R92!I<R!T;R!C<F5A=&4@9&ER96-T;W)I97,@<F5C
M=7)S:79E;'DN"B`J"B`J($!L:6-E;G-E("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!C871E9V]R
M>2`@3F5T=V]R:VEN9PH@*B!`<&%C:V%G92`@($944`H@*B!`875T:&]R("`@
M(%1O8FEA<R!38VAL:71T(#QT;V)Y0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@("!296QE87-E
M.B`Q+C,N,0H@*B!`;&EN:R`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92].971?1E10"B`J($!S:6YC92`@("`@,"XP+C$*("H@0&%C8V5S<R`@
M("!P=6)L:6,*("HO"F-L87-S($YE=%]&5%`@97AT96YD<R!014%2(`I["B`@
M("`O*BH*("`@("`J(%1H92!H;W-T('1O(&-O;FYE8W0@=&\*("`@("`J"B`@
M("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`=F%R("`@("!S=')I;F<*
M("`@("`J+PH@("`@"B`@("!V87(@)%]H;W-T;F%M93L*"B`@("`O*BH*("`@
M("`J(%1H92!P;W)T(&9O<B!F='`M8V]N;F5C=&EO;B`H<W1A;F1A<F0@:7,@
M,C$I"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A
M<B`@("`@:6YT"B`@("`@*B\*("`@(`H@("`@=F%R("1?<&]R="`](#(Q.PH*
M("`@("\J*@H@("`@("H@5&AE('5S97)N86UE(&9O<B!L;V=I;@H@("`@("H*
M("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@('-T<FEN
M9PH@("`@("HO"B`@("`*("`@('9A<B`D7W5S97)N86UE.PH*("`@("\J*@H@
M("`@("H@5&AE('!A<W-W;W)D(&9O<B!L;V=I;@H@("`@("H*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@('-T<FEN9PH@("`@("HO
M"B`@("`*("`@('9A<B`D7W!A<W-W;W)D.PH*("`@("\J*@H@("`@("H@1&5T
M97)M:6YE('=H971H97(@=&\@=7-E('!A<W-I=F4M;6]D92`H=')U92D@;W(@
M86-T:79E+6UO9&4@*&9A;'-E*0H@("`@("H*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J($!V87(@("`@(&)O;VP*("`@("`J+PH@("`@"B`@("!V
M87(@)%]P87-S=CL*"B`@("`O*BH*("`@("`J(%1H92!S=&%N9&%R9"!M;V1E
M(&9O<B!F='`M=')A;G-F97(*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B!`=F%R("`@("!I;G0*("`@("`J+PH@("`@"B`@("!V87(@
M)%]M;V1E(#T@1E107T))3D%263L*"B`@("`O*BH*("`@("`J(%1H:7,@:&]L
M9',@=&AE(&AA;F1L92!F;W(@=&AE(&9T<"UC;VYN96-T:6]N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@<F5S;W5R
M8V4*("`@("`J+PH@("`@"B`@("!V87(@)%]H86YD;&4["@H@("`@+RHJ"B`@
M("`@*B!#;VYT86EN<R!T:&4@=&EM96]U="!F;W(@1E10(&]P97)A=&EO;G,*
M("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`=F%R("`@
M("!I;G0*("`@("`J($!S:6YC92`@(#$N,PH@("`@("HO"B`@("`*("`@('9A
M<B`D7W1I;65O=70@/2`Y,#L*("`@("`@("`*("`@("\J*@H@("`@("H@4V%V
M97,@9FEL92UE>'1E;G-I;VYS(&9O<B!A<V-I:2T@86YD(&)I;F%R>2UM;V1E
M"B`@("`@*@H@("`@("H@5&AE(&%R<F%Y(&-O;G1A:6YS(#(@<W5B+6%R<F%Y
M<R`H(F%S8VEI(B!A;F0@(F)I;F%R>2(I+"!W:&EC:"!B;W1H(&-O;G1A:6X*
M("`@("`J(&9I;&4M97AT96YS:6]N<R!W:71H;W5T('1H92`B+B(@*"(N<&AP
M(B`](")P:'`B*2X*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B!`=F%R("`@("!A<G)A>0H@("`@("HO"B`@("`*("`@('9A<B`D7V9I
M;&5?97AT96YS:6]N<SL*"B`@("`O*BH*("`@("`J(&QS(&UA=&-H"B`@("`@
M*B!-871C:&5S('1H92!L<R!E;G1R:65S(&%G86EN<W0@82!R96=E>"!A;F0@
M;6%P<R!T:&4@<F5S=6QT:6YG(&%R<F%Y('1O('-P96%K:6YG(&YA;65S"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@
M87)R87D*("`@("`J($!S:6YC92`@(#$N,PH@("`@("HO"B`@("`*("`@('9A
M<B`D7VQS7VUA=&-H(#T@87)R87DH"B`@("`@("`@)W5N:7@G("`@(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G<&%T=&5R;B<@/3X@)R\H/SHH9"E\+BDH6W)W
M>'0M72LI7',K*%QW*RE<<RLH6UQW7&1=*RE<<RLH6UQW7&1=*RE<<RLH7'<K
M*5QS*RA<4RM<<RM<4RM<<RM<4RLI7',K*"XK*2\G+`H@("`@("`@("`@("`G
M;6%P)R`@("`@/3X@87)R87DH)VYA;64G/3XX+"=S:7IE)ST^-BPG<FEG:'1S
M)ST^,BPG=7-E<B<]/C0L)V=R;W5P)ST^-2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9I;&5S7VEN<VED92<]/C,L)V1A=&4G/3XW+"=I<U]D
M:7(G/3XQ*0H@("`@("`@("DL"B`@("`@("`@)W=I;F1O=W,G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G<&%T=&5R;B<@/3X@)R\H+BLI7',K*"XK*5QS*R@H
M/$1)4CXI?%LP+3E=*RE<<RLH+BLI+R<L"B`@("`@("`@("`@("=M87`G("`@
M("`]/B!A<G)A>2@G;F%M92<]/C4L)V1A=&4G/3XQ+"=I<U]D:7(G/3XS*0H@
M("`@("`@("D*("`@("D["B`@("`*("`@("\J*@H@("`@("H@;6%T8VAE<@H@
M("`@("H@4W1O<F5S('1H92!M871C:&5R(&9O<B!T:&4@8W5R<F5N="!C;VYN
M96-T:6]N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@
M0'9A<B`@("`@87)R87D*("`@("`J($!S:6YC92`@(#$N,PH@("`@("HO"B`@
M("!V87(@)%]M871C:&5R(#T@;G5L;#L*("`@(`H@("`@+RHJ"B`@("`@*B!(
M;VQD<R!A;&P@3F5T7T944%]/8G-E<G9E<B!O8FIE8W1S(`H@("`@("H@=&AA
M="!W:7-H('1O(&)E(&YO=&EF:65D(&]F(&YE=R!M97-S86=E<RX*("`@("`J
M"B`@("`@*B!`=F%R("`@("!A<G)A>0H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("H@0'-I;F-E("`@,2XS"B`@("`@*B\*("`@(`H@("`@=F%R("1?
M;&ES=&5N97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H:7,@9V5N
M97)A=&5S(&$@;F5W($944"U/8FIE8W0N(%1H92!&5%`M8V]N;F5C=&EO;B!W
M:6QL(&YO="!B92!E<W1A8FQI<VAE9"P@>65T+@H@("`@("H@66]U(&-A;B!L
M96%V92`D:&]S="!A;F0@)'!O<G0@8FQA;FLL(&EF('EO=2!W86YT+B!4:&4@
M)&AO<W0@=VEL;"!N;W0@8F4@<V5T"B`@("`@*B!A;F0@=&AE("1P;W)T('=I
M;&P@8F4@;&5F="!A="`R,2X@66]U(&AA=F4@=&\@<V5T('1H92`D:&]S="!M
M86YU86QY(&)E9F]R90H@("`@("H@=')Y:6YG('1O(&-O;FYE8W0@;W(@=VET
M:"!T:&4@8V]N;F5C="@I(&UE=&AO9"X*("`@("`J"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D:&]S="`@("`H;W!T
M:6]N86PI(%1H92!H;W-T;F%M92`*("`@("`J($!P87)A;2`@(&EN="`@("`D
M<&]R="`@("`H;W!T:6]N86PI(%1H92!P;W)T"B`@("`@*B!`<&%R86T@("!I
M;G0@("`@)'1I;65O=70@*&]P=&EO;F%L*2!3971S('1H92!S=&%N9&%R9"!T
M:6UE;W5T"B`@("`@*B!`<F5T=7)N("!V;VED"B`@("`@*B!`<V5E("`@("!.
M971?1E10.CIS971(;W-T;F%M92@I+"!.971?1E10.CIS9710;W)T*"DL($YE
M=%]&5%`Z.F-O;FYE8W0H*0H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N($YE
M=%]&5%`H)&AO<W0@/2!N=6QL+"`D<&]R="`](&YU;&PL("1T:6UE;W5T(#T@
M.3`I"B`@("!["B`@("`@("`@)'1H:7,M/E!%05(H*3L*("`@("`@("!I9B`H
M:7-S970H)&AO<W0I*2!["B`@("`@("`@("`@("1T:&ES+3YS971(;W-T;F%M
M92@D:&]S="D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D<&]R="DI
M('L*("`@("`@("`@("`@)'1H:7,M/G-E=%!O<G0H)'!O<G0I.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7W1I;65O=70@/2`D=&EM96]U=#L*("`@("`@
M("`D=&AI<RT^7V9I;&5?97AT96YS:6]N<UM&5%!?05-#24E=(#T@87)R87DH
M*3L*("`@("`@("`D=&AI<RT^7V9I;&5?97AT96YS:6]N<UM&5%!?0DE.05)9
M72`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T
M:6]N(&=E;F5R871E<R!T:&4@1E10+6-O;FYE8W1I;VXN(%EO=2!C86X@;W!T
M:6]N86QL>2!D969I;F4@80H@("`@("H@:&]S=&YA;64@86YD+V]R(&$@<&]R
M="X@268@>6]U(&1O('-O+"!T:&ES(&1A=&$@:7,@<W1O<F5D(&EN<VED92!T
M:&4@;V)J96-T+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1H;W-T("`@("AO<'1I;VYA;"D@5&AE($AO
M<W1N86UE"B`@("`@*B!`<&%R86T@("!I;G0@("`@)'!O<G0@("`@*&]P=&EO
M;F%L*2!4:&4@4&]R="`*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@
M("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@
M("H@0'-E92`@("`@3D547T944%]%4E)?0T].3D5#5%]&04E,140*("`@("`J
M+PH@("`@"B`@("!F=6YC=&EO;B!C;VYN96-T*"1H;W-T(#T@;G5L;"P@)'!O
M<G0@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;6%T8VAE<B`](&YU
M;&P["B`@("`@("`@:68@*&ES<V5T*"1H;W-T*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5T2&]S=&YA;64H)&AO<W0I.PH@("`@("`@('T*("`@("`@("!I
M9B`H:7-S970H)'!O<G0I*2!["B`@("`@("`@("`@("1T:&ES+3YS9710;W)T
M*"1P;W)T*3L*("`@("`@("!]"B`@("`@("`@)&AA;F1L92`]($!F='!?8V]N
M;F5C="@D=&AI<RT^9V5T2&]S=&YA;64H*2P@)'1H:7,M/F=E=%!O<G0H*2P@
M)'1H:7,M/E]T:6UE;W5T*3L*("`@("`@("!I9B`H(21H86YD;&4I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#;VYN96-T:6]N
M('1O(&AO<W0@9F%I;&5D(BP@3D547T944%]%4E)?0T].3D5#5%]&04E,140I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:&%N9&QE
M(#TF("1H86YD;&4["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@8VQO<V4@
M=&AE($944"UC;VYN96-T:6]N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N("!B;V]L?%!%05)?17)R;W(@4F5T=7)N<R!T
M<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R90H@("`@("HO
M"B`@("`*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@
M("1R97,@/2!`9G1P7V-L;W-E*"1T:&ES+3Y?:&%N9&QE*3L*("`@("`@("!I
M9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T1I<V-O;FYE8W0@9F%I;&5D+B<L($Y%5%]&5%!?15)27T1)4T-/3DY%
M0U1?1D%)3$5$*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&QO9V=E<R!Y;W4@:6YT;R!T:&4@
M9G1P+7-E<G9E<BX@66]U(&%R92!F<F5E('1O('-P96-I9GD@=7-E<FYA;64@
M86YD('!A<W-W;W)D"B`@("`@*B!I;B!T:&ES(&UE=&AO9"X@268@>6]U('-P
M96-I9GD@:70L('1H92!V86QU97,@=VEL;"!B92!T86ME;B!I;G1O('1H92!C
M;W)R97-P;VYD:6YG"B`@("`@*B!A='1R:6)U=&5S+"!I9B!D;R!N;W0@<W!E
M8VEF>2P@=&AE(&%T=')I8G5T97,@87)E('1A:V5N+@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1U<V5R
M;F%M92`@*&]P=&EO;F%L*2!4:&4@=7-E<FYA;64@=&\@=7-E(`H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("1P87-S=V]R9"`@*&]P=&EO;F%L*2!4:&4@<&%S
M<W=O<F0@=&\@=7-E"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@
M("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@
M("H@0'-E92`@("`@3D547T944%]%4E)?3$]'24Y?1D%)3$5$"B`@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@;&]G:6XH)'5S97)N86UE(#T@;G5L;"P@)'!A
M<W-W;W)D(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1U<V5R
M;F%M92DI('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F=E=%5S
M97)N86UE*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=%5S97)N86UE*"1U<V5R;F%M92D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES<V5T*"1P87-S=V]R9"DI('L*("`@("`@("`@("`@)'!A<W-W;W)D
M(#T@)'1H:7,M/F=E=%!A<W-W;W)D*"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=%!A<W-W;W)D*"1P87-S=V]R9"D["B`@("`@
M("`@?0H*("`@("`@("`D<F5S(#T@0&9T<%]L;V=I;B@D=&AI<RT^7VAA;F1L
M92P@)'5S97)N86UE+"`D<&%S<W=O<F0I.PH*("`@("`@("!I9B`H(21R97,I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")5;F%B
M;&4@=&\@;&]G:6XB+"!.151?1E107T524E],3T=)3E]&04E,140I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@8VAA;F=E<R!T:&4@8W5R
M<F5N=&QY('5S960@9&ER96-T;W)Y+B!9;W4@8V%N('5S92!E:71H97(@86X@
M86)S;VQU=&4*("`@("`J(&1I<F5C=&]R>2UP871H("AE+F<N("(O:&]M92]B
M;&%H(BD@;W(@82!R96QA=&EV92!O;F4@*&4N9RX@(BXN+W1E<W0B*2X*("`@
M("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T
M<FEN9R`D9&ER("!4:&4@9&ER96-T;W)Y('1O(&=O('1O+@H@("`@("H@0')E
M='5R;B`@;6EX960@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E
M(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]$25)#
M2$%.1T5?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@8V0H)&1I
M<BD*("`@('L*("`@("`@("`D97)G(#T@0&9T<%]C:&1I<B@D=&AI<RT^7VAA
M;F1L92P@)&1I<BD["B`@("`@("`@:68@*"$D97)G*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1&ER96-T;W)Y(&-H86YG92!F
M86EL960B+"!.151?1E107T524E]$25)#2$%.1T5?1D%)3$5$*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:&]W)W,@>6]U('1H92!A8W1U86P@
M<&%T:"!O;B!T:&4@<V5R=F5R"B`@("`@*B!4:&ES(&9U;F-T:6]N('%U97-T
M:6]N<R!T:&4@9G1P+6AA;F1L92!F;W(@=&AE(&%C='5A;"!S96QE8W1E9"!P
M871H(&%N9"!R971U<FYS(&ET+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("H@0')E='5R;B`@;6EX960@("`@("`@(%1H92!A8W1U86P@
M<&%T:"!O<B!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?1$5415)-24Y%4$%42%]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC
M=&EO;B!P=V0H*0H@("`@>PH@("`@("`@("1R97,@/2!`9G1P7W!W9"@D=&AI
M<RT^7VAA;F1L92D["B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&1E=&5R;6EN
M92!T:&4@86-T=6%L('!A=&@N(BP@3D547T944%]%4E)?1$5415)-24Y%4$%4
M2%]&04E,140I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@
M=V]R:W,@<VEM:6QA<B!T;R!T:&4@;6MD:7(M8V]M;6%N9"!O;B!Y;W5R(&QO
M8V%L(&UA8VAI;F4N(%EO=2!C86X@96ET:&5R(&=I=F4*("`@("`J(&ET(&%N
M(&%B<V]L=71E(&]R(')E;&%T:79E('!A=&@N(%1H92!R96QA=&EV92!P871H
M('=I;&P@8F4@8V]M<&QE=&5D('=I=&@@=&AE(&%C='5A;`H@("`@("H@<V5L
M96-T960@<V5R=F5R+7!A=&@N("AS964Z('!W9"@I*0H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1D:7(@
M("`@("`@06)S;VQU=&4@;W(@<F5L871I=F4@9&ER+7!A=&@*("`@("`J($!P
M87)A;2`@(&)O;VP@("`D<F5C=7)S:79E("AO<'1I;VYA;"D@0W)E871E(&%L
M;"!N965D960@9&ER96-T;W)I97,*("`@("`J($!R971U<FX@(&UI>&5D("`@
M("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R
M<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]#4D5!5$5$25)?1D%)
M3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@;6MD:7(H)&1I<BP@)')E
M8W5R<VEV92`](&9A;'-E*0H@("`@>PH@("`@("`@("1D:7(@/2`D=&AI<RT^
M7V-O;G-T<G5C=%]P871H*"1D:7(I.PH@("`@("`@("1S879E9&ER(#T@)'1H
M:7,M/G!W9"@I.PH@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD["B`@("`@("`@)&4@/2`D=&AI<RT^8V0H)&1I
M<BD["B`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@
M("!I9B`H)&4@/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/F-D*"1S
M879E9&ER*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3YC9"@D<V%V961I<BD["B`@("`@("`@:68@*"1R96-U
M<G-I=F4@/3T](&9A;'-E*7L*("`@("`@("`@("`@)')E<R`]($!F='!?;6MD
M:7(H)'1H:7,M/E]H86YD;&4L("1D:7(I.PH@("`@("`@("`@("!I9B`H(21R
M97,I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B0W)E871I;VX@;V8@)R1D:7(G(&9A:6QE9"(L($Y%5%]&5%!?15)27T-2
M14%4141)4E]&04E,140I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!I9BAS=')P;W,H)&1I<BP@)R\G*2`]/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;6MD:7(H
M)&1I<BQF86QS92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!O<R`]
M(#`["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^;6MD:7(H9&ER;F%M92@D
M9&ER*2P@=')U92D["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^;6MD:7(H
M)&1I<BP@9F%L<V4I.PH@("`@("`@("`@("!I9B`H)')E<R`A/3T@=')U92D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5&AI<R!M971H;V0@=')I97,@97AE8W5T:6YG(&$@8V]M
M;6%N9"!O;B!T:&4@9G1P+"!U<VEN9R!3251%($5814,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&-O
M;6UA;F0@5&AE(&-O;6UA;F0@=&\@97AE8W5T90H@("`@("H@0')E='5R;B`@
M;6EX960@("`@("`@("`@(%1H92!R97-U;'0@;V8@=&AE(&-O;6UA;F0@*&EF
M('-U8V-E<W-F=6QL*2P@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`
M<V5E("`@("!.151?1E107T524E]%6$5#7T9!24Q%1`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N(&5X96-U=&4H)&-O;6UA;F0I"B`@("!["B`@("`@("`@
M)')E<R`]($!F='!?97AE8R@D=&AI<RT^7VAA;F1L92P@)&-O;6UA;F0I.PH@
M("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(D5X96-U=&EO;B!O9B!C;VUM86YD("<D8V]M;6%N9"<@
M9F%I;&5D+B(L($Y%5%]&5%!?15)27T5814-?1D%)3$5$*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E(&$@4TE412!C;VUM86YD(&]N
M('1H92!S97)V97(*("`@("`J(%1H:7,@;65T:&]D('1R:65S('1O(&5X96-U
M=&4@82!3251%(&-O;6UA;F0@;VX@=&AE(&9T<"!S97)V97(N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M)&-O;6UA;F0@("!4:&4@8V]M;6%N9"!W:71H('!A<F%M971E<G,@=&\@97AE
M8W5T90H@("`@("H@0')E='5R;B`@;6EX960@("`@("`@("`@("`@5')U92!I
M9B!S=6-C97-S9G5L+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S
M964@("`@($Y%5%]&5%!?15)27U-)5$5?1D%)3$5$"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@<VET92@D8V]M;6%N9"D*("`@('L*("`@("`@("`D<F5S
M(#T@0&9T<%]S:71E*"1T:&ES+3Y?:&%N9&QE+"`D8V]M;6%N9"D["B`@("`@
M("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B17AE8W5T:6]N(&]F(%-)5$4@8V]M;6%N9"`G)&-O;6UA;F0G
M(&9A:6QE9"XB+"!.151?1E107T524E]3251%7T9!24Q%1"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@=VEL;"!T<GD@=&\@
M8VAM;V0@=&AE(&9I;&4@<W!E8VEF:65D(&]N('1H92!S97)V97(*("`@("`J
M($-U<G)E;G1L>2P@>6]U(&UU<W0@9VEV92!A(&YU;6)E<B!A<R!T:&4@=&AE
M('!E<FUI<W-I;VX@87)G=6UE;G0@*#<W-R!O<@H@("`@("H@<VEM:6QA<BDN
M(%1H92!F:6QE(&-A;B!B92!E:71H97(@82!R96QA=&EV92!O<B!A8G-O;'5T
M92!P871H+@H@("`@("H@3D]413H@4V]M92!S97)V97)S(&1O(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X@26X@=&AA="!C87-E+"!Y;W4@=VEL;`H@("`@
M("H@9V5T(&$@4$5!4B!E<G)O<B!O8FIE8W0@<F5T=7)N960N($EF('-U8V-E
M<W-F=6PL('1H92!M971H;V0@<F5T=7)N<R!T<G5E"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1T87)G
M970@("`@("`@(%1H92!F:6QE(&]R(&%R<F%Y(&]F(&9I;&5S('1O('-E="!P
M97)M:7-S:6]N<R!F;W(*("`@("`J($!P87)A;2`@(&EN=&5G97(@)'!E<FUI
M<W-I;VYS("`@5&AE(&UO9&4@=&\@<V5T('1H92!F:6QE('!E<FUI<W-I;VYS
M('1O"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("`@("`@(%1R
M=64@:68@<W5C8V5S<V9U;"P@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@
M*B!`<V5E("`@("!.151?1E107T524E]#2$U/1%]&04E,140*("`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!C:&UO9"@D=&%R9V5T+"`D<&5R;6ES<VEO;G,I
M"B`@("!["B`@("`@("`@+R\@268@)'1A<F=E="!I<R!A;B!A<G)A>3H@3&]O
M<"!T:')O=6=H(&ET+@H@("`@("`@(&EF("AI<U]A<G)A>2@D=&%R9V5T*2D@
M>PH*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1A<F=E
M="D[("1I*RLI('L*("`@("`@("`@("`@("`@("1R97,@/2`D=&AI<RT^8VAM
M;V0H)'1A<F=E=%LD:5TL("1P97)M:7-S:6]N<RD["B`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("`@("`@?2`O+R!E;F0@:68@
M:7-%<G)O<@H@("`@("`@("`@("!]("\O(&5N9"!F;W(@:2`\(&-O=6YT*"1T
M87)G970I"@H@("`@("`@('T@96QS92!["@H@("`@("`@("`@("`D<F5S(#T@
M)'1H:7,M/G-I=&4H(D-(34]$("(@+B`D<&5R;6ES<VEO;G,@+B`B("(@+B`D
M=&%R9V5T*3L*("`@("`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0TA-3T0@(B`N("1P97)M
M:7-S:6]N<R`N("(@(B`N("1T87)G970@+B`B(&9A:6QE9"(L($Y%5%]&5%!?
M15)27T-(34]$7T9!24Q%1"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@?0H*("`@("`@
M("!]("\O(&5N9"!I9B!I<U]A<G)A>0H*("`@('T@+R\@96YD(&UE=&AO9"!C
M:&UO9`H*("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@=VEL;"!T<GD@=&\@
M8VAM;V0@82!F;VQD97(@86YD(&%L;"!O9B!I=',@8V]N=&5N=',*("`@("`J
M(&]N('1H92!S97)V97(N(%1H92!T87)G970@87)G=6UE;G0@;75S="!B92!A
M(&9O;&1E<B!O<B!A;B!A<G)A>2!O9B!F;VQD97)S"B`@("`@*B!A;F0@=&AE
M('!E<FUI<W-I;VYS(&%R9W5M96YT(&AA=F4@=&\@8F4@86X@:6YT96=E<B`H
M:2YE+B`W-S<I+@H@("`@("H@5&AE(&9I;&4@8V%N(&)E(&5I=&AE<B!A(')E
M;&%T:79E(&]R(&%B<V]L=71E('!A=&@N"B`@("`@*B!.3U1%.B!3;VUE('-E
M<G9E<G,@9&\@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B!);B!T:&%T(&-A
M<V4L('EO=0H@("`@("H@=VEL;"!G970@82!014%2(&5R<F]R(&]B:F5C="!R
M971U<FYE9"X@268@<W5C8V5S<V9U;"P@=&AE(&UE=&AO9`H@("`@("H@<F5T
M=7)N<R!T<G5E"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B!`<&%R86T@("!M:7AE9"`@("1T87)G970@("`@("`@(%1H92!F;VQD97(@
M;W(@87)R87D@;V8@9F]L9&5R<R!T;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S970@<&5R;6ES<VEO;G,@9F]R"B`@("`@*B!`
M<&%R86T@("!I;G1E9V5R("1P97)M:7-S:6]N<R`@(%1H92!M;V1E('1O('-E
M="!T:&4@9F]L9&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%N9"!F:6QE('!E<FUI<W-I;VYS('1O"B`@("`@*B!`<F5T=7)N
M("!M:7AE9"`@("`@("`@("`@("`@("`@(%1R=64@:68@<W5C8V5S<V9U;"P@
M;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E10
M7T524E]#2$U/1%]&04E,140L($Y%5%]&5%!?15)27T1%5$5234E.15!!5$A?
M1D%)3$5$+"!.151?1E107T524E]205=$25),25-47T9!24Q%1"P@3D547T94
M4%]%4E)?1$E23$E35%]53E-54%!/4E1%1`H@("`@("HO"B`@("`*("`@(&9U
M;F-T:6]N(&-H;6]D4F5C=7)S:79E*"1T87)G970L("1P97)M:7-S:6]N<RD*
M("`@('L*("`@("`@("!S=&%T:6,@)&1I<E]P97)M:7-S:6]N<SL*"B`@("`@
M("`@:68H(6ES<V5T*"1D:7)?<&5R;6ES<VEO;G,I*7L@+R\@36%K:6YG(&1I
M<F5C=&]R>2!S<&5C:69I8R!P97)M:7-S:6]N<PH@("`@("`@("`@("`D9&ER
M7W!E<FUI<W-I;VYS(#T@)'1H:7,M/E]M86ME1&ER4&5R;6ES<VEO;G,H)'!E
M<FUI<W-I;VYS*3L*("`@("`@("!]"@H@("`@("`@("\O($EF("1T87)G970@
M:7,@86X@87)R87DZ($QO;W`@=&AR;W5G:"!I=`H@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&%R9V5T*2D@>PH*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)'1A<F=E="D[("1I*RLI('L*("`@("`@("`@("`@("`@("1R
M97,@/2`D=&AI<RT^8VAM;V1296-U<G-I=F4H)'1A<F=E=%LD:5TL("1P97)M
M:7-S:6]N<RD["B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@("`@("`@("`@?2`O+R!E;F0@:68@:7-%<G)O<@H@("`@("`@("`@("!]
M("\O(&5N9"!F;W(@:2`\(&-O=6YT*"1T87)G970I"@H@("`@("`@('T@96QS
M92!["@H@("`@("`@("`@("`D<F5M;W1E7W!A=&@@/2`D=&AI<RT^7V-O;G-T
M<G5C=%]P871H*"1T87)G970I.PH*("`@("`@("`@("`@+R\@0VAM;V0@=&AE
M(&1I<F5C=&]R>2!I='-E;&8*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YC:&UO9"@D<F5M;W1E7W!A=&@L("1D:7)?<&5R;6ES<VEO;G,I.PH*("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!)9B`D<F5M;W1E7W!A=&@@;&%S="!C:&%R86-T97(@:7,@
M;F]T(&$@<VQA<V@L(&%D9"!O;F4*("`@("`@("`@("`@:68@*'-U8G-T<B@D
M<F5M;W1E7W!A=&@L('-T<FQE;B@D<F5M;W1E7W!A=&@I+3$I("$]("(O(BD@
M>PH*("`@("`@("`@("`@("`@("1R96UO=&5?<&%T:"`N/2`B+R(["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1D:7)?;&ES="`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1M;V1E(#T@3D547T944%]$25)37T].3%D["B`@("`@("`@
M("`@("1D:7)?;&ES="`]("1T:&ES+3YL<R@D<F5M;W1E7W!A=&@L("1M;V1E
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)&1I<E]L:7-T(&%S("1D:7)?96YT
M<GDI('L*"B`@("`@("`@("`@("`@("`D<F5M;W1E7W!A=&A?;F5W(#T@)')E
M;6]T95]P871H+B1D:7)?96YT<GE;(FYA;64B72XB+R(["@H@("`@("`@("`@
M("`@("`@+R\@0VAM;V0@=&AE(&1I<F5C=&]R>2!W92=R92!A8F]U="!T;R!E
M;G1E<@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC:&UO9"@D
M<F5M;W1E7W!A=&A?;F5W+"`D9&ER7W!E<FUI<W-I;VYS*3L*"B`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8VAM;V1296-U
M<G-I=F4H)')E;6]T95]P871H7VYE=RP@)'!E<FUI<W-I;VYS*3L*"B`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@?2`O+R!E;F0@9F]R96%C:"!D:7)?;&ES="!A
M<R!D:7)?96YT<GD*"B`@("`@("`@("`@("1F:6QE7VQI<W0@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`D;6]D92`]($Y%5%]&5%!?1DE,15-?3TY,63L*("`@
M("`@("`@("`@)&9I;&5?;&ES="`]("1T:&ES+3YL<R@D<F5M;W1E7W!A=&@L
M("1M;V1E*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@
M)&9I;&5?96YT<GDI('L*"B`@("`@("`@("`@("`@("`D<F5M;W1E7V9I;&4@
M/2`D<F5M;W1E7W!A=&@N)&9I;&5?96YT<GE;(FYA;64B73L*"B`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-H;6]D*"1R96UO=&5?9FEL92P@
M)'!E<FUI<W-I;VYS*3L*"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@?2`O+R!E
M;F0@9F]R96%C:"`D9FEL95]L:7-T"@H@("`@("`@('T@+R\@96YD(&EF(&ES
M7V%R<F%Y"@H@("`@("`@(')E='5R;B!T<G5E.R`O+R!.;R!E<G)O<G,*"B`@
M("!]("\O(&5N9"!M971H;V0@8VAM;V1296-U<G-I=F4*"B`@("`O*BH*("`@
M("`J(%)E;F%M92!O<B!M;W9E(&$@9FEL92!O<B!A(&1I<F5C=&]R>2!F<F]M
M('1H92!F='`M<V5R=F5R"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@)')E;6]T95]F<F]M(%1H92!R96UO
M=&4@9FEL92!O<B!D:7)E8W1O<GD@;W)I9VEN86P@=&\@<F5N86UE(&]R(&UO
M=F4*("`@("`J($!P87)A;2`@('-T<FEN9R`D<F5M;W1E7W1O(%1H92!R96UO
M=&4@9FEL92!O<B!D:7)E8W1O<GD@9FEN86P@=&\@<F5N86UE(&]R(&UO=F4*
M("`@("`J($!R971U<FX@(&)O;VP@)')E<R!4<G5E(&]N('-U8V-E<W,L(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?4D5.04U%7T9!24Q%1`H@("`@("HO"@H@("`@9G5N8W1I;VX@<F5N86UE
M("@D<F5M;W1E7V9R;VTL("1R96UO=&5?=&\I(`H@("`@>PH@("`@("`@("1R
M97,@/2!`9G1P7W)E;F%M92@D=&AI<RT^7VAA;F1L92P@)')E;6]T95]F<F]M
M+"`D<F5M;W1E7W1O*3L*("`@("`@("!I9B@A)')E<RD@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!R96YA;64@
M(BXD<F5M;W1E7V9R;VTN(B!T;R`B+B1R96UO=&5?=&\N(B`A(BP@3D547T94
M4%]%4E)?4D5.04U%7T9!24Q%1"D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!W:6QL(')E='5R
M;B!L;V=I8V%L('!E<FUI<W-I;VYS(&UA<VL@9F]R(&1I<F5C=&]R>2X*("`@
M("`J(&EF(&1I<F5C=&]R>2!H879E('1O(&)E('=R:71E86)L92!I="!H879E
M(&%L<V\@8F4@97AE8W5T86)L90H@("`@("H*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`D<&5R;6ES<VEO;G,@("`@
M1FEL92!P97)M:7-S:6]N<R!I;B!D:6=I=',@9F]R(&9I;&4@*&DN92X@-C8V
M*0H@("`@("H@0')E='5R;B`@<W1R:6YG("`@("`@("`@("`@("`@("!&:6QE
M('!E<FUI<W-I;VYS(&EN(&1I9VET<R!F;W(@9&ER96-T;W)Y("AI+F4N(#<W
M-RD*("`@("`J+PH*("`@(&9U;F-T:6]N(%]M86ME1&ER4&5R;6ES<VEO;G,H
M)'!E<FUI<W-I;VYS*7L*("`@("`@("`D<&5R;6ES<VEO;G,@/2`H<W1R:6YG
M*21P97)M:7-S:6]N<SL*"B`@("`@("`@9F]R*"1I(#T@,#L@)&D@/"!S=')L
M96XH)'!E<FUI<W-I;VYS*3L@)&DK*RE[("\O(&=O:6YG('1H<F]U9V@@*'5S
M97(L(&=R;W5P+"!W;W)L9"D*("`@("`@("`@("`@:68H*&EN="DD<&5R;6ES
M<VEO;G-[)&E]("8@-"!A;F0@(2@H:6YT*21P97)M:7-S:6]N<WLD:7T@)B`Q
M*2E[("\O(%)E860@<&5R;6ES<VEO;B!I<R!S970*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(&)U="!E>&5C=71E(&YO="!Y970*("`@("`@
M("`@("`@("`@("AI;G0I)'!E<FUI<W-I;VYS>R1I?2`]("AI;G0I)'!E<FUI
M<W-I;VYS>R1I?2`K(#$[("\O($%D9&EN9R!E>&5C=71E(&9L86<*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AS=')I;F<I)'!E
M<FUI<W-I;VYS.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!W:6QL(')E
M='5R;B!T:&4@;&%S="!M;V1I9FEC871I;VXM=&EM92!O9B!A(&9I;&4N(%EO
M=2!C86X@96ET:&5R(&=I=F4@=&AI<PH@("`@("H@9G5N8W1I;VX@82!R96QA
M=&EV92!O<B!A;B!A8G-O;'5T92!P871H('1O('1H92!F:6QE('1O(&-H96-K
M+@H@("`@("H@3D]413H@4V]M92!S97)V97)S('=I;&P@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E(&%N9"!T:&4@9G5N8W1I;VX@=V]R:W,*("`@("`J(&]N
M;'D@;VX@9FEL97,L(&YO="!D:7)E8W1O<FEE<R$@5VAE;B!S=6-C97-S9G5L
M+`H@("`@("H@:70@=VEL;"!R971U<FX@=&AE(&QA<W0@;6]D:69I8V%T:6]N
M+71I;64@87,@82!U;FEX+71I;65S=&%M<"!O<BP@=VAE;B`D9F]R;6%T(&ES
M"B`@("`@*B!S<&5C:69I960L(&$@<')E9F]R;6%T960@=&EM97-T<FEN9RX*
M("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@
M('-T<FEN9R`D9FEL92`@("!4:&4@9FEL92!T;R!C:&5C:PH@("`@("H@0'!A
M<F%M("`@<W1R:6YG("1F;W)M870@("AO<'1I;VYA;"D@5&AE(&9O<FUA="!T
M;R!G:79E('1H92!D871E(&)A8VL@"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@;F]T('-E="P@:70@=VEL;"!R971U<FX@82!5;FEX('1I
M;65S=&%M<`H@("`@("H@0')E='5R;B`@;6EX960@("`@("`@("`@(%5N:7@@
M=&EM97-T86UP+"!A('!R969O<FUA=&5D(&1A=&4M<W1R:6YG(&]R(%!%05(Z
M.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]-1%1-1$E27U5.
M4U504$]25$5$+"!.151?1E107T524E]-1%1-7T9!24Q%1"P@3D547T944%]%
M4E)?1$%4149/4DU!5%]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO
M;B!M9'1M*"1F:6QE+"`D9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@("`D
M9FEL92`]("1T:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)&9I;&4I.PH@("`@("`@
M(&EF("@D=&AI<RT^7V-H96-K7V1I<B@D9FEL92DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")&:6QE;F%M92`G)&9I;&4G('-E
M96US('1O(&)E(&$@9&ER96-T;W)Y+B(L($Y%5%]&5%!?15)27TU$5$U$25)?
M54Y355!03U)4140I.PH@("`@("`@('T*("`@("`@("`D<F5S(#T@0&9T<%]M
M9'1M*"1T:&ES+3Y?:&%N9&QE+"`D9FEL92D["B`@("`@("`@:68@*"1R97,@
M/3T@+3$I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")#;W5L9"!N;W0@9V5T(&QA<W0M;6]D:69I8V%T:6]N+61A=&4@;V8@)R1F
M:6QE)RXB+"!.151?1E107T524E]-1%1-7T9!24Q%1"D["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D9F]R;6%T*2D@>PH@("`@("`@("`@("`D<F5S
M(#T@9&%T92@D9F]R;6%T+"`D<F5S*3L*("`@("`@("`@("`@:68@*"$D<F5S
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(D1A=&4M9F]R;6%T(&9A:6QE9"!O;B!T:6UE<W1A;7`@)R1R97,G+B(L($Y%
M5%]&5%!?15)27T1!5$5&3U)-051?1D%)3$5$*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%1H:7,@=VEL;"!R971U<FX@=&AE('-I>F4@;V8@82!G:79E;B!F
M:6QE(&EN(&)Y=&5S+B!9;W4@8V%N(&5I=&AE<B!G:79E('1H:7,@9G5N8W1I
M;VX*("`@("`J(&$@<F5L871I=F4@;W(@86X@86)S;VQU=&4@9FEL92UP871H
M+B!.3U1%.B!3;VUE('-E<G9E<G,@9&\@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E(0H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A
M<F%M("`@<W1R:6YG("1F:6QE("`@5&AE(&9I;&4@=&\@8VAE8VL*("`@("`J
M($!R971U<FX@(&UI>&5D("`@("`@("`@(%-I>F4@:6X@8GET97,@;W(@4$5!
M4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27U-)6D5?1D%)
M3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<VEZ92@D9FEL92D*("`@
M('L*("`@("`@("`D9FEL92`]("1T:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)&9I
M;&4I.PH@("`@("`@("1R97,@/2!`9G1P7W-I>F4H)'1H:7,M/E]H86YD;&4L
M("1F:6QE*3L*("`@("`@("!I9B`H)')E<R`]/2`M,2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!D971E<FUI
M;F4@9FEL97-I>F4@;V8@)R1F:6QE)RXB+"!.151?1E107T524E]325I%7T9!
M24Q%1"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1R
M97,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!M971H
M;V0@<F5T=7)N<R!A(&1I<F5C=&]R>2UL:7-T(&]F('1H92!C=7)R96YT(&1I
M<F5C=&]R>2!O<B!G:79E;B!O;F4N"B`@("`@*B!4;R!D:7-P;&%Y('1H92!C
M=7)R96YT('-E;&5C=&5D(&1I<F5C=&]R>2P@<VEM<&QY('-E="!T:&4@9FER
M<W0@<&%R86UE=&5R('1O(&YU;&P*("`@("`J(&]R(&QE879E(&ET(&)L86YK
M+"!I9B!Y;W4@9&\@;F]T('=A;G0@=&\@=7-E(&%N>2!O=&AE<B!P87)A;65T
M97)S+@H@("`@("H@/$)2/CQ"4CX*("`@("`J(%1H97)E(&%R92`T(&1I9F9E
M<F5N="!M;V1E<R!O9B!L:7-T:6YG(&1I<F5C=&]R:65S+B!%:71H97(@=&\@
M;&ES="!O;FQY"B`@("`@*B!T:&4@9FEL97,@*'5S:6YG($Y%5%]&5%!?1DE,
M15-?3TY,62DL('1O(&QI<W0@;VYL>2!D:7)E8W1O<FEE<R`H=7-I;F<*("`@
M("`J($Y%5%]&5%!?1$E24U]/3DQ9*2!O<B!T;R!S:&]W(&)O=&@@*'5S:6YG
M($Y%5%]&5%!?1$E24U]&24Q%4RP@=VAI8V@@:7,@9&5F875L="DN"B`@("`@
M*B`\0E(^/$)2/@H@("`@("H@5&AE(#1T:"!O;F4@:7,@=&AE($Y%5%]&5%!?
M4D%73$E35"P@=VAI8V@@<F5T=7)N<R!J=7-T('1H92!A<G)A>2!C<F5A=&5D
M(&)Y('1H90H@("`@("H@9G1P7W)A=VQI<W0H*2UF=6YC=&EO;B!B=6EL9"!I
M;G1O(%!(4"X*("`@("`J(#Q"4CX\0E(^"B`@("`@*B!4:&4@;W1H97(@9G5N
M8W1I;VXM;6]D97,@=VEL;"!R971U<FX@86X@87)R87D@8V]N=&%I;FEN9R!T
M:&4@<F5Q=65S=&5D(&1A=&$N"B`@("`@*B!4:&4@9FEL97,@86YD(&1I<G,@
M87)E(&QI<W1E9"!I;B!H=6UA;BUS;W)T960@;W)D97(L(&)U="!I9B!Y;W4@
M<V5L96-T"B`@("`@*B!.151?1E107T1)4E-?1DE,15,@=&AE(&1I<F5C=&]R
M:65S('=I;&P@8F4@861D960@86)O=F4@=&AE(&9I;&5S+`H@("`@("H@8G5T
M(&%L=&AO=6=H(&)O=&@@<V]R=&5D+@H@("`@("H@/$)2/CQ"4CX*("`@("`J
M($%L;"!E;&5M96YT<R!I;B!T:&4@87)R87ES(&%R92!A<W-O8VEA=&EV92!A
M<G)A>7,@=&AE;7-E;'9E<RX@5&AE(&AA=F4@=&AE(&9O;&QO=VEN9PH@("`@
M("H@<W1R=6-T=7)E.@H@("`@("H@/$)2/CQ"4CX*("`@("`J($1I<G,Z/$)2
M/@H@("`@("H@("`@("`@("`@(%LB;F%M92)=("`@("`@("`]/B`@<W1R:6YG
M(%1H92!N86UE(&]F('1H92!D:7)E8W1O<GD\0E(^"B`@("`@*B`@("`@("`@
M("`@6R)R:6=H=',B72`@("`@(#T^("!S=')I;F<@5&AE(')I9VAT<R!O9B!T
M:&4@9&ER96-T;W)Y("AI;B!S='EL92`B<G=X<BUX<BUX(BD\0E(^"B`@("`@
M*B`@("`@("`@("`@6R)U<V5R(ET@("`@("`@(#T^("!S=')I;F<@5&AE(&]W
M;F5R(&]F('1H92!D:7)E8W1O<GD\0E(^"B`@("`@*B`@("`@("`@("`@6R)G
M<F]U<")=("`@("`@(#T^("!S=')I;F<@5&AE(&=R;W5P+6]W;F5R(&]F('1H
M92!D:7)E8W1O<GD\0E(^"B`@("`@*B`@("`@("`@("`@6R)F:6QE<U]I;G-I
M9&4B73T^("!S=')I;F<@5&AE(&YU;6)E<B!O9B!F:6QE<R]D:7)S(&EN<VED
M92!T:&4@9&ER96-T;W)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@97AC;'5D:6YG("(N(B!A;F0@(BXN(CQ"4CX*("`@
M("`J("`@("`@("`@("!;(F1A=&4B72`@("`@("`@/3X@(&EN="!4:&4@8W)E
M871I;VXM9&%T92!A<R!5;FEX('1I;65S=&%M<#Q"4CX*("`@("`J("`@("`@
M("`@("!;(FES7V1I<B)=("`@("`@/3X@(&)O;VP@=')U92P@8V%U<V4@=&AI
M<R!I<R!A(&1I<CQ"4CX*("`@("`J(#Q"4CX\0E(^"B`@("`@*B!&:6QE<SH\
M0E(^"B`@("`@*B`@("`@("`@("`@6R)N86UE(ET@("`@("`@(#T^("!S=')I
M;F<@5&AE(&YA;64@;V8@=&AE(&9I;&4\0E(^"B`@("`@*B`@("`@("`@("`@
M6R)S:7IE(ET@("`@("`@(#T^("!I;G0@4VEZ92!I;B!B>71E<SQ"4CX*("`@
M("`J("`@("`@("`@("!;(G)I9VAT<R)=("`@("`@/3X@('-T<FEN9R!4:&4@
M<FEG:'1S(&]F('1H92!F:6QE("AI;B!S='EL92`B<G=X<BUX<BUX(BD\0E(^
M"B`@("`@*B`@("`@("`@("`@6R)U<V5R(ET@("`@("`@(#T^("!S=')I;F<@
M5&AE(&]W;F5R(&]F('1H92!F:6QE/$)2/@H@("`@("H@("`@("`@("`@(%LB
M9W)O=7`B72`@("`@("`]/B`@<W1R:6YG(%1H92!G<F]U<"UO=VYE<B!O9B!T
M:&4@9FEL93Q"4CX*("`@("`J("`@("`@("`@("!;(F1A=&4B72`@("`@("`@
M/3X@(&EN="!4:&4@8W)E871I;VXM9&%T92!A<R!5;FEX('1I;65S=&%M<#Q"
M4CX*("`@("`J("`@("`@("`@("!;(FES7V1I<B)=("`@("`@/3X@(&)O;VP@
M9F%L<V4L(&-A=7-E('1H:7,@:7,@82!F:6QE/$)2/@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1D:7(@
M("`H;W!T:6]N86PI(%1H92!D:7)E8W1O<GD@=&\@;&ES="!O<B!N=6QL+"!W
M:&5N(&QI<W1I;F<@=&AE(&-U<G)E;G0@9&ER96-T;W)Y+@H@("`@("H@0'!A
M<F%M("`@:6YT("`@("1M;V1E("`H;W!T:6]N86PI(%1H92!M;V1E('=H:6-H
M('1Y<&5S('1O(&QI<W0@*&9I;&5S+"!D:7)E8W1O<FEE<R!O<B!B;W1H*2X*
M("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@5&AE(&1I<F5C=&]R>2!L
M:7-T(&%S(&1E<V-R:6)E9"!A8F]V92!O<B!014%2.CI%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("H@0'-E92`@("`@3D547T944%]$25)37T9)3$53+"!.151?
M1E107T1)4E-?3TY,62P@3D547T944%]&24Q%4U]/3DQ9+"!.151?1E107U)!
M5TQ)4U0L($Y%5%]&5%!?15)27T1%5$5234E.15!!5$A?1D%)3$5$+"!.151?
M1E107T524E]205=$25),25-47T9!24Q%1"P@3D547T944%]%4E)?1$E23$E3
M5%]53E-54%!/4E1%1`H@("`@("HO"B`@("`@"B`@("!F=6YC=&EO;B!L<R@D
M9&ER(#T@;G5L;"P@)&UO9&4@/2!.151?1E107T1)4E-?1DE,15,I"B`@("![
M"B`@("`@("`@:68@*"%I<W-E="@D9&ER*2D@>PH@("`@("`@("`@("`D9&ER
M(#T@0&9T<%]P=V0H)'1H:7,M/E]H86YD;&4I.PH@("`@("`@("`@("!I9B`H
M(21D:7(I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B0V]U;&0@;F]T(')E=')I979E(&-U<G)E;G0@9&ER96-T;W)Y(BP@
M3D547T944%]%4E)?1$5415)-24Y%4$%42%]&04E,140I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&EF("@H)&UO9&4@(3T@3D547T944%]&
M24Q%4U]/3DQ9*2`F)B`H)&UO9&4@(3T@3D547T944%]$25)37T].3%DI("8F
M("@D;6]D92`A/2!.151?1E107U)!5TQ)4U0I*2!["B`@("`@("`@("`@("1M
M;V1E(#T@3D547T944%]$25)37T9)3$53.PH@("`@("`@('T*"B`@("`@("`@
M<W=I=&-H("@D;6]D92D@>PH@("`@("`@("`@("!C87-E($Y%5%]&5%!?1$E2
M4U]&24Q%4SH@("`@)')E<R`]("1T:&ES+3Y?;'-?8F]T:"`H("1D:7(@*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E($Y%5%]&5%!?1$E24U]/3DQ9.B`@("`@)')E
M<R`]("1T:&ES+3Y?;'-?9&ER<R`H("1D:7(@*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C
M87-E($Y%5%]&5%!?1DE,15-?3TY,63H@("`@)')E<R`]("1T:&ES+3Y?;'-?
M9FEL97,@*"`D9&ER("D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92!.151?1E107U)!
M5TQ)4U0Z("`@("`@("1R97,@/2!`9G1P7W)A=VQI<W0H)'1H:7,M/E]H86YD
M;&4L("1D:7(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D('=I;&P@9&5L971E
M('1H92!G:79E;B!F:6QE(&]R(&1I<F5C=&]R>2`H)'!A=&@I(&9R;VT@=&AE
M('-E<G9E<@H@("`@("H@*&UA>6)E(')E8W5R<VEV92DN"B`@("`@*@H@("`@
M("H@5VAE=&AE<B!T:&4@9VEV96X@<W1R:6YG(&ES(&$@9FEL92!O<B!D:7)E
M8W1O<GD@:7,@;VYL>2!D971E<FUI;F5D(&)Y('1H92!L87-T"B`@("`@*B!S
M:6=N(&EN<VED92!T:&4@<W1R:6YG("@B+R(@;W(@;F]T*2X*("`@("`J"B`@
M("`@*B!)9B!Y;W4@<W!E8VEF>2!A(&1I<F5C=&]R>2P@>6]U(&-A;B!O<'1I
M;VYA;&QY('-P96-I9GD@)')E8W5R<VEV92!A<R!T<G5E+`H@("`@("H@=&\@
M;&5T('1H92!D:7)E8W1O<GD@8F4@9&5L971E9"!R96-U<G-I=F4@*'=I=&@@
M86QL('-U8BUD:7)E8W1O<FEE<R!A;F0@9FEL97,*("`@("`J(&EN:&5R:71E
M9"DN"B`@("`@*@H@("`@("H@66]U(&-A;B!E:71H97(@9VEV92!A(&%B<V]L
M=71E(&]R(')E;&%T:79E('!A=&@@9F]R('1H92!F:6QE("\@9&ER+B!)9B!Y
M;W4@8VAO;W-E('1O"B`@("`@*B!U<V4@=&AE(')E;&%T:79E('!A=&@L(&ET
M('=I;&P@8F4@875T;VUA=&EC86QL>2!C;VUP;&5T960@=VET:"!T:&4@86-T
M=6%L"B`@("`@*B!S96QE8W1E9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)'!A=&@@
M("`@("!4:&4@86)S;VQU=&4@;W(@<F5L871I=F4@<&%T:"!T;R!T:&4@9FEL
M92`O(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2`@(&)O;VP@("`D<F5C=7)S
M:79E("AO<'1I;VYA;"D*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@
M("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@
M("`@*B!`<V5E("`@("!.151?1E107T524E]$14Q%5$5&24Q%7T9!24Q%1"P@
M3D547T944%]%4E)?1$5,151%1$E27T9!24Q%1"P@3D547T944%]%4E)?4D5-
M3U1%4$%42$Y/1$E2"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<FTH)'!A
M=&@L("1R96-U<G-I=F4@/2!F86QS92D*("`@('L*("`@("`@("`D<&%T:"`]
M("1T:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)'!A=&@I.PH*("`@("`@("!I9B`H
M)'1H:7,M/E]C:&5C:U]D:7(H)'!A=&@I*2!["B`@("`@("`@("`@(&EF("@D
M<F5C=7)S:79E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R
M;5]D:7)?<F5C=7)S:79E*"1P871H*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)M7V1I<B@D<&%T:"D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R;5]F:6QE*"1P871H*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N('=I;&P@9&]W;FQO860@
M82!F:6QE(&9R;VT@=&AE(&9T<"US97)V97(N(%EO=2!C86X@96ET:&5R('-P
M8VEF>2!A(&%B<V]L=71E"B`@("`@*B!P871H('1O('1H92!F:6QE("AB96=I
M;FYI;F<@=VET:"`B+R(I(&]R(&$@<F5L871I=F4@;VYE+"!W:&EC:"!W:6QL
M(&)E(&-O;7!L971E9`H@("`@("H@=VET:"!T:&4@86-T=6%L(&1I<F5C=&]R
M>2!Y;W4@<V5L96-T960@;VX@=&AE('-E<G9E<BX@66]U(&-A;B!S<&5C:69Y
M"B`@("`@*B!T:&4@<&%T:"!T;R!W:&EC:"!T:&4@9FEL92!W:6QL(&)E(&1O
M=VYL;V%D960@;VX@=&AE(&QO8V%L"B`@("`@*B!M87-C:&EN92P@:68@=&AE
M(&9I;&4@<VAO=6QD(&)E(&]V97)W<FET=&5N(&EF(&ET(&5X:7-T<R`H;W!T
M:6]N86QL>2P@9&5F875L="!I<PH@("`@("H@;F\@;W9E<G=R:71I;F<I(&%N
M9"!I;B!W:&EC:"!M;V1E("A&5%!?05-#24D@;W(@1E107T))3D%262D@=&AE
M(&9I;&4@<VAO=6QD(&)E"B`@("`@*B!D;W=N;&]A9&5D("AI9B!Y;W4@9&\@
M;F]T('-P96-I9GD@=&AI<RP@=&AE(&UE=&AO9"!T<FEE<R!T;R!D971E<FUI
M;F4@:70@875T;VUA=&EC86QL>0H@("`@("H@9G)O;2!T:&4@;6]D92UD:7)E
M8W1O<GD@;W(@=7-E<R!T:&4@9&5F875L="UM;V1E+"!S970@8GD@>6]U*2X@
M268@>6]U(&=I=F4@82!R96QA=&EV90H@("`@("H@<&%T:"!T;R!T:&4@;&]C
M86PM9FEL92P@=&AE('-C<FEP="UP871H(&ES('5S960@87,@8F%S97!A=&@N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@)')E;6]T95]F:6QE(%1H92!A8G-O;'5T92!O<B!R96QA=&EV
M92!P871H('1O('1H92!F:6QE('1O(&1O=VYL;V%D"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@)&QO8V%L7V9I;&4@(%1H92!L;V-A;"!F:6QE('1O('!U="!T
M:&4@9&]W;FQO861E9"!I;@H@("`@("H@0'!A<F%M("`@8F]O;"`@("1O=F5R
M=W)I=&4@("`H;W!T:6]N86PI(%=H971H97(@=&\@;W9E<G=R:71E(&5X:7-T
M:6YG(&9I;&4*("`@("`J($!P87)A;2`@(&EN="`@("`D;6]D92`@("`@("`@
M*&]P=&EO;F%L*2!%:71H97(@1E107T%30TE)(&]R($944%]"24Y!4ED*("`@
M("`J($!R971U<FX@(&UI>&5D("`@("`@("`@("`@("`@5')U92!O;B!S=6-C
M97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%
M5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&3U)"241$14XL($Y%5%]&
M5%!?15)27T]615)74DE414Q/0T%,1DE,15]&04E,140L($Y%5%]&5%!?15)2
M7T]615)74DE414Q/0T%,1DE,15]&04E,140*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!G970H)')E;6]T95]F:6QE+"`D;&]C86Q?9FEL92P@)&]V97)W
M<FET92`](&9A;'-E+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D;6]D92DI('L*("`@("`@("`@("`@)&UO9&4@/2`D=&AI<RT^
M8VAE8VM&:6QE17AT96YS:6]N*"1R96UO=&5?9FEL92D["B`@("`@("`@?0H*
M("`@("`@("`D<F5M;W1E7V9I;&4@/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H
M*"1R96UO=&5?9FEL92D["@H@("`@("`@(&EF("A`9FEL95]E>&ES=',H)&QO
M8V%L7V9I;&4I("8F("$D;W9E<G=R:71E*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B3&]C86P@9FEL92`G)&QO8V%L7V9I;&4G
M(&5X:7-T<R!A;F0@;6%Y(&YO="!B92!O=F5R=W)I=&5N+B(L($Y%5%]&5%!?
M15)27T]615)74DE414Q/0T%,1DE,15]&3U)"241$14XI.PH@("`@("`@('T*
M("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1L;V-A;%]F:6QE*2`F)B`A0&ES
M7W=R:71E86)L92@D;&]C86Q?9FEL92D@)B8@)&]V97)W<FET92D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(DQO8V%L(&9I;&4@
M)R1L;V-A;%]F:6QE)R!I<R!N;W0@=W)I=&5A8FQE+B!#86X@;F]T(&]V97)W
M<FET92XB+"!.151?1E107T524E]/5D525U))5$5,3T-!3$9)3$5?1D%)3$5$
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("A`9G5N8W1I;VY?97AI<W1S*"=F
M='!?;F)?9V5T)RDI>PH@("`@("`@("`@("`D<F5S(#T@0&9T<%]N8E]G970H
M)'1H:7,M/E]H86YD;&4L("1L;V-A;%]F:6QE+"`D<F5M;W1E7V9I;&4L("1M
M;V1E*3L*("`@("`@("`@("`@=VAI;&4@*"1R97,@/3T@1E107TU/4D5$051!
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*"=N8E]G970G
M*3L*("`@("`@("`@("`@("`@("1R97,@/2!`9G1P7VYB7V-O;G1I;G5E("@D
M=&AI<RT^7VAA;F1L92D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<F5S(#T@0&9T<%]G970H)'1H:7,M/E]H86YD;&4L
M("1L;V-A;%]F:6QE+"`D<F5M;W1E7V9I;&4L("1M;V1E*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B1FEL92`G)')E;6]T95]F:6QE)R!C;W5L9"!N;W0@
M8F4@9&]W;FQO861E9"!T;R`G)&QO8V%L7V9I;&4G+B(L($Y%5%]&5%!?15)2
M7T]615)74DE414Q/0T%,1DE,15]&04E,140I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@=VEL;"!U<&QO860@82!F:6QE
M('1O('1H92!F='`M<V5R=F5R+B!9;W4@8V%N(&5I=&AE<B!S<&5C:69Y(&$@
M86)S;VQU=&4*("`@("`J('!A=&@@=&\@=&AE(')E;6]T92UF:6QE("AB96=I
M;FYI;F<@=VET:"`B+R(I(&]R(&$@<F5L871I=F4@;VYE+"!W:&EC:"!W:6QL
M(&)E(&-O;7!L971E9`H@("`@("H@=VET:"!T:&4@86-T=6%L(&1I<F5C=&]R
M>2!Y;W4@<V5L96-T960@;VX@=&AE('-E<G9E<BX@66]U(&-A;B!S<&5C:69Y
M"B`@("`@*B!T:&4@<&%T:"!F<F]M('=H:6-H('1H92!F:6QE('=I;&P@8F4@
M=7!L;V%D960@;VX@=&AE(&QO8V%L"B`@("`@*B!M87-C:&EN92P@:68@=&AE
M(&9I;&4@<VAO=6QD(&)E(&]V97)W<FET=&5N(&EF(&ET(&5X:7-T<R`H;W!T
M:6]N86QL>2P@9&5F875L="!I<PH@("`@("H@;F\@;W9E<G=R:71I;F<I(&%N
M9"!I;B!W:&EC:"!M;V1E("A&5%!?05-#24D@;W(@1E107T))3D%262D@=&AE
M(&9I;&4@<VAO=6QD(&)E"B`@("`@*B!D;W=N;&]A9&5D("AI9B!Y;W4@9&\@
M;F]T('-P96-I9GD@=&AI<RP@=&AE(&UE=&AO9"!T<FEE<R!T;R!D971E<FUI
M;F4@:70@875T;VUA=&EC86QL>0H@("`@("H@9G)O;2!T:&4@;6]D92UD:7)E
M8W1O<GD@;W(@=7-E<R!T:&4@9&5F875L="UM;V1E+"!S970@8GD@>6]U*2X@
M268@>6]U(&=I=F4@82!R96QA=&EV90H@("`@("H@<&%T:"!T;R!T:&4@;&]C
M86PM9FEL92P@=&AE('-C<FEP="UP871H(&ES('5S960@87,@8F%S97!A=&@N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@)&QO8V%L7V9I;&4@(%1H92!L;V-A;"!F:6QE('1O('5P;&]A
M9`H@("`@("H@0'!A<F%M("`@<W1R:6YG("1R96UO=&5?9FEL92!4:&4@86)S
M;VQU=&4@;W(@<F5L871I=F4@<&%T:"!T;R!T:&4@9FEL92!T;R!U<&QO860@
M=&\*("`@("`J($!P87)A;2`@(&)O;VP@("`D;W9E<G=R:71E("`@*&]P=&EO
M;F%L*2!7:&5T:&5R('1O(&]V97)W<FET92!E>&ES=&EN9R!F:6QE"B`@("`@
M*B!`<&%R86T@("!I;G0@("`@)&UO9&4@("`@("`@("AO<'1I;VYA;"D@16ET
M:&5R($944%]!4T-)22!O<B!&5%!?0DE.05)9"B`@("`@*B!`<F5T=7)N("!M
M:7AE9"`@("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E
M(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E],3T-!
M3$9)3$5.3U1%6$E35"P@3D547T944%]%4E)?3U9%4E=2251%4D5-3U1%1DE,
M15]&3U)"241$14XL($Y%5%]&5%!?15)27U503$]!1$9)3$5?1D%)3$5$"B`@
M("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<'5T*"1L;V-A;%]F:6QE+"`D<F5M
M;W1E7V9I;&4L("1O=F5R=W)I=&4@/2!F86QS92P@)&UO9&4@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)&UO9&4I*2!["B`@("`@("`@("`@
M("1M;V1E(#T@)'1H:7,M/F-H96-K1FEL945X=&5N<VEO;B@D;&]C86Q?9FEL
M92D["B`@("`@("`@?0H@("`@("`@("1R96UO=&5?9FEL92`]("1T:&ES+3Y?
M8V]N<W1R=6-T7W!A=&@H)')E;6]T95]F:6QE*3L*"B`@("`@("`@:68@*"%`
M9FEL95]E>&ES=',H)&QO8V%L7V9I;&4I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B3&]C86P@9FEL92`G)&QO8V%L7V9I;&4G
M(&1O97,@;F]T(&5X:7-T+B(L($Y%5%]&5%!?15)27TQ/0T%,1DE,14Y/5$58
M25-4*3L*("`@("`@("!]"B`@("`@("`@:68@*"A`9G1P7W-I>F4H)'1H:7,M
M/E]H86YD;&4L("1R96UO=&5?9FEL92D@(3T@+3$I("8F("$D;W9E<G=R:71E
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4F5M
M;W1E(&9I;&4@)R1R96UO=&5?9FEL92<@97AI<W1S(&%N9"!M87D@;F]T(&)E
M(&]V97)W<FET96XN(BP@3D547T944%]%4E)?3U9%4E=2251%4D5-3U1%1DE,
M15]&3U)"241$14XI.PH@("`@("`@('T*"B`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G9G1P7VYB7W!U="<I*7L*("`@("`@("`@("`@)')E<R`]($!F
M='!?;F)?<'5T*"1T:&ES+3Y?:&%N9&QE+"`D<F5M;W1E7V9I;&4L("1L;V-A
M;%]F:6QE+"`D;6]D92D["B`@("`@("`@("`@('=H:6QE("@D<F5S(#T]($94
M4%]-3U)%1$%402D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A;FYO=6YC
M92@G;F)?<'5T)RD["B`@("`@("`@("`@("`@("`D<F5S(#T@0&9T<%]N8E]C
M;VYT:6YU92@D=&AI<RT^7VAA;F1L92D["B`@("`@("`@("`@('T*"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<R`]($!F='!?<'5T*"1T:&ES
M+3Y?:&%N9&QE+"`D<F5M;W1E7V9I;&4L("1L;V-A;%]F:6QE+"`D;6]D92D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D9I;&4@)R1L;V-A;%]F:6QE)R!C
M;W5L9"!N;W0@8F4@=7!L;V%D960@=&\@)R1R96UO=&5?9FEL92<N(BP@3D54
M7T944%]%4E)?55!,3T%$1DE,15]&04E,140I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VYA;&ET>2!A;&QO=W,@>6]U('1O
M('1R86YS9F5R(&$@=VAO;&4@9&ER96-T;W)Y+7-T<G5C='5R92!F<F]M('1H
M90H@("`@("H@<F5M;W1E+69T<"!T;R!Y;W5R(&QO8V%L(&AO<W0N(%EO=2!H
M879E('1O(&=I=F4@82!R96UO=&4M9&ER96-T;W)Y("AE;F1I;F<@=VET:`H@
M("`@("H@)R\G*2!A;F0@=&AE(&QO8V%L(&1I<F5C=&]R>2`H96YD:6YG('=I
M=&@@)R\G*2!W:&5R92!T;R!P=70@=&AE(&9I;&5S('EO=2!D;W=N;&]A9"X*
M("`@("`J(%1H92!R96UO=&4@<&%T:"!I<R!A=71O;6%T:6-A;&QY(&-O;7!L
M971E9"!W:71H('1H92!C=7)R96YT+7)E;6]T92UD:7(L(&EF('EO=2!G:79E
M"B`@("`@*B!A(')E;&%T:79E('!A=&@@=&\@=&AI<R!F=6YC=&EO;BX@66]U
M(&-A;B!G:79E(&$@<F5L871I=F4@<&%T:"!F;W(@=&AE("1L;V-A;%]P871H
M+`H@("`@("H@=&]O+B!4:&5N('1H92!S8W)I<'0M8F%S961I<B!W:6QL(&)E
M('5S960@9F]R(&-O;6QE=&EO;B!O9B!T:&4@<&%T:"X*("`@("`J(%1H92!P
M87)A;65T97(@)&]V97)W<FET92!W:6QL(&1E=&5R;6EN92P@=VAE=&AE<B!T
M;R!O=F5R=W)I=&4@97AI<W1I;F<@9FEL97,@;W(@;F]T+@H@("`@("H@4W1A
M;F1A<F0@9F]R('1H:7,@:7,@9F%L<V4N($9O=7)T:"!Y;W4@8V%N(&5X<&QI
M8VET;'D@<V5T(&$@;6]D92!F;W(@86QL('1R86YS9F5R+0H@("`@("H@86-T
M:6]N<R!D;VYE+B!)9B!Y;W4@9&\@;F]T('-E="!T:&ES+"!T:&4@;65T:&]D
M('1R:65S('1O(&1E=&5R;6EN92!T:&4@=')A;G-F97(M"B`@("`@*B!M;V1E
M(&)Y(&-H96-K:6YG('EO=7(@;6]D92UD:7)E8W1O<GD@9F]R('1H92!F:6QE
M+65X=&5N<VEO;BX@268@=&AE(&5X=&5N<VEO;B!I<R!N;W0*("`@("`J(&EN
M<VED92!T:&4@;6]D92UD:7)E8W1O<GDL(&ET('=I;&P@9V5T('EO=7(@9&5F
M875L="UM;V1E+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1R96UO=&5?<&%T:"!4:&4@<&%T:"!T;R!D
M;W=N;&]A9`H@("`@("H@0'!A<F%M("`@<W1R:6YG("1L;V-A;%]P871H("!4
M:&4@<&%T:"!T;R!D;W=N;&]A9"!T;PH@("`@("H@0'!A<F%M("`@8F]O;"`@
M("1O=F5R=W)I=&4@("`H;W!T:6]N86PI(%=H971H97(@=&\@;W9E<G=R:71E
M(&5X:7-T:6YG(&9I;&5S("AT<G5E*2!O<B!N;W0@*&9A;'-E+"!S=&%N9&%R
M9"DN"B`@("`@*B!`<&%R86T@("!I;G0@("`@)&UO9&4@("`@("`@("AO<'1I
M;VYA;"D@5&AE('1R86YS9F5R;6]D92`H96ET:&5R($944%]!4T-)22!O<B!&
M5%!?0DE.05)9*2X*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@("`@
M("`@5')U92!O;B!S=6-C97,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@
M("H@0'-E92`@("`@3D547T944%]%4E)?3U9%4E=2251%3$]#04Q&24Q%7T9/
M4D))1$1%3BP@3D547T944%]%4E)?3U9%4E=2251%3$]#04Q&24Q%7T9!24Q%
M1"P@3D547T944%]%4E)?3U9%4E=2251%3$]#04Q&24Q%7T9!24Q%1"P@3D54
M7T944%]%4E)?4D5-3U1%4$%42$Y/1$E2+"!.151?1E107T524E],3T-!3%!!
M5$A.3T1)4BQ.151?1E107T524E]#4D5!5$5,3T-!3$1)4E]&04E,140*("`@
M("`J+PH@("`@"B`@("!F=6YC=&EO;B!G971296-U<G-I=F4H)')E;6]T95]P
M871H+"`D;&]C86Q?<&%T:"P@)&]V97)W<FET92`](&9A;'-E+"`D;6]D92`]
M(&YU;&PI"B`@("!["B`@("`@("`@)')E;6]T95]P871H(#T@)'1H:7,M/E]C
M;VYS=')U8W1?<&%T:"@D<F5M;W1E7W!A=&@I.PH@("`@("`@(&EF("@A)'1H
M:7,M/E]C:&5C:U]D:7(H)')E;6]T95]P871H*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D=I=F5N(')E;6]T92UP871H("<D
M<F5M;W1E7W!A=&@G('-E96US(&YO="!T;R!B92!A(&1I<F5C=&]R>2XB+"!.
M151?1E107T524E]214U/5$50051(3D]$25(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21T:&ES+3Y?8VAE8VM?9&ER*"1L;V-A;%]P871H*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D=I=F5N(&QO8V%L
M+7!A=&@@)R1L;V-A;%]P871H)R!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O
M<GDN(BP@3D547T944%]%4E)?3$]#04Q0051(3D]$25(I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%`:7-?9&ER*"1L;V-A;%]P871H*2D@>PH@("`@("`@
M("`@("`D<F5S(#T@0&UK9&ER*"1L;V-A;%]P871H*3L*("`@("`@("`@("`@
M:68@*"$D<F5S*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(D-O=6QD(&YO="!C<F5A=&4@9&ER("<D;&]C86Q?<&%T:"<B
M+"!.151?1E107T524E]#4D5!5$5,3T-!3$1)4E]&04E,140I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@("1D:7)?;&ES="`](&%R<F%Y*"D[
M"B`@("`@("`@)&1I<E]L:7-T(#T@)'1H:7,M/FQS*"1R96UO=&5?<&%T:"P@
M3D547T944%]$25)37T].3%DI.PH@("`@("`@(&9O<F5A8V@@*"1D:7)?;&ES
M="!A<R`D9&ER7V5N=')Y*2!["B`@("`@("`@("`@(&EF("@D9&ER7V5N=')Y
M6R=N86UE)UT@(3T@)RXG("8F("1D:7)?96YT<GE;)VYA;64G72`A/2`G+BXG
M*2!["B`@("`@("`@("`@("`@("`D<F5M;W1E7W!A=&A?;F5W(#T@)')E;6]T
M95]P871H+B1D:7)?96YT<GE;(FYA;64B72XB+R(["B`@("`@("`@("`@("`@
M("`D;&]C86Q?<&%T:%]N97<@/2`D;&]C86Q?<&%T:"XD9&ER7V5N=')Y6R)N
M86UE(ETN(B\B.PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YG
M971296-U<G-I=F4H)')E;6]T95]P871H7VYE=RP@)&QO8V%L7W!A=&A?;F5W
M+"`D;W9E<G=R:71E+"`D;6]D92D["B`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`D9FEL95]L:7-T(#T@87)R87DH*3L*("`@
M("`@("`D9FEL95]L:7-T(#T@)'1H:7,M/FQS*"1R96UO=&5?<&%T:"P@3D54
M7T944%]&24Q%4U]/3DQ9*3L*("`@("`@("!F;W)E86-H("@D9FEL95]L:7-T
M(&%S("1F:6QE7V5N=')Y*2!["B`@("`@("`@("`@("1R96UO=&5?9FEL92`]
M("1R96UO=&5?<&%T:"XD9FEL95]E;G1R>5LB;F%M92)=.PH@("`@("`@("`@
M("`D;&]C86Q?9FEL92`]("1L;V-A;%]P871H+B1F:6QE7V5N=')Y6R)N86UE
M(ET["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T*"1R96UO=&5?
M9FEL92P@)&QO8V%L7V9I;&4L("1O=F5R=W)I=&4L("1M;V1E*3L*("`@("`@
M("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H:7,@9G5N8W1I;VYA;&ET>2!A;&QO=W,@>6]U('1O('1R86YS9F5R(&$@
M=VAO;&4@9&ER96-T;W)Y+7-T<G5C='5R92!F<F]M('EO=7(*("`@("`J(&QO
M8V%L(&AO<W0@=&\@=&AE(')E;6]T92UF='`N(%EO=2!H879E('1O(&=I=F4@
M82!R96UO=&4M9&ER96-T;W)Y("AE;F1I;F<@=VET:`H@("`@("H@)R\G*2!A
M;F0@=&AE(&QO8V%L(&1I<F5C=&]R>2`H96YD:6YG('=I=&@@)R\G*2!W:&5R
M92!T;R!P=70@=&AE(&9I;&5S('EO=2!D;W=N;&]A9"X*("`@("`J(%1H92!R
M96UO=&4@<&%T:"!I<R!A=71O;6%T:6-A;&QY(&-O;7!L971E9"!W:71H('1H
M92!C=7)R96YT+7)E;6]T92UD:7(L(&EF('EO=2!G:79E"B`@("`@*B!A(')E
M;&%T:79E('!A=&@@=&\@=&AI<R!F=6YC=&EO;BX@66]U(&-A;B!G:79E(&$@
M<F5L871I=F4@<&%T:"!F;W(@=&AE("1L;V-A;%]P871H+`H@("`@("H@=&]O
M+B!4:&5N('1H92!S8W)I<'0M8F%S961I<B!W:6QL(&)E('5S960@9F]R(&-O
M;6QE=&EO;B!O9B!T:&4@<&%T:"X*("`@("`J(%1H92!P87)A;65T97(@)&]V
M97)W<FET92!W:6QL(&1E=&5R;6EN92P@=VAE=&AE<B!T;R!O=F5R=W)I=&4@
M97AI<W1I;F<@9FEL97,@;W(@;F]T+@H@("`@("H@4W1A;F1A<F0@9F]R('1H
M:7,@:7,@9F%L<V4N($9O=7)T:"!Y;W4@8V%N(&5X<&QI8VET;'D@<V5T(&$@
M;6]D92!F;W(@86QL('1R86YS9F5R+0H@("`@("H@86-T:6]N<R!D;VYE+B!)
M9B!Y;W4@9&\@;F]T('-E="!T:&ES+"!T:&4@;65T:&]D('1R:65S('1O(&1E
M=&5R;6EN92!T:&4@=')A;G-F97(M"B`@("`@*B!M;V1E(&)Y(&-H96-K:6YG
M('EO=7(@;6]D92UD:7)E8W1O<GD@9F]R('1H92!F:6QE+65X=&5N<VEO;BX@
M268@=&AE(&5X=&5N<VEO;B!I<R!N;W0*("`@("`J(&EN<VED92!T:&4@;6]D
M92UD:7)E8W1O<GDL(&ET('=I;&P@9V5T('EO=7(@9&5F875L="UM;V1E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@
M<W1R:6YG("1R96UO=&5?<&%T:"!4:&4@<&%T:"!T;R!D;W=N;&]A9"`*("`@
M("`J($!P87)A;2`@('-T<FEN9R`D;&]C86Q?<&%T:"`@5&AE('!A=&@@=&\@
M9&]W;FQO860@=&\*("`@("`J($!P87)A;2`@(&)O;VP@("`D;W9E<G=R:71E
M("`@*&]P=&EO;F%L*2!7:&5T:&5R('1O(&]V97)W<FET92!E>&ES=&EN9R!F
M:6QE<R`H=')U92D@;W(@;F]T("AF86QS92P@<W1A;F1A<F0I+@H@("`@("H@
M0'!A<F%M("`@:6YT("`@("1M;V1E("`@("`@("`H;W!T:6]N86PI(%1H92!T
M<F%N<V9E<FUO9&4@*&5I=&AE<B!&5%!?05-#24D@;W(@1E107T))3D%262DN
M"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("`@(%1R=64@;VX@
M<W5C8V5S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@
M($Y%5%]&5%!?15)27TQ/0T%,1DE,14Y/5$5825-4+"!.151?1E107T524E]/
M5D525U))5$5214U/5$5&24Q%7T9/4D))1$1%3BP@3D547T944%]%4E)?55!,
M3T%$1DE,15]&04E,140L($Y%5%]&5%!?15)27TQ/0T%,4$%42$Y/1$E2+"!.
M151?1E107T524E]214U/5$50051(3D]$25(*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!P=71296-U<G-I=F4H)&QO8V%L7W!A=&@L("1R96UO=&5?<&%T
M:"P@)&]V97)W<FET92`](&9A;'-E+"`D;6]D92`](&YU;&PI"B`@("!["B`@
M("`@("`@)')E;6]T95]P871H(#T@)'1H:7,M/E]C;VYS=')U8W1?<&%T:"@D
M<F5M;W1E7W!A=&@I.PH@("`@("`@(&EF("@A)'1H:7,M/E]C:&5C:U]D:7(H
M)&QO8V%L7W!A=&@I('Q\("%I<U]D:7(H)&QO8V%L7W!A=&@I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1VEV96X@;&]C86PM
M<&%T:"`G)&QO8V%L7W!A=&@G('-E96US(&YO="!T;R!B92!A(&1I<F5C=&]R
M>2XB+"!.151?1E107T524E],3T-!3%!!5$A.3T1)4BD["B`@("`@("`@?0H@
M("`@("`@(&EF("@A)'1H:7,M/E]C:&5C:U]D:7(H)')E;6]T95]P871H*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D=I=F5N
M(')E;6]T92UP871H("<D<F5M;W1E7W!A=&@G('-E96US(&YO="!T;R!B92!A
M(&1I<F5C=&]R>2XB+"!.151?1E107T524E]214U/5$50051(3D]$25(I.PH@
M("`@("`@('T*("`@("`@("`D;VQD7W!A=&@@/2`D=&AI<RT^<'=D*"D["B`@
M("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"1T:&ES+3YC9"@D<F5M;W1E7W!A
M=&@I*2D@>PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/FUK9&ER*"1R96UO
M=&5?<&%T:"D["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-%<G)O<B@D<F5S
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F-D*"1O;&1?<&%T:"D["B`@
M("`@("`@)&1I<E]L:7-T(#T@)'1H:7,M/E]L<U]L;V-A;"@D;&]C86Q?<&%T
M:"D["B`@("`@("`@9F]R96%C:"`H)&1I<E]L:7-T6R)D:7)S(ET@87,@)&1I
M<E]E;G1R>2D@>PH@("`@("`@("`@("`D<F5M;W1E7W!A=&A?;F5W(#T@)')E
M;6]T95]P871H+B1D:7)?96YT<GDN(B\B.PH@("`@("`@("`@("`D;&]C86Q?
M<&%T:%]N97<@/2`D;&]C86Q?<&%T:"XD9&ER7V5N=')Y+B(O(CL*("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YP=71296-U<G-I=F4H)&QO8V%L7W!A
M=&A?;F5W+"`D<F5M;W1E7W!A=&A?;F5W+"`D;W9E<G=R:71E+"`D;6]D92D[
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1D:7)?;&ES=%LB9FEL97,B
M72!A<R`D9FEL95]E;G1R>2D@>PH@("`@("`@("`@("`D<F5M;W1E7V9I;&4@
M/2`D<F5M;W1E7W!A=&@N)&9I;&5?96YT<GD["B`@("`@("`@("`@("1L;V-A
M;%]F:6QE(#T@)&QO8V%L7W!A=&@N)&9I;&5?96YT<GD["B`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^<'5T*"1L;V-A;%]F:6QE+"`D<F5M;W1E7V9I
M;&4L("1O=F5R=W)I=&4L("1M;V1E*3L*("`@("`@("`@("`@:68@*"1T:&ES
M+3YI<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@8VAE8VMS+"!W
M:&5T:&5R(&$@9FEL92!S:&]U;&0@8F4@=')A;G-F97)E9"!I;B!A<V-I:2T@
M;W(@8FEN87)Y+6UO9&4*("`@("`J(&)Y(&ET)W,@9FEL92UE>'1E;G-I;VXN
M($EF('1H92!F:6QE+65X=&5N<VEO;B!I<R!N;W0@<V5T(&]R"B`@("`@*B!T
M:&4@97AT96YS:6]N(&ES(&YO="!I;G-I9&4@;VYE(&]F('1H92!E>'1E;G-I
M;VXM9&ER<RP@=&AE(&%C='5A;"!S970*("`@("`J('1R86YS9F5R+6UO9&4@
M:7,@<F5T=7)N960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@)&9I;&5N86UE("!4:&4@9FEL96YA;64@
M=&\@8F4@8VAE8VME9`H@("`@("H@0')E='5R;B`@:6YT("`@("`@("`@("`@
M("`@16ET:&5R($944%]!4T-)22!O<B!&5%!?0DE.05)9"B`@("`@*B\*("`@
M(`H@("`@9G5N8W1I;VX@8VAE8VM&:6QE17AT96YS:6]N*"1F:6QE;F%M92D*
M("`@('L*("`@("`@("`D<&%T=&5R;B`]("(O7"XH+BHI)"\B.PH@("`@("`@
M("1H87-?97AT96YS:6]N(#T@<')E9U]M871C:"@D<&%T=&5R;BP@)&9I;&5N
M86UE+"`D97)E9W,I.PH@("`@("`@(&EF("@A)&AA<U]E>'1E;G-I;VXI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]D93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D97AT(#T@)&5R96=S6S%=.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD
M97AT72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9FEL95]E>'1E
M;G-I;VYS6R1E>'1=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?;6]D93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@2&]S=&YA
M;64*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A
M;2`@('-T<FEN9R`D:&]S="!4:&4@2&]S=&YA;64@=&\@<V5T"B`@("`@*B!`
M<F5T=7)N("!B;V]L(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z
M.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E](3U-43D%-14Y/
M4U1224Y'"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<V5T2&]S=&YA;64H
M)&AO<W0I"B`@("!["B`@("`@("`@:68@*"%I<U]S=')I;F<H)&AO<W0I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")(;W-T;F%M
M92!M=7-T(&)E(&$@<W1R:6YG+B(L($Y%5%]&5%!?15)27TA/4U1.04U%3D]3
M5%))3D<I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VAO<W1N86UE(#T@
M)&AO<W0["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE(%!O<G0*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J($!P87)A;2`@(&EN="`D<&]R="`@("!4:&4@4&]R="!T;R!S
M970*("`@("`J($!R971U<FX@(&)O;VP@5')U92!O;B!S=6-C97-S+"!O=&AE
M<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)2
M7U!/4E1,15-36D523PH@("`@("HO"B`@("`*("`@(&9U;F-T:6]N('-E=%!O
M<G0H)'!O<G0I"B`@("!["B`@("`@("`@:68@*"%I<U]I;G0H)'!O<G0I('Q\
M("@D<&]R="`\(#`I*2!["B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H
M(DEN=F%L:60@<&]R="X@2&%S('1O(&)E(&EN=&5G97(@/CT@,"(L($Y%5%]&
M5%!?15)27U!/4E1,15-36D523RD["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?<&]R="`]("1P;W)T.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T('1H92!5<V5R;F%M90H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1U<V5R
M(%1H92!5<V5R;F%M92!T;R!S970*("`@("`J($!R971U<FX@(&UI>&5D(%1R
M=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`
M<V5E("`@("!.151?1E107T524E]54T523D%-14Y/4U1224Y'"B`@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@<V5T57-E<FYA;64H)'5S97(I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1U<V5R*2!\?"`A:7-?<W1R:6YG*"1U<V5R*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G57-E<FYA
M;64@)'5S97(@:6YV86QI9"XG+"!.151?1E107T524E]54T523D%-14Y/4U12
M24Y'*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]U<V5R;F%M92`]("1U
M<V5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!087-S=V]R9`H@
M("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@
M('-T<FEN9R`D<&%S<W=O<F0@(%1H92!087-S=V]R9"!T;R!S970*("`@("`J
M($!R971U<FX@('9O:60*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27U!!
M4U-73U)$3D]35%))3D<*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!S9710
M87-S=V]R9"@D<&%S<W=O<F0I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P
M87-S=V]R9"D@?'P@(6ES7W-T<FEN9R@D<&%S<W=O<F0I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=087-S=V]R9"!X>'@@:6YV
M86QI9"XG+"!.151?1E107T524E]005-35T]21$Y/4U1224Y'*3L*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/E]P87-S=V]R9"`]("1P87-S=V]R9#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@=')A;G-F97(M;6]D92X@66]U
M(&-A;B!U<V4@=&AE('!R961E9FEN960@8V]N<W1A;G1S"B`@("`@*B!&5%!?
M05-#24D@;W(@1E107T))3D%262X@5&AE(&UO9&4@=VEL;"!B92!S=&]R960@
M9F]R(&%N>2!F=7)T:&5R('1R86YS9F5R<RX*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@(&EN="`@("`D;6]D92`@5&AE
M(&UO9&4@=&\@<V5T"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@(%1R
M=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`
M<V5E("`@("!.151?1E107T524E].3TU/1$5#3TY35`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N('-E=$UO9&4H)&UO9&4I"B`@("!["B`@("`@("`@:68@
M*"@D;6]D92`]/2!&5%!?05-#24DI('Q\("@D;6]D92`]/2!&5%!?0DE.05)9
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VUO9&4@/2`D;6]D93L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=&5%`M36]D92!H87,@96ET
M:&5R('1O(&)E($944%]!4T-)22!O<B!&5%!?0DE.05)9)RP@3D547T944%]%
M4E)?3D]-3T1%0T].4U0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@=')A;G-F97(M;65T:&]D('1O('!A<W-I=F4@;6]D90H@
M("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@
M=F]I9`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N('-E=%!A<W-I=F4H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<&%S<W8@/2!T<G5E.PH@("`@("`@($!F
M='!?<&%S=B@D=&AI<RT^7VAA;F1L92P@=')U92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3970@=&AE('1R86YS9F5R+6UE=&AO9"!T;R!A8W1I=F4@;6]D
M90H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R
M;B`@=F]I9`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N('-E=$%C=&EV92@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]P87-S=B`](&9A;'-E.PH@("`@("`@
M($!F='!?<&%S=B@D=&AI<RT^7VAA;F1L92P@9F%L<V4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('1H92!T:6UE;W5T(&9O<B!&5%`@;W!E<F%T:6]N
M<PH@("`@("H@57-E('1H:7,@;65T:&]D('1O('-E="!A('1I;65O=70@9F]R
M($944"!O<&5R871I;VXN(%1I;65O=70@:&%S('1O(&)E(&%N(&EN=&5G97(N
M"B`@("`@*@H@("`@("H@0&%C97-S("`@<'5B;&EC"B`@("`@*B!`<&%R86T@
M("!I;G0@)'1I;65O=70@=&AE('1I;65O=70@=&\@=7-E"B`@("`@*B!`<F5T
M=7)N("!B;V]L(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R
M<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]424U%3U543$534UI%
M4D\L($Y%5%]&5%!?15)27U-%5%1)345/551?1D%)3$5$"B`@("`@*B\*("`@
M("`*("`@(&9U;F-T:6]N('-E=%1I;65O=70@*"`D=&EM96]U="`](#`@*2`*
M("`@('L*("`@("`@("!I9B`H(6ES7VEN="@D=&EM96]U="D@?'P@*"1T:6UE
M;W5T(#P@,"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(E1I;65O=70@)'1I;65O=70@:7,@:6YV86QI9"P@:&%S('1O(&)E(&%N
M(&EN=&5G97(@/CT@,"(L($Y%5%]&5%!?15)27U1)345/551,15-36D523RD[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?=&EM96]U="`]("1T:6UE;W5T
M.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAA;F1L92D@)B8@:7-?<F5S
M;W5R8V4H)'1H:7,M/E]H86YD;&4I*2!["B`@("`@("`@("`@("1R97,@/2!`
M9G1P7W-E=%]O<'1I;VXH)'1H:7,M/E]H86YD;&4L($944%]424U%3U547U-%
M0RP@)'1I;65O=70I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M97,@/2!T<G5E.PH@("`@("`@('T*("`@("`@("!I9B`H(21R97,I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E-E="!T:6UE;W5T
M(&9A:6QE9"XB+"!.151?1E107T524E]3151424U%3U547T9!24Q%1"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2`@("`@("`@"B`@
M("`*("`@("\J*@H@("`@("H@061D<R!A;B!E>'1E;G-I;VX@=&\@82!M;V1E
M+61I<F5C=&]R>0H@("`@("H@5&AE(&UO9&4M9&ER96-T;W)Y('-A=F5S(&9I
M;&4M97AT96YS:6]N<R!C;W)E<W!O;F1I;F<@=&\@9FEL971Y<&5S"B`@("`@
M*B`H87-C:6D@92YG+CH@)W!H<"<L("=T>'0G+"`G:'1M)RPN+BX[(&)I;F%R
M>2!E+F<N.B`G:G!G)RP@)V=I9B<L("=E>&4G+"XN+BDN"B`@("`@*B!4:&4@
M97AT96YS:6]N<R!H879E('1O(&)E('-A=F5D('=I=&AO=70@=&AE("<N)RX@
M06YD"B`@("`@*B!C86X@8F4@<')E9&5F:6YE9"!I;B!A;B!E>'1E<FYA;"!F
M:6QE("AS964Z(&=E=$5X=&5N<VEO;G-&:6QE*"DI+@H@("`@("H*("`@("`J
M(%1H92!A<G)A>2!I<R!B=6EL9"!L:6ME('1H:7,Z("=P:'`G(#T^($944%]!
M4T-)22P@)W!N9R<@/3X@1E107T))3D%260H@("`@("H*("`@("`J(%1O(&-H
M86YG92!T:&4@;6]D92!O9B!A;B!E>'1E;G-I;VXL(&IU<W0@861D(&ET(&%G
M86EN('=I=&@@=&AE(&YE=R!M;V1E(0H@("`@("H*("`@("`J($!A8V-E<W,@
M('!U8FQI8PH@("`@("H@0'!A<F%M("`@:6YT("`@("1M;V1E("!%:71H97(@
M1E107T%30TE)(&]R($944%]"24Y!4ED*("`@("`J($!P87)A;2`@('-T<FEN
M9R`D97AT("`@17AT96YS:6]N"B`@("`@*B!`<F5T=7)N("!V;VED"B`@("`@
M*B\*("`@(`H@("`@9G5N8W1I;VX@861D17AT96YS:6]N*"1M;V1E+"`D97AT
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9FEL95]E>'1E;G-I;VYS6R1E>'1=
M(#T@)&UO9&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N
M(')E;6]V97,@86X@97AT96YS:6]N(&9R;VT@=&AE(&UO9&4M9&ER96-T;W)I
M97,@"B`@("`@*B`H9&5S8W)I8F5D(&%B;W9E*2X*("`@("`J"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D97AT("!4
M:&4@97AT96YS:6]N('1O(')E;6]V90H@("`@("H@0')E='5R;B`@=F]I9`H@
M("`@("HO"B`@("`*("`@(&9U;F-T:6]N(')E;6]V945X=&5N<VEO;B@D97AT
M*0H@("`@>PH@("`@("`@('5N<V5T*"1T:&ES+3Y?9FEL95]E>'1E;G-I;VYS
M6R1E>'1=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9V5T)W,@8F]T
M:"`H87-C:6DM(&%N9"!B:6YA<GDM;6]D92UD:7)E8W1O<FEE<RD@9G)O;2!T
M:&4@9VEV96X@9FEL92X*("`@("`J($)E=V%R92P@:68@>6]U(')E860@82!F
M:6QE(&EN=&\@=&AE(&UO9&4M9&ER96-T;W)Y+"!A;&P@9F]R;65R('-E="!V
M86QU97,@"B`@("`@*B!W:6QL(&)E('5N<V5T(0H@("`@("H*("`@("`J($!A
M8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1F:6QE;F%M
M92`@5&AE(&9I;&4@=&\@9V5T(&9R;VT*("`@("`J($!R971U<FX@(&UI>&5D
M("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z
M.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]%6%1&24Q%3D]4
M15A)4U0L($Y%5%]&5%!?15)27T585$9)3$5214%$7T9!24Q%1`H@("`@("HO
M"B`@("`*("`@(&9U;F-T:6]N(&=E=$5X=&5N<VEO;G-&:6QE*"1F:6QE;F%M
M92D*("`@('L*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE;F%M92DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")%>'1E
M;G-I;VYS+69I;&4@)R1F:6QE;F%M92<@9&]E<R!N;W0@97AI<W0B+"!.151?
M1E107T524E]%6%1&24Q%3D]415A)4U0I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%I<U]R96%D86)L92@D9FEL96YA;64I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B17AT96YS:6]N<RUF:6QE("<D9FEL
M96YA;64G(&ES(&YO="!R96%D86)L92(L($Y%5%]&5%!?15)27T585$9)3$52
M14%$7T9!24Q%1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9I;&5?
M97AT96YS:6]N(#T@0'!A<G-E7VEN:5]F:6QE*"1F:6QE;F%M92D["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!(;W-T;F%M90H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0')E='5R;B`@<W1R:6YG("!4:&4@2&]S=&YA;64*("`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!G971(;W-T;F%M92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:&]S=&YA;64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!0;W)T"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N("!I;G0@("`@(%1H92!0;W)T"B`@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@9V5T4&]R="@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(%5S97)N86UE"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N("!S=')I;F<@(%1H92!5<V5R;F%M90H@("`@("HO
M"B`@("`*("`@(&9U;F-T:6]N(&=E=%5S97)N86UE*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]U<V5R;F%M93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(%!A<W-W;W)D"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!S=')I;F<@(%1H92!087-S=V]R
M9`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&=E=%!A<W-W;W)D*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P87-S=V]R9#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(%1R86YS9F5R;6]D90H@("`@("H*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@:6YT("`@
M("!4:&4@=')A;G-F97)M;V1E+"!E:71H97(@1E107T%30TE)(&]R($944%]"
M24Y!4EDN"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@9V5T36]D92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]D93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,L('=H971H97(@=&AE(&-O;FYE8W1I;VX@:7,@
M<V5T('1O('!A<W-I=F4@;6]D92!O<B!N;W0*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!R971U<FX@(&)O;VP@("`@5')U92!I9B!P
M87-S:79E+2P@9F%L<V4@:68@86-T:79E+6UO9&4*("`@("`J+PH@("`@"B`@
M("!F=6YC=&EO;B!I<U!A<W-I=F4H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A<W-V.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@;6]D92!S970@9F]R(&$@9FEL92UE>'1E;G-I;VX*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`@("1E
M>'0@("`@5&AE(&5X=&5N<VEO;B!Y;W4@=V%N;F$@87-K(&9O<@H@("`@("H@
M0')E='5R;B`@:6YT("`@("`@("`@("`@("!%:71H97(@1E107T%30TE)+"!&
M5%!?0DE.05)9(&]R($Y53$P@*&EF(&YO="!S970@82!M;V1E(&9O<B!I="D*
M("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!G971%>'1E;G-I;VY-;V1E*"1E
M>'0I"B`@("!["B`@("`@("`@<F5T=7)N($`D=&AI<RT^7V9I;&5?97AT96YS
M:6]N<ULD97AT73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@8W5R
M<F5N=&QY('-E="!T:6UE;W5T+@H@("`@("H@4F5T=7)N<R!T:&4@86-T=6%L
M('1I;65O=70@<V5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<F5T=7)N(&EN="!4:&4@86-T=6%L('1I;65O=70*("`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!G9714:6UE;W5T("@@*0H@("`@>PH@("`@("`@
M(')E='5R;B!F='!?9V5T7V]P=&EO;B@D=&AI<RT^7VAA;F1L92P@1E107U1)
M345/551?4T5#*3L*("`@('T@("`@"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@
M3F5T7T944%]/8G-E<G9E<B!I;G-T86YC92!T;R!T:&4@;&ES="!O9B!O8G-E
M<G9E<G,@"B`@("`@*B!T:&%T(&%R92!L:7-T96YI;F<@9F]R(&UE<W-A9V5S
M(&5M:71T960@8GD@=&AI<R!.971?1E10(&EN<W1A;F-E+@H@("`@("H*("`@
M("`J($!P87)A;2`@(&]B:F5C="`@("1O8G-E<G9E<B`@("`@5&AE($YE=%]&
M5%!?3V)S97)V97(@:6YS=&%N8V4@=&\@871T86-H(`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<R!A(&QI<W1E;F5R+@H@("`@
M("H@0')E='5R;B`@8F]O;&5A;B`@("`@("`@("`@("`@("!4<G5E(&EF('1H
M92!O8G-E<G9E<B!I<R!S=6-C97-S9G5L;'D@871T86-H960N"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@(#$N,PH@("`@("HO"B`@
M("`*("`@(&9U;F-T:6]N(&%T=&%C:"@F)&]B<V5R=F5R*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?82@D;V)S97)V97(L("=.971?1E107T]B<V5R=F5R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]L:7-T96YE<G-;)&]B<V5R=F5R+3YG971)9"@I72`]("8D
M;V)S97)V97(["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F5S(&$@3F5T7T944%]/8G-E<G9E<B!I;G-T86YC92!F
M<F]M('1H92!L:7-T(&]F(&]B<V5R=F5R<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@("!O8FIE8W0@("`D;V)S97)V97(@("`@(%1H92!.971?1E107T]B<V5R
M=F5R(&EN<W1A;F-E('1O(&1E=&%C:"`*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@;&ES="!O9B!L:7-T96YE<G,N
M"B`@("`@*B!`<F5T=7)N("!B;V]L96%N("`@("`@("`@("`@("`@(%1R=64@
M:68@=&AE(&]B<V5R=F5R(&ES('-U8V-E<W-F=6QL>2!D971A8VAE9"X*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@,2XS"B`@("`@
M*B\*("`@(`H@("`@9G5N8W1I;VX@9&5T86-H*"1O8G-E<G9E<BD*("`@('L*
M("`@("`@("!I9B`H(6ES7V$H)&]B<V5R=F5R+"`G3F5T7T944%]/8G-E<G9E
M<B<I('Q\"B`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7VQI<W1E;F5R<ULD
M;V)S97)V97(M/F=E=$ED*"E=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!U;G-E="@D=&AI<RT^7VQI<W1E;F5R
M<ULD;V)S97)V97(M/F=E=$ED*"E=*3L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($EN9F]R;7,@96%C:"!R96=I<W1E<F5D
M(&]B<V5R=F5R(&EN<W1A;F-E('1H870@82!N97<@;65S<V%G92!H87,@8F5E
M;@H@("`@("H@<V5N="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`*("`@("`J($!P87)A;2`@(&UI>&5D("`@
M("`D979E;G0@("`@("`@02!H87-H(&1E<V-R:6)I;F<@=&AE(&YE="!E=F5N
M="X@("`*("`@("`J($!A8V-E<W,@('!R:79A=&4@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@("H@
M0'-I;F-E("`@,2XS("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@"B`@("`@*B\@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`*("`@(`H@("`@9G5N8W1I;VX@7V%N;F]U;F-E*"1E=F5N
M="D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQI<W1E;F5R<R!A
M<R`D:60@/3X@)&QI<W1E;F5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&ES
M=&5N97)S6R1I9%TM/FYO=&EF>2@D979E;G0I.PH@("`@("`@('T*("`@('T*
M("`@(`H@("`@("`@("\J*@H@("`@("H@4F5B=6EL9"!T:&4@<&%T:"P@:68@
M9VEV96X@<F5L871I=F4*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@)'!A=&@@("!4:&4@<&%T:"!T;R!C
M:&5C:R!A;F0@8V]N<W1R=6-T"B`@("`@*B!`<F5T=7)N("!S=')I;F<@("`@
M("`@("!4:&4@8G5I;&0@<&%T:`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N
M(%]C;VYS=')U8W1?<&%T:"@D<&%T:"D*("`@('L*("`@("`@("!I9B`H*'-U
M8G-T<B@D<&%T:"P@,"P@,2D@(3T@(B\B*2`F)B`H<W5B<W1R*"1P871H+"`P
M+"`R*2`A/2`B+B\B*2D@>PH@("`@("`@("`@("`D86-T=6%L7V1I<B`]($!F
M='!?<'=D*"1T:&ES+3Y?:&%N9&QE*3L*("`@("`@("`@("`@:68@*'-U8G-T
M<B@D86-T=6%L7V1I<BP@*'-T<FQE;B@D86-T=6%L7V1I<BD@+2`R*2P@,2D@
M(3T@(B\B*2!["B`@("`@("`@("`@("`@("`D86-T=6%L7V1I<B`N/2`B+R([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!A=&@@/2`D86-T=6%L7V1I
M<BXD<&%T:#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1P871H.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAE8VMS+"!W:&5T:&5R(&$@9VEV96X@<W1R
M:6YG(&ES(&$@9&ER96-T;W)Y+7!A=&@@*&5N9',@=VET:"`B+R(I(&]R(&YO
M="X*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@)'!A=&@@(%!A=&@@=&\@8VAE8VL*("`@("`J($!R971U
M<FX@(&)O;VP@("`@("`@("`@5')U92!I9B`D<&%T:"!I<R!A(&1I<F5C=&]R
M>2P@;W1H97)W:7-E(&9A;'-E"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M7V-H96-K7V1I<B@D<&%T:"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1P
M871H*2`F)B!S=6)S='(H)'!A=&@L("AS=')L96XH)'!A=&@I("T@,2DL(#$I
M(#T]("(O(BD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!W:6QL(')E;6]V92!A(&9I;&4*
M("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@)&9I;&4@("!4:&4@9FEL92!T;R!D96QE=&4*("`@("`J($!R
M971U<FX@(&UI>&5D("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W
M:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]$
M14Q%5$5&24Q%7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]R
M;5]F:6QE*"1F:6QE*0H@("`@>PH@("`@("`@(&EF("AS=6)S='(H)&9I;&4L
M(#`L(#$I("$]("(O(BD@>PH@("`@("`@("`@("`D86-T=6%L7V1I<B`]($!F
M='!?<'=D*"1T:&ES+3Y?:&%N9&QE*3L*("`@("`@("`@("`@:68@*'-U8G-T
M<B@D86-T=6%L7V1I<BP@*'-T<FQE;B@D86-T=6%L7V1I<BD@+2`R*2P@,2D@
M(3T@(B\B*2!["B`@("`@("`@("`@("`@("`D86-T=6%L7V1I<B`N/2`B+R([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&9I;&4@/2`D86-T=6%L7V1I
M<BXD9FEL93L*("`@("`@("!]"B`@("`@("`@)')E<R`]($!F='!?9&5L971E
M*"1T:&ES+3Y?:&%N9&QE+"`D9FEL92D["B`@("`@("`@"B`@("`@("`@:68@
M*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B0V]U;&0@;F]T(&1E;&5T92!F:6QE("<D9FEL92<N(BP@3D547T944%]%
M4E)?1$5,151%1DE,15]&04E,140I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%1H:7,@=VEL;"!R96UO=F4@82!D:7(*("`@("`J"B`@("`@*B!`
M86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&1I<B`@
M5&AE(&1I<B!T;R!D96QE=&4*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@
M("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@
M("H@0'-E92`@("`@3D547T944%]%4E)?4D5-3U1%4$%42$Y/1$E2+"!.151?
M1E107T524E]$14Q%5$5$25)?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@7W)M7V1I<B@D9&ER*0H@("`@>PH@("`@("`@(&EF("AS=6)S='(H
M)&1I<BP@*'-T<FQE;B@D9&ER*2`M(#$I+"`Q*2`A/2`B+R(I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$:7)E8W1O<GD@;F%M
M92`G)&1I<B<@:7,@:6YV86QI9"P@:&%S('1O(&5N9"!W:71H("<O)R(L($Y%
M5%]&5%!?15)27U)%34]415!!5$A.3T1)4BD["B`@("`@("`@?0H@("`@("`@
M("1R97,@/2!`9G1P7W)M9&ER*"1T:&ES+3Y?:&%N9&QE+"`D9&ER*3L*("`@
M("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")#;W5L9"!N;W0@9&5L971E(&1I<F5C=&]R>2`G)&1I<B<N
M(BP@3D547T944%]%4E)?1$5,151%1$E27T9!24Q%1"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@5&AI<R!W:6QL(')E;6]V92!A(&1I<B!A;F0@
M86QL('-U8F1I<G,@86YD("UF:6QE<PH@("`@("H*("`@("`J($!A8V-E<W,@
M('!R:79A=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`D9FEL92`@5&AE(&1I
M<B!T;R!D96QE=&4@<F5C=7)S:79E;'D*("`@("`J($!R971U<FX@(&UI>&5D
M("`@("`@("`@5')U92!O;B!S=6-C97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R
M;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27U)%34]415!!5$A.3T1)
M4BP@3D547T944%]%4E)?1$5,151%1$E27T9!24Q%1`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N(%]R;5]D:7)?<F5C=7)S:79E*"1D:7(I"B`@("!["B`@
M("`@("`@:68@*'-U8G-T<B@D9&ER+"`H<W1R;&5N*"1D:7(I("T@,2DL(#$I
M("$]("(O(BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D1I<F5C=&]R>2!N86UE("<D9&ER)R!I<R!I;G9A;&ED+"!H87,@=&\@
M96YD('=I=&@@)R\G(BP@3D547T944%]%4E)?4D5-3U1%4$%42$Y/1$E2*3L*
M("`@("`@("!]"B`@("`@("`@)&9I;&5?;&ES="`]("1T:&ES+3Y?;'-?9FEL
M97,H)&1I<BD["B`@("`@("`@9F]R96%C:"`H)&9I;&5?;&ES="!A<R`D9FEL
M92D@>PH@("`@("`@("`@("`D9FEL92`]("1D:7(N)&9I;&5;(FYA;64B73L*
M("`@("`@("`@("`@)')E<R`]("1T:&ES+3YR;2@D9FEL92D["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@)&1I<E]L:7-T(#T@)'1H:7,M/E]L<U]D:7)S*"1D:7(I.PH@("`@("`@
M(&9O<F5A8V@@*"1D:7)?;&ES="!A<R`D;F5W7V1I<BD@>PH@("`@("`@("`@
M("`D;F5W7V1I<B`]("1D:7(N)&YE=U]D:7);(FYA;64B72XB+R(["B`@("`@
M("`@("`@("1R97,@/2`D=&AI<RT^7W)M7V1I<E]R96-U<G-I=F4H)&YE=U]D
M:7(I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1R97,@/2`D=&AI<RT^7W)M7V1I<B@D9&ER*3L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,
M:7-T<R!U<"!F:6QE<R!A;F0@9&ER96-T;W)I97,*("`@("`J"B`@("`@*B!`
M86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&1I<B`@
M5&AE(&1I<F5C=&]R>2!T;R!L:7-T('5P"B`@("`@*B!`<F5T=7)N("!A<G)A
M>2`@("`@("`@06X@87)R87D@;V8@9&ER<R!A;F0@9FEL97,*("`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!?;'-?8F]T:"@D9&ER*0H@("`@>PH@("`@("`@
M("1L:7-T7W-P;&ET=&5D(#T@)'1H:7,M/E]L:7-T7V%N9%]P87)S92@D9&ER
M*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1L:7-T7W-P;&ET=&5D6R)F:6QE
M<R)=*2D@>PH@("`@("`@("`@("`D;&ES=%]S<&QI='1E9%LB9FEL97,B72`]
M(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?87)R87DH)&QI
M<W1?<W!L:71T961;(F1I<G,B72DI('L*("`@("`@("`@("`@)&QI<W1?<W!L
M:71T961;(F1I<G,B72`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1R
M97,@/2!A<G)A>2@I.PH@("`@("`@($!A<G)A>5]S<&QI8V4H)')E<RP@,"P@
M,"P@)&QI<W1?<W!L:71T961;(F9I;&5S(ETI.PH@("`@("`@($!A<G)A>5]S
M<&QI8V4H)')E<RP@,"P@,"P@)&QI<W1?<W!L:71T961;(F1I<G,B72D["B`@
M("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T
M<R!U<"!D:7)E8W1O<FEE<PH@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A
M=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("!4:&4@9&ER96-T;W)Y
M('1O(&QI<W0@=7`*("`@("`J($!R971U<FX@(&%R<F%Y("`@("`@("!!;B!A
M<G)A>2!O9B!D:7)S"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7VQS7V1I
M<G,H)&1I<BD*("`@('L*("`@("`@("`D;&ES="`]("1T:&ES+3Y?;&ES=%]A
M;F1?<&%R<V4H)&1I<BD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QI
M<W0I*2!["B`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1L:7-T6R)D:7)S(ET["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!,:7-T<R!U<"!F:6QE<PH@("`@("H*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("!4:&4@9&ER96-T
M;W)Y('1O(&QI<W0@=7`*("`@("`J($!R971U<FX@(&%R<F%Y("`@("`@("!!
M;B!A<G)A>2!O9B!F:6QE<PH@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]L
M<U]F:6QE<R@D9&ER*0H@("`@>PH@("`@("`@("1L:7-T(#T@)'1H:7,M/E]L
M:7-T7V%N9%]P87)S92@D9&ER*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D;&ES="DI('L*("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&QI<W1;(F9I;&5S(ET["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4:&ES(&QI<W1S('5P('1H92!D:7)E8W1O<GDM8V]N=&5N
M="!A;F0@<&%R<V5S('1H92!I=&5M<R!I;G1O('=E;&PM9F]R;6%T960@87)R
M87ES"B`@("`@*B!4:&4@<F5S=6QT<R!O9B!T:&ES(&%R<F%Y(&%R92!S;W)T
M960@*&1I<G,@;VX@=&]P+"!S;W)T960@8GD@;F%M93L*("`@("`J(&9I;&5S
M(&)E;&]W+"!S;W)T960@8GD@;F%M92DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@<W1R:6YG("1D:7(@(%1H92!D
M:7)E8W1O<GD@=&\@<&%R<V4*("`@("`J($!R971U<FX@(&%R<F%Y("`@("`@
M("!,:7-T<R!O9B!D:7)S(&%N9"!F:6QE<PH@("`@("H@0'-E92`@("`@3D54
M7T944%]%4E)?4D%71$E23$E35%]&04E,140*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!?;&ES=%]A;F1?<&%R<V4H)&1I<BD*("`@('L*("`@("`@("`D
M9&ER<U]L:7-T(#T@87)R87DH*3L*("`@("`@("`D9FEL97-?;&ES="`](&%R
M<F%Y*"D["B`@("`@("`@)&1I<E]L:7-T(#T@0&9T<%]R87=L:7-T*"1T:&ES
M+3Y?:&%N9&QE+"`D9&ER*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D:7)?
M;&ES="DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T-O=6QD(&YO="!G970@<F%W(&1I<F5C=&]R>2!L:7-T:6YG+B<L($Y%5%]&
M5%!?15)27U)!5T1)4DQ)4U1?1D%)3$5$*3L*("`@("`@("!]"B`@("`@("`@
M+R\@2&%N9&QE(&5M<'1Y(&1I<F5C=&]R:65S"B`@("`@("`@:68@*&-O=6YT
M*"1D:7)?;&ES="D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M)V1I<G,G(#T^("1D:7)S7VQI<W0L("=F:6QE<R<@/3X@)&9I;&5S7VQI<W0I
M.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;6%T8VAE
M<BD@?'P@4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7VUA=&-H97(I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;6%T8VAE<B`]("1T:&ES+3Y?9&5T97)M:6YE7V]S
M7VUA=&-H*"1D:7)?;&ES="D["B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1T:&ES+3Y?;6%T8VAE<BDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUA=&-H97(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@9F]R96%C:"`H)&1I<E]L:7-T(&%S("1E;G1R>2D@>PH@("`@("`@
M("`@("!I9B`H(7!R96=?;6%T8V@H)'1H:7,M/E]M871C:&5R6R=P871T97)N
M)UTL("1E;G1R>2P@)&TI*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VUA=&-H97);)VUA<"==(&%S
M("1K97D]/B1V86PI('L*("`@("`@("`@("`@("`@("1E;G1R>5LD:V5Y72`]
M("1M6R1V86Q=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E;G1R>5LG
M<W1A;7`G72`]("1T:&ES+3Y?<&%R<V5?1&%T92@D96YT<GE;)V1A=&4G72D[
M"@H@("`@("`@("`@("!I9B`H)&5N=')Y6R=I<U]D:7(G72D@>PH@("`@("`@
M("`@("`@("`@)&1I<G-?;&ES=%M=(#T@)&5N=')Y.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&9I;&5S7VQI<W1;72`]("1E;G1R
M>3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!`=7-O<G0H)&1I
M<G-?;&ES="P@87)R87DH(DYE=%]&5%`B+"`B7VYA=%]S;W)T(BDI.PH@("`@
M("`@($!U<V]R="@D9FEL97-?;&ES="P@87)R87DH(DYE=%]&5%`B+"`B7VYA
M=%]S;W)T(BDI.PH@("`@("`@("1R97-;(F1I<G,B72`]("AI<U]A<G)A>2@D
M9&ER<U]L:7-T*2D@/R`D9&ER<U]L:7-T(#H@87)R87DH*3L*("`@("`@("`D
M<F5S6R)F:6QE<R)=(#T@*&ES7V%R<F%Y*"1F:6QE<U]L:7-T*2D@/R`D9FEL
M97-?;&ES="`Z(&%R<F%Y*"D["B`@("`@("`@<F5T=7)N("1R97,["B`@("!]
M"B`@("`*("`@("\J*@H@("`@("H@1&5T97)M:6YE('-E<G9E<B!/4PH@("`@
M("H@5&AI<R!D971E<FUI;F5S('1H92!S97)V97(@3U,@86YD(')E='5R;G,@
M82!V86QI9"!R96=E>"!T;R!P87)S90H@("`@("H@;',H*2!O=71P=70N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@
M87)R87D@)&1I<E]L:7-T(%1H92!R87<@9&ER(&QI<W0@=&\@<&%R<V4*("`@
M("`J($!R971U<FX@(&UI>&5D($%N(&%R<F%Y(&]F("=P871T97)N)R!A;F0@
M)VUA<"<@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@
M*B!`<V5E("`@("!.151?1E107T524E]$25),25-47U5.4U504$]25$5$"B`@
M("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7V1E=&5R;6EN95]O<U]M871C:"@F
M)&1I<E]L:7-T*2!["B`@("!F;W)E86-H("@D9&ER7VQI<W0@87,@)&5N=')Y
M*2!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]L<U]M871C:"!A<R`D;W,@
M/3X@)&UA=&-H*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"1M871C
M:%LG<&%T=&5R;B==+"`D96YT<GDI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1M871C:#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@?0H@("`@("`@("1E<G)O<B`]("=4:&4@;&ES="!S='EL92!O9B!Y
M;W5R('-E<G9E<B!S965M<R!N;W0@=&\@8F4@<W5P<&]R=&5D+B!0;&5A<V4@
M96UA:6P@82`B)&9T<"T^;',H3D547T944%]205=,25-4*3LB(&]U='!U="!P
M;'5S(&EN9F\@;VX@=&AE('-E<G9E<B!T;R!T:&4@;6%I;G1A:6YE<B!O9B!T
M:&ES('!A8VMA9V4@=&\@9V5T(&ET('-U<'!O<G1E9"$@5&AA;FMS(&9O<B!Y
M;W5R(&AE;'`A)SL*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M97)R;W(L($Y%5%]&5%!?15)27T1)4DQ)4U1?54Y355!03U)4140I.PH@("`@
M?0H@("`@+RHJ"B`@("`@*B!,:7-T<R!A(&QO8V%L(&1I<F5C=&]R>0H@("`@
M("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@('-T
M<FEN9R`D9&ER7W!A=&@@(%1H92!D:7(@=&\@;&ES=`H@("`@("H@0')E='5R
M;B`@87)R87D@("`@("`@("`@("`@5&AE(&QI<W0@;V8@9&ER<R!A;F0@9FEL
M97,*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?;'-?;&]C86PH)&1I<E]P
M871H*0H@("`@>PH@("`@("`@("1D:7(@/2!D:7(H)&1I<E]P871H*3L*("`@
M("`@("`D9&ER7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("1F:6QE7VQI<W0@
M/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("AF86QS92`A/3T@*"1E;G1R>2`]
M("1D:7(M/G)E860H*2DI('L*("`@("`@("`@("`@:68@*"@D96YT<GD@(3T@
M)RXG*2`F)B`H)&5N=')Y("$]("<N+B<I*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?9&ER*"1D:7)?<&%T:"XD96YT<GDI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1I<E]L:7-T6UT@/2`D96YT<GD["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE7VQI<W1;72`]("1E
M;G1R>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`D9&ER+3YC;&]S92@I.PH@("`@("`@("1R97-;)V1I<G,G
M72`]("1D:7)?;&ES=#L*("`@("`@("`D<F5S6R=F:6QE<R==(#T@)&9I;&5?
M;&ES=#L*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O*BH*("`@
M("`J($9U;F-T:6]N(&9O<B!U<V4@=VET:"!U<V]R="@I+@H@("`@("H@0V]M
M<&%R97,@=&AE(&QI<W0M87)R87DM96QE;65N=',@8GD@;F%M92X*("`@("`J
M"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@7VYA=%]S;W)T*"1I=&5M7S$L("1I=&5M7S(I"B`@("!["B`@("`@
M("`@<F5T=7)N('-T<FYA=&-M<"@D:71E;5\Q6R=N86UE)UTL("1I=&5M7S);
M)VYA;64G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S92!D871E<R!T
M;R!T:6UE<W1A;7!S"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("1D871E("!$871E"B`@("`@*B!`<F5T
M=7)N("!I;G0@("`@("`@("`@(%1I;65S=&%M<`H@("`@("H@0'-E92`@("`@
M3D547T944%]%4E)?1$%4149/4DU!5%]&04E,140*("`@("`J+PH@("`@"B`@
M("!F=6YC=&EO;B!?<&%R<V5?1&%T92@D9&%T92D*("`@('L*("`@("`@("`O
M+R!397`@,3`@,C(Z,#8@/3X@4V5P(#$P+"`\>65A<CX@,C(Z,#8*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+RA;02U:82UZ72LI6R!=*RA;,"TY72LI6R!=
M*RA;,"TY72LI.BA;,"TY72LI+R<L("1D871E+"`D<F5S*2D@>PH@("`@("`@
M("`@("`D>65A<B`](&1A=&4H)UDG*3L*("`@("`@("`@("`@)&UO;G1H(#T@
M)')E<ULQ73L*("`@("`@("`@("`@)&1A>2`]("1R97-;,ET["B`@("`@("`@
M("`@("1H;W5R(#T@)')E<ULS73L*("`@("`@("`@("`@)&UI;G5T92`]("1R
M97-;-%T["B`@("`@("`@("`@("1D871E(#T@(B1M;VYT:"`D9&%Y+"`D>65A
M<B`D:&]U<CHD;6EN=71E(CL*("`@("`@("`@("`@)'1M<$1A=&4@/2!S=')T
M;W1I;64H)&1A=&4I.PH@("`@("`@("`@("!I9B`H)'1M<$1A=&4@/B!T:6UE
M*"DI('L*("`@("`@("`@("`@("`@("1Y96%R+2T["B`@("`@("`@("`@("`@
M("`D9&%T92`]("(D;6]N=&@@)&1A>2P@)'EE87(@)&AO=7(Z)&UI;G5T92([
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@,#DM,3`M,#0@
M/3X@,#DO,3`O,#0*("`@("`@("!E;'-E:68@*'!R96=?;6%T8V@H)R]>7&1<
M9"U<9%QD+5QD7&0O)RPD9&%T92DI('L*("`@("`@("`@("`@)&1A=&4@/2!S
M=')?<F5P;&%C92@G+2<L)R\G+"1D871E*3L*("`@("`@("!]"B`@("`@("`@
M)')E<R`]('-T<G1O=&EM92@D9&%T92D["B`@("`@("`@:68@*"$D<F5S*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G1&%T96-O
M;G9E<G-I;VX@9F%I;&5D+B<L($Y%5%]&5%!?15)27T1!5$5&3U)-051?1D%)
M3$5$*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"GT*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O<&5C;&-M9"YP:'`N;W)I9P``````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,U,C4`,3`U,34T,S$P-3<`,#(P-#(U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\
M(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4
M:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@
M("`@("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P-"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N
M970N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z('!E8VQC;60N<&AP+'8@,2XQ(#(P
M,#4O,#(O,C$@,#4Z,S`Z-38@8V5L;&]G($5X<"`D#0H-"B\J*@T*("H@0&YO
M9&5P($=T:PT*("HO#0II9B`H)R]H;VUE+VQU8V5R+W=O<FLO<&5A<B]S:&%R
M92]P:'`G("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L-"B`@("!I;FE?
M<V5T*"=I;F-L=61E7W!A=&@G+"`G+VAO;64O;'5C97(O=V]R:R]P96%R+W-H
M87)E+W!H<"<I.PT*("`@("1R87<@/2!F86QS93L-"GT@96QS92![#0H@("`@
M+R\@=&AI<R!I<R!A(')A=RP@=6YI;G-T86QL960@<&5A<BP@96ET:&5R(&$@
M8W9S(&-H96-K;W5T+"!O<B!P:'`@9&ES=')O#0H@("`@)')A=R`]('1R=64[
M#0I]#0ID969I;F4H)U!%05)?4E5.5%E012<L("=P96-L)RD[#0IR97%U:7)E
M7V]N8V4@)W!E87)C;60N<&AP)SL-"B\J#0H@*B!,;V-A;"!V87)I86)L97,Z
M#0H@*B!T86(M=VED=&@Z(#0-"B`J(&,M8F%S:6,M;V9F<V5T.B`T#0H@*B!I
M;F1E;G0M=&%B<RUM;V1E.B!N:6P-"B`J(&UO9&4Z('!H<`T*("H@16YD.@T*
M("HO#0HO+R!V:6TV,#`Z<WEN/7!H<`T*#0H_/@T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+TUA:6PN<&AP````````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$W-C`Q`#$P-3$U-#,Q,#4W`#`Q-C<T,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R
M<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O
M=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A
M=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@
M?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S
M92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W(Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($UA:6PN<&AP+'8@,2XQ,B`R
M,#`U+S`X+S(R(#`Q.C$Y.C(W(&IO;B!%>'`@)`H*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["@HO*BH*("H@4$5!4B=S($UA:6PZ.B!I;G1E<F9A8V4N($1E
M9FEN97,@=&AE(&EN=&5R9F%C92!F;W(@:6UP;&5M96YT:6YG"B`J(&UA:6QE
M<G,@=6YD97(@=&AE(%!%05(@:&EE<F%R8VAY+"!A;F0@<')O=FED97,@<W5P
M<&]R=&EN9R!F=6YC=&EO;G,*("H@=7-E9G5L(&EN(&UU;'1I<&QE(&UA:6QE
M<B!B86-K96YD<RX*("H*("H@0&%C8V5S<R!P=6)L:6,*("H@0'9E<G-I;VX@
M)%)E=FES:6]N.B`Q+C$R("0*("H@0'!A8VMA9V4@36%I;`H@*B\*8VQA<W,@
M36%I;`I["B`@("`O*BH*("`@("`J($QI;F4@=&5R;6EN871O<B!U<V5D(&9O
M<B!S97!A<F%T:6YG(&AE861E<B!L:6YE<RX*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D<V5P(#T@(EQR7&XB.PH*("`@("\J*@H@("`@
M("H@4')O=FED97,@86X@:6YT97)F86-E(&9O<B!G96YE<F%T:6YG($UA:6PZ
M.B!O8FIE8W1S(&]F('9A<FEO=7,*("`@("`J('1Y<&5S"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9')I=F5R(%1H92!K:6YD(&]F($UA:6PZ.B!O
M8FIE8W0@=&\@:6YS=&%N=&EA=&4N"B`@("`@*B!`<&%R86T@87)R87D@("1P
M87)A;7,@5&AE('!A<F%M971E<G,@=&\@<&%S<R!T;R!T:&4@36%I;#HZ(&]B
M:F5C="X*("`@("`J($!R971U<FX@;V)J96-T($UA:6P@82!I;G-T86YC92!O
M9B!T:&4@9')I=F5R(&-L87-S(&]R(&EF(&9A:6QS(&$@4$5!4B!%<G)O<@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A
M8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@)&1R:79E<B`]('-T<G1O;&]W97(H)&1R:79E<BD["B`@("`@("`@0&EN
M8VQU9&5?;VYC92`G36%I;"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("`D8VQA<W,@/2`G36%I;%\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&UA:6QE<B`](&YE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R;B`D;6%I;&5R
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=5;F%B;&4@=&\@9FEN9"!C;&%S<R!F;W(@9')I=F5R("<@
M+B`D9')I=F5R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)
M;7!L96UE;G1S($UA:6PZ.G-E;F0H*2!F=6YC=&EO;B!U<VEN9R!P:'`G<R!B
M=6EL="UI;B!M86EL*"D*("`@("`J(&-O;6UA;F0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1R96-I<&EE;G1S($5I=&AE<B!A(&-O;6UA+7-E<&5R
M871E9"!L:7-T(&]F(')E8VEP:65N=',*("`@("`J("`@("`@("`@("`@("`H
M4D9#.#(R(&-O;7!L:6%N="DL(&]R(&%N(&%R<F%Y(&]F(')E8VEP:65N=',L
M"B`@("`@*B`@("`@("`@("`@("`@96%C:"!21D,X,C(@=F%L:60N(%1H:7,@
M;6%Y(&-O;G1A:6X@<F5C:7!I96YT<R!N;W0*("`@("`J("`@("`@("`@("`@
M("!S<&5C:69I960@:6X@=&AE(&AE861E<G,L(&9O<B!"8V,Z+"!R97-E;F1I
M;F<*("`@("`J("`@("`@("`@("`@("!M97-S86=E<RP@971C+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D:&5A9&5R<R!4:&4@87)R87D@;V8@:&5A
M9&5R<R!T;R!S96YD('=I=&@@=&AE(&UA:6PL(&EN(&%N"B`@("`@*B`@("`@
M("`@("`@("`@87-S;V-I871I=F4@87)R87DL('=H97)E('1H92!A<G)A>2!K
M97D@:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@:&5A9&5R(&YA;64@*&EE
M+"`G4W5B:F5C="<I+"!A;F0@=&AE(&%R<F%Y('9A;'5E"B`@("`@*B`@("`@
M("`@("`@("`@:7,@=&AE(&AE861E<B!V86QU92`H:64L("=T97-T)RDN(%1H
M92!H96%D97(*("`@("`J("`@("`@("`@("`@("!P<F]D=6-E9"!F<F]M('1H
M;W-E('9A;'5E<R!W;W5L9"!B92`G4W5B:F5C=#H*("`@("`J("`@("`@("`@
M("`@("!T97-T)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V1Y
M(%1H92!F=6QL('1E>'0@;V8@=&AE(&UE<W-A9V4@8F]D>2P@:6YC;'5D:6YG
M(&%N>0H@("`@("H@("`@("`@("`@("`@("!-:6UE('!A<G1S+"!E=&,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS('1R=64@;VX@<W5C
M8V5S<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@(&-O
M;G1A:6YI;F<@82!D97-C<FEP=&EV92!E<G)O<B!M97-S86=E(&]N"B`@("`@
M*B`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0&1E<')E8V%T960@=7-E($UA:6Q?;6%I;#HZ<V5N9"!I;G-T
M96%D"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H
M96%D97)S+"`D8F]D>2D*("`@('L*("`@("`@("`O+R!I9B!W92=R92!P87-S
M960@86X@87)R87D@;V8@<F5C:7!I96YT<RP@:6UP;&]D92!I="X*("`@("`@
M("!I9B`H:7-?87)R87DH)')E8VEP:65N=',I*2!["B`@("`@("`@("`@("1R
M96-I<&EE;G1S(#T@:6UP;&]D92@G+"`G+"`D<F5C:7!I96YT<RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!G970@=&AE(%-U8FIE8W0@;W5T(&]F('1H92!H
M96%D97)S(&%R<F%Y('-O('1H870@=V4@8V%N"B`@("`@("`@+R\@<&%S<R!I
M="!A<R!A('-E<&5R871E(&%R9W5M96YT('1O(&UA:6PH*2X*("`@("`@("`D
M<W5B:F5C="`]("<G.PH@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG4W5B
M:F5C="==*2D@>PH@("`@("`@("`@("`D<W5B:F5C="`]("1H96%D97)S6R=3
M=6)J96-T)UT["B`@("`@("`@("`@('5N<V5T*"1H96%D97)S6R=3=6)J96-T
M)UTI.PH@("`@("`@('T*"B`@("`@("`@+R\@9FQA='1E;B!T:&4@:&5A9&5R
M<R!O=70N"B`@("`@("`@;&ES="@L)'1E>'1?:&5A9&5R<RD@/2!-86EL.CIP
M<F5P87)E2&5A9&5R<R@D:&5A9&5R<RD["@H@("`@("`@(')E='5R;B!M86EL
M*"1R96-I<&EE;G1S+"`D<W5B:F5C="P@)&)O9'DL("1T97AT7VAE861E<G,I
M.PH*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@86X@87)R87D@;V8@;6%I
M;"!H96%D97)S(&%N9"!R971U<FX@82!S=')I;F<@8V]N=&%I;FEN9PH@("`@
M("H@=&5X="!U<V%B;&4@:6X@<V5N9&EN9R!A(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D
M97)S('1O('!R97!A<F4L(&EN(&%N(&%S<V]C:6%T:79E"B`@("`@*B`@("`@
M("`@("`@("`@87)R87DL('=H97)E('1H92!A<G)A>2!K97D@:7,@=&AE(&AE
M861E<B!N86UE("AI92P*("`@("`J("`@("`@("`@("`@("`G4W5B:F5C="<I
M+"!A;F0@=&AE(&%R<F%Y('9A;'5E(&ES('1H92!H96%D97(*("`@("`J("`@
M("`@("`@("`@("!V86QU92`H:64L("=T97-T)RDN(%1H92!H96%D97(@<')O
M9'5C960@9G)O;2!T:&]S90H@("`@("H@("`@("`@("`@("`@('9A;'5E<R!W
M;W5L9"!B92`G4W5B:F5C=#H@=&5S="<N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!2971U<FYS(&9A;'-E(&EF(&ET(&5N8V]U;G1E<G,@82!B860@
M861D<F5S<RP*("`@("`J("`@("`@("`@("`@("`@;W1H97)W:7-E(')E='5R
M;G,@86X@87)R87D@8V]N=&%I;FEN9R!T=V\*("`@("`J("`@("`@("`@("`@
M("`@96QE;65N=',Z($%N>2!&<F]M.B!A9&1R97-S(&9O=6YD(&EN('1H92!H
M96%D97)S+`H@("`@("H@("`@("`@("`@("`@("!A;F0@=&AE('!L86EN('1E
M>'0@=F5R<VEO;B!O9B!T:&4@:&5A9&5R<RX*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!P<F5P87)E2&5A9&5R<R@D:&5A
M9&5R<RD*("`@('L*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@
M("1F<F]M(#T@;G5L;#L*"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@
M)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H
M)&ME>2P@)T9R;VTG*2`]/3T@,"D@>PH@("`@("`@("`@("`@("`@:6YC;'5D
M95]O;F-E("=-86EL+U)&0S@R,BYP:'`G.PH@("`@("`@("`@("`@("`@)'!A
M<G-E<B`]("9N97<@36%I;%]21D,X,C(H*3L*("`@("`@("`@("`@("`@("1A
M9&1R97-S97,@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1V86QU92P@
M)VQO8V%L:&]S="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1A9&1R97-S97,I*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1A9&1R97-S97,["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@)&9R;VT@/2`D861D<F5S<V5S6S!=+3YM86EL8F]X("X@)T`G
M("X@)&%D9')E<W-E<ULP72T^:&]S=#L*"B`@("`@("`@("`@("`@("`O+R!2
M96IE8W0@96YV96QO<&4@1G)O;3H@861D<F5S<V5S('=I=&@@<W!A8V5S+@H@
M("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D9G)O;2P@)R`G*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D;&EN97-;72`]("1K97D@+B`G.B`G("X@
M)'9A;'5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R8V%S96-M<"@D:V5Y
M+"`G4F5C96EV960G*2`]/3T@,"D@>PH@("`@("`@("`@("`@("`@)')E8V5I
M=F5D(#T@87)R87DH*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E
M(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R96-E:79E
M9%M=(#T@)&ME>2`N("<Z("<@+B`D;&EN93L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D<F5C96EV961;72`]("1K97D@+B`G.B`G
M("X@)'9A;'5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M+R\@4'5T(%)E8V5I=F5D.B!H96%D97)S(&%T('1H92!T;W`N("!3<&%M(&1E
M=&5C=&]R<R!O9G1E;@H@("`@("`@("`@("`@("`@+R\@9FQA9R!M97-S86=E
M<R!W:71H(%)E8V5I=F5D.B!H96%D97)S(&%F=&5R('1H92!3=6)J96-T.@H@
M("`@("`@("`@("`@("`@+R\@87,@<W!A;2X*("`@("`@("`@("`@("`@("1L
M:6YE<R`](&%R<F%Y7VUE<F=E*"1R96-E:79E9"P@)&QI;F5S*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O($EF("1V86QU92!I
M<R!A;B!A<G)A>2`H:2YE+BP@82!L:7-T(&]F(&%D9')E<W-E<RDL(&-O;G9E
M<G0*("`@("`@("`@("`@("`@("\O(&ET('1O(&$@8V]M;6$M9&5L:6UI=&5D
M('-T<FEN9R!O9B!I=',@96QE;65N=',@*&%D9')E<W-E<RDN"B`@("`@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1V86QU92`](&EM<&QO9&4H)RP@)RP@)'9A;'5E*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L:6YE<UM=(#T@)&ME>2`N
M("<Z("<@+B`D=F%L=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!A<G)A>2@D9G)O;2P@:F]I;B@D=&AI<RT^<V5P+"`D;&EN
M97,I("X@)'1H:7,M/G-E<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME
M(&$@<V5T(&]F(')E8VEP:65N=',@86YD('!A<G-E('1H96TL(')E='5R;FEN
M9R!A;B!A<G)A>2!O9@H@("`@("H@8F%R92!A9&1R97-S97,@*&9O<G=A<F0@
M<&%T:',I('1H870@8V%N(&)E('!A<W-E9"!T;R!S96YD;6%I;`H@("`@("H@
M;W(@86X@<VUT<"!S97)V97(@=VET:"!T:&4@<F-P="!T;SH@8V]M;6%N9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@16ET:&5R(&$@8V]M;6$M<V5P
M97)A=&5D(&QI<W0@;V8@<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@
M("A21D,X,C(@8V]M<&QI86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT
M<RP*("`@("`J("`@("`@("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y($%N(&%R<F%Y(&]F(&9O<G=A<F0@
M<&%T:',@*&)A<F4@861D<F5S<V5S*2X*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S95)E8VEP:65N=',H)')E8VEP
M:65N=',I"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=-86EL+U)&0S@R
M,BYP:'`G.PH*("`@("`@("`O+R!I9B!W92=R92!P87-S960@86X@87)R87DL
M(&%S<W5M92!A9&1R97-S97,@87)E('9A;&ED(&%N9`H@("`@("`@("\O(&EM
M<&QO9&4@=&AE;2!B969O<F4@<&%R<VEN9RX*("`@("`@("!I9B`H:7-?87)R
M87DH)')E8VEP:65N=',I*2!["B`@("`@("`@("`@("1R96-I<&EE;G1S(#T@
M:6UP;&]D92@G+"`G+"`D<F5C:7!I96YT<RD["B`@("`@("`@?0H*("`@("`@
M("`O+R!087)S92!R96-I<&EE;G1S+"!L96%V:6YG(&]U="!A;&P@<&5R<V]N
M86P@:6YF;RX@5&AI<R!I<PH@("`@("`@("\O(&9O<B!S;71P(')E8VEP:65N
M=',L(&5T8RX@06QL(')E;&5V86YT('!E<G-O;F%L(&EN9F]R;6%T:6]N"B`@
M("`@("`@+R\@<VAO=6QD(&%L<F5A9'D@8F4@:6X@=&AE(&AE861E<G,N"B`@
M("`@("`@)&%D9')E<W-E<R`]($UA:6Q?4D9#.#(R.CIP87)S94%D9')E<W-,
M:7-T*"1R96-I<&EE;G1S+"`G;&]C86QH;W-T)RP@9F%L<V4I.PH@("`@("`@
M("1R96-I<&EE;G1S(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)&%D9')E<W-E<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&%D9')E<W-E
M<R!A<R`D;V(I('L*("`@("`@("`@("`@("`@("1R96-I<&EE;G1S6UT@/2`D
M;V(M/FUA:6QB;W@@+B`G0"<@+B`D;V(M/FAO<W0["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5C:7!I96YT<SL*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]&:6QE+G!H<```````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,#$P,@`Q,#4Q
M-30S,3`U-P`P,38W,C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!&
M:6QE"B`J(`H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A
M=&5G;W)Y("`@($9I;&4*("H@0'!A8VMA9V4@("`@($9I;&4*("H@0&%U=&AO
M<B`@("`@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X*("H@0&%U
M=&AO<B`@("`@(%1A;"!0965R(#QT86Q`<&AP+FYE=#X*("H@0&%U=&AO<B`@
M("`@($UI8VAA96P@5V%L;&YE<B`\;6EK94!P:'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`@,C`P,BTR,#`U(%1H92!!=71H;W)S"B`J($!L:6-E;G-E("`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!&:6QE+G!H<"QV(#$N
M,S$@,C`P-2\P-R\R,2`P-SHU,SHP.2!M:6ME($5X<"`D"B`J($!L:6YK("`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1FEL90H@*B\*"B\J
M*@H@*B!297%U:7)E<R!014%2"B`J+PIR97%U:7)E7V]N8V4@)U!%05(N<&AP
M)SL*"B\J*@H@*B!4:&4@9&5F875L="!N=6UB97(@;V8@8GET97,@9F]R(')E
M861I;F<*("HO"FEF("@A9&5F:6YE9"@G1DE,15]$149!54Q47U)%041325I%
M)RDI('L*("`@(&1E9FEN92@G1DE,15]$149!54Q47U)%041325I%)RP@,3`R
M-"P@=')U92D["GT*"B\J*@H@*B!4:&4@;6%X:6UU;2!N=6UB97(@;V8@8GET
M97,@9F]R(')E861I;F<@;&EN97,*("HO"FEF("@A9&5F:6YE9"@G1DE,15]-
M05A?3$E.15]214%$4TE:12<I*2!["B`@("!D969I;F4H)T9)3$5?34%87TQ)
M3D5?4D5!1%-)6D4G+"`T,#DV,"P@=')U92D["GT*"B\J*@H@*B!7:&5T:&5R
M(&9I;&4@;&]C:W,@<VAO=6QD(&)L;V-K"B`J+PII9B`H(61E9FEN960H)T9)
M3$5?3$]#2U-?0DQ/0TLG*2D@>PH@("`@9&5F:6YE*"=&24Q%7TQ/0TM37T),
M3T-+)RP@=')U92P@=')U92D["GT*"B\J*@H@*B!-;V1E('1O('5S92!F;W(@
M<F5A9&EN9R!F<F]M(&9I;&5S"B`J+PID969I;F4H)T9)3$5?34]$15]214%$
M)RP@)W)B)RP@=')U92D["@HO*BH*("H@36]D92!T;R!U<V4@9F]R('1R=6YC
M871I;F<@9FEL97,L('1H96X@=W)I=&EN9PH@*B\*9&5F:6YE*"=&24Q%7TU/
M1$5?5U))5$4G+"`G=V(G+"!T<G5E*3L*"B\J*@H@*B!-;V1E('1O('5S92!F
M;W(@87!P96YD:6YG('1O(&9I;&5S"B`J+PID969I;F4H)T9)3$5?34]$15]!
M4%!%3D0G+"`G86(G+"!T<G5E*3L*"B\J*@H@*B!5<V4@=&AI<R!W:&5N(&$@
M<VAA<F5D("AR96%D*2!L;V-K(&ES(')E<75I<F5D"B`J+PID969I;F4H)T9)
M3$5?3$]#2U]32$%2140G+"!,3T-+7U-(('P@*$9)3$5?3$]#2U-?0DQ/0TL@
M/R`P(#H@3$]#2U].0BDL('1R=64I.PH*+RHJ"B`J(%5S92!T:&ES('=H96X@
M86X@97AC;'5S:79E("AW<FET92D@;&]C:R!I<R!R97%U:7)E9`H@*B\*9&5F
M:6YE*"=&24Q%7TQ/0TM?15A#3%53259%)RP@3$]#2U]%6"!\("A&24Q%7TQ/
M0TM37T),3T-+(#\@,"`Z($Q/0TM?3D(I+"!T<G5E*3L*"B\J*@H@*B!#;&%S
M<R!F;W(@:&%N9&QI;F<@9FEL97,*("H@"B`J($$@8VQA<W,@=VET:"!C;VUM
M;VX@9G5N8W1I;VYS(&9O<B!W<FET:6YG+`H@*B!R96%D:6YG(&%N9"!H86YD
M;&EN9R!F:6QE<R!A;F0@9&ER96-T;W)I97,*("H@"B`J($!A=71H;W(@(%)I
M8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X*("H@0&%U=&AO<B`@5&%L
M(%!E97(@/'1A;$!P:'`N;F5T/@H@*B!`875T:&]R("!-:6-H865L(%=A;&QN
M97(@/&UI:V5`<&AP+FYE=#X*("H@0&%C8V5S<R`@<'5B;&EC(`H@*B!`<&%C
M:V%G92!&:6QE"B`J(`H@*B!`<W1A=&EC"B`J+PIC;&%S<R!&:6QE(&5X=&5N
M9',@4$5!4B`*>PH@("`@+RHJ"B`@("`@*B!$97-T<G5C=&]R"B`@("`@*B`*
M("`@("`J(%5N;&]C:W,@86YY(&QO8VME9"!F:6QE('!O:6YT97)S(&%N9"!C
M;&]S97,@86QL(&9I;&5P;VEN=&5R<PH@("`@("H@"B`@("`@*B!`86-C97-S
M('!R:79A=&4@"B`@("`@*B\*("`@(&9U;F-T:6]N(%]&:6QE*"D*("`@('L*
M("`@("`@("!&:6QE.CIC;&]S94%L;"@I.PH@("`@?0H@("`@"B`@("`O*BH*
M("`@("`J($AA;F1L97,@9FEL92!P;VEN=&5R<RX@268@82!F:6QE('!O:6YT
M97(@;F5E9',@=&\@8F4@;W!E;F5D+`H@("`@("H@:70@=VEL;"!B92X@268@
M:70@86QR96%D>2!E>&ES=',@*&)A<V5D(&]N(&9I;&5N86UE(&%N9"!M;V1E
M*0H@("`@("H@=&AE;B!T:&4@97AI<W1I;F<@;VYE('=I;&P@8F4@<F5T=7)N
M960N"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!R:79A=&4@"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!&:6QE;F%M92!T;R!B92!U<V5D
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1M;V1E($UO9&4@=&\@;W!E;B!T
M:&4@9FEL92!I;@H@("`@("H@0'!A<F%M("`@;6EX960@("`D;&]C:R!4>7!E
M(&]F(&QO8VL@=&\@=7-E"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?
M17)R;W(@;VX@97)R;W(@;W(@9FEL92!P;VEN=&5R(')E<V]U<F-E(&]N('-U
M8V-E<W,*("`@("`J+PH@("`@9G5N8W1I;VX@)E]G971&:6QE4&]I;G1E<B@D
M9FEL96YA;64L("1M;V1E+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1F:6QE4&]I;G1E<G,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I
M;&4G+"`G9FEL95!O:6YT97)S)RD["B`@("`@("`@"B`@("`@("`@+R\@5VEN
M,S(@:7,@8V%S92UI;G-E;G-I=&EV90H@("`@("`@(&EF("A/4U]724Y$3U=3
M*2!["B`@("`@("`@("`@("1F:6QE;F%M92`]('-T<E1O3&]W97(H)&9I;&5N
M86UE*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@8VAE8VL@:68@
M9FEL92!P;VEN=&5R(&%L<F5A9'D@97AI<W1S"B`@("`@("`@:68@*"`@("`A
M:7-S970H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72D@?'P@"B`@
M("`@("`@("`@("`@("`A:7-?<F5S;W5R8V4H)&9I;&50;VEN=&5R<ULD9FEL
M96YA;65=6R1M;V1E72DI('L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O
M(&-H96-K(&EF('=E(&-A;B!O<&5N('1H92!F:6QE(&EN('1H92!D97-I<F5D
M(&UO9&4*("`@("`@("`@("`@<W=I=&-H("@D;6]D92D*("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@8V%S92!&24Q%7TU/1$5?4D5!1#H*("`@("`@
M("`@("`@("`@("`@("!I9B`H("`@("%P<F5G7VUA=&-H*"<O7BXK*#\\(69I
M;&4I.EPO7"\O:2<L("1F:6QE;F%M92D@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("%F:6QE7V5X:7-T<R@D9FEL96YA;64I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&:6QE
M(&1O97,@;F]T(&5X:7-T.B`D9FEL96YA;64B*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(`H@("`@("`@("`@("`@("`@8V%S92!&24Q%7TU/1$5?05!014Y$.@H@("`@
M("`@("`@("`@("`@8V%S92!&24Q%7TU/1$5?5U))5$4Z"B`@("`@("`@("`@
M("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]W<FET86)L92@D9FEL96YA;64I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B1FEL92!I<R!N;W0@=W)I=&%B;&4Z("1F:6QE;F%M92(I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"%I<U]W<FET86)L92@D9&ER(#T@9&ER;F%M92@D9FEL
M96YA;64I*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(&-R96%T92!F:6QE(&EN(&1I<F5C=&]R
M>3H@)&1I<B(I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"));G9A;&ED(&%C8V5S<R!M;V1E.B`D;6]D92(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!O<&5N(&9I;&4*
M("`@("`@("`@("`@)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72`]
M($!F;W!E;B@D9FEL96YA;64L("1M;V1E*3L*("`@("`@("`@("`@:68@*"%I
M<U]R97-O=7)C92@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A
M:6QE9"!T;R!O<&5N(&9I;&4Z("<@+B`D9FEL96YA;64I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(&QO8VL@9FEL90H@
M("`@("`@(&EF("@D;&]C:RD@>PH@("`@("`@("`@("`D;&]C:R`]("1M;V1E
M(#T]($9)3$5?34]$15]214%$(#\@1DE,15],3T-+7U-(05)%1"`Z($9)3$5?
M3$]#2U]%6$-,55-)5D4["B`@("`@("`@("`@("1L;V-K<R`]("9014%2.CIG
M9713=&%T:6-0<F]P97)T>2@G1FEL92<L("=L;V-K<R<I.PH@("`@("`@("`@
M("!I9B`H0&9L;V-K*"1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95TL
M("1L;V-K*2D@>PH@("`@("`@("`@("`@("`@)&QO8VMS6UT@/2`F)&9I;&50
M;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E73L*("`@("`@("`@("`@?2!E;'-E
M:68@*$9)3$5?3$]#2U-?0DQ/0TLI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*")&:6QE(&%L<F5A9'D@;&]C:V5D.B`D9FEL
M96YA;64B*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*")#;W5L9"!N;W0@;&]C:R!F:6QE
M.B`D9FEL96YA;64B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`*("`@("`@("!R971U<FX@)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M
M;V1E73L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!296%D<R!A;B!E;G1I<F4@
M9FEL92!A;F0@<F5T=7)N<R!I="X*("`@("`J(%5S97,@9FEL95]G971?8V]N
M=&5N=',@:68@879A:6QA8FQE+@H@("`@("H@"B`@("`@*B!`86-C97-S("!P
M=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!.86UE
M(&]F(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`@*B!`<&%R86T@("!M:7AE9"`@
M("1L;V-K(%1Y<&4@;V8@;&]C:R!T;R!U<V4*("`@("`J($!R971U<FX@(&UI
M>&5D("`@4$5!4E]%<G)O<B!I9B!A;B!E<G)O<B!H87,@;V-C=7)E9"!O<B!A
M('-T<FEN9R!W:71H('1H92!C;VYT96YT<R!O9B!T:&4@=&AE(&9I;&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9$%L;"@D9FEL96YA;64L("1L;V-K(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL
M95]G971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@("!I9B`H9F%L<V4@/3T]
M("1F:6QE(#T@0&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@
M<F5A9"!F:6QE.B`D9FEL96YA;64B*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@)&9I;&4["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@
M("1F:6QE(#T@)R<["B`@("`@("`@=VAI;&4@*&9A;'-E("$]/2`D8G5F(#T@
M1FEL93HZ<F5A9"@D9FEL96YA;64L($9)3$5?1$5&055,5%]214%$4TE:12P@
M)&QO8VLI*2!["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1B=68I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&)U9CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9FEL92`N/2`D8G5F.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("`O+R!C;&]S92!T:&4@9FEL92!P;VEN=&5R"B`@("`@("`@
M1FEL93HZ8VQO<V4H)&9I;&5N86UE+"!&24Q%7TU/1$5?4D5!1"D["B`@("`@
M("`@"B`@("`@("`@<F5T=7)N("1F:6QE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('-P96-I9FEE9"!N=6UB97(@;V8@8GET97,@;V8@82!F
M:6QE+B`*("`@("`J($1E9F%U;'1S('1O($9)3$5?1$5&055,5%]214%$4TE:
M12X@($EF("1S:7IE(&ES(#`L(&%L;"!F:6QE('=I;&P@8F4@<F5A9"X*("`@
M("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D9FEL96YA;64@3F%M92!O9B!F:6QE('1O(')E860@9G)O;0H@
M("`@("H@0'!A<F%M("`@:6YT96=E<B`D<VEZ92!">71E<R!T;R!R96%D"B`@
M("`@*B!`<&%R86T@("!M:7AE9"`@("1L;V-K(%1Y<&4@;V8@;&]C:R!T;R!U
M<V4*("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4E]%<G)O<B!O;B!E<G)O
M<B!O<B!A('-T<FEN9R!W:&EC:"!C;VYT86EN<R!T:&4@9&%T82!R96%D"B`@
M("`@*B`@("`@("`@("`@("`@("`@(%=I;&P@86QS;R!R971U<FX@9F%L<V4@
M=7!O;B!%3T8*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D9FEL96YA;64L
M("1S:7IE(#T@1DE,15]$149!54Q47U)%041325I%+"`D;&]C:R`](&9A;'-E
M*0H@("`@>PH@("`@("`@('-T871I8R`D9FEL95!O:6YT97)S.PH@("`@("`@
M(`H@("`@("`@(&EF("@P(#T]("1S:7IE*2!["B`@("`@("`@("`@(')E='5R
M;B!&:6QE.CIR96%D06QL*"1F:6QE;F%M92P@)&QO8VLI.PH@("`@("`@('T@
M"@H@("`@("`@(&EF("@@("`@(6ES<V5T*"1F:6QE4&]I;G1E<G-;)&9I;&5N
M86UE72D@?'P@"B`@("`@("`@("`@("`@("`A:7-?<F5S;W5R8V4H)&9I;&50
M;VEN=&5R<ULD9FEL96YA;65=*2D@>PH@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M
M92P@1DE,15]-3T1%7U)%040L("1L;V-K*2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D9G`["B`@("`@("`@("`@('T@"@H@("`@("`@("`@("`D9FEL
M95!O:6YT97)S6R1F:6QE;F%M95T@/2`F)&9P.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1F<"`]("8D9FEL95!O:6YT97)S6R1F:6QE;F%M95T[
M"B`@("`@("`@?2`*"B`@("`@("`@<F5T=7)N("%F96]F*"1F<"D@/R!F<F5A
M9"@D9G`L("1S:7IE*2`Z(&9A;'-E.PH@("`@?2`*"B`@("`O*BH*("`@("`J
M(%=R:71E<R!T:&4@9VEV96X@9&%T82!T;R!T:&4@9VEV96X@9FEL96YA;64N
M(`H@("`@("H@1&5F875L=',@=&\@;F\@;&]C:RP@87!P96YD(&UO9&4N"B`@
M("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@
M('-T<FEN9R`@)&9I;&5N86UE($YA;64@;V8@9FEL92!T;R!W<FET92!T;PH@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&%T82!$871A('1O('=R:71E('1O
M(&9I;&4*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&UO9&4@36]D92!T;R!O
M<&5N(&9I;&4@:6X*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&QO8VL@5'EP
M92!O9B!L;V-K('1O('5S90H@("`@("H@0')E='5R;B`@;6EX960@("!014%2
M7T5R<F]R(&]N(&5R<F]R(&]R(&YU;6)E<B!O9B!B>71E<R!W<FET=&5N('1O
M(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1F:6QE;F%M92P@
M)&1A=&$L("1M;V1E(#T@1DE,15]-3T1%7T%04$5.1"P@)&QO8VL@/2!F86QS
M92D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9G`@/2`F1FEL
M93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M92P@)&UO9&4L("1L;V-K*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("!]"B`@("`@("`@
M:68@*"TQ(#T]/2`D8GET97,@/2!`9G=R:71E*"1F<"P@)&1A=&$L('-T<FQE
M;B@D9&%T82DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*")#86YN;W0@=W)I=&4@9&%T83H@)R1D871A)R!T;R!F:6QE.B`G)&9I
M;&5N86UE)R(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&)Y=&5S.PH@
M("`@?2`*"B`@("`O*BH*("`@("`J(%)E861S(&%N9"!R971U<FYS(&$@<VEN
M9VQE(&-H87)A8W1E<B!F<F]M(&=I=F5N(&9I;&5N86UE"B`@("`@*B`*("`@
M("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M)&9I;&5N86UE($YA;64@;V8@9FEL92!T;R!R96%D(&9R;VT*("`@("`J($!P
M87)A;2`@(&UI>&5D("`@)&QO8VL@5'EP92!O9B!L;V-K('1O('5S90H@("`@
M("H@0')E='5R;B`@;6EX960@("!014%27T5R<F]R(&]N(&5R<F]R(&]R(&]N
M92!C:&%R86-T97(@;V8@=&AE('-P96-I9FEE9"!F:6QE"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E861#:&%R*"1F:6QE;F%M92P@)&QO8VL@/2!F86QS92D*
M("`@('L*("`@("`@("!R971U<FX@1FEL93HZ<F5A9"@D9FEL96YA;64L(#$L
M("1L;V-K*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!7<FET97,@82!S:6YG
M;&4@8VAA<F%C=&5R('1O(&$@9FEL90H@("`@("H@"B`@("`@*B!`86-C97-S
M("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!.
M86UE(&]F(&9I;&4@=&\@=W)I=&4@=&\*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@)&-H87(@0VAA<F%C=&5R('1O('=R:71E"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("1M;V1E($UO9&4@=&\@=7-E('=H96X@=W)I=&EN9PH@("`@("H@
M0'!A<F%M("`@;6EX960@("`D;&]C:R!4>7!E(&]F(&QO8VL@=&\@=7-E"B`@
M("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?17)R;W(@;VX@97)R;W(L(&]R
M(#$@;VX@<W5C8V5S<PH@("`@("HO"B`@("!F=6YC=&EO;B!W<FET94-H87(H
M)&9I;&5N86UE+"`D8VAA<BP@)&UO9&4@/2!&24Q%7TU/1$5?05!014Y$+"`D
M;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1F<"`]("9&:6QE.CI?9V5T1FEL95!O:6YT97(H)&9I;&5N86UE+"`D;6]D
M92P@)&QO8VLI*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@
M('T*("`@("`@("!I9B`H+3$@/3T]($!F=W)I=&4H)&9P+"`D8VAA<BP@,2DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO
M="!W<FET92!D871A.B`G)&1A=&$G('1O(&9I;&4Z("<D9FEL96YA;64G(BD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`Q.PH@("`@?2`*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!L:6YE(&]F('1H92!F:6QE("AW:71H;W5T('1R
M86EL:6YG($-23$8I+@H@("`@("H@36%X:6UU;2!R96%D(&QI;F4@;&5N9W1H
M(&ES($9)3$5?34%87TQ)3D5?4D5!1%-)6D4N"B`@("`@*B`*("`@("`J($!A
M8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&9I;&5N
M86UE($YA;64@;V8@9FEL92!T;R!R96%D(&9R;VT*("`@("`J($!P87)A;2`@
M(&)O;VQE86X@)&QO8VL@5VAE=&AE<B!F:6QE('-H;W5L9"!B92!L;V-K960*
M("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4E]%<G)O<B!O;B!E<G)O<B!O
M<B!A('-T<FEN9R!C;VYT86EN:6YG('1H92!L:6YE(')E860@9G)O;2!F:6QE
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861,:6YE*"1F:6QE;F%M92P@)&QO
M8VL@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)&9I;&50;VEN=&5R
M<SL@+R\@57-E9"!T;R!P<F5V96YT('5N;F5C97-S87)Y(&-A;&QS('1O(%]G
M971&:6QE4&]I;G1E<B@I"B`@("`@("`@"B`@("`@("`@:68@*"`@("`A:7-S
M970H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=*2!\?"`*("`@("`@("`@("`@
M("`@("%I<U]R97-O=7)C92@D9FEL95!O:6YT97)S6R1F:6QE;F%M95TI*2![
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F<"`]("9&:6QE.CI?
M9V5T1FEL95!O:6YT97(H)&9I;&5N86UE+"!&24Q%7TU/1$5?4D5!1"P@)&QO
M8VLI*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("`@
M("`@?2`*"B`@("`@("`@("`@("1F:6QE4&]I;G1E<G-;)&9I;&5N86UE72`]
M("8D9G`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@)B1F
M:6QE4&]I;G1E<G-;)&9I;&5N86UE73L*("`@("`@("!](`H*("`@("`@("!I
M9B`H9F5O9B@D9G`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!](`H@("`@("`@(`H@("`@("`@(')E='5R;B!R=')I;2AF9V5T<R@D
M9G`L($9)3$5?34%87TQ)3D5?4D5!1%-)6D4I+"`B7')<;B(I.PH@("`@?2`*
M"B`@("`O*BH*("`@("`J(%=R:71E<R!A('-I;F=L92!L:6YE+"!A<'!E;F1I
M;F<@82!,1B`H8GD@9&5F875L="D*("`@("`J(`H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL96YA;64@3F%M
M92!O9B!F:6QE('1O('=R:71E('1O"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("1L:6YE($QI;F4@;V8@9&%T82!T;R!B92!W<FET=&5N('1O(&9I;&4*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@)&UO9&4@5W)I=&4@;6]D92P@8V%N(&)E
M(&5I=&AE<B!&24Q%7TU/1$5?5U))5$4@;W(@1DE,15]-3T1%7T%04$5.1`H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`D8W)L9B!4:&4@0U),1B!Y;W5R('-Y
M<W1E;2!I<R!U<VEN9RX@54Y)6"`](%QN(%=I;F1O=W,@/2!<<EQN($UA8R`]
M(%QR"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1L;V-K(%=H971H97(@=&\@
M;&]C:R!T:&4@9FEL90H@("`@("H@0')E='5R;B`@;6EX960@("!014%27T5R
M<F]R(&]N(&5R<F]R(&]R(&YU;6)E<B!O9B!B>71E<R!W<FET=&5N('1O(&9I
M;&4@*&EN8VQU9&EN9R!A<'!E;F1E9"!C<FQF*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!W<FET94QI;F4H)&9I;&5N86UE+"`D;&EN92P@)&UO9&4@/2!&24Q%
M7TU/1$5?05!014Y$+"`D8W)L9B`](")<;B(L("1L;V-K(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9P(#T@)D9I;&4Z.E]G
M971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E+"`D;&]C:RDI*2!["B`@
M("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H@("`@("`@(&EF("@M
M,2`]/3T@)&)Y=&5S(#T@9G=R:71E*"1F<"P@)&QI;F4@+B`D8W)L9BDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!W
M<FET92!D871A.B`G)&1A=&$G('1O(&9I;&4Z("<D9FEL92<B*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1B>71E<SL*("`@('T@"@H@("`@+RHJ"B`@
M("`@*B!4:&ES(')E=VEN9',@82!F:6QE<&]I;G1E<B!T;R!T:&4@<W1A<G0@
M;V8@82!F:6QE"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@)&9I;&5N86UE(%1H92!F:6QE;F%M90H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`D;6]D92!-;V1E('1H92!F:6QE('=A
M<R!O<&5N960@:6X*("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4B!%<G)O
M<B!O;B!E<G)O<BP@=')U92!O;B!S=6-C97-S"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E=VEN9"@D9FEL96YA;64L("1M;V1E*0H@("`@>PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1F<"`]("9&:6QE.CI?9V5T1FEL95!O:6YT97(H
M)&9I;&5N86UE+"`D;6]D92DI*2!["B`@("`@("`@("`@(')E='5R;B`D9G`[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A0')E=VEN9"@D9G`I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@<F5W:6YD
M(&9I;&4Z("1F:6QE;F%M92(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M=')U93L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@86QL(&]P96X@
M9FEL92!P;VEN=&5R<PH@("`@("H@"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!R971U<FX@('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO
M<V5!;&PH*0H@("`@>PH@("`@("`@("1L;V-K<R`]("9014%2.CIG9713=&%T
M:6-0<F]P97)T>2@G1FEL92<L("=L;V-K<R<I.PH@("`@("`@("1F:6QE4&]I
M;G1E<G,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I;&4G+"`G9FEL
M95!O:6YT97)S)RD["B`@("`@("`@"B`@("`@("`@+R\@=6YL;V-K(&9I;&5S
M"B`@("`@("`@9F]R("@D:2`](#`L("1C(#T@8V]U;G0H)&QO8VMS*3L@)&D@
M/"`D8SL@)&DK*RD@>PH@("`@("`@("`@("!I<U]R97-O=7)C92@D;&]C:W-;
M)&E=*2!A;F0@0&9L;V-K*"1L;V-K<ULD:5TL($Q/0TM?54XI.PH@("`@("`@
M('T*("`@("`@("`*("`@("`@("`O+R!C;&]S92!F:6QE<PH@("`@("`@(&EF
M("@A96UP='DH)&9I;&50;VEN=&5R<RDI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)&9I;&50;VEN=&5R<R!A<R`D9FYA;64@/3X@)&UO9&5S*2!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1M;V1E<RD@87,@)&UO
M9&4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&9I
M;&50;VEN=&5R<ULD9FYA;65=6R1M;V1E72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@0&9C;&]S92@D9FEL95!O:6YT97)S6R1F;F%M95U;)&UO9&5=
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M=6YS970H)&9I;&50;VEN=&5R<ULD9FYA;65=6R1M;V1E72D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`*
M("`@("\J*@H@("`@("H@5&AI<R!C;&]S97,@86X@;W!E;B!F:6QE('!O:6YT
M97(*("`@("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A
M<F%M("`@<W1R:6YG("`D9FEL96YA;64@5&AE(&9I;&5N86UE('1H870@=V%S
M(&]P96YE9`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D;6]D92!-;V1E('1H
M92!F:6QE('=A<R!O<&5N960@:6X*("`@("`J($!R971U<FX@(&UI>&5D("`@
M4$5!4B!%<G)O<B!O;B!E<G)O<BP@=')U92!O=&AE<G=I<V4*("`@("`J+PH@
M("`@9G5N8W1I;VX@8VQO<V4H)&9I;&5N86UE+"`D;6]D92D*("`@('L*("`@
M("`@("`D9FEL95!O:6YT97)S(#T@)E!%05(Z.F=E=%-T871I8U!R;W!E<G1Y
M*"=&:6QE)RP@)V9I;&50;VEN=&5R<R<I.PH@("`@("`@(`H@("`@("`@(&EF
M("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1F:6QE;F%M92`]('-T<E1O
M3&]W97(H)&9I;&5N86UE*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@
M)&9P(#T@)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E73L*("`@("`@
M("!U;G-E="@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=*3L*("`@
M("`@("`*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@("`@
M("`@("`O+R!U;FQO8VL@9FEL90H@("`@("`@("`@("!`9FQO8VLH)&9P+"!,
M3T-+7U5.*3L*("`@("`@("`@("`@+R\@8VQO<V4@9FEL90H@("`@("`@("`@
M("!I9B`H(4!F8VQO<V4H)&9P*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!C;&]S92!F:6QE.B`D9FEL96YA
M;64B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`*("`@("`@
M("!R971U<FX@=')U93L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!4:&ES('5N
M;&]C:W,@82!L;V-K960@9FEL92!P;VEN=&5R+@H@("`@("H@"B`@("`@*B!`
M86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE
M;F%M92!4:&4@9FEL96YA;64@=&AA="!W87,@;W!E;F5D"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@("1M;V1E($UO9&4@=&AE(&9I;&4@=V%S(&]P96YE9"!I
M;@H@("`@("H@0')E='5R;B`@;6EX960@("!014%2($5R<F]R(&]N(&5R<F]R
M+"!T<G5E(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!U;FQO8VLH
M)&9I;&5N86UE+"`D;6]D92D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M92P@
M)&UO9&4I*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@('T*
M("`@("`@("!I9B`H(4!F;&]C:R@D9G`L($Q/0TM?54XI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86-N;F]T('5N;&]C:R!F
M:6QE.B`D9FEL96YA;64B*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!](`H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960*("`@("`J
M+PH@("`@9G5N8W1I;VX@<W1R:7!4<F%I;&EN9U-E<&%R871O<G,H)'!A=&@L
M("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@
M("`@(')E='5R;B!R=')I;2@D<&%T:"P@)'-E<&%R871O<BD["B`@("!](`H*
M("`@("\J*@H@("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@9G5N8W1I
M;VX@<W1R:7!,96%D:6YG4V5P87)A=&]R<R@D<&%T:"P@)'-E<&%R871O<B`]
M($1)4D5#5$]265]315!!4D%43U(I"B`@("!["B`@("`@("`@<F5T=7)N(&QT
M<FEM*"1P871H+"`D<V5P87)A=&]R*3L*("`@('T@"@H@("`@+RHJ"B`@("`@
M*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE7U5T:6PZ.F)U:6QD4&%T:"@I
M(&EN<W1E860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD4&%T:"@D<&%R
M=',L("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@
M("`@("`@(')E<75I<F5?;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@
M<F5T=7)N($9I;&5?571I;#HZ8G5I;&10871H*"1P87)T<RP@)'-E<&%R871O
M<BD["B`@("!](`H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@("`@("!5
M<V4@1FEL95]5=&EL.CIS:VEP4F]O="@I(&EN<W1E860N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-K:7!2;V]T*"1P871H*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@<F5T=7)N($9I;&5?
M571I;#HZ<VMI<%)O;W0H)'!A=&@I.PH@("`@?2`*"B`@("`O*BH*("`@("`J
M($!D97!R96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ=&UP1&ER*"D@:6YS
M=&5A9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&5M<$1I<B@I"B`@("![
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE+U5T:6PN<&AP)SL*("`@("`@
M("!R971U<FX@1FEL95]5=&EL.CIT;7!$:7(H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($!D97!R96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ=&UP1FEL
M92@I(&EN<W1E860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1E;7!&:6QE
M*"1D:7)N86UE(#T@;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M)T9I;&4O571I;"YP:'`G.PH@("`@("`@(')E='5R;B!&:6QE7U5T:6PZ.G1M
M<$9I;&4H)&1I<FYA;64I.PH@("`@?2`*"B`@("`O*BH*("`@("`J($!D97!R
M96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ:7-!8G-O;'5T92@I(&EN<W1E
M860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES06)S;VQU=&4H)'!A=&@I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE+U5T:6PN<&AP)SL*("`@
M("`@("!R971U<FX@1FEL95]5=&EL.CII<T%B<V]L=71E*"1P871H*3L*("`@
M('T@"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE
M7U5T:6PZ.G)E;&%T:79E4&%T:"@I(&EN<W1E860N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;&%T:79E4&%T:"@D<&%T:"P@)')O;W0L("1S97!A<F%T;W(@
M/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@("`@(')E<75I<F5?
M;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@<F5T=7)N($9I;&5?571I
M;#HZ<F5L871I=F50871H*"1P871H+"`D<F]O="P@)'-E<&%R871O<BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE
M7U5T:6PZ.G)E86QP871H*"D@:6YS=&5A9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A;'!A=&@H)'!A=&@L("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T50
M05)!5$]2*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G1FEL92]5=&EL
M+G!H<"<["B`@("`@("`@<F5T=7)N($9I;&5?571I;#HZ<F5A;'!A=&@H)'!A
M=&@L("1S97!A<F%T;W(I.PH@("`@?0I]"@I014%2.CIR96=I<W1E<E-H=71D
M;W=N1G5N8RAA<G)A>2@G1FEL92<L("=?1FEL92<I*3L*"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!%05(N<&AP````````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3`U,#0U`#$P-3$U-#,Q,#4W
M`#`Q-C8P-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+RHJ#0H@*B!014%2+"!T:&4@4$A0($5X=&5N<VEO;B!A
M;F0@07!P;&EC871I;VX@4F5P;W-I=&]R>0T*("H-"B`J(%!%05(@8VQA<W,@
M86YD(%!%05)?17)R;W(@8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&5R;&EN9R!(=6=H
M97,@/'-T97)L:6YG0'!H<"YN970^#0H@*B!`875T:&]R("`@("!3=&EG($)A
M:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N
M0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@4$5!4BYP:'`L=B`Q+CDX(#(P,#8O,#$O
M,C,@,#4Z,S@Z,#4@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BHC
M0"L-"B`J($524D]2(&-O;G-T86YT<PT*("HO#0ID969I;F4H)U!%05)?15)2
M3U)?4D5455).)RP@("`@(#$I.PT*9&5F:6YE*"=014%27T524D]27U!224Y4
M)RP@("`@("`R*3L-"F1E9FEN92@G4$5!4E]%4E)/4E]44DE'1T52)RP@("`@
M-"D[#0ID969I;F4H)U!%05)?15)23U)?1$E%)RP@("`@("`@(#@I.PT*9&5F
M:6YE*"=014%27T524D]27T-!3$Q"04-+)RP@(#$V*3L-"B\J*@T*("H@5T%2
M3DE.1SH@;V)S;VQE=&4-"B`J($!D97!R96-A=&5D#0H@*B\-"F1E9FEN92@G
M4$5!4E]%4E)/4E]%6$-%4%1)3TXG+"`S,BD[#0HO*BHC0"TJ+PT*9&5F:6YE
M*"=014%27UI%,B<L("AF=6YC=&EO;E]E>&ES=',H)W9E<G-I;VY?8V]M<&%R
M92<I("8F#0H@("`@("`@("`@("`@("`@("`@('9E<G-I;VY?8V]M<&%R92AZ
M96YD7W9E<G-I;VXH*2P@(C(M9&5V(BP@(F=E(BDI*3L-"@T*:68@*'-U8G-T
M<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2![#0H@("`@9&5F:6YE*"=/4U]7
M24Y$3U=3)RP@=')U92D[#0H@("`@9&5F:6YE*"=/4U]53DE8)RP@("`@9F%L
M<V4I.PT*("`@(&1E9FEN92@G4$5!4E]/4R<L("`@("=7:6YD;W=S)RD[#0I]
M(&5L<V4@>PT*("`@(&1E9FEN92@G3U-?5TE.1$]74R<L(&9A;'-E*3L-"B`@
M("!D969I;F4H)T]37U5.25@G+"`@("!T<G5E*3L-"B`@("!D969I;F4H)U!%
M05)?3U,G+"`@("`G56YI>"<I.R`O+R!B;&%T86YT(&%S<W5M<'1I;VX-"GT-
M"@T*+R\@:6YS=&%N="!B86-K=V%R9',@8V]M<&%T:6)I;&ET>0T*:68@*"%D
M969I;F5D*"=0051(7U-%4$%2051/4B<I*2![#0H@("`@:68@*$]37U=)3D1/
M5U,I('L-"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<[)RD[
M#0H@("`@?2!E;'-E('L-"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/
M4B<L("<Z)RD[#0H@("`@?0T*?0T*#0HD1TQ/0D%,4ULG7U!%05)?9&5F875L
M=%]E<G)O<E]M;V1E)UT@("`@(#T@4$5!4E]%4E)/4E]215154DX[#0HD1TQ/
M0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT@(#T@15]54T52
M7TY/5$E#13L-"B1'3$]"04Q36R=?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L
M:7-T)UT@/2!A<G)A>2@I.PT*)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U
M;F-S)UT@("`@("`@("`](&%R<F%Y*"D[#0HD1TQ/0D%,4ULG7U!%05)?97)R
M;W)?:&%N9&QE<E]S=&%C:R==("`@(#T@87)R87DH*3L-"@T*0&EN:5]S970H
M)W1R86-K7V5R<F]R<R<L('1R=64I.PT*#0HO*BH-"B`J($)A<V4@8VQA<W,@
M9F]R(&]T:&5R(%!%05(@8VQA<W-E<RX@(%!R;W9I9&5S(')U9&EM96YT87)Y
M#0H@*B!E;75L871I;VX@;V8@9&5S=')U8W1O<G,N#0H@*@T*("H@268@>6]U
M('=A;G0@82!D97-T<G5C=&]R(&EN('EO=7(@8VQA<W,L(&EN:&5R:70@4$5!
M4B!A;F0@;6%K92!A#0H@*B!D97-T<G5C=&]R(&UE=&AO9"!C86QL960@7WEO
M=7)C;&%S<VYA;64@*'-A;64@;F%M92!A<R!T:&4-"B`J(&-O;G-T<G5C=&]R
M+"!B=70@=VET:"!A(")?(B!P<F5F:7@I+B`@06QS;RP@:6X@>6]U<B!C;VYS
M=')U8W1O<B!Y;W4-"B`J(&AA=F4@=&\@8V%L;"!T:&4@4$5!4B!C;VYS=')U
M8W1O<CH@)'1H:7,M/E!%05(H*3LN#0H@*B!4:&4@9&5S=')U8W1O<B!M971H
M;V0@=VEL;"!B92!C86QL960@=VET:&]U="!P87)A;65T97)S+B`@3F]T92!T
M:&%T#0H@*B!A="!I;B!S;VUE(%-!4$D@:6UP;&5M96YT871I;VYS("AS=6-H
M(&%S($%P86-H92DL(&%N>2!O=71P=70@9'5R:6YG#0H@*B!T:&4@<F5Q=65S
M="!S:'5T9&]W;B`H:6X@=VAI8V@@9&5S=')U8W1O<G,@87)E(&-A;&QE9"D@
M<V5E;7,@=&\@8F4-"B`J(&1I<V-A<F1E9"X@($EF('EO=2!N965D('1O(&=E
M="!A;GD@9&5B=6<@:6YF;W)M871I;VX@9G)O;2!Y;W5R#0H@*B!D97-T<G5C
M=&]R+"!U<V4@97)R;W)?;&]G*"DL('-Y<VQO9R@I(&]R('-O;65T:&EN9R!S
M:6UI;&%R+@T*("H-"B`J($E-4$]25$%.5"$@5&\@=7-E('1H92!E;75L871E
M9"!D97-T<G5C=&]R<R!Y;W4@;F5E9"!T;R!C<F5A=&4@=&AE#0H@*B!O8FIE
M8W1S(&)Y(')E9F5R96YC93H@)&]B:B`])B!N97<@4$5!4E]C:&EL9#L-"B`J
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`
M875T:&]R("`@("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<V5E("`@("`@("!014%27T5R<F]R#0H@*B!`<VEN8V4@
M("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4$A0(#0N,"XR#0H@*B!`;&EN
M:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO8V]R92YP
M96%R+G!H<"-C;W)E+G!E87(N<&5A<@T*("HO#0IC;&%S<R!014%2#0I[#0H@
M("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*@T*("`@("`J(%=H971H
M97(@=&\@96YA8FQE(&EN=&5R;F%L(&1E8G5G(&UE<W-A9V5S+@T*("`@("`J
M#0H@("`@("H@0'9A<B`@("`@8F]O;`T*("`@("`J($!A8V-E<W,@('!R:79A
M=&4-"B`@("`@*B\-"B`@("!V87(@)%]D96)U9R`](&9A;'-E.PT*#0H@("`@
M+RHJ#0H@("`@("H@1&5F875L="!E<G)O<B!M;V1E(&9O<B!T:&ES(&]B:F5C
M="X-"B`@("`@*@T*("`@("`J($!V87(@("`@(&EN=`T*("`@("`J($!A8V-E
M<W,@('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]D969A=6QT7V5R<F]R
M7VUO9&4@/2!N=6QL.PT*#0H@("`@+RHJ#0H@("`@("H@1&5F875L="!E<G)O
M<B!O<'1I;VYS('5S960@9F]R('1H:7,@;V)J96-T('=H96X@97)R;W(@;6]D
M90T*("`@("`J(&ES(%!%05)?15)23U)?5%))1T=%4BX-"B`@("`@*@T*("`@
M("`J($!V87(@("`@(&EN=`T*("`@("`J($!A8V-E<W,@('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]D969A=6QT7V5R<F]R7V]P=&EO;G,@/2!N=6QL
M.PT*#0H@("`@+RHJ#0H@("`@("H@1&5F875L="!E<G)O<B!H86YD;&5R("AC
M86QL8F%C:RD@9F]R('1H:7,@;V)J96-T+"!I9B!E<G)O<B!M;V1E(&ES#0H@
M("`@("H@4$5!4E]%4E)/4E]#04Q,0D%#2RX-"B`@("`@*@T*("`@("`J($!V
M87(@("`@('-T<FEN9PT*("`@("`J($!A8V-E<W,@('!R:79A=&4-"B`@("`@
M*B\-"B`@("!V87(@)%]D969A=6QT7V5R<F]R7VAA;F1L97(@/2`G)SL-"@T*
M("`@("\J*@T*("`@("`J(%=H:6-H(&-L87-S('1O('5S92!F;W(@97)R;W(@
M;V)J96-T<RX-"B`@("`@*@T*("`@("`J($!V87(@("`@('-T<FEN9PT*("`@
M("`J($!A8V-E<W,@('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]E<G)O
M<E]C;&%S<R`]("=014%27T5R<F]R)SL-"@T*("`@("\J*@T*("`@("`J($%N
M(&%R<F%Y(&]F(&5X<&5C=&5D(&5R<F]R<RX-"B`@("`@*@T*("`@("`J($!V
M87(@("`@(&%R<F%Y#0H@("`@("H@0&%C8V5S<R`@<')I=F%T90T*("`@("`J
M+PT*("`@('9A<B`D7V5X<&5C=&5D7V5R<F]R<R`](&%R<F%Y*"D[#0H-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ
M#0H@("`@("H@0V]N<W1R=6-T;W(N("!296=I<W1E<G,@=&AI<R!O8FIE8W0@
M:6X-"B`@("`@*B`D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="!F;W(@
M9&5S=')U8W1O<B!E;75L871I;VX@:68@80T*("`@("`J(&1E<W1R=6-T;W(@
M;V)J96-T(&5X:7-T<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M)&5R<F]R7V-L87-S("`H;W!T:6]N86PI('=H:6-H(&-L87-S('1O('5S92!F
M;W(-"B`@("`@*B`@("`@("`@97)R;W(@;V)J96-T<RP@9&5F875L=',@=&\@
M4$5!4E]%<G)O<BX-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!R
M971U<FX@=F]I9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05(H)&5R<F]R
M7V-L87-S(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1C;&%S<VYA;64@/2!S
M=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI.PT*("`@("`@("!I9B`H)'1H
M:7,M/E]D96)U9RD@>PT*("`@("`@("`@("`@<')I;G0@(E!%05(@8V]N<W1R
M=6-T;W(@8V%L;&5D+"!C;&%S<STD8VQA<W-N86UE7&XB.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D97)R;W)?8VQA<W,@(3T](&YU;&PI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W)?8VQA<W,@/2`D97)R;W)?8VQA<W,[#0H@
M("`@("`@('T-"B`@("`@("`@=VAI;&4@*"1C;&%S<VYA;64@)B8@<W1R8V%S
M96-M<"@D8VQA<W-N86UE+"`B<&5A<B(I*2![#0H@("`@("`@("`@("`D9&5S
M=')U8W1O<B`](")?)&-L87-S;F%M92([#0H@("`@("`@("`@("!I9B`H;65T
M:&]D7V5X:7-T<R@D=&AI<RP@)&1E<W1R=6-T;W(I*2![#0H@("`@("`@("`@
M("`@("`@9VQO8F%L("1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T.PT*
M("`@("`@("`@("`@("`@("1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T
M6UT@/2`F)'1H:7,[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D1TQ/
M0D%,4ULG7U!%05)?4TA55$1/5TY?4D5'25-415)%1"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;B@B7U!%
M05)?8V%L;%]D97-T<G5C=&]R<R(I.PT*("`@("`@("`@("`@("`@("`@("`D
M1TQ/0D%,4ULG7U!%05)?4TA55$1/5TY?4D5'25-415)%1"==(#T@=')U93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1C;&%S<VYA
M;64@/2!G971?<&%R96YT7V-L87-S*"1C;&%S<VYA;64I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&1E<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J($1E<W1R=6-T;W(@
M*'1H92!E;75L871E9"!T>7!E(&]F+BXN*2X@($1O97,@;F]T:&EN9R!R:6=H
M="!N;W<L#0H@("`@("H@8G5T(&ES(&EN8VQU9&5D(&9O<B!F;W)W87)D(&-O
M;7!A=&EB:6QI='DL('-O('-U8F-L87-S#0H@("`@("H@9&5S=')U8W1O<G,@
M<VAO=6QD(&%L=V%Y<R!C86QL(&ET+@T*("`@("`J#0H@("`@("H@4V5E('1H
M92!N;W1E(&EN('1H92!C;&%S<R!D97-C:7!T:6]N(&%B;W5T(&]U='!U="!F
M<F]M#0H@("`@("H@9&5S=')U8W1O<G,N#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]014%2*"D@>PT*("`@("`@("!I9B`H)'1H:7,M/E]D96)U
M9RD@>PT*("`@("`@("`@("`@<')I;G1F*")014%2(&1E<W1R=6-T;W(@8V%L
M;&5D+"!C;&%S<STE<UQN(BP@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I
M*2D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9V5T4W1A=&EC4')O<&5R='DH*0T*#0H@("`@+RHJ#0H@("`@*B!)9B!Y
M;W4@:&%V92!A(&-L87-S('1H870G<R!M;W-T;'DO96YT:7)E;'D@<W1A=&EC
M+"!A;F0@>6]U(&YE960@<W1A=&EC#0H@("`@*B!P<F]P97)T:65S+"!Y;W4@
M8V%N('5S92!T:&ES(&UE=&AO9"!T;R!S:6UU;&%T92!T:&5M+B!%9RX@:6X@
M>6]U<B!M971H;V0H<RD-"B`@("`J(&1O('1H:7,Z("1M>59A<B`]("9014%2
M.CIG9713=&%T:6-0<F]P97)T>2@G;7EC;&%S<R<L("=M>59A<B<I.PT*("`@
M("H@66]U($U54U0@=7-E(&$@<F5F97)E;F-E+"!O<B!T:&5Y('=I;&P@;F]T
M('!E<G-I<W0A#0H@("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J
M($!P87)A;2`@<W1R:6YG("1C;&%S<R`@5&AE(&-A;&QI;F<@8VQA<W-N86UE
M+"!T;R!P<F5V96YT(&-L87-H97,-"B`@("`J($!P87)A;2`@<W1R:6YG("1V
M87(@("`@5&AE('9A<FEA8FQE('1O(')E=')I979E+@T*("`@("H@0')E='5R
M;B!M:7AE9"`@($$@<F5F97)E;F-E('1O('1H92!V87)I86)L92X@268@;F]T
M('-E="!I="!W:6QL(&)E#0H@("`@*B`@("`@("`@("`@("`@("`@875T;R!I
M;FET:6%L:7-E9"!T;R!.54Q,+@T*("`@("HO#0H@("`@9G5N8W1I;VX@)F=E
M=%-T871I8U!R;W!E<G1Y*"1C;&%S<RP@)'9A<BD-"B`@("![#0H@("`@("`@
M('-T871I8R`D<')O<&5R=&EE<SL-"B`@("`@("`@<F5T=7)N("1P<F]P97)T
M:65S6R1C;&%S<UU;)'9A<ET[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(')E9VES=&5R4VAU=&1O=VY&=6YC*"D-"@T*("`@("\J*@T*("`@
M("H@57-E('1H:7,@9G5N8W1I;VX@=&\@<F5G:7-T97(@82!S:'5T9&]W;B!M
M971H;V0@9F]R('-T871I8PT*("`@("H@8VQA<W-E<RX-"B`@("`J#0H@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("H@0'!A<F%M("!M:7AE9"`D9G5N8R`@
M5&AE(&9U;F-T:6]N(&YA;64@*&]R(&%R<F%Y(&]F(&-L87-S+VUE=&AO9"D@
M=&\@8V%L;`T*("`@("H@0'!A<F%M("!M:7AE9"`D87)G<R`@5&AE(&%R9W5M
M96YT<R!T;R!P87-S('1O('1H92!F=6YC=&EO;@T*("`@("H@0')E='5R;B!V
M;VED#0H@("`@*B\-"B`@("!F=6YC=&EO;B!R96=I<W1E<E-H=71D;W=N1G5N
M8R@D9G5N8RP@)&%R9W,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@+R\@
M:68@=V4@87)E(&-A;&QE9"!S=&%T:6-A;&QY+"!T:&5R92!I<R!A('!O=&5N
M=&EA;`T*("`@("`@("`O+R!T:&%T(&YO('-H=71D;W=N(&9U;F,@:7,@<F5G
M:7-T97)E9"X@($)U9R`C-C0T-0T*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"
M04Q36R=?4$5!4E]32%541$]73E]214=)4U1%4D5$)UTI*2![#0H@("`@("`@
M("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;B@B7U!%05)?8V%L;%]D
M97-T<G5C=&]R<R(I.PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27U-(
M551$3U=.7U)%1TE35$52140G72`]('1R=64[#0H@("`@("`@('T-"B`@("`@
M("`@)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UU;72`](&%R<F%Y
M*"1F=6YC+"`D87)G<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&ES17)R;W(H*0T*#0H@("`@+RHJ#0H@("`@("H@5&5L;"!W:&5T:&5R
M(&$@=F%L=64@:7,@82!014%2(&5R<F]R+@T*("`@("`J#0H@("`@("H@0'!A
M<F%M("`@;6EX960@)&1A=&$@("!T:&4@=F%L=64@=&\@=&5S=`T*("`@("`J
M($!P87)A;2`@(&EN="`@("1C;V1E("`@:68@)&1A=&$@:7,@86X@97)R;W(@
M;V)J96-T+"!R971U<FX@=')U90T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@;VYL>2!I9B`D8V]D92!I<R!A('-T<FEN9R!A;F0-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("1O8FHM/F=E=$UE<W-A9V4H*2`]/2`D
M8V]D92!O<@T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)&-O9&4@
M:7,@86X@:6YT96=E<B!A;F0@)&]B:BT^9V5T0V]D92@I(#T]("1C;V1E#0H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC#0H@("`@("H@0')E='5R;B`@8F]O;"`@
M("!T<G5E(&EF('!A<F%M971E<B!I<R!A;B!E<G)O<@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&ES17)R;W(H)&1A=&$L("1C;V1E(#T@;G5L;"D-"B`@("![
M#0H@("`@("`@(&EF("AI<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2![#0H@
M("`@("`@("`@("!I9B`H:7-?;G5L;"@D8V]D92DI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T@96QS96EF("AI<U]S
M=')I;F<H)&-O9&4I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1D871A
M+3YG971-97-S86=E*"D@/3T@)&-O9&4[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T82T^9V5T0V]D92@I(#T]
M("1C;V1E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M<V5T17)R;W)(86YD;&EN9R@I#0H-"B`@("`O*BH-"B`@("`@*B!3971S(&AO
M=R!E<G)O<G,@9V5N97)A=&5D(&)Y('1H:7,@;V)J96-T('-H;W5L9"!B92!H
M86YD;&5D+@T*("`@("`J($-A;B!B92!I;G9O:V5D(&)O=&@@:6X@;V)J96-T
M<R!A;F0@<W1A=&EC86QL>2X@($EF(&-A;&QE9`T*("`@("`J('-T871I8V%L
M;'DL('-E=$5R<F]R2&%N9&QI;F<@<V5T<R!T:&4@9&5F875L="!B96AA=FEO
M=7(@9F]R(&%L;`T*("`@("`J(%!%05(@;V)J96-T<RX@($EF(&-A;&QE9"!I
M;B!A;B!O8FIE8W0L('-E=$5R<F]R2&%N9&QI;F<@<V5T<PT*("`@("`J('1H
M92!D969A=6QT(&)E:&%V:6]U<B!F;W(@=&AA="!O8FIE8W0N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@:6YT("1M;V1E#0H@("`@("H@("`@("`@($]N92!O
M9B!014%27T524D]27U)%5%523BP@4$5!4E]%4E)/4E]04DE.5"P-"B`@("`@
M*B`@("`@("`@4$5!4E]%4E)/4E]44DE'1T52+"!014%27T524D]27T1)12P-
M"B`@("`@*B`@("`@("`@4$5!4E]%4E)/4E]#04Q,0D%#2R!O<B!014%27T52
M4D]27T580T505$E/3BX-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D
M;W!T:6]N<PT*("`@("`J("`@("`@("!7:&5N("1M;V1E(&ES(%!%05)?15)2
M3U)?5%))1T=%4BP@=&AI<R!I<R!T:&4@97)R;W(@;&5V96P@*&]N90T*("`@
M("`J("`@("`@("!O9B!%7U5315)?3D]424-%+"!%7U5315)?5T%23DE.1R!O
M<B!%7U5315)?15)23U(I+@T*("`@("`J#0H@("`@("H@("`@("`@(%=H96X@
M)&UO9&4@:7,@4$5!4E]%4E)/4E]#04Q,0D%#2RP@=&AI<R!P87)A;65T97(@
M:7,@97AP96-T960-"B`@("`@*B`@("`@("`@=&\@8F4@=&AE(&-A;&QB86-K
M(&9U;F-T:6]N(&]R(&UE=&AO9"X@($$@8V%L;&)A8VL-"B`@("`@*B`@("`@
M("`@9G5N8W1I;VX@:7,@82!S=')I;F<@=VET:"!T:&4@;F%M92!O9B!T:&4@
M9G5N8W1I;VXL(&$-"B`@("`@*B`@("`@("`@8V%L;&)A8VL@;65T:&]D(&ES
M(&%N(&%R<F%Y(&]F('1W;R!E;&5M96YT<SH@=&AE(&5L96UE;G0-"B`@("`@
M*B`@("`@("`@870@:6YD97@@,"!I<R!T:&4@;V)J96-T+"!A;F0@=&AE(&5L
M96UE;G0@870@:6YD97@@,2!I<PT*("`@("`J("`@("`@("!T:&4@;F%M92!O
M9B!T:&4@;65T:&]D('1O(&-A;&P@:6X@=&AE(&]B:F5C="X-"B`@("`@*@T*
M("`@("`J("`@("`@("!7:&5N("1M;V1E(&ES(%!%05)?15)23U)?4%))3E0@
M;W(@4$5!4E]%4E)/4E]$244L('1H:7,@:7,-"B`@("`@*B`@("`@("`@82!P
M<FEN=&8@9F]R;6%T('-T<FEN9R!U<V5D('=H96X@<')I;G1I;F<@=&AE(&5R
M<F]R#0H@("`@("H@("`@("`@(&UE<W-A9V4N#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J($!S
M964@4$5!4E]%4E)/4E]215154DX-"B`@("`@*B!`<V5E(%!%05)?15)23U)?
M4%))3E0-"B`@("`@*B!`<V5E(%!%05)?15)23U)?5%))1T=%4@T*("`@("`J
M($!S964@4$5!4E]%4E)/4E]$244-"B`@("`@*B!`<V5E(%!%05)?15)23U)?
M0T%,3$)!0TL-"B`@("`@*B!`<V5E(%!%05)?15)23U)?15A#15!424].#0H@
M("`@("H-"B`@("`@*B!`<VEN8V4@4$A0(#0N,"XU#0H@("`@("HO#0H-"B`@
M("!F=6YC=&EO;B!S971%<G)O<DAA;F1L:6YG*"1M;V1E(#T@;G5L;"P@)&]P
M=&EO;G,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M*2`F)B!I<U]A*"1T:&ES+"`G4$5!4B<I*2![#0H@("`@("`@("`@("`D<V5T
M;6]D92`@("`@/2`F)'1H:7,M/E]D969A=6QT7V5R<F]R7VUO9&4[#0H@("`@
M("`@("`@("`D<V5T;W!T:6]N<R`@/2`F)'1H:7,M/E]D969A=6QT7V5R<F]R
M7V]P=&EO;G,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<V5T
M;6]D92`@("`@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D
M92==.PT*("`@("`@("`@("`@)'-E=&]P=&EO;G,@(#T@)B1'3$]"04Q36R=?
M4$5!4E]D969A=6QT7V5R<F]R7V]P=&EO;G,G73L-"B`@("`@("`@?0T*#0H@
M("`@("`@('-W:71C:"`H)&UO9&4I('L-"B`@("`@("`@("`@(&-A<V4@4$5!
M4E]%4E)/4E]%6$-%4%1)3TXZ#0H@("`@("`@("`@("!C87-E(%!%05)?15)2
M3U)?4D5455)..@T*("`@("`@("`@("`@8V%S92!014%27T524D]27U!224Y4
M.@T*("`@("`@("`@("`@8V%S92!014%27T524D]27U1224='15(Z#0H@("`@
M("`@("`@("!C87-E(%!%05)?15)23U)?1$E%.@T*("`@("`@("`@("`@8V%S
M92!N=6QL.@T*("`@("`@("`@("`@("`@("1S971M;V1E(#T@)&UO9&4[#0H@
M("`@("`@("`@("`@("`@)'-E=&]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S92!014%27T52
M4D]27T-!3$Q"04-+.@T*("`@("`@("`@("`@("`@("1S971M;V1E(#T@)&UO
M9&4[#0H@("`@("`@("`@("`@("`@+R\@8VQA<W,O;V)J96-T(&UE=&AO9"!C
M86QL8F%C:PT*("`@("`@("`@("`@("`@(&EF("AI<U]C86QL86)L92@D;W!T
M:6]N<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)'-E=&]P=&EO;G,@/2`D
M;W!T:6]N<SL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED(&5R<F]R(&-A;&QB
M86-K(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@9&5F875L=#H-
M"B`@("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED(&5R<F]R
M(&UO9&4B+"!%7U5315)?5T%23DE.1RD[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@97AP96-T17)R;W(H*0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M971H
M;V0@:7,@=7-E9"!T;R!T96QL('=H:6-H(&5R<F]R<R!Y;W4@97AP96-T('1O
M(&=E="X-"B`@("`@*B!%>'!E8W1E9"!E<G)O<G,@87)E(&%L=V%Y<R!R971U
M<FYE9"!W:71H(&5R<F]R(&UO9&4-"B`@("`@*B!014%27T524D]27U)%5%52
M3BX@($5X<&5C=&5D(&5R<F]R(&-O9&5S(&%R92!S=&]R960@:6X@82!S=&%C
M:RP-"B`@("`@*B!A;F0@=&AI<R!M971H;V0@<'5S:&5S(&$@;F5W(&5L96UE
M;G0@;VYT;R!I="X@(%1H92!L:7-T(&]F#0H@("`@("H@97AP96-T960@97)R
M;W)S(&%R92!I;B!E9F9E8W0@=6YT:6P@=&AE>2!A<F4@<&]P<&5D(&]F9B!T
M:&4-"B`@("`@*B!S=&%C:R!W:71H('1H92!P;W!%>'!E8W0H*2!M971H;V0N
M#0H@("`@("H-"B`@("`@*B!.;W1E('1H870@=&AI<R!M971H;V0@8V%N(&YO
M="!B92!C86QL960@<W1A=&EC86QL>0T*("`@("`J#0H@("`@("H@0'!A<F%M
M(&UI>&5D("1C;V1E(&$@<VEN9VQE(&5R<F]R(&-O9&4@;W(@86X@87)R87D@
M;V8@97)R;W(@8V]D97,@=&\@97AP96-T#0H@("`@("H-"B`@("`@*B!`<F5T
M=7)N(&EN="`@("`@=&AE(&YE=R!D97!T:"!O9B!T:&4@(F5X<&5C=&5D(&5R
M<F]R<R(@<W1A8VL-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&5X<&5C=$5R<F]R*"1C;V1E(#T@)RHG*0T*("`@('L-
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1C;V1E*2D@>PT*("`@("`@("`@("`@
M87)R87E?<'5S:"@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<RP@)&-O9&4I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@87)R87E?<'5S:"@D=&AI
M<RT^7V5X<&5C=&5D7V5R<F]R<RP@87)R87DH)&-O9&4I*3L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@<VEZ96]F*"1T:&ES+3Y?97AP96-T961?97)R
M;W)S*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<&]P17AP
M96-T*"D-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;65T:&]D('!O<',@;VYE
M(&5L96UE;G0@;V9F('1H92!E>'!E8W1E9"!E<G)O<B!C;V1E<PT*("`@("`J
M('-T86-K+@T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2`@('1H92!L
M:7-T(&]F(&5R<F]R(&-O9&5S('1H870@=V5R92!P;W!P960-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!P;W!%>'!E8W0H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N(&%R<F%Y7W!O<"@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<RD[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]C:&5C:T1E;$5X<&5C="@I
M#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UE=&AO9"!C:&5C:W,@=6YS971S
M(&%N(&5R<F]R(&-O9&4@:68@879A:6QA8FQE#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@;6EX960@97)R;W(@8V]D90T*("`@("`J($!R971U<FX@8F]O;"!T
M<G5E(&EF('1H92!E<G)O<B!C;V1E('=A<R!U;G-E="P@9F%L<V4@;W1H97)W
M:7-E#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'-I;F-E(%!(
M4"`T+C,N,`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C:&5C:T1E;$5X<&5C
M="@D97)R;W)?8V]D92D-"B`@("![#0H@("`@("`@("1D96QE=&5D(#T@9F%L
M<V4[#0H-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]E>'!E8W1E9%]E<G)O
M<G,@05,@)&ME>2`]/B`D97)R;W)?87)R87DI('L-"B`@("`@("`@("`@(&EF
M("AI;E]A<G)A>2@D97)R;W)?8V]D92P@)&5R<F]R7V%R<F%Y*2D@>PT*("`@
M("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?97AP96-T961?97)R;W)S6R1K
M97E=6V%R<F%Y7W-E87)C:"@D97)R;W)?8V]D92P@)&5R<F]R7V%R<F%Y*5TI
M.PT*("`@("`@("`@("`@("`@("1D96QE=&5D(#T@=')U93L-"B`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@+R\@8VQE86X@=7`@96UP='D@87)R87ES
M#0H@("`@("`@("`@("!I9B`H,"`]/2!C;W5N="@D=&AI<RT^7V5X<&5C=&5D
M7V5R<F]R<ULD:V5Y72DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7V5X<&5C=&5D7V5R<F]R<ULD:V5Y72D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1D96QE=&5D.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!D96Q%>'!E8W0H*0T*#0H@("`@+RHJ
M#0H@("`@("H@5&AI<R!M971H;V0@9&5L971E<R!A;&P@;V-C=7)E;F-E<R!O
M9B!T:&4@<W!E8VEF:65D(&5L96UE;G0@9G)O;0T*("`@("`J('1H92!E>'!E
M8W1E9"!E<G)O<B!C;V1E<R!S=&%C:RX-"B`@("`@*@T*("`@("`J($!P87)A
M;2`@;6EX960@)&5R<F]R7V-O9&4@97)R;W(@8V]D92!T:&%T('-H;W5L9"!B
M92!D96QE=&5D#0H@("`@("H@0')E='5R;B!M:7AE9"!L:7-T(&]F(&5R<F]R
M(&-O9&5S('1H870@=V5R92!D96QE=&5D(&]R(&5R<F]R#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B!`<VEN8V4@4$A0(#0N,RXP#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9&5L17AP96-T*"1E<G)O<E]C;V1E*0T*("`@('L-
M"B`@("`@("`@)&1E;&5T960@/2!F86QS93L-"@T*("`@("`@("!I9B`H*&ES
M7V%R<F%Y*"1E<G)O<E]C;V1E*2`F)B`H,"`A/2!C;W5N="@D97)R;W)?8V]D
M92DI*2D@>PT*("`@("`@("`@("`@+R\@)&5R<F]R7V-O9&4@:7,@82!N;VXM
M96UP='D@87)R87D@:&5R93L-"B`@("`@("`@("`@("\O('=E('=A;&L@=&AR
M;W5G:"!I="!T<GEI;F<@=&\@=6YS970@86QL#0H@("`@("`@("`@("`O+R!V
M86QU97,-"B`@("`@("`@("`@(&9O<F5A8V@H)&5R<F]R7V-O9&4@87,@)&ME
M>2`]/B`D97)R;W(I('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C
M:&5C:T1E;$5X<&5C="@D97)R;W(I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1D96QE=&5D(#T@('1R=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)&1E;&5T960@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U
M<FX@)&1E;&5T960@/R!T<G5E(#H@4$5!4CHZ<F%I<V5%<G)O<B@B5&AE(&5X
M<&5C=&5D(&5R<F]R('EO=2!S=6)M:71T960@9&]E<R!N;W0@97AI<W0B*3L@
M+R\@24U04D]612!-10T*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1E<G)O
M<E]C;V1E*2D@>PT*("`@("`@("`@("`@+R\@)&5R<F]R7V-O9&4@8V]M97,@
M86QO;F4L('1R>6EN9R!T;R!U;G-E="!I=`T*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?8VAE8VM$96Q%>'!E8W0H)&5R<F]R7V-O9&4I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")4:&4@
M97AP96-T960@97)R;W(@>6]U('-U8FUI='1E9"!D;V5S(&YO="!E>&ES="(I
M.R`O+R!)35!23U9%($U%#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`O+R`D97)R;W)?8V]D92!I<R!E;7!T>0T*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E1H92!E>'!E8W1E
M9"!E<G)O<B!Y;W4@<W5B;6ET=&5D(&ES(&5M<'1Y(BD[("\O($E-4%)/5D4@
M344-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!R86ES945R<F]R*"D-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;65T:&]D
M(&ES(&$@=W)A<'!E<B!T:&%T(')E='5R;G,@86X@:6YS=&%N8V4@;V8@=&AE
M#0H@("`@("H@8V]N9FEG=7)E9"!E<G)O<B!C;&%S<R!W:71H('1H:7,@;V)J
M96-T)W,@9&5F875L="!E<G)O<@T*("`@("`J(&AA;F1L:6YG(&%P<&QI960N
M("!)9B!T:&4@)&UO9&4@86YD("1O<'1I;VYS('!A<F%M971E<G,@87)E(&YO
M=`T*("`@("`J('-P96-I9FEE9"P@=&AE(&]B:F5C="=S(&1E9F%U;'1S(&%R
M92!U<V5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1M97-S86=E
M(&$@=&5X="!E<G)O<B!M97-S86=E(&]R(&$@4$5!4B!E<G)O<B!O8FIE8W0-
M"B`@("`@*@T*("`@("`J($!P87)A;2!I;G0@)&-O9&4@("`@("!A(&YU;65R
M:6,@97)R;W(@8V]D92`H:70@:7,@=7`@=&\@>6]U<B!C;&%S<PT*("`@("`J
M("`@("`@("`@("`@("`@("`@=&\@9&5F:6YE('1H97-E(&EF('EO=2!W86YT
M('1O('5S92!C;V1E<RD-"B`@("`@*@T*("`@("`J($!P87)A;2!I;G0@)&UO
M9&4@("`@("!/;F4@;V8@4$5!4E]%4E)/4E]215154DXL(%!%05)?15)23U)?
M4%))3E0L#0H@("`@("H@("`@("`@("`@("`@("`@("!014%27T524D]27U12
M24='15(L(%!%05)?15)23U)?1$E%+`T*("`@("`J("`@("`@("`@("`@("`@
M("`@4$5!4E]%4E)/4E]#04Q,0D%#2RP@4$5!4E]%4E)/4E]%6$-%4%1)3TXN
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&]P=&EO;G,@268@)&UO
M9&4@:7,@4$5!4E]%4E)/4E]44DE'1T52+"!T:&ES('!A<F%M971E<@T*("`@
M("`J("`@("`@("`@("`@("`@("`@<W!E8VEF:65S('1H92!02%`M:6YT97)N
M86P@97)R;W(@;&5V96P@*&]N92!O9@T*("`@("`J("`@("`@("`@("`@("`@
M("`@15]54T527TY/5$E#12P@15]54T527U=!4DY)3D<@;W(@15]54T527T52
M4D]2*2X-"B`@("`@*B`@("`@("`@("`@("`@("`@($EF("1M;V1E(&ES(%!%
M05)?15)23U)?0T%,3$)!0TLL('1H:7,-"B`@("`@*B`@("`@("`@("`@("`@
M("`@('!A<F%M971E<B!S<&5C:69I97,@=&AE(&-A;&QB86-K(&9U;F-T:6]N
M(&]R#0H@("`@("H@("`@("`@("`@("`@("`@("!M971H;V0N("!);B!O=&AE
M<B!E<G)O<B!M;V1E<R!T:&ES('!A<F%M971E<@T*("`@("`J("`@("`@("`@
M("`@("`@("`@:7,@:6=N;W)E9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97)I;F9O($EF('EO=2!N965D('1O('!A<W,@86QO;F<@9F]R
M(&5X86UP;&4@9&5B=6<-"B`@("`@*B`@("`@("`@("`@("`@("`@(&EN9F]R
M;6%T:6]N+"!T:&ES('!A<F%M971E<B!I<R!M96%N="!F;W(@=&AA="X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R7V-L87-S(%1H92!R
M971U<FYE9"!E<G)O<B!O8FIE8W0@=VEL;"!B90T*("`@("`J("`@("`@("`@
M("`@("`@("`@:6YS=&%N=&EA=&5D(&9R;VT@=&AI<R!C;&%S<RP@:68@<W!E
M8VEF:65D+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&)O;VP@)'-K:7!M<V<@
M268@=')U92P@<F%I<V5%<G)O<B!W:6QL(&]N;'D@<&%S<R!E<G)O<B!C;V1E
M<RP-"B`@("`@*B`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!M97-S86=E
M('!A<F%M971E<B!W:6QL(&)E(&1R;W!P960N#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J($!R971U<FX@;V)J96-T("`@82!014%2
M(&5R<F]R(&]B:F5C=`T*("`@("`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD
M;&EN9PT*("`@("`J($!S:6YC92!02%`@-"XP+C4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B`F<F%I<V5%<G)O<B@D;65S<V%G92`](&YU;&PL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O9&4@/2!N=6QL+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("1M;V1E(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D;W!T:6]N<R`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'5S97)I;F9O(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D97)R;W)?8VQA<W,@/2!N=6QL+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("1S:VEP;7-G(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`O+R!4
M:&4@97)R;W(@:7,@>65T(&$@4$5!4B!E<G)O<B!O8FIE8W0-"B`@("`@("`@
M:68@*&ES7V]B:F5C="@D;65S<V%G92DI('L-"B`@("`@("`@("`@("1C;V1E
M("`@("`@("`]("1M97-S86=E+3YG971#;V1E*"D[#0H@("`@("`@("`@("`D
M=7-E<FEN9F\@("`@/2`D;65S<V%G92T^9V5T57-E<DEN9F\H*3L-"B`@("`@
M("`@("`@("1E<G)O<E]C;&%S<R`]("1M97-S86=E+3YG9714>7!E*"D[#0H@
M("`@("`@("`@("`D;65S<V%G92T^97)R;W)?;65S<V%G95]P<F5F:7@@/2`G
M)SL-"B`@("`@("`@("`@("1M97-S86=E("`@("`]("1M97-S86=E+3YG971-
M97-S86=E*"D[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S970H)'1H
M:7,I("8F(&ES<V5T*"1T:&ES+3Y?97AP96-T961?97)R;W)S*2`F)B!S:7IE
M;V8H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I(#X@,"`F)B!S:7IE;V8H)&5X
M<"`](&5N9"@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<RDI*2![#0H@("`@("`@
M("`@("!I9B`H)&5X<%LP72`]/2`B*B(@?'P-"B`@("`@("`@("`@("`@("`H
M:7-?:6YT*')E<V5T*"1E>'`I*2`F)B!I;E]A<G)A>2@D8V]D92P@)&5X<"DI
M('Q\#0H@("`@("`@("`@("`@("`@*&ES7W-T<FEN9RAR97-E="@D97AP*2D@
M)B8@:6Y?87)R87DH)&UE<W-A9V4L("1E>'`I*2D@>PT*("`@("`@("`@("`@
M("`@("1M;V1E(#T@4$5!4E]%4E)/4E]215154DX[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@+R\@3F\@;6]D92!G:79E;BP@=')Y(&=L
M;V)A;"!O;F5S#0H@("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"D@>PT*("`@
M("`@("`@("`@+R\@0VQA<W,@97)R;W(@:&%N9&QE<@T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES*2`F)B!I<W-E="@D=&AI<RT^7V1E9F%U;'1?97)R
M;W)?;6]D92DI('L-"B`@("`@("`@("`@("`@("`D;6]D92`@("`]("1T:&ES
M+3Y?9&5F875L=%]E<G)O<E]M;V1E.PT*("`@("`@("`@("`@("`@("1O<'1I
M;VYS(#T@)'1H:7,M/E]D969A=6QT7V5R<F]R7V]P=&EO;G,[#0H@("`@("`@
M("`@("`O+R!';&]B86P@97)R;W(@:&%N9&QE<@T*("`@("`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7VUO
M9&4G72DI('L-"B`@("`@("`@("`@("`@("`D;6]D92`@("`]("1'3$]"04Q3
M6R=?4$5!4E]D969A=6QT7V5R<F]R7VUO9&4G73L-"B`@("`@("`@("`@("`@
M("`D;W!T:6]N<R`]("1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7V]P
M=&EO;G,G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@
M(&EF("@D97)R;W)?8VQA<W,@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1E
M8R`]("1E<G)O<E]C;&%S<SL-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T
M:&ES*2`F)B!I<W-E="@D=&AI<RT^7V5R<F]R7V-L87-S*2D@>PT*("`@("`@
M("`@("`@)&5C(#T@)'1H:7,M/E]E<G)O<E]C;&%S<SL-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1E8R`]("=014%27T5R<F]R)SL-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'-K:7!M<V<I('L-"B`@("`@("`@("`@("1A
M(#T@)FYE=R`D96,H)&-O9&4L("1M;V1E+"`D;W!T:6]N<RP@)'5S97)I;F9O
M*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1A(#T@)FYE=R`D96,H)&UE<W-A9V4L("1C;V1E+"`D
M;6]D92P@)&]P=&EO;G,L("1U<V5R:6YF;RD[#0H@("`@("`@("`@("!R971U
M<FX@)&$[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@=&AR;W=%<G)O<B@I#0H-"B`@("`O*BH-"B`@("`@*B!3:6UP;&5R
M(&9O<FT@;V8@<F%I<V5%<G)O<B!W:71H(&9E=V5R(&]P=&EO;G,N("!);B!M
M;W-T(&-A<V5S#0H@("`@("H@;65S<V%G92P@8V]D92!A;F0@=7-E<FEN9F\@
M87)E(&5N;W5G:"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&UE
M<W-A9V4-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9T:')O=T5R
M<F]R*"1M97-S86=E(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]D92`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@)'5S
M97)I;F9O(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RD@)B8@:7-?82@D=&AI<RP@)U!%05(G*2D@>PT*("`@("`@("`@("`@)&$@
M/2`F)'1H:7,M/G)A:7-E17)R;W(H)&UE<W-A9V4L("1C;V1E+"!N=6QL+"!N
M=6QL+"`D=7-E<FEN9F\I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&$@/2`F4$5!4CHZ<F%I<V5%
M<G)O<B@D;65S<V%G92P@)&-O9&4L(&YU;&PL(&YU;&PL("1U<V5R:6YF;RD[
M#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("!F=6YC=&EO;B!S=&%T:6-0=7-H17)R;W)(86YD
M;&EN9R@D;6]D92P@)&]P=&EO;G,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@
M)'-T86-K(#T@)B1'3$]"04Q36R=?4$5!4E]E<G)O<E]H86YD;&5R7W-T86-K
M)UT[#0H@("`@("`@("1D969?;6]D92`@("`]("8D1TQ/0D%,4ULG7U!%05)?
M9&5F875L=%]E<G)O<E]M;V1E)UT[#0H@("`@("`@("1D969?;W!T:6]N<R`]
M("8D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT[#0H@
M("`@("`@("1S=&%C:UM=(#T@87)R87DH)&1E9E]M;V1E+"`D9&5F7V]P=&EO
M;G,I.PT*("`@("`@("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@("`@("!C
M87-E(%!%05)?15)23U)?15A#15!424]..@T*("`@("`@("`@("`@8V%S92!0
M14%27T524D]27U)%5%523CH-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/
M4E]04DE.5#H-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]44DE'1T52
M.@T*("`@("`@("`@("`@8V%S92!014%27T524D]27T1)13H-"B`@("`@("`@
M("`@(&-A<V4@;G5L;#H-"B`@("`@("`@("`@("`@("`D9&5F7VUO9&4@/2`D
M;6]D93L-"B`@("`@("`@("`@("`@("`D9&5F7V]P=&EO;G,@/2`D;W!T:6]N
M<SL-"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S
M92!014%27T524D]27T-!3$Q"04-+.@T*("`@("`@("`@("`@("`@("1D969?
M;6]D92`]("1M;V1E.PT*("`@("`@("`@("`@("`@("\O(&-L87-S+V]B:F5C
M="!M971H;V0@8V%L;&)A8VL-"B`@("`@("`@("`@("`@("!I9B`H:7-?8V%L
M;&%B;&4H)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`@("`@("`@("1D969?
M;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@('1R:6=G97)?97)R;W(H(FEN=F%L:60@
M97)R;W(@8V%L;&)A8VLB+"!%7U5315)?5T%23DE.1RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@
M("!D969A=6QT.@T*("`@("`@("`@("`@("`@('1R:6=G97)?97)R;W(H(FEN
M=F%L:60@97)R;W(@;6]D92(L($5?55-%4E]705).24Y'*3L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*("`@("`@("`D<W1A8VM;72`]
M(&%R<F%Y*"1M;V1E+"`D;W!T:6]N<RD[#0H@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-T871I8U!O<$5R<F]R2&%N9&QI
M;F<H*0T*("`@('L-"B`@("`@("`@)'-T86-K(#T@)B1'3$]"04Q36R=?4$5!
M4E]E<G)O<E]H86YD;&5R7W-T86-K)UT[#0H@("`@("`@("1S971M;V1E("`@
M("`]("8D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UT[#0H@
M("`@("`@("1S971O<'1I;VYS("`]("8D1TQ/0D%,4ULG7U!%05)?9&5F875L
M=%]E<G)O<E]O<'1I;VYS)UT[#0H@("`@("`@(&%R<F%Y7W!O<"@D<W1A8VLI
M.PT*("`@("`@("!L:7-T*"1M;V1E+"`D;W!T:6]N<RD@/2`D<W1A8VM;<VEZ
M96]F*"1S=&%C:RD@+2`Q73L-"B`@("`@("`@87)R87E?<&]P*"1S=&%C:RD[
M#0H@("`@("`@('-W:71C:"`H)&UO9&4I('L-"B`@("`@("`@("`@(&-A<V4@
M4$5!4E]%4E)/4E]%6$-%4%1)3TXZ#0H@("`@("`@("`@("!C87-E(%!%05)?
M15)23U)?4D5455)..@T*("`@("`@("`@("`@8V%S92!014%27T524D]27U!2
M24Y4.@T*("`@("`@("`@("`@8V%S92!014%27T524D]27U1224='15(Z#0H@
M("`@("`@("`@("!C87-E(%!%05)?15)23U)?1$E%.@T*("`@("`@("`@("`@
M8V%S92!N=6QL.@T*("`@("`@("`@("`@("`@("1S971M;V1E(#T@)&UO9&4[
M#0H@("`@("`@("`@("`@("`@)'-E=&]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S92!014%2
M7T524D]27T-!3$Q"04-+.@T*("`@("`@("`@("`@("`@("1S971M;V1E(#T@
M)&UO9&4[#0H@("`@("`@("`@("`@("`@+R\@8VQA<W,O;V)J96-T(&UE=&AO
M9"!C86QL8F%C:PT*("`@("`@("`@("`@("`@(&EF("AI<U]C86QL86)L92@D
M;W!T:6]N<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)'-E=&]P=&EO;G,@
M/2`D;W!T:6]N<SL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED(&5R<F]R(&-A
M;&QB86-K(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@9&5F875L
M=#H-"B`@("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED(&5R
M<F]R(&UO9&4B+"!%7U5315)?5T%23DE.1RD[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+R\@>WM[('!U<VA%<G)O<DAA;F1L:6YG*"D-"@T*("`@("\J
M*@T*("`@("`J(%!U<V@@82!N97<@97)R;W(@:&%N9&QE<B!O;B!T;W`@;V8@
M=&AE(&5R<F]R(&AA;F1L97(@;W!T:6]N<R!S=&%C:RX@5VET:"!T:&ES#0H@
M("`@("H@>6]U(&-A;B!E87-I;'D@;W9E<G)I9&4@=&AE(&%C='5A;"!E<G)O
M<B!H86YD;&5R(&9O<B!S;VUE(&-O9&4@86YD(')E<W1O<F4-"B`@("`@*B!I
M="!L871E<B!W:71H('!O<$5R<F]R2&%N9&QI;F<N#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@;6EX960@)&UO9&4@*'-A;64@87,@<V5T17)R;W)(86YD;&EN
M9RD-"B`@("`@*B!`<&%R86T@;6EX960@)&]P=&EO;G,@*'-A;64@87,@<V5T
M17)R;W)(86YD;&EN9RD-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!!
M;'=A>7,@=')U90T*("`@("`J#0H@("`@("H@0'-E92!014%2.CIS971%<G)O
M<DAA;F1L:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<'5S:$5R<F]R2&%N
M9&QI;F<H)&UO9&4L("1O<'1I;VYS(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M("1S=&%C:R`]("8D1TQ/0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE<E]S=&%C
M:R==.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,I("8F(&ES7V$H)'1H:7,L
M("=014%2)RDI('L-"B`@("`@("`@("`@("1D969?;6]D92`@("`]("8D=&AI
M<RT^7V1E9F%U;'1?97)R;W)?;6]D93L-"B`@("`@("`@("`@("1D969?;W!T
M:6]N<R`]("8D=&AI<RT^7V1E9F%U;'1?97)R;W)?;W!T:6]N<SL-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D969?;6]D92`@("`]("8D1TQ/
M0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UT[#0H@("`@("`@("`@
M("`D9&5F7V]P=&EO;G,@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R
M;W)?;W!T:6]N<R==.PT*("`@("`@("!]#0H@("`@("`@("1S=&%C:UM=(#T@
M87)R87DH)&1E9E]M;V1E+"`D9&5F7V]P=&EO;G,I.PT*#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RD@)B8@:7-?82@D=&AI<RP@)U!%05(G*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/G-E=$5R<F]R2&%N9&QI;F<H)&UO9&4L("1O<'1I
M;VYS*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(%!%05(Z.G-E
M=$5R<F]R2&%N9&QI;F<H)&UO9&4L("1O<'1I;VYS*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<W1A8VM;72`](&%R<F%Y*"1M;V1E+"`D;W!T:6]N<RD[#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!P;W!%<G)O<DAA;F1L:6YG*"D-"@T*("`@("\J*@T*("`@("H@
M4&]P('1H92!L87-T(&5R<F]R(&AA;F1L97(@=7-E9`T*("`@("H-"B`@("`J
M($!R971U<FX@8F]O;"!!;'=A>7,@=')U90T*("`@("H-"B`@("`J($!S964@
M4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<-"B`@("`J+PT*("`@(&9U;F-T:6]N
M('!O<$5R<F]R2&%N9&QI;F<H*0T*("`@('L-"B`@("`@("`@)'-T86-K(#T@
M)B1'3$]"04Q36R=?4$5!4E]E<G)O<E]H86YD;&5R7W-T86-K)UT[#0H@("`@
M("`@(&%R<F%Y7W!O<"@D<W1A8VLI.PT*("`@("`@("!L:7-T*"1M;V1E+"`D
M;W!T:6]N<RD@/2`D<W1A8VM;<VEZ96]F*"1S=&%C:RD@+2`Q73L-"B`@("`@
M("`@87)R87E?<&]P*"1S=&%C:RD[#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RD@)B8@:7-?82@D=&AI<RP@)U!%05(G*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/G-E=$5R<F]R2&%N9&QI;F<H)&UO9&4L("1O<'1I;VYS*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(%!%05(Z.G-E=$5R<F]R2&%N9&QI
M;F<H)&UO9&4L("1O<'1I;VYS*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;&]A
M9$5X=&5N<VEO;B@I#0H-"B`@("`O*BH-"B`@("`J($]3(&EN9&5P96YD86YT
M(%!(4"!E>'1E;G-I;VX@;&]A9"X@4F5M96UB97(@=&\@=&%K92!C87)E#0H@
M("`@*B!O;B!T:&4@8V]R<F5C="!E>'1E;G-I;VX@;F%M92!F;W(@8V%S92!S
M96YS:71I=F4@3U-E<RX-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R:6YG("1E
M>'0@5&AE(&5X=&5N<VEO;B!N86UE#0H@("`@*B!`<F5T=7)N(&)O;VP@4W5C
M8V5S<R!O<B!N;W0@;VX@=&AE(&1L*"D@8V%L;`T*("`@("HO#0H@("`@9G5N
M8W1I;VX@;&]A9$5X=&5N<VEO;B@D97AT*0T*("`@('L-"B`@("`@("`@:68@
M*"%E>'1E;G-I;VY?;&]A9&5D*"1E>'0I*2![#0H@("`@("`@("`@("`O+R!I
M9B!E:71H97(@<F5T=7)N<R!T<G5E(&1L*"D@=VEL;"!P<F]D=6-E(&$@1D%4
M04P@97)R;W(L('-T;W`@=&AA=`T*("`@("`@("`@("`@:68@*"AI;FE?9V5T
M*"=E;F%B;&5?9&PG*2`A/2`Q*2!\?"`H:6YI7V=E="@G<V%F95]M;V1E)RD@
M/3T@,2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H3U-?5TE.1$]74RD@>PT*("`@
M("`@("`@("`@("`@("1S=69F:7@@/2`G+F1L;"<[#0H@("`@("`@("`@("!]
M(&5L<V5I9B`H4$A07T]3(#T]("=(4"U56"<I('L-"B`@("`@("`@("`@("`@
M("`D<W5F9FEX(#T@)RYS;"<[#0H@("`@("`@("`@("!](&5L<V5I9B`H4$A0
M7T]3(#T]("=!25@G*2![#0H@("`@("`@("`@("`@("`@)'-U9F9I>"`]("<N
M82<[#0H@("`@("`@("`@("!](&5L<V5I9B`H4$A07T]3(#T]("=/4U@G*2![
M#0H@("`@("`@("`@("`@("`@)'-U9F9I>"`]("<N8G5N9&QE)SL-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'-U9F9I>"`]("<N
M<V\G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N($!D;"@G
M<&AP7R<N)&5X="XD<W5F9FEX*2!\?"!`9&PH)&5X="XD<W5F9FEX*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"GT-"@T*+R\@>WM[(%]014%27V-A;&Q?9&5S=')U8W1O<G,H*0T*
M#0IF=6YC=&EO;B!?4$5!4E]C86QL7V1E<W1R=6-T;W)S*"D-"GL-"B`@("!G
M;&]B86P@)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0[#0H@("`@:68@
M*&ES7V%R<F%Y*"1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T*2`F)@T*
M("`@("`@("!S:7IE;V8H)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0I
M*0T*("`@('L-"B`@("`@("`@<F5S970H)%]014%27V1E<W1R=6-T;W)?;V)J
M96-T7VQI<W0I.PT*("`@("`@("!I9B`H0%!%05(Z.F=E=%-T871I8U!R;W!E
M<G1Y*"=014%2)RP@)V1E<W1R=6-T;&EF;R<I*2![#0H@("`@("`@("`@("`D
M7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="`](&%R<F%Y7W)E=F5R<V4H
M)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0I.PT*("`@("`@("!]#0H@
M("`@("`@('=H:6QE("AL:7-T*"1K+"`D;V)J<F5F*2`](&5A8V@H)%]014%2
M7V1E<W1R=6-T;W)?;V)J96-T7VQI<W0I*2![#0H@("`@("`@("`@("`D8VQA
M<W-N86UE(#T@9V5T7V-L87-S*"1O8FIR968I.PT*("`@("`@("`@("`@=VAI
M;&4@*"1C;&%S<VYA;64I('L-"B`@("`@("`@("`@("`@("`D9&5S=')U8W1O
M<B`](")?)&-L87-S;F%M92([#0H@("`@("`@("`@("`@("`@:68@*&UE=&AO
M9%]E>&ES=',H)&]B:G)E9BP@)&1E<W1R=6-T;W(I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1O8FIR968M/B1D97-T<G5C=&]R*"D[#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2!G971?<&%R96YT7V-L
M87-S*"1C;&%S<VYA;64I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`O+R!%;7!T>2!T:&4@;V)J96-T
M(&QI<W0@=&\@96YS=7)E('1H870@9&5S=')U8W1O<G,@87)E#0H@("`@("`@
M("\O(&YO="!C86QL960@;6]R92!T:&%N(&]N8V4N#0H@("`@("`@("1?4$5!
M4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T(#T@87)R87DH*3L-"B`@("!]#0H-
M"B`@("`O+R!.;W<@8V%L;"!T:&4@<VAU=&1O=VX@9G5N8W1I;VYS#0H@("`@
M:68@*&ES7V%R<F%Y*"1'3$]"04Q36R=?4$5!4E]S:'5T9&]W;E]F=6YC<R==
M*2!!3D0@(65M<'1Y*"1'3$]"04Q36R=?4$5!4E]S:'5T9&]W;E]F=6YC<R==
M*2D@>PT*("`@("`@("!F;W)E86-H("@D1TQ/0D%,4ULG7U!%05)?<VAU=&1O
M=VY?9G5N8W,G72!A<R`D=F%L=64I('L-"B`@("`@("`@("`@(&-A;&Q?=7-E
M<E]F=6YC7V%R<F%Y*"1V86QU95LP72P@)'9A;'5E6S%=*3L-"B`@("`@("`@
M?0T*("`@('T-"GT-"@T*+R\@?7U]#0HO*BH-"B`J(%-T86YD87)D(%!%05(@
M97)R;W(@8VQA<W,@9F]R(%!(4"`T#0H@*@T*("H@5&AI<R!C;&%S<R!I<R!S
M=7!S97)S961E9"!B>2![0&QI;FL@4$5!4E]%>&-E<'1I;VY](&EN(%!(4"`U
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O
M;3X-"B`J($!A=71H;W(@("`@($=R96=O<GD@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]C;W)E+G!E87(N<&5A<BUE<G)O<BYP:'`-"B`J($!S964@
M("`@("`@(%!%05(Z.G)A:7-E17)R;W(H*2P@4$5!4CHZ=&AR;W=%<G)O<B@I
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4$A0(#0N
M,"XR#0H@*B\-"F-L87-S(%!%05)?17)R;W(-"GL-"B`@("`O+R![>WL@<')O
M<&5R=&EE<PT*#0H@("`@=F%R("1E<G)O<E]M97-S86=E7W!R969I>"`]("<G
M.PT*("`@('9A<B`D;6]D92`@("`@("`@("`@("`@("`@/2!014%27T524D]2
M7U)%5%523CL-"B`@("!V87(@)&QE=F5L("`@("`@("`@("`@("`@(#T@15]5
M4T527TY/5$E#13L-"B`@("!V87(@)&-O9&4@("`@("`@("`@("`@("`@(#T@
M+3$[#0H@("`@=F%R("1M97-S86=E("`@("`@("`@("`@("`]("<G.PT*("`@
M('9A<B`D=7-E<FEN9F\@("`@("`@("`@("`@/2`G)SL-"B`@("!V87(@)&)A
M8VMT<F%C92`@("`@("`@("`@(#T@;G5L;#L-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]%
M<G)O<B!C;VYS=')U8W1O<@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;65S<V%G92`@;65S<V%G90T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN
M="`D8V]D92`@("`@*&]P=&EO;F%L*2!E<G)O<B!C;V1E#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@:6YT("1M;V1E("`@("`H;W!T:6]N86PI(&5R<F]R(&UO
M9&4L(&]N92!O9CH@4$5!4E]%4E)/4E]215154DXL#0H@("`@("H@4$5!4E]%
M4E)/4E]04DE.5"P@4$5!4E]%4E)/4E]$244L(%!%05)?15)23U)?5%))1T=%
M4BP-"B`@("`@*B!014%27T524D]27T-!3$Q"04-+(&]R(%!%05)?15)23U)?
M15A#15!424].#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&]P=&EO
M;G,@("`H;W!T:6]N86PI(&5R<F]R(&QE=F5L+"!?3U)?(&EN('1H92!C87-E
M(&]F#0H@("`@("H@4$5!4E]%4E)/4E]#04Q,0D%#2RP@=&AE(&-A;&QB86-K
M(&9U;F-T:6]N(&]R(&]B:F5C="]M971H;V0-"B`@("`@*B!T=7!L92X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)I;F9O("AO<'1I;VYA
M;"D@861D:71I;VYA;"!U<V5R+V1E8G5G(&EN9F\-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!014%27T5R<F]R*"1M97-S86=E(#T@)W5N:VYO=VX@97)R;W(G+"`D8V]D
M92`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`D;6]D92`](&YU
M;&PL("1O<'1I;VYS(#T@;G5L;"P@)'5S97)I;F9O(#T@;G5L;"D-"B`@("![
M#0H@("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@
M)&UO9&4@/2!014%27T524D]27U)%5%523CL-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^;65S<V%G92`@(#T@)&UE<W-A9V4[#0H@("`@("`@("1T:&ES
M+3YC;V1E("`@("`@/2`D8V]D93L-"B`@("`@("`@)'1H:7,M/FUO9&4@("`@
M("`]("1M;V1E.PT*("`@("`@("`D=&AI<RT^=7-E<FEN9F\@(#T@)'5S97)I
M;F9O.PT*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*")D96)U9U]B86-K
M=')A8V4B*2D@>PT*("`@("`@("`@("`@:68@*$`A4$5!4CHZ9V5T4W1A=&EC
M4')O<&5R='DH)U!%05)?17)R;W(G+"`G<VMI<'1R86-E)RDI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^8F%C:W1R86-E(#T@9&5B=6=?8F%C:W1R86-E
M*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M
M;V1E("8@4$5!4E]%4E)/4E]#04Q,0D%#2RD@>PT*("`@("`@("`@("`@)'1H
M:7,M/FQE=F5L(#T@15]54T527TY/5$E#13L-"B`@("`@("`@("`@("1T:&ES
M+3YC86QL8F%C:R`]("1O<'1I;VYS.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@:68@*"1O<'1I;VYS(#T]/2!N=6QL*2![#0H@("`@("`@("`@
M("`@("`@)&]P=&EO;G,@/2!%7U5315)?3D]424-%.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)'1H:7,M/FQE=F5L(#T@)&]P=&EO;G,[#0H@("`@
M("`@("`@("`D=&AI<RT^8V%L;&)A8VL@/2!N=6QL.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?4%))3E0I('L-
M"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1O<'1I;VYS*2!\?"!I<U]I;G0H
M)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`@("`@)&9O<FUA="`]("(E<R([
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1F;W)M
M870@/2`D;W!T:6]N<SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('!R
M:6YT9B@D9F]R;6%T+"`D=&AI<RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27U1224='
M15(I('L-"B`@("`@("`@("`@('1R:6=G97)?97)R;W(H)'1H:7,M/F=E=$UE
M<W-A9V4H*2P@)'1H:7,M/FQE=F5L*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27T1)12D@>PT*("`@("`@("`@
M("`@)&US9R`]("1T:&ES+3YG971-97-S86=E*"D[#0H@("`@("`@("`@("!I
M9B`H:7-?;G5L;"@D;W!T:6]N<RD@?'P@:7-?:6YT*"1O<'1I;VYS*2D@>PT*
M("`@("`@("`@("`@("`@("1F;W)M870@/2`B)7,B.PT*("`@("`@("`@("`@
M("`@(&EF("AS=6)S='(H)&US9RP@+3$I("$](")<;B(I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&US9R`N/2`B7&XB.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&9O<FUA
M="`]("1O<'1I;VYS.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9&EE
M*'-P<FEN=&8H)&9O<FUA="P@)&US9RDI.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?0T%,3$)!0TLI('L-"B`@
M("`@("`@("`@(&EF("AI<U]C86QL86)L92@D=&AI<RT^8V%L;&)A8VLI*2![
M#0H@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F-A;&QB
M86-K+"`D=&AI<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]%6$-%4%1)3TXI('L-
M"B`@("`@("`@("`@('1R:6=G97)?97)R;W(H(E!%05)?15)23U)?15A#15!4
M24].(&ES(&]B<V]L971E+"!U<V4@8VQA<W,@4$5!4E]%>&-E<'1I;VX@9F]R
M(&5X8V5P=&EO;G,B+"!%7U5315)?5T%23DE.1RD[#0H@("`@("`@("`@("!E
M=F%L*"<D92`](&YE=R!%>&-E<'1I;VXH)'1H:7,M/FUE<W-A9V4L("1T:&ES
M+3YC;V1E*3MT:')O=R@D92D[)RD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@9V5T36]D92@I#0H-"B`@("`O*BH-"B`@
M("`@*B!'970@=&AE(&5R<F]R(&UO9&4@9G)O;2!A;B!E<G)O<B!O8FIE8W0N
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&EN="!E<G)O<B!M;V1E#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971-
M;V1E*"D@>PT*("`@("`@("!R971U<FX@)'1H:7,M/FUO9&4[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$-A;&QB86-K*"D-"@T*("`@
M("\J*@T*("`@("`J($=E="!T:&4@8V%L;&)A8VL@9G5N8W1I;VXO;65T:&]D
M(&9R;VT@86X@97)R;W(@;V)J96-T+@T*("`@("`J#0H@("`@("H@0')E='5R
M;B!M:7AE9"!C86QL8F%C:R!F=6YC=&EO;B!O<B!O8FIE8W0O;65T:&]D(&%R
M<F%Y#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971#86QL8F%C:R@I('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC
M86QL8F%C:SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T
M365S<V%G92@I#0H-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@97)R;W(@
M;65S<V%G92!F<F]M(&%N(&5R<F]R(&]B:F5C="X-"B`@("`@*@T*("`@("`J
M($!R971U<FX@('-T<FEN9R`@9G5L;"!E<G)O<B!M97-S86=E#0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971-97-S
M86=E*"D-"B`@("![#0H@("`@("`@(')E='5R;B`H)'1H:7,M/F5R<F]R7VUE
M<W-A9V5?<')E9FEX("X@)'1H:7,M/FUE<W-A9V4I.PT*("`@('T-"@T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$-O9&4H*0T*#0H@("`@+RHJ#0H@
M("`@("H@1V5T(&5R<F]R(&-O9&4@9G)O;2!A;B!E<G)O<B!O8FIE8W0-"B`@
M("`@*@T*("`@("`J($!R971U<FX@:6YT(&5R<F]R(&-O9&4-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@("!F=6YC=&EO;B!G971#;V1E
M*"D-"B`@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F-O9&4[#0H@("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G9714>7!E*"D-"@T*("`@
M("\J*@T*("`@("`J($=E="!T:&4@;F%M92!O9B!T:&ES(&5R<F]R+V5X8V5P
M=&EO;BX-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(&5R<F]R+V5X
M8V5P=&EO;B!N86UE("AT>7!E*0T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T5'EP92@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@9V5T7V-L87-S*"1T:&ES*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@9V5T57-E<DEN9F\H*0T*#0H@("`@+RHJ#0H@("`@
M("H@1V5T(&%D9&ET:6]N86P@=7-E<BUS=7!P;&EE9"!I;F9O<FUA=&EO;BX-
M"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG('5S97(M<W5P<&QI960@
M:6YF;W)M871I;VX-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=%5S97));F9O*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^=7-E<FEN9F\[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=$1E8G5G26YF;R@I#0H-"B`@("`O*BH-"B`@("`@*B!'
M970@861D:71I;VYA;"!D96)U9R!I;F9O<FUA=&EO;B!S=7!P;&EE9"!B>2!T
M:&4@87!P;&EC871I;VXN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R!D96)U9R!I;F9O<FUA=&EO;@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5B=6=);F9O*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^9V5T57-E<DEN9F\H*3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T0F%C:W1R86-E*"D-"@T*("`@
M("\J*@T*("`@("`J($=E="!T:&4@8V%L;"!B86-K=')A8V4@9G)O;2!W:&5R
M92!T:&4@97)R;W(@=V%S(&=E;F5R871E9"X-"B`@("`@*B!3=7!P;W)T960@
M=VET:"!02%`@-"XS+C`@;W(@;F5W97(N#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@:6YT("1F<F%M92`H;W!T:6]N86PI('=H870@9G)A;64@=&\@9F5T8V@-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y($)A8VMT<F%C92P@;W(@3E5,3"!I9B!N
M;W0@879A:6QA8FQE+@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T0F%C:W1R86-E*"1F<F%M92`](&YU;&PI#0H@
M("`@>PT*("`@("`@("!I9B`H9&5F:6YE9"@G4$5!4E])1TY/4D5?0D%#2U12
M04-%)RDI('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D9G)A;64@/3T](&YU;&PI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^8F%C:W1R86-E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^8F%C:W1R86-E6R1F<F%M95T[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9%5S97));F9O*"D-"@T*("`@(&9U
M;F-T:6]N(&%D9%5S97));F9O*"1I;F9O*0T*("`@('L-"B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3YU<V5R:6YF;RDI('L-"B`@("`@("`@("`@("1T:&ES
M+3YU<V5R:6YF;R`]("1I;F9O.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)'1H:7,M/G5S97)I;F9O("X]("(@*BH@)&EN9F\B.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('1O4W1R:6YG
M*"D-"@T*("`@("\J*@T*("`@("`J($UA:V4@82!S=')I;F<@<F5P<F5S96YT
M871I;VX@;V8@=&AI<R!O8FIE8W0N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R!A('-T<FEN9R!W:71H(&%N(&]B:F5C="!S=6UM87)Y#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!T;U-T
M<FEN9R@I('L-"B`@("`@("`@)&UO9&5S(#T@87)R87DH*3L-"B`@("`@("`@
M)&QE=F5L<R`](&%R<F%Y*$5?55-%4E].3U1)0T4@(#T^("=N;W1I8V4G+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@15]54T527U=!4DY)3D<@/3X@)W=A
M<FYI;F<G+`T*("`@("`@("`@("`@("`@("`@("`@("`@15]54T527T524D]2
M("`@/3X@)V5R<F]R)RD[#0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%
M05)?15)23U)?0T%,3$)!0TLI('L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&AI<RT^8V%L;&)A8VLI*2![#0H@("`@("`@("`@("`@("`@)&-A;&QB
M86-K(#T@*&ES7V]B:F5C="@D=&AI<RT^8V%L;&)A8VM;,%TI(#\-"B`@("`@
M("`@("`@("`@("`@("`@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,M/F-A
M;&QB86-K6S!=*2D@.@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%L
M;&)A8VM;,%TI("X@)SHZ)R`N#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC86QL8F%C:ULQ73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&-A;&QB86-K(#T@)'1H:7,M/F-A;&QB86-K.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H)ULE<SH@;65S
M<V%G93TB)7,B(&-O9&4])60@;6]D93UC86QL8F%C:R`G+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V-A;&QB86-K/25S('!R969I>#TB)7,B(&EN
M9F\](B5S(ETG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L
M;W=E<BAG971?8VQA<W,H)'1H:7,I*2P@)'1H:7,M/FUE<W-A9V4L("1T:&ES
M+3YC;V1E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QB86-K
M+"`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=7-E<FEN9F\I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?4%))3E0I('L-
M"B`@("`@("`@("`@("1M;V1E<UM=(#T@)W!R:6YT)SL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27U1224='15(I
M('L-"B`@("`@("`@("`@("1M;V1E<UM=(#T@)W1R:6=G97(G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?1$E%
M*2![#0H@("`@("`@("`@("`D;6]D97-;72`]("=D:64G.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?4D5455).
M*2![#0H@("`@("`@("`@("`D;6]D97-;72`]("=R971U<FXG.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!S<')I;G1F*"=;)7,Z(&UE<W-A9V4](B5S
M(B!C;V1E/25D(&UO9&4])7,@;&5V96P])7,@)RX-"B`@("`@("`@("`@("`@
M("`@("`@("`@)W!R969I>#TB)7,B(&EN9F\](B5S(ETG+`T*("`@("`@("`@
M("`@("`@("`@("`@("!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI+"`D
M=&AI<RT^;65S<V%G92P@)'1H:7,M/F-O9&4L#0H@("`@("`@("`@("`@("`@
M("`@("`@(&EM<&QO9&4H(GPB+"`D;6]D97,I+"`D;&5V96QS6R1T:&ES+3YL
M979E;%TL#0H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<E]M
M97-S86=E7W!R969I>"P-"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G5S97)I;F9O*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*+RH-"B`J
M($QO8V%L(%9A<FEA8FQE<SH-"B`J(&UO9&4Z('!H<`T*("H@=&%B+7=I9'1H
M.B`T#0H@*B!C+6)A<VEC+6]F9G-E=#H@-`T*("H@16YD.@T*("HO#0H_/@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]$871E+G!H<```````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#$Q,S`P,``Q,#4Q-30S,3`U-P`P,38W,C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30@<V]F='1A8G-T;W`]-#H@*B\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#4@0F%B82!"
M=65H;&5R+"!0:65R<F4M06QA:6X@2F]Y92`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS92P@5&AA="!I
M<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H("`@("`@?`HO
M+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@
M?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@?"!P96%R+61E
M=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<CH@0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O
M;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@
M("`@(%!I97)R92U!;&%I;B!*;WEE(#QP86IO>65`<&AP+FYE=#X@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PH*+RHJ"B`J($=E;F5R:6,@9&%T92!H86YD;&EN9R!C;&%S<R!F
M;W(@4$5!4@H@*@H@*B!'96YE<FEC(&1A=&4@:&%N9&QI;F<@8VQA<W,@9F]R
M(%!%05(N("!!='1E;7!T<R!T;R!B92!T:6UE('IO;F4@87=A<F4*("H@=&AR
M;W5G:"!T:&4@1&%T93HZ5&EM95IO;F4@8VQA<W,N("!3=7!P;W)T<R!S979E
M<F%L(&]P97)A=&EO;G,@9G)O;0H@*B!$871E.CI#86QC(&]N($1A=&4@;V)J
M96-T<RX*("H*("H@0&-A=&5G;W)Y("`@1&%T92!A;F0@5&EM90H@*B!`<&%C
M:V%G92`@("!$871E"B`J($!A=71H;W(@("`@($)A8F$@0G5E:&QE<B`\8F%B
M84!B86)A>BYC;VT^"B`J($!A=71H;W(@("`@(%!I97)R92U!;&%I;B!*;WEE
M(#QP86IO>65`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U
M<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC
M96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@1&%T92YP:'`L=B`Q+C,U
M(#(P,#4O,3$O,34@,#`Z,38Z,S@@<&%J;WEE($5X<"`D"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J+PH*+RHJ
M0",K"B`J($EN8VQU9&4@<W5P<&]R=&EN9R!C;&%S<V5S"B`J+PIR97%U:7)E
M7V]N8V4@)T1A=&4O5&EM95IO;F4N<&AP)SL*<F5Q=6ER95]O;F-E("=$871E
M+T-A;&,N<&AP)SL*<F5Q=6ER95]O;F-E("=$871E+U-P86XN<&AP)SL*+RHJ
M0",M*B\*"B\J*D`C*PH@*B!/=71P=70@9F]R;6%T<RX@(%!A<W,@=&AI<R!T
M;R!G971$871E*"DN"B`J+PHO*BH*("H@(EE965DM34TM1$0@2$@Z34TZ4U,B
M"B`J+PID969I;F4H)T1!5$5?1D]234%47TE33R<L(#$I.PHO*BH*("H@(EE9
M65E-35-35$A(34U34RA:?"@K+RTI2$A-32D_(@H@*B\*9&5F:6YE*"=$051%
M7T9/4DU!5%])4T]?0D%324,G+"`R*3L*+RHJ"B`J(")965E9+4U-+5-35$A(
M.DU-.E-3*%I\*"LO+2E(2#I-32D_(@H@*B\*9&5F:6YE*"=$051%7T9/4DU!
M5%])4T]?15A414Y$140G+"`S*3L*+RHJ"B`J(")965E9+4U-+5-35$A(.DU-
M.E-3*"Y3*BD_*%I\*"LO+2E(2#I-32D_(@H@*B\*9&5F:6YE*"=$051%7T9/
M4DU!5%])4T]?15A414Y$141?34E#4D]424U%)RP@-BD["B\J*@H@*B`B65E9
M64U-1$1(2$U-4U,B"B`J+PID969I;F4H)T1!5$5?1D]234%47U1)34535$%-
M4"<L(#0I.PHO*BH*("H@;&]N9R!I;G0L('-E8V]N9',@<VEN8V4@=&AE('5N
M:7@@97!O8V@*("HO"F1E9FEN92@G1$%415]&3U)-051?54Y)6%1)344G+"`U
M*3L*+RHJ0",M*B\*"B\J*@H@*B!'96YE<FEC(&1A=&4@:&%N9&QI;F<@8VQA
M<W,@9F]R(%!%05(*("H*("H@1V5N97)I8R!D871E(&AA;F1L:6YG(&-L87-S
M(&9O<B!014%2+B`@071T96UP=',@=&\@8F4@=&EM92!Z;VYE(&%W87)E"B`J
M('1H<F]U9V@@=&AE($1A=&4Z.E1I;65:;VYE(&-L87-S+B`@4W5P<&]R=',@
M<V5V97)A;"!O<&5R871I;VYS(&9R;VT*("H@1&%T93HZ0V%L8R!O;B!$871E
M(&]B:F5C=',N"B`J"B`J($!A=71H;W(@("`@($)A8F$@0G5E:&QE<B`\8F%B
M84!B86)A>BYC;VT^"B`J($!A=71H;W(@("`@(%!I97)R92U!;&%I;B!*;WEE
M(#QP86IO>65`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U
M<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC
M96YS90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N-@H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B\*8VQA
M<W,@1&%T90I["B`@("`O*BH*("`@("`J('1H92!Y96%R"B`@("`@*B!`=F%R
M(&EN=`H@("`@("HO"B`@("!V87(@)'EE87(["B`@("`O*BH*("`@("`J('1H
M92!M;VYT:`H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1M;VYT
M:#L*("`@("\J*@H@("`@("H@=&AE(&1A>0H@("`@("H@0'9A<B!I;G0*("`@
M("`J+PH@("`@=F%R("1D87D["B`@("`O*BH*("`@("`J('1H92!H;W5R"B`@
M("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&AO=7(["B`@("`O*BH*
M("`@("`J('1H92!M:6YU=&4*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@
M('9A<B`D;6EN=71E.PH@("`@+RHJ"B`@("`@*B!T:&4@<V5C;VYD"B`@("`@
M*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)'-E8V]N9#L*("`@("\J*@H@
M("`@("H@=&AE('!A<G1S(&]F(&$@<V5C;VYD"B`@("`@*B!`=F%R(&9L;V%T
M"B`@("`@*B\*("`@('9A<B`D<&%R='-E8V]N9#L*"B`@("`O*BH*("`@("`J
M('1I;65Z;VYE(&9O<B!T:&ES(&1A=&4*("`@("`J($!V87(@;V)J96-T($1A
M=&5?5&EM95IO;F4*("`@("`J+PH@("`@=F%R("1T>CL*"B`@("`O*BH*("`@
M("`J(&1E9FEN92!T:&4@9&5F875L="!W965K9&%Y(&%B8G)E=FEA=&EO;B!L
M96YG=&@*("`@("`J('5S960@8GD@.CIF;W)M870H*0H@("`@("H@0'9A<B!I
M;G0*("`@("`J+PH@("`@=F%R("1G9717965K9&%Y06)B<FYA;65,96YG=&@@
M/2`S.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0W)E871E<R!A(&YE=R!$871E($]B:F5C="!I;FET:6%L:7IE9"!T;R!T
M:&4@8W5R<F5N="!D871E+W1I;64@:6X@=&AE"B`@("`@*B!S>7-T96TM9&5F
M875L="!T:6UE>F]N92!B>2!D969A=6QT+B`@02!D871E(&]P=&EO;F%L;'D*
M("`@("`J('!A<W-E9"!I;B!M87D@8F4@:6X@=&AE($E33R`X-C`Q+"!424U%
M4U1!35`@;W(@54Y)6%1)344@9F]R;6%T+`H@("`@("H@;W(@86YO=&AE<B!$
M871E(&]B:F5C="X@($EF(&YO(&1A=&4@:7,@<&%S<V5D+"!T:&4@8W5R<F5N
M="!D871E+W1I;64*("`@("`J(&ES('5S960N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S964@<V5T1&%T92@I"B`@("`@*B!`<&%R
M86T@;6EX960@)&1A=&4@;W!T:6]N86P@+2!D871E+W1I;64@=&\@:6YI=&EA
M;&EZ90H@("`@("H@0')E='5R;B!O8FIE8W0@1&%T92!T:&4@;F5W($1A=&4@
M;V)J96-T"B`@("`@*B\*("`@(&9U;F-T:6]N($1A=&4H)&1A=&4@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1T:&ES+3YT>B`]($1A=&5?5&EM95IO;F4Z.F=E
M=$1E9F%U;'0H*3L*("`@("`@("!I9B`H:7-?;G5L;"@D9&%T92DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$1A=&4H9&%T92@B62UM+60@2#II.G,B*2D[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&1A=&4L("=$871E)RDI('L*("`@
M("`@("`@("`@)'1H:7,M/F-O<'DH)&1A=&4I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YS971$871E*"1D871E*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&9I96QD<R!O9B!A($1A
M=&4@;V)J96-T(&)A<V5D(&]N('1H92!I;G!U="!D871E(&%N9"!F;W)M870*
M("`@("`J"B`@("`@*B!3970@=&AE(&9I96QD<R!O9B!A($1A=&4@;V)J96-T
M(&)A<V5D(&]N('1H92!I;G!U="!D871E(&%N9"!F;W)M870L"B`@("`@*B!W
M:&EC:"!I<R!S<&5C:69I960@8GD@=&AE($1!5$5?1D]234%47RH@8V]N<W1A
M;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871E(&EN<'5T(&1A=&4*("`@("`J($!P87)A;2!I;G0@
M)&9O<FUA="!/<'1I;VYA;"!F;W)M870@8V]N<W1A;G0@*$1!5$5?1D]234%4
M7RHI(&]F('1H92!I;G!U="!D871E+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@(%1H:7,@<&%R86UE=&5R(&ES;B=T(')E86QL>2!N965D960@86YY;6]R
M92P@8G5T('EO=2!C;W5L9`H@("`@("H@("`@("`@("`@("`@("`@("`@('5S
M92!I="!T;R!F;W)C92!$051%7T9/4DU!5%]53DE85$E-12X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T1&%T92@D9&%T92P@)&9O<FUA="`]($1!5$5?1D]2
M34%47TE33RD*("`@('L*"B`@("`@("`@:68@*`H@("`@("`@("`@("!P<F5G
M7VUA=&-H*"<O7BA<9'LT?2DM/RA<9'LR?2DM/RA<9'LR?2DH6U1<<UT_*%QD
M>S)]*3H_*%QD>S)]*3H_*%QD>S)]*2A<+EQD*RD_*%I\6UPK7"U=7&1[,GTZ
M/UQD>S)]*3\I/R0O:2<L("1D871E+"`D<F5G<RD*("`@("`@("`@("`@)B8@
M)&9O<FUA="`A/2!$051%7T9/4DU!5%]53DE85$E-12D@>PH@("`@("`@("`@
M("`O+R!$051%7T9/4DU!5%])4T\L($E33U]"05-)0RP@25-/7T585$5.1$5$
M+"!A;F0@5$E-15-404U0"B`@("`@("`@("`@("\O(%1H97-E(&9O<FUA=',@
M87)E(&5X=')E;65L>2!C;&]S92!T;R!E86-H(&]T:&5R+B`@5&AI<R!R96=E
M>`H@("`@("`@("`@("`O+R!I<R!V97)Y(&QO;W-E(&%N9"!A8V-E<'1S(&%L
M;6]S="!A;GD@8G5T8VAE<F5D(&9O<FUA="!Y;W4@8V]U;&0*("`@("`@("`@
M("`@+R\@=&AR;W<@870@:70N("!E+F<N(#(P,#,M,3`M,#<@,3DZ-#4Z,34@
M86YD(#(P,#,M,3`P-S$Y-#4Z,34*("`@("`@("`@("`@+R\@87)E('1H92!S
M86UE('1H:6YG(&EN('1H92!E>65S(&]F('1H:7,@<F5G97@L(&5V96X@=&AO
M=6=H('1H90H@("`@("`@("`@("`O+R!L871T97(@:7,@;F]T(&$@=F%L:60@
M25-/(#@V,#$@9&%T92X*("`@("`@("`@("`@)'1H:7,M/GEE87(@("`@("`@
M/2`D<F5G<ULQ73L*("`@("`@("`@("`@)'1H:7,M/FUO;G1H("`@("`@/2`D
M<F5G<ULR73L*("`@("`@("`@("`@)'1H:7,M/F1A>2`@("`@("`@/2`D<F5G
M<ULS73L*("`@("`@("`@("`@)'1H:7,M/FAO=7(@("`@("`@/2!I<W-E="@D
M<F5G<ULU72D_)')E9W-;-5TZ,#L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T
M92`@("`@/2!I<W-E="@D<F5G<ULV72D_)')E9W-;-ETZ,#L*("`@("`@("`@
M("`@)'1H:7,M/G-E8V]N9"`@("`@/2!I<W-E="@D<F5G<ULW72D_)')E9W-;
M-UTZ,#L*("`@("`@("`@("`@)'1H:7,M/G!A<G1S96-O;F0@/2!I<W-E="@D
M<F5G<ULX72D_*&9L;V%T*21R96=S6SA=.BAF;&]A="DP.PH*("`@("`@("`@
M("`@+R\@:68@86X@;V9F<V5T(&ES(&1E9FEN960L(&-O;G9E<G0@=&EM92!T
M;R!55$,*("`@("`@("`@("`@+R\@1&%T92!C=7)R96YT;'D@8V%N)W0@<V5T
M(&$@=&EM97IO;F4@;VYL>2!B>2!O9F9S970L"B`@("`@("`@("`@("\O('-O
M(&ET(&AA<R!T;R!S=&]R92!I="!A<R!55$,*("`@("`@("`@("`@:68@*&ES
M<V5T*"1R96=S6SE=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G1O551#
M8GE/9F9S970H)')E9W-;.5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E:68@*&ES7VYU;65R:6,H)&1A=&4I*2!["B`@("`@("`@("`@("\O(%5.
M25A424U%"B`@("`@("`@("`@("1T:&ES+3YS971$871E*&1A=&4H(EDM;2UD
M($@Z:3IS(BP@)&1A=&4I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!U;FMN;W=N(&9O<FUA=`H@("`@("`@("`@("`D=&AI<RT^>65A<B`@
M("`@("`](#`["B`@("`@("`@("`@("1T:&ES+3YM;VYT:"`@("`@(#T@,3L*
M("`@("`@("`@("`@)'1H:7,M/F1A>2`@("`@("`@/2`Q.PH@("`@("`@("`@
M("`D=&AI<RT^:&]U<B`@("`@("`](#`["B`@("`@("`@("`@("1T:&ES+3YM
M:6YU=&4@("`@(#T@,#L*("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`@("`@
M/2`P.PH@("`@("`@("`@("`D=&AI<RT^<&%R='-E8V]N9"`]("AF;&]A="DP
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A('-T<FEN
M9R`H;W(@;W1H97(I(')E<')E<V5N=&%T:6]N(&]F('1H:7,@9&%T90H@("`@
M("H*("`@("`J($=E="!A('-T<FEN9R`H;W(@;W1H97(I(')E<')E<V5N=&%T
M:6]N(&]F('1H:7,@9&%T92!I;B!T:&4*("`@("`J(&9O<FUA="!S<&5C:69I
M960@8GD@=&AE($1!5$5?1D]234%47RH@8V]N<W1A;G1S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT("1F;W)M870@
M9F]R;6%T(&-O;G-T86YT("A$051%7T9/4DU!5%\J*2!O9B!T:&4@;W5T<'5T
M(&1A=&4*("`@("`J($!R971U<FX@<W1R:6YG('1H92!D871E(&EN('1H92!R
M97%U97-T960@9F]R;6%T"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A=&4H
M)&9O<FUA="`]($1!5$5?1D]234%47TE33RD*("`@('L*("`@("`@("!S=VET
M8V@@*"1F;W)M870I('L*("`@("`@("!C87-E($1!5$5?1D]234%47TE33SH*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF;W)M870H(B59+25M+25D("54
M(BD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@1$%415]&3U)-
M051?25-/7T)!4TE#.@H@("`@("`@("`@("`D9F]R;6%T(#T@(B59)6TE9%0E
M2"5-)5,B.PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1Z+3YG971)1"@I(#T]
M("=55$,G*2!["B`@("`@("`@("`@("`@("`D9F]R;6%T("X]("):(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9O<FUA="@D
M9F]R;6%T*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92!$051%
M7T9/4DU!5%])4T]?15A414Y$140Z"B`@("`@("`@("`@("1F;W)M870@/2`B
M)5DM)6TM)614)4@Z)4TZ)5,B.PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1Z
M+3YG971)1"@I(#T]("=55$,G*2!["B`@("`@("`@("`@("`@("`D9F]R;6%T
M("X]("):(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F9O<FUA="@D9F]R;6%T*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@8V%S92!$051%7T9/4DU!5%])4T]?15A414Y$141?34E#4D]424U%.@H@
M("`@("`@("`@("`D9F]R;6%T(#T@(B59+25M+25D5"5(.B5-.B5S(CL*("`@
M("`@("`@("`@:68@*"1T:&ES+3YT>BT^9V5T240H*2`]/2`G551#)RD@>PH@
M("`@("`@("`@("`@("`@)&9O<FUA="`N/2`B6B(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF;W)M870H)&9O<FUA="D["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@1$%415]&3U)-051?5$E-
M15-404U0.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9O<FUA="@B)5DE
M;25D)4@E3253(BD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@
M1$%415]&3U)-051?54Y)6%1)344Z"B`@("`@("`@("`@(')E='5R;B!M:W1I
M;64H)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0L
M("1T:&ES+3YM;VYT:"P@)'1H:7,M/F1A>2P@)'1H:7,M/GEE87(I.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;W!Y('9A;'5E<R!F<F]M(&%N;W1H97(@1&%T92!O8FIE8W0*("`@("`J
M"B`@("`@*B!-86ME<R!T:&ES($1A=&4@82!C;W!Y(&]F(&%N;W1H97(@1&%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!P87)A;2!O8FIE8W0@1&%T92`D9&%T92!$871E('1O(&-O<'D@9G)O;0H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;W!Y*"1D871E*0H@("`@>PH@("`@("`@
M("1T:&ES+3YY96%R(#T@)&1A=&4M/GEE87(["B`@("`@("`@)'1H:7,M/FUO
M;G1H(#T@)&1A=&4M/FUO;G1H.PH@("`@("`@("1T:&ES+3YD87D@/2`D9&%T
M92T^9&%Y.PH@("`@("`@("1T:&ES+3YH;W5R(#T@)&1A=&4M/FAO=7(["B`@
M("`@("`@)'1H:7,M/FUI;G5T92`]("1D871E+3YM:6YU=&4["B`@("`@("`@
M)'1H:7,M/G-E8V]N9"`]("1D871E+3YS96-O;F0["B`@("`@("`@)'1H:7,M
M/G1Z(#T@)&1A=&4M/G1Z.PH@("`@?0H*("`@("\J*@H@("`@("H@($1A=&4@
M<')E='1Y('!R:6YT:6YG+"!S:6UI;&%R('1O('-T<F9T:6UE*"D*("`@("`J
M"B`@("`@*B`@1F]R;6%T<R!T:&4@9&%T92!I;B!T:&4@9VEV96X@9F]R;6%T
M+"!M=6-H(&QI:V4*("`@("`J("!S=')F=&EM92@I+B`@36]S="!S=')F=&EM
M92@I(&]P=&EO;G,@87)E('-U<'!O<G1E9"X\8G(^/&)R/@H@("`@("H*("`@
M("`J("!F;W)M871T:6YG(&]P=&EO;G,Z/&)R/CQB<CX*("`@("`J"B`@("`@
M*B`@/&-O9&4^)6$@(#PO8V]D93X@(&%B8G)E=FEA=&5D('=E96MD87D@;F%M
M92`H4W5N+"!-;VXL(%1U92D@/&)R/@H@("`@("H@(#QC;V1E/B5!("`\+V-O
M9&4^("!F=6QL('=E96MD87D@;F%M92`H4W5N9&%Y+"!-;VYD87DL(%1U97-D
M87DI(#QB<CX*("`@("`J("`\8V]D93XE8B`@/"]C;V1E/B`@86)B<F5V:6%T
M960@;6]N=&@@;F%M92`H2F%N+"!&96(L($UA<BD@/&)R/@H@("`@("H@(#QC
M;V1E/B5"("`\+V-O9&4^("!F=6QL(&UO;G1H(&YA;64@*$IA;G5A<GDL($9E
M8G)U87)Y+"!-87)C:"D@/&)R/@H@("`@("H@(#QC;V1E/B5#("`\+V-O9&4^
M("!C96YT=7)Y(&YU;6)E<B`H=&AE('EE87(@9&EV:61E9"!B>2`Q,#`@86YD
M('1R=6YC871E9"!T;R!A;B!I;G1E9V5R+"!R86YG92`P,"!T;R`Y.2D@/&)R
M/@H@("`@("H@(#QC;V1E/B5D("`\+V-O9&4^("!D87D@;V8@;6]N=&@@*')A
M;F=E(#`P('1O(#,Q*2`\8G(^"B`@("`@*B`@/&-O9&4^)40@(#PO8V]D93X@
M('-A;64@87,@(B5M+R5D+R5Y(B`\8G(^"B`@("`@*B`@/&-O9&4^)64@(#PO
M8V]D93X@(&1A>2!O9B!M;VYT:"P@<VEN9VQE(&1I9VET("AR86YG92`P('1O
M(#,Q*2`\8G(^"B`@("`@*B`@/&-O9&4^)44@(#PO8V]D93X@(&YU;6)E<B!O
M9B!D87ES('-I;F-E('5N<W!E8VEF:65D(&5P;V-H("AI;G1E9V5R+"!$871E
M7T-A;&,Z.F1A=&54;T1A>7,H*2D@/&)R/@H@("`@("H@(#QC;V1E/B5(("`\
M+V-O9&4^("!H;W5R(&%S(&1E8VEM86P@;G5M8F5R("@P,"!T;R`R,RD@/&)R
M/@H@("`@("H@(#QC;V1E/B5)("`\+V-O9&4^("!H;W5R(&%S(&1E8VEM86P@
M;G5M8F5R(&]N(#$R+6AO=7(@8VQO8VL@*#`Q('1O(#$R*2`\8G(^"B`@("`@
M*B`@/&-O9&4^)6H@(#PO8V]D93X@(&1A>2!O9B!Y96%R("AR86YG92`P,#$@
M=&\@,S8V*2`\8G(^"B`@("`@*B`@/&-O9&4^)6T@(#PO8V]D93X@(&UO;G1H
M(&%S(&1E8VEM86P@;G5M8F5R("AR86YG92`P,2!T;R`Q,BD@/&)R/@H@("`@
M("H@(#QC;V1E/B5-("`\+V-O9&4^("!M:6YU=&4@87,@82!D96-I;6%L(&YU
M;6)E<B`H,#`@=&\@-3DI(#QB<CX*("`@("`J("`\8V]D93XE;B`@/"]C;V1E
M/B`@;F5W;&EN92!C:&%R86-T97(@*%QN*2`\8G(^"B`@("`@*B`@/&-O9&4^
M)4\@(#PO8V]D93X@(&1S="UC;W)R96-T960@=&EM97IO;F4@;V9F<V5T(&5X
M<')E<W-E9"!A<R`B*R\M2$@Z34TB(#QB<CX*("`@("`J("`\8V]D93XE;R`@
M/"]C;V1E/B`@<F%W('1I;65Z;VYE(&]F9G-E="!E>'!R97-S960@87,@(BLO
M+4A(.DU-(B`\8G(^"B`@("`@*B`@/&-O9&4^)7`@(#PO8V]D93X@(&5I=&AE
M<B`G86TG(&]R("=P;2<@9&5P96YD:6YG(&]N('1H92!T:6UE(#QB<CX*("`@
M("`J("`\8V]D93XE4"`@/"]C;V1E/B`@96ET:&5R("=!32<@;W(@)U!-)R!D
M97!E;F1I;F<@;VX@=&AE('1I;64@/&)R/@H@("`@("H@(#QC;V1E/B5R("`\
M+V-O9&4^("!T:6UE(&EN(&%M+W!M(&YO=&%T:6]N+"!S86UE(&%S("(E23HE
M33HE4R`E<"(@/&)R/@H@("`@("H@(#QC;V1E/B52("`\+V-O9&4^("!T:6UE
M(&EN(#(T+6AO=7(@;F]T871I;VXL('-A;64@87,@(B5(.B5-(B`\8G(^"B`@
M("`@*B`@/&-O9&4^)7,@(#PO8V]D93X@('-E8V]N9',@:6YC;'5D:6YG('1H
M92!D96-I;6%L(')E<')E<V5N=&%T:6]N('-M86QL97(@=&AA;B!O;F4@<V5C
M;VYD(#QB<CX*("`@("`J("`\8V]D93XE4R`@/"]C;V1E/B`@<V5C;VYD<R!A
M<R!A(&1E8VEM86P@;G5M8F5R("@P,"!T;R`U.2D@/&)R/@H@("`@("H@(#QC
M;V1E/B5T("`\+V-O9&4^("!T86(@8VAA<F%C=&5R("A<="D@/&)R/@H@("`@
M("H@(#QC;V1E/B54("`\+V-O9&4^("!C=7)R96YT('1I;64L('-A;64@87,@
M(B5(.B5-.B53(B`\8G(^"B`@("`@*B`@/&-O9&4^)7<@(#PO8V]D93X@('=E
M96MD87D@87,@9&5C:6UA;"`H,"`](%-U;F1A>2D@/&)R/@H@("`@("H@(#QC
M;V1E/B55("`\+V-O9&4^("!W965K(&YU;6)E<B!O9B!C=7)R96YT('EE87(L
M(&9I<G-T('-U;F1A>2!A<R!F:7)S="!W965K(#QB<CX*("`@("`J("`\8V]D
M93XE>2`@/"]C;V1E/B`@>65A<B!A<R!D96-I;6%L("AR86YG92`P,"!T;R`Y
M.2D@/&)R/@H@("`@("H@(#QC;V1E/B59("`\+V-O9&4^("!Y96%R(&%S(&1E
M8VEM86P@:6YC;'5D:6YG(&-E;G1U<GD@*')A;F=E(#`P,#`@=&\@.3DY.2D@
M/&)R/@H@("`@("H@(#QC;V1E/B4E("`\+V-O9&4^("!L:71E<F%L("<E)R`\
M8G(^"B`@("`@*B`\8G(^"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!P87)A;2!S=')I;F<@9F]R;6%T('1H92!F;W)M870@<W1R:6YG
M(&9O<B!R971U<FYE9"!D871E+W1I;64*("`@("`J($!R971U<FX@<W1R:6YG
M(&1A=&4O=&EM92!I;B!G:79E;B!F;W)M870*("`@("`J+PH@("`@9G5N8W1I
M;VX@9F]R;6%T*"1F;W)M870I"B`@("!["B`@("`@("`@)&]U='!U="`]("(B
M.PH*("`@("`@("!F;W(H)'-T<G!O<R`](#`[("1S=')P;W,@/"!S=')L96XH
M)&9O<FUA="D[("1S=')P;W,K*RD@>PH@("`@("`@("`@("`D8VAA<B`]('-U
M8G-T<B@D9F]R;6%T+"1S=')P;W,L,2D["B`@("`@("`@("`@(&EF("@D8VAA
M<B`]/2`B)2(I('L*("`@("`@("`@("`@("`@("1N97AT8VAA<B`]('-U8G-T
M<B@D9F]R;6%T+"1S=')P;W,@*R`Q+#$I.PH@("`@("`@("`@("`@("`@<W=I
M=&-H("@D;F5X=&-H87(I('L*("`@("`@("`@("`@("`@(&-A<V4@(F$B.@H@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CIG9717
M965K9&%Y06)B<FYA;64H)'1H:7,M/F1A>2PD=&AI<RT^;6]N=&@L)'1H:7,M
M/GEE87(L("1T:&ES+3YG9717965K9&%Y06)B<FYA;65,96YG=&@I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B
M02(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z
M.F=E=%=E96MD87E&=6QL;F%M92@D=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD
M=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E(")B(CH*("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]($1A=&5?0V%L8SHZ9V5T36]N=&A!8F)R;F%M92@D=&AI<RT^;6]N
M=&@I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@8V%S92`B0B(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$
M871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H)'1H:7,M/FUO;G1H*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M(D,B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B
M)3`R9"(L:6YT=F%L*"1T:&ES+3YY96%R+S$P,"DI.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B9"(Z"B`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D(BPD=&AI
M<RT^9&%Y*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(D0B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@<W!R:6YT9B@B)3`R9"\E,#)D+R4P,F0B+"1T:&ES+3YM;VYT:"PD=&AI
M<RT^9&%Y+"1T:&ES+3YY96%R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@(&-A<V4@(F4B.@H@("`@("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@)'1H:7,M/F1A>2`J(#$[("\O(&=E="!R:60@;V8@
M;&5A9&EN9R!Z97)O"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E(")%(CH*("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D=&AI<RT^9&%Y+"1T:&ES
M+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")((CH*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0B+"`D=&AI<RT^:&]U<BD[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E("=H)SH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN
M=&8H(B5D(BP@)'1H:7,M/FAO=7(I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`B22(Z"B`@("`@("`@("`@("`@
M("`@("`@)&AO=7(@/2`H)'1H:7,M/FAO=7(@*R`Q*2`^(#$R(#\@)'1H:7,M
M/FAO=7(@+2`Q,B`Z("1T:&ES+3YH;W5R.PH@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9"(L("1H;W5R/3TP(#\@,3(@.B`D
M:&]U<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E(")I(CH*("`@("`@("`@("`@("`@("`@("`D:&]U<B`]("@D
M=&AI<RT^:&]U<B`K(#$I(#X@,3(@/R`D=&AI<RT^:&]U<B`M(#$R(#H@)'1H
M:7,M/FAO=7(["B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I
M;G1F*"(E9"(L("1H;W5R/3TP(#\@,3(@.B`D:&]U<BD["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")J(CH*("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ:G5L:6%N
M1&%T92@D=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M(")M(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H
M(B4P,F0B+"1T:&ES+3YM;VYT:"D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")-(CH*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0B+"1T:&ES+3YM:6YU=&4I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M8V%S92`B;B(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B7&XB
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M8V%S92`B3R(Z"B`@("`@("`@("`@("`@("`@("`@)&]F9FUS(#T@)'1H:7,M
M/G1Z+3YG971/9F9S970H)'1H:7,I.PH@("`@("`@("`@("`@("`@("`@("1D
M:7)E8W1I;VX@/2`D;V9F;7,@/CT@,"`_("(K(B`Z("(M(CL*("`@("`@("`@
M("`@("`@("`@("`D;V9F;6EN<R`](&%B<R@D;V9F;7,I("\@,3`P,"`O(#8P
M.PH@("`@("`@("`@("`@("`@("`@("1H;W5R<R`]("1O9F9M:6YS("\@-C`[
M"B`@("`@("`@("`@("`@("`@("`@)&UI;G5T97,@/2`D;V9F;6EN<R`E(#8P
M.PH@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)7,E
M,#)D.B4P,F0B+"`D9&ER96-T:6]N+"`D:&]U<G,L("1M:6YU=&5S*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M(F\B.@H@("`@("`@("`@("`@("`@("`@("1O9F9M<R`]("1T:&ES+3YT>BT^
M9V5T4F%W3V9F<V5T*"1T:&ES*3L*("`@("`@("`@("`@("`@("`@("`D9&ER
M96-T:6]N(#T@)&]F9FUS(#X](#`@/R`B*R(@.B`B+2(["B`@("`@("`@("`@
M("`@("`@("`@)&]F9FUI;G,@/2!A8G,H)&]F9FUS*2`O(#$P,#`@+R`V,#L*
M("`@("`@("`@("`@("`@("`@("`D:&]U<G,@/2`D;V9F;6EN<R`O(#8P.PH@
M("`@("`@("`@("`@("`@("`@("1M:6YU=&5S(#T@)&]F9FUI;G,@)2`V,#L*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B5S)3`R
M9#HE,#)D(BP@)&1I<F5C=&EO;BP@)&AO=7)S+"`D;6EN=71E<RD["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")P
M(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YH;W5R
M(#X](#$R(#\@(G!M(B`Z(")A;2(["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")0(CH*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1T:&ES+3YH;W5R(#X](#$R(#\@(E!-(B`Z(")!
M32(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(")R(CH*("`@("`@("`@("`@("`@("`@("`D:&]U<B`]("@D=&AI
M<RT^:&]U<B`K(#$I(#X@,3(@/R`D=&AI<RT^:&]U<B`M(#$R(#H@)'1H:7,M
M/FAO=7(["B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F
M*"(E,#)D.B4P,F0Z)3`R9"`E<R(L("1H;W5R/3TP(#\@(#$R(#H@)&AO=7(L
M("1T:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0L("1T:&ES+3YH;W5R(#X]
M(#$R(#\@(E!-(B`Z(")!32(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@8V%S92`B4B(Z"B`@("`@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D.B4P,F0B+"`D=&AI<RT^:&]U
M<BP@)'1H:7,M/FUI;G5T92D["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E(")S(CH*("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]('-T<E]R97!L86-E*"<L)RP@)RXG+"!S<')I;G1F*"(E
M,#EF(BP@*&9L;V%T*2@H9FQO870I)'1H:7,M/G-E8V]N9"`K("1T:&ES+3YP
M87)T<V5C;VYD*2DI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B4R(Z"B`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!S<')I;G1F*"(E,#)D(BP@)'1H:7,M/G-E8V]N9"D["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")T
M(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X](")<="(["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")4
M(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P
M,F0Z)3`R9#HE,#)D(BP@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4L("1T
M:&ES+3YS96-O;F0I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B=R(Z"B`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D=&AI<RT^9&%Y+"1T:&ES
M+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")5(CH*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ=V5E:T]F665A<B@D=&AI<RT^
M9&%Y+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")Y(CH*("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]('-U8G-T<B@D=&AI<RT^>65A<BPR
M+#(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@8V%S92`B62(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D
M=&AI<RT^>65A<CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@(&-A<V4@(EHB.@H@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@)'1H:7,M/G1Z+3YI;D1A>6QI9VAT5&EM92@D=&AI<RD@/R`D=&AI
M<RT^='HM/F=E=$135%-H;W)T3F%M92@I(#H@)'1H:7,M/G1Z+3YG9713:&]R
M=$YA;64H*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(B4B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@(B4B.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M("1C:&%R+B1N97AT8VAA<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1S=')P;W,K*SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@)&-H87(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1O=71P=70["@H@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H:7,@9&%T92]T:6UE(&EN(%5N:7@@=&EM92@I(&9O
M<FUA=`H@("`@("H*("`@("`J($=E="!A(')E<')E<V5N=&%T:6]N(&]F('1H
M:7,@9&%T92!I;B!5;FEX('1I;64H*2!F;W)M870N("!4:&ES(&UA>2!O;FQY
M(&)E"B`@("`@*B!V86QI9"!F;W(@9&%T97,@9G)O;2`Q.3<P('1O('XR,#,X
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&EN="!N=6UB97(@;V8@<V5C;VYD<R!S:6YC92!T:&4@=6YI>"!E<&]C:`H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714:6UE*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/F=E=$1A=&4H1$%415]&3U)-051?54Y)6%1)344I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@=&EM92!Z;VYE(&]F('1H
M:7,@1&%T90H@("`@("H*("`@("`J(%-E=',@=&AE('1I;64@>F]N92!O9B!T
M:&ES(&1A=&4@=VET:"!T:&4@9VEV96X*("`@("`J($1A=&5?5&EM95IO;F4@
M;V)J96-T+B`@1&]E<R!N;W0@86QT97(@=&AE(&1A=&4O=&EM92P*("`@("`J
M(&]N;'D@87-S:6=N<R!A(&YE=R!T:6UE('IO;F4N("!&;W(@8V]N=F5R<VEO
M;BP@=7-E"B`@("`@*B!C;VYV97)T5%HH*2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E7U1I;65:;VYE
M("1T>B!T:&4@1&%T95]4:6UE6F]N92!O8FIE8W0@=&\@=7-E+"!I9B!C86QL
M960*("`@("`J('=I=&@@82!P87)A;6%T97(@=&AA="!I<R!N;W0@82!$871E
M7U1I;65:;VYE(&]B:F5C="P@=VEL;"!F86QL('1H<F]U9V@@=&\*("`@("`J
M('-E=%1:8GE)1"@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!S97146B@D='HI
M"B`@("!["B`@("`):68H:7-?82@D='HL("=$871E7U1I;65Z;VYE)RDI('L*
M("`@("`@("`))'1H:7,M/G1Z(#T@)'1Z.PH@("`@"7T@96QS92!["B`@("`)
M"21T:&ES+3YS97146F)Y240H)'1Z*3L*("`@(`E]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!T:6UE('IO;F4@;V8@=&AI<R!D871E('=I=&@@
M=&AE(&=I=F5N('1I;64@>F]N92!I9`H@("`@("H*("`@("`J(%-E=',@=&AE
M('1I;64@>F]N92!O9B!T:&ES(&1A=&4@=VET:"!T:&4@9VEV96X*("`@("`J
M('1I;64@>F]N92!I9"P@;W(@=&\@=&AE('-Y<W1E;2!D969A=6QT(&EF('1H
M90H@("`@("H@9VEV96X@:60@:7,@:6YV86QI9"X@1&]E<R!N;W0@86QT97(@
M=&AE(&1A=&4O=&EM92P*("`@("`J(&]N;'D@87-S:6=N<R!A(&YE=R!T:6UE
M('IO;F4N("!&;W(@8V]N=F5R<VEO;BP@=7-E"B`@("`@*B!C;VYV97)T5%HH
M*2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M('-T<FEN9R!I9"!A('1I;64@>F]N92!I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S97146F)Y240H)&ED*0H@("`@>PH@("`@("`@(&EF("A$871E7U1I;65:
M;VYE.CII<U9A;&ED240H)&ED*2D@>PH@("`@("`@("`@("`D=&AI<RT^='H@
M/2!N97<@1&%T95]4:6UE6F]N92@D:60I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YT>B`]($1A=&5?5&EM95IO;F4Z.F=E=$1E9F%U
M;'0H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!497-T<R!I
M9B!T:&ES(&1A=&4O=&EM92!I<R!I;B!$4U0*("`@("`J"B`@("`@*B!2971U
M<FYS('1R=64@:68@9&%Y;&EG:'0@<V%V:6YG<R!T:6UE(&ES(&EN(&5F9F5C
M="!F;W(*("`@("`J('1H:7,@9&%T92!I;B!T:&ES(&1A=&4G<R!T:6UE('IO
M;F4N("!3964@1&%T95]4:6UE6F]N93HZ:6Y$87EL:6=H=%1I;64H*0H@("`@
M("H@9F]R(&-O;7!A=&%B:6QI='D@:6YF;W)M871I;VXN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E
M(&EF($135"!I<R!I;B!E9F9E8W0@9F]R('1H:7,@9&%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!I;D1A>6QI9VAT5&EM92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YT>BT^:6Y$87EL:6=H=%1I;64H)'1H:7,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]N=F5R=',@=&AI<R!D871E('1O(%540R!A;F0@
M<V5T<R!T:&ES(&1A=&4G<R!T:6UE>F]N92!T;R!55$,*("`@("`J"B`@("`@
M*B!#;VYV97)T<R!T:&ES(&1A=&4@=&\@551#(&%N9"!S971S('1H:7,@9&%T
M92=S('1I;65Z;VYE('1O(%540PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O551#*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/G1Z+3YG971/9F9S970H)'1H:7,I(#X@,"D@>PH@("`@
M("`@("`@("`D=&AI<RT^<W5B=')A8W1396-O;F1S*&EN='9A;"@D=&AI<RT^
M='HM/F=E=$]F9G-E="@D=&AI<RD@+R`Q,#`P*2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/F%D9%-E8V]N9',H:6YT=F%L*&%B<R@D
M=&AI<RT^='HM/F=E=$]F9G-E="@D=&AI<RDI("\@,3`P,"DI.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^='H@/2!N97<@1&%T95]4:6UE6F]N92@G551#
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A=&4@
M=&\@82!N97<@=&EM92!Z;VYE"B`@("`@*@H@("`@("H@0V]N=F5R=',@=&AI
M<R!D871E('1O(&$@;F5W('1I;64@>F]N92X*("`@("`J(%=!4DY)3D<Z(%1H
M:7,@;6%Y(&YO="!W;W)K(&-O<G)E8W1L>2!I9B!Y;W5R('-Y<W1E;2!D;V5S
M(&YO="!A;&QO=PH@("`@("H@<'5T96YV*"D@;W(@:68@;&]C86QT:6UE*"D@
M9&]E<R!N;W0@=V]R:R!I;B!Y;W5R(&5N=FER;VYM96YT+B`@4V5E"B`@("`@
M*B!$871E.CI4:6UE6F]N93HZ:6Y$87EL:6=H=%1I;64H*2!F;W(@;6]R92!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'!A<F%M(&]B:F5C="!$871E7U1I;65:;VYE("1T>B!T:&4@1&%T93HZ
M5&EM95IO;F4@;V)J96-T(&9O<B!T:&4@8V]N=F5R<VEO;B!T:6UE('IO;F4*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=%1:*"1T>BD*("`@('L*("`@
M("`@("`O+R!C;VYV97)T('1O(%540PH@("`@("`@(&EF("@D=&AI<RT^='HM
M/F=E=$]F9G-E="@D=&AI<RD@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3YS
M=6)T<F%C=%-E8V]N9',H:6YT=F%L*&%B<R@D=&AI<RT^='HM/F=E=$]F9G-E
M="@D=&AI<RDI("\@,3`P,"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YA9&1396-O;F1S*&EN='9A;"AA8G,H)'1H:7,M/G1Z+3YG
M971/9F9S970H)'1H:7,I*2`O(#$P,#`I*3L*("`@("`@("!]"B`@("`@("`@
M+R\@8V]N=F5R="!55$,@=&\@;F5W('1I;65Z;VYE"B`@("`@("`@:68@*"1T
M>BT^9V5T3V9F<V5T*"1T:&ES*2`^(#`I('L*("`@("`@("`@("`@)'1H:7,M
M/F%D9%-E8V]N9',H:6YT=F%L*&%B<R@D='HM/F=E=$]F9G-E="@D=&AI<RDI
M("\@,3`P,"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YS=6)T<F%C=%-E8V]N9',H:6YT=F%L*&%B<R@D='HM/F=E=$]F9G-E="@D
M=&AI<RDI("\@,3`P,"DI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^='H@
M/2`D='H["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A
M=&4@=&\@82!N97<@=&EM92!Z;VYE+"!G:79E;B!A('9A;&ED('1I;64@>F]N
M92!)1`H@("`@("H*("`@("`J($-O;G9E<G1S('1H:7,@9&%T92!T;R!A(&YE
M=R!T:6UE('IO;F4L(&=I=F5N(&$@=F%L:60@=&EM92!Z;VYE($E$"B`@("`@
M*B!705).24Y'.B!4:&ES(&UA>2!N;W0@=V]R:R!C;W)R96-T;'D@:68@>6]U
M<B!S>7-T96T@9&]E<R!N;W0@86QL;W<*("`@("`J('!U=&5N=B@I(&]R(&EF
M(&QO8V%L=&EM92@I(&1O97,@;F]T('=O<FL@:6X@>6]U<B!E;G9I<F]N;65N
M="X@(%-E90H@("`@("H@1&%T93HZ5&EM95IO;F4Z.FEN1&%Y;&EG:'14:6UE
M*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!P87)A;2!S=')I;F<@:60@82!T:6UE('IO;F4@
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=%1:8GE)1"@D:60I"B`@
M("!["B`@("`@("!I9B`H1&%T95]4:6UE6F]N93HZ:7-686QI9$E$*"1I9"DI
M('L*("`@("`@("`@("1T>B`](&YE=R!$871E7U1I;65:;VYE*"1I9"D["B`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@)'1Z(#T@1&%T95]4:6UE6F]N93HZ
M9V5T1&5F875L="@I.PH@("`@("`@?0H@("`@("`@)'1H:7,M/F-O;G9E<G14
M6B@D='HI.PH@("`@?0H*("`@(&9U;F-T:6]N('1O551#8GE/9F9S970H)&]F
M9G-E="D*("`@('L*("`@("`@("!I9B`H)&]F9G-E="`]/2`B6B(@?'P@)&]F
M9G-E="`]/2`B*S`P.C`P(B!\?"`D;V9F<V5T(#T]("(K,#`P,"(I('L*("`@
M("`@("`@("`@)'1H:7,M/G1O551#*"D["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H6UPK
M7"U=*2A<9'LR?2DZ/RA<9'LR?2DO)RP@)&]F9G-E="P@)')E9W,I*2!["B`@
M("`@("`@("`@("\O(&-O;G9E<G0@;V9F<V5T('1O('-E8V]N9',*("`@("`@
M("`@("`@)&AO=7)S("`]("AI;G0I(&ES<V5T*"1R96=S6S)=*3\D<F5G<ULR
M73HP.PH@("`@("`@("`@("`D;6EN<R`@(#T@*&EN="D@:7-S970H)')E9W-;
M,UTI/R1R96=S6S-=.C`["B`@("`@("`@("`@("1O9F9S970@/2`H)&AO=7)S
M("H@,S8P,"D@*R`H)&UI;G,@*B`V,"D["@H@("`@("`@("`@("!I9B`H:7-S
M970H)')E9W-;,5TI("8F("1R96=S6S%=(#T]("(M(BD@>PH@("`@("`@("`@
M("`@("`@)&]F9G-E="`J/2`M,3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"1O9F9S970@/B`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<W5B=')A8W1396-O;F1S*&EN='9A;"@D;V9F<V5T*2D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^861D4V5C;VYD<RAI
M;G1V86PH86)S*"1O9F9S970I*2D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3YT>B`](&YE=R!$871E7U1I;65:;VYE*"=55$,G*3L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@9VEV96X@
M;G5M8F5R(&]F('-E8V]N9',@=&\@=&AE(&1A=&4*("`@("`J"B`@("`@*B!!
M9&1S(&$@9VEV96X@;G5M8F5R(&]F('-E8V]N9',@=&\@=&AE(&1A=&4*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D
M<V5C('1H92!N=6UB97(@;V8@<V5C;VYD<R!T;R!A9&0*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D4V5C;VYD<R@D<V5C*0H@("`@>PH@("`@("`@("1T:&ES
M+3YA9&13<&%N*&YE=R!$871E7U-P86XH*&EN=&5G97(I)'-E8RDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!A('1I;64@<W!A;B!T;R!T:&4@9&%T
M90H@("`@("H*("`@("`J($%D9',@82!T:6UE('-P86X@=&\@=&AE(&1A=&4*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B
M:F5C="!$871E7U-P86X@)'-P86X@=&AE('1I;64@<W!A;B!T;R!A9&0*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D4W!A;B@D<W!A;BD*("`@('L*("`@("`@
M("!I9B`H(6ES7V$H)'-P86XL("=$871E7U-P86XG*2D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^<V5C;VYD("L]
M("1S<&%N+3YS96-O;F0["B`@("`@("`@:68@*"1T:&ES+3YS96-O;F0@/CT@
M-C`I('L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T92LK.PH@("`@("`@("`@
M("`D=&AI<RT^<V5C;VYD("T](#8P.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/FUI;G5T92`K/2`D<W!A;BT^;6EN=71E.PH@("`@("`@(&EF("@D=&AI
M<RT^;6EN=71E(#X](#8P*2!["B`@("`@("`@("`@("1T:&ES+3YH;W5R*RL[
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^:&]U<B`^/2`R-"D@>PH@("`@("`@
M("`@("`@("`@;&ES="@D=&AI<RT^>65A<BP@)'1H:7,M/FUO;G1H+"`D=&AI
M<RT^9&%Y*2`]"B`@("`@("`@("`@("`@("`@("`@<W-C86YF*$1A=&5?0V%L
M8SHZ;F5X=$1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY
M96%R*2P@(B4P-',E,#)S)3`R<R(I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FAO=7(@+3T@,C0["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/FUI;G5T92`M/2`V,#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YH;W5R
M("L]("1S<&%N+3YH;W5R.PH@("`@("`@(&EF("@D=&AI<RT^:&]U<B`^/2`R
M-"D@>PH@("`@("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N
M=&@L("1T:&ES+3YD87DI(#T*("`@("`@("`@("`@("`@('-S8V%N9BA$871E
M7T-A;&,Z.FYE>'1$87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI
M<RT^>65A<BDL("(E,#1S)3`R<R4P,G,B*3L*("`@("`@("`@("`@)'1H:7,M
M/FAO=7(@+3T@,C0["B`@("`@("`@?0H*("`@("`@("`D9"`]($1A=&5?0V%L
M8SHZ9&%T951O1&%Y<R@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES
M+3YY96%R*3L*("`@("`@("`D9"`K/2`D<W!A;BT^9&%Y.PH*("`@("`@("!L
M:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*
M("`@("`@("`@("`@<W-C86YF*$1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9"DL
M("(E,#1S)3`R<R4P,G,B*3L*("`@("`@("`D=&AI<RT^>65A<B`@/2!I;G1V
M86PH)'1H:7,M/GEE87(I.PH@("`@("`@("1T:&ES+3YM;VYT:"`](&EN='9A
M;"@D=&AI<RT^;6]N=&@I.PH@("`@("`@("1T:&ES+3YD87D@("`](&EN='9A
M;"@D=&AI<RT^9&%Y*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-U8G1R86-T
M<R!A(&=I=F5N(&YU;6)E<B!O9B!S96-O;F1S(&9R;VT@=&AE(&1A=&4*("`@
M("`J"B`@("`@*B!3=6)T<F%C=',@82!G:79E;B!N=6UB97(@;V8@<V5C;VYD
M<R!F<F]M('1H92!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!P87)A;2!I;G0@)'-E8R!T:&4@;G5M8F5R(&]F('-E8V]N9',@
M=&\@<W5B=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<W5B=')A8W1396-O
M;F1S*"1S96,I"B`@("!["B`@("`@("`@)'1H:7,M/G-U8G1R86-T4W!A;BAN
M97<@1&%T95]3<&%N*"1S96,I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-U
M8G1R86-T<R!A('1I;64@<W!A;B!T;R!T:&4@9&%T90H@("`@("H*("`@("`J
M(%-U8G1R86-T<R!A('1I;64@<W!A;B!T;R!T:&4@9&%T90H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&5?
M4W!A;B`D<W!A;B!T:&4@=&EM92!S<&%N('1O('-U8G1R86-T"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-U8G1R86-T4W!A;B@D<W!A;BD*("`@('L*("`@("`@
M("!I9B`H(6ES7V$H)'-P86XL("=$871E7U-P86XG*2D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H@("`@("`@(&EF("@D<W!A;BT^:7-%;7!T
M>2@I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3YS96-O;F0@+3T@)'-P86XM/G-E8V]N9#L*("`@("`@("!I9B`H
M)'1H:7,M/G-E8V]N9"`\(#`I('L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T
M92TM.PH@("`@("`@("`@("`D=&AI<RT^<V5C;VYD("L](#8P.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/FUI;G5T92`M/2`D<W!A;BT^;6EN=71E.PH@
M("`@("`@(&EF("@D=&AI<RT^;6EN=71E(#P@,"D@>PH@("`@("`@("`@("`D
M=&AI<RT^:&]U<BTM.PH@("`@("`@("`@("!I9B`H)'1H:7,M/FAO=7(@/"`P
M*2!["B`@("`@("`@("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^
M;6]N=&@L("1T:&ES+3YD87DI(#T*("`@("`@("`@("`@("`@("`@("!S<V-A
M;F8H1&%T95]#86QC.CIP<F5V1&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT
M:"P@)'1H:7,M/GEE87(I+"`B)3`T<R4P,G,E,#)S(BD["B`@("`@("`@("`@
M("`@("`D=&AI<RT^:&]U<B`K/2`R-#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^;6EN=71E("L](#8P.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/FAO=7(@+3T@)'-P86XM/FAO=7(["B`@("`@("`@:68@*"1T:&ES
M+3YH;W5R(#P@,"D@>PH@("`@("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D
M=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*("`@("`@("`@("`@("`@('-S
M8V%N9BA$871E7T-A;&,Z.G!R979$87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO
M;G1H+"`D=&AI<RT^>65A<BDL("(E,#1S)3`R<R4P,G,B*3L*("`@("`@("`@
M("`@)'1H:7,M/FAO=7(@*ST@,C0["B`@("`@("`@?0H*("`@("`@("`D9"`]
M($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N
M=&@L("1T:&ES+3YY96%R*3L*("`@("`@("`D9"`M/2`D<W!A;BT^9&%Y.PH*
M("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES
M+3YD87DI(#T*("`@("`@("`@("`@<W-C86YF*$1A=&5?0V%L8SHZ9&%Y<U1O
M1&%T92@D9"DL("(E,#1S)3`R<R4P,G,B*3L*("`@("`@("`D=&AI<RT^>65A
M<B`@/2!I;G1V86PH)'1H:7,M/GEE87(I.PH@("`@("`@("1T:&ES+3YM;VYT
M:"`](&EN='9A;"@D=&AI<RT^;6]N=&@I.PH@("`@("`@("1T:&ES+3YD87D@
M("`](&EN='9A;"@D=&AI<RT^9&%Y*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-O;7!A<F5S('1W;R!D871E<PH@("`@("H*("`@("`J($-O;7!A<F5S('1W
M;R!D871E<RX@(%-U:71A8FQE(&9O<B!U<V4*("`@("`J(&EN('-O<G1I;F<@
M9G5N8W1I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@;V)J96-T($1A=&4@)&0Q('1H92!F:7)S="!D871E"B`@("`@
M*B!`<&%R86T@;V)J96-T($1A=&4@)&0R('1H92!S96-O;F0@9&%T90H@("`@
M("H@0')E='5R;B!I;G0@,"!I9B!T:&4@9&%T97,@87)E(&5Q=6%L+"`M,2!I
M9B!D,2!I<R!B969O<F4@9#(L(#$@:68@9#$@:7,@869T97(@9#(*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]M<&%R92@D9#$L("1D,BD*("`@('L*("`@("`@
M("`D9#$M/F-O;G9E<G146BAN97<@1&%T95]4:6UE6F]N92@G551#)RDI.PH@
M("`@("`@("1D,BT^8V]N=F5R=%1:*&YE=R!$871E7U1I;65:;VYE*"=55$,G
M*2D["B`@("`@("`@)&1A>7,Q(#T@1&%T95]#86QC.CID871E5&]$87ES*"1D
M,2T^9&%Y+"`D9#$M/FUO;G1H+"`D9#$M/GEE87(I.PH@("`@("`@("1D87ES
M,B`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9#(M/F1A>2P@)&0R+3YM;VYT
M:"P@)&0R+3YY96%R*3L*("`@("`@("!I9B`H)&1A>7,Q(#P@)&1A>7,R*2!R
M971U<FX@+3$["B`@("`@("`@:68@*"1D87ES,2`^("1D87ES,BD@<F5T=7)N
M(#$["B`@("`@("`@:68@*"1D,2T^:&]U<B`\("1D,BT^:&]U<BD@<F5T=7)N
M("TQ.PH@("`@("`@(&EF("@D9#$M/FAO=7(@/B`D9#(M/FAO=7(I(')E='5R
M;B`Q.PH@("`@("`@(&EF("@D9#$M/FUI;G5T92`\("1D,BT^;6EN=71E*2!R
M971U<FX@+3$["B`@("`@("`@:68@*"1D,2T^;6EN=71E(#X@)&0R+3YM:6YU
M=&4I(')E='5R;B`Q.PH@("`@("`@(&EF("@D9#$M/G-E8V]N9"`\("1D,BT^
M<V5C;VYD*2!R971U<FX@+3$["B`@("`@("`@:68@*"1D,2T^<V5C;VYD(#X@
M)&0R+3YS96-O;F0I(')E='5R;B`Q.PH@("`@("`@(')E='5R;B`P.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&5S="!I9B!T:&ES(&1A=&4O=&EM92!I<R!B
M969O<F4@82!C97)T86EN(&1A=&4O=&EM90H@("`@("H*("`@("`J(%1E<W0@
M:68@=&AI<R!D871E+W1I;64@:7,@8F5F;W)E(&$@8V5R=&%I;B!D871E+W1I
M;64*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M(&]B:F5C="!$871E("1W:&5N('1H92!D871E('1O('1E<W0@86=A:6YS=`H@
M("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AI<R!D871E(&ES(&)E
M9F]R92`D=VAE;@H@("`@("HO"B`@("!F=6YC=&EO;B!B969O<F4H)'=H96XI
M"B`@("!["B`@("`@("`@:68@*$1A=&4Z.F-O;7!A<F4H)'1H:7,L)'=H96XI
M(#T]("TQ*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!497-T(&EF('1H:7,@9&%T92]T:6UE(&ES
M(&%F=&5R(&$@8V5R=&EA;B!D871E+W1I;64*("`@("`J"B`@("`@*B!497-T
M(&EF('1H:7,@9&%T92]T:6UE(&ES(&%F=&5R(&$@8V5R=&EA;B!D871E+W1I
M;64*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M(&]B:F5C="!$871E("1W:&5N('1H92!D871E('1O('1E<W0@86=A:6YS=`H@
M("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AI<R!D871E(&ES(&%F
M=&5R("1W:&5N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F=&5R*"1W:&5N*0H@
M("`@>PH@("`@("`@(&EF("A$871E.CIC;VUP87)E*"1T:&ES+"1W:&5N*2`]
M/2`Q*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!497-T(&EF('1H:7,@9&%T92]T:6UE(&ES(&5X
M86-T;'D@97%U86P@=&\@82!C97)T:6%N(&1A=&4O=&EM90H@("`@("H*("`@
M("`J(%1E<W0@:68@=&AI<R!D871E+W1I;64@:7,@97AA8W1L>2!E<75A;"!T
M;R!A(&-E<G1I86X@9&%T92]T:6UE"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@1&%T92`D=VAE;B!T:&4@9&%T
M92!T;R!T97-T(&%G86EN<W0*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E
M(&EF('1H:7,@9&%T92!I<R!E>&%C=&QY(&5Q=6%L('1O("1W:&5N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5Q=6%L<R@D=VAE;BD*("`@('L*("`@("`@("!I
M9B`H1&%T93HZ8V]M<&%R92@D=&AI<RPD=VAE;BD@/3T@,"D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1&5T97)M:6YE(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@9G5T=7)E"B`@
M("`@*@H@("`@("H@1&5T97)M:6YE(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@
M9G5T=7)E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R
M971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@9G5T
M=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1G5T=7)E*"D*("`@('L*("`@
M("`@("`D;F]W(#T@;F5W($1A=&4H*3L*("`@("`@("!I9B`H)'1H:7,M/F%F
M=&5R*"1N;W<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@:68@=&AI<R!D871E
M(&ES(&EN('1H92!P87-T"B`@("`@*@H@("`@("H@1&5T97)M:6YE(&EF('1H
M:7,@9&%T92!I<R!I;B!T:&4@<&%S=`H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!I9B!T:&ES(&1A
M=&4@:7,@:6X@=&AE('!A<W0*("`@("`J+PH@("`@9G5N8W1I;VX@:7-087-T
M*"D*("`@('L*("`@("`@("`D;F]W(#T@;F5W($1A=&4H*3L*("`@("`@("!I
M9B`H)'1H:7,M/F)E9F]R92@D;F]W*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE
M(&EF('1H92!Y96%R(&EN('1H:7,@9&%T92!I<R!A(&QE87`@>65A<@H@("`@
M("H*("`@("`J($1E=&5R;6EN92!I9B!T:&4@>65A<B!I;B!T:&ES(&1A=&4@
M:7,@82!L96%P('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AI<R!Y96%R(&ES(&$@
M;&5A<"!Y96%R"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3&5A<%EE87(H*0H@
M("`@>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.FES3&5A<%EE87(H)'1H
M:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!*=6QI
M86X@9&%T92!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@1V5T('1H92!*
M=6QI86X@9&%T92!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!*=6QI86X@9&%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971*=6QI86Y$871E*"D*("`@('L*("`@
M("`@("!R971U<FX@1&%T95]#86QC.CIJ=6QI86Y$871E*"1T:&ES+3YD87DL
M("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T<R!T:&4@9&%Y(&]F('1H92!W965K(&9O<B!T:&ES(&1A=&4*
M("`@("`J"B`@("`@*B!'971S('1H92!D87D@;V8@=&AE('=E96L@9F]R('1H
M:7,@9&%T92`H,#U3=6YD87DI"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!R971U<FX@:6YT('1H92!D87D@;V8@=&AE('=E96L@*#`]
M4W5N9&%Y*0H@("`@("HO"B`@("!F=6YC=&EO;B!G971$87E/9E=E96LH*0H@
M("`@>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A>4]F5V5E:R@D=&AI
M<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE('=E96L@;V8@=&AE('EE87(@9F]R('1H
M:7,@9&%T90H@("`@("H*("`@("`J($=E=',@=&AE('=E96L@;V8@=&AE('EE
M87(@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@=V5E:R!O9B!T:&4@>65A<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9717965K3V9996%R*"D*("`@('L*("`@("`@
M("!R971U<FX@1&%T95]#86QC.CIW965K3V9996%R*"1T:&ES+3YD87DL("1T
M:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T<R!T:&4@<75A<G1E<B!O9B!T:&4@>65A<B!F;W(@=&AI<R!D871E
M"B`@("`@*@H@("`@("H@1V5T<R!T:&4@<75A<G1E<B!O9B!T:&4@>65A<B!F
M;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!R971U<FX@:6YT('1H92!Q=6%R=&5R(&]F('1H92!Y96%R("@Q+30I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U87)T97)/9EEE87(H*0H@("`@
M>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.G%U87)T97)/9EEE87(H)'1H
M:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'971S(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@1V5T<R!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&ES(&UO;G1H"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A
M>7-);DUO;G1H*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#86QC.CID
M87ES26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!W965K<R!I;B!T
M:&4@;6]N=&@@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($=E=',@=&AE
M(&YU;6)E<B!O9B!W965K<R!I;B!T:&4@;6]N=&@@9F]R('1H:7,@9&%T90H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN
M="!N=6UB97(@;V8@=V5E:W,@:6X@=&AI<R!M;VYT:`H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9717965K<TEN36]N=&@H*0H@("`@>PH@("`@("`@(')E='5R
M;B!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T:&ES
M+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&9U;&P@
M;F%M92!O<B!A8F)R:79I871E9"!N86UE(&]F('1H:7,@=V5E:V1A>0H@("`@
M("H*("`@("`J($=E=',@=&AE(&9U;&P@;F%M92!O<B!A8F)R:79I871E9"!N
M86UE(&]F('1H:7,@=V5E:V1A>0H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86)B<B!A8F)R:79A=&4@=&AE
M(&YA;64*("`@("`J($!R971U<FX@<W1R:6YG(&YA;64@;V8@=&AI<R!D87D*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%Y3F%M92@D86)B<B`](&9A;'-E
M+"`D;&5N9W1H(#T@,RD*("`@('L*("`@("`@("!I9B`H)&%B8G(I('L*("`@
M("`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE
M*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(L("1L96YG
M=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!$871E
M7T-A;&,Z.F=E=%=E96MD87E&=6QL;F%M92@D=&AI<RT^9&%Y+"`D=&AI<RT^
M;6]N=&@L("1T:&ES+3YY96%R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!F=6QL(&YA;64@;W(@86)B<FEV:6%T960@;F%M
M92!O9B!T:&ES(&UO;G1H"B`@("`@*@H@("`@("H@1V5T<R!T:&4@9G5L;"!N
M86UE(&]R(&%B8G)I=FEA=&5D(&YA;64@;V8@=&AI<R!M;VYT:`H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M86)B<B!A8F)R:79A=&4@=&AE(&YA;64*("`@("`J($!R971U<FX@<W1R:6YG
M(&YA;64@;V8@=&AI<R!M;VYT:`H@("`@("HO"B`@("!F=6YC=&EO;B!G971-
M;VYT:$YA;64H)&%B8G(@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&%B
M8G(I('L*("`@("`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9V5T36]N=&A!
M8F)R;F%M92@D=&AI<RT^;6]N=&@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H)'1H
M:7,M/FUO;G1H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@82!$871E(&]B:F5C="!F;W(@=&AE(&1A>2!A9G1E<B!T:&ES(&]N90H@
M("`@("H*("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O<B!T:&4@9&%Y(&%F
M=&5R('1H:7,@;VYE+@H@("`@("H@5&AE('1I;64@;V8@=&AE(')E='5R;F5D
M($1A=&4@;V)J96-T(&ES('1H92!S86UE(&%S('1H:7,@=&EM92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!O8FIE8W0@
M1&%T92!$871E(')E<')E<V5N=&EN9R!T:&4@;F5X="!D87D*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T3F5X=$1A>2@I"B`@("!["B`@("`@("`@)&1A>2`]
M($1A=&5?0V%L8SHZ;F5X=$1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L
M("1T:&ES+3YY96%R+"`B)5DM)6TM)60B*3L*("`@("`@("`D9&%T92`]('-P
M<FEN=&8H(B5S("4P,F0Z)3`R9#HE,#)D(BP@)&1A>2P@)'1H:7,M/FAO=7(L
M("1T:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0I.PH@("`@("`@("1N97=$
M871E(#T@;F5W($1A=&4H*3L*("`@("`@("`D;F5W1&%T92T^<V5T1&%T92@D
M9&%T92D["B`@("`@("`@<F5T=7)N("1N97=$871E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R('1H92!D87D@8F5F;W)E
M('1H:7,@;VYE"B`@("`@*@H@("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R
M('1H92!D87D@8F5F;W)E('1H:7,@;VYE+@H@("`@("H@5&AE('1I;64@;V8@
M=&AE(')E='5R;F5D($1A=&4@;V)J96-T(&ES('1H92!S86UE(&%S('1H:7,@
M=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E
M='5R;B!O8FIE8W0@1&%T92!$871E(')E<')E<V5N=&EN9R!T:&4@<')E=FEO
M=7,@9&%Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R979$87DH*0H@("`@
M>PH@("`@("`@("1D87D@/2!$871E7T-A;&,Z.G!R979$87DH)'1H:7,M/F1A
M>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BP@(B59+25M+25D(BD["B`@
M("`@("`@)&1A=&4@/2!S<')I;G1F*"(E<R`E,#)D.B4P,F0Z)3`R9"(L("1D
M87DL("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD
M*3L*("`@("`@("`D;F5W1&%T92`](&YE=R!$871E*"D["B`@("`@("`@)&YE
M=T1A=&4M/G-E=$1A=&4H)&1A=&4I.PH@("`@("`@(')E='5R;B`D;F5W1&%T
M93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O
M<B!T:&4@=V5E:V1A>2!A9G1E<B!T:&ES(&]N90H@("`@("H*("`@("`J($=E
M="!A($1A=&4@;V)J96-T(&9O<B!T:&4@=V5E:V1A>2!A9G1E<B!T:&ES(&]N
M92X*("`@("`J(%1H92!T:6UE(&]F('1H92!R971U<FYE9"!$871E(&]B:F5C
M="!I<R!T:&4@<V%M92!A<R!T:&ES('1I;64N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;V)J96-T($1A=&4@1&%T92!R
M97!R97-E;G1I;F<@=&AE(&YE>'0@=V5E:V1A>0H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971.97AT5V5E:V1A>2@I"B`@("!["B`@("`@("`@)&1A>2`]($1A
M=&5?0V%L8SHZ;F5X=%=E96MD87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H
M+"`D=&AI<RT^>65A<BP@(B59+25M+25D(BD["B`@("`@("`@)&1A=&4@/2!S
M<')I;G1F*"(E<R`E,#)D.B4P,F0Z)3`R9"(L("1D87DL("1T:&ES+3YH;W5R
M+"`D=&AI<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD*3L*("`@("`@("`D;F5W
M1&%T92`](&YE=R!$871E*"D["B`@("`@("`@)&YE=T1A=&4M/G-E=$1A=&4H
M)&1A=&4I.PH@("`@("`@(')E='5R;B`D;F5W1&%T93L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O<B!T:&4@=V5E:V1A>2!B
M969O<F4@=&AI<R!O;F4*("`@("`J"B`@("`@*B!'970@82!$871E(&]B:F5C
M="!F;W(@=&AE('=E96MD87D@8F5F;W)E('1H:7,@;VYE+@H@("`@("H@5&AE
M('1I;64@;V8@=&AE(')E='5R;F5D($1A=&4@;V)J96-T(&ES('1H92!S86UE
M(&%S('1H:7,@=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B!O8FIE8W0@1&%T92!$871E(')E<')E<V5N=&EN9R!T
M:&4@<')E=FEO=7,@=V5E:V1A>0H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M<F5V5V5E:V1A>2@I"B`@("!["B`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ
M<')E=E=E96MD87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^
M>65A<BP@(B59+25M+25D(BD["B`@("`@("`@)&1A=&4@/2!S<')I;G1F*"(E
M<R`E,#)D.B4P,F0Z)3`R9"(L("1D87DL("1T:&ES+3YH;W5R+"`D=&AI<RT^
M;6EN=71E+"`D=&AI<RT^<V5C;VYD*3L*("`@("`@("`D;F5W1&%T92`](&YE
M=R!$871E*"D["B`@("`@("`@)&YE=T1A=&4M/G-E=$1A=&4H)&1A=&4I.PH@
M("`@("`@(')E='5R;B`D;F5W1&%T93L*("`@('T*"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!Y96%R(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@
M("`@("H*("`@("`J(%)E='5R;G,@=&AE('EE87(@9FEE;&0@;V8@=&AE(&1A
M=&4@;V)J96-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@:6YT('1H92!Y96%R"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%EE87(H*0H@("`@>PH@("`@("`@(')E='5R;B`H:6YT*21T:&ES+3YY96%R
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;6]N=&@@9FEE
M;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@4F5T=7)N<R!T
M:&4@;6]N=&@@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!M;VYT
M:`H@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:"@I"B`@("!["B`@("`@
M("`@<F5T=7)N("AI;G0I)'1H:7,M/FUO;G1H.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@9&%Y(&9I96QD(&]F('1H92!D871E(&]B:F5C
M=`H@("`@("H*("`@("`J(%)E='5R;G,@=&AE(&1A>2!F:65L9"!O9B!T:&4@
M9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0')E='5R;B!I;G0@=&AE(&1A>0H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971$87DH*0H@("`@>PH@("`@("`@(')E='5R;B`H:6YT*21T:&ES+3YD87D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!H;W5R(&9I96QD
M(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%)E='5R;G,@=&AE
M(&AO=7(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!H;W5R"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$AO=7(H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^:&]U<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&UI;G5T92!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J
M"B`@("`@*B!2971U<FYS('1H92!M:6YU=&4@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R
M971U<FX@:6YT('1H92!M:6YU=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M36EN=71E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FUI;G5T93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-E8V]N9"!F:65L
M9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!2971U<FYS('1H
M92!S96-O;F0@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!S96-O
M;F0*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5C;VYD*"D*("`@('L*("`@
M("`@("`@<F5T=7)N("1T:&ES+3YS96-O;F0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE('EE87(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@
M("`@*@H@("`@("H@4V5T('1H92!Y96%R(&9I96QD(&]F('1H92!D871E(&]B
M:F5C="P@:6YV86QI9"!Y96%R<R`H;F]T(#`M.3DY.2D@87)E('-E="!T;R`P
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@
M:6YT("1Y('1H92!Y96%R"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%EE87(H
M)'DI"B`@("!["B`@("`@("`@:68@*"1Y(#P@,"!\?"`D>2`^(#DY.3DI('L*
M("`@("`@("`@("`@)'1H:7,M/GEE87(@/2`P.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YY96%R(#T@)'D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('1H92!M;VYT:"!F:65L9"!O9B!T:&4@
M9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3970@=&AE(&UO;G1H(&9I96QD
M(&]F('1H92!D871E(&]B:F5C="P@:6YV86QI9"!M;VYT:',@*&YO="`Q+3$R
M*2!A<F4@<V5T('1O(#$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!P87)A;2!I;G0@)&T@=&AE(&UO;G1H"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$UO;G1H*"1M*0H@("`@>PH@("`@("`@(&EF("@D;2`\(#$@
M?'P@)&T@/B`Q,BD@>PH@("`@("`@("`@("`D=&AI<RT^;6]N=&@@/2`Q.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YM;VYT:"`]("1M
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&%Y
M(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%-E="!T
M:&4@9&%Y(&9I96QD(&]F('1H92!D871E(&]B:F5C="P@:6YV86QI9"!D87ES
M("AN;W0@,2TS,2D@87)E('-E="!T;R`Q+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT("1D('1H92!D87D*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T1&%Y*"1D*0H@("`@>PH@("`@("`@(&EF("@D
M9"`^(#,Q('Q\("1D(#P@,2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%Y(#T@
M,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&%Y(#T@
M)&0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!H
M;W5R(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%-E
M="!T:&4@:&]U<B!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0@:6X@,C0M:&]U
M<B!F;W)M870N"B`@("`@*B!);G9A;&ED(&AO=7)S("AN;W0@,"TR,RD@87)E
M('-E="!T;R`P+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@:6YT("1H('1H92!H;W5R"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$AO=7(H)&@I"B`@("!["B`@("`@("`@:68@*"1H(#X@,C,@?'P@)&@@
M/"`P*2!["B`@("`@("`@("`@("1T:&ES+3YH;W5R(#T@,#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^:&]U<B`]("1H.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@;6EN=71E(&9I96QD
M(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%-E="!T:&4@;6EN
M=71E(&9I96QD(&]F('1H92!D871E(&]B:F5C="P@:6YV86QI9"!M:6YU=&5S
M("AN;W0@,"TU.2D@87)E('-E="!T;R`P+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT("1M('1H92!M:6YU=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T36EN=71E*"1M*0H@("`@>PH@("`@("`@
M(&EF("@D;2`^(#4Y('Q\("1M(#P@,"D@>PH@("`@("`@("`@("`D=&AI<RT^
M;6EN=71E(#T@,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^;6EN=71E(#T@)&T["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T('1H92!S96-O;F0@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@
M("`@*@H@("`@("H@4V5T('1H92!S96-O;F0@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T+"!I;G9A;&ED('-E8V]N9',@*&YO="`P+34Y*2!A<F4@<V5T('1O
M(#`N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A
M;2!I;G0@)',@=&AE('-E8V]N9`H@("`@("HO"B`@("!F=6YC=&EO;B!S9713
M96-O;F0H)',I('L*("`@("`@("!I9B`H)',@/B`U.2!\?"`D<R`\(#`I('L*
M("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`](#`["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`]("1S.PH@("`@("`@('T*
M("`@('T*?0H*/SX*+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(
M4%5N:70N<&AP````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$P,#$P`#$P-3$U-#,Q,#4W`#`Q-S,S,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*B!V:6TZ('-E
M="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O
M<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P>7)I9VAT
M("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T
M:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*
M("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R
M>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E
M('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET
M:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F
M('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0*
M("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J("`@("!T
M:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I
M9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.
M96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE
M(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D
M('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`J("`@
M("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W
M<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/
M5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/
M4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)2
M04Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%1"!43RP@5$A%
M($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)
M5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)
M345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4($]73D52
M($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.
M1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2
M($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4
M($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@
M3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513
M.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@0T%54T5$
M($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#
M3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)
M3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*("H@04Y9
M(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&
M($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%
M+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(
M4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S
M96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P
M-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!02%!5;FET+G!H<"QV(#$N,3<@,C`P-2\Q,2\Q
M,"`P.3HT-SHQ,2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*"G)E
M<75I<F5?;VYC92`G4$A056YI="]497-T0V%S92YP:'`G.PIR97%U:7)E7V]N
M8V4@)U!(4%5N:70O5&5S=%)E<W5L="YP:'`G.PIR97%U:7)E7V]N8V4@)U!(
M4%5N:70O5&5S=%-U:71E+G!H<"<["@HO*BH*("H@4$A056YI="!R=6YS(&$@
M5&5S=%-U:71E(&%N9"!R971U<FYS(&$@5&5S=%)E<W5L="!O8FIE8W0N"B`J
M"B`J($AE<F4@:7,@86X@97AA;7!L93H*("H*("H@/&-O9&4^"B`J(#P_<&AP
M"B`J(')E<75I<F5?;VYC92`G4$A056YI="YP:'`G.PH@*@H@*B!C;&%S<R!-
M871H5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A<V4@>PH@*B`@("`@=F%R
M("1F5F%L=64Q.PH@*B`@("`@=F%R("1F5F%L=64R.PH@*@H@*B`@("`@9G5N
M8W1I;VX@36%T:%1E<W0H)&YA;64I('L*("H@("`@("`@)'1H:7,M/E!(4%5N
M:71?5&5S=$-A<V4H)&YA;64I.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I
M;VX@<V5T57`H*2!["B`J("`@("`@("1T:&ES+3YF5F%L=64Q(#T@,CL*("H@
M("`@("`@)'1H:7,M/F9686QU93(@/2`S.PH@*B`@("`@?0H@*@H@*B`@("`@
M9G5N8W1I;VX@=&5S=$%D9"@I('L*("H@("`@("`@)'1H:7,M/F%S<V5R=%1R
M=64H)'1H:7,M/F9686QU93$@*R`D=&AI<RT^9E9A;'5E,B`]/2`U*3L*("H@
M("`@('T*("H@?0H@*@H@*B`D<W5I=&4@/2!N97<@4$A056YI=%]497-T4W5I
M=&4H*3L*("H@)'-U:71E+3YA9&1497-T*&YE=R!-871H5&5S="@G=&5S=$%D
M9"<I*3L*("H*("H@)')E<W5L="`](%!(4%5N:70Z.G)U;B@D<W5I=&4I.PH@
M*B!P<FEN="`D<F5S=6QT+3YT;TA434PH*3L*("H@/SX*("H@/"]C;V1E/@H@
M*@H@*B!!;'1E<FYA=&EV96QY+"!Y;W4@8V%N('!A<W,@82!C;&%S<R!N86UE
M('1O('1H92!02%!5;FET7U1E<W13=6ET92@I"B`J(&-O;G-T<G5C=&]R(&%N
M9"!L970@:70@875T;VUA=&EC86QL>2!A9&0@86QL(&UE=&AO9',@;V8@=&AA
M="!C;&%S<PH@*B!T:&%T('-T87)T('=I=&@@)W1E<W0G('1O('1H92!S=6ET
M93H*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J("1S=6ET92`@/2!N97<@4$A0
M56YI=%]497-T4W5I=&4H)TUA=&A497-T)RD["B`J("1R97-U;'0@/2!02%!5
M;FET.CIR=6XH)'-U:71E*3L*("H@<')I;G0@)')E<W5L="T^=&](5$U,*"D[
M"B`J(#\^"B`J(#PO8V]D93X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@
M*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA
M;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P
M>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A
M<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@
M3&EC96YS90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@
M*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C`N,`H@*B\*8VQA<W,@4$A056YI="!["B`@("`O*BH*("`@("`J(%)U;G,@
M82!T97-T*'-U:71E*2X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@
M("`@*B!`<F5T=7)N(%!(4%5N:71?5&5S=%)E<W5L=`H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)G)U;B@F)'-U:71E*2![
M"B`@("`@("`@)')E<W5L="`](&YE=R!02%!5;FET7U1E<W1297-U;'0H*3L*
M("`@("`@("`D<W5I=&4M/G)U;B@D<F5S=6QT*3L*"B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@
M=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN
M9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(N<&AP````````
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,30P
M,S$`,3`U,34T,S$P-3<`,#$V,S,W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*
M+RHJ"B`J($1A=&%B87-E(&EN9&5P96YD96YT('%U97)Y(&EN=&5R9F%C90H@
M*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S
M90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y
M("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@
M4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!4;VUA
M<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!$0BYP:'`L=B`Q+C@P(#(P
M,#4O,#(O,38@,#(Z,38Z,#`@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@
M3V)T86EN('1H92!014%2(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F
M<F]M"B`J+PIR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"@HO+R![>WL@8V]N
M<W1A;G1S"B\O('M[>R!E<G)O<B!C;V1E<PH*+RHJ(T`K"B`J($]N92!O9B!0
M14%2($1")W,@<&]R=&%B;&4@97)R;W(@8V]D97,N"B`J($!S964@1$)?8V]M
M;6]N.CIE<G)O<D-O9&4H*2P@1$(Z.F5R<F]R365S<V%G92@I"B`J"B`J('M`
M:6YT97)N86P@268@>6]U(&%D9"!A;B!E<G)O<B!C;V1E(&AE<F4L(&UA:V4@
M<W5R92!Y;W4@86QS;R!A9&0@82!T97AT=6%L"B`J('9E<G-I;VX@;V8@:70@
M:6X@1$(Z.F5R<F]R365S<V%G92@I+GU]"B`J+PH*+RHJ"B`J(%1H92!C;V1E
M(')E='5R;F5D(&)Y(&UA;GD@;65T:&]D<R!U<&]N('-U8V-E<W,*("HO"F1E
M9FEN92@G1$)?3TLG+"`Q*3L*"B\J*@H@*B!5;FMO=VX@97)R;W(*("HO"F1E
M9FEN92@G1$)?15)23U(G+"`M,2D["@HO*BH*("H@4WEN=&%X(&5R<F]R"B`J
M+PID969I;F4H)T1"7T524D]27U-93E1!6"<L("TR*3L*"B\J*@H@*B!4<FEE
M9"!T;R!I;G-E<G0@82!D=7!L:6-A=&4@=F%L=64@:6YT;R!A('!R:6UA<GD@
M;W(@=6YI<75E(&EN9&5X"B`J+PID969I;F4H)T1"7T524D]27T-/3E-44D%)
M3E0G+"`M,RD["@HO*BH*("H@06X@:61E;G1I9FEE<B!I;B!T:&4@<75E<GD@
M<F5F97)S('1O(&$@;F]N+65X:7-T86YT(&]B:F5C=`H@*B\*9&5F:6YE*"=$
M0E]%4E)/4E].3U1?1D]53D0G+"`M-"D["@HO*BH*("H@5')I960@=&\@8W)E
M871E(&$@9'5P;&EC871E(&]B:F5C=`H@*B\*9&5F:6YE*"=$0E]%4E)/4E]!
M3%)%04197T5825-44R<L("TU*3L*"B\J*@H@*B!4:&4@8W5R<F5N="!D<FEV
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&4@86-T:6]N('EO=2!A='1E;7!T960*
M("HO"F1E9FEN92@G1$)?15)23U)?54Y355!03U)4140G+"`M-BD["@HO*BH*
M("H@5&AE(&YU;6)E<B!O9B!P87)A;65T97)S(&1O97,@;F]T(&UA=&-H('1H
M92!N=6UB97(@;V8@<&QA8V5H;VQD97)S"B`J+PID969I;F4H)T1"7T524D]2
M7TU)4TU!5$-()RP@+3<I.PH*+RHJ"B`J($$@;&ET97)A;"!S=6)M:71T960@
M9&ED(&YO="!M871C:"!T:&4@9&%T82!T>7!E(&5X<&5C=&5D"B`J+PID969I
M;F4H)T1"7T524D]27TE.5D%,240G+"`M."D["@HO*BH*("H@5&AE(&-U<G)E
M;G0@1$)-4R!D;V5S(&YO="!S=7!P;W)T('1H92!A8W1I;VX@>6]U(&%T=&5M
M<'1E9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E].3U1?0T%004),12<L("TY*3L*
M"B\J*@H@*B!!(&QI=&5R86P@<W5B;6ET=&5D('=A<R!T;V\@;&]N9R!S;R!T
M:&4@96YD(&]F(&ET('=A<R!R96UO=F5D"B`J+PID969I;F4H)T1"7T524D]2
M7U1254Y#051%1"<L("TQ,"D["@HO*BH*("H@02!L:71E<F%L(&YU;6)E<B!S
M=6)M:71T960@9&ED(&YO="!M871C:"!T:&4@9&%T82!T>7!E(&5X<&5C=&5D
M"B`J+PID969I;F4H)T1"7T524D]27TE.5D%,241?3E5-0D52)RP@+3$Q*3L*
M"B\J*@H@*B!!(&QI=&5R86P@9&%T92!S=6)M:71T960@9&ED(&YO="!M871C
M:"!T:&4@9&%T82!T>7!E(&5X<&5C=&5D"B`J+PID969I;F4H)T1"7T524D]2
M7TE.5D%,241?1$%412<L("TQ,BD["@HO*BH*("H@071T96UP="!T;R!D:79I
M9&4@<V]M971H:6YG(&)Y('IE<F\*("HO"F1E9FEN92@G1$)?15)23U)?1$E6
M6D523R<L("TQ,RD["@HO*BH*("H@02!D871A8F%S92!N965D<R!T;R!B92!S
M96QE8W1E9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E].3T1"4T5,14-4140G+"`M
M,30I.PH*+RHJ"B`J($-O=6QD(&YO="!C<F5A=&4@=&AE(&]B:F5C="!R97%U
M97-T960*("HO"F1E9FEN92@G1$)?15)23U)?0T%.3D]47T-214%412<L("TQ
M-2D["@HO*BH*("H@0V]U;&0@;F]T(&1R;W`@=&AE(&1A=&%B87-E(')E<75E
M<W1E9"!B96-A=7-E(&ET(&1O97,@;F]T(&5X:7-T"B`J+PID969I;F4H)T1"
M7T524D]27T-!3DY/5%]$4D]0)RP@+3$W*3L*"B\J*@H@*B!!;B!I9&5N=&EF
M:65R(&EN('1H92!Q=65R>2!R969E<G,@=&\@82!N;VXM97AI<W1A;G0@=&%B
M;&4*("HO"F1E9FEN92@G1$)?15)23U)?3D]354-(5$%"3$4G+"`M,3@I.PH*
M+RHJ"B`J($%N(&ED96YT:69I97(@:6X@=&AE('%U97)Y(')E9F5R<R!T;R!A
M(&YO;BUE>&ES=&%N="!C;VQU;6X*("HO"F1E9FEN92@G1$)?15)23U)?3D]3
M54-(1DE%3$0G+"`M,3DI.PH*+RHJ"B`J(%1H92!D871A('-U8FUI='1E9"!T
M;R!T:&4@;65T:&]D('=A<R!I;F%P<')O<')I871E"B`J+PID969I;F4H)T1"
M7T524D]27TY%141?34]215]$051!)RP@+3(P*3L*"B\J*@H@*B!4:&4@871T
M96UP="!T;R!L;V-K('1H92!T86)L92!F86EL960*("HO"F1E9FEN92@G1$)?
M15)23U)?3D]47TQ/0TM%1"<L("TR,2D["@HO*BH*("H@5&AE(&YU;6)E<B!O
M9B!C;VQU;6YS(&1O97-N)W0@;6%T8V@@=&AE(&YU;6)E<B!O9B!V86QU97,*
M("HO"F1E9FEN92@G1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7)RP@+3(R
M*3L*"B\J*@H@*B!4:&4@1%-.('-U8FUI='1E9"!H87,@<')O8FQE;7,*("HO
M"F1E9FEN92@G1$)?15)23U)?24Y604Q)1%]$4TXG+"`M,C,I.PH*+RHJ"B`J
M($-O=6QD(&YO="!C;VYN96-T('1O('1H92!D871A8F%S90H@*B\*9&5F:6YE
M*"=$0E]%4E)/4E]#3TY.14-47T9!24Q%1"<L("TR-"D["@HO*BH*("H@5&AE
M(%!(4"!E>'1E;G-I;VX@;F5E9&5D(&9O<B!T:&ES($1"35,@8V]U;&0@;F]T
M(&)E(&9O=6YD"B`J+PID969I;F4H)T1"7T524D]27T585$5.4TE/3E].3U1?
M1D]53D0G+"TR-2D["@HO*BH*("H@5&AE('!R97-E;G0@=7-E<B!H87,@:6YA
M9&5Q=6%T92!P97)M:7-S:6]N<R!T;R!P97)F;W)M('1H92!T87-K(')E<75E
M<W1D"B`J+PID969I;F4H)T1"7T524D]27T%#0T534U]624],051)3TXG+"`M
M,C8I.PH*+RHJ"B`J(%1H92!D871A8F%S92!R97%U97-T960@9&]E<R!N;W0@
M97AI<W0*("HO"F1E9FEN92@G1$)?15)23U)?3D]354-(1$(G+"`M,C<I.PH*
M+RHJ"B`J(%1R:65D('1O(&EN<V5R="!A(&YU;&P@=F%L=64@:6YT;R!A(&-O
M;'5M;B!T:&%T(&1O97-N)W0@86QL;W<@;G5L;',*("HO"F1E9FEN92@G1$)?
M15)23U)?0T].4U1204E.5%].3U1?3E5,3"<L+3(Y*3L*+RHJ(T`M*B\*"@HO
M+R!]?7T*+R\@>WM[('!R97!A<F5D('-T871E;65N="UR96QA=&5D"@H*+RHJ
M(T`K"B`J($ED96YT:69I97)S(&9O<B!T:&4@<&QA8V5H;VQD97)S('5S960@
M:6X@<')E<&%R960@<W1A=&5M96YT<RX*("H@0'-E92!$0E]C;VUM;VXZ.G!R
M97!A<F4H*0H@*B\*"B\J*@H@*B!);F1I8V%T97,@82!S8V%L87(@*#QK8F0^
M/SPO:V)D/BD@<&QA8V5H;VQD97(@=V%S('5S960*("H*("H@475O=&4@86YD
M(&5S8V%P92!T:&4@=F%L=64@87,@;F5C97-S87)Y+@H@*B\*9&5F:6YE*"=$
M0E]005)!35]30T%,05(G+"`Q*3L*"B\J*@H@*B!);F1I8V%T97,@86X@;W!A
M<75E("@\:V)D/B8\+VMB9#XI('!L86-E:&]L9&5R('=A<R!U<V5D"B`J"B`J
M(%1H92!V86QU92!P<F5S96YT960@:7,@82!F:6QE(&YA;64N("!%>'1R86-T
M('1H92!C;VYT96YT<R!O9B!T:&%T(&9I;&4*("H@86YD('!L86-E('1H96T@
M:6X@=&AI<R!C;VQU;6XN"B`J+PID969I;F4H)T1"7U!!4D%-7T]005%512<L
M(#(I.PH*+RHJ"B`J($EN9&EC871E<R!A(&UI<V,@*#QK8F0^(3PO:V)D/BD@
M<&QA8V5H;VQD97(@=V%S('5S960*("H*("H@5&AE('9A;'5E('-H;W5L9"!N
M;W0@8F4@<75O=&5D(&]R(&5S8V%P960N"B`J+PID969I;F4H)T1"7U!!4D%-
M7TU)4T,G+"`@(#,I.PHO*BHC0"TJ+PH*"B\O('U]?0HO+R![>WL@8FEN87)Y
M(&1A=&$M<F5L871E9`H*"B\J*B-`*PH@*B!4:&4@9&EF9F5R96YT('=A>7,@
M;V8@<F5T=7)N:6YG(&)I;F%R>2!D871A(&9R;VT@<75E<FEE<RX*("HO"@HO
M*BH*("H@4V5N9',@=&AE(&9E=&-H960@9&%T82!S=')A:6=H="!T:')O=6=H
M('1O(&]U='!U=`H@*B\*9&5F:6YE*"=$0E]"24Y-3T1%7U!!4U-42%)5)RP@
M,2D["@HO*BH*("H@3&5T<R!Y;W4@<F5T=7)N(&1A=&$@87,@=7-U86P*("HO
M"F1E9FEN92@G1$)?0DE.34]$15]215154DXG+"`R*3L*"B\J*@H@*B!#;VYV
M97)T<R!T:&4@9&%T82!T;R!H97@@9F]R;6%T(&)E9F]R92!R971U<FYI;F<@
M:70*("H*("H@1F]R(&5X86UP;&4@=&AE('-T<FEN9R`B,3(S(B!W;W5L9"!B
M96-O;64@(C,Q,S(S,R(N"B`J+PID969I;F4H)T1"7T))3DU/1$5?0T].5D52
M5"<L(#,I.PHO*BHC0"TJ+PH*"B\O('U]?0HO+R![>WL@9F5T8V@@;6]D97,*
M"@HO*BHC0"L*("H@1F5T8V@@36]D97,N"B`J($!S964@1$)?8V]M;6]N.CIS
M971&971C:$UO9&4H*0H@*B\*"B\J*@H@*B!);F1I8V%T97,@=&AE(&-U<G)E
M;G0@9&5F875L="!F971C:"!M;V1E('-H;W5L9"!B92!U<V5D"B`J($!S964@
M1$)?8V]M;6]N.CHD9F5T8VAM;V1E"B`J+PID969I;F4H)T1"7T9%5$-(34]$
M15]$149!54Q4)RP@,"D["@HO*BH*("H@0V]L=6UN(&1A=&$@:6YD97AE9"!B
M>2!N=6UB97)S+"!O<F1E<F5D(&9R;VT@,"!A;F0@=7`*("HO"F1E9FEN92@G
M1$)?1D540TA-3T1%7T]21$52140G+"`Q*3L*"B\J*@H@*B!#;VQU;6X@9&%T
M82!I;F1E>&5D(&)Y(&-O;'5M;B!N86UE<PH@*B\*9&5F:6YE*"=$0E]&151#
M2$U/1$5?05-33T,G+"`R*3L*"B\J*@H@*B!#;VQU;6X@9&%T82!A<R!O8FIE
M8W0@<')O<&5R=&EE<PH@*B\*9&5F:6YE*"=$0E]&151#2$U/1$5?3T)*14-4
M)RP@,RD["@HO*BH*("H@1F]R(&UU;'1I+61I;65N<VEO;F%L(')E<W5L=',L
M(&UA:V4@=&AE(&-O;'5M;B!N86UE('1H92!F:7)S="!L979E;`H@*B!O9B!T
M:&4@87)R87D@86YD('!U="!T:&4@<F]W(&YU;6)E<B!I;B!T:&4@<V5C;VYD
M(&QE=F5L(&]F('1H92!A<G)A>0H@*@H@*B!4:&ES(&ES(&9L:7!P960@9G)O
M;2!T:&4@;F]R;6%L(&)E:&%V:6]R+"!W:&EC:"!P=71S('1H92!R;W<@;G5M
M8F5R<PH@*B!I;B!T:&4@9FER<W0@;&5V96P@;V8@=&AE(&%R<F%Y(&%N9"!T
M:&4@8V]L=6UN(&YA;65S(&EN('1H92!S96-O;F0@;&5V96PN"B`J+PID969I
M;F4H)T1"7T9%5$-(34]$15]&3$E04$5$)RP@-"D["B\J*B-`+2HO"@HO*BHC
M0"L*("H@3VQD(&9E=&-H(&UO9&5S+B`@3&5F="!H97)E(&9O<B!C;VUP871I
M8FEL:71Y+@H@*B\*9&5F:6YE*"=$0E]'151-3T1%7T]21$52140G+"!$0E]&
M151#2$U/1$5?3U)$15)%1"D["F1E9FEN92@G1$)?1T5434]$15]!4U-/0R<L
M("`@1$)?1D540TA-3T1%7T%34T]#*3L*9&5F:6YE*"=$0E]'151-3T1%7T9,
M25!0140G+"!$0E]&151#2$U/1$5?1DQ)4%!%1"D["B\J*B-`+2HO"@H*+R\@
M?7U]"B\O('M[>R!T86)L94EN9F\H*2`F)B!A=71O4')E<&%R92@I+7)E;&%T
M960*"@HO*BHC0"L*("H@5&AE('1Y<&4@;V8@:6YF;W)M871I;VX@=&\@<F5T
M=7)N(&9R;VT@=&AE('1A8FQE26YF;R@I(&UE=&AO9"X*("H*("H@0FET=VES
M960@8V]N<W1A;G1S+"!S;R!T:&5Y(&-A;B!B92!C;VUB:6YE9"!U<VEN9R`\
M:V)D/GP\+VMB9#X*("H@86YD(')E;6]V960@=7-I;F<@/&MB9#Y>/"]K8F0^
M+@H@*@H@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("H*("H@>T!I
M;G1E<FYA;"!3:6YC92!T:&4@5$%"3$5)3D9/(&-O;G-T86YT<R!A<F4@8FET
M=VES960L(&EF(&UO<F4@;V8@=&AE;2!A<F4*("H@861D960@:6X@=&AE(&9U
M='5R92P@;6%K92!S=7)E('1O(&%D:G5S="!$0E]404),14E.1D]?1E5,3"!A
M8V-O<F1I;F=L>2Y]?0H@*B\*9&5F:6YE*"=$0E]404),14E.1D]?3U)$15(G
M+"`Q*3L*9&5F:6YE*"=$0E]404),14E.1D]?3U)$15)404),12<L(#(I.PID
M969I;F4H)T1"7U1!0DQ%24Y&3U]&54Q,)RP@,RD["B\J*B-`+2HO"@H*+RHJ
M(T`K"B`J(%1H92!T>7!E(&]F('%U97)Y('1O(&-R96%T92!W:71H('1H92!A
M=71O;6%T:6,@<75E<GD@8G5I;&1I;F<@;65T:&]D<RX*("H@0'-E92!$0E]C
M;VUM;VXZ.F%U=&]0<F5P87)E*"DL($1"7V-O;6UO;CHZ875T;T5X96-U=&4H
M*0H@*B\*9&5F:6YE*"=$0E]!551/455%4EE?24Y315)4)RP@,2D["F1E9FEN
M92@G1$)?05543U%515)97U501$%412<L(#(I.PHO*BHC0"TJ+PH*"B\O('U]
M?0HO+R![>WL@<&]R=&%B:6QI='D@;6]D97,*"@HO*BHC0"L*("H@4&]R=&%B
M:6QI='D@36]D97,N"B`J"B`J($)I='=I<V5D(&-O;G-T86YT<RP@<V\@=&AE
M>2!C86X@8F4@8V]M8FEN960@=7-I;F<@/&MB9#Y\/"]K8F0^"B`J(&%N9"!R
M96UO=F5D('5S:6YG(#QK8F0^7CPO:V)D/BX*("H*("H@0'-E92!$0E]C;VUM
M;VXZ.G-E=$]P=&EO;B@I"B`J"B`J('M`:6YT97)N86P@4VEN8V4@=&AE(%!/
M4E1!0DE,2519(&-O;G-T86YT<R!A<F4@8FET=VES960L(&EF(&UO<F4@;V8@
M=&AE;2!A<F4*("H@861D960@:6X@=&AE(&9U='5R92P@;6%K92!S=7)E('1O
M(&%D:G5S="!$0E]03U)404))3$E465]!3$P@86-C;W)D:6YG;'DN?7T*("HO
M"@HO*BH*("H@5'5R;B!O9F8@86QL('!O<G1A8FEL:71Y(&9E871U<F5S"B`J
M+PID969I;F4H)T1"7U!/4E1!0DE,25197TY/3D4G+"`P*3L*"B\J*@H@*B!#
M;VYV97)T(&YA;65S(&]F('1A8FQE<R!A;F0@9FEE;&1S('1O(&QO=V5R(&-A
M<V4*("H@=VAE;B!U<VEN9R!T:&4@9V5T*B@I+"!F971C:"HH*2!A;F0@=&%B
M;&5);F9O*"D@;65T:&]D<PH@*B\*9&5F:6YE*"=$0E]03U)404))3$E465],
M3U=%4D-!4T4G+"`Q*3L*"B\J*@H@*B!2:6=H="!T<FEM('1H92!D871A(&]U
M='!U="!B>2!G970J*"D@86YD(&9E=&-H*B@I"B`J+PID969I;F4H)T1"7U!/
M4E1!0DE,25197U)44DE-)RP@,BD["@HO*BH*("H@1F]R8V4@<F5P;W)T:6YG
M('1H92!N=6UB97(@;V8@<F]W<R!D96QE=&5D"B`J+PID969I;F4H)T1"7U!/
M4E1!0DE,25197T1%3$5415]#3U5.5"<L(#0I.PH*+RHJ"B`J($5N86)L92!H
M86-K('1H870@;6%K97,@;G5M4F]W<R@I('=O<FL@:6X@3W)A8VQE"B`J+PID
M969I;F4H)T1"7U!/4E1!0DE,25197TY535)/5U,G+"`X*3L*"B\J*@H@*B!-
M86ME<R!C97)T86EN(&5R<F]R(&UE<W-A9V5S(&EN(&-E<G1A:6X@9')I=F5R
M<R!C;VUP871I8FQE"B`J('=I=&@@=&AO<V4@9G)O;2!O=&AE<B!$0DU3)W,*
M("H*("H@*R!M>7-Q;"P@;7ES<6QI.B`@8VAA;F=E('5N:7%U92]P<FEM87)Y
M(&ME>2!C;VYS=')A:6YT<PH@*B`@($1"7T524D]27T%,4D5!1%E?15A)4U13
M("T^($1"7T524D]27T-/3E-44D%)3E0*("H*("H@*R!O9&)C*&%C8V5S<RDZ
M("!-4R=S($]$0D,@9')I=F5R(')E<&]R=',@)VYO('-U8V@@9FEE;&0G(&%S
M(&-O9&4*("H@("`P-S`P,2P@=VAI8V@@;65A;G,@)W1O;R!F97<@<&%R86UE
M=&5R<RXG("!7:&5N('1H:7,@;W!T:6]N(&ES(&]N"B`J("`@=&AA="!C;V1E
M(&=E=',@;6%P<&5D('1O($1"7T524D]27TY/4U5#2$9)14Q$+@H@*B\*9&5F
M:6YE*"=$0E]03U)404))3$E465]%4E)/4E,G+"`Q-BD["@HO*BH*("H@0V]N
M=F5R="!N=6QL('9A;'5E<R!T;R!E;7!T>2!S=')I;F=S(&EN(&1A=&$@;W5T
M<'5T(&)Y"B`J(&=E="HH*2!A;F0@9F5T8V@J*"D*("HO"F1E9FEN92@G1$)?
M4$]25$%"24Q)5%E?3E5,3%]43U]%35!462<L(#,R*3L*"B\J*@H@*B!4=7)N
M(&]N(&%L;"!P;W)T86)I;&ET>2!F96%T=7)E<PH@*B\*9&5F:6YE*"=$0E]0
M3U)404))3$E465]!3$PG+"`V,RD["B\J*B-`+2HO"@HO+R!]?7T*"@HO+R!]
M?7T*+R\@>WM[(&-L87-S($1""@HO*BH*("H@1&%T86)A<V4@:6YD97!E;F1E
M;G0@<75E<GD@:6YT97)F86-E"B`J"B`J(%1H92!M86EN(")$0B(@8VQA<W,@
M:7,@<VEM<&QY(&$@8V]N=&%I;F5R(&-L87-S('=I=&@@<V]M92!S=&%T:6,*
M("H@;65T:&]D<R!F;W(@8W)E871I;F<@1$(@;V)J96-T<R!A<R!W96QL(&%S
M('-O;64@=71I;&ET>2!F=6YC=&EO;G,*("H@8V]M;6]N('1O(&%L;"!P87)T
M<R!O9B!$0BX*("H*("H@5&AE(&]B:F5C="!M;V1E;"!O9B!$0B!I<R!A<R!F
M;VQL;W=S("AI;F1E;G1A=&EO;B!M96%N<R!I;FAE<FET86YC92DZ"B`J(#QP
M<F4^"B`J($1"("`@("`@("`@("!4:&4@;6%I;B!$0B!C;&%S<RX@(%1H:7,@
M:7,@<VEM<&QY(&$@=71I;&ET>2!C;&%S<PH@*B`@("`@("`@("`@("`@=VET
M:"!S;VUE(")S=&%T:6,B(&UE=&AO9',@9F]R(&-R96%T:6YG($1"(&]B:F5C
M=',@87,*("H@("`@("`@("`@("`@('=E;&P@87,@8V]M;6]N('5T:6QI='D@
M9G5N8W1I;VYS(&9O<B!O=&AE<B!$0B!C;&%S<V5S+@H@*@H@*B!$0E]C;VUM
M;VX@("`@5&AE(&)A<V4@9F]R(&5A8V@@1$(@:6UP;&5M96YT871I;VXN("!0
M<F]V:61E<R!D969A=6QT"B`J('P@("`@("`@("`@("!I;7!L96UE;G1A=&EO
M;G,@*&EN($]/(&QI;F=O('9I<G1U86P@;65T:&]D<RD@9F]R"B`J('P@("`@
M("`@("`@("!T:&4@86-T=6%L($1"(&EM<&QE;65N=&%T:6]N<R!A<R!W96QL
M(&%S(&$@8G5N8V@@;V8*("H@?"`@("`@("`@("`@('%U97)Y('5T:6QI='D@
M9G5N8W1I;VYS+@H@*B!\"B`J("LM1$)?;7ES<6P@("!4:&4@1$(@:6UP;&5M
M96YT871I;VX@9F]R($UY4U%,+B`@26YH97)I=',@1$)?8V]M;6]N+@H@*B`@
M("`@("`@("`@("`@5VAE;B!C86QL:6YG($1".CIF86-T;W)Y(&]R($1".CIC
M;VYN96-T(&9O<B!->5-13`H@*B`@("`@("`@("`@("`@8V]N;F5C=&EO;G,L
M('1H92!O8FIE8W0@<F5T=7)N960@:7,@86X@:6YS=&%N8V4@;V8@=&AI<PH@
M*B`@("`@("`@("`@("`@8VQA<W,N"B`J(#PO<')E/@H@*@H@*B!`8V%T96=O
M<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J($!A=71H;W(@("`@(%1O
M;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@("`@
M1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PIC;&%S
M<R!$0@I["B`@("`O+R![>WL@)F9A8W1O<GDH*0H*("`@("\J*@H@("`@("H@
M0W)E871E(&$@;F5W($1"(&]B:F5C="!F;W(@=&AE('-P96-I9FEE9"!D871A
M8F%S92!T>7!E(&)U="!D;VXG=`H@("`@("H@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("!T
M:&4@9&%T86)A<V4@='EP92`H96<@(FUY<W%L(BD*("`@("`J($!P87)A;2!A
M<G)A>2`@)&]P=&EO;G,@(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F(&]P=&EO
M;B!N86UE<R!A;F0@=F%L=65S"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE
M8W0@(&$@;F5W($1"(&]B:F5C="X@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO
M;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1T>7!E+"`D;W!T
M:6]N<R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&]P
M=&EO;G,I*2!["B`@("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH)W!E<G-I
M<W1E;G0G(#T^("1O<'1I;VYS*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG9&5B=6<G72D@)B8@)&]P=&EO;G-;)V1E8G5G)UT@
M/CT@,BD@>PH@("`@("`@("`@("`O+R!E>'!O<V4@<&AP(&5R<F]R<R!W:71H
M('-U9F9I8VEE;G0@9&5B=6<@;&5V96P*("`@("`@("`@("`@:6YC;'5D95]O
M;F-E(")$0B][)'1Y<&5]+G!H<"(["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@0&EN8VQU9&5?;VYC92`B1$(O>R1T>7!E?2YP:'`B.PH@("`@("`@
M('T*"B`@("`@("`@)&-L87-S;F%M92`](")$0E\D>W1Y<&5](CL*"B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M92DI('L*("`@("`@("`@
M("`@)'1M<"`](%!%05(Z.G)A:7-E17)R;W(H;G5L;"P@1$)?15)23U)?3D]4
M7T9/54Y$+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`B56YA8FQE('1O(&EN8VQU9&4@=&AE($1"+WLD='EP97TN
M<&AP(@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("(@
M9FEL92!F;W(@)R1D<VXG(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)T1"7T5R<F]R)RP@=')U92D["B`@("`@("`@("`@(')E='5R
M;B`D=&UP.PH@("`@("`@('T*"B`@("`@("`@0"1O8FH@/28@;F5W("1C;&%S
M<VYA;64["@H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O<'1I;VX@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T97-T(#T@)&]B:BT^<V5T3W!T
M:6]N*"1O<'1I;VXL("1V86QU92D["B`@("`@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D=&5S="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&5S=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8FH[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@)F-O;FYE8W0H*0H*("`@
M("\J*@H@("`@("H@0W)E871E(&$@;F5W($1"(&]B:F5C="!I;F-L=61I;F<@
M82!C;VYN96-T:6]N('1O('1H92!S<&5C:69I960@9&%T86)A<V4*("`@("`J
M"B`@("`@*B!%>&%M<&QE(#$N"B`@("`@*B`\8V]D93X*("`@("`J(')E<75I
M<F5?;VYC92`G1$(N<&AP)SL*("`@("`J"B`@("`@*B`D9'-N(#T@)W!G<W%L
M.B\O=7-E<CIP87-S=V]R9$!H;W-T+V1A=&%B87-E)SL*("`@("`J("1O<'1I
M;VYS(#T@87)R87DH"B`@("`@*B`@("`@)V1E8G5G)R`@("`@("`]/B`R+`H@
M("`@("H@("`@("=P;W)T86)I;&ET>2<@/3X@1$)?4$]25$%"24Q)5%E?04Q,
M+`H@("`@("H@*3L*("`@("`J"B`@("`@*B`D9&(@/28@1$(Z.F-O;FYE8W0H
M)&1S;BP@)&]P=&EO;G,I.PH@("`@("H@:68@*%!%05(Z.FES17)R;W(H)&1B
M*2D@>PH@("`@("H@("`@(&1I92@D9&(M/F=E=$UE<W-A9V4H*2D["B`@("`@
M*B!]"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1D<VX@("`@("!T:&4@<W1R:6YG(")D871A('-O=7)C92!N86UE(B!O<B!A
M<G)A>2!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<FUA="!R971U<FYE9"!B>2!$0CHZ<&%R<V5$4TXH*0H@("`@("H@0'!A<F%M
M(&%R<F%Y("1O<'1I;VYS("!A;B!A<W-O8VEA=&EV92!A<G)A>2!O9B!O<'1I
M;VX@;F%M97,@86YD('9A;'5E<PH@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T("!A(&YE=R!$0B!O8FIE8W0N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!U<V5S($1"7V1B87-E.CIC;VYN96-T
M*"DL($1"7V9B<W%L.CIC;VYN96-T*"DL($1"7VEB87-E.CIC;VYN96-T*"DL
M"B`@("`@*B`@("`@("!$0E]I9G@Z.F-O;FYE8W0H*2P@1$)?;7-Q;#HZ8V]N
M;F5C="@I+"!$0E]M<W-Q;#HZ8V]N;F5C="@I+`H@("`@("H@("`@("`@1$)?
M;7ES<6PZ.F-O;FYE8W0H*2P@1$)?;7ES<6QI.CIC;VYN96-T*"DL($1"7V]C
M:3@Z.F-O;FYE8W0H*2P*("`@("`J("`@("`@($1"7V]D8F,Z.F-O;FYE8W0H
M*2P@1$)?<&=S<6PZ.F-O;FYE8W0H*2P@1$)?<W%L:71E.CIC;VYN96-T*"DL
M"B`@("`@*B`@("`@("!$0E]S>6)A<V4Z.F-O;FYE8W0H*0H@("`@("H*("`@
M("`J($!U<V5S($1".CIP87)S94133B@I+"!$0E]C;VUM;VXZ.G-E=$]P=&EO
M;B@I+"!014%2.CII<T5R<F]R*"D*("`@("`J+PH@("`@9G5N8W1I;VX@)F-O
M;FYE8W0H)&1S;BP@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M("1D<VYI;F9O(#T@1$(Z.G!A<G-E1%-.*"1D<VXI.PH@("`@("`@("1T>7!E
M(#T@)&1S;FEN9F];)W!H<'1Y<&4G73L*"B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D;W!T:6]N<RDI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@
M1F]R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+B`@)&]P=&EO;G,@=7-E9"!T
M;R!B92!B;V]L96%N+`H@("`@("`@("`@("`@*B!I;F1I8V%T:6YG('=H971H
M97(@=&AE(&-O;FYE8W1I;VX@<VAO=6QD(&)E('!E<G-I<W1E;G0N"B`@("`@
M("`@("`@("`J+PH@("`@("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"=P97)S
M:7-T96YT)R`]/B`D;W!T:6]N<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)V1E8G5G)UTI("8F("1O<'1I;VYS6R=D96)U9R==
M(#X](#(I('L*("`@("`@("`@("`@+R\@97AP;W-E('!H<"!E<G)O<G,@=VET
M:"!S=69F:6-I96YT(&1E8G5G(&QE=F5L"B`@("`@("`@("`@(&EN8VQU9&5?
M;VYC92`B1$(O)'MT>7!E?2YP:'`B.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($!I;F-L=61E7V]N8V4@(D1"+R1[='EP97TN<&AP(CL*("`@("`@
M("!]"@H@("`@("`@("1C;&%S<VYA;64@/2`B1$)?)'MT>7!E?2(["B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M92DI('L*("`@("`@("`@
M("`@)'1M<"`](%!%05(Z.G)A:7-E17)R;W(H;G5L;"P@1$)?15)23U)?3D]4
M7T9/54Y$+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`B56YA8FQE('1O(&EN8VQU9&4@=&AE($1"+WLD='EP97TN
M<&AP(@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("(@
M9FEL92!F;W(@)R1D<VXG(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)T1"7T5R<F]R)RP@=')U92D["B`@("`@("`@("`@(')E='5R
M;B`D=&UP.PH@("`@("`@('T*"B`@("`@("`@0"1O8FH@/28@;F5W("1C;&%S
M<VYA;64["@H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O<'1I;VX@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T97-T(#T@)&]B:BT^<V5T3W!T
M:6]N*"1O<'1I;VXL("1V86QU92D["B`@("`@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D=&5S="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&5S=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&5R<B`]("1O8FHM
M/F-O;FYE8W0H)&1S;FEN9F\L("1O8FHM/F=E=$]P=&EO;B@G<&5R<VES=&5N
M="<I*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)&5R<BDI('L*("`@("`@
M("`@("`@)&5R<BT^861D57-E<DEN9F\H)&1S;BD["B`@("`@("`@("`@(')E
M='5R;B`D97)R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8FH["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@87!I5F5R<VEO;B@I"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE($1"($%022!V97)S:6]N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@('1H92!$0B!!4$D@=F5R<VEO;B!N=6UB
M97(*("`@("`J+PH@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("<Q+C<N-B<["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@:7-%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF
M(&$@=F%R:6%B;&4@:7,@82!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)'9A;'5E("!T:&4@=F%R:6%B;&4@=&\@8VAE8VL*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@('=H971H97(@)'9A;'5E(&ES
M($1"7T5R<F]R(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5R<F]R
M*"1V86QU92D*("`@('L*("`@("`@("!R971U<FX@:7-?82@D=F%L=64L("=$
M0E]%<G)O<B<I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&ES0V]N
M;F5C=&EO;B@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF(&$@=F%L
M=64@:7,@82!$0E\\9')I=F5R/B!O8FIE8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)'9A;'5E("!T:&4@=F%L=64@=&\@=&5S=`H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;"`@=VAE=&AE<B`D=F%L=64@:7,@82!$0E\\9')I
M=F5R/B!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;VYN96-T:6]N
M*"1V86QU92D*("`@('L*("`@("`@("!R971U<FX@*&ES7V]B:F5C="@D=F%L
M=64I("8F"B`@("`@("`@("`@("`@("!I<U]S=6)C;&%S<U]O9B@D=F%L=64L
M("=D8E]C;VUM;VXG*2`F)@H@("`@("`@("`@("`@("`@;65T:&]D7V5X:7-T
M<R@D=F%L=64L("=S:6UP;&51=65R>2<I*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!I<TUA;FEP*"D*"B`@("`O*BH*("`@("`J(%1E;&P@=VAE
M=&AE<B!A('%U97)Y(&ES(&$@9&%T82!M86YI<'5L871I;VX@;W(@9&%T82!D
M969I;FET:6]N('%U97)Y"B`@("`@*@H@("`@("H@17AA;7!L97,@;V8@9&%T
M82!M86YI<'5L871I;VX@<75E<FEE<R!A<F4@24Y315)4+"!54$1!5$4@86YD
M($1%3$5412X*("`@("`J($5X86UP;&5S(&]F(&1A=&$@9&5F:6YI=&EO;B!Q
M=65R:65S(&%R92!#4D5!5$4L($123U`L($%,5$52+"!'4D%.5"P*("`@("`J
M(%)%5D]+12X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@
M=&AE('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!W:&5T
M:&5R("1Q=65R>2!I<R!A(&1A=&$@;6%N:7!U;&%T:6]N('%U97)Y"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES36%N:7`H)'%U97)Y*0H@("`@>PH@("`@("`@
M("1M86YI<',@/2`G24Y315)4?%501$%417Q$14Q%5$5\4D503$%#17PG"B`@
M("`@("`@("`@("`@("`N("=#4D5!5$5\1%)/4'PG"B`@("`@("`@("`@("`@
M("`N("=,3T%$($1!5$%\4T5,14-4("XJ($E.5$]\0T]067PG"B`@("`@("`@
M("`@("`@("`N("=!3%1%4GQ'4D%.5'Q2159/2T5\)PH@("`@("`@("`@("`@
M("`@+B`G3$]#2WQ53DQ/0TLG.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7EQS*B(_*"<@+B`D;6%N:7!S("X@)RE<<RLO:2<L("1Q=65R>2DI('L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DUE
M<W-A9V4H*0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@=&5X='5A;"!E<G)O
M<B!M97-S86=E(&9O<B!A($1"(&5R<F]R(&-O9&4*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D=F%L=64@('1H92!$0B!E<G)O<B!C;V1E"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E<G)O<B!M97-S86=E(&]R
M(&9A;'-E(&EF('1H92!E<G)O<B!C;V1E('=A<PH@("`@("H@("`@("`@("`@
M("`@("`@("!N;W0@<F5C;V=N:7IE9`H@("`@("HO"B`@("!F=6YC=&EO;B!E
M<G)O<DUE<W-A9V4H)'9A;'5E*0H@("`@>PH@("`@("`@('-T871I8R`D97)R
M;W)-97-S86=E<SL*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<DUE<W-A9V5S
M*2D@>PH@("`@("`@("`@("`D97)R;W)-97-S86=E<R`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@1$)?15)23U(@("`@("`@("`@("`@("`@("`@(#T^("=U
M;FMN;W=N(&5R<F]R)RP*("`@("`@("`@("`@("`@($1"7T524D]27T%#0T53
M4U]624],051)3TX@("`]/B`G:6YS=69F:6-I96YT('!E<FUI<W-I;VYS)RP*
M("`@("`@("`@("`@("`@($1"7T524D]27T%,4D5!1%E?15A)4U13("`@("`]
M/B`G86QR96%D>2!E>&ES=',G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?
M0T%.3D]47T-214%412`@("`@(#T^("=C86X@;F]T(&-R96%T92<L"B`@("`@
M("`@("`@("`@("!$0E]%4E)/4E]#04Y.3U1?1%)/4"`@("`@("`@/3X@)V-A
M;B!N;W0@9')O<"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]#3TY.14-4
M7T9!24Q%1"`@("`@/3X@)V-O;FYE8W0@9F%I;&5D)RP*("`@("`@("`@("`@
M("`@($1"7T524D]27T-/3E-44D%)3E0@("`@("`@("`]/B`G8V]N<W1R86EN
M="!V:6]L871I;VXG+`H@("`@("`@("`@("`@("`@1$)?15)23U)?0T].4U12
M04E.5%].3U1?3E5,3#T^("=N=6QL('9A;'5E('9I;VQA=&5S(&YO="UN=6QL
M(&-O;G-T<F%I;G0G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?1$E66D52
M3R`@("`@("`@("`@(#T^("=D:79I<VEO;B!B>2!Z97)O)RP*("`@("`@("`@
M("`@("`@($1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0]/B`G97AT96YS
M:6]N(&YO="!F;W5N9"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E])3E9!
M3$E$("`@("`@("`@("`@/3X@)VEN=F%L:60G+`H@("`@("`@("`@("`@("`@
M1$)?15)23U)?24Y604Q)1%]$051%("`@("`@(#T^("=I;G9A;&ED(&1A=&4@
M;W(@=&EM92<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E])3E9!3$E$7T13
M3B`@("`@("`@/3X@)VEN=F%L:60@1%-.)RP*("`@("`@("`@("`@("`@($1"
M7T524D]27TE.5D%,241?3E5-0D52("`@("`]/B`G:6YV86QI9"!N=6UB97(G
M+`H@("`@("`@("`@("`@("`@1$)?15)23U)?34E334%40T@@("`@("`@("`@
M(#T^("=M:7-M871C:"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E].145$
M7TU/4D5?1$%402`@("`@/3X@)VEN<W5F9FEC:65N="!D871A('-U<'!L:65D
M)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY/1$)314Q%0U1%1"`@("`@
M("`]/B`G;F\@9&%T86)A<V4@<V5L96-T960G+`H@("`@("`@("`@("`@("`@
M1$)?15)23U)?3D]354-(1$(@("`@("`@("`@(#T^("=N;R!S=6-H(&1A=&%B
M87-E)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY/4U5#2$9)14Q$("`@
M("`@("`]/B`G;F\@<W5C:"!F:65L9"<L"B`@("`@("`@("`@("`@("!$0E]%
M4E)/4E].3U-50TA404),12`@("`@("`@/3X@)VYO('-U8V@@=&%B;&4G+`H@
M("`@("`@("`@("`@("`@1$)?15)23U)?3D]47T-!4$%"3$4@("`@("`@(#T^
M("=$0B!B86-K96YD(&YO="!C87!A8FQE)RP*("`@("`@("`@("`@("`@($1"
M7T524D]27TY/5%]&3U5.1"`@("`@("`@("`]/B`G;F]T(&9O=6YD)RP*("`@
M("`@("`@("`@("`@($1"7T524D]27TY/5%],3T-+140@("`@("`@("`]/B`G
M;F]T(&QO8VME9"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]364Y405@@
M("`@("`@("`@("`@/3X@)W-Y;G1A>"!E<G)O<B<L"B`@("`@("`@("`@("`@
M("!$0E]%4E)/4E]53E-54%!/4E1%1"`@("`@("`@/3X@)VYO="!S=7!P;W)T
M960G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?5%)53D-!5$5$("`@("`@
M("`@(#T^("=T<G5N8V%T960G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?
M5D%,545?0T]53E1?3TY?4D]7(#T^("=V86QU92!C;W5N="!O;B!R;W<G+`H@
M("`@("`@("`@("`@("`@1$)?3TL@("`@("`@("`@("`@("`@("`@("`@(#T^
M("=N;R!E<G)O<B<L"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)'9A;'5E*2D@>PH@("`@("`@("`@("`D=F%L
M=64@/2`D=F%L=64M/F=E=$-O9&4H*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!I<W-E="@D97)R;W)-97-S86=E<ULD=F%L=65=*2`_("1E<G)O<DUE
M<W-A9V5S6R1V86QU95T*("`@("`@("`@("`@("`@("`@("`@.B`D97)R;W)-
M97-S86=E<UM$0E]%4E)/4ET["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<&%R<V5$4TXH*0H*("`@("\J*@H@("`@("H@4&%R<V4@82!D871A('-O
M=7)C92!N86UE"B`@("`@*@H@("`@("H@061D:71I;VYA;"!K97ES(&-A;B!B
M92!A9&1E9"!B>2!A<'!E;F1I;F<@82!54DD@<75E<GD@<W1R:6YG('1O('1H
M90H@("`@("H@96YD(&]F('1H92!$4TXN"B`@("`@*@H@("`@("H@5&AE(&9O
M<FUA="!O9B!T:&4@<W5P<&QI960@1%-.(&ES(&EN(&ET<R!F=6QL97-T(&9O
M<FTZ"B`@("`@*B`\8V]D93X*("`@("`J("!P:'!T>7!E*&1B<WEN=&%X*3HO
M+W5S97)N86UE.G!A<W-W;W)D0'!R;W1O8V]L*VAO<W1S<&5C+V1A=&%B87-E
M/V]P=&EO;CTX)F%N;W1H97(]=')U90H@("`@("H@/"]C;V1E/@H@("`@("H*
M("`@("`J($UO<W0@=F%R:6%T:6]N<R!A<F4@86QL;W=E9#H*("`@("`J(#QC
M;V1E/@H@("`@("H@('!H<'1Y<&4Z+R]U<V5R;F%M93IP87-S=V]R9$!P<F]T
M;V-O;"MH;W-T<W!E8SHQ,3`O+W5S<B]D8E]F:6QE+F1B/VUO9&4],#8T-`H@
M("`@("H@('!H<'1Y<&4Z+R]U<V5R;F%M93IP87-S=V]R9$!H;W-T<W!E8R]D
M871A8F%S95]N86UE"B`@("`@*B`@<&AP='EP93HO+W5S97)N86UE.G!A<W-W
M;W)D0&AO<W1S<&5C"B`@("`@*B`@<&AP='EP93HO+W5S97)N86UE0&AO<W1S
M<&5C"B`@("`@*B`@<&AP='EP93HO+VAO<W1S<&5C+V1A=&%B87-E"B`@("`@
M*B`@<&AP='EP93HO+VAO<W1S<&5C"B`@("`@*B`@<&AP='EP92AD8G-Y;G1A
M>"D*("`@("`J("!P:'!T>7!E"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9'-N($1A=&$@4V]U<F-E($YA;64@=&\@8F4@
M<&%R<V5D"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!A;B!A<W-O8VEA
M=&EV92!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@:V5Y<SH*("`@("`J("`K
M('!H<'1Y<&4Z("!$871A8F%S92!B86-K96YD('5S960@:6X@4$A0("AM>7-Q
M;"P@;V1B8R!E=&,N*0H@("`@("H@("L@9&)S>6YT87@Z($1A=&%B87-E('5S
M960@=VET:"!R96=A<F1S('1O(%-13"!S>6YT87@@971C+@H@("`@("H@("L@
M<')O=&]C;VPZ($-O;6UU;FEC871I;VX@<')O=&]C;VP@=&\@=7-E("AT8W`L
M('5N:7@@971C+BD*("`@("`J("`K(&AO<W1S<&5C.B!(;W-T('-P96-I9FEC
M871I;VX@*&AO<W1N86UE6SIP;W)T72D*("`@("`J("`K(&1A=&%B87-E.B!$
M871A8F%S92!T;R!U<V4@;VX@=&AE($1"35,@<V5R=F5R"B`@("`@*B`@*R!U
M<V5R;F%M93H@57-E<B!N86UE(&9O<B!L;V=I;@H@("`@("H@("L@<&%S<W=O
M<F0Z(%!A<W-W;W)D(&9O<B!L;V=I;@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M87)S94133B@D9'-N*0H@("`@>PH@("`@("`@("1P87)S960@/2!A<G)A>2@*
M("`@("`@("`@("`@)W!H<'1Y<&4G("`]/B!F86QS92P*("`@("`@("`@("`@
M)V1B<WEN=&%X)R`]/B!F86QS92P*("`@("`@("`@("`@)W5S97)N86UE)R`]
M/B!F86QS92P*("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B!F86QS92P*("`@
M("`@("`@("`@)W!R;W1O8V]L)R`]/B!F86QS92P*("`@("`@("`@("`@)VAO
M<W1S<&5C)R`]/B!F86QS92P*("`@("`@("`@("`@)W!O<G0G("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@)W-O8VME="<@("`]/B!F86QS92P*("`@("`@
M("`@("`@)V1A=&%B87-E)R`]/B!F86QS92P*("`@("`@("`I.PH*("`@("`@
M("!I9B`H:7-?87)R87DH)&1S;BDI('L*("`@("`@("`@("`@)&1S;B`](&%R
M<F%Y7VUE<F=E*"1P87)S960L("1D<VXI.PH@("`@("`@("`@("!I9B`H(21D
M<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@("`@("1D<VY;)V1B<WEN
M=&%X)UT@/2`D9'-N6R=P:'!T>7!E)UT["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N("1D<VX["B`@("`@("`@?0H*("`@("`@("`O+R!&:6YD
M('!H<'1Y<&4@86YD(&1B<WEN=&%X"B`@("`@("`@:68@*"@D<&]S(#T@<W1R
M<&]S*"1D<VXL("<Z+R\G*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1S
M='(@/2!S=6)S='(H)&1S;BP@,"P@)'!O<RD["B`@("`@("`@("`@("1D<VX@
M/2!S=6)S='(H)&1S;BP@)'!O<R`K(#,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S='(@/2`D9'-N.PH@("`@("`@("`@("`D9'-N(#T@;G5L
M;#L*("`@("`@("!]"@H@("`@("`@("\O($=E="!P:'!T>7!E(&%N9"!D8G-Y
M;G1A>`H@("`@("`@("\O("1S='(@/3X@<&AP='EP92AD8G-Y;G1A>"D*("`@
M("`@("!I9B`H<')E9U]M871C:"@G?%XH+BL_*5PH*"XJ/RE<*21\)RP@)'-T
M<BP@)&%R<BDI('L*("`@("`@("`@("`@)'!A<G-E9%LG<&AP='EP92==("`]
M("1A<G);,5T["B`@("`@("`@("`@("1P87)S961;)V1B<WEN=&%X)UT@/2`A
M)&%R<ELR72`_("1A<G);,5T@.B`D87)R6S)=.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1P87)S961;)W!H<'1Y<&4G72`@/2`D<W1R.PH@("`@
M("`@("`@("`D<&%R<V5D6R=D8G-Y;G1A>"==(#T@)'-T<CL*("`@("`@("!]
M"@H@("`@("`@(&EF("@A8V]U;G0H)&1S;BDI('L*("`@("`@("`@("`@<F5T
M=7)N("1P87)S960["B`@("`@("`@?0H*("`@("`@("`O+R!'970@*&EF(&9O
M=6YD*3H@=7-E<FYA;64@86YD('!A<W-W;W)D"B`@("`@("`@+R\@)&1S;B`]
M/B!U<V5R;F%M93IP87-S=V]R9$!P<F]T;V-O;"MH;W-T<W!E8R]D871A8F%S
M90H@("`@("`@(&EF("@H)&%T(#T@<W1R<G!O<R@D9'-N+"=`)RDI("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`D<W1R(#T@<W5B<W1R*"1D<VXL(#`L("1A
M="D["B`@("`@("`@("`@("1D<VX@/2!S=6)S='(H)&1S;BP@)&%T("L@,2D[
M"B`@("`@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D<W1R+"`G.B<I*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P87)S961;)W5S97)N86UE
M)UT@/2!R87=U<FQD96-O9&4H<W5B<W1R*"1S='(L(#`L("1P;W,I*3L*("`@
M("`@("`@("`@("`@("1P87)S961;)W!A<W-W;W)D)UT@/2!R87=U<FQD96-O
M9&4H<W5B<W1R*"1S='(L("1P;W,@*R`Q*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<&%R<V5D6R=U<V5R;F%M92==(#T@<F%W
M=7)L9&5C;V1E*"1S='(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!&:6YD('!R;W1O8V]L(&%N9"!H;W-T<W!E8PH*("`@("`@("!I
M9B`H<')E9U]M871C:"@G?%XH6UXH72LI7"@H+BH_*5PI+S\H+BH_*21\)RP@
M)&1S;BP@)&UA=&-H*2D@>PH@("`@("`@("`@("`O+R`D9'-N(#T^('!R;W1O
M*'!R;W1O7V]P=',I+V1A=&%B87-E"B`@("`@("`@("`@("1P<F]T;R`@("`@
M("`]("1M871C:%LQ73L*("`@("`@("`@("`@)'!R;W1O7V]P=',@(#T@)&UA
M=&-H6S)=(#\@)&UA=&-H6S)=(#H@9F%L<V4["B`@("`@("`@("`@("1D<VX@
M("`@("`@("`]("1M871C:%LS73L*"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@)&1S;B`]/B!P<F]T;V-O;"MH;W-T<W!E8R]D871A8F%S92`H
M;VQD(&9O<FUA="D*("`@("`@("`@("`@:68@*'-T<G!O<R@D9'-N+"`G*R<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@;&ES="@D<')O=&\L("1D
M<VXI(#T@97AP;&]D92@G*R<L("1D<VXL(#(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("AS=')P;W,H)&1S;BP@)R\G*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@(&QI<W0H)'!R;W1O7V]P=',L("1D<VXI(#T@97AP
M;&]D92@G+R<L("1D<VXL(#(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'!R;W1O7V]P=',@/2`D9'-N.PH@("`@("`@("`@("`@
M("`@)&1S;B`](&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O('!R;V-E<W,@=&AE(&1I9F9E<F5N="!P<F]T;V-O;"!O<'1I;VYS
M"B`@("`@("`@)'!A<G-E9%LG<')O=&]C;VPG72`]("@A96UP='DH)'!R;W1O
M*2D@/R`D<')O=&\@.B`G=&-P)SL*("`@("`@("`D<')O=&]?;W!T<R`](')A
M=W5R;&1E8V]D92@D<')O=&]?;W!T<RD["B`@("`@("`@:68@*"1P87)S961;
M)W!R;W1O8V]L)UT@/3T@)W1C<"<I('L*("`@("`@("`@("`@:68@*'-T<G!O
M<R@D<')O=&]?;W!T<RP@)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@(&QI<W0H)'!A<G-E9%LG:&]S='-P96,G72P*("`@("`@("`@("`@("`@
M("`@("`@)'!A<G-E9%LG<&]R="==*2`](&5X<&QO9&4H)SHG+"`D<')O=&]?
M;W!T<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<&%R<V5D6R=H;W-T<W!E8R==(#T@)'!R;W1O7V]P=',["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V5I9B`H)'!A<G-E9%LG<')O=&]C;VPG72`]/2`G
M=6YI>"<I('L*("`@("`@("`@("`@)'!A<G-E9%LG<V]C:V5T)UT@/2`D<')O
M=&]?;W!T<SL*("`@("`@("!]"@H@("`@("`@("\O($=E="!D86)A<V4@:68@
M86YY"B`@("`@("`@+R\@)&1S;B`]/B!D871A8F%S90H@("`@("`@(&EF("@D
M9'-N*2!["B`@("`@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D9'-N+"`G
M/R<I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("\O("]D871A8F%S
M90H@("`@("`@("`@("`@("`@)'!A<G-E9%LG9&%T86)A<V4G72`](')A=W5R
M;&1E8V]D92@D9'-N*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("\O("]D871A8F%S93]P87)A;3$]=F%L=64Q)G!A<F%M,CUV86QU
M93(*("`@("`@("`@("`@("`@("1P87)S961;)V1A=&%B87-E)UT@/2!R87=U
M<FQD96-O9&4H<W5B<W1R*"1D<VXL(#`L("1P;W,I*3L*("`@("`@("`@("`@
M("`@("1D<VX@/2!S=6)S='(H)&1S;BP@)'!O<R`K(#$I.PH@("`@("`@("`@
M("`@("`@:68@*'-T<G!O<R@D9'-N+"`G)B<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@("`@("1O<'1S(#T@97AP;&]D92@G)B<L("1D<VXI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L@+R\@9&%T86)A<V4_<&%R86TQ/79A
M;'5E,0H@("`@("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH)&1S;BD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M;W!T<R!A<R`D;W!T*2!["B`@("`@("`@("`@("`@("`@("`@;&ES="@D:V5Y
M+"`D=F%L=64I(#T@97AP;&]D92@G/2<L("1O<'0I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'!A<G-E9%LD:V5Y72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@9&]N)W0@86QL;W<@<&%R86US(&]V97)W<FET
M90H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R<V5D6R1K97E=(#T@<F%W
M=7)L9&5C;V1E*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'!A<G-E9#L*("`@('T*"B`@("`O+R!]?7T*?0H*+R\@?7U]
M"B\O('M[>R!C;&%S<R!$0E]%<G)O<@H*+RHJ"B`J($1"7T5R<F]R(&EM<&QE
M;65N=',@82!C;&%S<R!F;W(@<F5P;W)T:6YG('!O<G1A8FQE(&1A=&%B87-E
M(&5R<F]R"B`J(&UE<W-A9V5S"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!0
M2%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?17)R;W(@97AT96YD<R!0
M14%27T5R<F]R"GL*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@
M("`@("H@1$)?17)R;W(@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&-O9&4@("`@("`@1$(@97)R;W(@8V]D92P@;W(@<W1R:6YG
M('=I=&@@97)R;W(@;65S<V%G90H@("`@("H@0'!A<F%M(&EN="`@("1M;V1E
M("`@("`@('=H870@(F5R<F]R(&UO9&4B('1O(&]P97)A=&4@:6X*("`@("`J
M($!P87)A;2!I;G0@("`D;&5V96P@("`@("!W:&%T(&5R<F]R(&QE=F5L('1O
M('5S92!F;W(@)&UO9&4@)@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!014%27T524D]27U1224='15(*("`@("`J($!P87)A;2!M:7AE9"`D
M9&5B=6=I;F9O("!A9&1I=&EO;F%L(&1E8G5G(&EN9F\L('-U8V@@87,@=&AE
M(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`<V5E(%!%05)?17)R;W(*("`@
M("`J+PH@("`@9G5N8W1I;VX@1$)?17)R;W(H)&-O9&4@/2!$0E]%4E)/4BP@
M)&UO9&4@/2!014%27T524D]27U)%5%523BP*("`@("`@("`@("`@("`@("`@
M("`@("1L979E;"`]($5?55-%4E].3U1)0T4L("1D96)U9VEN9F\@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]I;G0H)&-O9&4I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y014%27T5R<F]R*"=$0B!%<G)O<CH@)R`N($1".CIE<G)O
M<DUE<W-A9V4H)&-O9&4I+"`D8V]D92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&UO9&4L("1L979E;"P@)&1E8G5G:6YF;RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E!%05)?17)R;W(H(D1"($5R
M<F]R.B`D8V]D92(L($1"7T524D]2+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;6]D92P@)&QE=F5L+"`D9&5B=6=I;F9O*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"GT*"B\O('U]?0HO+R![>WL@8VQA<W,@1$)?
M<F5S=6QT"@HO*BH*("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@=W)A<'!E
M<B!F;W(@82!$0B!R97-U;'0@<V5T"B`J"B`J($$@;F5W(&EN<W1A;F-E(&]F
M('1H:7,@8VQA<W,@=VEL;"!B92!R971U<FYE9"!B>2!T:&4@1$(@:6UP;&5M
M96YT871I;VX*("H@869T97(@<')O8V5S<VEN9R!A('%U97)Y('1H870@<F5T
M=7)N<R!D871A+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C
M:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H
M<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O1$(*("HO"F-L87-S($1"7W)E<W5L=`I["B`@("`O+R![>WL@<')O
M<&5R=&EE<PH*("`@("\J*@H@("`@("H@4VAO=6QD(')E<W5L=',@8F4@9G)E
M960@875T;VUA=&EC86QL>2!W:&5N('1H97)E(&%R92!N;R!M;W)E(')O=W,_
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!S964@1$)?8V]M;6]N.CHD
M;W!T:6]N<PH@("`@("HO"B`@("!V87(@)&%U=&]F<F5E.PH*("`@("\J*@H@
M("`@("H@02!R969E<F5N8V4@=&\@=&AE($1"7SQD<FEV97(^(&]B:F5C=`H@
M("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1D8F@["@H@("`@
M+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!D969A=6QT(&9E=&-H(&UO9&4*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.B1F971C
M:&UO9&4*("`@("`J+PH@("`@=F%R("1F971C:&UO9&4["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;F%M92!O9B!T:&4@8VQA<W,@:6YT;R!W:&EC:"!R97-U;'1S
M('-H;W5L9"!B92!F971C:&5D('=H96X*("`@("`J($1"7T9%5$-(34]$15]/
M0DI%0U0@:7,@:6X@969F96-T"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J($!S964@1$)?8V]M;6]N.CHD9F5T8VAM;V1E7V]B:F5C=%]C;&%S
M<PH@("`@("HO"B`@("!V87(@)&9E=&-H;6]D95]O8FIE8W1?8VQA<W,["@H@
M("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O=W,@=&\@9F5T8V@@9G)O
M;2!A(&QI;6ET('%U97)Y"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1L:6UI=%]C;W5N="`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<F]W('1O('-T87)T(&9E=&-H:6YG(&9R;VT@:6X@;&EM:70@<75E<FEE
M<PH@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D;&EM:71?
M9G)O;2`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@97AE8W5T92!P87)A
M;65T97)S('1H870@8W)E871E9"!T:&ES(')E<W5L=`H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("H@0'-I;F-E(%!R;W!E<G1Y(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-RXP"B`@("`@*B\*("`@('9A<B`D<&%R86UE=&5R<SL*"B`@
M("`O*BH*("`@("`J(%1H92!Q=65R>2!S=')I;F<@=&AA="!C<F5A=&5D('1H
M:7,@<F5S=6QT"B`@("`@*@H@("`@("H@0V]P:65D(&AE<F4@:6YC87-E(&ET
M(&-H86YG97,@:6X@)&1B:"P@=VAI8V@@:7,@<F5F97)E;F-E9`H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`<VEN8V4@4')O<&5R='D@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@=F%R("1Q
M=65R>3L*"B`@("`O*BH*("`@("`J(%1H92!Q=65R>2!R97-U;'0@<F5S;W5R
M8V4@:60@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@
M("`J+PH@("`@=F%R("1R97-U;'0["@H@("`@+RHJ"B`@("`@*B!4:&4@<')E
M<V5N="!R;W<@8F5I;F<@9&5A;'0@=VET:`H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D<F]W7V-O=6YT97(@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@5&AE('!R97!A<F5D('-T871E;65N="!R97-O=7)C92!I9"!C
M<F5A=&5D(&)Y(%!(4"!I;B`D9&)H"B`@("`@*@H@("`@("H@5&AI<R!R97-O
M=7)C92!I<R!O;FQY(&%V86EL86)L92!W:&5N('1H92!R97-U;'0@<V5T('=A
M<R!C<F5A=&5D('5S:6YG"B`@("`@*B!A(&1R:79E<B=S(&YA=&EV92!E>&5C
M=71E*"D@;65T:&]D+"!N;W0@4$5!4B!$0B=S(&5M=6QA=&5D(&]N92X*("`@
M("`J"B`@("`@*B!#;W!I960@:&5R92!I;F-A<V4@:70@8VAA;F=E<R!I;B`D
M9&)H+"!W:&EC:"!I<R!R969E<F5N8V5D"B`@("`@*@H@("`@("H@>T!I;G1E
M<FYA;"`@36%I;FQY(&AE<F4@8F5C875S92!T:&4@26YT97)"87-E+T9I<F5B
M:7)D($%022!I<R!O;FQY"B`@("`@*B!A8FQE('1O(')E=')I979E(&1A=&$@
M9G)O;2!R97-U;'0@<V5T<R!I9B!T:&4@<W1A=&5M;G0@:&%N9&QE(&ES"B`@
M("`@*B!S=&EL;"!I;B!S8V]P92Y]?0H@("`@("H*("`@("`J($!V87(@<F5S
M;W5R8V4*("`@("`J($!S:6YC92!0<F]P97)T>2!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!V87(@)'-T871E;65N=#L*"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@
M("`J(%1H:7,@8V]N<W1R=6-T;W(@<V5T<R!T:&4@;V)J96-T)W,@<')O<&5R
M=&EE<PH@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@("`F)&1B:"`@("`@
M=&AE($1"(&]B:F5C="!R969E<F5N8V4*("`@("`J($!P87)A;2!R97-O=7)C
M92`D<F5S=6QT("`@=&AE(')E<W5L="!R97-O=7)C92!I9`H@("`@("H@0'!A
M<F%M(&%R<F%Y("`@("1O<'1I;VYS("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W
M:71H(')E<W5L="!O<'1I;VYS"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED
M"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7W)E<W5L="@F)&1B:"P@)')E<W5L
M="P@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3YA
M=71O9G)E92`@("`]("1D8F@M/F]P=&EO;G-;)V%U=&]F<F5E)UT["B`@("`@
M("`@)'1H:7,M/F1B:"`@("`@("`@(#T@)B1D8F@["B`@("`@("`@)'1H:7,M
M/F9E=&-H;6]D92`@(#T@)&1B:"T^9F5T8VAM;V1E.PH@("`@("`@("1T:&ES
M+3YF971C:&UO9&5?;V)J96-T7V-L87-S(#T@)&1B:"T^9F5T8VAM;V1E7V]B
M:F5C=%]C;&%S<SL*("`@("`@("`D=&AI<RT^<&%R86UE=&5R<R`@/2`D9&)H
M+3YL87-T7W!A<F%M971E<G,["B`@("`@("`@)'1H:7,M/G%U97)Y("`@("`@
M(#T@)&1B:"T^;&%S=%]Q=65R>3L*("`@("`@("`D=&AI<RT^<F5S=6QT("`@
M("`@/2`D<F5S=6QT.PH@("`@("`@("1T:&ES+3YS=&%T96UE;G0@("`](&5M
M<'1Y*"1D8F@M/FQA<W1?<W1M="D@/R!N=6QL(#H@)&1B:"T^;&%S=%]S=&UT
M.PH@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("1T:&ES+3YS971/<'1I;VXH)&ME>2P@)'9A;'5E
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@;W!T:6]N
M<R!F;W(@=&AE($1"7W)E<W5L="!O8FIE8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1K97D@("`@=&AE(&]P=&EO;B!T;R!S970*("`@("`J($!P
M87)A;2!M:7AE9"`@)'9A;'5E("!T:&4@=F%L=64@=&\@<V5T('1H92!O<'1I
M;VX@=&\*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T3W!T:6]N*"1K97DL("1V86QU92`](&YU;&PI"B`@("![
M"B`@("`@("`@<W=I=&-H("@D:V5Y*2!["B`@("`@("`@("`@(&-A<V4@)VQI
M;6ET7V9R;VTG.@H@("`@("`@("`@("`@("`@)'1H:7,M/FQI;6ET7V9R;VT@
M/2`D=F%L=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M8V%S92`G;&EM:71?8V]U;G0G.@H@("`@("`@("`@("`@("`@)'1H:7,M/FQI
M;6ET7V-O=6YT(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!F971C:%)O=R@I"@H@("`@+RHJ"B`@("`@*B!&971C
M:"!A(')O=R!O9B!D871A(&%N9"!R971U<FX@:70@8GD@<F5F97)E;F-E(&EN
M=&\@86X@87)R87D*("`@("`J"B`@("`@*B!4:&4@='EP92!O9B!A<G)A>2!R
M971U<FYE9"!C86X@8F4@8V]N=')O;&QE9"!E:71H97(@8GD@<V5T=&EN9R!T
M:&ES"B`@("`@*B!M971H;V0G<R`\=F%R/B1F971C:&UO9&4\+W9A<CX@<&%R
M86UE=&5R(&]R(&)Y(&-H86YG:6YG('1H92!D969A=6QT"B`@("`@*B!F971C
M:"!M;V1E('-E=$9E=&-H36]D92@I(&)E9F]R92!C86QL:6YG('1H:7,@;65T
M:&]D+@H@("`@("H*("`@("`J(%1H97)E(&%R92!T=V\@;W!T:6]N<R!F;W(@
M<W1A;F1A<F1I>FEN9R!T:&4@:6YF;W)M871I;VX@<F5T=7)N960*("`@("`J
M(&9R;VT@9&%T86)A<V5S+"!E;G-U<FEN9R!T:&5I<B!V86QU97,@87)E(&-O
M;G-I<W1E;G0@=VAE;B!C:&%N9VEN9PH@("`@("H@1$)-4R=S+B`@5&AE<V4@
M<&]R=&%B:6QI='D@;W!T:6]N<R!C86X@8F4@='5R;F5D(&]N('=H96X@8W)E
M871I;F<@80H@("`@("H@;F5W($1"(&]B:F5C="!O<B!B>2!U<VEN9R!S971/
M<'1I;VXH*2X*("`@("`J"B`@("`@*B`@("L@/'9A<CY$0E]03U)404))3$E4
M65],3U=%4D-!4T4\+W9A<CX*("`@("`J("`@("!C;VYV97)T(&YA;65S(&]F
M(&9I96QD<R!T;R!L;W=E<B!C87-E"B`@("`@*@H@("`@("H@("`K(#QV87(^
M1$)?4$]25$%"24Q)5%E?4E1224T\+W9A<CX*("`@("`J("`@("!R:6=H="!T
M<FEM('1H92!D871A"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D9F5T8VAM
M;V1E("!T:&4@8V]N<W1A;G0@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H
M92!D871A"B`@("`@*B!`<&%R86T@:6YT("1R;W=N=6T@("`@('1H92!R;W<@
M;G5M8F5R('1O(&9E=&-H("AI;F1E>"!S=&%R=',@870@,"D*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!A;B!A<G)A>2!O<B!O8FIE8W0@8V]N=&%I
M;FEN9R!T:&4@<F]W)W,@9&%T82P*("`@("`J("`@("`@("`@("`@("`@("!.
M54Q,('=H96X@=&AE(&5N9"!O9B!T:&4@<F5S=6QT('-E="!I<R!R96%C:&5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@;W(@82!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T
M3W!T:6]N*"DL($1"7V-O;6UO;CHZ<V5T1F5T8VA-;V1E*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F9E=&-H4F]W*"1F971C:&UO9&4@/2!$0E]&151#2$U/
M1$5?1$5&055,5"P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"1F971C:&UO9&4@/3T]($1"7T9%5$-(34]$15]$149!54Q4*2!["B`@("`@
M("`@("`@("1F971C:&UO9&4@/2`D=&AI<RT^9F5T8VAM;V1E.PH@("`@("`@
M('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`]/3T@1$)?1D540TA-3T1%7T]"
M2D5#5"D@>PH@("`@("`@("`@("`D9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%
M7T%34T]#.PH@("`@("`@("`@("`D;V)J96-T7V-L87-S(#T@)'1H:7,M/F9E
M=&-H;6]D95]O8FIE8W1?8VQA<W,["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^;&EM:71?9G)O;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/G)O=U]C;W5N=&5R(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<F]W7V-O=6YT97(@/2`D=&AI<RT^;&EM:71?9G)O;3L*("`@
M("`@("`@("`@("`@("\O(%-K:7`@<F]W<PH@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YD8F@M/F9E871U<F5S6R=L:6UI="==(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@("`@("`@
M("!W:&EL92`H)&DK*R`\("1T:&ES+3YL:6UI=%]F<F]M*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YD8F@M/F9E=&-H26YT;R@D=&AI<RT^
M<F5S=6QT+"`D87)R+"`D9F5T8VAM;V1E*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1T:&ES+3YR;W=?8V]U;G1E<B`^/2`H)'1H:7,M/FQI;6ET7V9R
M;VT@*R`D=&AI<RT^;&EM:71?8V]U;G0I*0H@("`@("`@("`@("!["B`@("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/F%U=&]F<F5E*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1T;7`@/2!N=6QL.PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T;7`["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES
M+3YD8F@M/F9E871U<F5S6R=L:6UI="==(#T]/2`G96UU;&%T92<I('L*("`@
M("`@("`@("`@("`@("1R;W=N=6T@/2`D=&AI<RT^<F]W7V-O=6YT97(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/G)O=U]C;W5N=&5R*RL[
M"B`@("`@("`@?0H@("`@("`@("1R97,@/2`D=&AI<RT^9&)H+3YF971C:$EN
M=&\H)'1H:7,M/G)E<W5L="P@)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;2D[
M"B`@("`@("`@:68@*"1R97,@/3T]($1"7T]+*2!["B`@("`@("`@("`@(&EF
M("AI<W-E="@D;V)J96-T7V-L87-S*2D@>PH@("`@("`@("`@("`@("`@+R\@
M5&AE(&1E9F%U;'0@;6]D92!I<R!S<&5C:69I960@:6X@=&AE"B`@("`@("`@
M("`@("`@("`O+R!$0E]C;VUM;VXZ.F9E=&-H;6]D95]O8FIE8W1?8VQA<W,@
M<')O<&5R='D*("`@("`@("`@("`@("`@(&EF("@D;V)J96-T7V-L87-S(#T]
M("=S=&1#;&%S<R<I('L*("`@("`@("`@("`@("`@("`@("`D87)R(#T@*&]B
M:F5C="D@)&%R<CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&%R<B`]("9N97<@)&]B:F5C=%]C;&%S<R@D87)R*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)&%R<CL*("`@("`@("!]"B`@("`@("`@:68@*"1R97,@/3T@;G5L
M;"`F)B`D=&AI<RT^875T;V9R964I('L*("`@("`@("`@("`@)'1H:7,M/F9R
M964H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@
M("`J($9E=&-H(&$@<F]W(&]F(&1A=&$@:6YT;R!A;B!A<G)A>2!W:&EC:"!I
M<R!P87-S960@8GD@<F5F97)E;F-E"B`@("`@*@H@("`@("H@5&AE('1Y<&4@
M;V8@87)R87D@<F5T=7)N960@8V%N(&)E(&-O;G1R;VQL960@96ET:&5R(&)Y
M('-E='1I;F<@=&AI<PH@("`@("H@;65T:&]D)W,@/'9A<CXD9F5T8VAM;V1E
M/"]V87(^('!A<F%M971E<B!O<B!B>2!C:&%N9VEN9R!T:&4@9&5F875L=`H@
M("`@("H@9F5T8V@@;6]D92!S971&971C:$UO9&4H*2!B969O<F4@8V%L;&EN
M9R!T:&ES(&UE=&AO9"X*("`@("`J"B`@("`@*B!4:&5R92!A<F4@='=O(&]P
M=&EO;G,@9F]R('-T86YD87)D:7II;F<@=&AE(&EN9F]R;6%T:6]N(')E='5R
M;F5D"B`@("`@*B!F<F]M(&1A=&%B87-E<RP@96YS=7)I;F<@=&AE:7(@=F%L
M=65S(&%R92!C;VYS:7-T96YT('=H96X@8VAA;F=I;F<*("`@("`J($1"35,G
M<RX@(%1H97-E('!O<G1A8FEL:71Y(&]P=&EO;G,@8V%N(&)E('1U<FYE9"!O
M;B!W:&5N(&-R96%T:6YG(&$*("`@("`J(&YE=R!$0B!O8FIE8W0@;W(@8GD@
M=7-I;F<@<V5T3W!T:6]N*"DN"B`@("`@*@H@("`@("H@("`K(#QV87(^1$)?
M4$]25$%"24Q)5%E?3$]715)#05-%/"]V87(^"B`@("`@*B`@("`@8V]N=F5R
M="!N86UE<R!O9B!F:65L9',@=&\@;&]W97(@8V%S90H@("`@("H*("`@("`J
M("`@*R`\=F%R/D1"7U!/4E1!0DE,25197U)44DE-/"]V87(^"B`@("`@*B`@
M("`@<FEG:'0@=')I;2!T:&4@9&%T80H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`F)&%R<B`@("`@("!T:&4@=F%R:6%B;&4@=VAE<F4@=&AE(&1A=&$@
M<VAO=6QD(&)E('!L86-E9`H@("`@("H@0'!A<F%M(&EN="`@("1F971C:&UO
M9&4@('1H92!C;VYS=&%N="!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE
M(&1A=&$*("`@("`J($!P87)A;2!I;G0@("`D<F]W;G5M("`@("!T:&4@<F]W
M(&YU;6)E<B!T;R!F971C:"`H:6YD97@@<W1A<G1S(&%T(#`I"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@:68@82!R;W<@:7,@<')O8V5S
M<V5D+"!.54Q,('=H96X@=&AE(&5N9"!O9B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("!R97-U;'0@<V5T(&ES(')E86-H960@;W(@82!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CIS971/<'1I;VXH*2P@1$)?8V]M;6]N.CIS971&971C:$UO9&4H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)B1A<G(L("1F971C:&UO9&4@
M/2!$0E]&151#2$U/1$5?1$5&055,5"P@)')O=VYU;2`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*"1F971C:&UO9&4@/3T]($1"7T9%5$-(34]$15]$149!
M54Q4*2!["B`@("`@("`@("`@("1F971C:&UO9&4@/2`D=&AI<RT^9F5T8VAM
M;V1E.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`]/3T@1$)?
M1D540TA-3T1%7T]"2D5#5"D@>PH@("`@("`@("`@("`D9F5T8VAM;V1E(#T@
M1$)?1D540TA-3T1%7T%34T]#.PH@("`@("`@("`@("`D;V)J96-T7V-L87-S
M(#T@)'1H:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^;&EM:71?9G)O;2`A/3T@;G5L;"D@>PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/G)O=U]C;W5N=&5R(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<F]W7V-O=6YT97(@/2`D=&AI<RT^;&EM
M:71?9G)O;3L*("`@("`@("`@("`@("`@("\O(%-K:7`@<F]W<PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YD8F@M/F9E871U<F5S6R=L:6UI="==(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1I(#T@,#L*("`@("`@
M("`@("`@("`@("`@("!W:&EL92`H)&DK*R`\("1T:&ES+3YL:6UI=%]F<F]M
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD8F@M/F9E=&-H
M26YT;R@D=&AI<RT^<F5S=6QT+"`D87)R+"`D9F5T8VAM;V1E*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1T:&ES+3YR;W=?8V]U;G1E<B`^/2`H"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQI;6ET7V9R;VT@*R`D=&AI<RT^
M;&EM:71?8V]U;G0I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/F%U=&]F<F5E*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F9R964H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^9&)H+3YF96%T=7)E<ULG;&EM:70G72`]/3T@)V5M=6QA=&4G*2![
M"B`@("`@("`@("`@("`@("`D<F]W;G5M(#T@)'1H:7,M/G)O=U]C;W5N=&5R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^<F]W7V-O=6YT
M97(K*SL*("`@("`@("!]"B`@("`@("`@)')E<R`]("1T:&ES+3YD8F@M/F9E
M=&-H26YT;R@D=&AI<RT^<F5S=6QT+"`D87)R+"`D9F5T8VAM;V1E+"`D<F]W
M;G5M*3L*("`@("`@("!I9B`H)')E<R`]/3T@1$)?3TLI('L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1O8FIE8W1?8VQA<W,I*2!["B`@("`@("`@("`@("`@
M("`O+R!D969A=6QT(&UO9&4@<W!E8VEF:65D(&EN('1H90H@("`@("`@("`@
M("`@("`@+R\@1$)?8V]M;6]N.CIF971C:&UO9&5?;V)J96-T7V-L87-S('!R
M;W!E<G1Y"B`@("`@("`@("`@("`@("!I9B`H)&]B:F5C=%]C;&%S<R`]/2`G
M<W1D0VQA<W,G*2!["B`@("`@("`@("`@("`@("`@("`@)&%R<B`]("AO8FIE
M8W0I("1A<G(["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1A<G(@/2!N97<@)&]B:F5C=%]C;&%S<R@D87)R*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@1$)?3TL["B`@("`@("`@?0H@("`@("`@(&EF("@D<F5S(#T](&YU;&P@
M)B8@)'1H:7,M/F%U=&]F<F5E*2!["B`@("`@("`@("`@("1T:&ES+3YF<F5E
M*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L
M=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YU;4-O;',H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9&)H+3YN=6U#;VQS*"1T:&ES+3YR97-U;'0I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;G5M4F]W<R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YD8F@M/F9E
M871U<F5S6R=N=6UR;W=S)UT@/3T]("=E;75L871E)PH@("`@("`@("`@("`F
M)B`D=&AI<RT^9&)H+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?3E5-4D]74RD*("`@("`@("!["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^9&)H+3YF96%T=7)E<ULG<')E<&%R92==*2!["B`@("`@("`@("`@
M("`@("`D<F5S(#T@)'1H:7,M/F1B:"T^<75E<GDH)'1H:7,M/G%U97)Y+"`D
M=&AI<RT^<&%R86UE=&5R<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F1B:"T^<75E<GDH)'1H:7,M/G%U
M97)Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@=VAI
M;&4@*"1R97,M/F9E=&-H26YT;R@D=&UP+"!$0E]&151#2$U/1$5?3U)$15)%
M1"DI('L*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9&)H+3YN=6U2;W=S*"1T:&ES+3YR97-U;'0I
M.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT
M4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@;F5X="!R97-U;'0@
M:68@82!B871C:"!O9B!Q=65R:65S('=A<R!E>&5C=71E9`H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;"`@=')U92!I9B!A(&YE=R!R97-U;'0@:7,@879A
M:6QA8FQE(&]R(&9A;'-E(&EF(&YO=`H@("`@("HO"B`@("!F=6YC=&EO;B!N
M97AT4F5S=6QT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1B:"T^
M;F5X=%)E<W5L="@D=&AI<RT^<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!F<F5E*"D*"B`@("`O*BH*("`@("`J($9R965S('1H92!R
M97-O=7)C97,@86QL;V-A=&5D(&9O<B!T:&ES(')E<W5L="!S970*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@('1R=64@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&9R964H*0H@("`@>PH@("`@("`@("1E<G(@/2`D=&AI<RT^9&)H+3YF<F5E
M4F5S=6QT*"1T:&ES+3YR97-U;'0I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D97)R*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/G)E<W5L="`](&9A;'-E.PH@("`@("`@("1T:&ES
M+3YS=&%T96UE;G0@/2!F86QS93L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B!`
M9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E9"!S;VUE('1I;64@8F5F;W)E
M(%)E;&5A<V4@,2XR"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D
M;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D;6]D
M92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD8F@M/G)A:7-E17)R
M;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/F1B:"T^=&%B;&5);F9O*"1T:&ES+"`D;6]D92D[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T475E<GDH*0H*("`@
M("\J*@H@("`@("H@1&5T97)M:6YE('1H92!Q=65R>2!S=')I;F<@=&AA="!C
M<F5A=&5D('1H:7,@<F5S=6QT"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<VEN8V4@365T
M:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%%U97)Y*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%)O
M=T-O=6YT97(H*0H*("`@("\J*@H@("`@("H@5&5L;',@=VAI8V@@<F]W(&YU
M;6)E<B!I<R!C=7)R96YT;'D@8F5I;F<@<')O8V5S<V5D"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!T:&4@8W5R<F5N="!R;W<@8F5I;F<@;&]O
M:V5D(&%T+B`@4W1A<G1S(&%T(#$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%)O=T-O=6YT97(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F]W
M7V-O=6YT97(["B`@("!]"@H@("`@+R\@?7U]"GT*"B\O('U]?0HO+R![>WL@
M8VQA<W,@1$)?<F]W"@HO*BH*("H@4$5!4B!$0B!2;W<@3V)J96-T"B`J"B`J
M(%1H92!O8FIE8W0@8V]N=&%I;G,@82!R;W<@;V8@9&%T82!F<F]M(&$@<F5S
M=6QT('-E="X@($5A8V@@8V]L=6UN)W,@9&%T80H@*B!I<R!P;&%C960@:6X@
M82!P<F]P97)T>2!N86UE9"!F;W(@=&AE(&-O;'5M;BX*("H*("H@0&-A=&5G
M;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@
M("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J($!S964@("`@("`@
M($1"7V-O;6UO;CHZ<V5T1F5T8VA-;V1E*"D*("HO"F-L87-S($1"7W)O=PI[
M"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H92!C
M;VYS=')U8W1O<B!P;&%C97,@82!R;W<G<R!D871A(&EN=&\@<')O<&5R=&EE
M<R!O9B!T:&ES(&]B:F5C=`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@
M=&AE(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(')O=R=S(&1A=&$*("`@("`J"B`@
M("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?<F]W
M*"8D87)R*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1A<G(@87,@)&ME>2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`F)&%R<ELD
M:V5Y73L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"GT*"B\O('U]?0H*
M+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB
M87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4WES=&5M+G!H<```````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-#8W-C0`,3`U,34T,S$P-3<`,#$W,S4W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J($9I;&4O1&ER96-T;W)Y(&UA;FEP=6QA=&EO;@T*("H-"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%-Y<W1E;0T*("H@0&%U=&AO
M<B`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%-Y<W1E;2YP
M:'`L=B`Q+C4S(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`P+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER
M95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)T-O;G-O;&4O1V5T
M;W!T+G!H<"<[#0H-"B1'3$]"04Q36R=?4WES=&5M7W1E;7!?9FEL97,G72`]
M(&%R<F%Y*"D[#0H-"B\J*@T**B!3>7-T96T@;V9F97)S(&-R;W-S('!L871T
M9F]R;2!C;VUP871I8FQE('-Y<W1E;2!F=6YC=&EO;G,-"BH-"BH@4W1A=&EC
M(&9U;F-T:6]N<R!F;W(@9&EF9F5R96YT(&]P97)A=&EO;G,N(%-H;W5L9"!W
M;W)K('5N9&5R#0HJ(%5N:7@@86YD(%=I;F1O=W,N(%1H92!N86UE<R!A;F0@
M=7-A9V4@:&%S(&)E96X@=&%K96X@9G)O;2!I=',@<F5S<&5C=&EV96QY#0HJ
M($=.52!C;VUM86YD<RX@5&AE(&9U;F-T:6]N<R!W:6QL(')E='5R;B`H8F]O
M;"D@9F%L<V4@;VX@97)R;W(@86YD('=I;&P-"BH@=')I9V=E<B!T:&4@97)R
M;W(@=VET:"!T:&4@4$A0('1R:6=G97)?97)R;W(H*2!F=6YC=&EO;B`H>6]U
M(&-A;B!S:6QE;F-E#0HJ('1H92!E<G)O<B!B>2!P<F5F:7AI;F<@82`G0"<@
M<VEG;B!A9G1E<B!T:&4@9G5N8W1I;VX@8V%L;"DN#0HJ#0HJ($1O8W5M96YT
M871I;VX@;VX@=&AI<R!C;&%S<R!Y;W4@8V%N(&9I;F0@:6XZ#0HJ(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+PT**@T**B!%>&%M<&QE('5S86=E.@T*
M*B!I9B`H(4!3>7-T96TZ.G)M*"<M<B!F:6QE,2!D:7(Q)RDI('L-"BH@("`@
M<')I;G0@(F-O=6QD(&YO="!D96QE=&4@9FEL93$@;W(@9&ER,2([#0HJ('T-
M"BH-"BH@26X@8V%S92!Y;W4@;F5E9"!T;R!T;R!P87-S(&9I;&4@;F%M97,@
M=VET:"!S<&%C97,L#0HJ('!A<W,@=&AE('!A<F%M<R!A<R!A;B!A<G)A>3H-
M"BH-"BH@4WES=&5M.CIR;2AA<G)A>2@G+7(G+"`D9FEL93$L("1D:7(Q*2D[
M#0HJ#0HJ($!C871E9V]R>2`@('!E87(-"BH@0'!A8VMA9V4@("`@4WES=&5M
M#0HJ($!A=71H;W(@("`@(%1O;6%S(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC
M;VT^#0HJ($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0HJ
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T**B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C0N.0T**B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T**B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`P+C$-"BHO#0IC;&%S<R!3>7-T96T-"GL-"B`@("`O*BH-"B`@
M("`J(')E='5R;G,@=&AE(&-O;6UA;F1L:6YE(&%R9W5M96YT<R!O9B!A(&9U
M;F-T:6]N#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&%R9W8@
M("`@("`@("`@('1H92!C;VUM86YD;&EN90T*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@)'-H;W)T7V]P=&EO;G,@('1H92!A;&QO=V5D(&]P=&EO;B!S:&]R
M="UT86=S#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D;&]N9U]O<'1I;VYS
M("`@=&AE(&%L;&]W960@;W!T:6]N(&QO;F<M=&%G<PT*("`@("H@0')E='5R
M;B`@(&%R<F%Y("`@=&AE(&=I=F5N(&]P=&EO;G,@86YD('1H97)E('9A;'5E
M<PT*("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!?<&%R<V5!<F=S*"1A<F=V+"`D<VAO<G1?;W!T:6]N<RP@)&QO;F=?;W!T
M:6]N<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A
M<F=V*2`F)B`D87)G=B`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&%R9W8@
M/2!P<F5G7W-P;&ET*"<O7',K+R<L("1A<F=V+"`M,2P@4%)%1U]34$Q)5%].
M3U]%35!462D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N($-O;G-O;&5?
M1V5T;W!T.CIG971O<'0R*"1A<F=V+"`D<VAO<G1?;W!T:6]N<RD[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@*B!/=71P=70@97)R;W)S('=I=&@@4$A0('1R
M:6=G97)?97)R;W(H*2X@66]U(&-A;B!S:6QE;F-E('1H92!E<G)O<G,-"B`@
M("`J('=I=&@@<')E9FEX:6YG(&$@(D`B('-I9VX@=&\@=&AE(&9U;F-T:6]N
M(&-A;&PZ($!3>7-T96TZ.FUK9&ER*"XN*3L-"B`@("`J#0H@("`@*B!`<&%R
M86T@;6EX960@)&5R<F]R(&$@4$5!4B!E<G)O<B!O<B!A('-T<FEN9R!W:71H
M('1H92!E<G)O<B!M97-S86=E#0H@("`@*B!`<F5T=7)N(&)O;VP@9F%L<V4-
M"B`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@
M<F%I<V5%<G)O<B@D97)R;W(I#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D97)R;W(I*2![#0H@("`@("`@("`@("`D97)R;W(@/2`D97)R
M;W(M/F=E=$UE<W-A9V4H*3L-"B`@("`@("`@?0T*("`@("`@("!T<FEG9V5R
M7V5R<F]R*"1E<G)O<BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!#<F5A=&5S(&$@
M;F5S=&5D(&%R<F%Y(')E<')E<V5N=&EN9R!T:&4@<W1R=6-T=7)E(&]F(&$@
M9&ER96-T;W)Y#0H@("`@*@T*("`@("H@4WES=&5M.CI?9&ER5&]3=')U8W0H
M)V1I<C$G+"`P*2`]/@T*("`@("H@("!!<G)A>0T*("`@("H@("`@*`T*("`@
M("H@("`@6V1I<G-=(#T^($%R<F%Y#0H@("`@*B`@("`@("`@*`T*("`@("H@
M("`@("`@("`@("!;,%T@/3X@9&ER,0T*("`@("H@("`@("`@("D-"B`@("`J
M#0H@("`@*B`@("!;9FEL97-=(#T^($%R<F%Y#0H@("`@*B`@("`@("`@*`T*
M("`@("H@("`@("`@("`@("!;,%T@/3X@9&ER,2]F:6QE,@T*("`@("H@("`@
M("`@("`@("!;,5T@/3X@9&ER,2]F:6QE,PT*("`@("H@("`@("`@("D-"B`@
M("`J("`@("D-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1S4&%T:"`@("`@
M($YA;64@;V8@=&AE(&1I<F5C=&]R>0T*("`@("H@0'!A<F%M("`@(&EN=&5G
M97(@)&UA>&EN<W0@("`@;6%X+B!D965P(&]F('1H92!L;V]K=7`-"B`@("`J
M($!P87)A;2`@("!I;G1E9V5R("1A:W1I;G-T("`@('-T87)T:6YG(&1E97`@
M;V8@=&AE(&QO;VMU<`T*("`@("H@0')E='5R;B`@(&%R<F%Y("`@=&AE('-T
M<G5C='5R92!O9B!T:&4@9&ER#0H@("`@*B!`86-C97-S("`@<')I=F%T90T*
M("`@("HO#0H-"B`@("!F=6YC=&EO;B!?9&ER5&]3=')U8W0H)'-0871H+"`D
M;6%X:6YS="P@)&%K=&EN<W0@/2`P*0T*("`@('L-"B`@("`@("`@)'-T<G5C
M="`](&%R<F%Y*"=D:7)S)R`]/B!A<G)A>2@I+"`G9FEL97,G(#T^(&%R<F%Y
M*"DI.PT*("`@("`@("!I9B`H*"1D:7(@/2!`;W!E;F1I<B@D<U!A=&@I*2`]
M/3T@9F%L<V4I('L-"B`@("`@("`@("`@(%-Y<W1E;3HZ<F%I<V5%<G)O<B@B
M0V]U;&0@;F]T(&]P96X@9&ER("1S4&%T:"(I.PT*("`@("`@("`@("`@<F5T
M=7)N("1S=')U8W0[("\O(%A86"!C;W5L9"!N;W0@;W!E;B!E<G)O<@T*("`@
M("`@("!]#0H@("`@("`@("1S=')U8W1;)V1I<G,G75M=(#T@)'-0871H(#T@
M<F5A;'!A=&@H)'-0871H*3L@+R\@6%A8(&1O;B=T(&%D9"!I9B`G+B<@;W(@
M)RXN)R`_#0H@("`@("`@("1L:7-T(#T@87)R87DH*3L-"B`@("`@("`@=VAI
M;&4@*&9A;'-E("$]/2`H)&9I;&4@/2!R96%D9&ER*"1D:7(I*2D@>PT*("`@
M("`@("`@("`@:68@*"1F:6QE("$]("<N)R`F)B`D9FEL92`A/2`G+BXG*2![
M#0H@("`@("`@("`@("`@("`@)&QI<W1;72`]("1F:6QE.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&-L;W-E9&ER*"1D:7(I.PT*("`@
M("`@("!S;W)T*"1L:7-T*3L-"B`@("`@("`@:68@*"1A:W1I;G-T(#P@)&UA
M>&EN<W0@?'P@)&UA>&EN<W0@/3T@,"D@>PT*("`@("`@("`@("`@9F]R96%C
M:"@D;&ES="!A<R`D=F%L*2![#0H@("`@("`@("`@("`@("`@)'!A=&@@/2`D
M<U!A=&@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'9A;#L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-?9&ER*"1P871H*2`F)B`A:7-?;&EN:R@D<&%T:"DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1M<"`](%-Y<W1E;3HZ7V1I<E1O
M4W1R=6-T*"1P871H+"`D;6%X:6YS="P@)&%K=&EN<W0K,2D[#0H@("`@("`@
M("`@("`@("`@("`@("1S=')U8W0@/2!A<G)A>5]M97)G95]R96-U<G-I=F4H
M)'1M<"P@)'-T<G5C="D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)'-T<G5C=%LG9FEL97,G75M=(#T@)'!A=&@[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D<W1R=6-T.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("H@0W)E871E<R!A(&YE<W1E9"!A<G)A>2!R97!R97-E;G1I;F<@=&AE
M('-T<G5C='5R92!O9B!A(&1I<F5C=&]R>2!A;F0@9FEL97,-"B`@("`J#0H@
M("`@*B!`<&%R86T@("`@87)R87D@)&9I;&5S($%R<F%Y(&QI<W1I;F<@9FEL
M97,@86YD(&1I<G,-"B`@("`J($!R971U<FX@("!A<G)A>0T*("`@("H@0'-E
M92!3>7-T96TZ.E]D:7)4;U-T<G5C="@I#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!?;75L=&EP;&54;U-T<G5C="@D9FEL97,I#0H@("`@>PT*("`@("`@("`D
M<W1R=6-T(#T@87)R87DH)V1I<G,G(#T^(&%R<F%Y*"DL("=F:6QE<R<@/3X@
M87)R87DH*2D[#0H@("`@("`@('-E='1Y<&4H)&9I;&5S+"`G87)R87DG*3L-
M"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE*2![#0H@("`@("`@
M("`@("!I9B`H:7-?9&ER*"1F:6QE*2`F)B`A:7-?;&EN:R@D9FEL92DI('L-
M"B`@("`@("`@("`@("`@("`D=&UP(#T@4WES=&5M.CI?9&ER5&]3=')U8W0H
M)&9I;&4L(#`I.PT*("`@("`@("`@("`@("`@("1S=')U8W0@/2!A<G)A>5]M
M97)G95]R96-U<G-I=F4H)'1M<"P@)'-T<G5C="D[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1S=')U8W1;)V9I;&5S)UU;72`]
M("1F:6QE.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D<W1R=6-T.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@5&AE(')M
M(&-O;6UA;F0@9F]R(')E;6]V:6YG(&9I;&5S+@T*("`@("H@4W5P<&]R=',@
M;75L=&EP;&4@9FEL97,@86YD(&1I<G,@86YD(&%L<V\@<F5C=7)S:79E(&1E
M;&5T97,-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D87)G<R`@
M('1H92!A<F=U;65N=',@9F]R(')M#0H@("`@*B!`<F5T=7)N("`@;6EX960@
M("!014%27T5R<F]R(&]R('1R=64@9F]R('-U8V-E<W,-"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(')M*"1A<F=S*0T*
M("`@('L-"B`@("`@("`@)&]P=',@/2!3>7-T96TZ.E]P87)S94%R9W,H)&%R
M9W,L("=R9B<I.R`O+R`B9B(@9&\@;F]T:&EN9R!B=70@;&EK92!I="`Z+2D-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]P=',I*2![#0H@("`@("`@
M("`@("!R971U<FX@4WES=&5M.CIR86ES945R<F]R*"1O<'1S*3L-"B`@("`@
M("`@?0T*("`@("`@("!F;W)E86-H*"1O<'1S6S!=(&%S("1O<'0I('L-"B`@
M("`@("`@("`@(&EF("@D;W!T6S!=(#T]("=R)RD@>PT*("`@("`@("`@("`@
M("`@("1D;U]R96-U<G-I=F4@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1R970@/2!T<G5E.PT*("`@("`@("!I9B`H:7-S
M970H)&1O7W)E8W5R<VEV92DI('L-"B`@("`@("`@("`@("1S=')U8W0@/2!3
M>7-T96TZ.E]M=6QT:7!L951O4W1R=6-T*"1O<'1S6S%=*3L-"B`@("`@("`@
M("`@(&9O<F5A8V@H)'-T<G5C=%LG9FEL97,G72!A<R`D9FEL92D@>PT*("`@
M("`@("`@("`@("`@(&EF("@A0'5N;&EN:R@D9FEL92DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E="`](&9A;'-E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@H)'-T<G5C=%LG
M9&ER<R==(&%S("1D:7(I('L-"B`@("`@("`@("`@("`@("!I9B`H(4!R;61I
M<B@D9&ER*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@9F%L<V4[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&]P='-;,5T@87,@)&9I
M;&4I('L-"B`@("`@("`@("`@("`@("`D9&5L971E(#T@*&ES7V1I<B@D9FEL
M92DI(#\@)W)M9&ER)R`Z("=U;FQI;FLG.PT*("`@("`@("`@("`@("`@(&EF
M("@A0"1D96QE=&4H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1R
M970@/2!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@*B!-86ME(&1I<F5C=&]R:65S+@T*("`@("H-"B`@("`J
M(%1H92`M<"!O<'1I;VX@=VEL;"!C<F5A=&4@<&%R96YT(&1I<F5C=&]R:65S
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D87)G<R`@("!T:&4@;F%M92!O
M9B!T:&4@9&ER96-T;W(H>7QI97,I('1O(&-R96%T90T*("`@("H@0')E='5R
M;B`@(&)O;VP@("`@5')U92!F;W(@<W5C8V5S<PT*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@;6M$:7(H)&%R9W,I#0H@
M("`@>PT*("`@("`@("`D;W!T<R`](%-Y<W1E;3HZ7W!A<G-E07)G<R@D87)G
M<RP@)W!M.B<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;W!T<RDI
M('L-"B`@("`@("`@("`@(')E='5R;B!3>7-T96TZ.G)A:7-E17)R;W(H)&]P
M=',I.PT*("`@("`@("!]#0H@("`@("`@("1M;V1E(#T@,#<W-SL@+R\@9&5F
M875L="!M;V1E#0H@("`@("`@(&9O<F5A8V@H)&]P='-;,%T@87,@)&]P="D@
M>PT*("`@("`@("`@("`@:68@*"1O<'1;,%T@/3T@)W`G*2![#0H@("`@("`@
M("`@("`@("`@)&-R96%T95]P87)E;G1S(#T@=')U93L-"B`@("`@("`@("`@
M('T@96QS96EF*"1O<'1;,%T@/3T@)VTG*2![#0H@("`@("`@("`@("`@("`@
M+R\@:68@=&AE(&UO9&4@:7,@8VQE87)L>2!A;B!O8W1A;"!N=6UB97(@*'-T
M87)T<R!W:71H(#`I#0H@("`@("`@("`@("`@("`@+R\@8V]N=F5R="!I="!T
M;R!D96-I;6%L#0H@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D;W!T6S%=
M*2`F)B`D;W!T6S%=>S!](#T]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D;W!T6S%=(#T@;V-T9&5C*"1O<'1;,5TI.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("\O(&-O;G9E<G0@=&\@
M:6YT#0H@("`@("`@("`@("`@("`@("`@("1O<'1;,5T@*ST@,#L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&UO9&4@/2`D;W!T6S%=
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1R970@/2!T
M<G5E.PT*("`@("`@("!I9B`H:7-S970H)&-R96%T95]P87)E;G1S*2D@>PT*
M("`@("`@("`@("`@9F]R96%C:"@D;W!T<ULQ72!A<R`D9&ER*2![#0H@("`@
M("`@("`@("`@("`@)&1I<G-T86-K(#T@87)R87DH*3L-"B`@("`@("`@("`@
M("`@("!W:&EL92`H(4!I<U]D:7(H)&1I<BD@)B8@)&1I<B`A/2!$25)%0U1/
M4EE?4T5005)!5$]2*2![#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W5N
M<VAI9G0H)&1I<G-T86-K+"`D9&ER*3L-"B`@("`@("`@("`@("`@("`@("`@
M)&1I<B`](&1I<FYA;64H)&1I<BD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('=H:6QE("@D;F5W9&ER(#T@87)R87E?<VAI9G0H)&1I
M<G-T86-K*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7W=R:71E
M86)L92AD:7)N86UE*"1N97=D:7(I*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E="`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%M:V1I<B@D;F5W9&ER+"`D;6]D92DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&9O<F5A8V@H)&]P='-;,5T@
M87,@)&1I<BD@>PT*("`@("`@("`@("`@("`@(&EF("@A0&ES7V1I<B@D9&ER
M*2`F)B`A;6MD:7(H)&1I<BP@)&UO9&4I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1R970@/2!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@*B!#;VYC871E;F%T92!F:6QE<PT*("`@("H-
M"B`@("`J(%5S86=E.@T*("`@("H@,2D@)'9A<B`](%-Y<W1E;3HZ8V%T*"=S
M86UP;&4N='AT('1E<W0N='AT)RD[#0H@("`@*B`R*2!3>7-T96TZ.F-A="@G
M<V%M<&QE+G1X="!T97-T+G1X="`^(&9I;F%L+G1X="<I.PT*("`@("H@,RD@
M4WES=&5M.CIC870H)W-A;7!L92YT>'0@=&5S="YT>'0@/CX@9FEN86PN='AT
M)RD[#0H@("`@*@T*("`@("H@3F]T93H@87,@=&AE(&-L87-S('5S92!F;W!E
M;BP@=7)L<R!S:&]U;&0@=V]R:R!A;'-O("AT97-T('1H870I#0H@("`@*@T*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&%R9W,@("!T:&4@87)G=6UE;G1S
M#0H@("`@*B!`<F5T=7)N("`@8F]O;&5A;B!T<G5E(&]N('-U8V-E<W,-"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N("9C
M870H)&%R9W,I#0H@("`@>PT*("`@("`@("`D<F5T(#T@;G5L;#L-"B`@("`@
M("`@)&9I;&5S(#T@87)R87DH*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D
M87)G<RDI('L-"B`@("`@("`@("`@("1A<F=S(#T@<')E9U]S<&QI="@G+UQS
M*R\G+"`D87)G<RP@+3$L(%!214=?4U!,251?3D]?14U05%DI.PT*("`@("`@
M("!]#0H@("`@("`@(&9O<B@D:3TP.R`D:2`\(&-O=6YT*"1A<F=S*3L@)&DK
M*RD@>PT*("`@("`@("`@("`@:68@*"1A<F=S6R1I72`]/2`G/B<I('L-"B`@
M("`@("`@("`@("`@("`D;6]D92`]("=W8B<[#0H@("`@("`@("`@("`@("`@
M)&]U='!U=&9I;&4@/2`D87)G<ULD:2LQ73L-"B`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@('T@96QS96EF("@D87)G<ULD:5T@/3T@)SX^
M)RD@>PT*("`@("`@("`@("`@("`@("1M;V1E(#T@)V%B*R<[#0H@("`@("`@
M("`@("`@("`@)&]U='!U=&9I;&4@/2`D87)G<ULD:2LQ73L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&9I;&5S6UT@/2`D87)G<ULD:5T[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1M;V1E*2D@>PT*("`@
M("`@("`@("`@:68@*"$D;W5T<'5T9F0@/2!F;W!E;B@D;W5T<'5T9FEL92P@
M)&UO9&4I*2![#0H@("`@("`@("`@("`@("`@)&5R<B`](%-Y<W1E;3HZ<F%I
M<V5%<G)O<B@B0V]U;&0@;F]T(&]P96X@)&]U='!U=&9I;&4B*3L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1R970@/2!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A
M8V@@*"1F:6QE<R!A<R`D9FEL92D@>PT*("`@("`@("`@("`@:68@*"$D9F0@
M/2!F;W!E;B@D9FEL92P@)W(G*2D@>PT*("`@("`@("`@("`@("`@(%-Y<W1E
M;3HZ<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&]P96X@)&9I;&4B*3L-"B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('=H:6QE("@D8V]N="`](&9R96%D*"1F9"P@,C`T."DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&]U='!U=&9D*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!F=W)I=&4H)&]U='!U=&9D+"`D8V]N="D[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`N
M/2`D8V]N=#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!F8VQO<V4H)&9D*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H0&ES7W)E<V]U<F-E*"1O=71P=71F9"DI('L-"B`@("`@("`@("`@(&9C
M;&]S92@D;W5T<'5T9F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@0W)E871E<R!T96UP;W)A
M<GD@9FEL97,@;W(@9&ER96-T;W)I97,N(%1H:7,@9G5N8W1I;VX@=VEL;"!R
M96UO=F4-"B`@("`J('1H92!C<F5A=&5D(&9I;&5S('=H96X@=&AE('-C<FEP
M=',@9FEN:7-H(&ET<R!E>&5C=71I;VXN#0H@("`@*@T*("`@("H@57-A9V4Z
M#0H@("`@*B`@(#$I("1T96UP9FEL92`](%-Y<W1E;3HZ;6MT96UP*")P<F5F
M:7@B*3L-"B`@("`J("`@,BD@)'1E;7!D:7(@(#T@4WES=&5M.CIM:W1E;7`H
M(BUD('!R969I>"(I.PT*("`@("H@("`S*2`D=&5M<&9I;&4@/2!3>7-T96TZ
M.FUK=&5M<"@I.PT*("`@("H@("`T*2`D=&5M<&9I;&4@/2!3>7-T96TZ.FUK
M=&5M<"@B+70@+W9A<B]T;7`@<')E9FEX(BD[#0H@("`@*@T*("`@("H@<')E
M9FEX("T^(%1H92!S=')I;F<@=&AA="!W:6QL(&)E('!R97!E;F1E9"!T;R!T
M:&4@=&5M<"!N86UE#0H@("`@*B`@("`@("`@("`@*&1E9F%U;'1S('1O(")T
M;7`B*2X-"B`@("`J("UD("`@("`M/B!!('1E;7!O<F%R>2!D:7(@=VEL;"!B
M92!C<F5A=&5D(&EN<W1E860@;V8@82!F:6QE+@T*("`@("H@+70@("`@("T^
M(%1H92!T87)G970@9&ER('=H97)E('1H92!T96UP;W)A<GD@*&9I;&5\9&ER
M*2!W:6QL(&)E(&-R96%T960N($EF#0H@("`@*B`@("`@("`@("`@=&AI<R!P
M87)A;2!I<R!M:7-S:6YG(&)Y(&1E9F%U;'0@=&AE(&5N=B!V87)S(%1-4"!O
M;B!7:6YD;W=S(&]R#0H@("`@*B`@("`@("`@("`@5$U01$E2(&EN(%5N:7@@
M=VEL;"!B92!U<V5D+B!)9B!T:&5S92!V87)S(&%R92!A;'-O(&UI<W-I;F<-
M"B`@("`J("`@("`@("`@("!C.EQW:6YD;W=S7'1E;7`@;W(@+W1M<"!W:6QL
M(&)E('5S960N#0H@("`@*@T*("`@("H@0'!A<F%M("`@<W1R:6YG("`D87)G
M<R`@5&AE(&%R9W5M96YT<PT*("`@("H@0')E='5R;B`@;6EX960@("!T:&4@
M9G5L;"!P871H(&]F('1H92!C<F5A=&5D("AF:6QE?&1I<BD@;W(@9F%L<V4-
M"B`@("`J($!S964@4WES=&5M.CIT;7!D:7(H*0T*("`@("H@0&%C8V5S<R`@
M<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!M:W1E;7`H)&%R9W,@/2!N
M=6QL*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1F:7)S=%]T:6UE(#T@=')U
M93L-"B`@("`@("`@)&]P=',@/2!3>7-T96TZ.E]P87)S94%R9W,H)&%R9W,L
M("=T.F0G*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]P=',I*2![
M#0H@("`@("`@("`@("!R971U<FX@4WES=&5M.CIR86ES945R<F]R*"1O<'1S
M*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H*"1O<'1S6S!=(&%S("1O
M<'0I('L-"B`@("`@("`@("`@(&EF*"1O<'1;,%T@/3T@)V0G*2![#0H@("`@
M("`@("`@("`@("`@)'1M<%]I<U]D:7(@/2!T<G5E.PT*("`@("`@("`@("`@
M?2!E;'-E:68H)&]P=%LP72`]/2`G="<I('L-"B`@("`@("`@("`@("`@("`D
M=&UP9&ER(#T@)&]P=%LQ73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D<')E9FEX(#T@*&ES<V5T*"1O<'1S6S%=6S!=*2D@/R`D;W!T
M<ULQ75LP72`Z("=T;7`G.PT*("`@("`@("!I9B`H(6ES<V5T*"1T;7!D:7(I
M*2![#0H@("`@("`@("`@("`D=&UP9&ER(#T@4WES=&5M.CIT;7!D:7(H*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(5-Y<W1E;3HZ;6M$:7(H87)R87DH
M)RUP)RP@)'1M<&1I<BDI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@)'1M<"`]('1E;7!N86TH)'1M<&1I<BP@
M)'!R969I>"D[#0H@("`@("`@(&EF("AI<W-E="@D=&UP7VES7V1I<BDI('L-
M"B`@("`@("`@("`@('5N;&EN:R@D=&UP*3L@+R\@8F4@8V%R969U;"!P;W-S
M:6)L92!R86-E(&-O;F1I=&EO;B!H97)E#0H@("`@("`@("`@("!I9B`H(6UK
M9&ER*"1T;7`L(#`W,#`I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%-Y
M<W1E;3HZ<F%I<V5%<G)O<B@B56YA8FQE('1O(&-R96%T92!T96UP;W)A<GD@
M9&ER96-T;W)Y("1T;7!D:7(B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D1TQ/0D%,4ULG7U-Y<W1E;5]T96UP7V9I;&5S)UU;72`]
M("1T;7`[#0H@("`@("`@(&EF("@D9FER<W1?=&EM92D@>PT*("`@("`@("`@
M("`@4$5!4CHZ<F5G:7-T97)3:'5T9&]W;D9U;F,H87)R87DH)U-Y<W1E;2<L
M("=?<F5M;W9E5&UP1FEL97,G*2D[#0H@("`@("`@("`@("`D9FER<W1?=&EM
M92`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&UP.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("H@4F5M;W9E('1E;7!O<F%R>2!F:6QE
M<R!C<F5A=&5D(&UY(&UK5&5M<"X@5&AI<R!F=6YC=&EO;B!I<R!E>&5C=71E
M9`T*("`@("H@870@<V-R:7!T('-H=71D;W=N('1I;64-"B`@("`J#0H@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N(%]R96UO
M=F54;7!&:6QE<R@I#0H@("`@>PT*("`@("`@("!I9B`H8V]U;G0H)$=,3T)!
M3%-;)U]3>7-T96U?=&5M<%]F:6QE<R==*2D@>PT*("`@("`@("`@("`@)&1E
M;&5T92`]("1'3$]"04Q36R=?4WES=&5M7W1E;7!?9FEL97,G73L-"B`@("`@
M("`@("`@(&%R<F%Y7W5N<VAI9G0H)&1E;&5T92P@)RUR)RD[#0H@("`@("`@
M("`@("!3>7-T96TZ.G)M*"1D96QE=&4I.PT*("`@("`@("`@("`@)$=,3T)!
M3%-;)U]3>7-T96U?=&5M<%]F:6QE<R==(#T@87)R87DH*3L-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\J*@T*("`@("H@1V5T('1H92!P871H(&]F('1H
M92!T96UP;W)A;"!D:7)E8W1O<GD@<V5T(&EN('1H92!S>7-T96T-"B`@("`J
M(&)Y(&QO;VMI;F<@:6X@:71S(&5N=FER;VYM96YT<R!V87)I86)L97,N#0H@
M("`@*B!.;W1E.B!P:'`N:6YI+7)E8V]M;65N9&5D(')E;6]V97,@=&AE(")%
M(B!F<F]M('1H92!V87)I86)L97-?;W)D97(@<V5T=&EN9RP-"B`@("`J(&UA
M:VEN9R!U;F%V86EB;&4@=&AE("1?14Y6(&%R<F%Y+"!T:&%T(',@=VAY('=E
M(&1O('1E<W1S('=I=&@@7T5.5@T*("`@("H-"B`@("`J($!R971U<FX@<W1R
M:6YG(%1H92!T96UP;W)A;"!D:7)E8W1O<GD@;VX@=&AE('-Y<W1E;0T*("`@
M("HO#0H@("`@9G5N8W1I;VX@=&UP9&ER*"D-"B`@("![#0H@("`@("`@(&EF
M("A/4U]724Y$3U=3*2![#0H@("`@("`@("`@("!I9B`H)'9A<B`](&ES<V5T
M*"1?14Y66R=414U0)UTI(#\@)%]%3E9;)U1%35`G72`Z(&=E=&5N=B@G5$5-
M4"<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1V87([#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H)'9A<B`](&ES<V5T*"1?14Y66R=4
M35`G72D@/R`D7T5.5ELG5$U0)UT@.B!G971E;G8H)U1-4"<I*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1V87([#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H)'9A<B`](&ES<V5T*"1?14Y66R=W:6YD:7(G72D@/R`D
M7T5.5ELG=VEN9&ER)UT@.B!G971E;G8H)W=I;F1I<B<I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1V87([#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!R971U<FX@9V5T96YV*"=3>7-T96U2;V]T)RD@+B`G7'1E;7`G.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D=F%R(#T@:7-S970H)%]%3E9;)U1-
M4$1)4B==*2`_("1?14Y66R=435!$25(G72`Z(&=E=&5N=B@G5$U01$E2)RDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=F%R.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`G+W1M<"<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!4
M:&4@(G=H:6-H(B!C;VUM86YD("AS:&]W('1H92!F=6QL('!A=&@@;V8@82!C
M;VUM86YD*0T*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)'!R;V=R86T@
M5&AE(&-O;6UA;F0@=&\@<V5A<F-H(&9O<@T*("`@("H@0'!A<F%M(&UI>&5D
M("`D9F%L;&)A8VL@5F%L=64@=&\@<F5T=7)N(&EF("1P<F]G<F%M(&ES(&YO
M="!F;W5N9`T*("`@("H-"B`@("`J($!R971U<FX@;6EX960@02!S=')I;F<@
M=VET:"!T:&4@9G5L;"!P871H(&]R(&9A;'-E(&EF(&YO="!F;W5N9`T*("`@
M("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!W:&EC:"@D<')O9W)A;2P@)&9A;&QB86-K(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("`O+R!E;F9O<F-E($%020T*("`@("`@("!I
M9B`H(6ES7W-T<FEN9R@D<')O9W)A;2D@?'P@)R<@/3T@)'!R;V=R86TI('L-
M"B`@("`@("`@("`@(')E='5R;B`D9F%L;&)A8VL[#0H@("`@("`@('T-"@T*
M("`@("`@("`O+R!A=F%I;&%B;&4@<VEN8V4@-"XS+C!20S(-"B`@("`@("`@
M:68@*&1E9FEN960H)U!!5$A?4T5005)!5$]2)RDI('L-"B`@("`@("`@("`@
M("1P871H7V1E;&EM(#T@4$%42%]315!!4D%43U([#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D<&%T:%]D96QI;2`]($]37U=)3D1/5U,@/R`G
M.R<@.B`G.B<[#0H@("`@("`@('T-"B`@("`@("`@+R\@9G5L;"!P871H(&=I
M=F5N#0H@("`@("`@(&EF("AB87-E;F%M92@D<')O9W)A;2D@(3T@)'!R;V=R
M86TI('L-"B`@("`@("`@("`@("1P871H7V5L96UE;G1S6UT@/2!D:7)N86UE
M*"1P<F]G<F%M*3L-"B`@("`@("`@("`@("1P<F]G<F%M(#T@8F%S96YA;64H
M)'!R;V=R86TI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@+R\@
M2&]N;W(@<V%F92!M;V1E#0H@("`@("`@("`@("!I9B`H(6EN:5]G970H)W-A
M9F5?;6]D92<I('Q\("$D<&%T:"`](&EN:5]G970H)W-A9F5?;6]D95]E>&5C
M7V1I<B<I*2![#0H@("`@("`@("`@("`@("`@)'!A=&@@/2!G971E;G8H)U!!
M5$@G*3L-"B`@("`@("`@("`@("`@("!I9B`H(21P871H*2![#0H@("`@("`@
M("`@("`@("`@("`@("1P871H(#T@9V5T96YV*"=0871H)RD[("\O('-O;64@
M3U-E<R!A<F4@:G5S="!S='5P:60@96YO=6=H('1O(&1O('1H:7,-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%T
M:%]E;&5M96YT<R`](&5X<&QO9&4H)'!A=&A?9&5L:6TL("1P871H*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@(&EF("A/4U]724Y$3U=3*2![#0H@("`@("`@
M("`@("`D97AE7W-U9F9I>&5S(#T@9V5T96YV*"=0051(15A4)RD-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/R!E>'!L;V1E*"1P871H7V1E
M;&EM+"!G971E;G8H)U!!5$A%6%0G*2D-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B!A<G)A>2@G+F5X92<L)RYB870G+"<N8VUD)RPG+F-O
M;2<I.PT*("`@("`@("`@("`@+R\@86QL;W<@<&%S<VEN9R!A(&-O;6UA;F0N
M97AE('!A<F%M#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1P<F]G<F%M+"`G
M+B<I("$]/2!F86QS92D@>PT*("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI
M9G0H)&5X95]S=69F:7AE<RP@)R<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@+R\@:7-?97AE8W5T86)L92@I(&ES(&YO="!A=F%I;&%B;&4@;VX@
M=VEN9&]W<R!F;W(@4$A0-`T*("`@("`@("`@("`@)'!E87)?:7-?97AE8W5T
M86)L92`]("AF=6YC=&EO;E]E>&ES=',H)VES7V5X96-U=&%B;&4G*2D@/R`G
M:7-?97AE8W5T86)L92<@.B`G:7-?9FEL92<[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D97AE7W-U9F9I>&5S(#T@87)R87DH)R<I.PT*("`@
M("`@("`@("`@)'!E87)?:7-?97AE8W5T86)L92`]("=I<U]E>&5C=71A8FQE
M)SL-"B`@("`@("`@?0T*#0H@("`@("`@(&9O<F5A8V@@*"1E>&5?<W5F9FEX
M97,@87,@)'-U9F8I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P871H7V5L
M96UE;G1S(&%S("1D:7(I('L-"B`@("`@("`@("`@("`@("`D9FEL92`]("1D
M:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!R;V=R86T@+B`D<W5F9CL-
M"B`@("`@("`@("`@("`@("!I9B`H)'!E87)?:7-?97AE8W5T86)L92@D9FEL
M92DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1F:6QE.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)&9A;&QB86-K.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("H@5&AE(")F:6YD(B!C;VUM86YD#0H@("`@*@T*("`@("H@57-A9V4Z#0H@
M("`@*@T*("`@("H@4WES=&5M.CIF:6YD*"1D:7(I.PT*("`@("H@4WES=&5M
M.CIF:6YD*"(D9&ER("UT>7!E(&0B*3L-"B`@("`J(%-Y<W1E;3HZ9FEN9"@B
M)&1I<B`M='EP92!F(BD[#0H@("`@*B!3>7-T96TZ.F9I;F0H(B1D:7(@+6YA
M;64@*BYP:'`B*3L-"B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I<B`M;F%M92`J
M+G!H<"`M;F%M92`J+FAT;2HB*3L-"B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I
M<B`M;6%X9&5P=&@@,2(I.PT*("`@("H-"B`@("`J(%!A<F%M<R!I;7!L;65N
M=&5D.@T*("`@("H@)&1I<B`@("`@("`@("`@("T^(%-T87)T('1H92!S96%R
M8V@@870@=&AI<R!D:7)E8W1O<GD-"B`@("`J("UT>7!E(&0@("`@("`@("`M
M/B!R971U<FX@;VYL>2!D:7)E8W1O<FEE<PT*("`@("H@+71Y<&4@9B`@("`@
M("`@("T^(')E='5R;B!O;FQY(&9I;&5S#0H@("`@*B`M;6%X9&5P=&@@/&X^
M("`@+3X@;6%X(&1E<'1H(&]F(')E8W5R<VEO;@T*("`@("H@+6YA;64@/'!A
M='1E<FX^("T^('-E87)C:"!P871T97)N("AB87-H('-T>6QE*2X@375L=&EP
M;&4@+6YA;64@<&%R86T@86QL;W=E9`T*("`@("H-"B`@("`J($!P87)A;2`@
M;6EX960@16ET:&5R(&%R<F%Y(&]R('-T<FEN9R!W:71H('1H92!C;VUM86YD
M(&QI;F4-"B`@("`J($!R971U<FX@87)R87D@07)R87D@;V8@9F]U;F0@9FEL
M97,-"B`@("`J#0H@("`@*B\-"B`@("!F=6YC=&EO;B!F:6YD*"1A<F=S*0T*
M("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D87)G<RDI('L-"B`@("`@
M("`@("`@("1A<F=S(#T@<')E9U]S<&QI="@G+UQS*R\G+"`D87)G<RP@+3$L
M(%!214=?4U!,251?3D]?14U05%DI.PT*("`@("`@("!]#0H@("`@("`@("1D
M:7(@/2!A<G)A>5]S:&EF="@D87)G<RD[#0H@("`@("`@("1P871T97)N<R`]
M(&%R<F%Y*"D[#0H@("`@("`@("1D97!T:"`](#`[#0H@("`@("`@("1D;U]F
M:6QE<R`]("1D;U]D:7)S(#T@=')U93L-"B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@8V]U;G0H)&%R9W,I.R`D:2LK*2![#0H@("`@("`@("`@("!S=VET
M8V@@*"1A<F=S6R1I72D@>PT*("`@("`@("`@("`@("`@(&-A<V4@)RUT>7!E
M)SH-"B`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1A<F=S6R1I
M*S%=+"!A<G)A>2@G9"<L("=F)RDI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&%R9W-;)&DK,5T@/3T@)V0G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1O7V9I;&5S(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D;U]D:7)S(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@)&DK*SL-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@8V%S92`G+6YA;64G.@T*("`@("`@("`@("`@("`@("`@
M("!I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1A<F=S6R1I*S%=>S!](#T]("=<7"<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!P<F5P96YD(&1R:79E#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&%R9W-;)&DK,5T@/2!A9&1S;&%S:&5S*'-U8G-T
M<BAG971C=V0H*2P@,"P@,BD@+B`D87)G<ULD:2`K(#%=*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&5S8V%P92!P871H('-E<&%R871O<G,@=&\@879O:60@4$-212!P<F]B;&5M
M<PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%R9W-;)&DK,5T@/2!S=')?
M<F5P;&%C92@G7%PG+"`G7%Q<7"<L("1A<F=S6R1I*S%=*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<&%T=&5R;G-;
M72`]("(H(B`N('!R96=?<F5P;&%C92AA<G)A>2@G+UPN+R<L("<O7"HO)RDL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=<+B<L("<N*B<L("DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<F=S
M6R1I*S%=*0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("(I(CL-"B`@("`@("`@("`@("`@("`@("`@)&DK*SL-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G+6UA
M>&1E<'1H)SH-"B`@("`@("`@("`@("`@("`@("`@)&1E<'1H(#T@)&%R9W-;
M)&DK,5T[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1P871H(#T@4WES=&5M.CI?9&ER
M5&]3=')U8W0H)&1I<BP@)&1E<'1H*3L-"B`@("`@("`@:68@*"1D;U]F:6QE
M<R`F)B`D9&]?9&ER<RD@>PT*("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?
M;65R9V4H)'!A=&A;)V9I;&5S)UTL("1P871H6R=D:7)S)UTI.PT*("`@("`@
M("!](&5L<V5I9B`H)&1O7V1I<G,I('L-"B`@("`@("`@("`@("1F:6QE<R`]
M("1P871H6R=D:7)S)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D9FEL97,@/2`D<&%T:%LG9FEL97,G73L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H8V]U;G0H)'!A='1E<FYS*2D@>PT*("`@("`@("`@("`@)'!A='1E
M<FYS(#T@:6UP;&]D92@G?"<L("1P871T97)N<RD[#0H@("`@("`@("`@("`D
M<F5T(#T@87)R87DH*3L-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1F:6QE<RD[("1I*RLI('L-"B`@("`@("`@("`@("`@("!I9B`H
M<')E9U]M871C:"@B(UXD<&%T=&5R;G-<)",B+"`D9FEL97-;)&E=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D9FEL97-;)&E=.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9FEL97,[
M#0H@("`@?0T*?0T*/SX-"@```````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]P96%R8VUD+G!H<```````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-38Q,P`Q,#4Q-30S,3`U-P`P,3<T
M-S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\O#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T
M(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`T*+R\@
M?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@
M?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R<SH@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"`@("`@("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E
M8VYE="YC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@<&5A<F-M9"YP:'`L=B`Q+C,S
M(#(P,#8O,#$O,#(@,3@Z,#4Z-3,@8V5L;&]G($5X<"`D#0H-"F]B7V5N9%]C
M;&5A;B@I.PT*:68@*"%D969I;F5D*"=014%27U)53E194$4G*2D@>PT*("`@
M("\O('1H:7,@:7,@9&5F:6YE9"!I;B!P96-L8VUD+G!H<"!A<R`G<&5C;"<-
M"B`@("!D969I;F4H)U!%05)?4E5.5%E012<L("=P96%R)RD[#0I]#0ID969I
M;F4H)U!%05)?24=.3U)%7T)!0TM44D%#12<L(#$I.PT*:68@*"%F=6YC=&EO
M;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("!F=6YC=&EO
M;B!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I#0H@("`@>PT*("`@("`@
M("`D9G`@/2!F;W!E;B@D9FEL96YA;64L("=R8B<I.PT*("`@("`@("`D<F5T
M(#T@)R<[#0H@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2![#0H@("`@("`@
M("`@("`D<F5T("X](&9R96%D*"1F<"P@.#`Y,BD[.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"GT-"B\J*@T*("H@0&YO9&5P
M($=T:PT*("HO#0II9B`H)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M)R`A/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2![#0H@("`@:6YI7W-E="@G
M:6YC;'5D95]P871H)RP@)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M)RD[#0H@("`@)')A=R`](&9A;'-E.PT*?2!E;'-E('L-"B`@("`O+R!T:&ES
M(&ES(&$@<F%W+"!U;FEN<W1A;&QE9"!P96%R+"!E:71H97(@82!C=G,@8VAE
M8VMO=70L(&]R('!H<"!D:7-T<F\-"B`@("`D<F%W(#T@=')U93L-"GT-"D!I
M;FE?<V5T*"=A;&QO=U]U<FQ?9F]P96XG+"!T<G5E*3L-"FEF("@A:6YI7V=E
M="@G<V%F95]M;V1E)RDI('L-"B`@("!`<V5T7W1I;65?;&EM:70H,"D[#0I]
M#0IO8E]I;7!L:6-I=%]F;'5S:"AT<G5E*3L-"D!I;FE?<V5T*"=T<F%C:U]E
M<G)O<G,G+"!T<G5E*3L-"D!I;FE?<V5T*"=H=&UL7V5R<F]R<R<L(&9A;'-E
M*3L-"D!I;FE?<V5T*"=M86=I8U]Q=6]T97-?<G5N=&EM92<L(&9A;'-E*3L-
M"B1?4$5!4E]02%!$25(@/2`G(R0E7B8J)SL-"G-E=%]E<G)O<E]H86YD;&5R
M*"=E<G)O<E]H86YD;&5R)RD[#0H-"B1P96%R7W!A8VMA9V5?=F5R<VEO;B`]
M("(Q+C0N.2([#0H-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q=6ER
M95]O;F-E("=014%2+T9R;VYT96YD+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%
M05(O0V]N9FEG+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"YP
M:'`G.PT*<F5Q=6ER95]O;F-E("=#;VYS;VQE+T=E=&]P="YP:'`G.PT*#0H-
M"E!%05)?0V]M;6%N9#HZ<V5T1G)O;G1E;F14>7!E*"=#3$DG*3L-"B1A;&Q?
M8V]M;6%N9',@/2!014%27T-O;6UA;F0Z.F=E=$-O;6UA;F1S*"D[#0H-"B\O
M(')E;6]V92!T:&ES(&YE>'0@<&%R="!W:&5N('=E('-T;W`@<W5P<&]R=&EN
M9R!T:&%T(&-R87`M87-S(%!(4"`T+C(-"FEF("@A:7-S970H)%]315)615);
M)V%R9W8G72D@)B8@(6ES<V5T*"1A<F=V*2`F)B`A:7-S970H)$A45%!?4T52
M5D527U9!4E-;)V%R9W8G72DI('L-"B`@("!D:64H)T524D]2.B!E:71H97(@
M=7-E('1H92!#3$D@<&AP(&5X96-U=&%B;&4L(&]R('-E="!R96=I<W1E<E]A
M<F=C7V%R9W8]3VX@:6X@<&AP+FEN:2<I.PT*?0T*)&%R9W8@/2!#;VYS;VQE
M7T=E=&]P=#HZ<F5A9%!(4$%R9W8H*3L-"B\O(&9I>"!#1TD@<V%P:2!O9&1I
M='D@+2!T:&4@+2T@:6X@<&5A<BYB870O<&5A<B!I<R!N;W0@<F5M;W9E9`T*
M:68@*'!H<%]S87!I7VYA;64H*2`A/2`G8VQI)R`F)B!I<W-E="@D87)G=ELQ
M72D@)B8@)&%R9W9;,5T@/3T@)RTM)RD@>PT*("`@('5N<V5T*"1A<F=V6S%=
M*3L-"B`@("`D87)G=B`](&%R<F%Y7W9A;'5E<R@D87)G=BD[#0I]#0HD<')O
M9VYA;64@/2!014%27U)53E194$4[#0II9B`H:6Y?87)R87DH)V=E=&]P=#(G
M+"!G971?8VQA<W-?;65T:&]D<R@G0V]N<V]L95]'971O<'0G*2DI('L-"B`@
M("!A<G)A>5]S:&EF="@D87)G=BD[#0H@("`@)&]P=&EO;G,@/2!#;VYS;VQE
M7T=E=&]P=#HZ9V5T;W!T,B@D87)G=BP@(F,Z0SID.D0Z1V@_<U-Q=3IV5B(I
M.PT*?2!E;'-E('L-"B`@("`D;W!T:6]N<R`]($-O;G-O;&5?1V5T;W!T.CIG
M971O<'0H)&%R9W8L(")C.D,Z9#I$.D=H/W-3<74Z=E8B*3L-"GT-"FEF("A0
M14%2.CII<T5R<F]R*"1O<'1I;VYS*2D@>PT*("`@('5S86=E*"1O<'1I;VYS
M*3L-"GT-"@T*)&]P=',@/2`D;W!T:6]N<ULP73L-"@T*)&9E='EP92`]("=#
M3$DG.PT*:68@*"1P<F]G;F%M92`]/2`G9W!E87(G('Q\("1P<F]G;F%M92`]
M/2`G<&5A<BUG=&LG*2![#0H@("`@)&9E='EP92`]("='=&LG.PT*?2!E;'-E
M('L-"B`@("!F;W)E86-H("@D;W!T<R!A<R`D;W!T*2![#0H@("`@("`@(&EF
M("@D;W!T6S!=(#T]("=')RD@>PT*("`@("`@("`@("`@)&9E='EP92`]("='
M=&LG.PT*("`@("`@("!]#0H@("`@?0T*?0T*+R]#:&5C:R!I9B!'=&L@86YD
M(%!(4"`^/2`U+C$N,`T*:68@*"1F971Y<&4@/3T@)T=T:R<@)B8@=F5R<VEO
M;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,2XP)RP@)SX])RDI('L-"B`@
M("`D9F5T>7!E(#T@)T=T:S(G.PT*?0T*#0HD<&5A<E]U<V5R7V-O;F9I9R`]
M("<G.PT*)'!E87)?<WES=&5M7V-O;F9I9R`]("<G.PT*)'-T;W)E7W5S97)?
M8V]N9FEG(#T@9F%L<V4[#0HD<W1O<F5?<WES=&5M7V-O;F9I9R`](&9A;'-E
M.PT*)'9E<F)O<V4@/2`Q.PT*#0IF;W)E86-H("@D;W!T<R!A<R`D;W!T*2![
M#0H@("`@<W=I=&-H("@D;W!T6S!=*2![#0H@("`@("`@(&-A<V4@)V,G.@T*
M("`@("`@("`@("`@)'!E87)?=7-E<E]C;VYF:6<@/2`D;W!T6S%=.PT*("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)T,G.@T*("`@("`@("`@
M("`@)'!E87)?<WES=&5M7V-O;F9I9R`]("1O<'1;,5T[#0H@("`@("`@("`@
M("!B<F5A:SL-"B`@("!]#0I]#0H-"E!%05)?0V]M;6%N9#HZ<V5T1G)O;G1E
M;F14>7!E*"1F971Y<&4I.PT*)'5I(#T@)E!%05)?0V]M;6%N9#HZ9V5T1G)O
M;G1E;F1/8FIE8W0H*3L-"B1C;VYF:6<@/2`F4$5!4E]#;VYF:6<Z.G-I;F=L
M971O;B@D<&5A<E]U<V5R7V-O;F9I9RP@)'!E87)?<WES=&5M7V-O;F9I9RD[
M#0H-"FEF("A014%2.CII<T5R<F]R*"1C;VYF:6<I*2![#0H@("`@)%]F:6QE
M(#T@)R<[#0H@("`@:68@*"1P96%R7W5S97)?8V]N9FEG("$]/2!F86QS92D@
M>PT*("`@("`@("1?9FEL92`N/2`D<&5A<E]U<V5R7V-O;F9I9SL-"B`@("!]
M#0H@("`@:68@*"1P96%R7W-Y<W1E;5]C;VYF:6<@(3T](&9A;'-E*2![#0H@
M("`@("`@)%]F:6QE("X]("<O)R`N("1P96%R7W-Y<W1E;5]C;VYF:6<[#0H@
M("`@?0T*("`@(&EF("@D7V9I;&4@/3T@)R\G*2![#0H@("`@("`@("1?9FEL
M92`]("=4:&4@9&5F875L="!C;VYF:6<@9FEL92<[#0H@("`@?0T*("`@("1C
M;VYF:6<M/F=E=$UE<W-A9V4H*3L-"B`@("`D=6DM/F]U='!U=$1A=&$H(D52
M4D]2.B`D7V9I;&4@:7,@;F]T(&$@=F%L:60@8V]N9FEG(&9I;&4@;W(@:7,@
M8V]R<G5P=&5D+B(I.PT*("`@("\O(%=E('-T;W`L('=E(&AA=F4@;F\@:61E
M82!W:&5R92!W92!A<F4@.BD-"B`@("!E>&ET*"D[("`@(`T*?0T*#0HO+R!T
M:&ES(&ES('5S960@:6X@=&AE(&5R<F]R(&AA;F1L97(@=&\@<F5T<FEE=F4@
M82!R96QA=&EV92!P871H#0HD7U!%05)?4$A01$E2(#T@)&-O;F9I9RT^9V5T
M*"=P:'!?9&ER)RD[#0HD=6DM/G-E=$-O;F9I9R@D8V]N9FEG*3L-"E!%05(Z
M.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@87)R87DH
M)'5I+"`B9&ES<&QA>49A=&%L17)R;W(B*2D[#0II9B`H:6YI7V=E="@G<V%F
M95]M;V1E)RDI('L-"B`@("`D=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(')U
M;FYI;F<@:6X@<V%F92!M;V1E(')E<75I<F5S('1H870@86QL(&9I;&5S(&-R
M96%T960@)R`N#0H@("`@("`@("=B92!T:&4@<V%M92!U:60@87,@=&AE(&-U
M<G)E;G0@<V-R:7!T+B`@4$A0(')E<&]R=',@=&AI<R!S8W)I<'0@:7,@=6ED
M.B`G("X-"B`@("`@("`@0&=E=&UY=6ED*"D@+B`G+"!A;F0@8W5R<F5N="!U
M<V5R(&ES.B`G("X@0&=E=%]C=7)R96YT7W5S97(H*2D[#0I]#0H-"B1V97)B
M;W-E(#T@)&-O;F9I9RT^9V5T*")V97)B;W-E(BD[#0HD8VUD;W!T<R`](&%R
M<F%Y*"D[#0H-"FEF("@D<F%W*2![#0H@("`@:68@*"$D8V]N9FEG+3YI<T1E
M9FEN961,87EE<B@G=7-E<B<I("8F("$D8V]N9FEG+3YI<T1E9FEN961,87EE
M<B@G<WES=&5M)RDI('L-"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@
M("`@(&9O<F5A8V@@*"1O<'1S(&%S("1O<'0I('L-"B`@("`@("`@("`@(&EF
M("@D;W!T6S!=(#T]("=D)R!\?"`D;W!T6S!=(#T]("=$)RD@>PT*("`@("`@
M("`@("`@("`@("1F;W5N9"`]('1R=64[("\O('1H92!U<V5R(&MN;W=S('=H
M870@=&AE>2!A<F4@9&]I;F<L(&%N9"!A<F4@<V5T=&EN9R!C;VYF:6<@=F%L
M=65S#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D
M9F]U;F0I('L-"B`@("`@("`@("`@("\O(&YO('!R:6]R(')U;G,L('1R>2!T
M;R!I;G-T86QL(%!%05(-"B`@("`@("`@("`@(&EF("AS=')P;W,H9&ER;F%M
M92A?7T9)3$5?7RDL("=S8W)I<'1S)RDI('L-"B`@("`@("`@("`@("`@("`D
M<&%C:V%G97AM;"`](&1I<FYA;64H9&ER;F%M92A?7T9)3$5?7RDI("X@1$E2
M14-43U)97U-%4$%2051/4B`N("=P86-K86=E,BYX;6PG.PT*("`@("`@("`@
M("`@("`@("1P96%R8F%S92`](&1I<FYA;64H9&ER;F%M92A?7T9)3$5?7RDI
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<&%C
M:V%G97AM;"`](&1I<FYA;64H7U]&24Q%7U\I("X@1$E214-43U)97U-%4$%2
M051/4B`N("=P86-K86=E,BYX;6PG.PT*("`@("`@("`@("`@("`@("1P96%R
M8F%S92`](&1I<FYA;64H7U]&24Q%7U\I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P86-K86=E>&UL*2D@>PT*("`@
M("`@("`@("`@("`@("1O<'1I;VYS6S%=(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=I;G-T86QL)RP-"B`@("`@("`@("`@("`@("`@("`@)'!A
M8VMA9V5X;6P-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@
M("1C;VYF:6<M/G-E="@G<&AP7V1I<B<L("1P96%R8F%S92`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`G<&AP)RD[#0H@("`@("`@("`@("`@("`@)&-O;F9I
M9RT^<V5T*"=D871A7V1I<B<L("1P96%R8F%S92`N($1)4D5#5$]265]315!!
M4D%43U(@+B`G9&%T82<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E
M="@G9&]C7V1I<B<L("1P96%R8F%S92`N($1)4D5#5$]265]315!!4D%43U(@
M+B`G9&]C<R<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G=&5S
M=%]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W1E
M<W1S)RD[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"=E>'1?9&ER
M)RP@)'!E87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N("=E>'1E;G-I
M;VYS)RD[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"=B:6Y?9&ER
M)RP@)'!E87)B87-E*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YM97)G
M94-O;F9I9T9I;&4H)'!E87)B87-E("X@)W!E87(N:6YI)RP@9F%L<V4I.PT*
M("`@("`@("`@("`@("`@("1C;VYF:6<M/G-T;W)E*"D[#0H@("`@("`@("`@
M("`@("`@)&-O;F9I9RT^<V5T*"=A=71O7V1I<V-O=F5R)RP@,2D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0I]#0IF;W)E86-H("@D;W!T
M<R!A<R`D;W!T*2![#0H@("`@)'!A<F%M(#T@(65M<'1Y*"1O<'1;,5TI(#\@
M)&]P=%LQ72`Z('1R=64[#0H@("`@<W=I=&-H("@D;W!T6S!=*2![#0H@("`@
M("`@(&-A<V4@)V0G.@T*("`@("`@("`@("`@;&ES="@D:V5Y+"`D=F%L=64I
M(#T@97AP;&]D92@G/2<L("1P87)A;2D[#0H@("`@("`@("`@("`D8V]N9FEG
M+3YS970H)&ME>2P@)'9A;'5E+"`G=7-E<B<I.PT*("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@(&-A<V4@)T0G.@T*("`@("`@("`@("`@;&ES="@D:V5Y
M+"`D=F%L=64I(#T@97AP;&]D92@G/2<L("1P87)A;2D[#0H@("`@("`@("`@
M("`D8V]N9FEG+3YS970H)&ME>2P@)'9A;'5E+"`G<WES=&5M)RD[#0H@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G<R<Z#0H@("`@("`@("`@
M("`D<W1O<F5?=7-E<E]C;VYF:6<@/2!T<G5E.PT*("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@(&-A<V4@)U,G.@T*("`@("`@("`@("`@)'-T;W)E7W-Y
M<W1E;5]C;VYF:6<@/2!T<G5E.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@(&-A<V4@)W4G.@T*("`@("`@("`@("`@)&-O;F9I9RT^<F5M;W9E*"1P
M87)A;2P@)W5S97(G*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C
M87-E("=V)SH-"B`@("`@("`@("`@("1C;VYF:6<M/G-E="@G=F5R8F]S92<L
M("1C;VYF:6<M/F=E="@G=F5R8F]S92<I("L@,2D[#0H@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@8V%S92`G<2<Z#0H@("`@("`@("`@("`D8V]N9FEG
M+3YS970H)W9E<F)O<V4G+"`D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`M(#$I
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)U8G.@T*("`@
M("`@("`@("`@=7-A9V4H;G5L;"P@)W9E<G-I;VXG*3L-"B`@("`@("`@8V%S
M92`G8R<Z#0H@("`@("`@(&-A<V4@)T,G.@T*("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`O+R!A;&P@;F]N('!E
M87(@<&%R86US(&=O97,@=&\@=&AE(&-O;6UA;F0-"B`@("`@("`@("`@("1C
M;61O<'1S6R1O<'1;,%U=(#T@)'!A<F%M.PT*("`@("`@("`@("`@8G)E86L[
M#0H@("`@?0T*?0T*#0II9B`H)'-T;W)E7W-Y<W1E;5]C;VYF:6<I('L-"B`@
M("`D8V]N9FEG+3YS=&]R92@G<WES=&5M)RD[#0I]#0H-"FEF("@D<W1O<F5?
M=7-E<E]C;VYF:6<I('L-"B`@("`D8V]N9FEG+3YS=&]R92@G=7-E<B<I.PT*
M?0T*#0HD8V]M;6%N9"`]("AI<W-E="@D;W!T:6]N<ULQ75LP72DI(#\@)&]P
M=&EO;G-;,5U;,%T@.B!N=6QL.PT*#0II9B`H96UP='DH)&-O;6UA;F0I("8F
M("@D<W1O<F5?=7-E<E]C;VYF:6<@?'P@)'-T;W)E7W-Y<W1E;5]C;VYF:6<I
M*2![#0H@("`@97AI=#L-"GT-"@T*:68@*"1F971Y<&4@/3T@)T=T:R<@?'P@
M)&9E='EP92`]/2`G1W1K,B<I('L-"B`@("!I9B`H(21C;VYF:6<M/G9A;&ED
M0V]N9FEG=7)A=&EO;B@I*2![#0H@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H
M)T-2251)0T%,($524D]2.B!N;R!E>&ES=&EN9R!V86QI9"!C;VYF:6=U<F%T
M:6]N(&9I;&5S(&9O=6YD(&EN(&9I;&5S("<@+@T*("`@("`@("`@("`@(B<D
M<&5A<E]U<V5R7V-O;F9I9R<@;W(@)R1P96%R7W-Y<W1E;5]C;VYF:6<G+"!P
M;&5A<V4@8V]P>2!A;B!E>&ES=&EN9R!C;VYF:6=U<F%T:6]N(B`N#0H@("`@
M("`@("`@("`G9FEL92!T;R!O;F4@;V8@=&AE<V4@;&]C871I;VYS+"!O<B!U
M<V4@=&AE("UC(&%N9"`M<R!O<'1I;VYS('1O(&-R96%T92!O;F4G*3L-"B`@
M("!]#0H@("`@1W1K.CIM86EN*"D[#0I](&5L<V4@9&\@>PT*("`@(&EF("@D
M8V]M;6%N9"`]/2`G:&5L<"<I('L-"B`@("`@("`@=7-A9V4H;G5L;"P@0"1O
M<'1I;VYS6S%=6S%=*3L-"B`@("!]#0H@("`@:68@*"$D8V]N9FEG+3YV86QI
M9$-O;F9I9W5R871I;VXH*2D@>PT*("`@("`@("!014%2.CIR86ES945R<F]R
M*"=#4DE424-!3"!%4E)/4CH@;F\@97AI<W1I;F<@=F%L:60@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!F;W5N9"!I;B!F:6QE<R`G("X-"B`@("`@("`@("`@("(G
M)'!E87)?=7-E<E]C;VYF:6<G(&]R("<D<&5A<E]S>7-T96U?8V]N9FEG)RP@
M<&QE87-E(&-O<'D@86X@97AI<W1I;F<@8V]N9FEG=7)A=&EO;B(@+@T*("`@
M("`@("`@("`@)V9I;&4@=&\@;VYE(&]F('1H97-E(&QO8V%T:6]N<RP@;W(@
M=7-E('1H92`M8R!A;F0@+7,@;W!T:6]N<R!T;R!C<F5A=&4@;VYE)RD[#0H@
M("`@?0T*#0H@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PT*("`@("1C;60@/2!014%27T-O;6UA;F0Z.F9A8W1O<GDH
M)&-O;6UA;F0L("1C;VYF:6<I.PT*("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI
M;F<H*3L-"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VUD*2D@>PT*("`@("`@
M("!U<V%G92AN=6QL+"!`)&]P=&EO;G-;,5U;,%TI.PT*("`@('T-"@T*("`@
M("1S:&]R=%]A<F=S(#T@)&QO;F=?87)G<R`](&YU;&P[#0H@("`@4$5!4E]#
M;VUM86YD.CIG971'971O<'1!<F=S*"1C;VUM86YD+"`D<VAO<G1?87)G<RP@
M)&QO;F=?87)G<RD[#0H@("`@:68@*&EN7V%R<F%Y*"=G971O<'0R)RP@9V5T
M7V-L87-S7VUE=&AO9',H)T-O;G-O;&5?1V5T;W!T)RDI*2![#0H@("`@("`@
M(&%R<F%Y7W-H:69T*"1O<'1I;VYS6S%=*3L-"B`@("`@("`@)'1M<"`]($-O
M;G-O;&5?1V5T;W!T.CIG971O<'0R*"1O<'1I;VYS6S%=+"`D<VAO<G1?87)G
M<RP@)&QO;F=?87)G<RD[#0H@("`@?2!E;'-E('L-"B`@("`@("`@)'1M<"`]
M($-O;G-O;&5?1V5T;W!T.CIG971O<'0H)&]P=&EO;G-;,5TL("1S:&]R=%]A
M<F=S+"`D;&]N9U]A<F=S*3L-"B`@("!]#0H@("`@:68@*%!%05(Z.FES17)R
M;W(H)'1M<"DI('L-"B`@("`@("`@8G)E86L[#0H@("`@?0T*("`@(&QI<W0H
M)'1M<&]P="P@)'!A<F%M<RD@/2`D=&UP.PT*("`@("1O<'1S(#T@87)R87DH
M*3L-"B`@("!F;W)E86-H("@D=&UP;W!T(&%S("1F;V\@/3X@)'1M<#(I('L-
M"B`@("`@("`@;&ES="@D;W!T+"`D=F%L=64I(#T@)'1M<#([#0H@("`@("`@
M(&EF("@D=F%L=64@/3T](&YU;&PI('L-"B`@("`@("`@("`@("1V86QU92`]
M('1R=64[("\O(&]P=&EO;G,@=VET:&]U="!A<F=S#0H@("`@("`@('T-"B`@
M("`@("`@:68@*'-T<FQE;B@D;W!T*2`]/2`Q*2![#0H@("`@("`@("`@("`D
M8VUD;W!T:6]N<R`]("1C;60M/F=E=$]P=&EO;G,H)&-O;6UA;F0I.PT*("`@
M("`@("`@("`@9F]R96%C:"`H)&-M9&]P=&EO;G,@87,@)&\@/3X@)&0I('L-
M"B`@("`@("`@("`@("`@("!I9B`H0"1D6R=S:&]R=&]P="==(#T]("1O<'0I
M('L-"B`@("`@("`@("`@("`@("`@("`@)&]P='-;)&]=(#T@)'9A;'5E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(&EF("AS=6)S='(H)&]P="P@,"P@,BD@/3T@
M)RTM)RD@>PT*("`@("`@("`@("`@("`@("1O<'1S6W-U8G-T<B@D;W!T+"`R
M*5T@/2`D=F%L=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]
M#0H@("`@)&]K(#T@)&-M9"T^<G5N*"1C;VUM86YD+"`D;W!T<RP@)'!A<F%M
M<RD[#0H@("`@:68@*"1O:R`]/3T@9F%L<V4I('L-"B`@("`@("`@4$5!4CHZ
M<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@
M("!]#0H@("`@:68@*%!%05(Z.FES17)R;W(H)&]K*2D@>PT*("`@("`@("!0
M14%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL(&%R
M<F%Y*"1U:2P@(F1I<W!L87E&871A;$5R<F]R(BDI.PT*("`@("`@("!014%2
M.CIR86ES945R<F]R*"1O:RD[#0H@("`@?0T*?2!W:&EL92`H9F%L<V4I.PT*
M#0HO+R![>WL@=7-A9V4H*0T*#0IF=6YC=&EO;B!U<V%G92@D97)R;W(@/2!N
M=6QL+"`D:&5L<'-U8FIE8W0@/2!N=6QL*0T*>PT*("`@(&=L;V)A;"`D<')O
M9VYA;64L("1A;&Q?8V]M;6%N9',[#0H@("`@)'-T9&5R<B`](&9O<&5N*"=P
M:'`Z+R]S=&1E<G(G+"`G=R<I.PT*("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G)O<BDI('L-"B`@("`@("`@9G!U=',H)'-T9&5R<BP@)&5R<F]R+3YG971-
M97-S86=E*"D@+B`B7&XB*3L-"B`@("!](&5L<V5I9B`H)&5R<F]R("$]/2!N
M=6QL*2![#0H@("`@("`@(&9P=71S*"1S=&1E<G(L("(D97)R;W)<;B(I.PT*
M("`@('T-"B`@("!I9B`H)&AE;'!S=6)J96-T("$](&YU;&PI('L-"B`@("`@
M("`@)'!U="`](&-M9$AE;'`H)&AE;'!S=6)J96-T*3L-"B`@("!](&5L<V4@
M>PT*("`@("`@("`D<'5T(#T-"B`@("`@("`@("`@(")#;VUM86YD<SI<;B([
M#0H@("`@("`@("1M87AL96X@/2!M87@H87)R87E?;6%P*")S=')L96XB+"`D
M86QL7V-O;6UA;F1S*2D[#0H@("`@("`@("1F;W)M871S='(@/2`B)2U[)&UA
M>&QE;GUS("`E<UQN(CL-"B`@("`@("`@:W-O<G0H)&%L;%]C;VUM86YD<RD[
M#0H@("`@("`@(&9O<F5A8V@@*"1A;&Q?8V]M;6%N9',@87,@)&-M9"`]/B`D
M8VQA<W,I('L-"B`@("`@("`@("`@("1P=70@+CT@<W!R:6YT9B@D9F]R;6%T
M<W1R+"`D8VUD+"!014%27T-O;6UA;F0Z.F=E=$1E<V-R:7!T:6]N*"1C;60I
M*3L-"B`@("`@("`@?0T*("`@("`@("`D<'5T("X]#0H@("`@("`@("`@("`B
M57-A9V4Z("1P<F]G;F%M92!;;W!T:6]N<UT@8V]M;6%N9"!;8V]M;6%N9"UO
M<'1I;VYS72`\<&%R86UE=&5R<SY<;B(N#0H@("`@("`@("`@("`B5'EP92!<
M(B1P<F]G;F%M92!H96QP(&]P=&EO;G-<(B!T;R!L:7-T(&%L;"!O<'1I;VYS
M+EQN(BX-"B`@("`@("`@("`@(")4>7!E(%PB)'!R;V=N86UE(&AE;'`@<VAO
M<G1C=71S7"(@=&\@;&ES="!A;&P@8V]M;6%N9"!S:&]R=&-U=',N7&XB+@T*
M("`@("`@("`@("`@(E1Y<&4@7"(D<')O9VYA;64@:&5L<"`\8V]M;6%N9#Y<
M(B!T;R!G970@=&AE(&AE;'`@9F]R('1H92!S<&5C:69I960@8V]M;6%N9"XB
M.PT*("`@('T-"B`@("!F<'5T<R@D<W1D97)R+"`B)'!U=%QN(BD[#0H@("`@
M9F-L;W-E*"1S=&1E<G(I.PT*("`@(&5X:70[#0I]#0H-"F9U;F-T:6]N(&-M
M9$AE;'`H)&-O;6UA;F0I#0I[#0H@("`@9VQO8F%L("1P<F]G;F%M92P@)&%L
M;%]C;VUM86YD<RP@)&-O;F9I9SL-"B`@("!I9B`H)&-O;6UA;F0@/3T@(F]P
M=&EO;G,B*2![#0H@("`@("`@(')E='5R;@T*("`@("`@("`B3W!T:6]N<SI<
M;B(N#0H@("`@("`@("(@("`@("UV("`@("`@("`@:6YC<F5A<V4@=F5R8F]S
M:71Y(&QE=F5L("AD969A=6QT(#$I7&XB+@T*("`@("`@("`B("`@("`M<2`@
M("`@("`@(&)E('%U:65T+"!D96-R96%S92!V97)B;W-I='D@;&5V96Q<;B(N
M#0H@("`@("`@("(@("`@("UC(&9I;&4@("`@9FEN9"!U<V5R(&-O;F9I9W5R
M871I;VX@:6X@8&9I;&4G7&XB+@T*("`@("`@("`B("`@("`M0R!F:6QE("`@
M(&9I;F0@<WES=&5M(&-O;F9I9W5R871I;VX@:6X@8&9I;&4G7&XB+@T*("`@
M("`@("`B("`@("`M9"!F;V\]8F%R('-E="!U<V5R(&-O;F9I9R!V87)I86)L
M92!@9F]O)R!T;R!@8F%R)UQN(BX-"B`@("`@("`@(B`@("`@+40@9F]O/6)A
M<B!S970@<WES=&5M(&-O;F9I9R!V87)I86)L92!@9F]O)R!T;R!@8F%R)UQN
M(BX-"B`@("`@("`@(B`@("`@+4<@("`@("`@("!S=&%R="!I;B!G<F%P:&EC
M86P@*$=T:RD@;6]D95QN(BX-"B`@("`@("`@(B`@("`@+7,@("`@("`@("!S
M=&]R92!U<V5R(&-O;F9I9W5R871I;VY<;B(N#0H@("`@("`@("(@("`@("U3
M("`@("`@("`@<W1O<F4@<WES=&5M(&-O;F9I9W5R871I;VY<;B(N#0H@("`@
M("`@("(@("`@("UU(&9O;R`@("`@=6YS970@8&9O;R<@:6X@=&AE('5S97(@
M8V]N9FEG=7)A=&EO;EQN(BX-"B`@("`@("`@(B`@("`@+6@L("T_("`@("!D
M:7-P;&%Y(&AE;'`O=7-A9V4@*'1H:7,@;65S<V%G92E<;B(N#0H@("`@("`@
M("(@("`@("U6("`@("`@("`@=F5R<VEO;B!I;F9O<FUA=&EO;EQN(CL-"B`@
M("!](&5L<V5I9B`H)&-O;6UA;F0@/3T@(G-H;W)T8W5T<R(I('L-"B`@("`@
M("`@)'-C(#T@4$5!4E]#;VUM86YD.CIG9713:&]R=&-U=',H*3L-"B`@("`@
M("`@)')E="`](")3:&]R=&-U=',Z7&XB.PT*("`@("`@("!F;W)E86-H("@D
M<V,@87,@)',@/3X@)&,I('L-"B`@("`@("`@("`@("1R970@+CT@<W!R:6YT
M9B@B("`@("`E+3AS("5S7&XB+"`D<RP@)&,I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D<F5T.PT*#0H@("`@?2!E;'-E:68@*"1C;VUM86YD(#T]
M(")V97)S:6]N(BD@>PT*("`@("`@("!R971U<FX@(E!%05(@5F5R<VEO;CH@
M(BXD1TQ/0D%,4ULG<&5A<E]P86-K86=E7W9E<G-I;VXG72X-"B`@("`@("`@
M("`@("`@(")<;E!(4"!697)S:6]N.B`B+G!H<'9E<G-I;VXH*2X-"B`@("`@
M("`@("`@("`@(")<;EIE;F0@16YG:6YE(%9E<G-I;VXZ("(N>F5N9%]V97)S
M:6]N*"DN#0H@("`@("`@("`@("`@("`B7&Y2=6YN:6YG(&]N.B`B+G!H<%]U
M;F%M92@I.PT*#0H@("`@?2!E;'-E:68@*"1H96QP(#T@4$5!4E]#;VUM86YD
M.CIG971(96QP*"1C;VUM86YD*2D@>PT*("`@("`@("!I9B`H:7-?<W1R:6YG
M*"1H96QP*2D@>PT*("`@("`@("`@("`@<F5T=7)N("(D<')O9VYA;64@)&-O
M;6UA;F0@6V]P=&EO;G-=("1H96QP7&XB.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D:&5L<%LQ72`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N
M("(D<')O9VYA;64@)&-O;6UA;F0@)&AE;'!;,%TB.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@<F5T=7)N("(D<')O9VYA;64@)&-O;6UA;F0@
M6V]P=&EO;G-=("1H96QP6S!=7&XD:&5L<%LQ72([#0H@("`@("`@('T-"B`@
M("!]#0H@("`@<F5T=7)N(")#;VUM86YD("<D8V]M;6%N9"<@:7,@;F]T('9A
M;&ED+"!T<GD@)W!E87(@:&5L<"<B.PT*?0T*#0HO+R!]?7T-"@T*9G5N8W1I
M;VX@97)R;W)?:&%N9&QE<B@D97)R;F\L("1E<G)M<V<L("1F:6QE+"`D;&EN
M92P@)'9A<G,I('L-"B`@("!I9B`H*&1E9FEN960H)T5?4U1224-4)RD@)B8@
M)&5R<FYO("8@15]35%))0U0I('Q\("%E<G)O<E]R97!O<G1I;F<H*2D@>PT*
M("`@("`@("!I9B`H9&5F:6YE9"@G15]35%))0U0G*2`F)B`D97)R;F\@)B!%
M7U-44DE#5"D@>PT*("`@("`@("`@("`@<F5T=7)N.R`O+R!%7U-44DE#5`T*
M("`@("`@("!]#0H@("`@("`@(&EF("@D1TQ/0D%,4ULG8V]N9FEG)UTM/F=E
M="@G=F5R8F]S92<I(#P@-"D@>PT*("`@("`@("`@("`@<F5T=7)N.R`O+R!`
M<VEL96YC960@97)R;W(L('-H;W<@86QL(&EF(&1E8G5G(&ES(&AI9V@@96YO
M=6=H#0H@("`@("`@('T-"B`@("!]#0H@("`@)&5R<F]R='EP92`](&%R<F%Y
M("@-"B`@("`@("`@15]%4E)/4B`@(#T^("`B17)R;W(B+`T*("`@("`@("!%
M7U=!4DY)3D<@("`]/B`@(E=A<FYI;F<B+`T*("`@("`@("!%7U!!4E-%("`@
M/3X@(")087)S:6YG($5R<F]R(BP-"B`@("`@("`@15].3U1)0T4@("`]/B`@
M(DYO=&EC92(L#0H@("`@("`@($5?0T]215]%4E)/4B`@/3X@(")#;W)E($5R
M<F]R(BP-"B`@("`@("`@15]#3U)%7U=!4DY)3D<@(#T^("`B0V]R92!787)N
M:6YG(BP-"B`@("`@("`@15]#3TU024Q%7T524D]2("`]/B`@(D-O;7!I;&4@
M17)R;W(B+`T*("`@("`@("!%7T-/35!)3$5?5T%23DE.1R`]/B`@(D-O;7!I
M;&4@5V%R;FEN9R(L#0H@("`@("`@($5?55-%4E]%4E)/4B`]/B`@(E5S97(@
M17)R;W(B+`T*("`@("`@("!%7U5315)?5T%23DE.1R`]/B`@(E5S97(@5V%R
M;FEN9R(L#0H@("`@("`@($5?55-%4E].3U1)0T4@/3X@(")5<V5R($YO=&EC
M92(-"B`@("`I.PT*("`@("1P<F5F:7@@/2`D97)R;W)T>7!E6R1E<G)N;UT[
M#0H@("`@9VQO8F%L("1?4$5!4E]02%!$25([#0H@("`@:68@*'-T<FES='(H
M)&9I;&4L("1?4$5!4E]02%!$25(I*2![#0H@("`@("`@("1F:6QE(#T@<W5B
M<W1R*"1F:6QE+"!S=')L96XH)%]014%27U!(4$1)4BD@*R`Q*3L-"B`@("!]
M(&5L<V4@>PT*("`@("`@("`D9FEL92`](&)A<V5N86UE*"1F:6QE*3L-"B`@
M("!]#0H@("`@<')I;G0@(EQN)'!R969I>#H@)&5R<FUS9R!I;B`D9FEL92!O
M;B!L:6YE("1L:6YE7&XB.PT*?0T*#0H-"B\J#0H@*B!,;V-A;"!V87)I86)L
M97,Z#0H@*B!T86(M=VED=&@Z(#0-"B`J(&,M8F%S:6,M;V9F<V5T.B`T#0H@
M*B!I;F1E;G0M=&%B<RUM;V1E.B!N:6P-"B`J(&UO9&4Z('!H<`T*("H@16YD
M.@T*("HO#0HO+R!V:6TV,#`Z<WEN/7!H<`T*#0H_/@T*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+T-A8VAE+G!H<```````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(U,C4V`#$P-3$U-#,Q,#4W`#`Q-S`V-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N
M($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@
M)$ED.B!#86-H92YP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%
M>'`@)`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?;VYC92`G
M0V%C:&4O17)R;W(N<&AP)SL*"B\J*@HJ($-A8VAE(&ES(&$@8F%S92!C;&%S
M<R!F;W(@8V%C:&4@:6UP;&5M96YT871I;VYS+@HJ"BH@5&AE('!E87(@8V%C
M:&4@;6]D=6QE(&ES(&$@9V5N97)I8R!D871A(&-A8VAE('=H:6-H(&-A;B!B
M92!U<V5D('1O(`HJ(&-A8VAE('-C<FEP="!R=6YS+B!4:&4@:61E82!B96AI
M;F0@=&AE(&-A8VAE(&ES('%U:71E('-I;7!L92X@268@>6]U(&AA=F4**B!T
M:&4@<V%M92!I;G!U="!P87)A;65T97)S(&9O<B!W:&%T979E<B!T87-K<R]A
M;&=O<FET:&T@>6]U('5S92!Y;W4G;&P**B!U<W5A;&QY(&=E="!T:&4@<V%M
M92!O=71P=70N(%-O('=H>2!N;W0@8V%C:&EN9R!T96UP;&%T97,L(&9U;F-T
M:6]N<R!C86QL<RP**B!G<F%P:&EC(&=E;F5R871I;VX@971C+B!#86-H:6YG
M(&-E<G1A:6X@86-T:6]N<R!E+F<N(%A33%0@=')A;F9O<FUA=&EO;G,**B!S
M879E<R!Y;W4@;&]T<R!O9B!T:6UE+B`**@HJ(%1H92!D97-I9VX@;V8@=&AE
M(&-A8VAE(')E;6EN9',@;V8@4$A03&EB<R!S97-S:6]N(&EM<&QE;65N=&%T
M:6]N+B!!(`HJ("A02%!,:6(Z('-E<W-I;VXI(&-O;G1R;VQL97(@=7-E<R!S
M=&]R86=E(&-O;G1A:6YE<B`H4$A03&EB.B!C=%\J+FEN8RD@=&\@<V%V92`*
M*B!C97)T86EN(&1A=&$@*%!(4$QI8CH@<V5S<VEO;B!D871A*2X@26X@8V]N
M=')A<W0@=&\@=&AE('-E<W-I;VX@<W1U9F8@:70G<R!U<"!T;R`**B!Y;W4@
M=&\@9V5N97)A=&4@86X@240@9F]R('1H92!D871A('1O(&-A8VAE+B!)9B!Y
M;W4G<F4@=7-I;F<@=&AE(&]U='!U="!C86-H90HJ('EO=2!M:6=H="!U<V4@
M=&AE('-C<FEP="!N86UE(&%S(&$@<V5E9"!F;W(@8V%C:&4Z.F=E;F5R871E
M240H*2P@:68@>6]U<B!U<VEN9R!T:&4**B!F=6YC=&EO;B!C86-H92!Y;W4G
M9"!U<V4@86X@87)R87D@=VET:"!A;&P@9G5N8W1I;VX@<&%R86UE=&5R<RX*
M*@HJ(%5S86=E(&5X86UP;&4@;V8@=&AE(&=E;F5R:6,@9&%T82!C86-H93H*
M*@HJ(')E<75I<F5?;VYC92@G0V%C:&4N<&AP)RD["BH**B`D8V%C:&4@/2!N
M97<@0V%C:&4H)V9I;&4G+"!A<G)A>2@G8V%C:&5?9&ER)R`]/B`G8V%C:&4O
M)RD@*3L**B`D:60@/2`D8V%C:&4M/F=E;F5R871E240H)W1E<W1E;G1R>2<I
M.PHJ"BH@:68@*"1D871A(#T@)&-A8VAE+3YG970H)&ED*2D@>PHJ("`@('!R
M:6YT(")#86-H92!H:70N/&)R/D1A=&$Z("1D871A(CL**@HJ('T@96QS92![
M"BH@("`D9&%T82`]("=D871A(&]F(&%N>2!K:6YD)SL**B`@("1C86-H92T^
M<V%V92@D:60L("1D871A*3L**B`@('!R:6YT("=#86-H92!M:7-S+CQB<CXG
M.PHJ('T**@HJ(%=!4DY)3D<Z($YO($9I;&4O1$(M5&%B;&4M4F]W(&QO8VMI
M;F<@:7,@:6UP;&5M96YT960@>65T+`HJ("`@("`@("`@(&ET)W,@<&]S<VEB
M;&4L('1H870@>6]U(&=E="!C;W)R=7!T960@9&%T82UE;G1R:65S('5N9&5R
M"BH@("`@("`@("`@8F%D(&-I<F-U;7-T86YC97,@("AE<W!E8VEA;&QY('=I
M=&@@=&AE(&9I;&4@8V]N=&%I;F5R*0HJ"BH@0&%U=&AO<B`@(%5L9B!796YD
M96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S:6]N("`D260Z($-A
M8VAE+G!H<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"BH@
M0'!A8VMA9V4@($-A8VAE"BH@0&%C8V5S<R`@('!U8FQI8PHJ+PIC;&%S<R!#
M86-H92!E>'1E;F1S(%!%05(@>PH*("`@("\J*@H@("`@*B!%;F%B;&5S("\@
M9&ES86)L97,@8V%C:&EN9RX*("`@("H*("`@("H@5$]$3SH@061D(&5X<&QA
M;F%T:6]N('=H870@=&AI<R!I<R!G;V]D(&9O<BX*("`@("H*("`@("H@0'9A
M<B`@("`@(&)O;VQE86X*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("HO
M"B`@("!V87(@)&-A8VAI;F<@/2!T<G5E.PH*("`@("\J*@H@("`@*B!'87)B
M86=E(&-O;&QE8W1I;VXZ('!R;V)A8FEL:71Y(&EN('-E8V]N9',*("`@("H*
M("`@("H@268@<V5T('1O(&$@=F%L=64@86)O=F4@,"!A(&=A<F)A9V4@8V]L
M;&5C=&EO;B!W:6QL"B`@("`J(&9L=7-H(&%L;"!C86-H92!E;G1R:65S(&]L
M9&5R('1H86X@=&AE('-P96-I9FEE9"!N=6UB97(*("`@("H@;V8@<V5C;VYD
M<RX*("`@("H*("`@("H@0'9A<B`@("`@(&EN=&5G97(*("`@("H@0'-E92`@
M("`@("1G8U]P<F]B86)I;&ET>2P@)&=C7VUA>&QI9F5T:6UE"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!V87(@)&=C7W1I;64@(#T@,3L*
M"B`@("`O*BH*("`@("H@1V%R8F%G92!C;VQL96-T:6]N.B!P<F]B86)I;&ET
M>2!I;B!P97)C96YT"B`@("`J"B`@("`J(%1/1$\Z($%D9"!A;B!E>'!L86YA
M=&EO;BX*("`@("H*("`@("H@0'9A<B`@("`@(&EN=&5G97(@("`@(#`@/3X@
M;F5V97(*("`@("H@0'-E92`@("`@("1G8U]T:6UE+"`D9V-?;6%X;&EF971I
M;64*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@('9A<B`D9V-?
M<')O8F%B:6QI='D@/2`Q.PH@("`@"B`@("`O*BH*("`@("H@1V%R8F%G92!C
M;VQL96-T:6]N.B!D96QE=&4@86QL(&5N=')I97,@;F]T('5S92!F;W(@;B!S
M96-O;F1S+@H@("`@*@H@("`@*B!$969A=6QT(&ES(&]N92!D87DL(#8P("H@
M-C`@*B`R-"`](#@V-#`P('-E8V]N9',N"B`@("`J"B`@("`J($!V87(@(&EN
M=&5G97(*("`@("H@0'-E92`@)&=C7W!R;V)A8FEL:71Y+"`D9V-?=&EM90H@
M("`@*B\*("`@('9A<B`D9V-?;6%X;&EF971I;64@/2`X-C0P,#L*"B`@("`O
M*BH*("`@("H@4W1O<F%G92!C;VYT86EN97(@;V)J96-T+@H@("`@*@H@("`@
M*B!`=F%R("!O8FIE8W0@0V%C:&5?0V]N=&%I;F5R"B`@("`J+PH@("`@=F%R
M("1C;VYT86EN97(["@H@("`@+R\*("`@("\O('!U8FQI8R!M971H;V1S"B`@
M("`O+PH*("`@("\J*@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!.
M86UE(&]F(&-O;G1A:6YE<B!C;&%S<PH@("`@*B!`<&%R86T@("`@87)R87D@
M("!!<G)A>2!W:71H(&-O;G1A:6YE<B!C;&%S<R!O<'1I;VYS"B`@("`J+PH@
M("`@9G5N8W1I;VX@0V%C:&4H)&-O;G1A:6YE<BP@)&-O;G1A:6YE<E]O<'1I
M;VYS(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/E!%05(H*3L*("`@("`@
M("`D8V]N=&%I;F5R(#T@<W1R=&]L;W=E<B@D8V]N=&%I;F5R*3L*("`@("`@
M("`D8V]N=&%I;F5R7V-L87-S(#T@)T-A8VAE7T-O;G1A:6YE<E\G("X@)&-O
M;G1A:6YE<CL*("`@("`@("`D8V]N=&%I;F5R7V-L87-S9FEL92`]("=#86-H
M92]#;VYT86EN97(O)R`N("1C;VYT86EN97(@+B`G+G!H<"<["@H@("`@("`@
M(&EN8VQU9&5?;VYC92`D8V]N=&%I;F5R7V-L87-S9FEL93L*("`@("`@("`D
M=&AI<RT^8V]N=&%I;F5R(#T@;F5W("1C;VYT86EN97)?8VQA<W,H)&-O;G1A
M:6YE<E]O<'1I;VYS*3L*("`@('T*"B`@("`O+V1E8V]N<W1R=6-T;W(*("`@
M(&9U;F-T:6]N(%]#86-H92@I"B`@("!["B`@("`@("`@)'1H:7,M/F=A<F)A
M9V5#;VQL96-T:6]N*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!C=7)R96YT(&-A8VAI;F<@<W1A=&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B`@8F]O;&5A;B`@("`@5&AE(&-U<G)E;G0@8V%C:&EN9R!S=&%T92X*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M971#86-H:6YG*"D*("`@('L*("`@("`@("!R971U<FX@*"1T:&ES+3YC86-H
M:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES86)L
M97,@8V%C:&EN9RX*("`@("`J"B`@("`@*B!`<&%R86T@("!B;V]L96%N("`@
M("!4:&4@;F5W(&-A8VAI;F<@<W1A=&4N"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V%C:&EN9R@D<W1A=&4I"B`@
M("!["B`@("`@("`@)'1H:7,M/F-A8VAI;F<@/2`D<W1A=&4["B`@("!]"@H@
M("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(')E<75E<W1E9"!D871A<V5T(&ET
M(&EF(&5X:7-T<R!A;F0@:7,@;F]T(&5X<&ER960*("`@("H*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@;6EX960@("!C86-H
M960@9&%T82!O<B!.54Q,(&]N(&9A:6QU<F4*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D:60L("1G<F]U<"`]("=D
M969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@
M("`@("`@(')E='5R;B`G)SL*"B`@("`@("`@:68@*"1T:&ES+3YI<T-A8VAE
M9"@D:60L("1G<F]U<"D@)B8@(21T:&ES+3YI<T5X<&ER960H)&ED+"`D9W)O
M=7`I*0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQO860H)&ED+"`D9W)O
M=7`I.PH*("`@("`@("!R971U<FX@3E5,3#L*("`@('T@+R\@96YD(&9U;F,@
M9V5T"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!T:&4@9VEV96X@9&%T82!I;B!T
M:&4@8V%C:&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S
M970@240@=7-E9"!A<R!C86-H92!I9&5N=&EF:65R"B`@("`J($!P87)A;2`@
M("!M:7AE9"`@(&1A=&$@=&\@8V%C:&4*("`@("H@0'!A<F%M("`@(&EN=&5G
M97(@;&EF971I;64@;V8@=&AE(&-A8VAE9"!D871A(&EN('-E8V]N9',@+2`P
M(&9O<B!E;F1L97-S"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R
M;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E
M>'!I<F5S(#T@,"P@)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@:68@
M*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@
M("`@("`@(')E='5R;B`D=&AI<RT^97AT4V%V92@D:60L("1D871A+"`G)RPD
M97AP:7)E<RP@)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@<V%V90H*("`@
M("\J*@H@("`@*B!3=&]R97,@82!D871A<V5T('=I=&@@861D:71I;VYA;"!U
M<V5R9&5F:6YE9"!D871A+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!M:7AE9"`@(&1A=&$@=&\@
M<W1O<F4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@861D:71I;VYA;"!U<V5R
M9&5F:6YE9"!D871A"B`@("`J($!P87)A;2`@("!M:7AE9"`@('5S97)D969I
M;F5D(&5X<&ER92!D871E"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE
M(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J($!T:')O=W,@
M("!#86-H95]%<G)O<@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S
M964@("`@("!G9715<V5R9&%T82@I"B`@("`J+PH@("`@9G5N8W1I;VX@97AT
M4V%V92@D:60L("1C86-H961A=&$L("1U<V5R9&%T82P@)&5X<&ER97,@/2`P
M+"`D9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21T:&ES+3YC
M86-H:6YG*0H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YC;VYT86EN97(M/G-A=F4H)&ED+"`D8V%C:&5D871A+"`D
M97AP:7)E<RP@)&=R;W5P+"`D=7-E<F1A=&$I.PH@("`@?2`O+R!E;F0@9G5N
M8R!E>'13879E"@H@("`@+RHJ"B`@("`J($QO861S('1H92!G:79E;B!)1"!F
M<F]M('1H92!C86-H92X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U
M<`H@("`@*B!`<F5T=7)N("`@;6EX960@("!C86-H960@9&%T82!O<B!.54Q,
M(&]N(&9A:6QU<F4*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@
M(&9U;F-T:6]N(&QO860H)&ED+"`D9W)O=7`@/2`G9&5F875L="<I('L*("`@
M("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U<FX@
M)R<["@H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&%I;F5R+3YL;V%D*"1I
M9"P@)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@;&]A9`H*("`@("\J*@H@
M("`@*B!2971U<FYS('1H92!U<V5R9&%T82!F:65L9"!O9B!A(&-A8VAE9"!D
M871A('-E="X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E
M="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@
M*B!`<F5T=7)N("`@<W1R:6YG("!U<V5R9&%T80H@("`@*B!`86-C97-S("`@
M<'5B;&EC"B`@("`J($!S964@("`@("!E>'13879E*"D*("`@("HO"B`@("!F
M=6YC=&EO;B!G9715<V5R9&%T82@D:60L("1G<F]U<"`]("=D969A=6QT)RD@
M>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E
M='5R;B`G)SL*"B`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYT86EN97(M/F=E
M=%5S97)D871A*"1I9"P@)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@9V5T
M57-E<F1A=&$*"B`@("`O*BH*("`@("H@4F5M;W9E<R!T:&4@<W!E8VEF:65D
M(&1A=&%S970@9G)O;2!T:&4@8V%C:&4N"B`@("`J"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@(&)O;VQE86X*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@D:60L
M("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A
M8VAI;F<I"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/F-O;G1A:6YE<BT^<F5M;W9E*"1I9"P@)&=R;W5P*3L*("`@
M('T@+R\@96YD(&9U;F,@<F5M;W9E"@H@("`@+RHJ"B`@("`J($9L=7-H97,@
M=&AE(&-A8VAE("T@<F5M;W9E<R!A;&P@9&%T82!F<F]M(&ET"B`@("`J"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P+"!I9B!E;7!T>2!A
M;&P@9W)O=7!S('=I;&P@8F4@9FQA<VAE9`H@("`@*B!`<F5T=7)N("`@:6YT
M96=E<B!N=6UB97(@;V8@<F5M;W9E9"!D871A<V5T<PH@("`@*B\*("`@(&9U
M;F-T:6]N(&9L=7-H*"1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF
M("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^9FQU<V@H)&=R;W5P
M*3L*("`@('T@+R\@96YD(&9U;F,@9FQU<V@*"B`@("`O*BH*("`@("H@0VAE
M8VMS(&EF(&$@9&%T87-E="!E>&ES=',N"B`@("`J"B`@("`J($YO=&4Z('1H
M:7,@9&]E<R!N;W0@<V%Y('1H870@=&AE(&-A8VAE9"!D871A(&ES(&YO="!E
M>'!I<F5D(0H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T
M($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J
M($!R971U<FX@("!B;V]L96%N"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("HO"B`@("!F=6YC=&EO;B!I<T-A8VAE9"@D:60L("1G<F]U<"`]("=D969A
M=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYT
M86EN97(M/FES0V%C:&5D*"1I9"P@)&=R;W5P*3L*("`@('T@+R\@96YD(&9U
M;F,@:7-#86-H960*"B`@("`O*BH*("`@("H@0VAE8VMS(&EF(&$@9&%T87-E
M="!I<R!E>'!I<F5D"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A
M=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*
M("`@("H@0'!A<F%M("`@(&EN=&5G97(@;6%X:6UU;2!A9V4@9F]R('1H92!C
M86-H960@9&%T82!I;B!S96-O;F1S("T@,"!F;W(@96YD;&5S<PH@("`@*B`@
M("`@("`@("`@("`@("`@("!)9B!T:&4@8V%C:&5D(&1A=&$@:7,@;VQD97(@
M8G5T('1H92!G:79E;B!L:69E=&EM92!I="!W:6QL"B`@("`J("`@("`@("`@
M("`@("`@("`@(&)E(')E;6]V960@9G)O;2!T:&4@8V%C:&4N(%EO=2!D;VXG
M="!H879E('1O('!R;W9I9&4@=&AI<PH@("`@*B`@("`@("`@("`@("`@("`@
M("!A<F=U;65N="!I9B!Y;W4@8V%L;"!I<T5X<&ER960H*2X@179E<GD@9&%T
M87-E="!K;F]W<PH@("`@*B`@("`@("`@("`@("`@("`@("!I="=S(&5X<&ER
M92!D871E(&%N9"!W:6QL(&)E(')E;6]V960@875T;VUA=&EC86QL>2X@57-E
M"B`@("`J("`@("`@("`@("`@("`@("`@('1H:7,@;VYL>2!I9B!Y;W4@:VYO
M=R!W:&%T('EO=2=R92!D;VEN9RXN+@H@("`@*B!`<F5T=7)N("`@8F]O;&5A
M;@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@
M:7-%>'!I<F5D*"1I9"P@)&=R;W5P(#T@)V1E9F%U;'0G+"`D;6%X7V%G92`]
M(#`I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@
M("!R971U<FX@=')U93L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYT86EN
M97(M/FES17AP:7)E9"@D:60L("1G<F]U<"P@)&UA>%]A9V4I.PH@("`@?2`O
M+R!E;F0@9G5N8R!I<T5X<&ER960*"B`@("`O*BH*("`@("H@1V5N97)A=&5S
M(&$@(G5N:7%U92(@240@9F]R('1H92!G:79E;B!V86QU90H@("`@*@H@("`@
M*B!4:&ES(&ES(&$@<75I8VL@8G5T(&1I<G1Y(&AA8VL@=&\@9V5T(&$@(G5N
M:7%U92(@240@9F]R(&$@86YY(&MI;F0@;V8@=F%R:6%B;&4N"B`@("`J($E$
M(&-L87-H97,@;6EG:'0@;V-C=7(@9G)O;2!T:6UE('1O('1I;64@86QT:&]U
M9V@@=&AE>2!A<F4@97AT<F5M92!U;FQI:V5L>2$*("`@("H*("`@("H@0'!A
M<F%M("`@(&UI>&5D("`@=F%R:6%B;&4@=&\@9V5N97)A=&4@82!)1"!F;W(*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@(G5N:7%U92(@240*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E240H
M)'9A<FEA8FQE*2!["B`@("`@("`@+R\@5T%23DE.1SH@240@8VQA<VAE<R!A
M<F4@<&]S<VEB;&4@86QT:&]U9V@@=6YL:6ME;'D*("`@("`@("!R971U<FX@
M;60U*'-E<FEA;&EZ92@D=F%R:6%B;&4I*3L*("`@('T*"B`@("`O*BH*("`@
M("H@0V%L;',@=&AE(&=A<F)A9V4@8V]L;&5C=&]R(&]F('1H92!S=&]R86=E
M(&]B:F5C="!W:71H(&$@8V5R=&%I;B!P<F]B86)I;&ET>0H@("`@*@H@("`@
M*B!`<&%R86T@("`@8F]O;&5A;B!&;W)C92!A(&=A<F)A9V4@8V]L;&5C=&EO
M;B!R=6X_"B`@("`J($!S964@("1G8U]P<F]B86)I;&ET>2P@)&=C7W1I;64*
M("`@("HO"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO;B@D9F]R8V4@
M/2!F86QS92D@>PH@("`@("`@('-T871I8R`D;&%S=%]R=6X@/2`P.PH*("`@
M("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U<FX[
M"@H@("`@("`@('-R86YD*"AD;W5B;&4I(&UI8W)O=&EM92@I("H@,3`P,#`P
M,"D["@H@("`@("`@("\O('1I;64@86YD('!R;V)A8FEL:71Y(&)A<V5D"B`@
M("`@("`@:68@*"@D9F]R8V4I('Q\("@D;&%S=%]R=6X@)B8@)&QA<W1?<G5N
M(#P@=&EM92@I("L@)'1H:7,M/F=C7W1I;64I('Q\("AR86YD*#$L(#$P,"D@
M/"`D=&AI<RT^9V-?<')O8F%B:6QI='DI*2!["B`@("`@("`@("`@("1T:&ES
M+3YC;VYT86EN97(M/F=A<F)A9V5#;VQL96-T:6]N*"1T:&ES+3YG8U]M87AL
M:69E=&EM92D["B`@("`@("`@("`@("1L87-T7W)U;B`]('1I;64H*3L*("`@
M("`@("!]"B`@("!]("\O(&5N9"!F=6YC(&=A<F)A9V5#;VQL96-T:6]N"@I]
M("\O(&5N9"!C;&%S<R!C86-H90H_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]P96%R8VUD+G!H<"YO
M<FEG````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-38Q
M-P`Q,#4Q-30S,3`U-P`P,C`T-#``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\O#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L
M.B`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@
M075T:&]R<SH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("!4;VUA
M<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@
M<&5A<F-M9"YP:'`L=B`Q+C,S(#(P,#8O,#$O,#(@,3@Z,#4Z-3,@8V5L;&]G
M($5X<"`D#0H-"F]B7V5N9%]C;&5A;B@I.PT*:68@*"%D969I;F5D*"=014%2
M7U)53E194$4G*2D@>PT*("`@("\O('1H:7,@:7,@9&5F:6YE9"!I;B!P96-L
M8VUD+G!H<"!A<R`G<&5C;"<-"B`@("!D969I;F4H)U!%05)?4E5.5%E012<L
M("=P96%R)RD[#0I]#0ID969I;F4H)U!%05)?24=.3U)%7T)!0TM44D%#12<L
M(#$I.PT*:68@*"%F=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S
M)RDI('L-"B`@("!F=6YC=&EO;B!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA
M;64I#0H@("`@>PT*("`@("`@("`D9G`@/2!F;W!E;B@D9FEL96YA;64L("=R
M8B<I.PT*("`@("`@("`D<F5T(#T@)R<[#0H@("`@("`@('=H:6QE("@A9F5O
M9B@D9G`I*2![#0H@("`@("`@("`@("`D<F5T("X](&9R96%D*"1F<"P@.#`Y
M,BD[.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-
M"GT-"B\J*@T*("H@0&YO9&5P($=T:PT*("HO#0II9B`H)R]H;VUE+VQU8V5R
M+W=O<FLO<&5A<B]S:&%R92]P:'`G("$]("=`)RXG:6YC;'5D95]P871H)RXG
M0"<I('L-"B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"`G+VAO;64O;'5C
M97(O=V]R:R]P96%R+W-H87)E+W!H<"<I.PT*("`@("1R87<@/2!F86QS93L-
M"GT@96QS92![#0H@("`@+R\@=&AI<R!I<R!A(')A=RP@=6YI;G-T86QL960@
M<&5A<BP@96ET:&5R(&$@8W9S(&-H96-K;W5T+"!O<B!P:'`@9&ES=')O#0H@
M("`@)')A=R`]('1R=64[#0I]#0I`:6YI7W-E="@G86QL;W=?=7)L7V9O<&5N
M)RP@=')U92D[#0II9B`H(6EN:5]G970H)W-A9F5?;6]D92<I*2![#0H@("`@
M0'-E=%]T:6UE7VQI;6ET*#`I.PT*?0T*;V)?:6UP;&EC:71?9FQU<V@H=')U
M92D[#0I`:6YI7W-E="@G=')A8VM?97)R;W)S)RP@=')U92D[#0I`:6YI7W-E
M="@G:'1M;%]E<G)O<G,G+"!F86QS92D[#0I`:6YI7W-E="@G;6%G:6-?<75O
M=&5S7W)U;G1I;64G+"!F86QS92D[#0HD7U!%05)?4$A01$E2(#T@)R,D)5XF
M*B<[#0IS971?97)R;W)?:&%N9&QE<B@G97)R;W)?:&%N9&QE<B<I.PT*#0HD
M<&5A<E]P86-K86=E7W9E<G-I;VX@/2`B,2XT+CDB.PT*#0IR97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP
M:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T-O;F9I9RYP:'`G.PT*<F5Q=6ER
M95]O;F-E("=014%2+T-O;6UA;F0N<&AP)SL-"G)E<75I<F5?;VYC92`G0V]N
M<V]L92]'971O<'0N<&AP)SL-"@T*#0I014%27T-O;6UA;F0Z.G-E=$9R;VYT
M96YD5'EP92@G0TQ))RD[#0HD86QL7V-O;6UA;F1S(#T@4$5!4E]#;VUM86YD
M.CIG971#;VUM86YD<R@I.PT*#0HO+R!R96UO=F4@=&AI<R!N97AT('!A<G0@
M=VAE;B!W92!S=&]P('-U<'!O<G1I;F<@=&AA="!C<F%P+6%S<R!02%`@-"XR
M#0II9B`H(6ES<V5T*"1?4T525D526R=A<F=V)UTI("8F("%I<W-E="@D87)G
M=BD@)B8@(6ES<V5T*"1(5%107U-%4E9%4E]605)36R=A<F=V)UTI*2![#0H@
M("`@9&EE*"=%4E)/4CH@96ET:&5R('5S92!T:&4@0TQ)('!H<"!E>&5C=71A
M8FQE+"!O<B!S970@<F5G:7-T97)?87)G8U]A<F=V/4]N(&EN('!H<"YI;FDG
M*3L-"GT-"B1A<F=V(#T@0V]N<V]L95]'971O<'0Z.G)E86102%!!<F=V*"D[
M#0HO+R!F:7@@0T=)('-A<&D@;V1D:71Y("T@=&AE("TM(&EN('!E87(N8F%T
M+W!E87(@:7,@;F]T(')E;6]V960-"FEF("AP:'!?<V%P:5]N86UE*"D@(3T@
M)V-L:2<@)B8@:7-S970H)&%R9W9;,5TI("8F("1A<F=V6S%=(#T]("<M+2<I
M('L-"B`@("!U;G-E="@D87)G=ELQ72D[#0H@("`@)&%R9W8@/2!A<G)A>5]V
M86QU97,H)&%R9W8I.PT*?0T*)'!R;V=N86UE(#T@4$5!4E]254Y465!%.PT*
M:68@*&EN7V%R<F%Y*"=G971O<'0R)RP@9V5T7V-L87-S7VUE=&AO9',H)T-O
M;G-O;&5?1V5T;W!T)RDI*2![#0H@("`@87)R87E?<VAI9G0H)&%R9W8I.PT*
M("`@("1O<'1I;VYS(#T@0V]N<V]L95]'971O<'0Z.F=E=&]P=#(H)&%R9W8L
M(")C.D,Z9#I$.D=H/W-3<74Z=E8B*3L-"GT@96QS92![#0H@("`@)&]P=&EO
M;G,@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T*"1A<F=V+"`B8SI#.F0Z1#I'
M:#]S4W%U.G96(BD[#0I]#0II9B`H4$5!4CHZ:7-%<G)O<B@D;W!T:6]N<RDI
M('L-"B`@("!U<V%G92@D;W!T:6]N<RD[#0I]#0H-"B1O<'1S(#T@)&]P=&EO
M;G-;,%T[#0H-"B1F971Y<&4@/2`G0TQ))SL-"FEF("@D<')O9VYA;64@/3T@
M)V=P96%R)R!\?"`D<')O9VYA;64@/3T@)W!E87(M9W1K)RD@>PT*("`@("1F
M971Y<&4@/2`G1W1K)SL-"GT@96QS92![#0H@("`@9F]R96%C:"`H)&]P=',@
M87,@)&]P="D@>PT*("`@("`@("!I9B`H)&]P=%LP72`]/2`G1R<I('L-"B`@
M("`@("`@("`@("1F971Y<&4@/2`G1W1K)SL-"B`@("`@("`@?0T*("`@('T-
M"GT-"B\O0VAE8VL@:68@1W1K(&%N9"!02%`@/CT@-2XQ+C`-"FEF("@D9F5T
M>7!E(#T]("='=&LG("8F('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL
M("<U+C$N,"<L("<^/2<I*2![#0H@("`@)&9E='EP92`]("='=&LR)SL-"GT-
M"@T*)'!E87)?=7-E<E]C;VYF:6<@/2`G)SL-"B1P96%R7W-Y<W1E;5]C;VYF
M:6<@/2`G)SL-"B1S=&]R95]U<V5R7V-O;F9I9R`](&9A;'-E.PT*)'-T;W)E
M7W-Y<W1E;5]C;VYF:6<@/2!F86QS93L-"B1V97)B;W-E(#T@,3L-"@T*9F]R
M96%C:"`H)&]P=',@87,@)&]P="D@>PT*("`@('-W:71C:"`H)&]P=%LP72D@
M>PT*("`@("`@("!C87-E("=C)SH-"B`@("`@("`@("`@("1P96%R7W5S97)?
M8V]N9FEG(#T@)&]P=%LQ73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("!C87-E("=#)SH-"B`@("`@("`@("`@("1P96%R7W-Y<W1E;5]C;VYF:6<@
M/2`D;W!T6S%=.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@?0T*?0T*#0I0
M14%27T-O;6UA;F0Z.G-E=$9R;VYT96YD5'EP92@D9F5T>7!E*3L-"B1U:2`]
M("9014%27T-O;6UA;F0Z.F=E=$9R;VYT96YD3V)J96-T*"D[#0HD8V]N9FEG
M(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH)'!E87)?=7-E<E]C;VYF:6<L
M("1P96%R7W-Y<W1E;5]C;VYF:6<I.PT*#0II9B`H4$5!4CHZ:7-%<G)O<B@D
M8V]N9FEG*2D@>PT*("`@("1?9FEL92`]("<G.PT*("`@(&EF("@D<&5A<E]U
M<V5R7V-O;F9I9R`A/3T@9F%L<V4I('L-"B`@("`@("`D7V9I;&4@+CT@)'!E
M87)?=7-E<E]C;VYF:6<[#0H@("`@?0T*("`@(&EF("@D<&5A<E]S>7-T96U?
M8V]N9FEG("$]/2!F86QS92D@>PT*("`@("`@("1?9FEL92`N/2`G+R<@+B`D
M<&5A<E]S>7-T96U?8V]N9FEG.PT*("`@('T-"B`@("!I9B`H)%]F:6QE(#T]
M("<O)RD@>PT*("`@("`@("`D7V9I;&4@/2`G5&AE(&1E9F%U;'0@8V]N9FEG
M(&9I;&4G.PT*("`@('T-"B`@("`D8V]N9FEG+3YG971-97-S86=E*"D[#0H@
M("`@)'5I+3YO=71P=71$871A*")%4E)/4CH@)%]F:6QE(&ES(&YO="!A('9A
M;&ED(&-O;F9I9R!F:6QE(&]R(&ES(&-O<G)U<'1E9"XB*3L-"B`@("`O+R!7
M92!S=&]P+"!W92!H879E(&YO(&ED96$@=VAE<F4@=V4@87)E(#HI#0H@("`@
M97AI="@I.R`@("`-"GT-"@T*+R\@=&AI<R!I<R!U<V5D(&EN('1H92!E<G)O
M<B!H86YD;&5R('1O(')E=')I979E(&$@<F5L871I=F4@<&%T:`T*)%]014%2
M7U!(4$1)4B`]("1C;VYF:6<M/F=E="@G<&AP7V1I<B<I.PT*)'5I+3YS971#
M;VYF:6<H)&-O;F9I9RD[#0I014%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?0T%,3$)!0TLL(&%R<F%Y*"1U:2P@(F1I<W!L87E&871A;$5R<F]R
M(BDI.PT*:68@*&EN:5]G970H)W-A9F5?;6]D92<I*2![#0H@("`@)'5I+3YO
M=71P=71$871A*"=705).24Y'.B!R=6YN:6YG(&EN('-A9F4@;6]D92!R97%U
M:7)E<R!T:&%T(&%L;"!F:6QE<R!C<F5A=&5D("<@+@T*("`@("`@("`G8F4@
M=&AE('-A;64@=6ED(&%S('1H92!C=7)R96YT('-C<FEP="X@(%!(4"!R97!O
M<G1S('1H:7,@<V-R:7!T(&ES('5I9#H@)R`N#0H@("`@("`@($!G971M>75I
M9"@I("X@)RP@86YD(&-U<G)E;G0@=7-E<B!I<SH@)R`N($!G971?8W5R<F5N
M=%]U<V5R*"DI.PT*?0T*#0HD=F5R8F]S92`]("1C;VYF:6<M/F=E="@B=F5R
M8F]S92(I.PT*)&-M9&]P=',@/2!A<G)A>2@I.PT*#0II9B`H)')A=RD@>PT*
M("`@(&EF("@A)&-O;F9I9RT^:7-$969I;F5D3&%Y97(H)W5S97(G*2`F)B`A
M)&-O;F9I9RT^:7-$969I;F5D3&%Y97(H)W-Y<W1E;2<I*2![#0H@("`@("`@
M("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("@D;W!T<R!A<R`D
M;W!T*2![#0H@("`@("`@("`@("!I9B`H)&]P=%LP72`]/2`G9"<@?'P@)&]P
M=%LP72`]/2`G1"<I('L-"B`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E
M.R`O+R!T:&4@=7-E<B!K;F]W<R!W:&%T('1H97D@87)E(&1O:6YG+"!A;F0@
M87)E('-E='1I;F<@8V]N9FEG('9A;'5E<PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@A)&9O=6YD*2![#0H@("`@("`@("`@("`O
M+R!N;R!P<FEO<B!R=6YS+"!T<GD@=&\@:6YS=&%L;"!014%2#0H@("`@("`@
M("`@("!I9B`H<W1R<&]S*&1I<FYA;64H7U]&24Q%7U\I+"`G<V-R:7!T<R<I
M*2![#0H@("`@("`@("`@("`@("`@)'!A8VMA9V5X;6P@/2!D:7)N86UE*&1I
M<FYA;64H7U]&24Q%7U\I*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&%C
M:V%G93(N>&UL)SL-"B`@("`@("`@("`@("`@("`D<&5A<F)A<V4@/2!D:7)N
M86UE*&1I<FYA;64H7U]&24Q%7U\I*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'!A8VMA9V5X;6P@/2!D:7)N86UE*%]?1DE,
M15]?*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-
M"B`@("`@("`@("`@("`@("`D<&5A<F)A<V4@/2!D:7)N86UE*%]?1DE,15]?
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T
M<R@D<&%C:V%G97AM;"DI('L-"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULQ
M72`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G:6YS=&%L;"<L#0H@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E>&UL#0H@("`@("`@("`@("`@
M("`@*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS970H)W!H<%]D:7(G
M+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!H<"<I.PT*
M("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G9&%T85]D:7(G+"`D<&5A
M<F)A<V4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)V1A=&$G*3L-"B`@("`@
M("`@("`@("`@("`D8V]N9FEG+3YS970H)V1O8U]D:7(G+"`D<&5A<F)A<V4@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)V1O8W,G*3L-"B`@("`@("`@("`@
M("`@("`D8V]N9FEG+3YS970H)W1E<W1?9&ER)RP@)'!E87)B87-E("X@1$E2
M14-43U)97U-%4$%2051/4B`N("=T97-T<R<I.PT*("`@("`@("`@("`@("`@
M("1C;VYF:6<M/G-E="@G97AT7V1I<B<L("1P96%R8F%S92`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`G97AT96YS:6]N<R<I.PT*("`@("`@("`@("`@("`@
M("1C;VYF:6<M/G-E="@G8FEN7V1I<B<L("1P96%R8F%S92D[#0H@("`@("`@
M("`@("`@("`@)&-O;F9I9RT^;65R9V5#;VYF:6=&:6QE*"1P96%R8F%S92`N
M("=P96%R+FEN:2<L(&9A;'-E*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG
M+3YS=&]R92@I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G875T
M;U]D:7-C;W9E<B<L(#$I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@?0T*?0T*9F]R96%C:"`H)&]P=',@87,@)&]P="D@>PT*("`@("1P87)A
M;2`]("%E;7!T>2@D;W!T6S%=*2`_("1O<'1;,5T@.B!T<G5E.PT*("`@('-W
M:71C:"`H)&]P=%LP72D@>PT*("`@("`@("!C87-E("=D)SH-"B`@("`@("`@
M("`@(&QI<W0H)&ME>2P@)'9A;'5E*2`](&5X<&QO9&4H)STG+"`D<&%R86TI
M.PT*("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"1K97DL("1V86QU92P@)W5S
M97(G*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=$)SH-
M"B`@("`@("`@("`@(&QI<W0H)&ME>2P@)'9A;'5E*2`](&5X<&QO9&4H)STG
M+"`D<&%R86TI.PT*("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"1K97DL("1V
M86QU92P@)W-Y<W1E;2<I.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M(&-A<V4@)W,G.@T*("`@("`@("`@("`@)'-T;W)E7W5S97)?8V]N9FEG(#T@
M=')U93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=3)SH-
M"B`@("`@("`@("`@("1S=&]R95]S>7-T96U?8V]N9FEG(#T@=')U93L-"B`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=U)SH-"B`@("`@("`@
M("`@("1C;VYF:6<M/G)E;6]V92@D<&%R86TL("=U<V5R)RD[#0H@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G=B<Z#0H@("`@("`@("`@("`D
M8V]N9FEG+3YS970H)W9E<F)O<V4G+"`D8V]N9FEG+3YG970H)W9E<F)O<V4G
M*2`K(#$I.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)W$G
M.@T*("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"=V97)B;W-E)RP@)&-O;F9I
M9RT^9V5T*"=V97)B;W-E)RD@+2`Q*3L-"B`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("!C87-E("=6)SH-"B`@("`@("`@("`@('5S86=E*&YU;&PL("=V
M97)S:6]N)RD[#0H@("`@("`@(&-A<V4@)V,G.@T*("`@("`@("!C87-E("=#
M)SH-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!D969A=6QT.@T*("`@
M("`@("`@("`@+R\@86QL(&YO;B!P96%R('!A<F%M<R!G;V5S('1O('1H92!C
M;VUM86YD#0H@("`@("`@("`@("`D8VUD;W!T<ULD;W!T6S!=72`]("1P87)A
M;3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@('T-"GT-"@T*:68@*"1S=&]R
M95]S>7-T96U?8V]N9FEG*2![#0H@("`@)&-O;F9I9RT^<W1O<F4H)W-Y<W1E
M;2<I.PT*?0T*#0II9B`H)'-T;W)E7W5S97)?8V]N9FEG*2![#0H@("`@)&-O
M;F9I9RT^<W1O<F4H)W5S97(G*3L-"GT-"@T*)&-O;6UA;F0@/2`H:7-S970H
M)&]P=&EO;G-;,5U;,%TI*2`_("1O<'1I;VYS6S%=6S!=(#H@;G5L;#L-"@T*
M:68@*&5M<'1Y*"1C;VUM86YD*2`F)B`H)'-T;W)E7W5S97)?8V]N9FEG('Q\
M("1S=&]R95]S>7-T96U?8V]N9FEG*2D@>PT*("`@(&5X:70[#0I]#0H-"FEF
M("@D9F5T>7!E(#T]("='=&LG('Q\("1F971Y<&4@/3T@)T=T:S(G*2![#0H@
M("`@:68@*"$D8V]N9FEG+3YV86QI9$-O;F9I9W5R871I;VXH*2D@>PT*("`@
M("`@("!014%2.CIR86ES945R<F]R*"=#4DE424-!3"!%4E)/4CH@;F\@97AI
M<W1I;F<@=F%L:60@8V]N9FEG=7)A=&EO;B!F:6QE<R!F;W5N9"!I;B!F:6QE
M<R`G("X-"B`@("`@("`@("`@("(G)'!E87)?=7-E<E]C;VYF:6<G(&]R("<D
M<&5A<E]S>7-T96U?8V]N9FEG)RP@<&QE87-E(&-O<'D@86X@97AI<W1I;F<@
M8V]N9FEG=7)A=&EO;B(@+@T*("`@("`@("`@("`@)V9I;&4@=&\@;VYE(&]F
M('1H97-E(&QO8V%T:6]N<RP@;W(@=7-E('1H92`M8R!A;F0@+7,@;W!T:6]N
M<R!T;R!C<F5A=&4@;VYE)RD[#0H@("`@?0T*("`@($=T:SHZ;6%I;B@I.PT*
M?2!E;'-E(&1O('L-"B`@("!I9B`H)&-O;6UA;F0@/3T@)VAE;'`G*2![#0H@
M("`@("`@('5S86=E*&YU;&PL($`D;W!T:6]N<ULQ75LQ72D[#0H@("`@?0T*
M("`@(&EF("@A)&-O;F9I9RT^=F%L:61#;VYF:6=U<F%T:6]N*"DI('L-"B`@
M("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@G0U))5$E#04P@15)23U(Z(&YO(&5X
M:7-T:6YG('9A;&ED(&-O;F9I9W5R871I;VX@9FEL97,@9F]U;F0@:6X@9FEL
M97,@)R`N#0H@("`@("`@("`@("`B)R1P96%R7W5S97)?8V]N9FEG)R!O<B`G
M)'!E87)?<WES=&5M7V-O;F9I9R<L('!L96%S92!C;W!Y(&%N(&5X:7-T:6YG
M(&-O;F9I9W5R871I;VXB("X-"B`@("`@("`@("`@("=F:6QE('1O(&]N92!O
M9B!T:&5S92!L;V-A=&EO;G,L(&]R('5S92!T:&4@+6,@86YD("US(&]P=&EO
M;G,@=&\@8W)E871E(&]N92<I.PT*("`@('T-"@T*("`@(%!%05(Z.G!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`D8VUD(#T@
M4$5!4E]#;VUM86YD.CIF86-T;W)Y*"1C;VUM86YD+"`D8V]N9FEG*3L-"B`@
M("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@:68@*%!%05(Z.FES
M17)R;W(H)&-M9"DI('L-"B`@("`@("`@=7-A9V4H;G5L;"P@0"1O<'1I;VYS
M6S%=6S!=*3L-"B`@("!]#0H-"B`@("`D<VAO<G1?87)G<R`]("1L;VYG7V%R
M9W,@/2!N=6QL.PT*("`@(%!%05)?0V]M;6%N9#HZ9V5T1V5T;W!T07)G<R@D
M8V]M;6%N9"P@)'-H;W)T7V%R9W,L("1L;VYG7V%R9W,I.PT*("`@(&EF("AI
M;E]A<G)A>2@G9V5T;W!T,B<L(&=E=%]C;&%S<U]M971H;V1S*"=#;VYS;VQE
M7T=E=&]P="<I*2D@>PT*("`@("`@("!A<G)A>5]S:&EF="@D;W!T:6]N<ULQ
M72D[#0H@("`@("`@("1T;7`@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T,B@D
M;W!T:6]N<ULQ72P@)'-H;W)T7V%R9W,L("1L;VYG7V%R9W,I.PT*("`@('T@
M96QS92![#0H@("`@("`@("1T;7`@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T
M*"1O<'1I;VYS6S%=+"`D<VAO<G1?87)G<RP@)&QO;F=?87)G<RD[#0H@("`@
M?0T*("`@(&EF("A014%2.CII<T5R<F]R*"1T;7`I*2![#0H@("`@("`@(&)R
M96%K.PT*("`@('T-"B`@("!L:7-T*"1T;7!O<'0L("1P87)A;7,I(#T@)'1M
M<#L-"B`@("`D;W!T<R`](&%R<F%Y*"D[#0H@("`@9F]R96%C:"`H)'1M<&]P
M="!A<R`D9F]O(#T^("1T;7`R*2![#0H@("`@("`@(&QI<W0H)&]P="P@)'9A
M;'5E*2`]("1T;7`R.PT*("`@("`@("!I9B`H)'9A;'5E(#T]/2!N=6QL*2![
M#0H@("`@("`@("`@("`D=F%L=64@/2!T<G5E.R`O+R!O<'1I;VYS('=I=&AO
M=70@87)G<PT*("`@("`@("!]#0H@("`@("`@(&EF("AS=')L96XH)&]P="D@
M/3T@,2D@>PT*("`@("`@("`@("`@)&-M9&]P=&EO;G,@/2`D8VUD+3YG971/
M<'1I;VYS*"1C;VUM86YD*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;61O
M<'1I;VYS(&%S("1O(#T^("1D*2![#0H@("`@("`@("`@("`@("`@:68@*$`D
M9%LG<VAO<G1O<'0G72`]/2`D;W!T*2![#0H@("`@("`@("`@("`@("`@("`@
M("1O<'1S6R1O72`]("1V86QU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H
M<W5B<W1R*"1O<'0L(#`L(#(I(#T]("<M+2<I('L-"B`@("`@("`@("`@("`@
M("`D;W!T<UMS=6)S='(H)&]P="P@,BE=(#T@)'9A;'5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@?0T*("`@("1O:R`]("1C;60M/G)U;B@D
M8V]M;6%N9"P@)&]P=',L("1P87)A;7,I.PT*("`@(&EF("@D;VL@/3T](&9A
M;'-E*2![#0H@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(G5N:VYO=VX@8V]M
M;6%N9"!@)&-O;6UA;F0G(BD[#0H@("`@?0T*("`@(&EF("A014%2.CII<T5R
M<F]R*"1O:RDI('L-"B`@("`@("`@4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA0
M14%27T524D]27T-!3$Q"04-++"!A<G)A>2@D=6DL(")D:7-P;&%Y1F%T86Q%
M<G)O<B(I*3L-"B`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@D;VLI.PT*("`@
M('T-"GT@=VAI;&4@*&9A;'-E*3L-"@T*+R\@>WM[('5S86=E*"D-"@T*9G5N
M8W1I;VX@=7-A9V4H)&5R<F]R(#T@;G5L;"P@)&AE;'!S=6)J96-T(#T@;G5L
M;"D-"GL-"B`@("!G;&]B86P@)'!R;V=N86UE+"`D86QL7V-O;6UA;F1S.PT*
M("`@("1S=&1E<G(@/2!F;W!E;B@G<&AP.B\O<W1D97)R)RP@)W<G*3L-"B`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(I*2![#0H@("`@("`@(&9P=71S
M*"1S=&1E<G(L("1E<G)O<BT^9V5T365S<V%G92@I("X@(EQN(BD[#0H@("`@
M?2!E;'-E:68@*"1E<G)O<B`A/3T@;G5L;"D@>PT*("`@("`@("!F<'5T<R@D
M<W1D97)R+"`B)&5R<F]R7&XB*3L-"B`@("!]#0H@("`@:68@*"1H96QP<W5B
M:F5C="`A/2!N=6QL*2![#0H@("`@("`@("1P=70@/2!C;61(96QP*"1H96QP
M<W5B:F5C="D[#0H@("`@?2!E;'-E('L-"B`@("`@("`@)'!U="`]#0H@("`@
M("`@("`@("`B0V]M;6%N9',Z7&XB.PT*("`@("`@("`D;6%X;&5N(#T@;6%X
M*&%R<F%Y7VUA<"@B<W1R;&5N(BP@)&%L;%]C;VUM86YD<RDI.PT*("`@("`@
M("`D9F]R;6%T<W1R(#T@(B4M>R1M87AL96Y]<R`@)7-<;B([#0H@("`@("`@
M(&MS;W)T*"1A;&Q?8V]M;6%N9',I.PT*("`@("`@("!F;W)E86-H("@D86QL
M7V-O;6UA;F1S(&%S("1C;60@/3X@)&-L87-S*2![#0H@("`@("`@("`@("`D
M<'5T("X]('-P<FEN=&8H)&9O<FUA='-T<BP@)&-M9"P@4$5!4E]#;VUM86YD
M.CIG971$97-C<FEP=&EO;B@D8VUD*2D[#0H@("`@("`@('T-"B`@("`@("`@
M)'!U="`N/0T*("`@("`@("`@("`@(E5S86=E.B`D<')O9VYA;64@6V]P=&EO
M;G-=(&-O;6UA;F0@6V-O;6UA;F0M;W!T:6]N<UT@/'!A<F%M971E<G,^7&XB
M+@T*("`@("`@("`@("`@(E1Y<&4@7"(D<')O9VYA;64@:&5L<"!O<'1I;VYS
M7"(@=&\@;&ES="!A;&P@;W!T:6]N<RY<;B(N#0H@("`@("`@("`@("`B5'EP
M92!<(B1P<F]G;F%M92!H96QP('-H;W)T8W5T<UPB('1O(&QI<W0@86QL(&-O
M;6UA;F0@<VAO<G1C=71S+EQN(BX-"B`@("`@("`@("`@(")4>7!E(%PB)'!R
M;V=N86UE(&AE;'`@/&-O;6UA;F0^7"(@=&\@9V5T('1H92!H96QP(&9O<B!T
M:&4@<W!E8VEF:65D(&-O;6UA;F0N(CL-"B`@("!]#0H@("`@9G!U=',H)'-T
M9&5R<BP@(B1P=71<;B(I.PT*("`@(&9C;&]S92@D<W1D97)R*3L-"B`@("!E
M>&ET.PT*?0T*#0IF=6YC=&EO;B!C;61(96QP*"1C;VUM86YD*0T*>PT*("`@
M(&=L;V)A;"`D<')O9VYA;64L("1A;&Q?8V]M;6%N9',L("1C;VYF:6<[#0H@
M("`@:68@*"1C;VUM86YD(#T](")O<'1I;VYS(BD@>PT*("`@("`@("!R971U
M<FX-"B`@("`@("`@(D]P=&EO;G,Z7&XB+@T*("`@("`@("`B("`@("`M=B`@
M("`@("`@(&EN8W)E87-E('9E<F)O<VET>2!L979E;"`H9&5F875L="`Q*5QN
M(BX-"B`@("`@("`@(B`@("`@+7$@("`@("`@("!B92!Q=6EE="P@9&5C<F5A
M<V4@=F5R8F]S:71Y(&QE=F5L7&XB+@T*("`@("`@("`B("`@("`M8R!F:6QE
M("`@(&9I;F0@=7-E<B!C;VYF:6=U<F%T:6]N(&EN(&!F:6QE)UQN(BX-"B`@
M("`@("`@(B`@("`@+4,@9FEL92`@("!F:6YD('-Y<W1E;2!C;VYF:6=U<F%T
M:6]N(&EN(&!F:6QE)UQN(BX-"B`@("`@("`@(B`@("`@+60@9F]O/6)A<B!S
M970@=7-E<B!C;VYF:6<@=F%R:6%B;&4@8&9O;R<@=&\@8&)A<B=<;B(N#0H@
M("`@("`@("(@("`@("U$(&9O;SUB87(@<V5T('-Y<W1E;2!C;VYF:6<@=F%R
M:6%B;&4@8&9O;R<@=&\@8&)A<B=<;B(N#0H@("`@("`@("(@("`@("U'("`@
M("`@("`@<W1A<G0@:6X@9W)A<&AI8V%L("A'=&LI(&UO9&5<;B(N#0H@("`@
M("`@("(@("`@("US("`@("`@("`@<W1O<F4@=7-E<B!C;VYF:6=U<F%T:6]N
M7&XB+@T*("`@("`@("`B("`@("`M4R`@("`@("`@('-T;W)E('-Y<W1E;2!C
M;VYF:6=U<F%T:6]N7&XB+@T*("`@("`@("`B("`@("`M=2!F;V\@("`@('5N
M<V5T(&!F;V\G(&EN('1H92!U<V5R(&-O;F9I9W5R871I;VY<;B(N#0H@("`@
M("`@("(@("`@("UH+"`M/R`@("`@9&ES<&QA>2!H96QP+W5S86=E("AT:&ES
M(&UE<W-A9V4I7&XB+@T*("`@("`@("`B("`@("`M5B`@("`@("`@('9E<G-I
M;VX@:6YF;W)M871I;VY<;B([#0H@("`@?2!E;'-E:68@*"1C;VUM86YD(#T]
M(")S:&]R=&-U=',B*2![#0H@("`@("`@("1S8R`](%!%05)?0V]M;6%N9#HZ
M9V5T4VAO<G1C=71S*"D[#0H@("`@("`@("1R970@/2`B4VAO<G1C=71S.EQN
M(CL-"B`@("`@("`@9F]R96%C:"`H)'-C(&%S("1S(#T^("1C*2![#0H@("`@
M("`@("`@("`D<F5T("X]('-P<FEN=&8H(B`@("`@)2TX<R`E<UQN(BP@)',L
M("1C*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"@T*("`@
M('T@96QS96EF("@D8V]M;6%N9"`]/2`B=F5R<VEO;B(I('L-"B`@("`@("`@
M<F5T=7)N(")014%2(%9E<G-I;VXZ("(N)$=,3T)!3%-;)W!E87)?<&%C:V%G
M95]V97)S:6]N)UTN#0H@("`@("`@("`@("`@("`B7&Y02%`@5F5R<VEO;CH@
M(BYP:'!V97)S:6]N*"DN#0H@("`@("`@("`@("`@("`B7&Y:96YD($5N9VEN
M92!697)S:6]N.B`B+GIE;F1?=F5R<VEO;B@I+@T*("`@("`@("`@("`@("`@
M(EQN4G5N;FEN9R!O;CH@(BYP:'!?=6YA;64H*3L-"@T*("`@('T@96QS96EF
M("@D:&5L<"`](%!%05)?0V]M;6%N9#HZ9V5T2&5L<"@D8V]M;6%N9"DI('L-
M"B`@("`@("`@:68@*&ES7W-T<FEN9R@D:&5L<"DI('L-"B`@("`@("`@("`@
M(')E='5R;B`B)'!R;V=N86UE("1C;VUM86YD(%MO<'1I;VYS72`D:&5L<%QN
M(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&AE;'!;,5T@/3T](&YU;&PI
M('L-"B`@("`@("`@("`@(')E='5R;B`B)'!R;V=N86UE("1C;VUM86YD("1H
M96QP6S!=(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R
M;B`B)'!R;V=N86UE("1C;VUM86YD(%MO<'1I;VYS72`D:&5L<%LP75QN)&AE
M;'!;,5TB.PT*("`@("`@("!]#0H@("`@?0T*("`@(')E='5R;B`B0V]M;6%N
M9"`G)&-O;6UA;F0G(&ES(&YO="!V86QI9"P@=')Y("=P96%R(&AE;'`G(CL-
M"GT-"@T*+R\@?7U]#0H-"F9U;F-T:6]N(&5R<F]R7VAA;F1L97(H)&5R<FYO
M+"`D97)R;7-G+"`D9FEL92P@)&QI;F4L("1V87)S*2![#0H@("`@:68@*"AD
M969I;F5D*"=%7U-44DE#5"<I("8F("1E<G)N;R`F($5?4U1224-4*2!\?"`A
M97)R;W)?<F5P;W)T:6YG*"DI('L-"B`@("`@("`@:68@*&1E9FEN960H)T5?
M4U1224-4)RD@)B8@)&5R<FYO("8@15]35%))0U0I('L-"B`@("`@("`@("`@
M(')E='5R;CL@+R\@15]35%))0U0-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)$=,3T)!3%-;)V-O;F9I9R==+3YG970H)W9E<F)O<V4G*2`\(#0I('L-"B`@
M("`@("`@("`@(')E='5R;CL@+R\@0'-I;&5N8V5D(&5R<F]R+"!S:&]W(&%L
M;"!I9B!D96)U9R!I<R!H:6=H(&5N;W5G:`T*("`@("`@("!]#0H@("`@?0T*
M("`@("1E<G)O<G1Y<&4@/2!A<G)A>2`H#0H@("`@("`@($5?15)23U(@("`]
M/B`@(D5R<F]R(BP-"B`@("`@("`@15]705).24Y'("`@/3X@(")787)N:6YG
M(BP-"B`@("`@("`@15]005)312`@(#T^("`B4&%R<VEN9R!%<G)O<B(L#0H@
M("`@("`@($5?3D]424-%("`@/3X@(").;W1I8V4B+`T*("`@("`@("!%7T-/
M4D5?15)23U(@(#T^("`B0V]R92!%<G)O<B(L#0H@("`@("`@($5?0T]215]7
M05).24Y'("`]/B`@(D-O<F4@5V%R;FEN9R(L#0H@("`@("`@($5?0T]-4$E,
M15]%4E)/4B`@/3X@(")#;VUP:6QE($5R<F]R(BP-"B`@("`@("`@15]#3TU0
M24Q%7U=!4DY)3D<@/3X@(")#;VUP:6QE(%=A<FYI;F<B+`T*("`@("`@("!%
M7U5315)?15)23U(@/3X@(")5<V5R($5R<F]R(BP-"B`@("`@("`@15]54T52
M7U=!4DY)3D<@/3X@(")5<V5R(%=A<FYI;F<B+`T*("`@("`@("!%7U5315)?
M3D]424-%(#T^("`B57-E<B!.;W1I8V4B#0H@("`@*3L-"B`@("`D<')E9FEX
M(#T@)&5R<F]R='EP95LD97)R;F]=.PT*("`@(&=L;V)A;"`D7U!%05)?4$A0
M1$E2.PT*("`@(&EF("AS=')I<W1R*"1F:6QE+"`D7U!%05)?4$A01$E2*2D@
M>PT*("`@("`@("`D9FEL92`]('-U8G-T<B@D9FEL92P@<W1R;&5N*"1?4$5!
M4E]02%!$25(I("L@,2D[#0H@("`@?2!E;'-E('L-"B`@("`@("`@)&9I;&4@
M/2!B87-E;F%M92@D9FEL92D[#0H@("`@?0T*("`@('!R:6YT(")<;B1P<F5F
M:7@Z("1E<G)M<V<@:6X@)&9I;&4@;VX@;&EN92`D;&EN95QN(CL-"GT-"@T*
M#0HO*@T*("H@3&]C86P@=F%R:6%B;&5S.@T*("H@=&%B+7=I9'1H.B`T#0H@
M*B!C+6)A<VEC+6]F9G-E=#H@-`T*("H@:6YD96YT+71A8G,M;6]D93H@;FEL
M#0H@*B!M;V1E.B!P:'`-"B`J($5N9#H-"B`J+PT*+R\@=FEM-C`P.G-Y;CUP
M:'`-"@T*/SX-"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W!E8VQC;60N<&AP````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-3(Q`#$P-3$U-#,Q,#4W
M`#`Q-S0V,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+R\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PT*+R\@?"!02%`@5F5R<VEO;B`U("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW
M+3(P,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\
M#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\("`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O
M>$!I9&5C;F5T+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!P96-L8VUD+G!H<"QV
M(#$N,2`R,#`U+S`R+S(Q(#`U.C,P.C4V(&-E;&QO9R!%>'`@)`T*#0HO*BH-
M"B`J($!N;V1E<"!'=&L-"B`J+PT*:68@*"<O=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PT*("`@
M(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L("<O=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B<I.PT*("`@("1R87<@/2!F86QS93L-"GT@96QS92![#0H@
M("`@+R\@=&AI<R!I<R!A(')A=RP@=6YI;G-T86QL960@<&5A<BP@96ET:&5R
M(&$@8W9S(&-H96-K;W5T+"!O<B!P:'`@9&ES=')O#0H@("`@)')A=R`]('1R
M=64[#0I]#0ID969I;F4H)U!%05)?4E5.5%E012<L("=P96-L)RD[#0IR97%U
M:7)E7V]N8V4@)W!E87)C;60N<&AP)SL-"B\J#0H@*B!,;V-A;"!V87)I86)L
M97,Z#0H@*B!T86(M=VED=&@Z(#0-"B`J(&,M8F%S:6,M;V9F<V5T.B`T#0H@
M*B!I;F1E;G0M=&%B<RUM;V1E.B!N:6P-"B`J(&UO9&4Z('!H<`T*("H@16YD
M.@T*("HO#0HO+R!V:6TV,#`Z<WEN/7!H<`T*#0H_/@T*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B],;V<N<&AP````````````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,#0V,P`Q,#4Q-30S,3`U-P`P,38V
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO
M9RYP:'`L=B`Q+C4Y(#(P,#8O,#0O,C4@,#8Z,#(Z,C,@:F]N($5X<"`D"B`J
M("1(;W)D93H@:&]R9&4O;&EB+TQO9RYP:'`L=B`Q+C$U(#(P,#`O,#8O,CD@
M,C,Z,SDZ-#4@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@
M,2XU.2`D"B`J($!P86-K86=E($QO9PH@*B\*"F1E9FEN92@G4$5!4E],3T=?
M14U%4D<G+"`@("`P*3L@("`@("\J*B!3>7-T96T@:7,@=6YU<V%B;&4@*B\*
M9&5F:6YE*"=014%27TQ/1U]!3$525"<L("`@(#$I.R`@("`@+RHJ($EM;65D
M:6%T92!A8W1I;VX@<F5Q=6ER960@*B\*9&5F:6YE*"=014%27TQ/1U]#4DE4
M)RP@("`@(#(I.R`@("`@+RHJ($-R:71I8V%L(&-O;F1I=&EO;G,@*B\*9&5F
M:6YE*"=014%27TQ/1U]%4E(G+"`@("`@(#,I.R`@("`@+RHJ($5R<F]R(&-O
M;F1I=&EO;G,@*B\*9&5F:6YE*"=014%27TQ/1U]705).24Y')RP@(#0I.R`@
M("`@+RHJ(%=A<FYI;F<@8V]N9&ET:6]N<R`J+PID969I;F4H)U!%05)?3$]'
M7TY/5$E#12<L("`@-2D[("`@("`O*BH@3F]R;6%L(&)U="!S:6=N:69I8V%N
M="`J+PID969I;F4H)U!%05)?3$]'7TE.1D\G+"`@("`@-BD[("`@("`O*BH@
M26YF;W)M871I;VYA;"`J+PID969I;F4H)U!%05)?3$]'7T1%0E5')RP@("`@
M-RD[("`@("`O*BH@1&5B=6<M;&5V96P@;65S<V%G97,@*B\*"F1E9FEN92@G
M4$5!4E],3T=?04Q,)RP@("`@("!B:6YD96,H)S$Q,3$Q,3$Q)RDI.R`@+RHJ
M($%L;"!M97-S86=E<R`J+PID969I;F4H)U!%05)?3$]'7TY/3D4G+"`@("`@
M8FEN9&5C*"<P,#`P,#`P,"<I*3L@("\J*B!.;R!M97-S86=E("HO"@HO*B!,
M;V<@='EP97,@9F]R(%!(4"=S(&YA=&EV92!E<G)O<E]L;V<H*2!F=6YC=&EO
M;BX@*B\*9&5F:6YE*"=014%27TQ/1U]465!%7U-94U1%32<L("`P*3L@+RHJ
M(%5S92!02%`G<R!S>7-T96T@;&]G9V5R("HO"F1E9FEN92@G4$5!4E],3T=?
M5%E015]-04E,)RP@("`@,2D[("\J*B!5<V4@4$A0)W,@;6%I;"@I(&9U;F-T
M:6]N("HO"F1E9FEN92@G4$5!4E],3T=?5%E015]$14)51R<L("`@,BD[("\J
M*B!5<V4@4$A0)W,@9&5B=6=G:6YG(&-O;FYE8W1I;VX@*B\*9&5F:6YE*"=0
M14%27TQ/1U]465!%7T9)3$4G+"`@("`S*3L@+RHJ($%P<&5N9"!T;R!A(&9I
M;&4@*B\*"B\J*@H@*B!4:&4@3&]G.CH@8VQA<W,@:6UP;&5M96YT<R!B;W1H
M(&%N(&%B<W1R86-T:6]N(&9O<B!V87)I;W5S(&QO9V=I;F<*("H@;65C:&%N
M:7-M<R!A;F0@=&AE(%-U8FIE8W0@96YD(&]F(&$@4W5B:F5C="U/8G-E<G9E
M<B!P871T97)N+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H
M<"YN970^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!,;V<*
M("HO"F-L87-S($QO9PI["B`@("`O*BH*("`@("`J($EN9&EC871E<R!W:&5T
M:&5R(&]R(&YO="!T:&4@;&]G(&-A;B!B965N(&]P96YE9"`O(&-O;FYE8W1E
M9"X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]O<&5N960@/2!F86QS93L*"B`@
M("`O*BH*("`@("`J($EN<W1A;F-E+7-P96-I9FEC('5N:7%U92!I9&5N=&EF
M:6-A=&EO;B!N=6UB97(N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?:60@/2`P
M.PH*("`@("\J*@H@("`@("H@5&AE(&QA8F5L('1H870@=6YI<75E;'D@:61E
M;G1I9FEE<R!T:&ES('-E="!O9B!L;V<@;65S<V%G97,N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]I9&5N="`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&1E
M9F%U;'0@<')I;W)I='D@=&\@=7-E('=H96X@;&]G9VEN9R!A;B!E=F5N="X*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]P<FEO<FET>2`](%!%05)?3$]'7TE.
M1D\["@H@("`@+RHJ"B`@("`@*B!4:&4@8FET;6%S:R!O9B!A;&QO=V5D(&QO
M9R!L979E;',N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;6%S:R`](%!%05)?
M3$]'7T%,3#L*"B`@("`O*BH*("`@("`J($AO;&1S(&%L;"!,;V=?;V)S97)V
M97(@;V)J96-T<R!T:&%T('=I<V@@=&\@8F4@;F]T:69I960@;V8@;F5W(&UE
M<W-A9V5S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L:7-T96YE<G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@36%P<R!C86YO;FEC86P@9F]R;6%T(&ME
M>7,@=&\@<&]S:71I;VX@87)G=6UE;G1S(&9O<B!U<V4@:6X@8G5I;&1I;F<*
M("`@("`J(")L:6YE(&9O<FUA="(@<W1R:6YG<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?9F]R;6%T36%P(#T@87)R87DH)R5[=&EM97-T86UP?2<@(#T^("<E
M,21S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E>VED96YT?2<@
M("`@("`]/B`G)3(D<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M)7MP<FEO<FET>7TG("`@/3X@)R4S)',G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R5[;65S<V%G97TG("`@(#T^("<E-"1S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<E>V9I;&5])R`@("`@("`]/B`G)34D<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)7ML:6YE?2<@("`@("`@
M/3X@)R4V)',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R5[9G5N
M8W1I;VY])R`@(#T^("<E-R1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<E7'LG("`@("`@("`@("`]/B`G)25[)RD["@H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@3&]G(&EN<W1A;F-E
M(&]F('1Y<&4@)&AA;F1L97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:&%N9&QE<B`@(%1H92!T>7!E(&]F(&-O;F-R971E($QO9R!S=6)C;&%S
M<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M071T96UP="!T;R!D>6YA;6EC86QL>2!I;F-L=61E('1H92!C;V1E(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@<W5B8VQA<W,N
M($-U<G)E;G1L>2P@=F%L:60@=F%L=65S(&%R90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("=C;VYS;VQE)RP@)W-Y<VQO9R<L("=S<6PG+"`G
M9FEL92<L(&%N9"`G;6-A;"<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("`@(%1H92!N86UE(&]F('1H92!A8W1U86QL>2!L;V<@9FEL
M92P@=&%B;&4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M;W1H97(@<W!E8VEF:6,@<W1O<F4@=&\@=7-E+B!$969A=6QT<R!T;R!A;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&5M<'1Y('-T<FEN9RP@
M=VET:"!W:&EC:"!T:&4@<W5B8VQA<W,@=VEL;`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%T=&5M<'0@=&\@9&\@<V]M971H:6YG(&EN=&5L
M;&EG96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT("`@
M("!4:&4@:61E;G1I='D@<F5P;W)T960@=&\@=&AE(&QO9R!S>7-T96TN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8V]N9B`@("`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;B!T:&%T(&$@
M<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("1L979E;"`@("`@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I
M;F<@=&AI<R!L979E;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!,
M;V<@("`@("`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@3&]G(&EN<W1A
M;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&P@
M;VX@86X@97)R;W(N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I
M;F-E($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&AA
M;F1L97(L("1N86UE(#T@)R<L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$
M14)51RD*("`@('L*("`@("`@("`D:&%N9&QE<B`]('-T<G1O;&]W97(H)&AA
M;F1L97(I.PH@("`@("`@("1C;&%S<R`]("=,;V=?)R`N("1H86YD;&5R.PH@
M("`@("`@("1C;&%S<V9I;&4@/2`G3&]G+R<@+B`D:&%N9&QE<B`N("<N<&AP
M)SL*"B`@("`@("`@+RH*("`@("`@("`@*B!!='1E;7!T('1O(&EN8VQU9&4@
M;W5R('9E<G-I;VX@;V8@=&AE(&YA;65D(&-L87-S+"!B=70@9&]N)W0@=')E
M870*("`@("`@("`@*B!A(&9A:6QU<F4@87,@9F%T86PN("!4:&4@8V%L;&5R
M(&UA>2!H879E(&%L<F5A9'D@:6YC;'5D960@=&AE:7(@;W=N"B`@("`@("`@
M("H@=F5R<VEO;B!O9B!T:&4@;F%M960@8VQA<W,N"B`@("`@("`@("HO"B`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("!I;F-L=61E7V]N8V4@)&-L87-S9FEL93L*("`@("`@("!]"@H@("`@("`@
M("\J($EF('1H92!C;&%S<R!E>&ES=',L(')E='5R;B!A(&YE=R!I;G-T86YC
M92!O9B!I="X@*B\*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI
M('L*("`@("`@("`@("`@)&]B:B`]("9N97<@)&-L87-S*"1N86UE+"`D:61E
M;G0L("1C;VYF+"`D;&5V96PI.PH@("`@("`@("`@("!R971U<FX@)&]B:CL*
M("`@("`@("!]"@H@("`@("`@("1N=6QL(#T@;G5L;#L*("`@("`@("!R971U
M<FX@)&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!,;V<@:6YS=&%N8V4@
M;V8@='EP90H@("`@("H@)&AA;F1L97(L(&]N;'D@8W)E871I;F<@82!N97<@
M:6YS=&%N8V4@:68@;F\@;&]G(&EN<W1A;F-E('=I=&@@=&AE('-A;64*("`@
M("`J('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@
M*B!9;W4@<VAO=6QD('5S92!T:&ES(&EF('1H97)E(&%R92!M=6QT:7!L92!P
M;&%C97,@>6]U(&UI9VAT(&-R96%T92!A"B`@("`@*B!L;V=G97(L('EO=2!D
M;VXG="!W86YT('1O(&-R96%T92!M=6QT:7!L92!L;V=G97)S+"!A;F0@>6]U
M(&1O;B=T('=A;G0@=&\*("`@("`J(&-H96-K(&9O<B!T:&4@97AI<W1A;F-E
M(&]F(&]N92!E86-H('1I;64N(%1H92!S:6YG;&5T;VX@<&%T=&5R;B!D;V5S
M(&%L;`H@("`@("H@=&AE(&-H96-K:6YG('=O<FL@9F]R('EO=2X*("`@("`J
M"B`@("`@*B`\8CY9;W4@35535"!C86QL('1H:7,@;65T:&]D('=I=&@@=&AE
M("1V87(@/2`F3&]G.CIS:6YG;&5T;VXH*2!S>6YT87@N"B`@("`@*B!7:71H
M;W5T('1H92!A;7!E<G-A;F0@*"8I(&EN(&9R;VYT(&]F('1H92!M971H;V0@
M;F%M92P@>6]U('=I;&P@;F]T(&=E=`H@("`@("H@82!R969E<F5N8V4L('EO
M=2!W:6QL(&=E="!A(&-O<'DN/"]B/@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&AA;F1L97(@("!4:&4@='EP92!O9B!C;VYC<F5T92!,;V<@<W5B
M8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@($%T=&5M<'0@=&\@9'EN86UI8V%L;'D@:6YC;'5D92!T:&4@8V]D92!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&ES('-U8F-L
M87-S+B!#=7)R96YT;'DL('9A;&ED('9A;'5E<R!A<F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8V]N<V]L92<L("=S>7-L;V<G+"`G<W%L
M)RP@)V9I;&4G+"!A;F0@)VUC86PG+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("!4:&4@;F%M92!O9B!T:&4@86-T=6%L;'D@;&]G
M(&9I;&4L('1A8FQE+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]T:&5R('-P96-I9FEC('-T;W)E('1O('5S92X@($1E9F%U;'1S('1O
M(&%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@96UP='D@<W1R
M:6YG+"!W:71H('=H:6-H('1H92!S=6)C;&%S<R!W:6QL"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@871T96UP="!T;R!D;R!S;VUE=&AI;F<@
M:6YT96QL:6=E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E
M;G0@("`@(%1H92!I9&5N=&ET>2!R97!O<G1E9"!T;R!T:&4@;&]G('-Y<W1E
M;2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-O;F8@("`@("`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N('1H
M870@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G0@)&QE=F5L("`@("`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN
M8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T($QO9R`@("`@("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!,;V<@
M:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"!O;B!A;B!E<G)O<BX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<VEN8V4@3&]G(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1H86YD;&5R+"`D;F%M92`]("<G+"`D:61E;G0@/2`G)RP@)&-O;F8@
M/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!0
M14%27TQ/1U]$14)51RD*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E
M<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2`D:6YS=&%N8V5S
M(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA
M<G)A>2@D:&%N9&QE<BP@)&YA;64L("1I9&5N="P@)&-O;F8L("1L979E;"DI
M.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9,;V<Z
M.F9A8W1O<GDH)&AA;F1L97(L("1N86UE+"`D:61E;G0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF
M+"`D;&5V96PI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC
M97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8G-T<F%C
M="!I;7!L96UE;G1A=&EO;B!O9B!T:&4@;W!E;B@I(&UE=&AO9"X*("`@("`J
M($!S:6YC92!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@
M("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J($%B<W1R86-T(&EM<&QE;65N=&%T:6]N(&]F('1H92!C;&]S92@I(&UE
M=&AO9"X*("`@("`J($!S:6YC92!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!8G-T<F%C="!I;7!L96UE;G1A=&EO;B!O9B!T
M:&4@9FQU<V@H*2!M971H;V0N"B`@("`@*B!`<VEN8V4@3&]G(#$N."XR"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9L=7-H*"D*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8G-T<F%C="!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4@;&]G*"D@;65T:&]D+@H@("`@("H@0'-I;F-E
M($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D
M<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@
M9F]R(&QO9V=I;F<@82!E;65R9V5N8WD@979E;G0N("!)="!W:6QL(&QO9R!A
M"B`@("`@*B!M97-S86=E(&%T('1H92!014%27TQ/1U]%34521R!L;V<@;&5V
M96PN"B`@("`@*@H@("`@("H@0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@
M("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@
M("H*("`@("`J($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G
M92!W87,@<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!E;65R9R@D;65S<V%G92D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?14U%4D<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@02!C;VYV96YI96YC92!F=6YC=&EO;B!F
M;W(@;&]G9VEN9R!A;B!A;&5R="!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@
M("`J(&UE<W-A9V4@870@=&AE(%!%05)?3$]'7T%,15)4(&QO9R!L979E;"X*
M("`@("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E("`@(%-T
M<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@("`@*@H@
M("`@("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S86=E('=A
M<R!S=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@
M('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%L97)T*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^;&]G*"1M97-S86=E+"!014%27TQ/1U]!3$525"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L
M;V=G:6YG(&$@8W)I=&EC86P@979E;G0N("!)="!W:6QL(&QO9R!A"B`@("`@
M*B!M97-S86=E(&%T('1H92!014%27TQ/1U]#4DE4(&QO9R!L979E;"X*("`@
M("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN
M9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@
M("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S
M=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-R:70H)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?3$]'7T-2250I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@02!C;VYV96YI96YC92!F=6YC=&EO;B!F;W(@;&]G9VEN
M9R!A(&5R<F]R(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@;65S<V%G
M92!A="!T:&4@4$5!4E],3T=?15)2(&QO9R!L979E;"X*("`@("`J"B`@("`@
M*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE
M8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@("H@0')E='5R
M;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S=6-C97-S9G5L
M;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R
M<B@D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D
M;65S<V%G92P@4$5!4E],3T=?15)2*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@82!W87)N:6YG
M(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@;65S<V%G92!A="!T:&4@
M4$5!4E],3T=?5T%23DE.1R!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O
M;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J($!R971U<FX@(&)O
M;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&QO
M9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S
M:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!W87)N:6YG
M*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G*"1M
M97-S86=E+"!014%27TQ/1U]705).24Y'*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@82!N;W1I
M8V4@979E;G0N("!)="!W:6QL(&QO9R!A"B`@("`@*B!M97-S86=E(&%T('1H
M92!014%27TQ/1U].3U1)0T4@;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P
M87)A;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C
M;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@("`@*B!`<F5T=7)N("!B
M;V]L96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!L
M;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@;F]T:6-E
M*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G*"1M
M97-S86=E+"!014%27TQ/1U].3U1)0T4I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@02!C;VYV96YI96YC92!F=6YC=&EO;B!F;W(@;&]G9VEN9R!A(&EN9F]R
M;6%T:6]N(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@;65S<V%G92!A
M="!T:&4@4$5!4E],3T=?24Y&3R!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T
M(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J($!R971U<FX@
M(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY
M(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!I;F9O
M*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G*"1M
M97-S86=E+"!014%27TQ/1U])3D9/*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@82!D96)U9R!E
M=F5N="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE<W-A9V4@870@=&AE(%!%
M05)?3$]'7T1%0E5'(&QO9R!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@
M("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I
M;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A
M;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@;&]G9V5D
M+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E
M("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8G5G*"1M97-S
M86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G*"1M97-S86=E
M+"!014%27TQ/1U]$14)51RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4@
M9&%T82X*("`@("`J"B`@("`@*B!)9B`D;65S<V%G92!I<R!A;B!O8FIE8W0L
M(%]E>'1R86-T365S<V%G92@I('=I;&P@871T96UP="!T;R!E>'1R86-T"B`@
M("`@*B!T:&4@;65S<V%G92!T97AT('5S:6YG(&$@:VYO=VX@;65T:&]D("AS
M=6-H(&%S(&$@4$5!4E]%<G)O<B!O8FIE8W0G<PH@("`@("H@9V5T365S<V%G
M92@I(&UE=&AO9"DN("!)9B!A(&MN;W=N(&UE=&AO9"P@8V%N;F]T(&)E(&9O
M=6YD+"!T:&4*("`@("`J('-E<FEA;&EZ960@<F5P<F5S96YT871I;VX@;V8@
M=&AE(&]B:F5C="!W:6QL(&)E(')E='5R;F5D+@H@("`@("H*("`@("`J($EF
M('1H92!M97-S86=E(&1A=&$@:7,@86QR96%D>2!A('-T<FEN9RP@:70@=VEL
M;"!B92!R971U<FYE9"!U;F-H86YG960N"B`@("`@*@H@("`@("H@0'!A<F%M
M("!M:7AE9"`D;65S<V%G92`@(%1H92!O<FEG:6YA;"!M97-S86=E(&1A=&$N
M("!4:&ES(&UA>2!B92!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1R:6YG(&]R(&%N>2!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@("`@("`@("`@(%1H92!S=')I;F<@<F5P<F5S96YT871I;VX@
M;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>'1R86-T365S<V%G92@D;65S<V%G
M92D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF('=E)W9E(&)E96X@
M9VEV96X@86X@;V)J96-T+"!A='1E;7!T('1O(&5X=')A8W0@=&AE(&UE<W-A
M9V4@=7-I;F<*("`@("`@("`@*B!A(&MN;W=N(&UE=&AO9"X@($EF('=E(&-A
M;B=T(&9I;F0@<W5C:"!A(&UE=&AO9"P@9&5F875L="!T;R!T:&4*("`@("`@
M("`@*B`B:'5M86XM<F5A9&%B;&4B('9E<G-I;VX@;V8@=&AE(&]B:F5C="X*
M("`@("`@("`@*@H@("`@("`@("`J(%=E(&%L<V\@=7-E('1H92!H=6UA;BUR
M96%D86)L92!F;W)M870@9F]R(&%R<F%Y<RX*("`@("`@("`@*B\*("`@("`@
M("!I9B`H:7-?;V)J96-T*"1M97-S86=E*2D@>PH@("`@("`@("`@("!I9B`H
M;65T:&]D7V5X:7-T<R@D;65S<V%G92P@)V=E=&UE<W-A9V4G*2D@>PH@("`@
M("`@("`@("`@("`@)&UE<W-A9V4@/2`D;65S<V%G92T^9V5T365S<V%G92@I
M.PH@("`@("`@("`@("!](&5L<V4@:68@*&UE=&AO9%]E>&ES=',H)&UE<W-A
M9V4L("=T;W-T<FEN9R<I*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]
M("1M97-S86=E+3YT;U-T<FEN9R@I.PH@("`@("`@("`@("!](&5L<V4@:68@
M*&UE=&AO9%]E>&ES=',H)&UE<W-A9V4L("=?7W1O<W1R:6YG)RDI('L*("`@
M("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H4$A07U9%4E-)3TXL
M("<U+C`N,"<L("=G92<I*2!["B`@("`@("`@("`@("`@("`@("`@)&UE<W-A
M9V4@/2`H<W1R:6YG*21M97-S86=E.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`]("1M97-S86=E+3Y?
M7W1O4W1R:6YG*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]('!R:6YT7W(H)&UE
M<W-A9V4L('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E(&EF
M("AI<U]A<G)A>2@D;65S<V%G92DI('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1M97-S86=E6R=M97-S86=E)UTI*2!["B`@("`@("`@("`@("`@("`D;65S
M<V%G92`]("1M97-S86=E6R=M97-S86=E)UT["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]('!R:6YT7W(H)&UE<W-A
M9V4L('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!/=&AE<G=I<V4L('=E(&%S<W5M92!T:&4@;65S<V%G92!I<R!A('-T<FEN
M9RX@*B\*("`@("`@("!R971U<FX@)&UE<W-A9V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!5<VEN9R!D96)U9U]B86-K=')A8V4H*2P@<F5T=7)N<R!T:&4@
M9FEL92P@;&EN92P@86YD(&5N8VQO<VEN9R!F=6YC=&EO;@H@("`@("H@;F%M
M92!O9B!T:&4@<V]U<F-E(&-O9&4@8V]N=&5X="!F<F]M('=H:6-H(&QO9R@I
M('=A<R!I;G9O:W9E9"X*("`@("`J"B`@("`@*B!`<&%R86T@("!I;G0@("`@
M("1D97!T:"`@5&AE(&EN:71I86P@;G5M8F5R(&]F(&9R86UE<R!W92!S:&]U
M;&0@<W1E<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VL@
M:6YT;R!T:&4@=')A8V4N"B`@("`@*@H@("`@("H@0')E='5R;B`@87)R87D@
M("!!<G)A>2!C;VYT86EN:6YG('1H<F5E('-T<FEN9W,Z('1H92!F:6QE;F%M
M92P@=&AE(&QI;F4L"B`@("`@*B`@("`@("`@("`@("`@("`@(&%N9"!T:&4@
M9G5N8W1I;VX@;F%M92!F<F]M('=H:6-H(&QO9R@I('=A<R!C86QL960N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'-I;F-E("`@
M3&]G(#$N.2XT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971"86-K=')A8V56
M87)S*"1D97!T:"D*("`@('L*("`@("`@("`O*B!3=&%R="!B>2!G96YE<F%T
M:6YG(&$@8F%C:W1R86-E(&9R;VT@=&AE(&-U<G)E;G0@8V%L;"`H:&5R92DN
M("HO"B`@("`@("`@)&)A8VMT<F%C92`](&1E8G5G7V)A8VMT<F%C92@I.PH*
M("`@("`@("`O*@H@("`@("`@("`J(%=E)W)E(&EN=&5R97-T960@:6X@=&AE
M(&9R86UE('=H:6-H(&EN=F]K960@=&AE(&QO9R@I(&9U;F-T:6]N+"!S;PH@
M("`@("`@("`J('=E(&YE960@=&\@=V%L:R!B86-K('-O;64@;G5M8F5R(&]F
M(&9R86UE<R!I;G1O('1H92!B86-K=')A8V4N("!4:&4*("`@("`@("`@*B`D
M9&5P=&@@<&%R86UE=&5R('1E;&QS('5S('=H97)E('1O('-T87)T(&QO;VMI
M;F<N("`@5V4@9V\@;VYE('-T97`*("`@("`@("`@*B!F=7)T:&5R(&)A8VL@
M=&\@9FEN9"!T:&4@;F%M92!O9B!T:&4@96YC87!S=6QA=&EN9R!F=6YC=&EO
M;B!F<F]M"B`@("`@("`@("H@=VAI8V@@;&]G*"D@=V%S(&-A;&QE9"X*("`@
M("`@("`@*B\*("`@("`@("`D9FEL92`]($`D8F%C:W1R86-E6R1D97!T:%U;
M)V9I;&4G73L*("`@("`@("`D;&EN92`]($`D8F%C:W1R86-E6R1D97!T:%U;
M)VQI;F4G73L*("`@("`@("`D9G5N8R`]($`D8F%C:W1R86-E6R1D97!T:"`K
M(#%=6R=F=6YC=&EO;B==.PH*("`@("`@("`O*@H@("`@("`@("`J($AO=V5V
M97(L(&EF(&QO9R@I('=A<R!C86QL960@9G)O;2!O;F4@;V8@;W5R(")S:&]R
M=&-U="(@9G5N8W1I;VYS+`H@("`@("`@("`J('=E)W)E(&=O:6YG('1O(&YE
M960@=&\@9V\@8F%C:R!A;B!A9&1I=&EO;F%L('-T97`N"B`@("`@("`@("HO
M"B`@("`@("`@:68@*&EN7V%R<F%Y*"1F=6YC+"!A<G)A>2@G96UE<F<G+"`G
M86QE<G0G+"`G8W)I="<L("=E<G(G+"`G=V%R;FEN9R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;F]T:6-E)RP@)VEN9F\G+"`G9&5B
M=6<G*2DI('L*("`@("`@("`@("`@)&9I;&4@/2!`)&)A8VMT<F%C95LD9&5P
M=&@@*R`Q75LG9FEL92==.PH@("`@("`@("`@("`D;&EN92`]($`D8F%C:W1R
M86-E6R1D97!T:"`K(#%=6R=L:6YE)UT["B`@("`@("`@("`@("1F=6YC(#T@
M0"1B86-K=')A8V5;)&1E<'1H("L@,EU;)V9U;F-T:6]N)UT["B`@("`@("`@
M?0H*("`@("`@("`O*@H@("`@("`@("`J($EF('=E(&-O=6QD;B=T(&5X=')A
M8W0@82!F=6YC=&EO;B!N86UE("AP97)H87!S(&)E8V%U<V4@=V4@=V5R90H@
M("`@("`@("`J(&5X96-U=&5D(&9R;VT@=&AE(")M86EN(B!C;VYT97AT*2P@
M<')O=FED92!A(&1E9F%U;'0@=F%L=64N"B`@("`@("`@("HO"B`@("`@("`@
M:68@*&ES7VYU;&PH)&9U;F,I*2!["B`@("`@("`@("`@("1F=6YC(#T@)RAN
M;VYE*2<["B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@82`S+71U<&QE
M(&-O;G1A:6YI;F<@*&9I;&4L(&QI;F4L(&9U;F-T:6]N*2X@*B\*("`@("`@
M("!R971U<FX@87)R87DH)&9I;&4L("1L:6YE+"`D9G5N8RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A(&9O<FUA='1E9"!L;V<@;&EN92!B
M87-E9"!O;B!A(&9O<FUA="!S=')I;F<@86YD(&$@<V5T(&]F"B`@("`@*B!V
M87)I86)L97,@<F5P<F5S96YT:6YG('1H92!C=7)R96YT(&QO9R!R96-O<F0@
M86YD('-T871E+@H@("`@("H*("`@("`J($!R971U<FX@('-T<FEN9R`@1F]R
M;6%T=&5D(&QO9R!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("H@0'-I;F-E("`@3&]G(#$N.2XT"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]F;W)M870H)&9O<FUA="P@)'1I;65S=&%M<"P@)'!R:6]R:71Y
M+"`D;65S<V%G92D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF('1H
M92!F;W)M870@<W1R:6YG(')E9F5R96YC97,@86YY(&]F('1H92!B86-K=')A
M8V4M9')I=F5N"B`@("`@("`@("H@=F%R:6%B;&5S("@E-2P@)38L("4W*2P@
M9V5N97)A=&4@=&AE(&)A8VMT<F%C92!A;F0@9F5T8V@@=&AE;2X*("`@("`@
M("`@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+R5;-38W72\G+"`D9F]R
M;6%T*2D@>PH@("`@("`@("`@("!L:7-T*"1F:6QE+"`D;&EN92P@)&9U;F,I
M(#T@)'1H:7,M/E]G971"86-K=')A8V5687)S*#(I.PH@("`@("`@('T*"B`@
M("`@("`@+RH*("`@("`@("`@*B!"=6EL9"!T:&4@9F]R;6%T=&5D('-T<FEN
M9RX@(%=E('5S92!T:&4@<W!R:6YT9B@I(&9U;F-T:6]N)W,*("`@("`@("`@
M*B`B87)G=6UE;G0@<W=A<'!I;F<B(&-A<&%B:6QI='D@=&\@9'EN86UI8V%L
M;'D@<V5L96-T(&%N9"!P;W-I=&EO;@H@("`@("`@("`J('1H92!V87)I86)L
M97,@=VAI8V@@=VEL;"!U;'1I;6%T96QY(&%P<&5A<B!I;B!T:&4@;&]G('-T
M<FEN9RX*("`@("`@("`@*B\*("`@("`@("!R971U<FX@<W!R:6YT9B@D9F]R
M;6%T+`H@("`@("`@("`@("`@("`@("`@("`@("1T:6UE<W1A;7`L"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I9&5N="P*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<')I;W)I='E4;U-T<FEN9R@D<')I;W)I='DI
M+`H@("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E+`H@("`@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1F:6QE*2`_("1F:6QE(#H@)R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@:7-S970H)&QI;F4I(#\@)&QI;F4@.B`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D9G5N8RD@/R`D9G5N8R`Z
M("<G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T<FEN
M9R!R97!R97-E;G1A=&EO;B!O9B!A(%!%05)?3$]'7RH@:6YT96=E<B!C;VYS
M=&%N="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1P<FEO<FET>2`@("`@
M02!014%27TQ/1U\J(&EN=&5G97(@8V]N<W1A;G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@("`@("`@("`@(%1H92!S=')I;F<@<F5P<F5S96YT
M871I;VX@;V8@)&QE=F5L+@H@("`@("H*("`@("`J($!S:6YC92`@($QO9R`Q
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<')I;W)I='E4;U-T<FEN9R@D<')I
M;W)I='DI"B`@("!["B`@("`@("`@)&QE=F5L<R`](&%R<F%Y*`H@("`@("`@
M("`@("!014%27TQ/1U]%34521R`@(#T^("=E;65R9V5N8WDG+`H@("`@("`@
M("`@("!014%27TQ/1U]!3$525"`@(#T^("=A;&5R="<L"B`@("`@("`@("`@
M(%!%05)?3$]'7T-2250@("`@/3X@)V-R:71I8V%L)RP*("`@("`@("`@("`@
M4$5!4E],3T=?15)2("`@("`]/B`G97)R;W(G+`H@("`@("`@("`@("!014%2
M7TQ/1U]705).24Y'(#T^("=W87)N:6YG)RP*("`@("`@("`@("`@4$5!4E],
M3T=?3D]424-%("`]/B`G;F]T:6-E)RP*("`@("`@("`@("`@4$5!4E],3T=?
M24Y&3R`@("`]/B`G:6YF;R<L"B`@("`@("`@("`@(%!%05)?3$]'7T1%0E5'
M("`@/3X@)V1E8G5G)PH@("`@("`@("D["@H@("`@("`@(')E='5R;B`D;&5V
M96QS6R1P<FEO<FET>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!T:&4@4$5!4E],3T=?*B!I;G1E9V5R(&-O;G-T86YT(&9O<B!T:&4@
M9VEV96X@<W1R:6YG"B`@("`@*B!R97!R97-E;G1A=&EO;B!O9B!A('!R:6]R
M:71Y(&YA;64N("!4:&ES(&9U;F-T:6]N('!E<F9O<FUS(&$*("`@("`J(&-A
M<V4M:6YS96YS:71I=F4@<V5A<F-H+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("!3=')I;F<@8V]N=&%I;FEN9R!A('!R:6]R:71Y
M(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("`@("`@("`@
M(%1H92!014%27TQ/1U\J(&EN=&5G97(@8V]N='-T86YT(&-O<G)E<W!O;F1I
M;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@=&AE('-P
M96-I9FEE9"!P<FEO<FET>2!N86UE+@H@("`@("H*("`@("`J($!S:6YC92`@
M($QO9R`Q+CDN,`H@("`@("HO"B`@("!F=6YC=&EO;B!S=')I;F=4;U!R:6]R
M:71Y*"1N86UE*0H@("`@>PH@("`@("`@("1L979E;',@/2!A<G)A>2@*("`@
M("`@("`@("`@)V5M97)G96YC>2<@/3X@4$5!4E],3T=?14U%4D<L"B`@("`@
M("`@("`@("=A;&5R="<@("`@(#T^(%!%05)?3$]'7T%,15)4+`H@("`@("`@
M("`@("`G8W)I=&EC86PG("`]/B!014%27TQ/1U]#4DE4+`H@("`@("`@("`@
M("`G97)R;W(G("`@("`]/B!014%27TQ/1U]%4E(L"B`@("`@("`@("`@("=W
M87)N:6YG)R`@(#T^(%!%05)?3$]'7U=!4DY)3D<L"B`@("`@("`@("`@("=N
M;W1I8V4G("`@(#T^(%!%05)?3$]'7TY/5$E#12P*("`@("`@("`@("`@)VEN
M9F\G("`@("`@/3X@4$5!4E],3T=?24Y&3RP*("`@("`@("`@("`@)V1E8G5G
M)R`@("`@/3X@4$5!4E],3T=?1$5"54<*("`@("`@("`I.PH*("`@("`@("!R
M971U<FX@)&QE=F5L<UMS=')T;VQO=V5R*"1N86UE*5T["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#86QC=6QA=&4@=&AE(&QO9R!M87-K(&9O<B!T:&4@9VEV
M96X@<')I;W)I='DN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;6%Y(&)E
M(&-A;&QE9"!S=&%T:6-A;&QY+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("`@)'!R:6]R:71Y("`@5&AE('!R:6]R:71Y('=H;W-E(&UA<VL@=VEL
M;"!B92!C86QC=6QA=&5D+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&-A;&-U;&%T960@;&]G(&UA<VLN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J
M+PH@("`@9G5N8W1I;VX@34%32R@D<')I;W)I='DI"B`@("!["B`@("`@("`@
M<F5T=7)N("@Q(#P\("1P<FEO<FET>2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#86QC=6QA=&4@=&AE(&QO9R!M87-K(&9O<B!A;&P@<')I;W)I=&EE<R!U
M<"!T;R!T:&4@9VEV96X@<')I;W)I='DN"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@;6%Y(&)E(&-A;&QE9"!S=&%T:6-A;&QY+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("`@)'!R:6]R:71Y("`@5&AE(&UA>&EM=6T@<')I
M;W)I='D@8V]V97)E9"!B>2!T:&ES(&UA<VLN"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@<F5S=6QT:6YG(&QO9R!M87-K+@H@("`@("H*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N
M-RXP"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@9&5P<F5C871E9"!S:6YC
M92!,;V<@,2XY+C0[('5S92!,;V<Z.DU!6"@I(&EN<W1E860*("`@("`J+PH@
M("`@9G5N8W1I;VX@55!43R@D<')I;W)I='DI"B`@("!["B`@("`@("`@<F5T
M=7)N($QO9SHZ34%8*"1P<FEO<FET>2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#86QC=6QA=&4@=&AE(&QO9R!M87-K(&9O<B!A;&P@<')I;W)I=&EE<R!G
M<F5A=&5R('1H86X@;W(@97%U86P@=&\@=&AE"B`@("`@*B!G:79E;B!P<FEO
M<FET>2X@($EN(&]T:&5R('=O<F1S+"`D<')I;W)I='D@=VEL;"!B92!T:&4@
M;&]W97-T('!R:6]R:71Y"B`@("`@*B!M871C:&5D(&)Y('1H92!R97-U;'1I
M;F<@;6%S:RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M87D@8F4@8V%L
M;&5D('-T871I8V%L;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M("`D<')I;W)I='D@("!4:&4@;6EN:6UU;2!P<FEO<FET>2!C;W9E<F5D(&)Y
M('1H:7,@;6%S:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!R97-U;'1I;F<@;&]G(&UA<VLN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XY+C0*("`@("`J+PH@("`@
M9G5N8W1I;VX@34E.*"1P<FEO<FET>2D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4E],3T=?04Q,(%X@*"@Q(#P\("1P<FEO<FET>2D@+2`Q*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!T:&4@;&]G(&UA<VL@9F]R(&%L
M;"!P<FEO<FET:65S(&QE<W,@=&AA;B!O<B!E<75A;"!T;R!T:&4*("`@("`J
M(&=I=F5N('!R:6]R:71Y+B`@26X@;W1H97(@=V]R9',L("1P<FEO<FET>2!W
M:6QL(&)E('1H92!H:6=H97-T<R!P<FEO<FET>0H@("`@("H@;6%T8VAE9"!B
M>2!T:&4@<F5S=6QT:6YG(&UA<VLN"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;6%Y(&)E(&-A;&QE9"!S=&%T:6-A;&QY+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("`@)'!R:6]R:71Y("`@5&AE(&UA>&EM=6T@<')I;W)I
M='D@8V]V97)E9"!B>2!T:&ES(&UA<VLN"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@<F5S=6QT:6YG(&QO9R!M87-K+@H@("`@("H*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N.2XT
M"B`@("`@*B\*("`@(&9U;F-T:6]N($U!6"@D<')I;W)I='DI"B`@("!["B`@
M("`@("`@<F5T=7)N("@H,2`\/"`H)'!R:6]R:71Y("L@,2DI("T@,2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3970@86YD(')E='5R;B!T:&4@;&5V96P@
M;6%S:R!F;W(@=&AE(&-U<G)E;G0@3&]G(&EN<W1A;F-E+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1M87-K("`@("!!(&)I='=I<V4@;6%S:R!O
M9B!L;V<@;&5V96QS+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M("`@("`@("!4:&4@8W5R<F5N="!L979E;"!M87-K+@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$UA<VLH)&UA<VLI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]M87-K(#T@)&UA<VL["@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUA<VL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C
M=7)R96YT(&QE=F5L(&UA<VLN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M<F=E<B`@("`@("`@(%1H92!C=7)R96YT(&QE=F5L(&UA<VLN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36%S:R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;6%S:SL*("`@('T*"B`@("`O*BH*("`@("`J
M($-H96-K(&EF('1H92!G:79E;B!P<FEO<FET>2!I<R!I;F-L=61E9"!I;B!T
M:&4@8W5R<F5N="!L979E;"!M87-K+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("`@)'!R:6]R:71Y("`@5&AE('!R:6]R:71Y('1O(&-H96-K+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@9VEV
M96X@<')I;W)I='D@:7,@:6YC;'5D960@:6X@=&AE(&-U<G)E;G0*("`@("`J
M("`@("`@("`@("`@("`@("`@;&]G(&UA<VLN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]I<TUA<VME9"@D<')I;W)I='DI"B`@("!["B`@
M("`@("`@<F5T=7)N("A,;V<Z.DU!4TLH)'!R:6]R:71Y*2`F("1T:&ES+3Y?
M;6%S:RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R
M96YT(&1E9F%U;'0@<')I;W)I='DN"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@8W5R<F5N="!D969A=6QT('!R:6]R:71Y+@H@("`@("H*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N
M."XT"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R:6]R:71Y*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]P<FEO<FET>3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE(&1E9F%U;'0@<')I;W)I='D@=&\@=&AE('-P
M96-I9FEE9"!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@("!I;G1E9V5R
M("1P<FEO<FET>2`@(%1H92!N97<@9&5F875L="!P<FEO<FET>2X*("`@("`J
M"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q
M+C@N-`H@("`@("HO"B`@("!F=6YC=&EO;B!S9710<FEO<FET>2@D<')I;W)I
M='DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P<FEO<FET>2`]("1P<FEO<FET
M>3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!,;V=?;V)S97)V97(@
M:6YS=&%N8V4@=&\@=&AE(&QI<W0@;V8@;V)S97)V97)S('1H870@87)E(&QI
M<W1E;FEN9PH@("`@("H@9F]R(&UE<W-A9V5S(&5M:71T960@8GD@=&AI<R!,
M;V<@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`@("`D
M;V)S97)V97(@("!4:&4@3&]G7V]B<V5R=F5R(&EN<W1A;F-E('1O(&%T=&%C
M:"!A<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI
M<W1E;F5R+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("`@5')U92!I
M9B!T:&4@;V)S97)V97(@:7,@<W5C8V5S<V9U;&QY(&%T=&%C:&5D+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G
M(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!A='1A8V@H)B1O8G-E<G9E<BD*
M("`@('L*("`@("`@("!I9B`H(6ES7V$H)&]B<V5R=F5R+"`G3&]G7V]B<V5R
M=F5R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&]B<V5R=F5R+3Y?:61=(#T@
M)B1O8G-E<G9E<CL*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296UO=F5S(&$@3&]G7V]B<V5R=F5R(&EN<W1A;F-E(&9R
M;VT@=&AE(&QI<W0@;V8@;V)S97)V97)S+@H@("`@("H*("`@("`J($!P87)A
M;2!O8FIE8W0@("`@)&]B<V5R=F5R("`@5&AE($QO9U]O8G-E<G9E<B!I;G-T
M86YC92!T;R!D971A8V@@9G)O;0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@;&ES="!O9B!L:7-T96YE<G,N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@("!4<G5E(&EF('1H92!O8G-E<G9E<B!I<R!S
M=6-C97-S9G5L;'D@9&5T86-H960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XP"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E=&%C:"@D;V)S97)V97(I"B`@("!["B`@("`@("`@:68@*"%I
M<U]A*"1O8G-E<G9E<BP@)TQO9U]O8G-E<G9E<B<I('Q\"B`@("`@("`@("`@
M("%I<W-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;V)S97)V97(M/E]I9%TI*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M('5N<V5T*"1T:&ES+3Y?;&ES=&5N97)S6R1O8G-E<G9E<BT^7VED72D["@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@26YF
M;W)M<R!E86-H(')E9VES=&5R960@;V)S97)V97(@:6YS=&%N8V4@=&AA="!A
M(&YE=R!M97-S86=E(&AA<R!B965N"B`@("`@*B!L;V=G960N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("`@("`D979E;G0@("`@("!!(&AA<V@@9&5S
M8W)I8FEN9R!T:&4@;&]G(&5V96YT+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?86YN;W5N8V4H)&5V96YT
M*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&ES=&5N97)S(&%S
M("1I9"`]/B`D;&ES=&5N97(I('L*("`@("`@("`@("`@:68@*"1E=F5N=%LG
M<')I;W)I='DG72`\/2`D=&AI<RT^7VQI<W1E;F5R<ULD:61=+3Y?<')I;W)I
M='DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&ES=&5N97)S6R1I9%TM
M/FYO=&EF>2@D979E;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@26YD:6-A=&5S('=H971H97(@=&AI<R!I<R!A
M(&-O;7!O<VET92!C;&%S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@("`@("`@("`@5')U92!I9B!T:&ES(&ES(&$@8V]M<&]S:71E(&-L87-S
M+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E
M("`@3&]G(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!I<T-O;7!O<VET92@I
M"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T<R!T:&ES($QO9R!I;G-T86YC92=S(&ED96YT:69I8V%T:6]N
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1I9&5N
M="`@("`@(%1H92!N97<@:61E;G1I9FEC871I;VX@<W1R:6YG+@H@("`@("H*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N
M-BXS"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ED96YT*"1I9&5N="D*("`@
M('L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!I9&5N=&EF:6-A=&EO
M;B!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@
M8W5R<F5N="!,;V<@:6YS=&%N8V4G<R!I9&5N=&EF:6-A=&EO;B!S=')I;F<N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@
M("!,;V<@,2XV+C,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T261E;G0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VED96YT.PH@("`@?0I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V1O8W,O````````````````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-3<`,#$U,S0U`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]#3U!924Y'````````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,3(W,P`Q,#4Q
M-30S,3`U-P`P,38T,#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````"0D@($=.52!,24)205)9($=%3D5204P@4%5"3$E#($Q)
M0T5.4T4*"0D@("`@("`@5F5R<VEO;B`R+"!*=6YE(#$Y.3$*"B!#;W!Y<FEG
M:'0@*$,I(#$Y.3$@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+"!);F,N"B`@
M("`)"2`@("`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+"!-
M02`@,#(Q,3$M,3,P-R`@55-!"B!%=F5R>6]N92!I<R!P97)M:71T960@=&\@
M8V]P>2!A;F0@9&ES=')I8G5T92!V97)B871I;2!C;W!I97,*(&]F('1H:7,@
M;&EC96YS92!D;V-U;65N="P@8G5T(&-H86YG:6YG(&ET(&ES(&YO="!A;&QO
M=V5D+@H*6U1H:7,@:7,@=&AE(&9I<G-T(')E;&5A<V5D('9E<G-I;VX@;V8@
M=&AE(&QI8G)A<GD@1U!,+B`@270@:7,*(&YU;6)E<F5D(#(@8F5C875S92!I
M="!G;V5S('=I=&@@=F5R<VEO;B`R(&]F('1H92!O<F1I;F%R>2!'4$PN70H*
M"0D)("`@(%!R96%M8FQE"@H@(%1H92!L:6-E;G-E<R!F;W(@;6]S="!S;V9T
M=V%R92!A<F4@9&5S:6=N960@=&\@=&%K92!A=V%Y('EO=7(*9G)E961O;2!T
M;R!S:&%R92!A;F0@8VAA;F=E(&ET+B`@0GD@8V]N=')A<W0L('1H92!'3E4@
M1V5N97)A;"!0=6)L:6,*3&EC96YS97,@87)E(&EN=&5N9&5D('1O(&=U87)A
M;G1E92!Y;W5R(&9R965D;VT@=&\@<VAA<F4@86YD(&-H86YG90IF<F5E('-O
M9G1W87)E+2UT;R!M86ME('-U<F4@=&AE('-O9G1W87)E(&ES(&9R964@9F]R
M(&%L;"!I=',@=7-E<G,N"@H@(%1H:7,@;&EC96YS92P@=&AE($QI8G)A<GD@
M1V5N97)A;"!0=6)L:6,@3&EC96YS92P@87!P;&EE<R!T;R!S;VUE"G-P96-I
M86QL>2!D97-I9VYA=&5D($9R964@4V]F='=A<F4@1F]U;F1A=&EO;B!S;V9T
M=V%R92P@86YD('1O(&%N>0IO=&AE<B!L:6)R87)I97,@=VAO<V4@875T:&]R
M<R!D96-I9&4@=&\@=7-E(&ET+B`@66]U(&-A;B!U<V4@:70@9F]R"GEO=7(@
M;&EB<F%R:65S+"!T;V\N"@H@(%=H96X@=V4@<W!E86L@;V8@9G)E92!S;V9T
M=V%R92P@=V4@87)E(')E9F5R<FEN9R!T;R!F<F5E9&]M+"!N;W0*<')I8V4N
M("!/=7(@1V5N97)A;"!0=6)L:6,@3&EC96YS97,@87)E(&1E<VEG;F5D('1O
M(&UA:V4@<W5R92!T:&%T('EO=0IH879E('1H92!F<F5E9&]M('1O(&1I<W1R
M:6)U=&4@8V]P:65S(&]F(&9R964@<V]F='=A<F4@*&%N9"!C:&%R9V4@9F]R
M"G1H:7,@<V5R=FEC92!I9B!Y;W4@=VES:"DL('1H870@>6]U(')E8V5I=F4@
M<V]U<F-E(&-O9&4@;W(@8V%N(&=E="!I=`II9B!Y;W4@=V%N="!I="P@=&AA
M="!Y;W4@8V%N(&-H86YG92!T:&4@<V]F='=A<F4@;W(@=7-E('!I96-E<R!O
M9B!I=`II;B!N97<@9G)E92!P<F]G<F%M<SL@86YD('1H870@>6]U(&MN;W<@
M>6]U(&-A;B!D;R!T:&5S92!T:&EN9W,N"@H@(%1O('!R;W1E8W0@>6]U<B!R
M:6=H=',L('=E(&YE960@=&\@;6%K92!R97-T<FEC=&EO;G,@=&AA="!F;W)B
M:60*86YY;VYE('1O(&1E;GD@>6]U('1H97-E(')I9VAT<R!O<B!T;R!A<VL@
M>6]U('1O('-U<G)E;F1E<B!T:&4@<FEG:'1S+@I4:&5S92!R97-T<FEC=&EO
M;G,@=')A;G-L871E('1O(&-E<G1A:6X@<F5S<&]N<VEB:6QI=&EE<R!F;W(@
M>6]U(&EF"GEO=2!D:7-T<FEB=71E(&-O<&EE<R!O9B!T:&4@;&EB<F%R>2P@
M;W(@:68@>6]U(&UO9&EF>2!I="X*"B`@1F]R(&5X86UP;&4L(&EF('EO=2!D
M:7-T<FEB=71E(&-O<&EE<R!O9B!T:&4@;&EB<F%R>2P@=VAE=&AE<B!G<F%T
M:7,*;W(@9F]R(&$@9F5E+"!Y;W4@;75S="!G:79E('1H92!R96-I<&EE;G1S
M(&%L;"!T:&4@<FEG:'1S('1H870@=V4@9V%V90IY;W4N("!9;W4@;75S="!M
M86ME('-U<F4@=&AA="!T:&5Y+"!T;V\L(')E8V5I=F4@;W(@8V%N(&=E="!T
M:&4@<V]U<F-E"F-O9&4N("!)9B!Y;W4@;&EN:R!A('!R;V=R86T@=VET:"!T
M:&4@;&EB<F%R>2P@>6]U(&UU<W0@<')O=FED90IC;VUP;&5T92!O8FIE8W0@
M9FEL97,@=&\@=&AE(')E8VEP:65N=',@<V\@=&AA="!T:&5Y(&-A;B!R96QI
M;FL@=&AE;0IW:71H('1H92!L:6)R87)Y+"!A9G1E<B!M86MI;F<@8VAA;F=E
M<R!T;R!T:&4@;&EB<F%R>2!A;F0@<F5C;VUP:6QI;F<*:70N("!!;F0@>6]U
M(&UU<W0@<VAO=R!T:&5M('1H97-E('1E<FUS('-O('1H97D@:VYO=R!T:&5I
M<B!R:6=H=',N"@H@($]U<B!M971H;V0@;V8@<')O=&5C=&EN9R!Y;W5R(')I
M9VAT<R!H87,@='=O('-T97!S.B`H,2D@8V]P>7)I9VAT"G1H92!L:6)R87)Y
M+"!A;F0@*#(I(&]F9F5R('EO=2!T:&ES(&QI8V5N<V4@=VAI8V@@9VEV97,@
M>6]U(&QE9V%L"G!E<FUI<W-I;VX@=&\@8V]P>2P@9&ES=')I8G5T92!A;F0O
M;W(@;6]D:69Y('1H92!L:6)R87)Y+@H*("!!;'-O+"!F;W(@96%C:"!D:7-T
M<FEB=71O<B=S('!R;W1E8W1I;VXL('=E('=A;G0@=&\@;6%K92!C97)T86EN
M"G1H870@979E<GEO;F4@=6YD97)S=&%N9',@=&AA="!T:&5R92!I<R!N;R!W
M87)R86YT>2!F;W(@=&AI<R!F<F5E"FQI8G)A<GDN("!)9B!T:&4@;&EB<F%R
M>2!I<R!M;V1I9FEE9"!B>2!S;VUE;VYE(&5L<V4@86YD('!A<W-E9"!O;BP@
M=V4*=V%N="!I=',@<F5C:7!I96YT<R!T;R!K;F]W('1H870@=VAA="!T:&5Y
M(&AA=F4@:7,@;F]T('1H92!O<FEG:6YA;`IV97)S:6]N+"!S;R!T:&%T(&%N
M>2!P<F]B;&5M<R!I;G1R;V1U8V5D(&)Y(&]T:&5R<R!W:6QL(&YO="!R969L
M96-T(&]N"G1H92!O<FEG:6YA;"!A=71H;W)S)R!R97!U=&%T:6]N<RX*#`H@
M($9I;F%L;'DL(&%N>2!F<F5E('!R;V=R86T@:7,@=&AR96%T96YE9"!C;VYS
M=&%N=&QY(&)Y('-O9G1W87)E"G!A=&5N=',N("!792!W:7-H('1O(&%V;VED
M('1H92!D86YG97(@=&AA="!C;VUP86YI97,@9&ES=')I8G5T:6YG(&9R964*
M<V]F='=A<F4@=VEL;"!I;F1I=FED=6%L;'D@;V)T86EN('!A=&5N="!L:6-E
M;G-E<RP@=&AU<R!I;B!E9F9E8W0*=')A;G-F;W)M:6YG('1H92!P<F]G<F%M
M(&EN=&\@<')O<')I971A<GD@<V]F='=A<F4N("!4;R!P<F5V96YT('1H:7,L
M"G=E(&AA=F4@;6%D92!I="!C;&5A<B!T:&%T(&%N>2!P871E;G0@;75S="!B
M92!L:6-E;G-E9"!F;W(@979E<GEO;F4G<PIF<F5E('5S92!O<B!N;W0@;&EC
M96YS960@870@86QL+@H*("!-;W-T($=.52!S;V9T=V%R92P@:6YC;'5D:6YG
M('-O;64@;&EB<F%R:65S+"!I<R!C;W9E<F5D(&)Y('1H92!O<F1I;F%R>0I'
M3E4@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@=VAI8V@@=V%S(&1E<VEG;F5D
M(&9O<B!U=&EL:71Y('!R;V=R86US+B`@5&AI<PIL:6-E;G-E+"!T:&4@1TY5
M($QI8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@87!P;&EE<R!T;R!C
M97)T86EN"F1E<VEG;F%T960@;&EB<F%R:65S+B`@5&AI<R!L:6-E;G-E(&ES
M('%U:71E(&1I9F9E<F5N="!F<F]M('1H92!O<F1I;F%R>0IO;F4[(&)E('-U
M<F4@=&\@<F5A9"!I="!I;B!F=6QL+"!A;F0@9&]N)W0@87-S=6UE('1H870@
M86YY=&AI;F<@:6X@:70@:7,*=&AE('-A;64@87,@:6X@=&AE(&]R9&EN87)Y
M(&QI8V5N<V4N"@H@(%1H92!R96%S;VX@=V4@:&%V92!A('-E<&%R871E('!U
M8FQI8R!L:6-E;G-E(&9O<B!S;VUE(&QI8G)A<FEE<R!I<R!T:&%T"G1H97D@
M8FQU<B!T:&4@9&ES=&EN8W1I;VX@=V4@=7-U86QL>2!M86ME(&)E='=E96X@
M;6]D:69Y:6YG(&]R(&%D9&EN9R!T;R!A"G!R;V=R86T@86YD('-I;7!L>2!U
M<VEN9R!I="X@($QI;FMI;F<@82!P<F]G<F%M('=I=&@@82!L:6)R87)Y+"!W
M:71H;W5T"F-H86YG:6YG('1H92!L:6)R87)Y+"!I<R!I;B!S;VUE('-E;G-E
M('-I;7!L>2!U<VEN9R!T:&4@;&EB<F%R>2P@86YD(&ES"F%N86QO9V]U<R!T
M;R!R=6YN:6YG(&$@=71I;&ET>2!P<F]G<F%M(&]R(&%P<&QI8V%T:6]N('!R
M;V=R86TN("!(;W=E=F5R+"!I;@IA('1E>'1U86P@86YD(&QE9V%L('-E;G-E
M+"!T:&4@;&EN:V5D(&5X96-U=&%B;&4@:7,@82!C;VUB:6YE9"!W;W)K+"!A
M"F1E<FEV871I=F4@;V8@=&AE(&]R:6=I;F%L(&QI8G)A<GDL(&%N9"!T:&4@
M;W)D:6YA<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS90IT<F5A=',@:70@87,@
M<W5C:"X*"B`@0F5C875S92!O9B!T:&ES(&)L=7)R960@9&ES=&EN8W1I;VXL
M('5S:6YG('1H92!O<F1I;F%R>2!'96YE<F%L"E!U8FQI8R!,:6-E;G-E(&9O
M<B!L:6)R87)I97,@9&ED(&YO="!E9F9E8W1I=F5L>2!P<F]M;W1E('-O9G1W
M87)E"G-H87)I;F<L(&)E8V%U<V4@;6]S="!D979E;&]P97)S(&1I9"!N;W0@
M=7-E('1H92!L:6)R87)I97,N("!790IC;VYC;'5D960@=&AA="!W96%K97(@
M8V]N9&ET:6]N<R!M:6=H="!P<F]M;W1E('-H87)I;F<@8F5T=&5R+@H*("!(
M;W=E=F5R+"!U;G)E<W1R:6-T960@;&EN:VEN9R!O9B!N;VXM9G)E92!P<F]G
M<F%M<R!W;W5L9"!D97!R:79E('1H90IU<V5R<R!O9B!T:&]S92!P<F]G<F%M
M<R!O9B!A;&P@8F5N969I="!F<F]M('1H92!F<F5E('-T871U<R!O9B!T:&4*
M;&EB<F%R:65S('1H96US96QV97,N("!4:&ES($QI8G)A<GD@1V5N97)A;"!0
M=6)L:6,@3&EC96YS92!I<R!I;G1E;F1E9"!T;PIP97)M:70@9&5V96QO<&5R
M<R!O9B!N;VXM9G)E92!P<F]G<F%M<R!T;R!U<V4@9G)E92!L:6)R87)I97,L
M('=H:6QE"G!R97-E<G9I;F<@>6]U<B!F<F5E9&]M(&%S(&$@=7-E<B!O9B!S
M=6-H('!R;V=R86US('1O(&-H86YG92!T:&4@9G)E90IL:6)R87)I97,@=&AA
M="!A<F4@:6YC;W)P;W)A=&5D(&EN('1H96TN("`H5V4@:&%V92!N;W0@<V5E
M;B!H;W<@=&\@86-H:65V90IT:&ES(&%S(')E9V%R9',@8VAA;F=E<R!I;B!H
M96%D97(@9FEL97,L(&)U="!W92!H879E(&%C:&EE=F5D(&ET(&%S(')E9V%R
M9',*8VAA;F=E<R!I;B!T:&4@86-T=6%L(&9U;F-T:6]N<R!O9B!T:&4@3&EB
M<F%R>2XI("!4:&4@:&]P92!I<R!T:&%T('1H:7,*=VEL;"!L96%D('1O(&9A
M<W1E<B!D979E;&]P;65N="!O9B!F<F5E(&QI8G)A<FEE<RX*"B`@5&AE('!R
M96-I<V4@=&5R;7,@86YD(&-O;F1I=&EO;G,@9F]R(&-O<'EI;F<L(&1I<W1R
M:6)U=&EO;B!A;F0*;6]D:69I8V%T:6]N(&9O;&QO=RX@(%!A>2!C;&]S92!A
M='1E;G1I;VX@=&\@=&AE(&1I9F9E<F5N8V4@8F5T=V5E;B!A"B)W;W)K(&)A
M<V5D(&]N('1H92!L:6)R87)Y(B!A;F0@82`B=V]R:R!T:&%T('5S97,@=&AE
M(&QI8G)A<GDB+B`@5&AE"F9O<FUE<B!C;VYT86EN<R!C;V1E(&1E<FEV960@
M9G)O;2!T:&4@;&EB<F%R>2P@=VAI;&4@=&AE(&QA='1E<B!O;FQY"G=O<FMS
M('1O9V5T:&5R('=I=&@@=&AE(&QI8G)A<GDN"@H@($YO=&4@=&AA="!I="!I
M<R!P;W-S:6)L92!F;W(@82!L:6)R87)Y('1O(&)E(&-O=F5R960@8GD@=&AE
M(&]R9&EN87)Y"D=E;F5R86P@4'5B;&EC($QI8V5N<V4@<F%T:&5R('1H86X@
M8GD@=&AI<R!S<&5C:6%L(&]N92X*#`H)"2`@1TY5($Q)0E)!4ED@1T5.15)!
M3"!054),24,@3$E#14Y310H@("!415)-4R!!3D0@0T].1$E424].4R!&3U(@
M0T]064E.1RP@1$E35%))0E5424].($%.1"!-3T1)1DE#051)3TX*"B`@,"X@
M5&AI<R!,:6-E;G-E($%G<F5E;65N="!A<'!L:65S('1O(&%N>2!S;V9T=V%R
M92!L:6)R87)Y('=H:6-H"F-O;G1A:6YS(&$@;F]T:6-E('!L86-E9"!B>2!T
M:&4@8V]P>7)I9VAT(&AO;&1E<B!O<B!O=&AE<B!A=71H;W)I>F5D"G!A<G1Y
M('-A>6EN9R!I="!M87D@8F4@9&ES=')I8G5T960@=6YD97(@=&AE('1E<FUS
M(&]F('1H:7,@3&EB<F%R>0I'96YE<F%L(%!U8FQI8R!,:6-E;G-E("AA;'-O
M(&-A;&QE9"`B=&AI<R!,:6-E;G-E(BDN("!%86-H(&QI8V5N<V5E(&ES"F%D
M9')E<W-E9"!A<R`B>6]U(BX*"B`@02`B;&EB<F%R>2(@;65A;G,@82!C;VQL
M96-T:6]N(&]F('-O9G1W87)E(&9U;F-T:6]N<R!A;F0O;W(@9&%T80IP<F5P
M87)E9"!S;R!A<R!T;R!B92!C;VYV96YI96YT;'D@;&EN:V5D('=I=&@@87!P
M;&EC871I;VX@<')O9W)A;7,**'=H:6-H('5S92!S;VUE(&]F('1H;W-E(&9U
M;F-T:6]N<R!A;F0@9&%T82D@=&\@9F]R;2!E>&5C=71A8FQE<RX*"B`@5&AE
M("),:6)R87)Y(BP@8F5L;W<L(')E9F5R<R!T;R!A;GD@<W5C:"!S;V9T=V%R
M92!L:6)R87)Y(&]R('=O<FL*=VAI8V@@:&%S(&)E96X@9&ES=')I8G5T960@
M=6YD97(@=&AE<V4@=&5R;7,N("!!(")W;W)K(&)A<V5D(&]N('1H90I,:6)R
M87)Y(B!M96%N<R!E:71H97(@=&AE($QI8G)A<GD@;W(@86YY(&1E<FEV871I
M=F4@=V]R:R!U;F1E<@IC;W!Y<FEG:'0@;&%W.B!T:&%T(&ES('1O('-A>2P@
M82!W;W)K(&-O;G1A:6YI;F<@=&AE($QI8G)A<GD@;W(@80IP;W)T:6]N(&]F
M(&ET+"!E:71H97(@=F5R8F%T:6T@;W(@=VET:"!M;V1I9FEC871I;VYS(&%N
M9"]O<B!T<F%N<VQA=&5D"G-T<F%I9VAT9F]R=V%R9&QY(&EN=&\@86YO=&AE
M<B!L86YG=6%G92X@("A(97)E:6YA9G1E<BP@=')A;G-L871I;VX@:7,*:6YC
M;'5D960@=VET:&]U="!L:6UI=&%T:6]N(&EN('1H92!T97)M(")M;V1I9FEC
M871I;VXB+BD*"B`@(E-O=7)C92!C;V1E(B!F;W(@82!W;W)K(&UE86YS('1H
M92!P<F5F97)R960@9F]R;2!O9B!T:&4@=V]R:R!F;W(*;6%K:6YG(&UO9&EF
M:6-A=&EO;G,@=&\@:70N("!&;W(@82!L:6)R87)Y+"!C;VUP;&5T92!S;W5R
M8V4@8V]D92!M96%N<PIA;&P@=&AE('-O=7)C92!C;V1E(&9O<B!A;&P@;6]D
M=6QE<R!I="!C;VYT86EN<RP@<&QU<R!A;GD@87-S;V-I871E9`II;G1E<F9A
M8V4@9&5F:6YI=&EO;B!F:6QE<RP@<&QU<R!T:&4@<V-R:7!T<R!U<V5D('1O
M(&-O;G1R;VP@8V]M<&EL871I;VX*86YD(&EN<W1A;&QA=&EO;B!O9B!T:&4@
M;&EB<F%R>2X*"B`@06-T:79I=&EE<R!O=&AE<B!T:&%N(&-O<'EI;F<L(&1I
M<W1R:6)U=&EO;B!A;F0@;6]D:69I8V%T:6]N(&%R92!N;W0*8V]V97)E9"!B
M>2!T:&ES($QI8V5N<V4[('1H97D@87)E(&]U='-I9&4@:71S('-C;W!E+B`@
M5&AE(&%C="!O9@IR=6YN:6YG(&$@<')O9W)A;2!U<VEN9R!T:&4@3&EB<F%R
M>2!I<R!N;W0@<F5S=')I8W1E9"P@86YD(&]U='!U="!F<F]M"G-U8V@@82!P
M<F]G<F%M(&ES(&-O=F5R960@;VYL>2!I9B!I=',@8V]N=&5N=',@8V]N<W1I
M='5T92!A('=O<FL@8F%S960*;VX@=&AE($QI8G)A<GD@*&EN9&5P96YD96YT
M(&]F('1H92!U<V4@;V8@=&AE($QI8G)A<GD@:6X@82!T;V]L(&9O<@IW<FET
M:6YG(&ET*2X@(%=H971H97(@=&AA="!I<R!T<G5E(&1E<&5N9',@;VX@=VAA
M="!T:&4@3&EB<F%R>2!D;V5S"F%N9"!W:&%T('1H92!P<F]G<F%M('1H870@
M=7-E<R!T:&4@3&EB<F%R>2!D;V5S+@H@(`H@(#$N(%EO=2!M87D@8V]P>2!A
M;F0@9&ES=')I8G5T92!V97)B871I;2!C;W!I97,@;V8@=&AE($QI8G)A<GDG
M<PIC;VUP;&5T92!S;W5R8V4@8V]D92!A<R!Y;W4@<F5C96EV92!I="P@:6X@
M86YY(&UE9&EU;2P@<')O=FED960@=&AA=`IY;W4@8V]N<W!I8W5O=7-L>2!A
M;F0@87!P<F]P<FEA=&5L>2!P=6)L:7-H(&]N(&5A8V@@8V]P>2!A;@IA<'!R
M;W!R:6%T92!C;W!Y<FEG:'0@;F]T:6-E(&%N9"!D:7-C;&%I;65R(&]F('=A
M<G)A;G1Y.R!K965P(&EN=&%C=`IA;&P@=&AE(&YO=&EC97,@=&AA="!R969E
M<B!T;R!T:&ES($QI8V5N<V4@86YD('1O('1H92!A8G-E;F-E(&]F(&%N>0IW
M87)R86YT>3L@86YD(&1I<W1R:6)U=&4@82!C;W!Y(&]F('1H:7,@3&EC96YS
M92!A;&]N9R!W:71H('1H90I,:6)R87)Y+@H*("!9;W4@;6%Y(&-H87)G92!A
M(&9E92!F;W(@=&AE('!H>7-I8V%L(&%C="!O9B!T<F%N<V9E<G)I;F<@82!C
M;W!Y+`IA;F0@>6]U(&UA>2!A="!Y;W5R(&]P=&EO;B!O9F9E<B!W87)R86YT
M>2!P<F]T96-T:6]N(&EN(&5X8VAA;F=E(&9O<B!A"F9E92X*#`H@(#(N(%EO
M=2!M87D@;6]D:69Y('EO=7(@8V]P>2!O<B!C;W!I97,@;V8@=&AE($QI8G)A
M<GD@;W(@86YY('!O<G1I;VX*;V8@:70L('1H=7,@9F]R;6EN9R!A('=O<FL@
M8F%S960@;VX@=&AE($QI8G)A<GDL(&%N9"!C;W!Y(&%N9`ID:7-T<FEB=71E
M('-U8V@@;6]D:69I8V%T:6]N<R!O<B!W;W)K('5N9&5R('1H92!T97)M<R!O
M9B!396-T:6]N(#$*86)O=F4L('!R;W9I9&5D('1H870@>6]U(&%L<V\@;65E
M="!A;&P@;V8@=&AE<V4@8V]N9&ET:6]N<SH*"B`@("!A*2!4:&4@;6]D:69I
M960@=V]R:R!M=7-T(&ET<V5L9B!B92!A('-O9G1W87)E(&QI8G)A<GDN"@H@
M("`@8BD@66]U(&UU<W0@8V%U<V4@=&AE(&9I;&5S(&UO9&EF:65D('1O(&-A
M<G)Y('!R;VUI;F5N="!N;W1I8V5S"B`@("!S=&%T:6YG('1H870@>6]U(&-H
M86YG960@=&AE(&9I;&5S(&%N9"!T:&4@9&%T92!O9B!A;GD@8VAA;F=E+@H*
M("`@(&,I(%EO=2!M=7-T(&-A=7-E('1H92!W:&]L92!O9B!T:&4@=V]R:R!T
M;R!B92!L:6-E;G-E9"!A="!N;PH@("`@8VAA<F=E('1O(&%L;"!T:&ER9"!P
M87)T:65S('5N9&5R('1H92!T97)M<R!O9B!T:&ES($QI8V5N<V4N"@H@("`@
M9"D@268@82!F86-I;&ET>2!I;B!T:&4@;6]D:69I960@3&EB<F%R>2!R969E
M<G,@=&\@82!F=6YC=&EO;B!O<B!A"B`@("!T86)L92!O9B!D871A('1O(&)E
M('-U<'!L:65D(&)Y(&%N(&%P<&QI8V%T:6]N('!R;V=R86T@=&AA="!U<V5S
M"B`@("!T:&4@9F%C:6QI='DL(&]T:&5R('1H86X@87,@86X@87)G=6UE;G0@
M<&%S<V5D('=H96X@=&AE(&9A8VEL:71Y"B`@("!I<R!I;G9O:V5D+"!T:&5N
M('EO=2!M=7-T(&UA:V4@82!G;V]D(&9A:71H(&5F9F]R="!T;R!E;G-U<F4@
M=&AA="P*("`@(&EN('1H92!E=F5N="!A;B!A<'!L:6-A=&EO;B!D;V5S(&YO
M="!S=7!P;'D@<W5C:"!F=6YC=&EO;B!O<@H@("`@=&%B;&4L('1H92!F86-I
M;&ET>2!S=&EL;"!O<&5R871E<RP@86YD('!E<F9O<FUS('=H871E=F5R('!A
M<G0@;V8*("`@(&ET<R!P=7)P;W-E(')E;6%I;G,@;65A;FEN9V9U;"X*"B`@
M("`H1F]R(&5X86UP;&4L(&$@9G5N8W1I;VX@:6X@82!L:6)R87)Y('1O(&-O
M;7!U=&4@<W%U87)E(')O;W1S(&AA<PH@("`@82!P=7)P;W-E('1H870@:7,@
M96YT:7)E;'D@=V5L;"UD969I;F5D(&EN9&5P96YD96YT(&]F('1H90H@("`@
M87!P;&EC871I;VXN("!4:&5R969O<F4L(%-U8G-E8W1I;VX@,F0@<F5Q=6ER
M97,@=&AA="!A;GD*("`@(&%P<&QI8V%T:6]N+7-U<'!L:65D(&9U;F-T:6]N
M(&]R('1A8FQE('5S960@8GD@=&AI<R!F=6YC=&EO;B!M=7-T"B`@("!B92!O
M<'1I;VYA;#H@:68@=&AE(&%P<&QI8V%T:6]N(&1O97,@;F]T('-U<'!L>2!I
M="P@=&AE('-Q=6%R90H@("`@<F]O="!F=6YC=&EO;B!M=7-T('-T:6QL(&-O
M;7!U=&4@<W%U87)E(')O;W1S+BD*"E1H97-E(')E<75I<F5M96YT<R!A<'!L
M>2!T;R!T:&4@;6]D:69I960@=V]R:R!A<R!A('=H;VQE+B`@268*:61E;G1I
M9FEA8FQE('-E8W1I;VYS(&]F('1H870@=V]R:R!A<F4@;F]T(&1E<FEV960@
M9G)O;2!T:&4@3&EB<F%R>2P*86YD(&-A;B!B92!R96%S;VYA8FQY(&-O;G-I
M9&5R960@:6YD97!E;F1E;G0@86YD('-E<&%R871E('=O<FMS(&EN"G1H96US
M96QV97,L('1H96X@=&AI<R!,:6-E;G-E+"!A;F0@:71S('1E<FUS+"!D;R!N
M;W0@87!P;'D@=&\@=&AO<V4*<V5C=&EO;G,@=VAE;B!Y;W4@9&ES=')I8G5T
M92!T:&5M(&%S('-E<&%R871E('=O<FMS+B`@0G5T('=H96X@>6]U"F1I<W1R
M:6)U=&4@=&AE('-A;64@<V5C=&EO;G,@87,@<&%R="!O9B!A('=H;VQE('=H
M:6-H(&ES(&$@=V]R:R!B87-E9`IO;B!T:&4@3&EB<F%R>2P@=&AE(&1I<W1R
M:6)U=&EO;B!O9B!T:&4@=VAO;&4@;75S="!B92!O;B!T:&4@=&5R;7,@;V8*
M=&AI<R!,:6-E;G-E+"!W:&]S92!P97)M:7-S:6]N<R!F;W(@;W1H97(@;&EC
M96YS965S(&5X=&5N9"!T;R!T:&4*96YT:7)E('=H;VQE+"!A;F0@=&AU<R!T
M;R!E86-H(&%N9"!E=F5R>2!P87)T(')E9V%R9&QE<W,@;V8@=VAO('=R;W1E
M"FET+@H*5&AU<RP@:70@:7,@;F]T('1H92!I;G1E;G0@;V8@=&AI<R!S96-T
M:6]N('1O(&-L86EM(')I9VAT<R!O<B!C;VYT97-T"GEO=7(@<FEG:'1S('1O
M('=O<FL@=W)I='1E;B!E;G1I<F5L>2!B>2!Y;W4[(')A=&AE<BP@=&AE(&EN
M=&5N="!I<R!T;PIE>&5R8VES92!T:&4@<FEG:'0@=&\@8V]N=')O;"!T:&4@
M9&ES=')I8G5T:6]N(&]F(&1E<FEV871I=F4@;W(*8V]L;&5C=&EV92!W;W)K
M<R!B87-E9"!O;B!T:&4@3&EB<F%R>2X*"DEN(&%D9&ET:6]N+"!M97)E(&%G
M9W)E9V%T:6]N(&]F(&%N;W1H97(@=V]R:R!N;W0@8F%S960@;VX@=&AE($QI
M8G)A<GD*=VET:"!T:&4@3&EB<F%R>2`H;W(@=VET:"!A('=O<FL@8F%S960@
M;VX@=&AE($QI8G)A<GDI(&]N(&$@=F]L=6UE(&]F"F$@<W1O<F%G92!O<B!D
M:7-T<FEB=71I;VX@;65D:75M(&1O97,@;F]T(&)R:6YG('1H92!O=&AE<B!W
M;W)K('5N9&5R"G1H92!S8V]P92!O9B!T:&ES($QI8V5N<V4N"@H@(#,N(%EO
M=2!M87D@;W!T('1O(&%P<&QY('1H92!T97)M<R!O9B!T:&4@;W)D:6YA<GD@
M1TY5($=E;F5R86P@4'5B;&EC"DQI8V5N<V4@:6YS=&5A9"!O9B!T:&ES($QI
M8V5N<V4@=&\@82!G:79E;B!C;W!Y(&]F('1H92!,:6)R87)Y+B`@5&\@9&\*
M=&AI<RP@>6]U(&UU<W0@86QT97(@86QL('1H92!N;W1I8V5S('1H870@<F5F
M97(@=&\@=&AI<R!,:6-E;G-E+"!S;PIT:&%T('1H97D@<F5F97(@=&\@=&AE
M(&]R9&EN87)Y($=.52!'96YE<F%L(%!U8FQI8R!,:6-E;G-E+"!V97)S:6]N
M(#(L"FEN<W1E860@;V8@=&\@=&AI<R!,:6-E;G-E+B`@*$EF(&$@;F5W97(@
M=F5R<VEO;B!T:&%N('9E<G-I;VX@,B!O9B!T:&4*;W)D:6YA<GD@1TY5($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@:&%S(&%P<&5A<F5D+"!T:&5N('EO=2!C
M86X@<W!E8VEF>0IT:&%T('9E<G-I;VX@:6YS=&5A9"!I9B!Y;W4@=VES:"XI
M("!$;R!N;W0@;6%K92!A;GD@;W1H97(@8VAA;F=E(&EN"G1H97-E(&YO=&EC
M97,N"@P*("!/;F-E('1H:7,@8VAA;F=E(&ES(&UA9&4@:6X@82!G:79E;B!C
M;W!Y+"!I="!I<R!I<G)E=F5R<VEB;&4@9F]R"G1H870@8V]P>2P@<V\@=&AE
M(&]R9&EN87)Y($=.52!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&%P<&QI97,@
M=&\@86QL"G-U8G-E<75E;G0@8V]P:65S(&%N9"!D97)I=F%T:79E('=O<FMS
M(&UA9&4@9G)O;2!T:&%T(&-O<'DN"@H@(%1H:7,@;W!T:6]N(&ES('5S969U
M;"!W:&5N('EO=2!W:7-H('1O(&-O<'D@<&%R="!O9B!T:&4@8V]D92!O9@IT
M:&4@3&EB<F%R>2!I;G1O(&$@<')O9W)A;2!T:&%T(&ES(&YO="!A(&QI8G)A
M<GDN"@H@(#0N(%EO=2!M87D@8V]P>2!A;F0@9&ES=')I8G5T92!T:&4@3&EB
M<F%R>2`H;W(@82!P;W)T:6]N(&]R"F1E<FEV871I=F4@;V8@:70L('5N9&5R
M(%-E8W1I;VX@,BD@:6X@;V)J96-T(&-O9&4@;W(@97AE8W5T86)L92!F;W)M
M"G5N9&5R('1H92!T97)M<R!O9B!396-T:6]N<R`Q(&%N9"`R(&%B;W9E('!R
M;W9I9&5D('1H870@>6]U(&%C8V]M<&%N>0II="!W:71H('1H92!C;VUP;&5T
M92!C;W)R97-P;VYD:6YG(&UA8VAI;F4M<F5A9&%B;&4@<V]U<F-E(&-O9&4L
M('=H:6-H"FUU<W0@8F4@9&ES=')I8G5T960@=6YD97(@=&AE('1E<FUS(&]F
M(%-E8W1I;VYS(#$@86YD(#(@86)O=F4@;VX@80IM961I=6T@8W5S=&]M87)I
M;'D@=7-E9"!F;W(@<V]F='=A<F4@:6YT97)C:&%N9V4N"@H@($EF(&1I<W1R
M:6)U=&EO;B!O9B!O8FIE8W0@8V]D92!I<R!M861E(&)Y(&]F9F5R:6YG(&%C
M8V5S<R!T;R!C;W!Y"F9R;VT@82!D97-I9VYA=&5D('!L86-E+"!T:&5N(&]F
M9F5R:6YG(&5Q=6EV86QE;G0@86-C97-S('1O(&-O<'D@=&AE"G-O=7)C92!C
M;V1E(&9R;VT@=&AE('-A;64@<&QA8V4@<V%T:7-F:65S('1H92!R97%U:7)E
M;65N="!T;PID:7-T<FEB=71E('1H92!S;W5R8V4@8V]D92P@979E;B!T:&]U
M9V@@=&AI<F0@<&%R=&EE<R!A<F4@;F]T"F-O;7!E;&QE9"!T;R!C;W!Y('1H
M92!S;W5R8V4@86QO;F<@=VET:"!T:&4@;V)J96-T(&-O9&4N"@H@(#4N($$@
M<')O9W)A;2!T:&%T(&-O;G1A:6YS(&YO(&1E<FEV871I=F4@;V8@86YY('!O
M<G1I;VX@;V8@=&AE"DQI8G)A<GDL(&)U="!I<R!D97-I9VYE9"!T;R!W;W)K
M('=I=&@@=&AE($QI8G)A<GD@8GD@8F5I;F<@8V]M<&EL960@;W(*;&EN:V5D
M('=I=&@@:70L(&ES(&-A;&QE9"!A(")W;W)K('1H870@=7-E<R!T:&4@3&EB
M<F%R>2(N("!3=6-H(&$*=V]R:RP@:6X@:7-O;&%T:6]N+"!I<R!N;W0@82!D
M97)I=F%T:79E('=O<FL@;V8@=&AE($QI8G)A<GDL(&%N9`IT:&5R969O<F4@
M9F%L;',@;W5T<VED92!T:&4@<V-O<&4@;V8@=&AI<R!,:6-E;G-E+@H*("!(
M;W=E=F5R+"!L:6YK:6YG(&$@(G=O<FL@=&AA="!U<V5S('1H92!,:6)R87)Y
M(B!W:71H('1H92!,:6)R87)Y"F-R96%T97,@86X@97AE8W5T86)L92!T:&%T
M(&ES(&$@9&5R:79A=&EV92!O9B!T:&4@3&EB<F%R>2`H8F5C875S92!I=`IC
M;VYT86EN<R!P;W)T:6]N<R!O9B!T:&4@3&EB<F%R>2DL(')A=&AE<B!T:&%N
M(&$@(G=O<FL@=&AA="!U<V5S('1H90IL:6)R87)Y(BX@(%1H92!E>&5C=71A
M8FQE(&ES('1H97)E9F]R92!C;W9E<F5D(&)Y('1H:7,@3&EC96YS92X*4V5C
M=&EO;B`V('-T871E<R!T97)M<R!F;W(@9&ES=')I8G5T:6]N(&]F('-U8V@@
M97AE8W5T86)L97,N"@H@(%=H96X@82`B=V]R:R!T:&%T('5S97,@=&AE($QI
M8G)A<GDB('5S97,@;6%T97)I86P@9G)O;2!A(&AE861E<B!F:6QE"G1H870@
M:7,@<&%R="!O9B!T:&4@3&EB<F%R>2P@=&AE(&]B:F5C="!C;V1E(&9O<B!T
M:&4@=V]R:R!M87D@8F4@80ID97)I=F%T:79E('=O<FL@;V8@=&AE($QI8G)A
M<GD@979E;B!T:&]U9V@@=&AE('-O=7)C92!C;V1E(&ES(&YO="X*5VAE=&AE
M<B!T:&ES(&ES('1R=64@:7,@97-P96-I86QL>2!S:6=N:69I8V%N="!I9B!T
M:&4@=V]R:R!C86X@8F4*;&EN:V5D('=I=&AO=70@=&AE($QI8G)A<GDL(&]R
M(&EF('1H92!W;W)K(&ES(&ET<V5L9B!A(&QI8G)A<GDN("!4:&4*=&AR97-H
M;VQD(&9O<B!T:&ES('1O(&)E('1R=64@:7,@;F]T('!R96-I<V5L>2!D969I
M;F5D(&)Y(&QA=RX*"B`@268@<W5C:"!A;B!O8FIE8W0@9FEL92!U<V5S(&]N
M;'D@;G5M97)I8V%L('!A<F%M971E<G,L(&1A=&$*<W1R=6-T=7)E(&QA>6]U
M=',@86YD(&%C8V5S<V]R<RP@86YD('-M86QL(&UA8W)O<R!A;F0@<VUA;&P@
M:6YL:6YE"F9U;F-T:6]N<R`H=&5N(&QI;F5S(&]R(&QE<W,@:6X@;&5N9W1H
M*2P@=&AE;B!T:&4@=7-E(&]F('1H92!O8FIE8W0*9FEL92!I<R!U;G)E<W1R
M:6-T960L(')E9V%R9&QE<W,@;V8@=VAE=&AE<B!I="!I<R!L96=A;&QY(&$@
M9&5R:79A=&EV90IW;W)K+B`@*$5X96-U=&%B;&5S(&-O;G1A:6YI;F<@=&AI
M<R!O8FIE8W0@8V]D92!P;'5S('!O<G1I;VYS(&]F('1H90I,:6)R87)Y('=I
M;&P@<W1I;&P@9F%L;"!U;F1E<B!396-T:6]N(#8N*0H*("!/=&AE<G=I<V4L
M(&EF('1H92!W;W)K(&ES(&$@9&5R:79A=&EV92!O9B!T:&4@3&EB<F%R>2P@
M>6]U(&UA>0ID:7-T<FEB=71E('1H92!O8FIE8W0@8V]D92!F;W(@=&AE('=O
M<FL@=6YD97(@=&AE('1E<FUS(&]F(%-E8W1I;VX@-BX*06YY(&5X96-U=&%B
M;&5S(&-O;G1A:6YI;F<@=&AA="!W;W)K(&%L<V\@9F%L;"!U;F1E<B!396-T
M:6]N(#8L"G=H971H97(@;W(@;F]T('1H97D@87)E(&QI;FME9"!D:7)E8W1L
M>2!W:71H('1H92!,:6)R87)Y(&ET<V5L9BX*#`H@(#8N($%S(&%N(&5X8V5P
M=&EO;B!T;R!T:&4@4V5C=&EO;G,@86)O=F4L('EO=2!M87D@86QS;R!C;VUP
M:6QE(&]R"FQI;FL@82`B=V]R:R!T:&%T('5S97,@=&AE($QI8G)A<GDB('=I
M=&@@=&AE($QI8G)A<GD@=&\@<')O9'5C92!A"G=O<FL@8V]N=&%I;FEN9R!P
M;W)T:6]N<R!O9B!T:&4@3&EB<F%R>2P@86YD(&1I<W1R:6)U=&4@=&AA="!W
M;W)K"G5N9&5R('1E<FUS(&]F('EO=7(@8VAO:6-E+"!P<F]V:61E9"!T:&%T
M('1H92!T97)M<R!P97)M:70*;6]D:69I8V%T:6]N(&]F('1H92!W;W)K(&9O
M<B!T:&4@8W5S=&]M97(G<R!O=VX@=7-E(&%N9"!R979E<G-E"F5N9VEN965R
M:6YG(&9O<B!D96)U9V=I;F<@<W5C:"!M;V1I9FEC871I;VYS+@H*("!9;W4@
M;75S="!G:79E('!R;VUI;F5N="!N;W1I8V4@=VET:"!E86-H(&-O<'D@;V8@
M=&AE('=O<FL@=&AA="!T:&4*3&EB<F%R>2!I<R!U<V5D(&EN(&ET(&%N9"!T
M:&%T('1H92!,:6)R87)Y(&%N9"!I=',@=7-E(&%R92!C;W9E<F5D(&)Y"G1H
M:7,@3&EC96YS92X@(%EO=2!M=7-T('-U<'!L>2!A(&-O<'D@;V8@=&AI<R!,
M:6-E;G-E+B`@268@=&AE('=O<FL*9'5R:6YG(&5X96-U=&EO;B!D:7-P;&%Y
M<R!C;W!Y<FEG:'0@;F]T:6-E<RP@>6]U(&UU<W0@:6YC;'5D92!T:&4*8V]P
M>7)I9VAT(&YO=&EC92!F;W(@=&AE($QI8G)A<GD@86UO;F<@=&AE;2P@87,@
M=V5L;"!A<R!A(')E9F5R96YC90ID:7)E8W1I;F<@=&AE('5S97(@=&\@=&AE
M(&-O<'D@;V8@=&AI<R!,:6-E;G-E+B`@06QS;RP@>6]U(&UU<W0@9&\@;VYE
M"F]F('1H97-E('1H:6YG<SH*"B`@("!A*2!!8V-O;7!A;GD@=&AE('=O<FL@
M=VET:"!T:&4@8V]M<&QE=&4@8V]R<F5S<&]N9&EN9PH@("`@;6%C:&EN92UR
M96%D86)L92!S;W5R8V4@8V]D92!F;W(@=&AE($QI8G)A<GD@:6YC;'5D:6YG
M('=H871E=F5R"B`@("!C:&%N9V5S('=E<F4@=7-E9"!I;B!T:&4@=V]R:R`H
M=VAI8V@@;75S="!B92!D:7-T<FEB=71E9"!U;F1E<@H@("`@4V5C=&EO;G,@
M,2!A;F0@,B!A8F]V92D[(&%N9"P@:68@=&AE('=O<FL@:7,@86X@97AE8W5T
M86)L92!L:6YK960*("`@('=I=&@@=&AE($QI8G)A<GDL('=I=&@@=&AE(&-O
M;7!L971E(&UA8VAI;F4M<F5A9&%B;&4@(G=O<FL@=&AA=`H@("`@=7-E<R!T
M:&4@3&EB<F%R>2(L(&%S(&]B:F5C="!C;V1E(&%N9"]O<B!S;W5R8V4@8V]D
M92P@<V\@=&AA="!T:&4*("`@('5S97(@8V%N(&UO9&EF>2!T:&4@3&EB<F%R
M>2!A;F0@=&AE;B!R96QI;FL@=&\@<')O9'5C92!A(&UO9&EF:65D"B`@("!E
M>&5C=71A8FQE(&-O;G1A:6YI;F<@=&AE(&UO9&EF:65D($QI8G)A<GDN("`H
M270@:7,@=6YD97)S=&]O9`H@("`@=&AA="!T:&4@=7-E<B!W:&\@8VAA;F=E
M<R!T:&4@8V]N=&5N=',@;V8@9&5F:6YI=&EO;G,@9FEL97,@:6X@=&AE"B`@
M("!,:6)R87)Y('=I;&P@;F]T(&YE8V5S<V%R:6QY(&)E(&%B;&4@=&\@<F5C
M;VUP:6QE('1H92!A<'!L:6-A=&EO;@H@("`@=&\@=7-E('1H92!M;V1I9FEE
M9"!D969I;FET:6]N<RXI"@H@("`@8BD@06-C;VUP86YY('1H92!W;W)K('=I
M=&@@82!W<FET=&5N(&]F9F5R+"!V86QI9"!F;W(@870*("`@(&QE87-T('1H
M<F5E('EE87)S+"!T;R!G:79E('1H92!S86UE('5S97(@=&AE(&UA=&5R:6%L
M<PH@("`@<W!E8VEF:65D(&EN(%-U8G-E8W1I;VX@-F$L(&%B;W9E+"!F;W(@
M82!C:&%R9V4@;F\@;6]R90H@("`@=&AA;B!T:&4@8V]S="!O9B!P97)F;W)M
M:6YG('1H:7,@9&ES=')I8G5T:6]N+@H*("`@(&,I($EF(&1I<W1R:6)U=&EO
M;B!O9B!T:&4@=V]R:R!I<R!M861E(&)Y(&]F9F5R:6YG(&%C8V5S<R!T;R!C
M;W!Y"B`@("!F<F]M(&$@9&5S:6=N871E9"!P;&%C92P@;V9F97(@97%U:79A
M;&5N="!A8V-E<W,@=&\@8V]P>2!T:&4@86)O=F4*("`@('-P96-I9FEE9"!M
M871E<FEA;',@9G)O;2!T:&4@<V%M92!P;&%C92X*"B`@("!D*2!697)I9GD@
M=&AA="!T:&4@=7-E<B!H87,@86QR96%D>2!R96-E:79E9"!A(&-O<'D@;V8@
M=&AE<V4*("`@(&UA=&5R:6%L<R!O<B!T:&%T('EO=2!H879E(&%L<F5A9'D@
M<V5N="!T:&ES('5S97(@82!C;W!Y+@H*("!&;W(@86X@97AE8W5T86)L92P@
M=&AE(')E<75I<F5D(&9O<FT@;V8@=&AE(")W;W)K('1H870@=7-E<R!T:&4*
M3&EB<F%R>2(@;75S="!I;F-L=61E(&%N>2!D871A(&%N9"!U=&EL:71Y('!R
M;V=R86US(&YE961E9"!F;W(*<F5P<F]D=6-I;F<@=&AE(&5X96-U=&%B;&4@
M9G)O;2!I="X@($AO=V5V97(L(&%S(&$@<W!E8VEA;"!E>&-E<'1I;VXL"G1H
M92!S;W5R8V4@8V]D92!D:7-T<FEB=71E9"!N965D(&YO="!I;F-L=61E(&%N
M>71H:6YG('1H870@:7,@;F]R;6%L;'D*9&ES=')I8G5T960@*&EN(&5I=&AE
M<B!S;W5R8V4@;W(@8FEN87)Y(&9O<FTI('=I=&@@=&AE(&UA:F]R"F-O;7!O
M;F5N=',@*&-O;7!I;&5R+"!K97)N96PL(&%N9"!S;R!O;BD@;V8@=&AE(&]P
M97)A=&EN9R!S>7-T96T@;VX*=VAI8V@@=&AE(&5X96-U=&%B;&4@<G5N<RP@
M=6YL97-S('1H870@8V]M<&]N96YT(&ET<V5L9B!A8V-O;7!A;FEE<PIT:&4@
M97AE8W5T86)L92X*"B`@270@;6%Y(&AA<'!E;B!T:&%T('1H:7,@<F5Q=6ER
M96UE;G0@8V]N=')A9&EC=',@=&AE(&QI8V5N<V4*<F5S=')I8W1I;VYS(&]F
M(&]T:&5R('!R;W!R:65T87)Y(&QI8G)A<FEE<R!T:&%T(&1O(&YO="!N;W)M
M86QL>0IA8V-O;7!A;GD@=&AE(&]P97)A=&EN9R!S>7-T96TN("!3=6-H(&$@
M8V]N=')A9&EC=&EO;B!M96%N<R!Y;W4@8V%N;F]T"G5S92!B;W1H('1H96T@
M86YD('1H92!,:6)R87)Y('1O9V5T:&5R(&EN(&%N(&5X96-U=&%B;&4@=&AA
M="!Y;W4*9&ES=')I8G5T92X*#`H@(#<N(%EO=2!M87D@<&QA8V4@;&EB<F%R
M>2!F86-I;&ET:65S('1H870@87)E(&$@=V]R:R!B87-E9"!O;B!T:&4*3&EB
M<F%R>2!S:61E+6)Y+7-I9&4@:6X@82!S:6YG;&4@;&EB<F%R>2!T;V=E=&AE
M<B!W:71H(&]T:&5R(&QI8G)A<GD*9F%C:6QI=&EE<R!N;W0@8V]V97)E9"!B
M>2!T:&ES($QI8V5N<V4L(&%N9"!D:7-T<FEB=71E('-U8V@@82!C;VUB:6YE
M9`IL:6)R87)Y+"!P<F]V:61E9"!T:&%T('1H92!S97!A<F%T92!D:7-T<FEB
M=71I;VX@;V8@=&AE('=O<FL@8F%S960@;VX*=&AE($QI8G)A<GD@86YD(&]F
M('1H92!O=&AE<B!L:6)R87)Y(&9A8VEL:71I97,@:7,@;W1H97)W:7-E"G!E
M<FUI='1E9"P@86YD('!R;W9I9&5D('1H870@>6]U(&1O('1H97-E('1W;R!T
M:&EN9W,Z"@H@("`@82D@06-C;VUP86YY('1H92!C;VUB:6YE9"!L:6)R87)Y
M('=I=&@@82!C;W!Y(&]F('1H92!S86UE('=O<FL*("`@(&)A<V5D(&]N('1H
M92!,:6)R87)Y+"!U;F-O;6)I;F5D('=I=&@@86YY(&]T:&5R(&QI8G)A<GD*
M("`@(&9A8VEL:71I97,N("!4:&ES(&UU<W0@8F4@9&ES=')I8G5T960@=6YD
M97(@=&AE('1E<FUS(&]F('1H90H@("`@4V5C=&EO;G,@86)O=F4N"@H@("`@
M8BD@1VEV92!P<F]M:6YE;G0@;F]T:6-E('=I=&@@=&AE(&-O;6)I;F5D(&QI
M8G)A<GD@;V8@=&AE(&9A8W0*("`@('1H870@<&%R="!O9B!I="!I<R!A('=O
M<FL@8F%S960@;VX@=&AE($QI8G)A<GDL(&%N9"!E>'!L86EN:6YG"B`@("!W
M:&5R92!T;R!F:6YD('1H92!A8V-O;7!A;GEI;F<@=6YC;VUB:6YE9"!F;W)M
M(&]F('1H92!S86UE('=O<FLN"@H@(#@N(%EO=2!M87D@;F]T(&-O<'DL(&UO
M9&EF>2P@<W5B;&EC96YS92P@;&EN:R!W:71H+"!O<B!D:7-T<FEB=71E"G1H
M92!,:6)R87)Y(&5X8V5P="!A<R!E>'!R97-S;'D@<')O=FED960@=6YD97(@
M=&AI<R!,:6-E;G-E+B`@06YY"F%T=&5M<'0@;W1H97)W:7-E('1O(&-O<'DL
M(&UO9&EF>2P@<W5B;&EC96YS92P@;&EN:R!W:71H+"!O<@ID:7-T<FEB=71E
M('1H92!,:6)R87)Y(&ES('9O:60L(&%N9"!W:6QL(&%U=&]M871I8V%L;'D@
M=&5R;6EN871E('EO=7(*<FEG:'1S('5N9&5R('1H:7,@3&EC96YS92X@($AO
M=V5V97(L('!A<G1I97,@=VAO(&AA=F4@<F5C96EV960@8V]P:65S+`IO<B!R
M:6=H=',L(&9R;VT@>6]U('5N9&5R('1H:7,@3&EC96YS92!W:6QL(&YO="!H
M879E('1H96ER(&QI8V5N<V5S"G1E<FUI;F%T960@<V\@;&]N9R!A<R!S=6-H
M('!A<G1I97,@<F5M86EN(&EN(&9U;&P@8V]M<&QI86YC92X*"B`@.2X@66]U
M(&%R92!N;W0@<F5Q=6ER960@=&\@86-C97!T('1H:7,@3&EC96YS92P@<VEN
M8V4@>6]U(&AA=F4@;F]T"G-I9VYE9"!I="X@($AO=V5V97(L(&YO=&AI;F<@
M96QS92!G<F%N=',@>6]U('!E<FUI<W-I;VX@=&\@;6]D:69Y(&]R"F1I<W1R
M:6)U=&4@=&AE($QI8G)A<GD@;W(@:71S(&1E<FEV871I=F4@=V]R:W,N("!4
M:&5S92!A8W1I;VYS(&%R90IP<F]H:6)I=&5D(&)Y(&QA=R!I9B!Y;W4@9&\@
M;F]T(&%C8V5P="!T:&ES($QI8V5N<V4N("!4:&5R969O<F4L(&)Y"FUO9&EF
M>6EN9R!O<B!D:7-T<FEB=71I;F<@=&AE($QI8G)A<GD@*&]R(&%N>2!W;W)K
M(&)A<V5D(&]N('1H90I,:6)R87)Y*2P@>6]U(&EN9&EC871E('EO=7(@86-C
M97!T86YC92!O9B!T:&ES($QI8V5N<V4@=&\@9&\@<V\L(&%N9`IA;&P@:71S
M('1E<FUS(&%N9"!C;VYD:71I;VYS(&9O<B!C;W!Y:6YG+"!D:7-T<FEB=71I
M;F<@;W(@;6]D:69Y:6YG"G1H92!,:6)R87)Y(&]R('=O<FMS(&)A<V5D(&]N
M(&ET+@H*("`Q,"X@16%C:"!T:6UE('EO=2!R961I<W1R:6)U=&4@=&AE($QI
M8G)A<GD@*&]R(&%N>2!W;W)K(&)A<V5D(&]N('1H90I,:6)R87)Y*2P@=&AE
M(')E8VEP:65N="!A=71O;6%T:6-A;&QY(')E8V5I=F5S(&$@;&EC96YS92!F
M<F]M('1H90IO<FEG:6YA;"!L:6-E;G-O<B!T;R!C;W!Y+"!D:7-T<FEB=71E
M+"!L:6YK('=I=&@@;W(@;6]D:69Y('1H92!,:6)R87)Y"G-U8FIE8W0@=&\@
M=&AE<V4@=&5R;7,@86YD(&-O;F1I=&EO;G,N("!9;W4@;6%Y(&YO="!I;7!O
M<V4@86YY(&9U<G1H97(*<F5S=')I8W1I;VYS(&]N('1H92!R96-I<&EE;G1S
M)R!E>&5R8VES92!O9B!T:&4@<FEG:'1S(&=R86YT960@:&5R96EN+@I9;W4@
M87)E(&YO="!R97-P;VYS:6)L92!F;W(@96YF;W)C:6YG(&-O;7!L:6%N8V4@
M8GD@=&AI<F0@<&%R=&EE<R!T;PIT:&ES($QI8V5N<V4N"@P*("`Q,2X@268L
M(&%S(&$@8V]N<V5Q=65N8V4@;V8@82!C;W5R="!J=61G;65N="!O<B!A;&QE
M9V%T:6]N(&]F('!A=&5N=`II;F9R:6YG96UE;G0@;W(@9F]R(&%N>2!O=&AE
M<B!R96%S;VX@*&YO="!L:6UI=&5D('1O('!A=&5N="!I<W-U97,I+`IC;VYD
M:71I;VYS(&%R92!I;7!O<V5D(&]N('EO=2`H=VAE=&AE<B!B>2!C;W5R="!O
M<F1E<BP@86=R965M96YT(&]R"F]T:&5R=VES92D@=&AA="!C;VYT<F%D:6-T
M('1H92!C;VYD:71I;VYS(&]F('1H:7,@3&EC96YS92P@=&AE>2!D;R!N;W0*
M97AC=7-E('EO=2!F<F]M('1H92!C;VYD:71I;VYS(&]F('1H:7,@3&EC96YS
M92X@($EF('EO=2!C86YN;W0*9&ES=')I8G5T92!S;R!A<R!T;R!S871I<V9Y
M('-I;75L=&%N96]U<VQY('EO=7(@;V)L:6=A=&EO;G,@=6YD97(@=&AI<PI,
M:6-E;G-E(&%N9"!A;GD@;W1H97(@<&5R=&EN96YT(&]B;&EG871I;VYS+"!T
M:&5N(&%S(&$@8V]N<V5Q=65N8V4@>6]U"FUA>2!N;W0@9&ES=')I8G5T92!T
M:&4@3&EB<F%R>2!A="!A;&PN("!&;W(@97AA;7!L92P@:68@82!P871E;G0*
M;&EC96YS92!W;W5L9"!N;W0@<&5R;6ET(')O>6%L='DM9G)E92!R961I<W1R
M:6)U=&EO;B!O9B!T:&4@3&EB<F%R>2!B>0IA;&P@=&AO<V4@=VAO(')E8V5I
M=F4@8V]P:65S(&1I<F5C=&QY(&]R(&EN9&ER96-T;'D@=&AR;W5G:"!Y;W4L
M('1H96X*=&AE(&]N;'D@=V%Y('EO=2!C;W5L9"!S871I<V9Y(&)O=&@@:70@
M86YD('1H:7,@3&EC96YS92!W;W5L9"!B92!T;PIR969R86EN(&5N=&ER96QY
M(&9R;VT@9&ES=')I8G5T:6]N(&]F('1H92!,:6)R87)Y+@H*268@86YY('!O
M<G1I;VX@;V8@=&AI<R!S96-T:6]N(&ES(&AE;&0@:6YV86QI9"!O<B!U;F5N
M9F]R8V5A8FQE('5N9&5R(&%N>0IP87)T:6-U;&%R(&-I<F-U;7-T86YC92P@
M=&AE(&)A;&%N8V4@;V8@=&AE('-E8W1I;VX@:7,@:6YT96YD960@=&\@87!P
M;'DL"F%N9"!T:&4@<V5C=&EO;B!A<R!A('=H;VQE(&ES(&EN=&5N9&5D('1O
M(&%P<&QY(&EN(&]T:&5R(&-I<F-U;7-T86YC97,N"@I)="!I<R!N;W0@=&AE
M('!U<G!O<V4@;V8@=&AI<R!S96-T:6]N('1O(&EN9'5C92!Y;W4@=&\@:6YF
M<FEN9V4@86YY"G!A=&5N=',@;W(@;W1H97(@<')O<&5R='D@<FEG:'0@8VQA
M:6US(&]R('1O(&-O;G1E<W0@=F%L:61I='D@;V8@86YY"G-U8V@@8VQA:6US
M.R!T:&ES('-E8W1I;VX@:&%S('1H92!S;VQE('!U<G!O<V4@;V8@<')O=&5C
M=&EN9R!T:&4*:6YT96=R:71Y(&]F('1H92!F<F5E('-O9G1W87)E(&1I<W1R
M:6)U=&EO;B!S>7-T96T@=VAI8V@@:7,*:6UP;&5M96YT960@8GD@<'5B;&EC
M(&QI8V5N<V4@<')A8W1I8V5S+B`@36%N>2!P96]P;&4@:&%V92!M861E"F=E
M;F5R;W5S(&-O;G1R:6)U=&EO;G,@=&\@=&AE('=I9&4@<F%N9V4@;V8@<V]F
M='=A<F4@9&ES=')I8G5T960*=&AR;W5G:"!T:&%T('-Y<W1E;2!I;B!R96QI
M86YC92!O;B!C;VYS:7-T96YT(&%P<&QI8V%T:6]N(&]F('1H870*<WES=&5M
M.R!I="!I<R!U<"!T;R!T:&4@875T:&]R+V1O;F]R('1O(&1E8VED92!I9B!H
M92!O<B!S:&4@:7,@=VEL;&EN9PIT;R!D:7-T<FEB=71E('-O9G1W87)E('1H
M<F]U9V@@86YY(&]T:&5R('-Y<W1E;2!A;F0@82!L:6-E;G-E92!C86YN;W0*
M:6UP;W-E('1H870@8VAO:6-E+@H*5&AI<R!S96-T:6]N(&ES(&EN=&5N9&5D
M('1O(&UA:V4@=&AO<F]U9VAL>2!C;&5A<B!W:&%T(&ES(&)E;&EE=F5D('1O
M"F)E(&$@8V]N<V5Q=65N8V4@;V8@=&AE(')E<W0@;V8@=&AI<R!,:6-E;G-E
M+@H*("`Q,BX@268@=&AE(&1I<W1R:6)U=&EO;B!A;F0O;W(@=7-E(&]F('1H
M92!,:6)R87)Y(&ES(')E<W1R:6-T960@:6X*8V5R=&%I;B!C;W5N=')I97,@
M96ET:&5R(&)Y('!A=&5N=',@;W(@8GD@8V]P>7)I9VAT960@:6YT97)F86-E
M<RP@=&AE"F]R:6=I;F%L(&-O<'ER:6=H="!H;VQD97(@=VAO('!L86-E<R!T
M:&4@3&EB<F%R>2!U;F1E<B!T:&ES($QI8V5N<V4@;6%Y(&%D9`IA;B!E>'!L
M:6-I="!G96]G<F%P:&EC86P@9&ES=')I8G5T:6]N(&QI;6ET871I;VX@97AC
M;'5D:6YG('1H;W-E(&-O=6YT<FEE<RP*<V\@=&AA="!D:7-T<FEB=71I;VX@
M:7,@<&5R;6ET=&5D(&]N;'D@:6X@;W(@86UO;F<@8V]U;G1R:65S(&YO="!T
M:'5S"F5X8VQU9&5D+B`@26X@<W5C:"!C87-E+"!T:&ES($QI8V5N<V4@:6YC
M;W)P;W)A=&5S('1H92!L:6UI=&%T:6]N(&%S(&EF"G=R:71T96X@:6X@=&AE
M(&)O9'D@;V8@=&AI<R!,:6-E;G-E+@H*("`Q,RX@5&AE($9R964@4V]F='=A
M<F4@1F]U;F1A=&EO;B!M87D@<'5B;&ES:"!R979I<V5D(&%N9"]O<B!N97<*
M=F5R<VEO;G,@;V8@=&AE($QI8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS
M92!F<F]M('1I;64@=&\@=&EM92X*4W5C:"!N97<@=F5R<VEO;G,@=VEL;"!B
M92!S:6UI;&%R(&EN('-P:7)I="!T;R!T:&4@<')E<V5N="!V97)S:6]N+`IB
M=70@;6%Y(&1I9F9E<B!I;B!D971A:6P@=&\@861D<F5S<R!N97<@<')O8FQE
M;7,@;W(@8V]N8V5R;G,N"@I%86-H('9E<G-I;VX@:7,@9VEV96X@82!D:7-T
M:6YG=6ES:&EN9R!V97)S:6]N(&YU;6)E<BX@($EF('1H92!,:6)R87)Y"G-P
M96-I9FEE<R!A('9E<G-I;VX@;G5M8F5R(&]F('1H:7,@3&EC96YS92!W:&EC
M:"!A<'!L:65S('1O(&ET(&%N9`HB86YY(&QA=&5R('9E<G-I;VXB+"!Y;W4@
M:&%V92!T:&4@;W!T:6]N(&]F(&9O;&QO=VEN9R!T:&4@=&5R;7,@86YD"F-O
M;F1I=&EO;G,@96ET:&5R(&]F('1H870@=F5R<VEO;B!O<B!O9B!A;GD@;&%T
M97(@=F5R<VEO;B!P=6)L:7-H960@8GD*=&AE($9R964@4V]F='=A<F4@1F]U
M;F1A=&EO;BX@($EF('1H92!,:6)R87)Y(&1O97,@;F]T('-P96-I9GD@80IL
M:6-E;G-E('9E<G-I;VX@;G5M8F5R+"!Y;W4@;6%Y(&-H;V]S92!A;GD@=F5R
M<VEO;B!E=F5R('!U8FQI<VAE9"!B>0IT:&4@1G)E92!3;V9T=V%R92!&;W5N
M9&%T:6]N+@H,"B`@,30N($EF('EO=2!W:7-H('1O(&EN8V]R<&]R871E('!A
M<G1S(&]F('1H92!,:6)R87)Y(&EN=&\@;W1H97(@9G)E90IP<F]G<F%M<R!W
M:&]S92!D:7-T<FEB=71I;VX@8V]N9&ET:6]N<R!A<F4@:6YC;VUP871I8FQE
M('=I=&@@=&AE<V4L"G=R:71E('1O('1H92!A=71H;W(@=&\@87-K(&9O<B!P
M97)M:7-S:6]N+B`@1F]R('-O9G1W87)E('=H:6-H(&ES"F-O<'ER:6=H=&5D
M(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXL('=R:71E('1O('1H
M92!&<F5E"E-O9G1W87)E($9O=6YD871I;VX[('=E('-O;65T:6UE<R!M86ME
M(&5X8V5P=&EO;G,@9F]R('1H:7,N("!/=7(*9&5C:7-I;VX@=VEL;"!B92!G
M=6ED960@8GD@=&AE('1W;R!G;V%L<R!O9B!P<F5S97)V:6YG('1H92!F<F5E
M('-T871U<PIO9B!A;&P@9&5R:79A=&EV97,@;V8@;W5R(&9R964@<V]F='=A
M<F4@86YD(&]F('!R;VUO=&EN9R!T:&4@<VAA<FEN9PIA;F0@<F5U<V4@;V8@
M<V]F='=A<F4@9V5N97)A;&QY+@H*"0D)("`@($Y/(%=!4E)!3E19"@H@(#$U
M+B!"14-!55-%(%1(12!,24)205)9($E3($Q)0T5.4T5$($92144@3T8@0TA!
M4D=%+"!42$5212!)4R!.3PI705)204Y462!&3U(@5$A%($Q)0E)!4EDL(%1/
M(%1(12!%6%1%3E0@4$5234E45$5$($)9($%04$Q)0T%"3$4@3$%7+@I%6$-%
M4%0@5TA%3B!/5$A%4E=)4T4@4U1!5$5$($E.(%=2251)3D<@5$A%($-/4%E2
M24=(5"!(3TQ$15)3($%.1"]/4@I/5$A%4B!005)42453(%!23U9)1$4@5$A%
M($Q)0E)!4ED@(D%3($E3(B!7251(3U54(%=!4E)!3E19($]&($%.60I+24Y$
M+"!%251(15(@15A04D534T5$($]2($E-4$Q)140L($E.0TQ51$E.1RP@0E54
M($Y/5"!,24U)5$5$(%1/+"!42$4*24U03$E%1"!705)204Y42453($]&($U%
M4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2"E!5
M4E!/4T4N("!42$4@14Y425)%(%))4TL@05,@5$\@5$A%(%%504Q)5%D@04Y$
M(%!%4D9/4DU!3D-%($]&(%1(10I,24)205)9($E3(%=)5$@@64]5+B`@4TA/
M54Q$(%1(12!,24)205)9(%!23U9%($1%1D5#5$E612P@64]5($%34U5-10I4
M2$4@0T]35"!/1B!!3$P@3D5#15-305)9(%-%4E9)0TE.1RP@4D5004E2($]2
M($-/4E)%0U1)3TXN"@H@(#$V+B!)3B!.3R!%5D5.5"!53DQ%4U,@4D5154E2
M140@0ED@05!03$E#04),12!,05<@3U(@04=2145$(%1/($E."E=2251)3D<@
M5TE,3"!!3ED@0T]065))1TA4($A/3$1%4BP@3U(@04Y9($]42$52(%!!4E19
M(%=(3R!-05D@34]$2499"D%.1"]/4B!2141)4U1224)55$4@5$A%($Q)0E)!
M4ED@05,@4$5234E45$5$($%"3U9%+"!"12!,24%"3$4@5$\@64]5"D9/4B!$
M04U!1T53+"!)3D-,541)3D<@04Y9($=%3D5204PL(%-014-)04PL($E.0TE$
M14Y404P@3U(*0T].4T51545.5$E!3"!$04U!1T53($%225-)3D<@3U54($]&
M(%1(12!54T4@3U(@24Y!0DE,2519(%1/(%5312!42$4*3$E"4D%262`H24Y#
M3%5$24Y'($)55"!.3U0@3$E-251%1"!43R!,3U-3($]&($1!5$$@3U(@1$%4
M02!"14E.1PI214Y$15)%1"!)3D%#0U52051%($]2($Q/4U-%4R!355-404E.
M140@0ED@64]5($]2(%1(25)$(%!!4E1)15,@3U(@00I&04E,55)%($]&(%1(
M12!,24)205)9(%1/($]015)!5$4@5TE42"!!3ED@3U1(15(@4T]&5%=!4D4I
M+"!%5D5.($E&"E-50T@@2$],1$52($]2($]42$52(%!!4E19($A!4R!"145.
M($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@*1$%-04=%4RX*
M"@D)("`@("!%3D0@3T8@5$5235,@04Y$($-/3D1)5$E/3E,*#`H@("`@("`@
M("`@($AO=R!T;R!!<'!L>2!4:&5S92!497)M<R!T;R!9;W5R($YE=R!,:6)R
M87)I97,*"B`@268@>6]U(&1E=F5L;W`@82!N97<@;&EB<F%R>2P@86YD('EO
M=2!W86YT(&ET('1O(&)E(&]F('1H92!G<F5A=&5S=`IP;W-S:6)L92!U<V4@
M=&\@=&AE('!U8FQI8RP@=V4@<F5C;VUM96YD(&UA:VEN9R!I="!F<F5E('-O
M9G1W87)E('1H870*979E<GEO;F4@8V%N(')E9&ES=')I8G5T92!A;F0@8VAA
M;F=E+B`@66]U(&-A;B!D;R!S;R!B>2!P97)M:71T:6YG"G)E9&ES=')I8G5T
M:6]N('5N9&5R('1H97-E('1E<FUS("AO<BP@86QT97)N871I=F5L>2P@=6YD
M97(@=&AE('1E<FUS(&]F('1H90IO<F1I;F%R>2!'96YE<F%L(%!U8FQI8R!,
M:6-E;G-E*2X*"B`@5&\@87!P;'D@=&AE<V4@=&5R;7,L(&%T=&%C:"!T:&4@
M9F]L;&]W:6YG(&YO=&EC97,@=&\@=&AE(&QI8G)A<GDN("!)="!I<PIS869E
M<W0@=&\@871T86-H('1H96T@=&\@=&AE('-T87)T(&]F(&5A8V@@<V]U<F-E
M(&9I;&4@=&\@;6]S="!E9F9E8W1I=F5L>0IC;VYV97D@=&AE(&5X8VQU<VEO
M;B!O9B!W87)R86YT>3L@86YD(&5A8V@@9FEL92!S:&]U;&0@:&%V92!A="!L
M96%S="!T:&4*(F-O<'ER:6=H="(@;&EN92!A;F0@82!P;VEN=&5R('1O('=H
M97)E('1H92!F=6QL(&YO=&EC92!I<R!F;W5N9"X*"B`@("`\;VYE(&QI;F4@
M=&\@9VEV92!T:&4@;&EB<F%R>2=S(&YA;64@86YD(&$@8G)I968@:61E82!O
M9B!W:&%T(&ET(&1O97,N/@H@("`@0V]P>7)I9VAT("A#*2`\>65A<CX@(#QN
M86UE(&]F(&%U=&AO<CX*"B`@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T
M=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@("!M;V1I
M9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&EB<F%R>2!'96YE
M<F%L(%!U8FQI8PH@("`@3&EC96YS92!A<R!P=6)L:7-H960@8GD@=&AE($9R
M964@4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R"B`@("!V97)S:6]N(#(@
M;V8@=&AE($QI8V5N<V4L(&]R("AA="!Y;W5R(&]P=&EO;BD@86YY(&QA=&5R
M('9E<G-I;VXN"@H@("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN
M('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@("!B=70@5TE4
M2$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W
M87)R86YT>2!O9@H@("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@($QI8G)A
M<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*
M("`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.
M52!,:6)R87)Y($=E;F5R86P@4'5B;&EC"B`@("!,:6-E;G-E(&%L;VYG('=I
M=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E"B`@
M("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S
M,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!"@I!;'-O(&%D9"!I;F9O
M<FUA=&EO;B!O;B!H;W<@=&\@8V]N=&%C="!Y;W4@8GD@96QE8W1R;VYI8R!A
M;F0@<&%P97(@;6%I;"X*"EEO=2!S:&]U;&0@86QS;R!G970@>6]U<B!E;7!L
M;WEE<B`H:68@>6]U('=O<FL@87,@82!P<F]G<F%M;65R*2!O<B!Y;W5R"G-C
M:&]O;"P@:68@86YY+"!T;R!S:6=N(&$@(F-O<'ER:6=H="!D:7-C;&%I;65R
M(B!F;W(@=&AE(&QI8G)A<GDL(&EF"FYE8V5S<V%R>2X@($AE<F4@:7,@82!S
M86UP;&4[(&%L=&5R('1H92!N86UE<SH*"B`@66]Y;V1Y;F4L($EN8RXL(&AE
M<F5B>2!D:7-C;&%I;7,@86QL(&-O<'ER:6=H="!I;G1E<F5S="!I;B!T:&4*
M("!L:6)R87)Y(&!&<F]B)R`H82!L:6)R87)Y(&9O<B!T=V5A:VEN9R!K;F]B
M<RD@=W)I='1E;B!B>2!*86UE<R!286YD;VT@2&%C:V5R+@H*("`\<VEG;F%T
M=7)E(&]F(%1Y($-O;VX^+"`Q($%P<FEL(#$Y.3`*("!4>2!#;V]N+"!0<F5S
M:61E;G0@;V8@5FEC90H*5&AA="=S(&%L;"!T:&5R92!I<R!T;R!I="$*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]214%$344`
M````````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C<S,@`Q,#4Q-30S,3`U-P`P,38R,S(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````5VAA="!I<R!(;W)D93\*/3T]/3T]
M/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-2\Q,"\Q."`Q
M,3HS,SHS-2`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#(N,3,N,3`N
M,2`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"BXN
M(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*
M5&AE($AO<F1E(%!R;VIE8W0@:7,@82!G<F]U<"!O9B!D979E;&]P97)S('=H
M;R!W<FET92!796(@87!P;&EC871I;VYS('5S:6YG"G1H92!(;W)D92!!<'!L
M:6-A=&EO;B!&<F%M97=O<FLL(&ET<V5L9B!A('!R;V1U8W0@;V8@=&AE(%!R
M;VIE8W0N"@I4:&4@2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K(&ES('=R
M:71T96X@:6X@4$A0+"!A;F0@<')O=FED97,@=&AE(&-O;6UO;@IT;V]L<R!A
M(%=E8B!A<'!L:6-A=&EO;B!R97%U:7)E<SH@8VQA<W-E<R!F;W(@9&5A;&EN
M9R!W:71H('!R969E<F5N8V5S+`IC;VUP<F5S<VEO;BP@8G)O=W-E<B!D971E
M8W1I;VXL(&-O;FYE8W1I;VX@=')A8VMI;F<L($U)344L(&%N9"!M;W)E+@H*
M5&AE($AO<F1E($9R86UE=V]R:RP@8GD@:71S96QF+"!D;V5S(&YO="!P<F]V
M:61E(&%N>2!S:6=N:69I8V%N="!E;F0@=7-E<@IF=6YC=&EO;F%L:71Y.R!I
M="!P<F]V:61E<R!A(&)A<V4@9F]R(&]T:&5R(&%P<&QI8V%T:6]N<R!A;F0@
M=&]O;',@9F]R"F1E=F5L;W!E<G,N(%EO=2!W:6QL('!R;V)A8FQY('=A;G0@
M=&\@:6YS=&%L;"!S;VUE(&]F('1H92!A=F%I;&%B;&4@2&]R9&4*87!P;&EC
M871I;VYS+"!S=6-H(&%S($E-4"`H82!W96)M86EL(&-L:65N="DL(&]R($MR
M;VYO;&ET:"`H82!C86QE;F1A<BDN(%1H97)E"FES(&$@;&ES="!O9B!(;W)D
M92!A<'!L:6-A=&EO;G,@86YD('!R;VIE8W1S(&%T"FAT='`Z+R]W=W<N:&]R
M9&4N;W)G+W!R;VIE8W1S+G!H<"X*"E1H:7,@<V]F='=A<F4@:7,@3U-)($-E
M<G1I9FEE9"!/<&5N(%-O=7)C92!3;V9T=V%R92X@($]322!#97)T:69I960@
M:7,@80IC97)T:69I8V%T:6]N(&UA<FL@;V8@=&AE(&!/<&5N(%-O=7)C92!)
M;FET:6%T:79E8%\N"@HN+B!?8$]P96X@4V]U<F-E($EN:71I871I=F5@.B!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+PH*"D]B=&%I;FEN9R!(;W)D90HM
M+2TM+2TM+2TM+2TM+2T*"D9U<G1H97(@:6YF;W)M871I;VX@;VX@2&]R9&4@
M86YD('1H92!L871E<W0@=F5R<VEO;B!C86X@8F4@;V)T86EN960@870*"B`@
M:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R9&4O"@I);F9O<FUA=&EO;B!O;B!A
M<'!L:6-A=&EO;G,@=&AA="!U<V4@=&AE($AO<F1E(&9R86UE=V]R:R!C86X@
M8F4@9F]U;F0@870*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O<')O:F5C=',N
M<&AP"@H*1&]C=6UE;G1A=&EO;@HM+2TM+2TM+2TM+2TM"@I4:&4@9F]L;&]W
M:6YG(&1O8W5M96YT871I;VX@:7,@879A:6QA8FQE(&EN('1H92!(;W)D92!D
M:7-T<FEB=71I;VXZ"@HZ4D5!1$U%7SH@("`@("`@("`@("`@("`@("`@5&AI
M<R!F:6QE"CI#3U!924Y'7SH@("`@("`@("`@("`@("`@("!#;W!Y<FEG:'0@
M86YD(&QI8V5N<V4@:6YF;W)M871I;VX*.F!D;V-S+T-(04Y'15-@7SH@("`@
M("`@("`@($-H86YG97,@8GD@<F5L96%S90HZ8&1O8W,O0T]$24Y'7U-404Y$
M05)$4V!?.B`@0V]D:6YG('-T86YD87)D<R!F;W(@2&]R9&4@<')O:F5C=',*
M.F!D;V-S+T-/3E1224)55$E.1V!?.B`@("`@($AO=R!T;R!C;VYT<FEB=71E
M('1O($AO<F1E"CI@9&]C<R]#4D5$25138%\Z("`@("`@("`@("!0<F]J96-T
M(&1E=F5L;W!E<G,*.F!D;V-S+TA!0TM)3D=@7SH@("`@("`@("`@($AO=R!T
M;R!G970@2&]R9&4@=FEA($-64PHZ8&1O8W,O24Y35$%,3&!?.B`@("`@("`@
M("`@26YS=&%L;&%T:6]N(&EN<W1R=6-T:6]N<R!A;F0@;F]T97,*.F!D;V-S
M+U!%4D9/4DU!3D-%8%\Z("`@("`@(%!E<F9O<FUA;F-E(&=U:61E"CI@9&]C
M<R]214Q%05-%8%\Z("`@("`@("`@("!296QE87-E('!R;V-E<W,@;F]T97,*
M.F!D;V-S+U-%0U5225198%\Z("`@("`@("`@(%-E8W5R:71Y(&YO=&5S"CI@
M9&]C<R]43T1/8%\Z("`@("`@("`@("`@("!$979E;&]P;65N="!43T1/(&QI
M<W0*.F!D;V-S+U501U)!1$E.1V!?.B`@("`@("`@(%!O:6YT97)S(&]N('5P
M9W)A9&EN9R!F<F]M('!R979I;W5S($AO<F1E('9E<G-I;VYS"@H*26YS=&%L
M;&%T:6]N"BTM+2TM+2TM+2TM+0H*26YS=')U8W1I;VYS(&9O<B!I;G-T86QL
M:6YG($AO<F1E(&-A;B!B92!F;W5N9"!I;B!T:&4@9FEL92!)3E-404Q,7R!I
M;B!T:&4*8&!D;V-S+V!@(&1I<F5C=&]R>2!O9B!T:&4@2&]R9&4@9&ES=')I
M8G5T:6]N+@H*"D%S<VES=&%N8V4*+2TM+2TM+2TM+0H*268@>6]U(&5N8V]U
M;G1E<B!P<F]B;&5M<R!W:71H($AO<F1E+"!H96QP(&ES(&%V86EL86)L92$@
M"@I4:&4@2&]R9&4@1G)E<75E;G1L>2!!<VME9"!1=65S=&EO;G,@3&ES="`H
M1D%1*2P@879A:6QA8FQE(&]N('1H92!796(@870*(`H@(&AT='`Z+R]W=W<N
M:&]R9&4N;W)G+V9A<2\*"E1H92!(;W)D92!0<F]J96-T(')U;G,@82!N=6UB
M97(@;V8@;6%I;&EN9R!L:7-T<RP@9F]R(&EN9&EV:61U86P@87!P;&EC871I
M;VYS"F%N9"!F;W(@:7-S=65S(')E;&%T:6YG('1O('1H92!P<F]J96-T(&%S
M(&$@=VAO;&4N("!);F9O<FUA=&EO;BP@87)C:&EV97,L(&%N9`IS=6)S8W)I
M<'1I;VX@:6YF;W)M871I;VX@8V%N(&)E(&9O=6YD(&%T"@H@(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+VUA:6PO"@I,87-T;'DL($AO<F1E(&1E=F5L;W!E<G,L
M(&-O;G1R:6)U=&]R<R!A;F0@=7-E<G,@86QS;R!M86ME(&]C8V%S:6]N86P*
M87!P96%R86YC97,@;VX@25)#+"!O;B!T:&4@8VAA;FYE;"`C:&]R9&4@;VX@
M=&AE(&9R965N;V1E($YE='=O<FL**&ER8RYF<F5E;F]D92YN970I+@H*"DQI
M8V5N<VEN9PHM+2TM+2TM+2T*"D9O<B!L:6-E;G-I;F<@86YD(&-O<'ER:6=H
M="!I;F9O<FUA=&EO;BP@<&QE87-E('-E92!T:&4@9FEL92!#3U!924Y'7R!I
M;B!T:&4*2&]R9&4@9&ES=')I8G5T:6]N+@H*5&AA;FMS+`H*5&AE($AO<F1E
M('1E86T*"@HN+B!?4D5!1$U%.B`_9CU214%$344N:'1M;`HN+B!?0T]064E.
M1SH@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O;&=P;"YP:'`*+BX@
M7V1O8W,O0TA!3D=%4SH@/V8]0TA!3D=%4RYH=&UL"BXN(%]D;V-S+T-/1$E.
M1U]35$%.1$%21%,Z(#]F/4-/1$E.1U]35$%.1$%21%,N:'1M;`HN+B!?9&]C
M<R]#3TY44DE"551)3D<Z(#]F/4-/3E1224)55$E.1RYH=&UL"BXN(%]D;V-S
M+T-2141)5%,Z(#]F/4-2141)5%,N:'1M;`HN+B!?9&]C<R](04-+24Y'.B`_
M9CU(04-+24Y'+FAT;6P*+BX@7TE.4U1!3$PZ"BXN(%]D;V-S+TE.4U1!3$PZ
M(#]F/4E.4U1!3$PN:'1M;`HN+B!?9&]C<R]015)&3U)-04Y#13H@/V8]4$52
M1D]234%.0T4N:'1M;`HN+B!?9&]C<R]214Q%05-%.B`_9CU214Q%05-%+FAT
M;6P*+BX@7V1O8W,O4T5#55))5%DZ(#]F/5-%0U522519+FAT;6P*+BX@7V1O
M8W,O5$]$3SH@/V8]5$]$3RYH=&UL"BXN(%]D;V-S+U501U)!1$E.1SH@/V8]
M55!'4D%$24Y'+FAT;6P*````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O0TA!3D=%
M4P``````````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`R,C4W-S,`,3`U,34T,S$P-3<`,#$V,S4U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM+2TM+0IV,RXQ+C,*+2TM+2TM
M"@I;8VIH72!314-54DE463H@5F%L:61A=&4@1T54+6)A<V5D(%523"!P87)A
M;65T97)S('!R;W9I9&5D('1O($AO<F1E)W,*("`@("`@:6YD97@N<&AP+@I;
M:F%N72!3=7!P;W)T(&EM<&]R=&EN9R!O9B!C;VUB:6YE9"!D871E+W1I;64@
M9FEE;&1S("A"=6<@(S,Q,38I+@I;:F%N72!,;V<@82!W87)N:6YG(&EF('5S
M:6YG('-E='1I;F=S('1H870@8G)E86L@<V5S<VEO;G,N"EMJ86Y=($9I>"!P
M87)S92!E<G)O<B!T:&%T(&)R;VME(%-Y;F--3"!S>6YC:')O;FEZ871I;VX@
M*$)U9R`C-#$V."DN"EMJ86Y=(%-U<'!O<G0@2V]L86(@9W)O=7`@04-,<R`H
M8W-A8V-A0'1H96-S;"YO<F<L(%)E<75E<W0@(S(R-S`I+@I;:F%N72!&:7@@
M=6YS97)I86QI>F4H*2!E<G)O<G,@:6X@<V5S<VEO;B!V:65W97(@*$)U9R`C
M,S4X-BDN"@H*+2TM+2TM"G8S+C$N,@HM+2TM+2T*"EMC:FA=(%-%0U522519
M.B!296UO=F4@=6YU<V5D(&EM86=E('!R;WAY(&-O9&4@9G)O;2!D97)E9F5R
M<F5R+@I;8VIH72!314-54DE463H@0VQO<V4@6%-3('!R;V)L96US(&EN(&1E
M<F5F97)R97(@*$E%(&]N;'DI+"!H96QP('9I97=E<B!A;F0*("`@("`@<')O
M8FQE;2!R97!O<G1I;F<@<V-R965N+@I;8VIH72!(86YD;&4@97)R;W)S(&=E
M;F5R871E9"!D=7)I;F<@6$U,+5)00R!C86QL<R!P<F]P97)L>0H@("`@("`H
M0F5N($ML86YG(#QB96Y`86QK86QO:60N;F5T/BP@0G5G(",T,#DW*2X*6VIA
M;ET@061D(&%D9&ET:6]N86P@:6YD97AE<R!T;R!P<F5F97)E;F-E('1A8FQE
M("AJ+F)E;F]I=$!F<F5E+F9R+"!"=6<@(S0P-SDI+@I;:F%N72!&:7@@<')E
M9F5R96YC92!C86-H92`H0G5G(",T,#<Y*2X*6VIA;ET@061D(&-O;F9I9W5R
M871I;VX@;W!T:6]N('1O(&1I<V%B;&4@1T54+6)A<V5D('-E<W-I;VYS+@I;
M:F%N72!&:7@@<')E9F5R96YC97,@86-C97-S(&9O<B!S<&5C:6%L($MO;&%B
M('5S97)S("AW<F]B96Q`9V5N=&]O+F]R9RP*("`@("`@0G5G(",T,#0Y*2X*
M6VUM<UT@1FEX('-E='1I;F<@9&5F875L="!C:&%R<V5T(&9O<B!N;VXM34E-
M12!M97-S86=E<R`H0G5G(",S.#`T*2X*6VIA;ET@061D('-E=F5R86P@;65T
M:&]D<R!T;R!M86YI<'5L871E(&=R;W5P<R!A;F0@<VAA<F5S('1O($AO<F1E
M)W,@05!)+@I;:F%N72!2971U<FX@<V5R:6%L:7IE9"!02%`@=F%L=65S('1H
M<F]U9V@@=&AE(%)%4U0@:6YT97)F86-E(&EF('!A<W-I;F<@80H@("`@("!R
M97-T0V]N=&5N=%1Y<&4@<&%R86UE=&5R(&]F("=A<'!L:6-A=&EO;B]X+6AT
M='!D+7!H<"<N"EMC:FA=($]N;'D@86QL;W<@=7-E<G,@=&\@87-S:6=N(%-H
M87)E('!E<FUI<W-I;VYS(&9O<B!G<F]U<',@=&AE>2!A<F4*("`@("`@;65M
M8F5R<R!O9BX*6VIA;ET@06QL;W<@=&\@9&ES86)L92!61E,@8F%C:V5N9',@
M:6X@=&AE(&%P<&QI8V%T:6]N<R<@8V]N9FEG=7)A=&EO;G,N"EMM;7-=(%5P
M9&%T92!T:&4@34E-12!#;VYT96YT+51Y<&4@8VAA<G-E="!P87)A;65T97(@
M:6X@82!-24U%(&UE<W-A9V4@=VAE;B!W90H@("`@("!C;VYV97)T('1H92!C
M;VYT96YT<R!F;W(@=FEE=VEN9R!I;B!T:&4@8G)O=W-E<B`H0G5G(",S-S(Y
M*2X*6V-J:%T@1FEX($AO<F1E7T9O<FU?5'EP95]A<W-I9VX@:F%V87-C<FEP
M="`H0G5G(",S-S0P*2X*6VIA;ET@061D('5P9W)A9&4@<V-R:7!T<R!F;W(@
M3W)A8VQE+@I;8VIH72!);F-L=61E(%!!5$A?24Y&3R!W:&5N979E<B!15452
M65]35%))3D<@:7,@<F5Q=65S=&5D(&EN($AO<F1E.CIS96QF57)L*"D*("`@
M("`@*$)U9R`C,S<P,RDN"EMJ86Y=($%D9"!G96YE<FEC(%-13"!U<&=R861E
M('-C<FEP="`H1&%N:65L($$N(%)A;6%L97D*("`@("`@/&1A;FEE;"YR86UA
M;&5Y0&1R86ME+F5D=3XI+@H*"BTM+2TM+0IV,RXQ+C$*+2TM+2TM"@I;8VIH
M72!314-54DE463H@1FEX(')E;6]T92!C;V1E(&5X96-U=&EO;B!V=6QN97)A
M8FEL:71Y(&9O=6YD(&)Y($IA;B!38VAN96ED97(N"EMC:FA=($9I>"!E>'!O
M<G0@86YD('-Y;F-H<F]N:7IA=&EO;B!O9B!E=F5N=',@86-R;W-S(&1A>6QI
M9VAT('-A=FEN9R!T:6UE"B`@("`@(&-H86YG97,N"EMJ86Y=($%D9"!P<F]P
M97(@;&]C:VEN9R!T;R!M>7-Q;"!S97-S:6]N(&AA;F1L97(@*$)U9R`C,S8V
M,"DN"EMC:FA=(&EE+F-S<R!I<R!N;W0@;F5C97-S87)Y(&9O<B!)13<L('-O
M(')E;F%M92!A<'!R;W!R:6%T96QY("A"=6<@(S,V-S$I+@I;:F%N72!&:7@@
M<75O=&$@<W5P<&]R="!F;W(@<V]M92!61E,@9')I=F5R<R`H0G5G(",S-C0W
M*2X*6V-J:%T@0F5T=&5R($]P97)A($UI;FD@9&5T96-T:6]N("A"=6<@(S(Y
M-C$I+@I;:F%N72!&:7@@;65N=2!W<F%P<&EN9R!W:71H($MO;&%B(&%N9"!0
M=7)P;&4@=&AE;64@*$)U9R`C,S4Y-"DN"@H*+2TM+0IV,RXQ"BTM+2T*"EMC
M:FA=(%)E;6]V92!B;V=U<R!#;VYT96YT+4QO8V%T:6]N(&AE861E<B!I;B!T
M:&4@5TU,($UO8FEL92!R96YD97)E<@H@("`@("`H0G5G(",S-#<V*2X*6VIA
M;ET@061D(&]P=&EO;B!T;R!B;&]C:R!+;VQA8B!A=71H96YT:6-A=&EO;B!A
M9G1E<B!F86EL960@;&]G:6YS"B`@("`@("AT;VMO94!K9&4N;W)G+"!297%U
M97-T(",S-#<T*2X*6VIA;ET@06QL;W<@=&\@<V5T(&AE:6=H="!O9B!I9G)A
M;64@<&]R=&%L(&)L;V-K("AT979A;G-`=&%C:&]M971R>2YC;VTL"B`@("`@
M(%)E<75E<W0@(S,U,#0I+@I;8VIH72!5<&1A=&4@5&]O;%1I<',@2F%V85-C
M<FEP="!O8FIE8W0@=&\@86QL;W<@=&]O;'1I<',@;VX@;F]N+3QA/B!E;&5M
M96YT<RX*6VUM<UT@4V]R="!A;B!)34%07U1R964@;V)J96-T(&)Y(&1I<W!L
M87D@;F%M92P@;F]T(&9U;&P@;6%I;&)O>"!N86UE+@I;;6%S72!-86ME('-U
M<F4@9&%T86)A<V4@<&]R=&%B:6QI='D@;W!T:6]N<R!A<F4@87!P;&EE9"!I
M;B!(:7-T;W)Y(&UO9'5L92X*("`@("`@*$)U9R`C,S0X,BD*"@HM+2TM+2TM
M+0IV,RXQ+5)#,PHM+2TM+2TM+0H*6VIA;ET@36%K92!S=7)E('1H870@2V]L
M86(@=7-E<G,@86QW87ES(&AA=F4@=&AE('-A;64@=7-E<B!N86UE("A"=6<@
M(S$S,3<I+@I;:F%N72!&:7@@;6]V:6YG(&]B:F5C=',@=VET:"!+;VQA8B!D
M<FEV97)S("AT;VMO94!K9&4N;W)G+"!"=6<@(S(X,3$I+@I;:F%N72!!9&0@
M<F5S970@8G5T=&]N('1O(&EM86=E(&9O<FT@9FEE;&1S+@I;:F%N72!&:7@@
M<V5L96-T:6]N(&]F(&1E9F%U;'0@:61E;G1I='D@*$)U9R`C,S0Q-BDN"EMM
M87-=($%D9"!(96)R97<@=')A;G-L871I;VXN"EMM87-=($%D9"!S=7!P;W)T
M(&9O<B!21D,@-#,Q-"US='EL92!)34%0($%#3',N"EMM;7-=($-O<G)E8W1L
M>2!E;F-O9&4@-RUB:70@34E-12!M97-S86=E<R!W:71H($Y53$P@8VAA<F%C
M=&5R<R`H0G5G(",S,SDU*2X*6VIA;ET@2&ED92!A<'!L:6-A=&EO;G,@=VET
M:"!S=&%T=7,@)VYO=&]O;&)A<B<@9G)O;2!O<'1I;VYS(&UE;G4@*$)U9R`C
M,S,X,RDN"@H*+2TM+2TM+2T*=C,N,2U20S(*+2TM+2TM+2T*"EMJ86Y=($%D
M9"!+:&UE<B!T<F%N<VQA=&EO;B`H3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K
M:&UE<F]S+FEN9F\^*2X*6VUM<UT@2&%N9&QE('%U;W1E9"!T97AT('=H96X@
M<&%R<VEN9R!-1$X@<F5Q=65S=',@*$)U9R`C,S,T,"DN"EMB96Y=($)E='1E
M<B!S=7!P;W)T(&9O<B!-4RU344PN"EMJ86Y=(%-H;W<@8V]R<F5C="!A9&1R
M97-S(&EN(&QA<W0M;&]G:6X@;65S<V%G92!I9B!C;VYN96-T:6YG('1H<F]U
M9V@@82!P<F]X>0H@("`@("`H0G5G(",S,C@X*2X*6VUM<UT@06QL;W<@861M
M:6X@=&\@9&ES86)L92!B<F]W<V5R('-T<FEN9R!C:&5C:W,@*$)U9R`C,S(X
M,BDN"EMJ86Y=($-O<G)E8W1L>2!E;F-O9&4@96UA:6P@9W)O=7`@;F%M97,@
M*$)U9R`C,S(S-"DN"EMC:FA=($%D9"!A(&1I<W!L87D@;65T:&]D(&9O<B!H
M;W5R36EN=71E4V5C;VYD(&9O<FT@9FEE;&1S("A"=6<@(S,Q-C4I+@I;8VIH
M72!(;W)D92=S('!R969E<F5N8V5S(&YO=R!A<F4@<F5F97)R960@=&\@87,@
M1VQO8F%L($]P=&EO;G,@<V\@=&AE('5S97(*("`@("`@9&]E<VXG="!N965D
M('1O(&MN;W<@=VAA="!(;W)D92!I<RP@86YD(&%L=V%Y<R!A<'!E87(@870@
M=&AE('1O<"!O9@H@("`@("!L:7-T<R!O9B!A<'!S(&9O<B!W:&EC:"!P<F5F
M97)E;F-E<R!A<F4@879A:6QA8FQE+@I;:F%N72!!9&0@=7!G<F%D92!I;G-T
M<G5C=&EO;G,@*$ME=FEN($UY97(@:V5V:6Y?;7EE<D!I=3$S+F]R9RP@0G5G
M(",S,C(R*2X*6V-J:%T@07!P;&EC871I;VYS('=H:6-H(&1O(&YO="!H879E
M(&$@8V]N9FEG+W!R969S+G!H<"!F:6QE(&YO(&QO;F=E<@H@("`@("!A<'!E
M87(@:6X@;&ES=',@;V8@87!P;&EC871I;VYS('1O('-E="!O<'1I;VYS(&9O
M<B!T;R!A=F]I9"!C;VYF=7-I;VXN"@H*+2TM+2TM+2T*=C,N,2U20S$*+2TM
M+2TM+2T*"EMC:FA=($UA:V4@=&AE(&QO8VL@9&ER96-T;W)Y(&9O<B!T:&4@
M;65M8V%C:&5D(%-E<W-I;VY(86YD;&5R(&-O;F9I9W5R86)L90H@("`@("`H
M0G5G(",S,3(P*2X*6VUM<UT@57!D871E(%1E>'1?1FQO=V5D.CH@=&\@<W5P
M<&]R="!21D,@,S8W-BX*6V-J:%T@1FEX(&]U='!U="!E<V-A<&EN9R!O9B!(
M;W)D95]&;W)M7U1Y<&5?8V5L;'!H;VYE(&EN(%5)7U9A<E)E;F1E<F5R7VAT
M;6PN"EMC:FA=($%L;&]W(&-H;V]S:6YG(%M.;VYE72!A<R!A(&1A=&%B87-E
M(&9O<B`D8V]N9ELG<W%L)UT@*$)U9R`C,C<U-"DN"EMJ86Y=($%D9"!)8V5L
M86YD:6,@=')A;G-L871I;VX@*$)J;W)N($1A=FED<W-O;B`\8FIO<W-I0'-N
M97)P82YI<SXI+@I;;6US72!7;W)K(&%R;W5N9"!B<F]K96X@:6UA<%\X8FET
M*"D@:6UP;&5M96YT871I;VX@:6X*("`@("`@34E-13HZ<75O=&5D4')I;G1A
M8FQE16YC;V1E("A"=6<@(S(Y-S4I+@I;;6US72!!9&0@9V%R8F%G92!C;VQL
M96-T:6]N('1O($AO<F1E7T-A8VAE+@I;8VIH72!&:7@@1W)O=7`Z.FQI<W1!
M;&Q5<V5R<R`H0V%R;&]S(%!E9')I;F%C:2P@0G5G(",R.3,W*2X*6VIA;ET@
M061D(&AI9V@@8V]N=')A<W0@=&AE;64@*'1M97)R:71T0&5M86EL+F%R:7IO
M;F$N961U+"!297%U97-T(",Q-3DX*2X*6VIA;ET@2V5E<',@<VED96)A<B!E
M>'!A;G-I;VX@<W1A=&4@86-R;W-S('-E<W-I;VYS("A297%U97-T(",Q-38T
M*2X*6VIA;ET@061D(&-O;F9I9W5R871I;VX@9F]R(&UA:6P@9&]M86EN('5S
M960@9F]R('!R;V)L96T@<F5P;W)T<PH@("`@("`H9'5S=&EN0'EW;&-S+F]R
M9RP@4F5Q=65S="`C,3,W-BDN"EMC:FA=($%D9"!D>6YA;6EC('1A8FQE(')E
M+7-O<G1I;F<@=&AR;W5G:"!J879A<V-R:7!T+@I;8VIH72!);G-P96-T(&UE
M=&AO9"!S:6=N871U<F5S('-O('1H870@=&AE(%)%4U0@9')I=F5R(&ES;B=T
M(&1E<&5N9&5N="!O;@H@("`@("!T:&4@;W)D97(@;V8@1T54('!A<F%M971E
M<G,N"EMC:FA=($%D9"!H;W)D92]G9710<F5F97)E;F-E(&%N9"!H;W)D92]S
M9710<F5F97)E;F-E($%022!M971H;V1S+@I;8VIH72!!9&0@82!L:7-T(&]F
M(&%C=&EV92!U<V5R<R!A;F0@86-T:79E('-E<W-I;VYS('1O('1H92!A9&UI
M;B!A<F5A+@I;8VIH72!!9&0@=6YO8G1R=7-I=F4@:F%V87-C<FEP="!T;V]L
M=&EP<R!B87-E9"!O;B!T:&4@=&ET;&4@871T<FEB=71E+@I;:F%N72!-;W9E
M('-I9&5B87(@8V]L;&%P<V4O97AP86YD(&)U='1O;B!B96QO=R!T:&4@;65N
M=2!B87(@*$]L:79E<B!+=6AL"B`@("`@(#QO:W5H;$!N971C;VQO9VYE+F1E
M/BDN"EMJ86Y=($%D9"!)9&5A<R!T:&5M92`H4F]E;"!';&]U9&5M86YS(#QR
M;V5L0&=L;W5D96UA;G,N:6YF;SXI+@I;8VIH72!-;W9E($AO<F1E7TAI<W1O
M<GD@9&%T82!T;R!I=',@;W=N(%-13"!T86)L92`H0G5G(",R,CDX*2X*6VIA
M;ET@061D($AO<F1E7T9O<FU?='EP95]F:6=L970@9F]R($-!4%1#2$$@9FEE
M;&1S('=I=&@@9FEG;&5T(&9O;G1S+@I;:F%N72!!9&0@2&]R9&5?1F]R;5]4
M>7!E7V1B;&]O:W5P(&9O<B!F;W)M(&9I96QD<R!W:71H(&1A=&%B87-E(&QO
M;VMU<',*("`@("`@*%)E<75E<W0@(S,R,BDN"EMJ86Y=($%D9"!C;VYF:6=U
M<F%T:6]N('1O(&1I<V%B;&4@(D%B;W5T(B!L:6YK<R!I;B!H96QP('=I;F1O
M=W,@*")-871T:&5W"B`@("`@($TN($=A;6)L92(@/&AO<F1E+61E=D!M9V%M
M8FQE+F-A/BDN"EMC:FA=($%L;&]W('-E;F1I;F<@<')O8FQE;2!R97!O<G1S
M('1O(&$@=&EC:V5T('-Y<W1E;2!U<VEN9R!T:&4*("`@("`@=&EC:V5T<R]A
M9&14:6-K970@05!)(&-A;&P@*$)U9R`C,3DQ-RDN"EMC:FA=($1E9FEN92!2
M5$P@<W1Y;&5S('9I82!A;B!A9&1I=&EO;F%L('-T>6QE<VAE970N"EMC:FA=
M(%5S86)I;&ET>2!I;7!R;W9E;65N=',@=&\@=&AE(&ED96YT:71I97,@;6%N
M86=E;65N="!P86=E("A"=6<@(S$X-#8I+@I;8F5N72!!9&0@3$1!4"!S=7!P
M;W)T('1O($=R;W5P('!A8VMA9V4N"EMC:FA=($%D9"!334(@9')I=F5R('1O
M(%9&4R!P86-K86=E+@I;8VIH72!!;&QO=R!C<F5A=&EO;B!O9B!E>'!I<FEN
M9R!A8V-O=6YT<R!I;B!,1$%0"B`@("`@("A2;V5L($=L;W5D96UA;G,@/')O
M96Q`9VQO=61E;6%N<RYI;F9O/BDN"EMC:FA=($%D9"!C;VYF:6=U<F%T:6]N
M(&]P=&EO;B!T;R!S96%R8V@@9F]R('1H92!U<V5R)W,@1$X@:6X@=&AE(%!R
M969S7VQD87`*("`@("`@9')I=F5R("A"=6<@(S$W.#8I+@I;:F%N72!!;&QO
M=R!T;R!S<&5C:69Y('1H92!O8FIE8W1C;&%S<R!F;W(@;F5W('5S97)S(&%D
M9&5D('1H<F]U9V@@3$1!4`H@("`@("`H4F]E;"!';&]U9&5M86YS(#QR;V5L
M0&=L;W5D96UA;G,N:6YF;SXI+@I;:F%N72!!9&0@<&%S<W=O<F0@97AP:7)A
M=&EO;B!A;F0@<&%S<W=O<F0@96YC<GEP=&EO;B!T;R!,1$%0(&%U=&AE;G1I
M8V%T:6]N"B`@("`@(&1R:79E<B`H4F]E;"!';&]U9&5M86YS(#QR;V5L0&=L
M;W5D96UA;G,N:6YF;SXI+@I;:F%N72!!9&0@<&5R;6ES<VEO;G,@=&\@<F5S
M=')I8W0@;G5M8F5R(&]F('!O<G1A;"!B;&]C:W,N"EMJ86Y=($%D9"!C;VYF
M:6=U<F%T:6]N(&9O<B!F:7AE9"!P;W)T86P@8FQO8VMS+@I;:FUF72!!9&0@
M875D:6\@;F]T:69I8V%T:6]N(&QI<W1E;F5R+"!M86ME('!O<G1A;"!H86YD
M;&4@875D:6\@;F]T:69I8V%T:6]N<PH@("`@("!B>2!B;&]C:W,@*&4N9RX@
M=&AE($E-4"!F;VQD97(@<W5M;6%R>2DN"EMM;7-=($-A8VAE(&-E<G1A:6X@
M<F5G:7-T<GD@9&%T82!T;R!P<F5V96YT('5N;F5E9&5D(&9I;&4@;&]A9&EN
M9R]P87)S:6YG"B`@("`@(&%F=&5R('1H92!I;FET:6%L(&QO9VEN+@I;;6%S
M72!!9&0@<W5P<&]R="!F;W(@8V]U;G1I;F<@875T:&5N=&EC871E9"!S97-S
M:6]N<R!V:6$@4V5S<VEO;DAA;F1L97)S+@I;8VIH72!292UW;W)K(%1A8G,@
M<V\@=&AA="!B86-K9W)O=6YD(&EM86=E<R!C86X@8F4@=7-E9"!I;B!C<F5A
M=&EV92!W87ES+@I;:F%N72!!9&0@(DUY($%C8V]U;G0@26YF;W)M871I;VXB
M(&)L;V-K('1H870@;6EM:6-S('1H92!!8V-O=6YT<R!M;V1U;&4N"EMJ86Y=
M($EM<')O=F4@<F5N9&5R:6YG(&9O<B!R:6=H="UT;RUL969T(&QA;F=U86=E
M<R`H06UI<FMA8FER($UE=&%.150@3'1D+BDN"EMJ86Y=($%D9"!S=7!P;W)T
M(&9O<B!A<F)I=')A<GDL(&YO;BUB;V]L96%N('!E<FUI<W-I;VX@=F%L=65S
M+@I;8F5N72!!9&0@86QT97)N871E7VQO9VEN(&%N9"!R961I<F5C=%]O;E]L
M;V=O=70@9F5A='5R97,N"EMJ86Y=($%D9"!G96YE<FEC(%--5%`@9')I=F5R
M('1O($YE=%]335,@<&%C:V%G92`H26%N($5U<F4@/&EE=7)E0'!H<"YN970^
M*2X*6VUJ<ET@3F5T7TE-4U`@=VEL;"!N;W<@875T;VUA=&EC86QL>2!C<F5A
M=&4@=7-E<B=S(&1E9F%U;'0@861D<F5S<V)O;VL@:68*("`@("`@:70@9&]E
M<R!N;W0@86QR96%D>2!E>&ES="!I;G-T96%D(&]F(&IU<W0@8V]M<&QA:6YI
M;F<@86)O=70@:70N"EMC:FA=($%D9"!S96QE8W0@86QL+"!N;VYE+"!A;F0@
M:6YV97)T(&]P=&EO;F%L;'D@=&\@2&]R9&5?1F]R;5]4>7!E7W-E=`H@("`@
M("!F:65L9',@*$1U8VL@/&1U8VM`;V)A;&$N;F5T/BDN"EMC:FA=(%!R969E
M<F5N8V5S(&]V97)V:65W(&ES(&YO=R!B=6EL="!W:71H(&$@9&5F:6YI=&EO
M;B!L:7-T("@\9&P^*2!S='EL960*("`@("`@=VET:"!#4U,N"EMJ86Y=($%D
M9"!S;W)T*"D@;65T:&]D('1O($AO<F1E7U1R964@8VQA<W,N"EMM9&I=($-H
M86YG92!A;GD@;W5T<'5T(&]F(#QB/B!A;F0@/&D^('1A9W,@=&\@/'-T<F]N
M9SX@86YD(#QE;3X@9F]R(&)E='1E<@H@("`@("!A8V-E<W-I8FEL:71Y('-U
M<'!O<G0N"EMJ;69=($%L;&]W($AO<F1E('1E;7!L871E<R!T;R!I;F-L=61E
M(&%P<&QI8V%T:6]N(&)L;V-K<RX*6VIA;ET@061D(&5X=&5N9&5D(&9O<F5C
M87-T<R!T;R!W96%T:&5R9&]T8V]M($)L;V-K("A2:6-K($5M97)Y"B`@("`@
M(#QR:6-K0&5M97)Y+FAO;65L:6YU>"YN970^*2X*6V-J:%T@06QL;W<@9F]R
M(&%R8FET<F%R>2!A='1R:6)U=&4@9FEL=&5R<R!W:&5N(&QI<W1I;F<@;W(@
M8V]U;G1I;F<@4VAA<F4*("`@("`@;V)J96-T<R`H1'5C:R`\9'5C:T!O8F%L
M82YN970^*2X*6V-J:%T@061D($1A=&%4<F5E.CIG9713;W)T9614<F5E*"D@
M*$1U8VL@/&1U8VM`;V)A;&$N;F5T/BDN"EMM:G)=(%-U<'!O<G0@9F]R(&EM
M=&5S="!A=71H96YT:6-A=&EO;B!A9&1E9"!T;R!0<F5F<U]I;7-P+@I;8VIH
M72!!9&0@4D535"!24$,@9')I=F5R("AS<G)A9F%`=7-C+F5S+"!"=6<@(S$U
M,#`I+@I;8VIH72!!9&0@<W5P<&]R="!F;W(@9F5T8VAI;F<@=&AE(&AI9VAE
M<W0@86YD(&QO=V5S="!I9',@:6X@86YY($1A=&%4<F5E"B`@("`@(&=R;W5P
M("A$=6-K(#QD=6-K0&]B86QA+FYE=#XI+@I;8VIH72!!9&0@1&%T851R964Z
M.G-O<G1">4%T=')I8G5T97,H*2!F;W(@<V]R=&EN9R!$871A5')E94]B:F5C
M=',@8F%S960@;VX*("`@("`@=&AE:7(@871T<FEB=71E<R`H1'5C:R`\9'5C
M:T!O8F%L82YN970^*2X*6VUJ<ET@26YI=&EA;"!S=7!P;W)T(&%D9&5D('1O
M($YE=%])35-0(&9O<B!I;71E<W0@9')I=F5R("AP<F]V:61E<R!P97)S:7-T
M96YT"B`@("`@($E-4U`@8V]N;F5C=&EO;G,@=7-I;F<@0WER=7,@:6UT97-T
M('5T:6QI='DI+@I;:F%N72!!9&0@;6%P(&QI;FMS('1O(%5+(&%N9"!!=7-T
M<F%L:6%N(&%D9')E<W,@9FEE;&1S"B`@("`@("AT=7)B82YL:7-T0'-U8F]R
M8FET+F-O;2P@0G5G(",Q-#8Q*2X*6VUM<UT@1&5T96-T:6]N(&]F(")P:&ES
M:&EN9R(@=&%C=&EC<R!I;B!T:&4@2%1-3"!-24U%7U9I97=E<B`H5&]D9"!-
M97)R:71T"B`@("`@(#QT;65R<FET=$!E;6%I;"YA<FEZ;VYA+F5D=3XL($)U
M9R`C,30S-"DN"EMM;7-=(%1E>'1?1FQO=V5D('!A8VMA9V4@;F]W(&-O<G)E
M8W1L>2!H86YD;&5S(&UU;'1I8GET92!C:&%R86-T97)S+@I;;6US72!-86EN
M=&5N86YC92!C;VYF:7)M871I;VX@<&%G97,@;F]W(')E;F1E<F5D('9I82!(
M;W)D95]496UP;&%T92`H5FEL:75S"B`@("`@(%-U;7-K87,@/'9I;&EU<T!L
M;FLN;'0^*2X*6VIA;ET@06QL;W<@=&\@<W!E8VEF>2!C:&%R<V5T(&]F(&EM
M<&]R=&5D($-35B!F:6QE<RX*6VIA;ET@061D($9I;&5?0U-6('!A8VMA9V4N
M"EMJ86Y=(%-H;W<@87!P;&EC871I;VX@;F%M97,@:6X@<&5R;6ES<VEO;G,@
M861M:6YI<W1R871I;VXN"EMJ;69=($%L;&]W('1H92!A=71H(&)A8VME;F0@
M=&\@<F5Q=65S="!A('!A<W-W;W)D(&-H86YG92P@<W5P<&]R="!E>'!I<FEN
M9PH@("`@("!P87-S=V]R9"!I;B!T:&4@4U%,(&)A8VME;F0N"EMC:FA=(%-H
M;W<@;65N=2!C:&EL9')E;B!F;W(@979E<GD@87!P;&EC871I;VX@=VET:"!P
M<F5F97)E;F-E<R!U;F1E<B!/<'1I;VYS"B`@("`@(&EN('1H92!S:61E8F%R
M(&UE;G4@*$)U9R`C,3`U."DN"EMM;7-=($%L;&]W(&EN9&EV:61U86P@34E-
M15]6:65W97)S('1O(&]V97)R:61E('1H92!#;VYT96YT+41I<W!O<VET:6]N
M($U)344*("`@("`@<&%R86UE=&5R(&%N9"!F;W)C92!V:65W:6YG(&EN;&EN
M92X*"@HM+2TM+2TM"G8S+C`N,3$*+2TM+2TM+0H*6V-J:%T@4T5#55))5%DZ
M(%)E;6]V92!U;G5S960@:6UA9V4@<')O>'D@8V]D92!F<F]M(&1E<F5F97)R
M97(N"EMC:FA=(%-%0U522519.B!#;&]S92!84U,@<')O8FQE;7,@:6X@9&5R
M969E<G)E<B`H244@;VYL>2DL(&AE;'`@=FEE=V5R(&%N9`H@("`@("!P<F]B
M;&5M(')E<&]R=&EN9R!S8W)E96XN"@H*+2TM+2TM+0IV,RXP+C$P"BTM+2TM
M+2T*"EMC:FA=(%-%0U522519.B!&:7@@<F5M;W1E(&-O9&4@97AE8W5T:6]N
M('9U;&YE<F%B:6QI='D@9F]U;F0@8GD@2F%N(%-C:&YE:61E<BX*"@HM+2TM
M+2T*=C,N,"XY"BTM+2TM+0H*6V-J:%T@1FEX('-H;W=S=&]P<&5R(&)U9R!I
M;B!(;W)D95]&;W)M('-E;&5C="!F:65L9',@*$)U9R`C,S$R,RDN"@H*+2TM
M+2TM"G8S+C`N.`HM+2TM+2T*"EMC:FA=(%=H96X@9&5L971I;F<@86X@:61E
M;G1I='DL(&1O;B=T('-H;W<@=&AE(&1E;&5T960@:61E;G1I='D*("`@("`@
M:6X@=&AE(&1E9F%U;'0@:61E;G1I='D@<V5L96-T(&1R;W!D;W=N(&]N('1H
M92!N97AT('!A9V4@;&]A9"X*6V-J:%T@1FEX(&5S8V%P:6YG(&]F(&1A=&$@
M:6X@=&AE('!R969E<F5N8V5S('1E;7!L871E<RX*6V-J:%T@1FEX(&5S8V%P
M:6YG(&]F(&1A=&$@:6X@=&AE(&1A=&$@:6UP;W)T('1E;7!L871E<RX*6V-J
M:%T@1FEX(&]U='!U="!E<V-A<&EN9R!O9B!(;W)D95]&;W)M7U1Y<&5?8V5L
M;'!H;VYE(&EN(%5)7U9A<E)E;F1E<F5R7VAT;6PN"EMC:FA=(%-%0U522519
M.B!#;&]S92!S979E<F%L(%A34R!P<F]B;&5M<R!I;B!T:&4@<VAA<F4@961I
M="!W:6YD;W<N"EMJ86Y=($9I>"!W96%T:&5R+F-O;2!P;W)T86P@8FQO8VLN
M"@H*+2TM+2TM"G8S+C`N-PHM+2TM+2T*"EMJ86Y=(%-%0U522519.B!&:7@@
M6%-3('9U;&YE<F%B:6QI=&EE<R!I;B!G>FEP+W1A<B!A;F0@8W-S($U)344@
M=FEE=V5R<RX*6V-J:%T@061D(&UI<W-I;F<@0T]-34E4(&EN($UY4U%,(%-E
M<W-I;VY(86YD;&5R(&1R:79E<@H@("`@("`H9&=E:&Q`:6YV97)S92YC82P@
M0G5G(",R-S,Q*2X*"@HM+2TM+2T*=C,N,"XV"BTM+2TM+0H*6VIA;ET@4&%S
M<R!A;&P@55),('!A<F%M971E<G,@=VAE<F4@;&EN:VEN9R!E;6%I;"!A9&1R
M97-S97,@*%)E<75E<W0@(S$U,S`I+@I;:F%N72!3:&]W(%=O<F0@=FEE=V5R
M(&-O;G1E;G0@=VET:"!C;W)R96-T(&-H87)S970@*'-G<F]N9&EN0&-S8F8N
M<6,N8V$L"B`@("`@($)U9R`C,C<S-RDN"@H*+2TM+2TM+2TM+0IV,RXP+C8M
M4D,Q"BTM+2TM+2TM+2T*"EMC:FA=($9I>"!T<F%N<V%C=&EO;G,@86YD(&)I
M;F%R>2!D871A(&EN(%!O<W1G<F5344P@<V5S<VEO;B!H86YD;&5R"B`@("`@
M("AC8G-`8W1S+G5C;&$N961U+"!"=6<@(S(W-#DL(",R-S@Y*2X*6VIA;ET@
M1FEX('-I9&5B87(@;65N=2!L87EO=70@9F]R($]P97)A("A"=6<@(S(W,C(I
M+@I;8VIH72!!9&0@/'!R93X@=&\@<W5P<&]R=&5D(&AE;'`@=&%G<R`H=FEJ
M87DN;6%H<G)A0&5S+F5A<WEN970N;F5T+`H@("`@("!"=6<@(S(V,S,I+@I;
M8VIH72!&:7@@=F%L:61A=&EO;B!O;B!I<&%D9')E<W,@2&]R9&5?1F]R;2!F
M:65L9',@*$)U9R`C,C4X,RDN"EMC:FA=($%D9"!!=71H.CIG971!=71H1&]M
M86EN*"D@*$)U9R`C,C4W,RDN"EMM:G)=($%D9"!A8FEL:71Y('1O(&5N86)L
M92]D:7-A8FQE($E-4U`@9VQO8F%L;'D@=FEA(&-O;F9I9W5R871I;VX@<V5T
M=&EN9W,N"EMJ86Y=($9I>"!C86QE;F1A<B!P;W!U<"!W:71H(%-A9F%R:2!B
M<F]W<V5R<R`H="YZ96QL0&=M>"YD92P@0G5G(",R-#0X*2X*6V-J:%T@5VAE
M;B!U<VEN9R!#1TD@4$A0+"!30U))4%1?3D%-12!M87D@8V]N=&%I;B!T:&4@
M<&%T:"!T;R!T:&4@4$A0(&)I;F%R>0H@("`@("!I;G-T96%D(&]F('1H92!S
M8W)I<'0@8F5I;F<@<G5N.R!U<V4@4$A07U-%3$8@:6YS=&5A9"`H0G5G(",R
M-#`Q*2X*6VIA;ET@1FEX('-H87)I;F<@=VET:"!G<F]U<',@:68@=7-I;F<@
M9W)O=7`@:&]O:W,@*$)U9R`C,C(Y,BDN"@H*+2TM+2TM"G8S+C`N-0HM+2TM
M+2T*"EMM;7-=($9I>"!61E,G<R!A=71O8W)E871E4&%T:"@I(&9O<B!D:7)E
M8W1O<GD@<&%T:',@8V]N=&%I;FEN9R!T:&4@<F]O=`H@("`@("!D:7)E8W1O
M<GDN"EMJ86Y=($9I>"!C>7)S<6P@875T:&5N=&EC871I;VX@9')I=F5R('=I
M=&@@=6YI>&AI97)A<F-H>7-E<"!E;F%B;&5D"B`@("`@("AS9W)O;F1I;D!C
M<V)F+G%C+F-A+"!"=6<@(S(S-C<I+@I;;6US72!&:7@@;F5S=&5D($E-05`@
M04Y$('-E87)C:&5S+@I;;6US72!);B!S<6P@5D93(&1R:79E<BP@86QL;W<@
M=&AE('5S92!O9B`G+R<@870@=&AE(&)E9VEN;FEN9R!O9B!A('!A=&@@=&\*
M("`@("`@:6YD:6-A=&4@=&AE(&)A<V4@9&ER96-T;W)Y+@I;:F%N72!&:7@@
M<F5T=7)N:6YG('1O(&QA<W0@<&%G92!A9G1E<B!S96YD:6YG('!R;V)L96T@
M<F5P;W)T("A"=6<@(S(S-3`I+@I;;6US72!&:7@@82!B=6<@=&AA="!C875S
M960@:&]O:R!C;V1E('1O(&)E(')U;B!U;FYE8V5S<V%R:6QY(&%F=&5R(&$@
M=7-E<@H@("`@("!I<R!A;')E861Y(&QO9V=E9"!I;BX*"@HM+2TM+2TM+2TM
M"G8S+C`N-2U20S(*+2TM+2TM+2TM+0H*6V-J:%T@1FEX(&$@9F%R+7)E86-H
M:6YG($1A=&%4<F5E(&)U9R!I;B!L;V%D:6YG('!A<F5N="!I9',@*$)U9R`C
M,C(P,RDN"@H*+2TM+2TM+2TM+0IV,RXP+C4M4D,Q"BTM+2TM+2TM+2T*"EMJ
M86Y=($%D9"!";W-N:6%N('1R86YS;&%T:6]N("A6961R86X@3&IU8F]V:6,@
M/'9L:G5B;W9I8T!S;6%R=&YE="YB83XI+@I;8VIH72!,970@2&]R9&5?5')E
M92!H86YD;&4@86QL(&EN9&5N="!C86QC=6QA=&EO;B!B87-E9"!O;B!P87)E
M;G0O8VAI;&0*("`@("`@<F5L871I;VYS:&EP<R`H0G5G(",R,3DX*2X*6V-J
M:%T@061D(&EN:71I86P@3$1!4"!397-S:6]N2&%N9&QE<B!D<FEV97(N"EMC
M:FA=(%5S92!R;W<M;&5V96P@;&]C:VEN9R!O<B!T<F%N<V%C=&EO;G,@=VAE
M<F4@<&]S<VEB;&4@=&\@879O:60*("`@("`@<V5S<VEO;B!C;W)R=7!T:6]N
M(&EN(%-E<W-I;VY(86YD;&5R("A"=6<@(S$U.#`I+@I;;6US72!!9&0@=&AE
M(&UE;6-A8VAE9"!397-S:6]N2&%N9&QE<CHZ(&1R:79E<B`H4F]N9RU%;B!&
M86X@/')A9F%N0&-S:64N;W)G/BDN"EMM;7-=($9I>"!V97)I9FEC871I;VX@
M;V8@34E-12!S=')I;F=S('=I=&@@97-C87!E9"!Q=6]T97,@*$)U9R`C,C$V
M."DN"EMJ86Y=($9I>"!G96YE<F%T:6]N(&]F(&9R964@<&5R:6]D<R!I;B!F
M<F5E+V)U<WD@8V]D92!W:71H(&]V97)L87!P:6YG(&5V96YT<RX*6VIA;ET@
M1&]N)W0@<VAO=R!/<'1I;VYS(&)U='1O;B!I;B!P<F]B;&5M(')E<&]R=&EN
M9R!P86=E+@I;:F%N72!!9&0@571I;#HZ<F5A;%!A=&@H*2!M971H;V0N"EMM
M87-=($EN8VQU9&4@=F5R<VEO;B!N=6UB97)S(&9O<B!A<'!L:6-A=&EO;G,@
M;VX@061M:6X@4V5T=7`@<V-R965N+B`H0G5G"B`@("`@(",Q-#(P*0I;;6%S
M72!#:&%N9V4@24U!4"!!=71H(&1R:79E<B!T;R!U<V4@:6UA<"]N;W1L<R!B
M>2!D969A=6QT(&EN(&YO;BU$4TX@;6]D92!T;PH@("`@("!M871C:"!$4TX@
M;6]D92X*6VUA<UT@061D('1L<R!A;F0@<V5L9BUS:6=N960@8V5R=&EF:6-A
M=&4@8V]N9FEG=7)A=&EO;B!O<'1I;VYS('1O($E-05`@075T:`H@("`@("!D
M<FEV97(N("A"=6<@(S$S-3<I"EMC:FA=(%)E8V]G;FEZ92!/<&5R82`X*R!A
M<R!P<F]V:61I;F<@861V86YC960@9F5A='5R97,@*$)U9R`C,C`V-BDN"EMC
M:FA=($9I>"!R96%D:6YG(&]F(&)I;F%R>2!F:6QE<R!O;B!7:6YD;W=S(&EN
M(%9#7W-V;B`H0G5G(",R,#,V*2X*6VUA<UT@1FEX(%-13"`G3$E+12<@8V%S
M92UI;G-E;G-I=&EV92!C;VUP87)I<V]N+B`H0G5G(",R,#,P*0I;:F%N72!!
M;&QO=R!C:&%R<V5T(&%W87)E($E-05`@<V5A<F-H97,N"EMJ86Y=($9I>"!'
M;V]G;&4@<V5A<F-H(&)L;V-K(&9O<B!N;VXM87-C:6D@8VAA<F%C=&5R<R`H
M0G5G(",Q,S(Y*2X*6VIA;ET@061D('%U:6-K+6EN<W1A;&P@:6YS=')U8W1I
M;VYS+@I;:F%N72!);7!R;W9E('!E<F9O<FUA;F-E(&]F('-E=F5R86P@9G)A
M;65W;W)K('!A8VMA9V5S+@I;;6US72!&:7@@34E-15]#;VYT96YT<SHZ(&-A
M8VAI;F<@:6X@4$A0(#4@*$)U9R`C,30Q,"DN"EMJ86Y=($9I>"!60R!35DX@
M8F%C:V5N9"!T;R!S=7!P;W)T('5S97(@;F%M97,@=VET:"!S<&%C97,*("`@
M("`@*'-H:6UM86YN:6YG0&=M86EL+F-O;2P@0G5G(",Q.3$Y*2X*6V-J:%T@
M17-C87!E($A434P@:6X@:61E;G1I='D@;F%M97,@*$)U9R`C,3DQ,"DN"EMM
M87-=(%5S92!U<&1A=&5D(%!O<W1G<F5344P@9G5N8W1I;VX@;F%M97,N"EMB
M96Y=(%5P9&%T92!A<'!L:6-A=&EO;B!L:7-T(&EN(&AO<F1E)W,@3$1!4"!S
M8VAE;6$*6V-J:%T@16YF;W)C92!M87AL96YG=&@@<F5S=')I8W1I;VYS(&EN
M($AO<F1E7T9O<FT@=F%L:61A=&EO;B`H0G5G(",Q.#DU*2X*6VIA;ET@1&ES
M86)L92!W96%T:&5R+F-O;2!";&]C:R!I9B!N;W0@8V]N9FEG=7)E9"X*6V-J
M:%T@26YC;'5D92!S;W5R8V5R;V]T(&EN(%9#(&-A8VAE(&ME>7,@*$)U9R`C
M,3<X,RDN"EMJ86Y=($%D9"!344P@<V-R:7!T(&%N9"!I;G-T<G5C=&EO;G,@
M9F]R($U31$4@9&%T86)A<V5S("A"=6=S(",Q.#8R+"`C,3@W,"P*("`@("`@
M:F5F9D!I;6%G92US<F,N8V]M*2X*6VIA;ET@06QL;W<@<&]R=&%L(&)L;V-K
M<R!T;R!B92!L87)G97(@=&AA;B!T=V\@8V]L=6UN+W)O=W,@*$)U9W,@(S$Q
M.#DL(#$V,S(I+@I;:F%N72!!9&0@4TU44"!A=71H96YT:6-A=&EO;B!T;R!P
M<F]B;&5M(')E<&]R=&EN9R`H0G5G(",Q,3(X*2X*6VIA;ET@4W5P<&]R="!H
M96QP(&9I;&5S(&EN(&%D;6EN(&1I<F5C=&]R>2!W:71H('1R86YS;&%T:6]N
M<RYP:'`@*$)U9R`C,3,T-"DN"EMJ86Y=($9I>&5D(%-13"!B:6YD:6YG(&9O
M<B!/1$)#(&%N9"!-4U-13"!D<FEV97)S("A"=6<@(S$X,38I+@I;:F%N72!!
M9&0@8V]N9FEG=7)A=&EO;B!O<'1I;VX@=&\@<V5T(&QO8V%T:6]N(&]F($U)
M344@;6%G:6,@9&%T86)A<V4N"EMM;7-=($UA:V4@<W5R92!H96%D97)S(&EN
M(&$@34E-15]087)T(&%R92!E;F-O9&5D('=I=&@@=&AE('-A;64@8VAA<F%C
M=&5R"B`@("`@('-E="!U<V5D(&EN('1H870@34E-15]087)T("A"=6<@(S$U
M.3$I+@I;;6US72!!9&0@3&ES="U(96%D97)S(&QI<W1E9"!I;B!21D,@,C,V
M.2!T;R!T:&4@;&ES="!O9B!-24U%($AE861E<G,@=&AA=`H@("`@("!C86X@
M;VYL>2!A<'!E87(@;VYC92!I;B!A('-I;F=L92!H96%D97(@*$)U9R`C,3<V
M-BDN"EMC:FA=($9I>"!T>7!O(&EN('!A<G-I;F<@;V8@1E)%14)54UD@9&%T
M82`H0G5G(",Q-3DP*2X*6VIA;ET@4W5P<&]R="!344QI=&4@86YD($]R86-L
M92!I;B!A;&P@4U%,(&)A8VME;F0@8V]N9FEG=7)A=&EO;G,N"EMC:FA=(%5S
M92!B:6YD('9A<FEA8FQE<R!I;B!T:&4@075T:"P@5D93+"!A;F0@4V5S<VEO
M;DAA;F1L97(@4U%,(&1R:79E<G,L"B`@("`@(&%N9"!I;B!S8W)I<'1S+W)E
M;6]V95]P<F5F<RYP:'`@*'-E;'-K>4!C;VQU;6)I82YE9'4L($)U9W,@(S$V
M-C4L"B`@("`@(",Q-C8V+"`C,38V-RP@(S$V-C@L(",Q-C<W*2X*6V-J:%T@
M<V5S<VEO;E]S971?8V]O:VEE7W!A<F%M<R@I(&5X<&5C=',@82!R96QA=&EV
M92!T:6UE;W5T.R!S971C;V]K:64@=V%N=',*("`@("`@86)S;VQU=&4N($=O
M(&)A8VL@=&\@82!C;VYF:6=I;G1E9V5R(&9O<B`D8V]N9ELG<V5S<VEO;B==
M6R=T:6UE;W5T)UT@86YD"B`@("`@(&%D9"!T:6UE*"D@=&\@=&AA="!V86QU
M92!I;B!S971C;V]K:64H*2!C86QL<R`H0G5G<R`C,3,P,BP@(S$V-3@I+@H@
M("`@("!42$E3($U!62!"4D5!2R!#3TY&24=54D%424].4R!3150@5$\@55-%
M(%!(4"!#3T1%+B!-04M%(%-54D4@5$\@55!$051%"B`@("`@(%E/55(@)&-O
M;F9;)W-E<W-I;VXG75LG=&EM96]U="==(%-%5%1)3D<@049415(@55!'4D%$
M24Y'+@I;8VIH72!5<V4@8FEN9"!V87)I86)L97,@:6X@=&AE(%!R969S(&%N
M9"!4;VME;B!344P@9')I=F5R<PH@("`@("`H<V5L<VMY0&-O;'5M8FEA+F5D
M=2P@0G5G<R`C,38U,BP@(S$V-3,I+@I;;6US72!0<G5N92!E>'!A;F1E9"!F
M;VQD97)S('1H870@;F\@;&]N9V5R(&5X:7-T(&EN($E-05!?5')E92`H0G5G
M(",Q-3$W*2X*6V-J:%T@1&]N)W0@=')Y('1O(&-O;7!R97-S(&]U='!U="!I
M9B!:4%,@8V]M<')E<W-I;VX@:7,@;VX@*$)U9R`C,38R-BDN"EMC:FA=($EF
M(&%N(&%P<"!O;FQY(&AA<R!O;F4@<')E9D=R;W5P+"!A;'=A>7,@<VAO=R!T
M:&%T('!R969'<F]U<"!I;G-T96%D"B`@("`@(&]F('-H;W=I;F<@86X@;W9E
M<G9I97<@<V-R965N('=I=&@@;VYL>2!O;F4@96YT<GDN"@H*+2TM+2TM"G8S
M+C`N-`HM+2TM+2T*"EMC:FA=(%5S92!F=6QL>2!Q=6%L:69I960@55),<R!I
M;B!T:&4@06YS96Q);6%G92!(5$U,07)E82!P;'5G:6X@*$)U9R`C,3(U.2DN
M"EMC:FA=(%-%0U522519.B!#;&]S92!84U,@=VAE;B!S971T:6YG('1H92!P
M87)E;G0@9G)A;64G<R!P86=E('1I=&QE(&)Y"B`@("`@(&IA=F%S8W)I<'0N
M"EMB;&-=($%D9"!0;W-T9W)E4U%,('5P9W)A9&4@<V-R:7!T("A"<F%D(%=I
M='1E(#QB<F%D0&1I<W1A;G1H87IE+F-O;2D*6V-J:%T@079O:60@9&EV:7-I
M;VX@8GD@>F5R;R!I9B!A;&P@<')E9F5R96YC97,@87)E(&QO8VME9"`H0G5G
M(",Q-C(W*2X*6VIA;ET@1FEX('-I9&5B87(@<F5F<F5S:&EN9R!W:71H($]P
M97)A+@H*"BTM+2TM+2TM+2T*=C,N,"XT+5)#,@HM+2TM+2TM+2TM"@I;:F%N
M72!);7!R;W9E(")L;V=I;B(@875T:&5N=&EC871I;VX@9')I=F5R("A"=6<@
M(S$U-S$I+@I;:F%N72!3:&]W(&1A=&%B87-E('-P96-I9FEC(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<R!I;B!G;&]B86P@4U%,(&-O;F9I9W5R871I;VX*("`@
M("`@=&]O+@I;:F%N72!&:7@@;&5F="!M96YU(&]V97)F;&]W(&EN($E%(&%N
M9"!3869A<FD@*$)U9R`C,34R-BDN"EMJ86Y=($9I>"!A=71O8W)E871I;F<@
M;V8@9&ER96-T;W)I97,@86YD('5P9&%T:6YG(&]F(&5X:7-T:6YG(&9I;&5S
M(&EN('1H90H@("`@("!S<6Q?9FEL92!61E,@9')I=F5R("AE9&1I94!O;65G
M87=A<F4N8V]M+"!"=6=S(",Q-34R(&%N9"`C,34U,RDN"EMJ86Y=($UA:V4@
M=W)A<'!I;F<@;65N=7,@=FES:6)L92!W:71H($=E8VMO(#$N-"!B<F]W<V5R
M<R`H92YG+B!.971S8V%P92`W+C$I+@I;:F%N72!5<V4@4U%,(&)I;F1I;F<@
M9F]R('-O;64@1&%T851R964@;W!E<F%T:6]N<RX*6VIA;ET@1FEX($1A=&%4
M<F5E(%-13"!S=7!P;W)T(&9O<B!/<F%C;&4N"EMJ86Y=($9I>"!344P@8V]N
M9FEG=7)A=&EO;B!F;W(@3W)A8VQE+@I;;6US72!-86ME('-U<F4@5D93(&=A
M<F)A9V4@8V]L;&5C=&EO;B!I<R!D;VYE(')E8W5R<VEV96QY+@H*"BTM+2TM
M+2TM+2T*=C,N,"XT+5)#,0HM+2TM+2TM+2TM"@I;:F%N72!!9&0@2&]R9&5?
M5')E95]S96QE8W0@8VQA<W,@*$)E;B!#:&%V970@/&)E;D!H;W)D92YO<F<^
M*2X*6VUJ<ET@1FEX($YE=%])35-0('1O('!R;W!E<FQY(&AA;F1L92!M=6QT
M:7!L92!L:6YE<R!I;B!A9&1R97-S8F]O:R!F:65L9',N"EMJ86Y=($9I>"!-
M24U%(&1E8V]D:6YG(&]F('-T<FEN9W,@=&AA="!C;VYT86EN("(E(B!I;B!M
M=6QT:6)Y=&4@<V5Q=65N8V5S"B`@("`@("A"=6<@(S$T,C,I+@I;8VIH72!#
M;VYT<F]L('-P86-E('5N9&5R('1H92!M96YU(&)A<B!W:71H(&$@=&AE;65A
M8FQE('-T>6QE("A"=6<@(S$T,C$I+@I;8VIH72!&:7@@2&]R9&5?5')E92!W
M:71H('1H92!M=6QT:6QI;F4@;W!T:6]N('-O('1H870@<F]W('-T>6QE<R!E
M>'1E;F0@;W9E<@H@("`@("!T:&4@=VAO;&4@:&5I9VAT(&]F('1H92!R;W<N
M"EMC:FA=($EF(&-O;F9I9W5R871I;VX@9FEL97,@=&AA="!H879E(&$@+F1I
M<W0@=F5R<VEO;B!A<F4@;6ES<VEN9RP*("`@("`@2&]R9&5?5&5S=#HZ8V]N
M9FEG1FEL97--:7-S:6YG*"D@=VEL;"!C;W!Y('1H92!D969A=6QT<R!O=F5R
M(&EF($AO<F1E"B`@("`@(&-A;B!W<FET92!T;R!T:&4@9FEL97-Y<W1E;2`H
M0G5G(",Q,#$U*2X*6V-J:%T@1FEX($%N<V5L26UA9V4@2%1-3$%R96$@<&QU
M9VEN("A"=6<@(S$T-S`I+@I;8VIH72!*=7-T(')E=')I979E('5I9"!W:&5N
M(&QI<W1I;F<@=7-E<G,@:6X@=&AE($Q$05`@075T:&5N=&EC871I;VX@9')I
M=F5R+@I;8VIH72!!9&0@8VAO<F%0<F5F<R!T;R!T:&4@:&]R9&5097)S;VX@
M3$1!4"!S8VAE;6$@*$)U9R`C,30U,BDN"EMC:FA=("=R;V]T9&XG(&ES(&YO
M="!R97%U:7)E9"!F;W(@3$1!4"!P<F5F97)E;F-E<R`H0G5G(",Q-#4S*2X*
M6VUM<UT@1FEX($E-05`@=&AR96%D(&-R96%T:6]N('=H96X@=&AE(&)A<V4@
M;&5V96P@8V]N=&%I;G,@;6]R92!T:&%N(&]N90H@("`@("!M97-S86=E+@I;
M:F%N72!!;&QO=R!V0V%R9',@=VET:"!L;W=E<F-A<V4@9FEE;&0@9&5S8W)I
M<'1O<G,N"EMJ86Y=($EM<')O=F4@=&%R+V=Z:7`@34E-12!V:65W97(@=&\@
M8F5T=&5R('-H;W<@=6YZ:7!P960@8V]N=&5N="X*6VUJ<ET@0F5T=&5R(&5R
M<F]R(&AA;F1L:6YG(&EN($YE=%])35-0+@I;;6US72!3<&5E9"!I;7!R;W9E
M;65N=',@86YD('-O<G1I;F<@9FEX97,@9F]R($E-05!?5')E92X*6VUM<UT@
M24U!4%]4<F5E(&YO=R!H86YD;&5S(&YO;BUU<'!E<F-A<V5D("=)3D)/6"<@
M<W1R:6YG<R!R971U<FYE9"!F<F]M('1H90H@("`@("!M86EL('-E<G9E<B`H
M0G5G(",Q.3DI+@I;;6US72!296)U:6QD(&-E<G1A:6X@:6YT97)N86P@34E-
M15]087)T(&1A=&$@=VAE;B!R971R:65V:6YG(&9R;VT@82!C86-H92X*6VIA
M;ET@4VAO=R!D871A8F%S92!S<&5C:69I8R!C;VYN96-T:6]N('!A<F%M971E
M<G,@:6X@8V]N9FEG=7)A=&EO;B!S8W)E96XN"EMM;7-=($E-05!?5')E92!N
M;W<@8V]R<F5C=&QY('5P9&%T960@=VAE;B!S=6)S8W)I8FEN9R]U;G-U8G-C
M<FEB:6YG(&9R;VT@80H@("`@("!M86EL8F]X("A"=6<@(S$Q,3$I+@I;;6US
M72!-86ME($E-05`@<V5A<F-H97,@;V8@;F]N+2)S=&%N9&%R9"(@:&5A9&5R
M<R!W;W)K('=I=&@@=&AE($Y/5"!D:7)E8W1I=F4*("`@("`@*$)U9R`C,3,V
M."DN"EMJ86Y=($9I>&5D(&1O=6)L92!L:6YE(&YU;6)E<G,@:6X@4V]U<F-E
M+6AI9VAL:6=H="!-24U%('9I97=E<B`H0G5G(",Q,S@S*2X*6VUM<UT@1FEX
M($E-05!?5&AR96%D('=H96X@9&5A;&EN9R!W:71H('1H92!F:7)S="!M97-S
M86=E(&EN('1H92!M86EL8F]X"B`@("`@("A"=6<@(S$R-3<I+@I;8VIH72!&
M:7@@;65N=2!H96EG:'1S(&EN(%-A9F%R:2X*6VIA;ET@0V%T8V@@97)R;W)S
M(&9R;VT@8V]N9FEG=7)A=&EO;B!F:6QE<R!T;R!A=F]I9"!B;&%N:R!P86=E
M<RX*6VIA;ET@4W5P<&]R="!M:6UE7VUA9VEC(&5X=&5N<VEO;B!A9V%I;B!I
M9B!F:6QE:6YF;R!I<R!N;W0@<')E<V5N="X*"@HM+2TM+2T*=C,N,"XS"BTM
M+2TM+0H*6VUJ<ET@3F5T7TE-4U`@;F]W(&-O<G)E8W1L>2!H86YD;&5S(&%D
M9')E<W-B;V]K(&YA;65S(&-O;G1A:6YI;F<@<W!A8V5S"B`@("`@("A"=6<@
M(S$R.#8I+@I;8VIH72!);7!L96UE;G0@8VQE87(H*2!I;B!T:&4@3$1!4"!P
M<F5F<R!D<FEV97(@*$)U9R`C,3,S-2DN"EMC:FA=($1O;B=T(&QI<W0@=6YI
M;G-T86QL960@87!P;&EC871I;VYS(&%S(&EN:71I86Q?87!P;&EC871I;VX@
M;W!T:6]N<PH@("`@("`H0G5G(",Q,S(T*2X*6VIA;ET@1FEX('!O<W1A=71H
M96YT:6-A=&4@:&]O:RP@;F]T(&-O;7!L971E;'D@9&5N>6EN9R!A8V-E<W,@
M869T97(@82!F86EL960*("`@("`@;&]G:6X@*$)U9R`C,3,R,"DN"EMJ86Y=
M($-H96-K8F]X97,@:6X@<&]R=&%L(&)L;V-K('-E='5P(&9O<FUS(&%R92!C
M;W)R96-T;'D@8VAE8VME9"!N;W<*("`@("`@*$)U9R`C,3(T-RDN"EMM;7-=
M($%L;&]W($E-05`@<V5A<F-H97,@=&\@=V]R:R!O;B!H96%D97)S('=I=&@@
M;75L=&EP;&4@96YT<FEE<PH@("`@("`H:V]L8D!B:71L86(N:'4I("A"=6<@
M(S$S,S`I+@I;;6US72!#;W)R96-T;'D@<V]R="!)3D)/6"!S=6)F;VQD97)S
M(&EN($E-05!?4V]R="`H0G5G(",Q,CDQ*2X*6V-J:%T@5'5R;B!O9F8@1F]R
M;2!4;VME;G,@:6X@=&AE(&-O;F9I9W5R871I;VX@:6YT97)F86-E+@I;:F%N
M72!3;W)T('5S97(@86YD(&=R;W5P(&QI<W1S(&EN('!E<FUI<W-I;VYS(&EN
M=&5R9F%C92`H0G5G(",Q,S`U*2X*6VIA;ET@06QL;W<@=&\@96YT97(@4$A0
M(&-O9&4@:6X@=&AE('-E<W-I;VX@=&EM96]U="!C;VYF:6=U<F%T:6]N("A"
M=6<@(S$S,#(I+@H*"BTM+2TM+2TM+2T*=C,N,"XS+5)#,0HM+2TM+2TM+2TM
M"@I;;6US72!&:7@@8G5G(&EN(%1E>'1?1FQO=V5D('=H97)E('5N<75O=&5D
M(&QI;F5S(&-O=6QD(&YO="!B92!F;&]W960N"EMC:FA=($9I>"!L;V=I8R!P
M<F]B;&5M<R!W:71H('1H92!->5-13"!A;F0@3T-)."!S97-S:6]N(&AA;F1L
M97)S('1H870*("`@("`@<')E=F5N=&5D('1H96T@9G)O;2!H86YD;&EN9R!R
M97-T87)T:6YG(&$@<V5S<VEO;B!C;&5A;FQY("A"=6<@(S$P.3<I+@I;8VIH
M72!&:7@@<&5R<VES=&5N8V4@;V8@)&-O;F9;)VUA:6QE<B==6R=P87)A;7,G
M75LG875T:"==(&EN('1H92!3971U<"!520H@("`@("`H0G5G(",Q,C@W*2X*
M6VIA;ET@26UP<F]V92!P97)F;W)M86YC92!O9B!$871A5')E92!O<&5R871I
M;VYS(&QI:V4@<F5A9&EN9R!E;6%I;"!M97-S86=E"B`@("`@(&AI<W1O<FEE
M<RX*6VIA;ET@3&]G('-U8V-E<W-F=6P@;&]G:6YS(&%N9"!L;V=O=71S('=I
M=&@@=&AE($Y/5$E#12!L979E;"`H5FEL:75S(%-U;7-K87,*("`@("`@/'9I
M;&EU<T!L;FLN;'0^*2X*6V-J:%T@16YC;V1E($A434P@96YT:71I97,@:6X@
M2&]R9&5?1F]R;5]4>7!E7VQO;F=T97AT(&1I<W!L87D@*$)U9R`C,3(V-RDN
M"EMM;7-=($9I>"!S97-S:6]N(&AA;F1L:6YG('1O(&5N<W5R92!V87)I86)L
M97,@87)E('!E<G-I<W1E;G0@86-R;W-S(&9U;F-T:6]N"B`@("`@(&-A;&QS
M("A'87)Y(%=I;F1H86T@/'=I;F1H86UG0&5M86EL+F%R:7IO;F$N961U/BDN
M"EMM;7-=($EM<')O=F5M96YT<R!T;R!796)#4%`@34E-15]6:65W97(@<F5N
M9&5R960@;W5T<'5T+@I;;6US72!-;W)E(&9I>&5S(&9O<B!54DQS('=I=&@@
M)R9A;7`G('=H96X@<&%S<VEN9R!T:')O=6=H('1H92!S86YI=&EZ97(N"EMJ
M86Y=($UA:V4@=W)A<'!I;F<@;65N=7,@;&]O:VEN9R!N:6-E<B!I;B!'96-K
M;R!A;F0@2TA434P@8F%S960@8G)O=W-E<G,N"EMJ86Y=($9I>"!-24U%('9I
M97=E<B!F;W(@9WII<"!F:6QE<R!T:&%T(&1O;B=T(&-O;G1A:6X@=&%R(&9I
M;&5S+@I;8VIH72!&:7@@=FES:6)I;&ET>2!O9B`\82`^('1A9W,@:6YS:61E
M('-M86QL:&5A9&5R(&)L;V-K<R!F;W(@=&AE($-O<FYF;&]W97(*("`@("`@
M=&AE;64@*$)U9R`C,3(P-BDN"EMC:FA=($1O(&YO="!C86-H92!J879A<V-R
M:7!T('-E<G9E9"!V:6$@<V5R=FEC97,O:F%V87-C<FEP="YP:'`@*$)U9R`C
M,3$T,"DN"EMC:FA=($9I>"!M86YA9V5M96YT(&]F(&-A=&5G;W)I97,@=&AA
M="!C;VYT86EN('%U;W1E<R`H0G5G(",Q,C`R*2X*6V-J:%T@2&%N9&QE(&%D
M9')E<W-E<R!T:&%T(&%R92!A;')E861Y('-U<G)O=6YD960@8GD@<75O=&5S
M(&EN"B`@("`@($U)344Z.E]R9F,X,C)%;F-O9&4H*2`H0G5G(",Q,30S*2X*
M6V-J:%T@1FEX(%9#7W-V;B=S(&AA;F1L:6YG(&]F(&1I<F5C=&]R>2!N86UE
M<R!W:71H('-P86-E<R`H0G5G(",Q,3(S*2X*6V-J:%T@1FEX(&-A8VAI;F<@
M;&]G:6,@=&AA="!W87,@8V%U<VEN9R!60R!T;R!N;W0@<')O<&5R;'D@<F5F
M<F5S:"!O8FIE8W1S(&EN"B`@("`@(&$@=&EM96QY(&UA;FYE<BX*6VIA;ET@
M06QL;W<@=&\@<V5T(&9I>&5D('1A8FQE(&-E;&P@=VED=&AS(&EN(%=94TE7
M64<@961I=&]R+@H*"BTM+2TM+0IV,RXP+C(*+2TM+2TM"@I;8VIH72!-86ME
M('-U<F4@;F]T('1O('1H<F]W(&5R<F]R<R!W:&5N(&)A9"!E;6%I;',@87)E
M('-U<'!L:65D(&EN"B`@("`@('-E<G9I8V5S+W!R;V)L96TN<&AP("A"=6<@
M(S$P-S`I+@I;:F%N72!&:7@@=W)O;F<@8VAA<G-E="!O9B!R969R97-H960@
M;65N=2!F<F%M92!I9B!N;W0@=7-I;F<@551&+3@@*$)U9W,*("`@("`@(S$P
M-3(L(",Q,#4U*2X*6VIA;ET@1FEX(&QE9G0@;65N=2!T<F5E(&-O;&QA<'-I
M;F<@869T97(@96%C:"!R969R97-H("A"=6<@(S$P-S(I+@I;:F%N72!&:7@@
M<VED96)A<B!B96EN9R!L;V%D960@='=I8V4@:68@;F]T('5S:6YG(&-O;VMI
M97,@*$)U9R`C,3`W-BDN"@H*+2TM+2TM"G8S+C`N,0HM+2TM+2T*"EMJ86Y=
M(%1E<W0@9F]R('-E<W-I;VXN875T;U]S=&%R="X*6VUM<UT@1FEX('!A<G-I
M;F<@;V8@:&5A9&5R('=I=&@@=6YD:7-C;&]S960M<F5C:7!I96YT<R`H0G5G
M(",Q,#4W*2X*6V-J:%T@061D(&$@8G)O=W-E<B!Q=6ER:R!F;W(@8G)O=W-E
M<G,@=&AA="!D;VXG="!S=7!P;W)T(&]V97)F;&]W.FAI9&1E;B!I;@H@("`@
M("!T86)L92!C96QL<R`H2TA434PI+@I;:F%N72!&:7@@87!P;&EC871I;VX@
M;&EN:W,@:68@;F]T('5S:6YG(&-O;VMI97,@*$)U9R`C,3`R.2DN"EMM;7-=
M($9I>"!D:7-A8FQI;F<@;V8@;6%I;G1E;F%N8V4@8V]N9FER;6%T:6]N<R`H
M0G5G(",Q,#(W*2X*6V-J:%T@1FEX(&%L:6=N;65N="!O9B!(96QP('=I;F1O
M=R!H96%D97(@:6X@35-)12`H0G5G(",Q,#(S*2X*6V-J:%T@1FEX('1H92!(
M;W)D95]";&]C:R!G<F%P:&EC<R!T;R!B92!I;F1E>&5D+"!N;W0@9W)A>7-C
M86QE("A"=6<@(S$P-3$I+@I;8VIH72!314-54DE463H@0VQO<V4@<V5V97)A
M;"!84U,@=G5L;F5R86)I;&ET:65S+@I;;6US72!-86ME('-U<F4@97AT97)N
M86P@55),)W,@=V]R:R!C;W)R96-T;'D@=VAE;B!T:&4@55),(&-O;G1A:6YS
M("<F86UP)R!A<PH@("`@("!T:&4@9&5L:6UI=&5R+@I;8VIH72!&:7@@:6YF
M:6YI=&4@;&]O<"!W:71H($%U=&A?87!P;&EC871I;VX@9')I=F5R("A"=6<@
M(S$P,#0I+@I;8VIH72!.979E<B!S970@86X@96UP='D@2&]R9&5?5')E92!C
M;V]K:64@*$)U9R`C,3`R,BDN"EMM;7-=($9I>"!D:7-P;&%Y:6YG(&]F(&9O
M;&1E<G,@:6X@24U!4%]4<F5E.CH@9F]R($E-05`@<V5R=F5R<R!T:&%T(&1O
M;B=T('5S90H@("`@("`G24Y"3U@G(&%S('1H96ER(&1E;&EM:71E<B`H0G5G
M(",Q,#$T*2X*6V-J:%T@2$]21$5?345.55]-05-+7TY/3D4@;F]W(')E86QL
M>2!M96%N<R!O;FQY(&5X<&QI8VET;'D@861D960@;65N=2!I=&5M<PH@("`@
M("!A<F4@9&ES<&QA>65D+@I;8VIH72!)9VYO<F4@2#,@:6X@=F5R<VEO;B!C
M;VUP87)I<V]N<R`H0G5G(",Q,#$W*2X*6V-J:%T@1&%T851R965?;G5L;"!N
M;W<@<W1U8G,@;W5T('1H92!F=6QL($1A=&%4<F5E($%022!T;R!A=F]I9"!F
M871A;"!E<G)O<G,*("`@("`@=VAE;B!N;W0@=7-I;F<@82!P97)M86YE;G0@
M8F%C:V5N9"X*6VIA;ET@1FEX(&1E;&5T:6YG(&]F(&ED96YT:71I97,@*$)U
M9R`C,3`Q."DN"@H*+2TM+0IV,RXP"BTM+2T*"EMC:FA=(%1R>2!T;R!C871C
M:"!D86YG97)O=7,@55),<R!I;B!T:&4@9&5R969E<G)E<B`H9V\N<&AP*2X*
M6V-J:%T@26UP<F]V92!T<F5E(&=R87!H:6-S(&9O<B!R:6=H="UT;RUL969T
M(&QA;F=U86=E<R`H5F%H:60@1VAA9F%R<&]U<@H@("`@("`\=F%H:61`9VAA
M9F%R<&]U<BYC;VT^*2X*6VUM<UT@1FEX($E-05!?5')E92!D:7-P;&%Y(&EF
M(&9O;&1E<B!C;VYT86EN<R!T:&4@=&5X="`G<&]P,R<N"EMC:FA=($9I>"!T
M:&4@2&]R9&5?1F]R;2!D871E('!I8VME<B!P;W!U<"!I;B!+;VYQ=65R;W(O
M4V%F87)I("A"=6<@(SDV,RDN"EMJ86Y=(%-P86-E<R!I;B!T<F5E('9I97=S
M('=I=&@@26YT97)N970@17AP;&]R97(@:&%V92!B965N(&9I>&5D+@H*"BTM
M+2TM+2TM"G8S+C`M4D,S"BTM+2TM+2TM"@I;8VIH72!!;'=A>7,@<F5L;V%D
M(&9R86UE<V5T(&%F=&5R(&QO9V=I;F<@:6X@*$)U9R`C.#$T*2X*6V-J:%T@
M1FEX(&UE;G4@<F5N9&5R:6YG(&9O<B!)12`U+C`O36%C+@I;8VIH72!4=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y(&9O<B!)12!B>2!D969A=6QT+@I;8VIH
M72!!;&QO=R!T;R!P87-S(&%N(&%R<F%Y(&]F(&%T=')I8G5T97,@=&\@2&]R
M9&4Z.FEM9R@I+@I;8VIH72!!;&QO=R!T;R!S970@82!P87-S=V]R9"!F;W(@
M=&AE(&%U=&\@875T:&5N=&EC871I;VX@9')I=F5R+@I;:F%N72!!9&0@;W!T
M:6]N(&9O<B!N=6QL(&1R:79E<B!T;R!M86EL97(@8V]N9FEG=7)A=&EO;BX*
M6VIA;ET@1FEX(&-O;F9I9W5R871I;VX@;V8@6E!3(&-A8VAE+@I;:F%N72!&
M:7@@<V]M92!J879A<V-R:7!T(&5R<F]R<R!W:71H($E%(#4N,"X*6V-J:%T@
M5&AE(")(;W)D92!0=7)P;&4B('1H96UE(&ES(&YO=R!S:6UP;'D@86YO=&AE
M<B!T:&5M92!T:&%T(&EN:&5R:71S(&9R;VT*("`@("`@=&AE(&=L;V)A;"!#
M4U,@<V5T=&EN9W,L(&EN<W1E860@;V8@8F5I;F<@8F]T:"!T:&4@<&%R96YT
M('1H96UE(&%S('=E;&P*("`@("`@87,@82!U<V5R+6-H;V]S96%B;&4@;W!T
M:6]N+B`@5&AE(&1E9F%U;'0@9W)A<&AI8W,@87)E(&YO=R!I;B!A"B`@("`@
M('1O<"UL979E;"!T:&5M97,O9W)A<&AI8W,@9&ER96-T;W)Y(&%S('=E;&P@
M9F]R('5S92!B>2!A;&P@=&AE;65S+@H*"BTM+2TM+2TM"G8S+C`M4D,R"BTM
M+2TM+2TM"@I;:F%N72!3:&]W('1A8B!W:71H('1H92!F:65L9"!T:&%T(&1I
M9&XG="!V86QI9&%T92!O;B!S=6)M:71T960@9F]R;7,N"EMM;7-=($%D9"!A
M(&=E;F5R:6,@34E-15]6:65W97(@=&AA="!W:6QL(&1I<W!L87D@=&AE(')A
M=R!T97AT(&]F('1E>'0O*@H@("`@("!P87)T<R!T:&%T('=E(&1O(&YO="!H
M879E(&$@<W!E8VEF:6,@=FEE=V5R(&9O<BX*"@HM+2TM+2TM+0IV,RXP+5)#
M,0HM+2TM+2TM+0H*6V-J:%T@57-E($A/4D1%7TU%3E5?34%32U\J(&-O;G-T
M86YT<R!F;W(@9&5T97)M:6YI;F<@=VAA="!L:6YK<R!A<F4@<VAO=VX*("`@
M("`@;VX@;65N=7,N"EMJ86Y=($-R96%T92!D969A=6QT('!A<F%M971E<G,@
M=VAE;B!A9&1I;F<@82!N97<@8FQO8VL@=&\@=&AE('!O<G1A;"X*6VUM<UT@
M075T;V1E=&5C="!E>&%C="!V97)S:6]N(&]F($E%("@U+C`K*2!O;B!L;V=I
M;B!A;F0@='5R;B!O9F8@8V]M<')E<W-I;VX*("`@("`@;VYL>2!F;W(@8G5G
M9WD@=F5R<VEO;G,N"EMC:FA=(%5S92!A;B!)12!B96AA=FEO<B!F;W(@:&%N
M9&QI;F<@86QP:&$@=')A;G-P87)E;F-Y('=I=&@@4$Y'(&EM86=E<PH@("`@
M("!I;G-T96%D(&]F(&%N(&]N;&]A9"!H86YD;&5R+@I;;6US72!!;&QO=R!A
M;&P@9F]L9&5R<R!T;R!B92!P<F4M9F5T8VAE9"!W:&5N(&EN=&EA;&EZ:6YG
M($E-05!?5')E93HZ+@I;;6US72!!9&1E9"!E>'1E;G-I;VYS('1O('1H92!F
M;W)M(')E;F1E<F5R(&9O<B!T:&4@9FEL92!S96QE8W1I;VX@05!)+@I;8VIH
M72!296YD97(@86QL(&UE;G5S(&%S(#QU;#X@=&%G<RP@9F]R;6%T=&5D('=I
M=&@@0U-3+@I;;6US72!!9&1E9"!E>&%M<&QE(&]F(%]I;7!?:&]O:U]S<&%M
M7V)O=6YC92!T;R!C;VYF:6<O:&]O:W,N<&AP+F1I<W0N"@H*+2TM+2TM+2TM
M"G8S+C`M0D5400HM+2TM+2TM+2T*"EMC:FA=($%L;&]W('1O(&EN<V5R="!I
M;6%G97,@9G)O;2!G86QL97)I97,@:6X@=&AE(%=94TE764<@2%1-3"!E9&ET
M;W(@*$1U8VL*("`@("`@/&1U8VM`;V)A;&$N;F5T/BP@4F]E;"!';&]U9&5M
M86YS(#QR;V5L0&=L;W5D96UA;G,N:6YF;SXI+@I;;61J72!!;&P@2&]R9&4@
M:6-O;G,@8VAA;F=E9"!F<F]M($=)1B!T;R!03D<N"EMM9&I=($%D9"`O=&AE
M;65S(&1I<F5C=&]R>2!A;F0@9W)O=7`@86QL(&]F(&5A8V@@=&AE;64G<R!F
M:6QE<R!U;F1E<B!A('-U8F1I<@H@("`@("!O9B!T:&ES(&1I<F5C=&]R>2X*
M6VIA;ET@4W=I=&-H(&9R;VT@9'EN86UI8R!T;R!S=&%T:6,@0U-3(&9I;&5S
M+@I;;6US72!!9&0@<W5P<&]R="!F;W(@365S<V%G92!$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VYS("A21D,@,C(Y."DN"EMJ86Y=($%D9"!486)L94]P97)A
M=&EO;G,L($-O;G1E>'1-96YU(&%N9"!,:7-T5'EP92!P;'5G:6YS('1O(')I
M8V@@=&5X=`H@("`@("!E9&ET;W(N"EMJ86Y=($%D9"!$871A5')E92!B<F]W
M<V5R('1O(&%D;6EN(&EN=&5R9F%C92X*6V-J:%T@5&AE($AO<F1E7T-A8VAE
M.CH@05!)(&AA<R!B965N(&-O;7!L971E;'D@<F5W<FET=&5N('1O('1A:V4*
M("`@("`@861V86YT86=E(&]F('1H92!N97<@6E!3-"!A<&D@9F]R(&-O;G1E
M;G0@8V%C:&EN9RP@=VAI8V@@86QL;W=S"B`@("`@(&$@;6]R92!F86UI;&EA
M<B!C86-H:6YG($%022!O=F5R86QL+B!4:&4@;VQD('IP<R!D<FEV97(@:&%S
M(&)E96X*("`@("`@9')O<'!E9"!B96-A=7-E(&]F('1H:7,N"EMJ86Y=($%D
M9"!097)S:6%N("A797-T97)N*2!T<F%N<VQA=&EO;B`H5F%H:60@1VAA9F%R
M<&]U<@H@("`@("`\=F%H:61`9VAA9F%R<&]U<BYC;VT^*2X*6VIA;ET@1')O
M<"!U<V%G92!O9B!A<F=?<V5P87)A=&]R+F]U='!U="X*6VIA;ET@36%K92!S
M:61E8F%R('=I9'1H(&$@<')E9F5R96YC92`H4FEC:R!%;65R>2`\<FEC:T!E
M;65R>2YH;VUE;&EN=7@N;F5T/BDN"EMC:FA=(%1H92!0<F5F<U]S<6P@9')I
M=F5R(&YO=R!U<V5S($1".CIP<F5P87)E+T1".CIE>&5C=71E(&9O<B!B971T
M97(@<W5P<&]R=`H@("`@("!O9B!L87)G92!F:65L9',@;VX@9&%T86)A<V4@
M8F%C:V5N9',@<W5C:"!A<R!/<F%C;&4N"EMC:FA=(%-U<'!O<G0@8W5S=&]M
M(&9I96QD(&UA<'!I;F=S(&EN($-35B!E>'!O<G1S+"!A;F0@861D(&%N($]U
M=&QO;VL@97AP;W)T"B`@("`@('1Y<&4N"EMC:FA=(%1H92!(;W)D92!S:61E
M8F%R(&UE;G4@:7,@;F]W(&)U:6QT('=I=&@@2&]R9&5?5')E92X*6VIA;ET@
M4T5#55))5%DZ($-L;W-E(&%N(%A34R!H;VQE(&EN('1H92!(5$U,('9I97=E
M<BP@82!V87)I871I;VX@=&\@=&AE(&]N90H@("`@("!R97!O<G1E9"!I;B!H
M='1P.B\O=W=W+F=R97EM86=I8RYC;VTO<V5C=7)I='DO861V:7-O<FEE<R]G
M;3`P-2UM8R\N"EMJ86Y=($%D9"!C;VYF:6=U<F%T:6]N(&]P=&EO;B!T;R!E
M;F%B;&4@4U-,(&9O<B!L;V=I;G,@;VYL>2X*6VIA;ET@4F5M;W9E('-H87)E
M('1Y<&4@*'!R:79A=&4O<'5B;&EC*2X*6VIA;ET@061D(&9R86UE=V]R:R!T
M;R!C;&5A<B!O=70@=7-E<B!D871A+"!E+F<N('=H96X@<F5M;W9I;F<@=7-E
M<G,N"EMJ86Y=($%D9"!A8V-E<W,@:V5Y<RX*6VIA;ET@1&]N)W0@<F5Q=6ER
M92!B;&]C:W,@=&\@8F4@<F5G:7-T97)E9"!I;B!T:&4@87!P;&EC871I;VYS
M)R!!4$ES+@I;8VIH72!);G1R;V1U8V4@82`G7V1E9F%U;'1?)R!C;VQO<B!A
M;F0@8F5T=&5R(&AA;F1L:6YG(&]F('5S97(M<W!E8VEF:65D"B`@("`@(%5N
M9FEL960@8V]L;W)S+@I;:F%N72!!;&QO=R!T:&5M97,@=&\@=7-E('1H96ER
M(&]W;B!I8V]N('-E=',N"EMC:FA=($-A=&5G;W)I97,@86YD(&-A=&5G;W)Y
M(&-O;&]R(&QA8F5L<R!A<F4@;F]W(&AA;F1L960@9VQO8F%L;'D@8GD@2&]R
M9&4L"B`@("`@(&%N9"!P<F]V:61E9"!T;R!A;&P@87!P;&EC871I;VYS('1H
M870@=7-E('1H96TN"EMJ86Y=($ED96YT:71I97,@87)E(&YO=R!M86YA9V5D
M('=I=&@@=&AE('!R969E<F5N8V5S(&-O9&4@86YD(&-A;B!B92!A8V-E<W-E
M9`H@("`@("!F<F]M(&5V97)Y(&%P<&QI8V%T:6]N+@I;;6US72!(86YD;&4@
M4D9#(#(R,S$@96YC;V1E9"!P87)A;65T97(@=F%L=65S+@I;;6US72!!9&0@
M24U!4%]3;W)T(&-L87-S('1O('!R;W9I9&4@<V]R=&EN9R!F;W(@24U!4"!M
M86EL8F]X(&QI<W1S+@I;:F%N72!!9&0@=7-E<B!M86YA9V5M96YT('1O($E-
M05`@875T:&5N=&EC871I;VX@9')I=F5R+@I;:F%N72!!9&0@24U!4%]!9&UI
M;B!C;&%S<R!T;R!M86YA9V4@24U!4"!M86EL8F]X97,N"EMM;7-=($%D9&5D
M(&$@9V5N97)I8R!T97AT+VAT;6P@34E-15]6:65W97(@9')I=F5R(&9O<B!A
M;&P@2&]R9&4@87!P;&EC871I;VYS"B`@("`@('1H870@871T96UP=',@=&\@
M<V%N:71I>F4@;6%L:6-I;W5S(&-O9&4@:&ED9&5N(&EN($A434PN"EMM;7-=
M($%D9&5D(&$@9V5N97)I8R!M97-S86=E+W)F8S@R,B!-24U%7U9I97=E<B!D
M<FEV97(N"EMC:FA=(%)E;6]V92!(3U)$15],24)3(&-O;G-T86YT(&%N9"!A
M<W-U;64@;&EB<F%R:65S(&%R92!I;B!T:&4@:6YC;'5D95]P871H+@I;:F%N
M72!!9&0@<V5A<F-H:6YG(&%N9"!P86=I;F<@=&\@=&AE('5S97(@861M:6YI
M<W1R871I;VX@:6YT97)F86-E("A*;V5L"B`@("`@(%9A;F1A;"`\:G9A;F1A
M;$!I;F9O=&5C:RYQ8RYC83XI+@H*"BTM+2TM+2TM+2T*=C,N,"U!3%!(00HM
M+2TM+2TM+2TM"@I;:F%N72!!8V-E<W,@:V5Y<R!A<F4@;F\@;&]N9V5R(&=E
M;F5R871E9"!A=71O;6%T:6-A;&QY(&)U="!D969I;F5D(&)Y('1H90H@("`@
M("!D979E;&]P97)S(&%N9"!T<F%N<VQA=&]R<RX*6V-J:%T@5&AE(&YE=R!S
M97)V:6-E<R]P<F5F<RYP:'`@9FEL92!I<R!N;W<@=&AE(&]N;'D@54D@<&%G
M92!N96-E<W-A<GD*("`@("`@9F]R('!R969E<F5N8V5S(&9O<B!A;&P@87!P
M;&EC871I;VYS("T@86QL(&%P<"]P<F5F<RYP:'`@9FEL97,*("`@("`@87)E
M(&YO=R!O8G-O;&5T92X*6V-J:%T@4')E9G,Z.F=E=%!R968H*2!H87,@8F5E
M;B!D97!R96-A=&5D(&%N9"!I<R!N;R!L;VYG97(@<')E<V5N="X*6V-J:%T@
M2&]R9&4Z.BP@4F5G:7-T<GDZ.BP@86YD('1H92!L87-T(&]F('1H92!L:6)S
M('1H870@87)E(&UO=FEN9R!S:&]U;&0@8F4*("`@("`@;6]V960@=&\@9G)A
M;65W;W)K('!A8VMA9V5S(&YO=RX*6V-J:%T@161I=&]R.CHL($UE;G4N<&AP
M+"!.3%,Z.BP@86YD(%-I9VYU<"YP:'`@:&%V92!A;&P@8F5E;B!M;W9E9"!T
M;PH@("`@("!F<F%M97=O<FL@<&%C:V%G97,N"EMM;7-=($UO=F5D('1H92!)
M34%0(%1R964@9V5N97)A=&EO;B!C;&%S<R!F<F]M($E-4"!T;R!F<F%M97=O
M<FL@<V\@:70@8V%N"B`@("`@(&)E('5S960@8GD@;W1H97(@87!P;&EC871I
M;VYS+@I;;61J72!3971U<"!N;W<@:&%S(&$@;6]R92!I;F9O<FUA=&EV92!F
M;W)M870N(%1H92!#5E,@=F5R<VEO;B!T86<@:7,@8V]P:65D"B`@("`@(&9R
M;VT@=&AE(&-O;F8N>&UL(&9I;&4@:6YT;R!T:&4@8V]N9BYP:'`@9FEL92!S
M;R!T:&%T(&ET(&)E('5S960@=&\@=V%R;@H@("`@("!W:&EC:"!A<'!L:6-A
M=&EO;G,@;F5E9"!T:&5I<B!C;VYF('5P9&%T960N"EMC:FA=(%5S92!J879A
M<V-R:7!T('1O(&%U=&]D971E8W0@=VAE=&AE<B!O<B!N;W0@=&AE(&9R86UE
M<V5T(&ES('!R97-E;G0N"EMC:FA=($AO<F1E7TAI<W1O<GDL($AO<F1E7TQI
M;FMS+"!A;F0@2&]R9&5?4V5A<F-H(&AA=F4@8F5E;B!M;W9E9"!T;PH@("`@
M("!F<F%M97=O<FL@<&%C:V%G97,N"EMC:FA=($%L;&]W(&%P<',@:6YC;'5D
M:6YG(&AO<F1E+VQI8B]B87-E+G!H<"!T;R!S<&5C:69Y('1H870@82!D:69F
M97)E;G0*("`@("`@<F5G:7-T<GD@87!P;&EC871I;VX@<VAO=6QD(&%C='5A
M;&QY(&)E('!U<VAE9"!O;G1O('1H92!296=I<W1R>0H@("`@("!A<'!L:6-A
M=&EO;B!S=&%C:RX@5&AI<R!L971S('1H92!F:6-T:6]N(&]F('!R;V)L96TN
M<&AP(&)E:6YG(&ET<PH@("`@("!O=VX@87!P;&EC871I;VX@<&QA>2!N:6-E
M;'D@=VET:"!T:&4@;F5W('!E<FUI<W-I;VYS(&-H96-K:6YG+@I;8VIH72!4
M:&4@;F5W(&%P<&QI8V%T:6]N('!E<FUI<W-I;VYS(&-H96-K:6YG(&AA<R!B
M965N(&UO9&EF:65D('1O"B`@("`@(&%L;&]W(&%C8V5S<R!T;R!A;&P@875T
M:&5N=&EC871E9"!U<V5R<R!B>2!D969A=6QT+"!A;F0@=&\@9&5N>0H@("`@
M("!G=65S="!A8V-E<W,@8GD@9&5F875L="X@06QL('9A<FEA=&EO;G,@;VX@
M=&AA="!M=7-T(&)E('-E=`H@("`@("!E>'!L:6-I=&QY+@I;8VIH72!296UO
M=F4@=&AE($=U97-T(%-E<G9I8V5S(&QI;FL[(&ET)W,@8F5E;B!O8G-O;&5T
M960@8GD*("`@("`@)&-O;F9;)VUE;G4G75LG86QW87ES)UTN"EMC:FA=(%9A
M<FEO=7,@)&YO7V%U=&@@86YD("1S96QF7V-O;G1A:6YE9%]A=71H(&9L86=S
M(&AA=F4@8F5E;B!S=&%N9&%R9&EZ960*("`@("`@:6YT;R!A;B!!551(7TA!
M3D1,15(@8V]N<W1A;G0L('=H:6-H(&EF(&1E9FEN960@<VEG;F%L<R!T:&4@
M87!P;&EC871I;VX*("`@("`@=&AA="!I="!S:&]U;&0@;F]T(&-H96-K('!E
M<FUI<W-I;VYS('5P;VX@8V%L;&EN9R`D<F5G:7-T<GDM/G!U<VA!<'`H*2P*
M("`@("`@87,@=&AE(&-A;&QI;F<@<V-R:7!T('=I;&P@:&%N9&QE('1H870@
M:71S96QF+"!O<B!I<R!A('-Y<W1E;2UL979E;"!C<F]N"B`@("`@(&IO8B]S
M8W)I<'0O971C+@I;8VIH72!!9&0@86X@;W!T:6]N('1O("1R96=I<W1R>2T^
M<'5S:$%P<"@I('1O('-P96-I9GD@=VAE=&AE<B!O<B!N;W0@=&\@8VAE8VL*
M("`@("`@87!P;&EC871I;VX@<&5R;6ES<VEO;G,N"EMC:FA=(%1H92`G86QL
M;W=?9W5E<W1S)R!S971T:6YG+"!A;F0@)')E9VES=')Y+3YA;&QO=T=U97-T
M<R@I+"!H879E(&)E96X*("`@("`@<F5M;W9E9"!I;B!F879O<B!O9B!(;W)D
M95]097)M<R!A<'!L:6-A=&EO;B!P97)M:7-S:6]N<RX*6VUM<UT@061D960@
M=&AE('1E>'0O<FEC:'1E>'0@34E-15]6:65W97(N"EMJ86Y=($EN<W1A;G1I
M871E('1H92!G;&]B86P@4&5R;7,@;V)J96-T(&EN(%)E9VES=')Y+G!H<"X*
M6V-J:%T@0V%T96=O<GD@:&%S(&)E96X@;6]V960@=&\@82!F<F%M97=O<FL@
M<&%C:V%G92P@86YD(&%L<V\@<F5N86UE9`H@("`@("!T;R!$871A5')E92!S
M;R!T:&%T(&ET(&AA<R!A(&UO<F4@:6YT=6ET:79E(&YA;64@9F]R('1H92!!
M4$DN"EMJ86Y=($%D9"!);F1O;F5S:6%N(&QA;F=U86=E("A3;&%M:6X@/'-L
M86UI;D!U;F5J+F%C+FED/BDN"EMJ86Y=($%D9"!!=71H7VQO9VEN(&-L87-S
M+@I;:F%N72!!9&0@2&]R9&4Z.F5X=&5R;F%L57)L*"DN"EMM9&I=(%!E<FUS
M(&ES(&YO=R!A(&=L;V)A;&QY(&%V86EL86)L92!O8FIE8W0L('-E="!B>2!T
M:&4@<F5G:7-T<GDG<PH@("`@("!L;V%D4&5R;7,H*2X*6VIA;ET@061D(")!
M8F]U="(@<&%G92!F;W(@=&AE(&AE;'`@<WES=&5M+@I;:F%N72!!9&0@4T]!
M4"!S97)V97(@=&\@4E!#(&9R86UE=V]R:RX*6V-J:%T@36]V92!0<F5F<U5)
M('1O(%!R969S+U5)+G!H<"!F;W(@<&%C:V%G92!C;VYS:7-T96YC>2X*6VUM
M<UT@061D960@3DQ37T=E;TE0.CH@=&\@9&\@2&]S=&YA;64@+3X@0V]U;G1R
M>2!L;V]K=7!S+B`@3DQ3.CH@=VEL;"!D;PH@("`@("!L;V]K=7!S(&)Y(&1E
M9F%U;'0@;F]W('5S:6YG(&-O=6YT<GD@5$Q$(&-O9&5S+@I;;6ER72!!9&0@
M<')E<')O8V5S<R!H;V]K(&9O<B!3:6=N=7`@<WES=&5M+@I;:F%N72!-;W9E
M($AO<F1E7T-,22P@2&]R9&5?0V%C:&4L($AO<F1E7T-I<&AE<BP@2&]R9&5?
M0V]M<')E<W,L"B`@("`@($AO<F1E7U1O:V5N(&%N9"!(;W)D95]5=&EL('!A
M8VMA9V5S('1O('1H92!F<F%M97=O<FL@;6]D=6QE+@I;8VIH72!296]R9V%N
M:7IE(&$@;G5M8F5R(&]F(&9I;&5S(&9R;VT@=&AE('1O<"!L979E;"!A;F0@
M9G)O;2!U=&EL+R!I;G1O(&$*("`@("`@;F5W('-E<G9I8V5S+R!D:7)E8W1O
M<GD@86YD(&$@;G5M8F5R(&]F('-E<G9I8V5S+RH@<W5B9&ER96-T;W)I97,N
M"B`@("`@(%1H:7,@<VAO=6QD(&=I=F4@=7,@82!B971T97(@8F%S92!F;W(@
M97AP86YD:6YG('1H92!S97)V:6-E<R!P<F]V:61E9`H@("`@("!B>2!T:&4@
M8V]R92!(;W)D92!M;V1U;&4@:6X@=&AE(&9U='5R92X*6VUA>%T@061D('-U
M<'!O<G0@9F]R(#QB/B!A;F0@/&D^('1A9W,@=&\@=&AE($AE;'`@>&UL('!A
M<G-E<BX*6V-J:%T@061D('1H92!(;W)D95](:7-T;W)Y($%022P@9F]R('-T
M;W)I;F<@=&EM97-T86UP960@979E;G1S(&9O<@H@("`@("!A<F)I=')A<GD@
M;V)J96-T<RX*6V-J:%T@2&]R9&5?5&5M<&QA=&4@;F]W(&%L;&]W<R!I9CH@
M8V]N9&ET:6]N<R!O;B!A<G)A>2!V86QU97,*("`@("`@*$YU;F\@3&]U<F5I
M<F\@/&YU;F]`8V\N<V%P;RYP=#XI+@I;:F%N72!4:&4@861M:6YI<W1R871O
M<B!C86X@;F]W(&9O<F-E('1H92!D969A=6QT(&QA;F=U86=E(&EN(&YL<RYP
M:'`*("`@("`@*$5T:65N;F4@1V]Y97(@/&5T:65N;F4N9V]Y97)`;&EN=7AQ
M=65B96,N8V]M/BDN"EMM9&I=($AO<F1E7T9O<FT@;F]W('-U<'!O<G1S('-E
M='1I;F<@;V8@82!H96QP(&EC;VX@;&EN:V5D('1O(&AE;'`N>&UL+@I;8VIH
M72!M:6UE7VUA<'!I;F<N<&AP(&ES(&YO(&QO;F=E<B!A(&-O;F9I9R!F:6QE
M.R!R97!L86-E9"!W:71H"B`@("`@(&UI;64N;6%P<&EN9RYP:'`@:6YS:61E
M('1H92!-24U%('!A8VMA9V4N"EMC:FA=($%D9"!';V]G;&4@<V5A<F-H(&%P
M<&QE="`H2F]E(%=I;'-O;B`\:F]E+G=I;'-O;D!M:6YD8V%N9'DN;W)G/BDN
M"EMJ86Y=(%541BTX('-U<'!O<G0@:7,@96YA8FQE9"!B>2!D969A=6QT(&YO
M=RX*6VIA;ET@5&AE;65S(&%R92!N;W<@875T;VUA=&EC86QL>2!R96%D(&9R
M;VT@=&AE(&-O;F9I9R]T:&5M97,@9&ER96-T;W)Y+@I;8VIH72!!9&0@<W5P
M<&]R="!F;W(@;W1H97(@:VEN9',@;V8@<V5R=F5R<R!A;F0@;W1H97(@:VEN
M9',@;V8@<F5S<&]N<V5S('1O"B`@("`@(')P8RYP:'`@86YD('1H92!24$,Z
M.B!!4$DN"EMJ=VU=($%D9"!S=7!P;W)T(&9O<B!A<'!R;W9I;F<@<75E=65D
M('-I9VYU<"!A<'!L:6-A=&EO;G,N"EMC:FA=($=R;W5P<R!C86X@;F]W(&AA
M=F4@86X@96UA:6P@861D<F5S<R!A<W-O8VEA=&5D('=I=&@@=&AE;2X*6V-J
M:%T@36%K92!(;W)D92UL979E;"!";&]C:W,@8V]N9FEG=7)A8FQE('1H<F]U
M9V@@=&AE(')E9VES=')Y+"!A;&QO=VEN9PH@("`@("!E87-I97(@861D:6YG
M(&]F(&YE=R!B;&]C:W,@*$IO92!7:6QS;VX@/&IO92YW:6QS;VY`;6EN9&-A
M;F1Y+F]R9SXI+@I;8VIH72!#871E9V]R>51R964@:7,@;F]W(&1E<')E8V%T
M960@:6X@9F%V;W(@;V8@2&]R9&5?5')E92X*6V-J:%T@36]V92!T:&4@861M
M:6X@<&5R;6ES<VEO;G,@86YD(&=R;W5P<R!P86=E<R!T;R!U<V4@2&]R9&5?
M5')E92X*6VUA>%T@061D(%]C;VUP87)E4&%S<W=O<F1S*"D@9G5N8W1I;VX@
M=&\@075T:%]S<6P@=&\@8V]R<F5C=&QY(&-O;7!A<F4*("`@("`@86QL(&-R
M>7!T960@<&%S<W=O<F1S('-I;6EL87(@=&\@=&AE(%!A<W-W9"!M;V1U;&4N
M"EMM87A=($%D9"!C<GEP="UD97,@*'=H:6-H(&ES('1H92!S86UE(&%S(&-R
M>7!T*2P@8W)Y<'0M;60U+"!A;F0@8W)Y<'0M8FQO=V9I<V@*("`@("`@96YC
M<GEP=&EO;B!T>7!E<RP@=&\@;6%T8V@@4&%S<W=D(&UO9'5L92X*6VUA>%T@
M061D(&]P=&EO;F%L('-H;W=?96YC<GEP=&EO;B!P87)A;2!T;R!!=71H7W-Q
M;"P@=&\@;6%T8V@@4&%S<W=D(&UO9'5L92X*6VUM<UT@061D960@25`@061D
M<F5S<R!C:&5C:R!T;R!!=71H.CIA=71H96YT:6-A=&4H*2!T;R!I;F-R96%S
M92!S96-U<FET>2X*6VIA;ET@4F5M;W9E($Y,4SHZ9&5C:6UA;$9R;VU,;V-A
M;&4H*2!A;F0@3DQ3.CID96-I;6%L5&],;V-A;&4H*2X*6V-J:%T@2&]R9&5?
M5D93.CH@:7,@;F]W(%9&4SHZ(&%G86EN+"!A;F0@:&%S(&YO(&5X=&5R;F%L
M($AO<F1E(&1E<&5N9&%N8VEE<RX*6V-J:%T@4F]U;F0@;W5T('1H92!V87)I
M;W5S('-H96QL('1O;VQS('=I=&@@82!C;VUM86YD('-H96QL+@I;8VIH72!!
M9&0@<VED96)A<BYP:'`@86YD(&%P<')O<')I871E('!R969S(&5N=')I97,@
M9F]R('5S:6YG($AO<F1E('=I=&@@=&AE"B`@("`@(&UE;G4@87,@82!-;WII
M;&QA('-I9&5B87(N"EMM;7-=($%D9"!)34%07T-A8VAE.CH@8VQA<W,@=&\@
M:&%N9&QE(&-A8VAE9"!)34%0('-E<G9E<B!D871A+@I;8VIH72!-86ME(&=E
M=$-A=&5G;W)I97-">4%T=')I8G5T97,H*2!M=6-H(&UO<F4@<V]P:&ES=&EC
M871E9"`M(&ET(&-A;@H@("`@("!N;W<@:&%N9&QE(&$@<')E='1Y(&UU8V@@
M87)B:71R87)Y(&QO9VEC('1R964@+2!A;F0@=7-E(&ET('1O(&]P=&EM:7IE
M"B`@("`@($AO<F1E7U-H87)E.CIL:7-T4VAA<F5S*"DN"EMC:FA=($%D9"!G
M971#871E9V]R:65S0GE!='1R:6)U=&5S*"DL(&%N9"!U<V4@:70@:6X*("`@
M("`@1W)O=7`Z.F=E=$=R;W5P365M8F5R<VAI<',H*2X*6V-J:%T@061D(&-O
M9&4@=&AA="!L971S(&$@0V%T96=O<GE/8FIE8W0@<W5B8VQA<W,@9&5F:6YE
M(&$@;6%P<&EN9R!F<F]M(&ET<PH@("`@("!I;G1E<FYA;"!D871A('1O('1H
M92!N97<@:&]R9&5?8V%T96=O<GE?871T<FEB=71E<R!T86)L92X*6VUM<UT@
M24U!4%]396%R8V@Z.B!N;W<@=7-E<R!A($E-05!?4V5A<F-H7U%U97)Y.CH@
M;V)J96-T('1O(&)U:6QD('1H90H@("`@("!A8W1U86P@24U!4"!S96%R8V@N
M"EMM;7-=($%D9&5D(&$@<V5C=7)E(&1E;&5T92!T96UP(&9I;&4@;W!T:6]N
M('1H870@=VEL;"!O=F5R=W)I=&4@86YY('1E;7`@9FEL90H@("`@("!W:71H
M(')A;F1O;2!D871A(&)E9F]R92!U;FQI;FMI;F<N"EMJ86Y=($%D9"!,879E
M;F1E<B!T:&5M92`H6FEA=7(@4F%H;6%N(#QZ:6%`<6%L86-O;2YC;VT^*2X*
M6V-J:%T@2&]R9&5?5&5M<&QA=&4Z.B!I<R!N;W<@8V%P86)L92!O9B!T<F%N
M<VQA=&EN9R!T97AT(&EN<VED90H@("`@("`\9V5T=&5X=#X\+V=E='1E>'0^
M('1A9W,N"EMC:FA=($AO<F1E7TUO8FEL93HZ(&YO=R!P<F]P97)L>2!S=7!P
M;W)T<R!M=6QT:7!L92!S=6)M:70@96QE;65N=',@:6X@9F]R;7,N"EMM86-=
M($%D9"!G96YE<FEC($-Y<G5S(&%U=&@@9')I=F5R+"!!=71H7V-Y<G5S+@I;
M;6%C72!!9&0@;W!T:6]N86P@96YC<GEP=&EO;B!P87)A;2!T;R!!=71H7W-Q
M;"P@=&\@;6%T8V@@4&%S<W=D(&UO9'5L92X*6VIA;ET@061D(&YE=R!H;V]K
M<R`H<F5P;&%C:6YG(%]H;W)D95]H;V]K7W5S97)N86UE*2!T;R!C;VYV97)T
M('5S97(@;F%M97,*("`@("`@9G)O;2!T:&4@8F%C:V5N9"!T;R!(;W)D92!A
M;F0@8F%C:RX*6V-J:%T@061D(&$@;F5W($%022!C86QL+"!!=71H.CII<T%U
M=&AE;G1I8V%T960H)')E86QM(#T@;G5L;"DL(&9O<@H@("`@("!D971E<FUI
M;FEN9R!W:&5T:&5R(&]R(&YO="!A('5S97(@:7,@;&]G9V5D(&EN('1O('1H
M92!C=7)R96YT"B`@("`@(')E86QM("AB>2!D969A=6QT(&YU;&PI+B!!=71H
M.CIG971!=71H*"D@:7,@<W1I;&P@=7-E9"!T;R!G970*("`@("`@=&AE(&-U
M<G)E;G0@=7-E<BP@8G5T(&YO=R!Y;W4@9&]N)W0@;F5E9"!T;R!K;F]W('1H
M92!A=71H(')E86QM"B`@("`@('1O(&=E="!T:&4@8W5R<F5N="!U<V5R("T@
M:G5S="!T;R!C:&5C:R!A=71H96YT:6-A=&EO;BX*6V-J:%T@1$A434P@9&%T
M92!P:6-K97(@;F]W(&]P96YS(')I9VAT(&]V97(@=&AE(&EM86=E('5S960@
M=&\@86YC:&]R(&ET+@I;8VIH72!4:&4@;&%S=%]L;V=I;B!P<F5F97)E;F-E
M(&ES(&YO=R!E;G1I<F5L>2!H86YD;&5D(&)Y($AO<F1E+@I;;6US72!!9&0@
M2&]R9&5?5&5S=#HZ(&-L87-S+W1E;7!L871E<R!T;R!A:60@:6X@8W)E871I
M;F<@=&5S="YP:'`@<V-R:7!T<RX*6VUM<UT@36]V92!C;VUP;&5X($E-05`@
M<V5A<F-H:6YG(&-O9&4@9G)O;2!)35!?4V5A<F-H.CH@=&\@24U!4%]396%R
M8V@Z.BX*6V-J:%T@4F4M=V]R:R!T:&4@2&]R9&4@3$1!4"!S8VAE;6$@8FET
M<R!T;R!B92!M;W)E(&-O<G)E8W0@86YD"B`@("`@(&-O;G-I<W1E;G0@*$%D
M86T@5&%U;F\@5VEL;&EA;7,@/&%D86U`;6]R<FES;VXM:6YD+F-O;3XI+@I;
M;6US72!!9&0@1$]-('1O;VQT:7`@8V%P86)I;&ET>2!V:6$@2&]R9&4Z.FQI
M;FM4;V]L=&EP*"DN"EMM;7-=($%D9"!G87)B86=E(&-O;&QE8W1I;VX@8VQA
M<W,@*$AO<F1E7U9&4U]'0SHZ*2!F;W(@5D93+@I;;6US72!!9&0@=&EM96]U
M="!T;R!01U`@:V5Y<V5R=F5R(&QO;VMU<"X*6V-J:%T@061D(&YA=FEG871I
M;VX@9F]R('!R979I;W5S+VYE>'0@<')E9F5R96YC97,@8FQO8VL@:6X@4')E
M9G-520H@("`@("`H36%T:&EE=2!#3$%"0554(#QM871H:65U+F-L86)A=71`
M9G)E92YF<CXI+@I;8VIH72!!9&0@2&]R9&5?3&EN:W,@05!)("AJ+FAU:6YI
M;FM`=V%N861O;RYN;"DN"EMC:FA=($%D9"!M;W)E(&EN=')O<W!E8W1I;VXL
M(&EN('1H92!F;W)M(&]F(&=E=$-O;G1E;G14>7!E*"D@86YD"B`@("`@(&=E
M=$QI;FLH*2P@=&\@=&AE($AO<F1E7TEM86=E.CH@05!)+@I;8VIH72!!9&0@
M=71I;"]C86-H979I97<N<&AP(&9O<B!V:65W:6YG(&%N>2!D871A('=I=&@@
M82!#;VYT96YT+71Y<&4*("`@("`@<'5T(&EN=&\@=&AE(&-A8VAE+@I;8VIH
M72!!9&0@2&]R9&5?0V%C:&4Z.F-A8VAE3V)J96-T*"D@9F]R('5S92!I;B!C
M86-H:6YG('1H92!R97-U;'1S(&]F"B`@("`@(&YO;BUS=&%T:6,@;V)J96-T
M(&UE=&AO9',N"EMC:FA=(%)E;F%M92!#86-H93HZ('1O($AO<F1E7T-A8VAE
M.CHN"EMC:FA=($UO=F4@0V%C:&5?<V5S<VEO;CHZ('1O($AO<F1E7U-E<W-I
M;VY/8FIE8W1S.CHN"EMM;7-=($%D9&5D($AO<F1E.CIE>'1E;G-I;VY%>&ES
M=',H*2!T;R!C86-H92!E>'1E;G-I;VY?;&]A9&5D*"D@8V%L;',N"EMC:FA=
M($%D9"!.3%,Z.F1E8VEM86Q4;TQO8V%L92@I(&%N9"!.3%,Z.F1E8VEM86Q&
M<F]M3&]C86QE*"D@=&\@:&%N9&QE"B`@("`@(&-O;G9E<G1I;F<@8F5T=V5E
M;B!D:69F97)E;G0@9&5C:6UA;"!P;VEN="!S97!A<F%T;W)S+@I;8VIH72!!
M9&1E9"!-24U%7TAE861E<G,Z.BX*6VUM<UT@36]V960@9WII<"!A;F0@=&%R
M(&9I;&4@:&%N9&QI;F<@=&\@2&]R9&5?0V]M<')E<W-?*CHZ(&UO9'5L97,N
M"EMM;7-=($UO=F5D(%I)4"!H86YD;&EN9R!T;R!T:&4@2&]R9&5?0V]M<')E
M<W-?>FEP.CH@;6]D=6QE+@I;;6US72!-;W9E9"!43D5&(&AA;F1L:6YG('1O
M('1H92!(;W)D95]#;VUP<F5S<U]T;F5F.CH@;6]D=6QE+@I;;6US72!!9&1E
M9"!(;W)D95]#;VUP<F5S<SHZ($%022`M('5S960@=&\@8V]M<')E<W,O9&5C
M;VUP<F5S<R!D871A+@I;;61J72!!9&1E9"!T:&4@1$]-(&-A;&5N9&%R(&1A
M=&4@<&EC:V5R('1O($AO<F1E7T9O<FTL(&)A<V5D(&]N('=O<FL@8GD*("`@
M("`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX@86YD
M($)R:6%N($ME:69E<@H@("`@("`\8G)I86Y`=F%L:6YO<BYN970^+@I;;6US
M72!!9&1E9"!M=6QT:7!A<G0O<F5P;W)T($U)345?5FEE=V5R.CHN"EMM;7-=
M($%D9&5D($U)344Z.F=E;F5R871E365S<V%G94E$*"D@=&\@9V5N97)A=&4@
M34E-12UC;VUP;&EA;G0@;65S<V%G92!)1',N"EMC:FA=($%D9"!C;VUM86YD
M+6QI;F4@<V5T=7`N<&AP('-C<FEP="X@4FEG:'0@;F]W+"!T:&ES(&]N;'D@
M9V5N97)A=&5S+W5P9&%T97,*("`@("`@8V]N9FEG=7)A=&EO;G,[('EO=2!C
M86YN;W0@*F5D:70J(&$@8V]N9FEG=7)A=&EO;B!W:71H(&ET+@I;:F%N72!!
M9&0@4W1R:6YG.CH@8VQA<W,@=VET:"!L;V-A;&4O8VAA<G-E="!S869E('-T
M<FEN9R!F=6YC=&EO;G,N"EMM;7-=($%D9&5D($AO<F1E.CIA=71H96YT:6-A
M=&EO;D9A:6QU<F52961I<F5C="@I+@I;;6US72!!9&1E9"!"<F]W<V5R.CIE
M<V-A<&5*4T-O9&4H*2!T;R!E<V-A<&4@8V5R=&%I;B!C:&%R86-T97)S(&EN
M"B`@("`@(&IA=F%S8W)I<'0@8V]D92!D97!E;F1I;F<@;VX@=&AE(&)R;W=S
M97(@='EP92X*6VIA;ET@061D($Y,4SHZ<W1R=&]L;W=E<B@I(&%N9"!U<V4@
M:70@979E<GEW:&5R92!W:&5R92!L;V-A;&4@:6YD97!E;F1A;F-E"B`@("`@
M(&ES(&YE8V5S<V%R>2X*6VIA;ET@061D(%1U<FMI<V@@=')A;G-L871I;VX@
M*$=E;F-O(%EI;&UA>B`\9V5N8V]Y:6QM87I`>6%H;V\N8V]M/BDN"EMM;7-=
M($%D9"`G;&EN:R<@<&%R86UE=&5R('1O('1H92!P<F5F97)E;F-E<R!C;VYF
M:6<@=&\@86QL;W<@9F]R(&AE;'`@;&EN:W,*("`@("`@=&\@8F4@861D960@
M=&\@=&AE('!R969E<F5N8V5S('!A9V5S+@I;;6US72!!;F]T:&5R($UA:6YT
M96YA;F-E.CH@<F5W<FET92`M(&YO=R!S=&]R92!A;&P@9&%T82!I;B!T:&4@
M8V%C:&5D"B`@("`@($UA:6YT96YA;F-E7U1A<VML:7-T(&]B:F5C="X*6VUM
M<UT@061D960@8VAE8VL@=&\@4')E9G,Z.B!T;R!E;G-U<F4@=&AE(&1A=&$@
M<W1O<F5D(&1O97,@;F]T(&5X8V5E9"!T:&4*("`@("`@;6%X:6UU;2!S=&]R
M86=E('-I>F4@;V8@=&AE('!R969E<F5N8V5S('-T;W)A9V4@<WES=&5M+@I;
M:F%N72!!9&0@551&+3@@<W5P<&]R="X@06YY(&-O;G1E;G0@=VET:"!A;GD@
M8VAA<G-E="!C86X@;F]W(&)E(&1I<W!L87EE9"!W:71H"B`@("`@(&%N>2!T
M<F%N<VQA=&EO;BX*6VUM<UT@061D($Y,4SHZ8VAE8VM#:&%R<V5T*"D@=&\@
M9&5T97)M:6YE('=H971H97(@82!G:79E;B!C:&%R86-T97(@<V5T(&ES"B`@
M("`@('9A;&ED(&]N('1H92!C=7)R96YT('-Y<W1E;2X*6V-J:%T@1&5P<F5C
M871E9"!296=I<W1R>3HZ:6YC;'5D949I;&5S*"D@86YD(%)E9VES=')Y.CIS
M:'5T9&]W;B@I+@I;;6US72!!9&0@<W5P<&]R="!I;B!-24U%7TUA9VEC.CH@
M=&\@=7-E('1H92!53DE8(&9I;&4@9G5N8W1I;VX@=&\@9&5T97)M:6YE"B`@
M("`@('1H92!-24U%('1Y<&4@;V8@=6YK;F]W;B!F:6QE<RX*6VUM<UT@061D
M960@86X@97AA;7!L92!C<F]N('-C<FEP="!T;R!D96QE=&4@;VQD('1E;7!O
M<F%R>2!F:6QE<RX*6VUM<UT@0V]R<F5C=&QY(&=E="!C:&%R<V5T(&EN9F]R
M;6%T:6]N(&9O<B!-24U%7U!A<G1S(&EN($U)345?4W1R=6-T=7)E+@I;;6US
M72!297=R;W1E($U)345?365S<V%G92!T;R!E>'1E;F0@34E-15]087)T+@I;
M8VIH72!!9&0@;W)D97)I;F<@97AT96YS:6]N<R!T;R!T:&4@0V%T96=O<GDZ
M.B!F<F%M97=O<FL*("`@("`@*$UA<FMO(#QM87)K;T!O8FQO+F-O;3XI+@I;
M8VIH72!!9&0@82!S:6UP;&4@=&5M<&QA=&4@96YG:6YE+"!D97)I=F5D(&9R
M;VT@8E1E;7!L871E+`H@("`@("!F;W(@2&]R9&4@87!P;&EC871I;VYS('1O
M('5S92X*6V-J:%T@061D($%U=&A?>6%H;V\Z.B!W:&EC:"!L971S('EO=2!H
M879E(&YO(&QO8V%L(&%U=&@@86YD(')E;'D@;VX*("`@("`@66%H;V\A(&UA
M:6P@=7-E<FYA;65S+@I;;6US72!-;W9E9"!397)V97(@8V]N9FEG=7)A=&EO
M;B!C:&5C:VEN9R!F=6YC=&EO;G,@=&\@4V5R=F5R.CHN"EMC:FA=(%1H92!U
M<V5R(&%D;6EN('!A9V4@8V%N(&YO=R!S970@9G5L;&YA;64@86YD(&9R;VU?
M861D<B!P<F5F97)E;F-E<PH@("`@("!F;W(@86YY('5S97(@87,@;&]N9R!A
M<R!T:&4@075T:"!B86-K96YD(&ES(&-A<&%B;&4@;V8@870@;&5A<W0*("`@
M("`@;&ES=&EN9R!U<V5R<R`H9&]E<VXG="!H879E('1O(&)E(&%B;&4@=&\@
M=7!D871E('1H96TI+@I;8VIH72!3:&%R93HZ(&ES(&YO=R!(;W)D95]3:&%R
M93HZ+"!A;F0@:7,@<F5W;W)K960@=&\@:&]L9"!P97)M:7-S:6]N<PH@("`@
M("!I;G1E<FYA;&QY+B!792!C86X@;F]W(&%S<VEG;B!G<F]U<"]D969A=6QT
M+V=U97-T('!E<FUI<W-I;VYS"B`@("`@(&UO<F4@96%S:6QY+@I;:F%N72!!
M9&0@4E!#.CIP87)S955R;"@I+@I;:F%N72!!9&0@4E!#(&)A<V5D(')E;6]T
M92!S=6UM87)I97,N"EMC:FA=($%D9"!A(%-13"!3:&5L;"!T;R!T:&4@2&]R
M9&4@861M:6X@<V5C=&EO;BX*6V-J:%T@1&]N)W0@<')E9FEX($AO<F1E(&%D
M;6EN(&UE;G5I=&5M<R!W:71H(")(;W)D92(@=&\@<V%V92!S<&%C92X*6V-J
M:%T@2&]R9&5?1F]R;3HZ(&9O<FUS(&YO=R!U<V4@=&AE($AO<F1E7U1O:V5N
M.CH@05!)(&)Y(&1E9F%U;'0@=&\*("`@("`@;6%K92!S=7)E('1H870@=&AE
M>2!C86YN;W0@8F4@<F5L;V%D960N"EMC:FA=(%)E;F%M92!4;VME;CHZ('1O
M($AO<F1E7U1O:V5N.CH@9F]R(&9U='5R92!P86-K86=I;F<N"EMJ86Y=($%D
M9"!296=I<W1R>3HZ;&ES=$%027,H*2!A;F0@4F5G:7-T<GDZ.FQI<W1-971H
M;V1S*"DN"EMC:FA=(%1H92!097)M<SHZ('-Y<W1E;2!N;W<@<W5P<&]R=',@
M9&5F875L="!A;F0@9W5E<W0@<&5R;6ES<VEO;G,N"EMC:FA=($%P<&QI8V%T
M:6]N<R!C86X@;F]W('!R;W9I9&4@:6YD:79I9'5A;"!R96=I<W1R>2!M971H
M;V1S+"!N;W0@:G5S="!W:&]L90H@("`@("!I;G1E<F9A8V5S+B!!<'!L:6-A
M=&EO;G,@8V%N(&]V97)R:61E(&$@<VEN9VQE(&UE=&AO9"!O=70@;V8@86X@
M:6YT97)F86-E"B`@("`@(&%S('=E;&P@+2!A;B!A<'`@<')O=FED:6YG(&$@
M;6%I;"]F:6QT97(@=VAI;&4@24U0('!R;W9I9&5S(&UA:6PO*BP@92YG+@I;
M8VIH72!296YA;65D($9O<FU3<')O8VME=#HZ('1O($AO<F1E7T9O<FTZ.B!A
M;F0@1W)A<&A3<')O8VME=#HZ('1O"B`@("`@($AO<F1E7T=R87!H.CH@9F]R
M(&-O;G-I<W1E;F-Y(&%N9"!F=71U<F4@4$5!4B!P86-K86=I;F<N"EMM:7)=
M($%D9&5D(&5X86UP;&4@;V8@7VEM<%]H;V]K<U]F971C:&UA:6Q?9FEL=&5R
M('1O(&-O;F9I9R]H;V]K<RYP:'`N9&ES=`I;;6US72!!9&1E9"!T:&4@34E-
M15]#;VYT96YT<SHZ(&-L87-S.R!F=6YC=&EO;G,@=&\@:&5L<"!I;B!T:&4@
M;W5T<'5T"B`@("`@(&]F($U)344@8V]N=&5N="X*6V-J:%T@4F5W<FET92!T
M:&4@0V%T96=O<GDZ.B!S>7-T96T@=&\@86QL;W<@;75L=&EP;&4@;&5A=F5S
M('=I=&@@=&AE('-A;64*("`@("`@;F%M92`H87,@;&]N9R!A<R!T:&5Y(&AA
M=F4@9&EF9F5R96YT('!A<F5N=',I(&%N9"!R97=R:71E(&5V97)Y=&AI;F<*
M("`@("`@*%!E<FUS.CHL($=R;W5P.CHL(%-H87)E.CHL(&5T8RXI('1O('5S
M92!I="X*6V-J:%T@36]V92!?9FEL94-L96%N=7`H*2!I;G1O($AO<F1E.CH@
M87,@2&]R9&4Z.F1E;&5T94%T4VAU=&1O=VXH*2P*("`@("`@86YD(&%D9"!(
M;W)D93HZ7V1E;&5T94%T4VAU=&1O=VXH*2!T;R!D;R!T:&4@86-T=6%L(&1E
M;&5T:6YG+@I;8VIH72!);FET:6%L('-U<'!O<G0@9F]R(&-O;F9I9W5R:6YG
M('1H92!S=6UM87)Y('-C<F5E;@H@("`@("`H17)I8R!296-H;&EN(#QE<FEC
M0&AP8V%L8RYO<F<^*2X*6V-J:%T@061D(&$@<WES=&5M(&9O<B!D969I;FEN
M9R!G96YE<FEC(&AO;VMS(&9O<B!A;GD@<')E9F5R96YC92X*("`@("`@4V5E
M(&AO<F1E+V-O;F9I9R]H;V]K<RYP:'`N9&ES="!F;W(@;&]T<R!O9B!E>&%M
M<&QE<R!A;F0@9&]C<RX*6V-J:%T@061D(&$@8V]L;W)P:6-K97(@=71I;&ET
M>2!T;R!(;W)D90H@("`@("`H36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CXI+@I;8VIH72!!9&0@82!G=65S="!S97)V:6-E<R!E
M;G1R>2!P86=E(&%N9"!L:6YK<R!T;R!I="!F<F]M(&%L;`H@("`@("!L;V=I
M;B!P86=E<RX*6VIA;ET@061D('1R86YS;&%T:6]N(&AE;'!E<B!S8W)I<'0N
M"EMM;7-=(%-T>6QE<VAE970@;&EN:R!G96YE<F%T:6]N(&AA;F1L960@8GD@
M2&]R9&4Z.G-T>6QE<VAE971,:6YK*"DN"EMC:FA=($%D9"!T:&4@;F5W($-O
M;F9I9SHZ($%022!A;F0@<V5T=7`N<&AP+"!A('-Y<W1E;2!W:&EC:"!R96%D
M<PH@("`@("!C;VYF:6=U<F%T:6]N<R!F<F]M(%A-3"!F:6QE<R!A;F0@97AI
M<W1I;F<@8V]N9BYP:'`@9FEL97,L"B`@("`@('1A:VEN9R!C87)E(&]F(&UE
M<F=E<R!A;F0@861D:6YG(&YE=R!P87)A;65T97)S+B!#=7)R96YT;'D@=V4*
M("`@("`@:&%V92!A('=E8B!W:7IA<F0N"EMC:FA=(&-S<RYP:'`@;F]W('-U
M<'!O<G1S(&QO861I;F<@0U-3(&-L87-S97,@9F]R(&UU;'1I<&QE(&%P<&QI
M8V%T:6]N<RX*6VUM<UT@4F5M;W9E9"!T:&4@4V5S<VEO;D-A8VAE(&-L87-S
M+B!%<75I=F%L96YT(&-O9&4@:7,@;F]W(&%V86EL86)L92!I;@H@("`@("!T
M:&4@0V%C:&5?<V5S<VEO;CHZ(&-L87-S+@I;;6US72!!9&1E9"!)12!B<F]K
M96XM8G)O=W-E<B!D;W=N;&]A9&EN9R!C;V1E('1O($)R;W=S97(Z.BX*6VUM
M<UT@061D960@82!S97-S:6]N(&1R:79E<B!T;R!#86-H93HZ+@I;8VIH72!2
M96YA;64@8V]N9FEG+VAO<F1E+G!H<"!T;R!C;VYF:6<O8V]N9BYP:'`N"EMC
M:FA=($UO=F4@8V]O:VEE7V1O;6%I;BP@8V]O:VEE7W!A=&@L('-E<G9E<E]N
M86UE+"!A;F0@<V5R=F5R7W!O<G0@:6YT;PH@("`@("!H;W)D92]C;VYF+G!H
M<"X*6V-J:%T@061D(&$@<&%R86UE=&5R(&9O<B!S971T:6YG('1H92!S97-S
M:6]N(&-A8VAE7VQI;6ET97(N"EMC:FA=($%D9"!-24U%7U9I97=E<E]T97AT
M('1O($AO<F1E+@I;8VIH72!297=R:71E(&%L;"!F86-T;W)Y+W-I;F=L971O
M;B!M971H;V1S('1O(&%L;&]W(&EN9&EV:61U86P@87!P;&EC871I;VYS"B`@
M("`@('1O('!R;W9I9&4@82!C=7-T;VT@8F%C:V5N9"P@86YD('1O(&%L;&]W
M('-I=&5S('1O('!R;W9I9&4@8W5S=&]M"B`@("`@(&)A8VME;F1S(&EN('1H
M96ER(&EN8VQU9&5?<&%T:"!S971T:6YG<RX*6VUM<UT@2&%N9&QI;F<@;V8@
M0V]N=&5N="U4>7!E('!A<F%M971E<G,@;6]V960@=&\@34E-15]087)T(&9R
M;VT@34E-15]-97-S86=E+@I;;6US72!#<GEP=%]P9W`Z.B!C86X@;F]W('5P
M;&]A9"!K97ES('1O(&$@<'5B;&EC(&ME>7-E<G9E<BX*6VUM<UT@4F5N86UE
M9"!T:&4@3&%N9SHZ(&-L87-S('1O($Y,4SHZ(&%N9"!M;W9E9"!T:&4@=&EM
M97IO;F4@<V5T=&EN9PH@("`@("!M971H;V0@:6YT;R!I="X*6VUM<UT@5&AE
M(&QO8V%L('1I;65Z;VYE(&-A;B!N;W<@8F4@<V5T('9I82!T:&4@2&]R9&4Z
M.G-E=%1I;65Z;VYE*"D@8V%L;"X*6VUM<UT@06QL(&)R;W=S97(@:&5A9&5R
M<R!F;W(@9&]W;FQO861I;F<@82!F:6QE(&AA=F4@8F5E;B!M;W9E9"!T;R!T
M:&4*("`@("`@0G)O=W-E<CHZ(&-L87-S+@I;8VIH72!!9&0@9FEL97,@=&\@
M=71I;"!T;R!S=7!P;W)T(&5M8F5D9&EN9R!A($=522!E9&ET;W(@:6YT;R!O
M=7(@<&%G97,N"EMM;7-=($U)344Z.B!N;R!L;VYG97(@97AP;W)T<R`D;6EM
M95]T>7!E<R!A;F0@)&UI;65?96YC;V1I;F=S(&%S(&=L;V)A;`H@("`@("!V
M87)I86)L97,@+2!R871H97(L($U)344Z.G1Y<&4H*2!A;F0@34E-13HZ96YC
M;V1I;F<H*2!S:&]U;&0@8F4@=7-E9"X*6VUM<UT@5&AE('1G>B!-24U%7U9I
M97=E<B!N;W<@;&ES=',@86QL(&9I;&5S('=I=&AO=70@=7-I;F<@86X@97AT
M97)N86P@:&5L<&5R"B`@("`@('!R;V=R86T@*$UI8VAA96P@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUM<UT@5&AE(')A<B!-24U%
M7U9I97=E<B!N;W<@;&ES=',@86QL(&9I;&5S('=I=&AO=70@=7-I;F<@86X@
M97AT97)N86P@:&5L<&5R"B`@("`@('!R;V=R86T@*$UI8VAA96P@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUM<UT@5&AE('II<"!-
M24U%7U9I97=E<B!N;W<@;&ES=',@86QL(&9I;&5S('=I=&AO=70@=7-I;F<@
M86X@97AT97)N86P@:&5L<&5R"B`@("`@('!R;V=R86T@*$UI8VAA96P@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUM<UT@36%I;G1E
M;F%N8V4Z.B!N;W<@=7-E<R!S97-S:6]N('9A<FEA8FQE<R!T;R!P<F]V:61E
M(&UU8V@@8VQE86YE<B!A;F0@;6]R90H@("`@("!R;V)U<W0@<&5R9F]R;6%N
M8V4N"EMM;7-=($U3+51.148@871T86-H;65N=',@87)E(&YO=R!H86YD;&5D
M(&-O;7!L971E;'D@=FEA(%!(4"!R871H97(@=&AA;B!W:71H"B`@("`@(&%N
M(&5X=&5R;F%L('!R;V=R86TN"EMM;7-=($%D9&5D(&%P<&QI8V%T:6]N+VUS
M+71N968@34E-15]6:65W97(N"EMM;7-=($AO<F1E7T-R>7!T7W!G<"!C;&%S
M<R!C86X@<75E<GD@<'5B;&EC(&ME>7-E<G9E<G,N"EMM;7-=($U)345?4W1R
M=6-T=7)E.CIP87)S94U)345(96%D97)S*"D@8V%N(&YO=R!P87)S92!A;&P@
M:&5A9&5R<R!O9B!A($U)344*("`@("`@;65S<V%G92!A;F0@<F5T=7)N(&%N
M(&]B:F5C="X*6VIA;ET@061D($U)344Z.G)F8S@R,E=R:71E061D<F5S<R@I
M('1O(')E<&QA8V4@:6UA<%]R9F,X,C)?=W)I=&5?861D<F5S<R@I+@I;;6US
M72!!9&1E9"!3+TU)344@34E-15]6:65W97(N"EMJ;VY=(%-U<'!O<G0@<F5F
M97)R86QS(&)E='=E96X@3$1!4"!S97)V97)S(&EN('1H92!,1$%0('!R969E
M<F5N8V5S(&1R:79E<@H@("`@("`H2V5V:6X@2&EL9&5B<F%N9"`\:V5V:6Y`
M:'$N96YS;W!O<G0N8V]M/BDN"EMC:FA=($U)345?4W1R=6-T=7)E.CIP87)S
M92@I(&YO=R!R971U<FYS(&$@34E-15]-97-S86=E(&]B:F5C=`H@("`@("`H
M36EC:&%E;"!-(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^*2X*6V-J:%T@0V]N9FEG=7)E(&%D;6EN:7-T<F%T:6]N('-E<G9I8V5S
M(&EN('1H92!296=I<W1R>0H@("`@("`H36%R8W5S($DN(%)Y86X@/&UA<F-U
M<T!R:6)O9FQA=FEN+FYE=#XI+@I;8VIH72!!9&0@05!)(&UE=&AO9',@9F]R
M(&=E='1I;F<@=&AE('!R969E<F5N8V5S(&%N9"!I9&5N=&ET:65S(&]F('5S
M97)S"B`@("`@(&]T:&5R('1H86X@=&AE(&QO9V=E9"UI;B!U<V5R+@I;8VIH
M72!!;&QO=R!S971T:6YG('1H92!#;VYT96YT+41I<W!O<VET:6]N(&]F($U)
M345?4&%R="!O8FIE8W1S+@I;8VIH72!!9&0@0W)Y<'0Z.B!F<F%M97=O<FL@
M*$UI8VAA96P@32!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N
M961U/BDN"EMM87A=($%D9"!"<F]W;B!(;W)D92!T:&5M92`H36%R8V\@3V)A
M:60@/&UA<F-O0&UU=RYE9'4^*2X*6VIO;ET@06QL;W<@=&AE($Q$05`@=F5R
M<VEO;B!T;R!B92!S<&5C:69I960@9F]R('1H92!,1$%0('!R969E<F5N8V5S
M(&1R:79E<BX*6VIA;ET@061D('1H96UE('!R969E<F5N8V4N"EMJ86Y=($%D
M9"!C86QL8F%C:R!F=6YT:6]N(&9O<B!P<F5F97)E;F-E<RX*6VIO;ET@4F5M
M;W9E('1H92`D8V]N9ELG;65N=2==6R=F;&]A=&EN9U]B87(G72!F=6YC=&EO
M;F%L:71Y+@I;:F%N72!,;V%D(&]N;'D@;&]G:6X@<&%G92!O;B!S=&%R='5P
M(&%N9"!R961I<F5C="!T;R!F<F%M97-E="!A9G1E<B!L;V=I;BX*6V-J:%T@
M1&]N)W0@86QL;W<@86YO;GEM;W5S(&%C8V5S<R!T;R!P<F]B;&5M+G!H<"X*
M6V-J:%T@061D(&5N7T="(&QO8V%L92X*6V-J:%T@4F5M;W9E(&5X=&5N<VEO
M;G,@;VX@=&5M<&]R87)Y(&9I;&5S.R!T:&ES(&ES(&$@=&5M<"!R86-E(&AO
M;&4N"EMC:FA=($%L;&]W(&9O<B!A=71O+6-R96%T:6]N(&]F('!E<FUI<W-I
M;VYS("AM=6QT:7!L92!L979E;',@;V8@:&EE<F%R8VAY*2X*6V-J:%T@061D
M(&%D9&EN9R]R96UO=FEN9R!O9B!U<V5R<R!F<F]M(&=R;W5P<RX*6V-J:%T@
M0W)E871E('1E;7`@9FEL97,@=VET:"!T:&4@<FEG:'0@97AT96YS:6]N(&EN
M($U)345?5FEE=V5R7V5N<V-R:7!T.CH@<V\*("`@("`@96YS8W)I<'0@:&%S
M(&UO<F4@8VQU97,@=&\@9W5E<W,@9FEL92!T>7!E+@I;8VIH72!4:&4@861M
M:6YI;G-T<F%T:6]N(&EN=&5R9F%C92!F;W(@1W)O=7!S(&%N9"!097)M:7-S
M:6]N<R!I<R!N;W<*("`@("`@;6]S=&QY(&9U;F-T:6]N86PN"EMC:FA=($UA
M:V4@87!P;&EC871I;VX@875T:&5N=&EC871I;VX@86X@075T:#HZ(&1R:79E
M<BP@:6YS=&5A9"!O9B!A('-P96-I86P*("`@("`@4F5G:7-T<GD@8V%S92X*
M6V-J:%T@1FEX('!R;V)L96US('=I=&@@=&AE($YO=&EF:6-A=&EO;B!S=&%C
M:R!A;F0@<F5G:7-T97)?9VQO8F%L<R!B96EN9R!O9F8N"EMJ;VY=($%L=&5R
M($AO<F1E.CII;6<H*2!T;R!E>'!L:6-I=&QY(&%C8V5P="!A;B!A;'0](B(@
M871T<FEB=71E+@H@("`@("!(;W)D93HZ:6UG*"D@;F]W(&=E;F5R871E<R!T
M:71L93TB(B!A='1R:6)U=&5S(&)A<V5D(&]N('1H92!A;'0](B(@=&5X="P*
M("`@("`@=&]O+@I;8VIH72!.;W1I9FEC871I;VXZ.FYO=&EF>2@I('!A<W-E
M<R!T:&4@;65S<V%G92!S=&%C:R!T;R!A;&P@;&ES=&5N97)S+"!S;R!T:&%T
M"B`@("`@(&QI<W1E;F5R<R!D;VXG="!H879E('1O(&MN;W<@86)O=70@=&AE
M(&UE<W-A9V4@<W1A8VLL(&%N9"!A<'`@=W)I=&5R<PH@("`@("!D;VXG="!H
M879E('1O(&MN;W<@86)O=70@86QL('!O<W-I8FQE(&QI<W1E;F5R<RX*6V-J
M:%T@4F5P;&%C92!T:&4@2$]21$5?*B!M97-S86=E(&-O;G-T86YT<R!W:71H
M("=H;W)D92YE<G)O<B<L(&5T8RX@9F]R"B`@("`@(&=R96%T97(@9FQE>&EB
M:6QI='DN"EMC:FA=(%)E;6]V92!(;W)D93HZ<F%I<V5-97-S86=E*"D@;F]W
M('1H870@=&AE($YO=&EF:6-A=&EO;B!S>7-T96T*("`@("`@<')O=FED97,@
M=&AA="!F=6YC=&EO;F%L:71Y+@I;8VIH72!5<V4@=&AE(&YE=R!.;W1I9FEC
M871I;VX@<WES=&5M+@I;8VIH72!296UO=F4@;W1H97(@4F5G:7-T<GD@9V5T
M*"D@;65T:&]D<RX*6VIO;ET@4F5M;W9E('-U<'!O<G0@9F]R('1H92!H;W)D
M95]L86YG=6%G92!C;V]K:64N"EMJ86Y=($UO=F4@=&AE(&UA:6YT96YA8V4@
M9G)A;65W;W)K(&9R;VT@24U0('1O($AO<F1E("A-:6-H865L($T@4VQU<V%R
M>@H@("`@("`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3XI+@H*"BTM
M+2TM+0IV,BXR+CD*+2TM+2TM"@I;:F%N72!314-54DE463H@1FEX('!O=&5N
M=&EA;"!84U,@=G5L;F5R86)I;&ET>2!D=64@=&\@;F]T('!R;W!E<FQY(&5S
M8V%P960*("`@("`@97)R;W(@;65S<V%G97,N"@H*+2TM+2TM"G8R+C(N.`HM
M+2TM+2T*"EMJ86Y=(%-%0U522519.B!#;&]S92!84U,@=VAE;B!S971T:6YG
M('1H92!P87)E;G0@9G)A;64G<R!P86=E('1I=&QE(&)Y"B`@("`@(&IA=F%S
M8W)I<'0@*&-J:"DN"@H*+2TM+2TM"G8R+C(N-PHM+2TM+2T*"EMC:FA=(%)E
M<W1O<F4@8V]M<&%T:6)I;&ET>2!W:71H(%!(4"`T+C$N"EMJ86Y=(%-%0U52
M2519.B!&:7@@<&]T96YT:6%L(%A34R!V=6QN97)A8FEL:71Y(&EN('1H92!H
M96QP('=I;F1O=RX*6VIA;ET@1FEX(&-H87)S970@9F]R($QA='9I86X@=')A
M;G-L871I;VX@*$)U9R`C-C4V*2X*"@HM+2TM+2T*=C(N,BXV"BTM+2TM+0H*
M6VIA;ET@57-E($1".CIP<F5P87)E+T1".CIE>&5C=71E($].3%D@9F]R($]R
M86-L92!T;R!A=F]I9"!I;7!L:6-I=&QY(')E<75I<FEN9PH@("`@("!02%`@
M-"XR(&9O<B!A;&P@;W1H97(@4D1"37,N"EMC:FA=($9I>"!/<F%C;&4@<V5S
M<VEO;B!H86YD;&5R+@I;8VIH72!!9&0@4U%,('-C<FEP=',@9F]R($]R86-L
M92!A;F0@4&]S=&=R95-13"!S97-S:6]N(&AA;F1L97)S+@I;:F%N72!$;VXG
M="!S=')I<"!T<F%I;&EN9R!S<&%C97,@9G)O;2!S:6=N871U<F4@9&%S:&5S
M(&EN($E-4"X*"@HM+2TM+2TM+2TM"G8R+C(N-BU20S$*+2TM+2TM+2TM+0H*
M6V-J:%T@1FEX('-U<'!O<G0@9F]R(&-U<W1O;2!S97-S:6]N(&AA;F1L97)S
M+@I;8VIH72!5<V4@1$(Z.G!R97!A<F4O1$(Z.F5X96-U=&4@:6X@=&AE(%!R
M969S7W-Q;"!D<FEV97(@9F]R(&)E='1E<B!S=7!P;W)T"B`@("`@(&]F(&QA
M<F=E(&9I96QD<R!O;B!D871A8F%S97,@<W5C:"!A<R!/<F%C;&4N"EMJ86Y=
M(%-H;W<@=&AE('5S97(G<R!F=6QL(&YA;64@;VX@=&AE('-U;6UA<GD@<V-R
M965N(&1I<F5C=&QY(&%F=&5R(&QO9V=I;F<*("`@("`@:6X@*$0N($%D86T@
M2V%R:6T@/&%D86U`86MA<G-O9G0N8V]M/BDN"EMJ86Y=($9I>"!J879A<V-R
M:7!T(&5R<F]R(&EN(")0<F]B;&5M(B!P86=E('=I=&@@<V]M92!T<F%N<VQA
M=&EO;G,@*$)U9R`C-C$I+@I;8VIH72!&:7@@:&%N9&QI;F<@;V8@4&]S=&=R
M95-13"!B;&]B<R`H0G5G(",T-"DN"@H*+2TM+2TM"G8R+C(N-0HM+2TM+2T*
M"EMJ86Y=($%D9"!);F1O;F5S:6%N(&QA;F=U86=E("A3;&%M:6X@/'-L86UI
M;D!U;F5J+F%C+FED/BDN"EMJ86Y=($%D9"!'86QI8VEA;B!T<F%N<VQA=&EO
M;B`H4F%F865L(%9A<F5L82!0970@/'-R<F%F84!U<V,N97,^+"!'=6EL;&5R
M;6\*("`@("`@365N9&5Z(#QG=6EL;&5`=7-C+F5S/BDN"EMM;7-=($9I>"!D
M;W=N;&]A9&EN9R!O9B!F:6QE<R!W:71H('-P86-E<R!I;B!-;WII;&QA+@H*
M"BTM+2TM+0IV,BXR+C0*+2TM+2TM"@I;;61J72!314-54DE463H@061D(&1E
M<F5F97)E<B!T;R!S=')I<"!O9F8@<V5S<VEO;B!I;F9O<FUA=&EO;B!F<F]M
M(&QI;FMS('1O"B`@("`@('1H92!O=71S:61E(&]F('1H92!(;W)D92!S>7-T
M96T@=&\@<')O=&5C="!A9V%I;G-T('-E<W-I;VX@:&EJ86-K:6YG+@I;;6US
M72!314-54DE463H@061D(&-O9&4@=&\@<')O=&5C="!A9V%I;G-T('-E<W-I
M;VX@9FEX871I;VX@:7-S=65S+@I;:F%N72!&:7@@82!B=6<@=VET:"!I;7!O
M<G1I;F<@=D-A<F0@,BXQ(&1A=&$N"EMJ86Y=($%D9"!!<F%B:6,@*%-Y<FEA
M*2!T<F%N<VQA=&EO;B`H4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;0H@("`@
M("`\9&5V=&5A;4!P;&%T:6YU;2US>2YN970^*2X*6VIA;ET@061D($UA8V5D
M;VYI86X@=')A;G-L871I;VX@*%-T;VIA;B!097-O=B`\<W-P0&5U<F5K82YC
M;VTN;6L^*2X*6VUI<ET@1FEX(&$@8G5G('1H870@:6YC;W)R96-T;'D@<75O
M=&5S('!R968@=F%L=65S("A"=6<@(S$R,C0I"EMC:FA=($9I>"!A(&)U9R!T
M:&%T('!R979E;G1E9"!L;V=G:6YG+@I;;6US72!$0B!S97-S:6]N(&AA;F1L
M97)S(&1O(&YO="!U<V4@<&5R<VES=&5N="!C;VYN96-T:6]N<R!B>2!D969A
M=6QT+@H*"BTM+2TM+0IV,BXR+C,*+2TM+2TM"@I;;6US72!&:7@@<&%R<V4@
M97)R;W(@:6X@2&]R9&5?0VEP:&5R7T)L;V-K36]D95]O9F(V-#HZ+@H*"BTM
M+2TM+0IV,BXR+C(*+2TM+2TM"@I;;6US72!/<'1I;6EZ871I;VX@;V8@4V5C
M<F5T.CH@86YD($AO<F1E7T-I<&AE<CHZ(&1R:79E<G,N"EMJ86Y=($%D9"!#
M871A;&%N('1R86YS;&%T:6]N("A!;F=E;',@1W5I;65RX"`\86YG96QS+D=U
M:6UE<F%`=6%B+F5S/BDN"EMM;7-=($%D9&5D(&$@4D%$2553($%U=&@Z.B!D
M<FEV97(N"EMM:7)=($%D9&5D(&$@4V%M8F$@075T:#HZ(&1R:79E<BX*6V-J
M:%T@061D960@=&AE($AO<F1E7TEM86=E.CH@8VQA<W,N"@H*+2TM+2TM"G8R
M+C(N,0HM+2TM+2T*"EMJ86Y=($9I>"!I;F-O;7!A=&EB:6QI='D@=VET:"!0
M2%`@/"`T+C(N,"!I;B!T:&4@4U%,(%9&4R!D<FEV97(N"EMJ86Y=($9I>"!U
M;F1E9FEN960@=F%R:6%B;&4@:6X@0VEP:&5R+G!H<"`H8VIH*2X*6VUM<UT@
M0V]M<&QE=&4@;65R9VEN9R!O9B!344P@<V5S<VEO;B!H86YD;&5R+@H*"BTM
M+2T*=C(N,@HM+2TM"@I;8VIH72!!9&0@<W5P<&]R="!F;W(@=7-E<BUD969I
M;F5D('-E<W-I;VX@:&%N9&QE<G,*("`@("`@*$UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUA8UT@0VAA;F=E(%-E8W)E=#HZ
M(&9R;VT@=7-I;F<@4$5!4B!#<GEP=%](0T5-1#4@=&\@=&AE($AO<F1E7T-I
M<&AE<B!C;&%S<RX*6VUA8UT@061D($AO<F1E7T-I<&AE<CHZ(&-L87-S('1O
M('!R;W9I9&4@82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@=&\*("`@
M("`@=F%R:6]U<R!#:7!H97)S(&9O<B!E;F-R>7!T:6]N(&]F(&%R8FET<F%R
M>2!L96YG=&@@<&EE8V5S(&]F(&1A=&$N"EMM;7-=($-O<G)E8W1L>2!G970@
M8VAA<G-E="!I;F9O<FUA=&EO;B!F;W(@34E-15]087)T<R!I;B!-24U%7U-T
M<G5C='5R92X*6VIA;ET@061D($QA='9I86X@=')A;G-L871I;VX@*$MA<W!A
M<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL=CXI+@I;:F%N72!!9&0@4F]M
M86YI86X@=')A;G-L871I;VX@*$-O<FYE;&EU($U54T%4(#QC;75S871`=&EA
M;6%T+FME>7-Y<RYR;SXI+@I;:F]N72!!9&1E9"!S=7!P;W)T(&9O<B!A;B`\
M97)E9CX@96YT:71Y('1O('1H92!H96QP('-Y<W1E;2X@(%1H:7,@86QL;W=S
M(&%N"B`@("`@(&5X=&5R;F%L(&QI;FL@=&\@8F4@96UB961D960@:6X@82!H
M96QP(&5N=')Y+B`H/&<N:&]R=$!U;G-W+F5D=2YA=3XI"EMC:FA=(%)E;F%M
M92!61E,Z.B!T;R!(;W)D95]61E,Z.B!F;W(@4$5!4B!P86-K86=I;F<N"EMC
M:FA=(%9&4SHZ(&ES(&YO=R!P86-K86=E9"!S;R!T:&%T(&ET(&-A;B!B92!E
M>'!O<G1E9"!A<R!A(%!%05(@8V]M<&]N96YT+@I;8VIH72!!9&0@82!M=6QT
M:2UU<V5R(%-13"!61E,@8F%C:V5N9"`H36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CXI+@I;8VIH72!4:&4@5D93(&%P:2!N;W<@8V]N
M<VES=&5N=&QY('1A:V5S(&$@=&5M<"!F:6QE(&EN('1H92!W<FET92@I(&UE
M=&AO9`H@("`@("!A8W)O<W,@86QL(&)A8VME;F1S("A-:6-H865L(%9A<F=H
M97-E(#QM:6ME+G9A<F=H97-E0&%S8V5L;&%T96-H+F-O;3XI+@I;8VIH72!!
M9&0@82!61E,@05!)(&9O<B!S=&]R86=E(&]F(&9I;&5S(&EN(&%N(&%B<W1R
M86-T960@9FEL97-Y<W1E;2X*6V-J:%T@061D(&$@<')E9F5R96YC92!T;R!A
M;&QO=R!M86EN=&5N86YC92!O<',@=VET:"!N;R!C;VYF:7)M871I;VX@<V-R
M965N"EMC:FA=(%)E<&QA8V4@)W-H;W<G(&%T=')I8G5T92!I;B!T:&4@<F5G
M:7-T<GD@=VET:"!A(&UO<F4@9FQE>&EB;&4@)W-T871E)PH@("`@("!A='1R
M:6)U=&4N"EMJ86Y=($%L;&]W('-E='1I;F<@=&AE(&YU;6)E<B!O9B!C;VQU
M;6YS(&EN('1H92!S=6UM87)Y('-C<F5E;B!A<R!A('5S97(*("`@("`@<')E
M9F5R96YC92`H0G)I86X@2V5I9F5R(#QB<FEA;D!V86QI;F]R+FYE=#XI+@I;
M8VIH72!!9&0@2&]R9&4Z.F=E=$=E="@I(&%N9"!(;W)D93HZ9V5T4&]S="@I
M+@I;8VIH72!!9&0@86X@:6YI=&EA;%]A<'!L:6-A=&EO;B!P<F5F97)E;F-E
M('-O('5S97)S(&-A;B!S96QE8W0@86X@87!P"B`@("`@('1O(&)E('1A:V5N
M('1O(&EN<W1E860@;V8@=&AE($AO<F1E(%-U;6UA<GD@;VX@;&]G:6XN"EMC
M:FA=($UA:V4@=&5X="P@:6-O;BP@;W(@8F]T:"!M96YU<R!A('5S97(@<')E
M9F5R96YC90H@("`@("`H2V%A;$@A(#QK86%L:$!S;6]L+F]R9SXI+@I;8VIH
M72!!9&0@82!P87)A;65T97(@9F]R('-E='1I;F<@=&AE('-E<W-I;VX@=&EM
M96]U="X*6V-J:%T@061D(&$@<&%R86UE=&5R(&9O<B!S971T:6YG('1H92!S
M97-S:6]N(&1E;&EM:71E<BX*6VUM<UT@061D($U)345?36%G:6,Z.F9I;&5N
M86UE5&]-24U%*"DN"EMJ86Y=(%5S92!A<F=?<V5P87)A=&]R+F]U='!U="!I
M;G-T96%D(&]F(&AA<F1C;V1I;F<@)R8G("A$879I9"!5;&5V:71C:`H@("`@
M("`\9&%V:61U0&5V97)Y9&YS+FYE=#XI+@I;:F%N72!!9&0@3F]T:69I8V%T
M:6]N.CIC;W5N="@I("A$879I9"!5;&5V:71C:"`\9&%V:61U0&5V97)Y9&YS
M+FYE=#XI+@I;8VIH72!!9&0@075T:#HZ:7-!9&UI;B@I+@I;8VIH72!!;&QO
M=R!L;V%D:6YG(&]F('-U8BUC;&%S<V5S(&9R;VT@<V5V97)A;"!A9&1I=&EO
M;F%L('-O=7)C97,N"EMJ86Y=(%)E;6]V92!R969E<F5N8V5S('1O(&YO="!Y
M970@<F5L96%S960@87!P;&EC871I;VYS("A';VQL96TL(%1R;VQL*2X*6V-J
M:%T@4F5W<FET92!#871E9V]R>5]S<6P@:6UP;&5M96YT871I;VX@=&\@8F4@
M;75C:"!M;W)E(&5F9FEC:65N="X*6VIA;ET@061D($QI=&AU86YI86X@=')A
M;G-L871I;VX@*$1A<FEU<R!-871U;&EA=7-K87,@/&1A<FEU<T!L;FLN;'0^
M*2X*6VUM<UT@061D($AO<F1E.CIC;VUP<F5S<T]U='!U="@I+@I;;6US72!!
M9&0@82!K97)B97)O<R!!=71H.CH@9')I=F5R+@I;:F%N72!!9&0@0G5L9V%R
M:6%N('1R86YS;&%T:6]N("A-:7)O<VQA=B!096YD978@/'!E;F1E=D!H;W1M
M86EL+F-O;3XI+@I;:F%N72!296UO=F4@9&5P<F5C871E9"!$0CHZ:7-787)N
M:6YG*"D@8V%L;',N"EMM;7-=($%D9"!(;W)D93HZ8W)E871E5&5M<$1I<B@I
M+@I;8VIH72!!9&0@2&]R9&4Z.G5S:6YG4U-,0V]N;F5C=&EO;B@I+@I;8VIH
M72!297!L86-E(#P_/2!W:71H(#P_<&AP(&5C:&\@=&\@<F5M;W9E('1H92!S
M:&]R=%]O<&5N7W1A9W,@<F5Q=6ER96UE;G0N"EMJ86Y=($%D9"!497AT.CIT
M;TA434PH*2P@5&5X=#HZ:&EG:&QI9VAT475O=&5S*"D@86YD(%1E>'0Z.F1I
M;5-I9VYA='5R92@I+@I;8VIH72!!9&0@4F5G:7-T<GDZ.FQI<W1!<'!S*"DN
M"EMC:FA=($%D9"!0<F5F<SHZ9V5T4')E9B@I(&9O<B!G971T:6YG('!R969E
M<F5N8V5S(&9O<B!S;VUE;VYE(&]T:&5R('1H86X@=&AE"B`@("`@(&QO9V=E
M9"UI;B!U<V5R+@I;8VIH72!!9&0@=&AE(&%B:6QI='D@=&\@;&]A9"!I9&5N
M=&ET:65S(&9O<B!S;VUE;VYE(&]T:&5R('1H86X@=&AE(&QO9V=E9"UI;@H@
M("`@("!U<V5R+@I;;6US72!!9&0@2&]R9&4Z.G)E;6]V95!A<F%M971E<B@I
M+@I;;6US72!!;&P@8G)O=W-E<B!H96%D97)S(&9O<B!D;W=N;&]A9&EN9R!A
M(&9I;&4@:&%V92!B965N(&UO=F5D('1O('1H90H@("`@("!"<F]W<V5R.CH@
M8VQA<W,N"EMJ86Y=($%D9"!D971E8W1I;VX@9F]R(%541B!C87!A8FEL:71Y
M('1O($)R;W=S97(@8VQA<W,N"EMM;7-=($%D9&5D(&EM86=E<R!-24U%7U9I
M97=E<BX*6V)J;ET@061D(%!O<W1G<F5344P@8V]M;6%N9"!F;&%G("A2:6-H
M87)D($<@2V]N;&]N(#Q21TMO;FQO;D`Q36%I;%!L86-E+F-O;3XI+@H*"BTM
M+2T*=C(N,0HM+2TM"@I;:F%N72!!9&0@2'5N9V%R:6%N('1R86YS;&%T:6]N
M("A,87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU/BDN
M"EMJ86Y=($%D9"!.;W)W96=I86X@3GEN;W)S:R!T<F%N<VQA=&EO;B`H4&5R
M+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N;W)G/BDN"EMJ;VY=($UA:F]R(&]V
M97)H875L('1O('1H92!,1$%0('!R969E<F5N8V5S(&1R:79E<BX@3F]T92!T
M:&4@8VAA;F=E<R!T;PH@("`@("!C;VYF:6<O:&]R9&4N<&AP(&%N9"!S8W)I
M<'1S+VQD87`O:&]R9&4N<V-H96UA('=H96X@=7!G<F%D:6YG+@I;:F%N72!!
M9&0@4VQO=F5N:6%N('1R86YS;&%T:6]N("A*=7)E($MR87-O=FEC(#QJ=7)E
M:T!R8V,M:7)C+G-I/BDN"EMC:FA=($%D9"!A($AO<F1E('!R969E<F5N8V5S
M('-C<F5E;BP@86YD(&$@<')E9F5R96YC92!T;R!R969R97-H('1H92!S=6UM
M87)Y"B`@("`@('-C<F5E;BX*6V-J:%T@061D('1E>'0O96YR:6-H960@34E-
M15]6:65W97(*("`@("`@*$5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E
M<D!P:'ES:6-S+G5T97AA<RYE9'4^*2X*6VIA;ET@26UP<F]V92!L86YG=6%G
M92!S96QE8W1I;VXN"EMJ86Y=($%D9"!*87!A;F5S92!T<F%N<VQA=&EO;B`H
M0BY*+B!";&%C:R`\=VEL;&EA;2YB;&%C:T!S=6XN8V]M/BDN"EMC:FA=($-L
M;W-E(&$@<&]T96YT:6%L('!R;V)L96T@=VET:"!R96=I<W1E<E]G;&]B86QS
M($]N(&%N9"`D:G-?;VY,;V%D+@I;:F%N72!!9&0@4')E9G,Z.FES1&5F875L
M="@I(&UE=&AO9"!T;R!D971E<FUI;F4@:68@82!P<F5F97)E;F-E)W,@=F%L
M=64@:7,*("`@("`@<V5T(&)Y('1H92!U<V5R(&]R('1H92!D969A=6QT('9A
M;'5E(&9R;VT@<')E9G,N<&AP+@I;:F]N72!/=F5R:&%U;&5D($Q$05`@<')E
M9F5R96YC97,@9')I=F5R+@I;8VIH72!-86ME($AO<F1E.CID:7-P96Q-86=I
M8U%U;W1E<R@I(')E8W5R<VEV92P@<V\@=&AA="!I="!H86YD;&5S(&%R<F%Y
M<RX*6V-J:%T@2&%V92!396-R970Z.G-E=$ME>2@I(&-H96-K(&9O<B!T:&4@
M<V5S<VEO;B!C;V]K:64@97AP;&EC:71L>2P@=&\@879O:60*("`@("`@<')O
M8FQE;7,@=VET:"!O;&0@8V]O:VEE<R!B96EN9R!S96YT('1O(&$@<VET92!W
M:&5N('1H97D@87)E(')E86QL>0H@("`@("!D:7-A8FQE9"X*6V-J:%T@061D
M(&$@4')E9G-522!C;&%S<R!F;W(@:&%N9&QI;F<@=&AE(&9O<FT@<')O8V5S
M<VEN9R!A;F0@54D@9V5N97)A=&EO;@H@("`@("!F;W(@=7-E<B!P<F5F97)E
M;F-E<SL@=&AI<R!C;V1E('=A<R!D=7!L:6-A=&5D(&%L;"!T:')O=6=H($AO
M<F1E+@I;8VIH72!!9&0@82!M87!P:6YG(&9U;F-T:6]N('1O('1H92!E;G-C
M<FEP="!D<FEV97(@=VAI8V@@;6%P<R!F:6QE"B`@("`@(&5X=&5N<VEO;G,@
M=&\@96YS8W)I<'0@;&%N9W5A9V4@8V]D97,L(&%N9"!P87-S('1H92!L86YG
M=6%G90H@("`@("!D:7)E8W1L>2!T;R!E;G-C<FEP="P@=&\@879O:60@:&%V
M:6YG('1O('5S92!A(&9I;&4@97AT96YS:6]N+@I;8VIH72!&:7@@34E-15]-
M86=I8SHZ34E-151O17AT*"D@=&\@=V]R:R!W:71H('@M97AT96YS:6]N+V5X
M="!T>7!E<RX*6V-J:%T@061D($U)345?36%G:6,Z.DU)3454;T5X="@I('1O
M(&UA<"!-24U%('1Y<&5S('1O(&9I;&4@97AT96YS:6]N<RX*6V-J:%T@4F5W
M<FET92!097)M<SHZ('1O('5S92!T:&4@0V%T96=O<FEE<R!B86-K96YD+@I;
M:F%N72!#:&%N9V4@=&AE($YO<G=E9VEA;B!";VMM86P@;&]C86QE(&9R;VT@
M;F]?0D]+('1O(&YB7TY/(&%N9"!M86ME(&ET('1H90H@("`@("!D969A=6QT
M(&QA;F=U86=E(&9O<B!.;W)W96=I86X@=7-E<G,N"EMC:FA=($UA:V4@2&]R
M9&4G<R!L;V=I;B!S8W)E96X@;FEC97([(&EN8VQU9&4@<F5A<V]N<R!I;B!I
M="X*6V-J:%T@57-E($A/4D1%7U1%35!,051%4R!F;W(@86QL('1E;7!L871E
M('!A=&AS+@I;8VIH72!5<V4@)')E9VES=')Y+3YG970H*2!F;W(@86QL(%)E
M9VES=')Y(&EN9F]R;6%T:6]N+@I;8VIH72!296UO=F5D(&%D;6EN:7-T<F%T
M:6]N(&-O9&4@=VAI8V@@:7,@:6YC;VUP;&5T92!A;F0@8V]N9G5S:6YG('1O
M('5S97)S+@I;:F%N72!!9&0@17-T;VYI86X@=')A;G-L871I;VX@*%1O;VUA
M<R!!87,@/'1O;VUA<RYA87-`<F%A9"YT87)T=2YE93XI+@I;:F%N72!!9&0@
M4VQO=F%K('1R86YS;&%T:6]N("A,96\@37)A9FMO(#QL96]`;V5L+G-K/BDN
M"EMJ;VY=($5N86)L92!T:&4@(G!O<G1A8FEL:71Y(B!O<'1I;VX@:6X@=&AE
M(%!%05(@1$(@*'-Q;"D@9')I=F5R<RX*6V-J:%T@57-E($AO<F1E)W,@)VEN
M:71I86Q?<&%G92<@8V]N9FEG=7)A=&EO;B!V86QU92!I;B!T:&4@2&]R9&4@
M9G)A;65S970N"EMJ86Y=($%D9"!0;W)T=6=U97,@=')A;G-L871I;VX@*$YU
M;F\@3&]U<F5I<F\@/&YU;F]`971H+G!T/BDN"EMJ86Y=(%)E8G5I;&0@=&AE
M(&QA;F=U86=E('-E;&5C=&EO;B!L;V=I8RX@5&AE(&QA;F=U86=E('-E;&5C
M=&5D(&]N('1H92!L;V=I;@H@("`@("!S8W)E96X@:7,@;F]W(')E<W!E8W1E
M9"!A;F0@=&AE('-I=&4G<R!S=&%N9&%R9"!L86YG=6%G92!I<R!D969I;F5D
M(&EN"B`@("`@(&QA;F<N<&AP(&EN<W1E860@;V8@96%C:"!A<'!L:6-A=&EO
M;B=S('!R969E<F5N8V5S+@I;:F%N72!!9&0@:F%V87-C<FEP="!T;R!S970@
M=&AE(&9R86UE<V5T)W,@<&%G92!T:71L92`H36EC:&%E;"!#;V-H<F%N90H@
M("`@("`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CXI+@I;:F%N72!!9&0@56MR
M86EN:6%N('1R86YS;&%T:6]N("A!;F1R:7D@2V]P>7-T>6%N<VMY(#QA;G)I
M0'!O;'EN970N;'9I=BYU83XI+@I;:F%N72!5<&1A=&4@9V5T=&5X="!D;V-U
M;65N=&%T:6]N(&%N9"!-86ME9FEL97,@9F]R(%-O;&%R:7,@86YD($1E8FEA
M;BX*6VIO;ET@36%I;G1E;F%N8V4@9FEX97,@9G)O;2!-:6-H865L($T@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3XN"EMJ86Y=($%D
M9"!$86YI<V@@=')A;G-L871I;VX@*$UA<G1I;B!,:7-T+5!E=&5R<V5N(#QM
M87)T:6Y`;&ES="UP971E<G-E;BYD:SXI+@H*"BTM+2T*=C(N,`HM+2TM"@I;
M:F%N72!!9&0@3F]R=V5G:6%N($)O;VMM86P@=')A;G-L871I;VX@*$]Y<W1E
M:6X@4W1E:6UL97(@/&]Y<W1E:6Y`<F5X=&$N;F5T/BDN"EMA=G-M72!!9&0@
M+FAT86-C97-S(&9I;&5S('1O(&1E;GD@86-C97-S('1O(&1A=&$@9&ER96-T
M;W)I97,N"EMJ86Y=($%D9"!&:6YN:7-H('1R86YS;&%T:6]N("A,965N82!(
M96EN;R`\;&EI;G5`=71A+F9I/BDN"EMC:FA=($9I>"!O;F4@;&%S="!P<F]B
M;&5M('=I=&@@4$]0,R!A;F0@;75L=&EP87)T+V%L=&5R;F%T:79E(&%T=&%C
M:&UE;G1S+@H*"BTM+2TM+2TM"G8R+C`M4D,T"BTM+2TM+2TM"@I;<FEC:%T@
M26YC;'5D92!R97=R:71T96X@86YD(')E;W)G86YI>F5D(&1O8W5M96YT871I
M;VXN"EMC:FA=($%D9"!A;B!-4U!O=V5R<&]I;G0@34E-15]6:65W97(N"EMJ
M86Y=(%1H92!L86YG=6%G92!C;V]K:64@=V%S(')E;6]V960@:6X@9F%V;W(@
M;V8@;F5W(&UE=&AO9',@:6X@=&AE($QA;F<Z.@H@("`@("!C;&%S<R!T:&%T
M('-E;&5C="!T:&4@;&%N9W5A9V4@86YD('-E="!T:&4@9V5T=&5X="!D;VUA
M:6XN"EMA=G-M72!);F-L=61E($-H;W)A(&EN('1H:7,@<F5L96%S92!C>6-L
M92P@8G5T(&YO="!S:&]W:6YG(&EN('1H92!T;V]L8F%R+@I;8VIH72!!9&0@
M34E-15]6:65W97)?>FEP+@I;8VIH72!4<FEM(')E9VES=')Y+G!H<"YD:7-T
M('1O(&]N;'D@;&ES="!A<'!S(&EN('1H:7,@<F5L96%S92!C>6-L92X*6VIA
M;ET@061D(&1E;&5T94]B:F5C="@I(&UE=&AO9"!T;R!T:&4@4V5S<VEO;D-A
M8VAE(&-L87-S+@I;8FIN72!#:&%N9V4@)V5N)R!A;F0@)V5N7T5.)R!L;V-A
M;&5S('1O("=E;E]54R<@*&1E9F%U;'0I+@H*"BTM+2TM+2TM"G8R+C`M4D,S
M"BTM+2TM+2TM"@I;8VIH72!296-O9VYI>F4@82!F97<@4&%L;2YN970@8G)O
M=W-E<G,@86YD('-E="!Q=6ER:W,O9F5A='5R97,@86-C;W)D:6YG;'DN"EMC
M:FA=(%-U<'!O<G0@9F]R(&%D9&EN9R!A;F0@;&ES=&EN9R!,1$%0('5S97)S
M(&=I=F5N(&$@<V5T('-C:&5M82X*6V-J:%T@4V5T('1H92!S97-S:6]N(&-O
M;VMI92!P87)A;65T97)S('=I=&@@;W5R(&-O;VMI95]P871H+V-O;VMI95]D
M;VUA:6X*("`@("`@<V5T=&EN9W,N(%1H:7,@;65A;G,@=&AA="!Y;W4@8V%N
M(&)E(&QO9V=E9"!I;G1O(&UU;'1I<&QE($AO<F1E"B`@("`@(&EN<W1A;&QA
M=&EO;G,@;VX@=&AE('-A;64@<V5R=F5R("AD:69F97)E;G0@<&%T:',I(&%N
M9"!N;W0@:&%V92!T:&4*("`@("`@<V5S<VEO;G,@:6YT97)F97)E+@I;8VIH
M72!5<V4@)VAO<W1S<&5C)R!C;VYS:7-T96YT;'D@:6X@075T:"!D<FEV97)S
M+@H*"BTM+2TM+2TM"G8R+C`M4D,Q"BTM+2TM+2TM"@I;:F%N72!!9&0@0G)A
M>FEL:6%N(%!O<G1U9W5E<V4@=')A;G-L871I;VX@*$-A<FQO<R!$86YI96P@
M2VEB<FET(#QK:6)R:71`=&5R<F$N8V]M+F)R/BDN"EMJ86Y=($%D9"!'<F5E
M:R!T<F%N<VQA=&EO;B`H4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS9&EM:71R
M:4!T96EA=&@N9W(^*2X*6VIA;ET@061D('9#87)D($U)344@9')I=F5R+B!#
M:&%N9V5D(&-O;F9I9R]M:6UE7V1R:79E<G,N<&AP+F1I<W0N"EMJ86Y=($%D
M9"!3=V5D:7-H('1R86YS;&%T:6]N("A!;F1R96%S($1A:&SI;B`\86YD<F5A
M<T!D86AL96XN=W,^*2X*6VIA;ET@061D($MO<F5A;B!T<F%N<VQA=&EO;B`H
M2BY)($MI;2`\87!O<FEE0&YE=&EA;BYC;VT^*2X*"@HM+2TM+2T*=C$N,RXU
M"BTM+2TM+0H*6VIO;ET@061D960@)&9I;&4@86YD("1L:6YE('!A<F%M971E
M<G,@=&\@2&]R9&4Z.F9A=&%L*"DN"EMJ;VY=(%)E;6]V960@=&AE(%!21493
M7RH@86YD($%55$A?*B!C;VYS=&%N=',@:6X@9F%V;W(@;V8@4$5!4E]%<G)O
M<B!O8FIE8W1S+@I;879S;5T@1&]N)W0@9&5P96YD(&]N('1H92!R96=I<W1R
M>2!B96EN9R!A=F%I;&%B;&4@=VAE;B!D:7-P;&%Y:6YG"B`@("`@('1H92`G
M2&]R9&4@:7,@;F]T(&-O;F9I9W5R960G(&UE<W-A9V4N"EMC:FA=($-L96%N
M('5P('1H92!)9&5N=&ET>2!C;&%S<R!T;R!B92!A(&=E;F5R86QI>F5D+"!C
M;&5A;B!P:65C92!O9B!T:&4*("`@("`@9G)A;65W;W)K('1H870@8V%N(&)E
M('5S960@:6X@;W1H97(@87!P<R!A;F0@<W5B8VQA<W-E9"!I9B!N96-E<W-A
M<GDN"EMC:FA=($UA:V4@9F%I;'5R92!T;R!C;VYN96-T('1O('1H92!P<F5F
M97)E;F-E<R!D871A<V]U<F-E(&$@9F%T86P@97)R;W(N"EMC:FA=($%D9&5D
M('1H92!397)I86QI>F4Z.B!C;&%S<R!F;W(@=F%R:6]U<R!M971H;V1S(&]F
M(&5N8V%P<W5L871I;F<@9&%T80H@("`@("`H<W1E<&@@/'-H=71H97)`>6%H
M;V\N9G(^*2X*6V-J:%T@061D960@=&AE(&-A<&%B:6QI='D@=&\@9V5T(&%U
M=&AE;G1I8V%T:6]N(&-R961E;G1I86QS(&]T:&5R('1H86X*("`@("`@=7-E
M<FYA;64@8F%C:R!F<F]M('1H92!!=71H(&9R86UE=V]R:RP@86YD(&-O;7!L
M971E9"!T:&4*("`@("`@875T:&5N=&EC871I;VX@<F5A;&T@9G5N8W1I;VYA
M;&ET>2X*6VIO;ET@06QL;W<@=&AE('1A8FQE(&-E;&P@86YD(&QI;FL@0U-3
M(&-L87-S97,@=&\@8F4@<W!E8VEF:65D('=H96X@8W)E871I;F<*("`@("`@
M;65N=2!I=&5M<RX*6VIA;ET@061D(')E9VES=')Y(&UE=&AO9"!F;W(@;&EN
M:VEN9R!T;R!A(&YA9R!T87-K+@I;:F%N72!!9&0@:61E;G1I='D@8VQA<W,N
M"EMM87A=($%D9"!296=I<W1R>3HZ9V5T3F%M92@I(&9O<B!Q=65R>6EN9R!A
M<'!L:6-A=&EO;B!N86UE<RX*6V-J:%T@2&]R9&4@;F]W('!R;W9I9&5S('1H
M92!(;W)D93HZ;&]G365S<V%G92@I(&UE=&AO9"!F;W(@;&]G9VEN9R!O9@H@
M("`@("!I;F9O<FUA=&EO;B!A8V-O<F1I;F<@=&\@8V]N9FEG=7)A8FQE('!R
M:6]R:71I97,L(&5T8RX*6VIA;ET@061D(&9U;F-T:6]N86QI='D@=&\@;6%P
M(&1A=&4@86YD('1I;64@9FEE;&1S('1O('1H92!$871A(&-L87-S+@I;8VIH
M72!!9&0@=&AE(&)E9VEN;FEN9W,@;V8@82!U<V5R(&%D;6EN:7-T<F%T:6]N
M('-Y<W1E;2X*6V-J:%T@061D($-H:6YE<V4@*%1R861I=&EO;F%L*2!T<F%N
M<VQA=&EO;B`H1&%V:60@0VAA;F<*("`@("`@/&1A=FED0'1H8G5O+F=O=BYT
M=SXI+@I;:F%N72!!9&0@271A;&EA;B!T<F%N<VQA=&EO;B`H1VEO=F%N;FD@
M365N96=H971T:2`\9VUE;F5G:&5T=&E`:6YF=FEC+FET/BDN"EMJ86Y=($%D
M9"!$871A(&-L87-S(&9O<B!I;7!O<G1I;F<@86YD(&5X<&]R=&EN9R!D871A
M+@I;:F]N72!#;&5A;F5D('5P('1H92!H96QP('-Y<W1E;2!A(&)I="X*6V-J
M:%T@061D($AO<F1E.CIF871A;"@I(&9O<B!D:7-P;&%Y:6YG(%!%05)?17)R
M;W(@;V)J96-T<R!A;F0@86)O<G1I;F<N"EMA=G-M72!%>'1E;F0@2&]R9&4Z
M.F=E=%1E;7!&:6QE*"D@=&\@86QL;W<@9&ER96-T;W)Y('1O(&)E(&]V97)R
M:61D96XN"EMA=G-M72!!;&QO=R!T96UP;W)A<GD@9FEL97,@=&\@8F4@=6YR
M96=I<W1E<F5D(&9R;VT@9&5L971I;VXN"EMA=G-M72!!9&0@82!#86-H92!F
M<F%M97=O<FL@9F]R('!E<G-I<W1E;G1L>2!S=&]R:6YG(&]B:F5C=',L(&%L
M;VYG"B`@("`@("!W:71H(&$@9FEL97-Y<W1E;2!D<FEV97(N"EMJ86Y=($%D
M9"!0;VQI<V@@=')A;G-L871I;VXN"EMC:FA=($9I>"!A('!R;V)L96T@=VET
M:"`D<F5G:7-T<GDM/F-A;&PH*2!A;F0@<W=I=&-H:6YG(&%P<&QI8V%T:6]N
M"B`@("`@(&-O;G1E>'1S+@I;8VIH72!'970@<FED(&]F('1H92!I;G9O:V4H
M*2!M971H;V1S(&EN('1H92!R96=I<W1R>2X*6V-J:%T@1&]N)W0@<F4M:6YC
M;'5D92!A<'!L:6-A=&EO;B!C;VYF:6<@9FEL97,[('-A=F4@8V]N9FEG<R!I
M;B!A(&-A8VAE('-O"B`@("`@('1H870@=V4@8V%N(&IU<W0@<&]I;G0@)$=,
M3T)!3%-;)V-O;F8G72!A="!T:&4@;VQD(&-O;F9I9R!O;@H@("`@("`D<F5G
M:7-T<GDM/G!O<$%P<"@I+"!E=&,N"EMJ86Y=($%D9"!&<F5N8V@@=')A;G-L
M871I;VX@*$9R961E<FEC(%1R=61E874@/&9T<G5D96%U0$-!32Y/4D<^*2X*
M6V-J:%T@061D($-Z96-H('1R86YS;&%T:6]N("AP8VAY=&EL0&%S<"YO9VDN
M961U*2X*6VIA;ET@061D(&YE=R!T:6UE>F]N92!H86YD;&EN9R!W:71H(&-L
M96%R=&5X="!T:6UE>F]N92!N86UE<R!I;B!L86YG+G!H<"X*6V-J:%T@061D
M(%)U<W-I86X@=')A;G-L871I;VX@*$EG;F%T($EK<GEA;F]V(#QI9VYA=$!I
M8F0N<G4^*2X*6VIO;ET@3F5W(&UE=&AO9',@:6X@0G)O=W-E<BYP:'`@9F]R
M(')E=')I979I;F<@=F5R<VEO;G,N(#QI>GIY0'%U;7)A;BYO<F<^"EMJ;VY=
M($)R;W=S97(N<&AP(&YO=R!D971E8W1S($]P97)A+B`\:7IZ>4!Q=6UR86XN
M;W)G/@I;8VIH72!-;W9E('1H92!L86YG=6%G92!A;F0@8VAA<G-E="!D969A
M=6QT<R!I;G1O(&-O;F9I9R]L86YG+G!H<"P@86YD(&%D9"!A"B`@("`@(%)E
M9VES=')Y(&UE=&AO9"!T;R!G970@=&AE(&-U<G)E;G0@8VAA<G-E="X*6V-J
M:%T@36%P(&)R;W=S97(@8V]D97,@<W5C:"!A<R`G;FPG('1O('1H92!F=6QL
M(&-O9&4@*"=N;%].3"<L(&5T8RXI+@I;879S;5T@4F5P;&%C92`D8V]N9ELG
M<&%T:',G72!W:71H('1H92`D<F5G:7-T<GD@97%U:79A;&5N=',N"EMA=G-M
M72!!9&0@9F]U<B!R96=I<W1R>2!F=6YC=&EO;G,@=&\@<75E<GD@=V5B<F]O
M=',@86YD('!A=&AS+@I;879S;5T@36%N>2!-24U%7U9I97=E<B!C:&%N9V5S
M.B!!4$D@='=E86MS+"!N97<@9')I=F5R<RP@=V]R:W,@=VET:"!)35`N"EMC
M:FA=("1C;VYF6R=U<V5R)UU;)V]N;&EN95]H96QP)UT@:7,@;F]W(&$@2&]R
M9&4M;&5V96P@<V5T=&EN9RX*6V%V<VU=($5N86)L92!A<'!L:6-A=&EO;G,@
M=&\@:&%V92!L;V-A;"!-24U%7U9I97=E<B!D<FEV97)S(&EN(&%D9&ET:6]N
M"B`@("`@("!T;R!T:&4@9VQO8F%L($AO<F1E(&]N97,N"EMA=G-M72!3:'5F
M9FQE(&%R;W5N9"!T:&4@34E-15]6:65W97(@05!).B!G971$<FEV97(H*2!I
M<R!N;W<@<')I=F%T90I;879S;5T@061D(&%N("=I;FET:6%L7W!A9V4G(&]P
M=&EO;B!T;R!T:&4@<F5G:7-T<GDL('1O(&QE="!U<R!L:6YK(&EN=&\*("`@
M("`@86YY('!A9V4@:6YS:61E(&%N(&%P<&QI8V%T:6]N+@I;8VIH72!!9&0@
M82!F<F%M97=O<FLM;&5V96P@8F%S92YP:'`@9FEL92!A;F0@;6%K92!F<F%M
M97=O<FL@<V-R:7!T<R!U<V4@:70N"EMC:FA=($%D9"!R92UO<F=A;FEZ960@
M8G5T('-T:6QL(&UO<W1L>2!O=70@;V8@9&%T92!(14Q0+TQ)4U13+U-/55)#
M12!F:6QE<PH@("`@("`H2F]S:"!-:6QL97(@/&IO<VAL:7-T<T!N96)O;F5T
M+F-O;3XI+@I;8VIH72!!9&0@82!P87)A;65T97(@=&AA="!D971E<FUI;F5S
M('=H971H97(@;W(@;F]T(&%P<',@87)E(&QI;FME9"!O;B!T:&4*("`@("`@
M2&]R9&4@;65N=6)A<BX*6V-J:%T@0VQE87(@=&AE('=H;VQE('-E<W-I;VX@
M=VAE;B!T:&4@=7-E<B!L;V=S(&]U="!O9B!(;W)D92X*6VIO;ET@061D960@
M4')E9G,Z.FES16UP='DH*2!F;W(@9&5T97)M:6YI;F<@=VAE=&AE<B!A('!R
M969E<F5N8V4@:7,@96UP='DN"EMJ;VY=($%D9&5D(&%N("1O;F-L:6-K('!A
M<F%M971E<B!T;R!(;W)D93HZ;&EN:R@I(&9O<B!S<&5C:69Y:6YG(&%N(&%N
M8VAO<B=S"B`@("`@("=O;F-L:6-K)R!*879A4V-R:7!T(&5V96YT+@I;8VIH
M72!5<V4@=&AE("IU<FPH*2!F=6YC=&EO;G,@;6]R92!C;VYS:7-T96YT;'D@
M=&\@;6%K92!S=7)E('1H870*("`@("`@8V]O:VEE+6QE<W,@<V5S<VEO;G,@
M=V]R:RX*6V-J:%T@36]D:69Y(&-S<RYP:'`@=&\@=7-E('1H92!296=I<W1R
M>2!T;R!G970@87!P;&EC871I;VX@9FEL92!P871H<RX*6V-J:%T@061D(&-O
M;VMI95]P871H(&%N9"!C;V]K:65?9&]M86EN('-E='1I;F=S(&9O<B!P96]P
M;&4@=VAO(&ME97`@87!P<PH@("`@("!O=71S:61E(&]F('1H92!(;W)D92!W
M96)R;V]T(&]R(&]N(&UU;'1I<&QE('-E<G9E<G,N"@H*+2TM+2TM"G8Q+C,N
M-`HM+2TM+2T*"EMC:FA=($%D9"!A($AO<F1E('-U;6UA<GD@9G)A;65W;W)K
M+"!W:&EC:"!U<V5S('1H92!296=I<W1R>2!T;R!G970*("`@("`@<W5M;6%R
M:65S(&]F(&%V86EL86)L92!D871A("T@=&%S:W,L(&5V96YT<RP@971C+B`M
M(&9O<B!T:&4@2&]R9&4*("`@("`@;&]G:6X@<V-R965N+@I;8VIH72!4:&4@
M<')E9F5R96YC97,@<V5T=&EN9W,@<VAO=6QD(&)E($AO<F1E+7=I9&4L(&%N
M9"!S;R!H879E(&)E96X@;6]V960@=&\*("`@("`@:&]R9&4O8V]N9FEG+VAO
M<F1E+G!H<"X*6V-J:%T@36]V92!P<F5F<RYG:68@86YD(&=E;F5R:6,@<')E
M9G,@=&5M<&QA=&5S(&EN=&\@2&]R9&4N"EMC:FA=($UO=F4@<V5T=&EN9R!O
M9B!T:&4@9V5T=&5X="!D;VUA:6X@:6YT;R!T:&4@4F5G:7-T<GDN"EMJ;VY=
M(%-I;7!L:69I960@=&AE('!R969E<F5N8V4@<WES=&5M)W,@8VQE86YU<"!F
M=6YC=&EO;G,N"EMJ;VY=($UE<F=E(&1O8W1Y<&4N:6YC(&EN=&\@8V]M;6]N
M+6AE861E<BYI;F,N"EMJ;VY=($%D9&5D(%1E>'0Z.FAT;6QS<&%C97,H*2!A
M;F0@5&5X=#HZ:'1M;&%L;'-P86-E<R@I+@I;8VIH72!!9&0@86X@;W!T:6]N
M('1O($AO<F1E.CIG971496UP1FEL92@I('1O(&YO="!D96QE=&4@=&AE(&9I
M;&4@870@=&AE"B`@("`@(&5N9"!O9B!T:&4@<F5Q=65S="X*6V-J:%T@061D
M(&$@)G-I;F=L971O;B@I(&UE=&AO9"!T;R!T:&4@4F5G:7-T<GD@8VQA<W,N
M"EMJ;VY=($%D9&5D($YA9R!I;G1E<F9A8V4@=&\@=&AE(')E9VES=')Y+@I;
M:F]N72!%>'!A;F1E9"!T:&4@<F5G:7-T<GD@=&\@:&%N9&QE(&EM<&]R=&EN
M9R!A<'!L:6-A=&EO;BUS<&5C:69I8PH@("`@("!C;VYF:6=U<F%T:6]N('9A
M;'5E<RX*6VUA>%T@061D(&%U=&@O;&]G:6X@86YD(&%U=&@O;&]G;W5T(&]P
M=&EO;G,@9F]R($=O;&QE;2!I;B!T:&4@<F5G:7-T<GDN"EMM87A=($%D9"!2
M96=I<W1R>3HZ9V5T365T:&]D(&9U;F-T:6]N+@I;;6%X72!!9&0@8V]N=&%C
M=',O<V]U<F-E<R!S97)V:6-E('1O('1H92!R96=I<W1R>2X*6V-J:%T@4F5N
M86UE('1H92!#;VYN96-T:6]N(&-L87-S97,@=&\@5&]K96XN"EMC:FA=(%)E
M;F%M92!T:&4@3V)J96-T4W1O<F4@8VQA<W,@=&\@4V5S<VEO;D-A8VAE+@I;
M:F]N72!!9&1I;F<@1'5T8V@@;&%N9W5A9V4N"EMA=G-M72!!9&0@:6-O;B!S
M=7!P;W)T('1O('1H92!-24U%7U9I97=E<B!F<F%M97=O<FL*6V%V<VU=(%5P
M9&%T92!T:&4@34E-15]6:65W97(@05!)('1O(&EN8VQU9&4@9V5T1')I=F5R
M*"D@86YD(&=E=$EC;VXH*0I;:F]N72!/=F5R:&%U;&5D('1H92!P<F5F97)E
M;F-E<R!C86-H:6YG('-Y<W1E;2!A(&)I="X*6V-J:%T@57!D871E($)R;W=S
M97(Z.B!T;R!R96-O9VYI>F4@244V+@I;:F]N72!!9&1E9"!(;W)D92UW:61E
M(&%N9"!D<FEV97(M<W!E8VEF:6,@8VQE86YU<"!M971H;V1S('1O('1H92!P
M<F5F97)E;F-E<PH@("`@("!S>7-T96TN"EMC:FA=(%)E;6]V92!T:&4@<W1R
M=&]L;W=E<B@I(&9R;VT@3&%N9SHZ<V5L96-T*"D@=VAI8V@@=V%S('!R979E
M;G1I;F<*("`@("`@<')O<&5R(&QO8V%L92!N86UE<R`H;&EK92!P=%]"4BD@
M9G)O;2!W;W)K:6YG(&-O<G)E8W1L>2X*6VUA>%T@061D960@875T:&5N=&EC
M871I;VX@:&%N9&QE<B!T;R!T:&4@4F5G:7-T<GDN"EMJ;VY=(%1H92`G<V5S
M<VEO;B<@<')E9F5R96YC97,@9')I=F5R(&YO=R!H;VYO<G,@<')E9F5R96YC
M92!S8V]P92X*6VUA>%T@36%D92!S:71E;F%M92!T:71L92!C;VYF:6=U<F%B
M;&4N"EMJ;VY=(%)E=V]R:V5D('1H92!-96YU.CIC=7-T;VU)=&5M*"D@=&\@
M86-C97!T(%!(4"!D871A('-T<G5C='5R97,@:6YS=&5A9`H@("`@("!O9B!A
M('-T<FEN9R!O9B!E;F-O9&5D('!A<F%M971E<G,N"EMA=G-M72!!9&1E9"!-
M24U%7U9I97=E<B!F<F%M97=O<FL@=&\@:&%N9&QE(')E;F1E<FEN9R!F:6QE
M<R!I;G1O($A434P*("`@("`@("AA;F0@;W1H97(I(&9O<FUA=',@:6X@82!U
M<V5R+65X=&5N<VEB;&4@9F%S:&EO;B`H97AP97)I;65N=&%L*0I;879S;5T@
M3F5W($U)345?36%G:6,@86YD(&UI;65?;6%P<&EN9RYP:'`@8V]N9FEG(&9I
M;&4@*&5X<&5R:6UE;G1A;"D*6V%V<VU=(%1W;R!N97<@=&5M<&]R87)Y(&9I
M;&4@:&%N9&QI;F<@9G5N8W1I;VYS+"!(;W)D93HZ9V5T5&5M<$9I;&4H*2!A
M;F0*("`@("`@2&]R9&4Z.F=E=%1E;7!$:7(H*2!T;R!T86ME(&-A<F4@;V8@
M=&AE(&AO=7-E:V5E<&EN9R!O9B!T96UP(&9I;&5S+@I;;6%X72!!9&1E9"!C
M;VYT86-T<R]A9&0@<V5R=FEC92!T;R!R96=I<W1R>2X*6V-J:%T@4F5G:7-T
M<GDZ.F-A;&PH*2!I<R!N;W<@4F5G:7-T<GDZ.FQI;FLH*2X@5&AE<F4@:7,@
M82!N97<*("`@("`@4F5G:7-T<GDZ.F-A;&PH*2!W:&EC:"!A8W1U86QL>2!R
M971U<FYS('1H92!R97-U;'0@;V8@82!F=6YC=&EO;B!C86QL"B`@("`@(&UA
M9&4@=&\@86YO=&AE<B!A<'!L:6-A=&EO;BX*6V-J:%T@1FEX($1"('%U97)Y
M(')E<W5L="!C:&5C:VEN9R!I;B!S<6P@9')I=F5R<RX*6V-J:%T@1FEX(&AE
M;'`@<V\@=&AA="!G96YE<FEC(&AE;'`@;&EN:W,@*&]N(&UE;G4@8F%R<RD@
M<VAO=R!T:&4@=&]P:6,@;&ES=`H@("`@("!C;W)R96-T;'DN"EMC:FA=($UA
M:V4@=&AE(&QO9VEN(&9O<FT@;FEC97(L(&%N9"!A9&0@82!L;V=O=70@;&EN
M:RX*6V-J:%T@36%K92!S=7)E(&%L;"!O9B!T:&4@<W%L(&1R:79E<G,@=7-E
M($1".CIQ=6]T95-T<FEN9R@I(&]N(&%L;"!S=')I;F=S+@I;8VIH72!297!L
M86-E(&$@0&UY<W%L7W%U97)Y*"D@=&AA="!W87,@:&ED:6YG(&EN($-O;FYE
M8W1I;VXO<W%L+G!H<"!W:71H"B`@("`@("1T:&ES+3YD8BT^<75E<GDH*2X*
M6V-J:%T@4F5T=7)N(&)A<V5N86UE*"1L86YG=6%G92D@9G)O;2!,86YG.CI3
M96QE8W0H*2!T;R!A=F]I9"!P;W-S:6)L90H@("`@("!E>'!L;VET<RX*6V-J
M:%T@061D(%)E9VES=')Y.CIH87--971H;V0H*2!F;W(@8VAE8VMI;F<@:68@
M82!P:65C92!O9B!F=6YC=&EO;F%L:71Y(&AA<PH@("`@("!B965N(')E9VES
M=&5R960@=VET:"!(;W)D92X*6VIO;ET@06YO=&AE<B!L87)G92!O=F5R:&%U
M;"!T;R!T:&4@<')E9F5R96YC97,@<WES=&5M+B`@3F]T92!T:&%T('1H90H@
M("`@("!I<T-H86YG96%B;&4H*2!F=6YC=&EO;B!H87,@8F5E;B!R96YA;65D
M(&ES3&]C:V5D*"DN("!4:&5R92!I<R!A;'-O"B`@("`@('-U<'!O<G0@9F]R
M('!R969E<F5N8V4@<V-O<&4@*'9I82!I<U-H87)E9"@I(&%N9"!S9713:&%R
M960H*2DN"EMJ;VY=($%D9&5D(&-A<&%I8FQI='D@=&5S=',@=&\@=&AO<V4@
M9')I=F5R<R!T:&%T(')E<75I<F4@;F]N+7-T86YD87)D(%!(4`H@("`@("!E
M>'1E;G-I;VYS("AH86YD;&5D(&)Y($AO<F1E.CIF=6YC=&EO;D-H96-K*"DI
M+@I;:F]N72!!9&1E9"!A;B!!=71H7TQ$05`@2&]R9&4@875T:&5N=&EC871I
M;VX@9')I=F5R+@I;8VIH72!!9&0@;&ET=&QE('-N:7!P970M=&5M<&QA=&5S
M(&9O<B!D>6YA;6EC86QL>2!B=6EL9&EN9R!P<F5F97)E;F-E($=527,N"EMC
M:FA=(%)E;F%M92!T:&4@075T:"!I;G1E<F9A8V4G<R!A=71H*"D@;65T:&]D
M('1O(&%U=&AE;G1I8V%T92@I('1O(&%V;VED"B`@("`@(&]V97)L87!P:6YG
M('1H92!N86UE(&]F('1H92!C;VYS=')U8W1O<B!F;W(@=&AE($%U=&@@<&%R
M96YT(&-L87-S+@I;8VIH72!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2!I<R!N
M;W<@<VEM<&QY("1C;VYF+B!!;GD@<V5T=&EN9W,@=&AA="!M=7-T(&)E"B`@
M("`@(&%C8V5S<VEB;&4@=6YC:&%N9V5D("AN;W0@;W9E<G)I9&1E;BD@<VAO
M=6QD(&)E('!U="!I;G1O("1C;VYF6R=H;W)D92==+@H@("`@("!%=F5R>71H
M:6YG(&5L<V4@:7,@9F%I<B!G86UE(&9O<B!A<'!L:6-A=&EO;G,@=&\@;W9E
M<G)I9&4N"EMC:FA=($%D9"!A('=M;"]W87`@;&]G:6X@9F]R;2X*6VUA>%T@
M061D(&%N($%U=&A?1E10($AO<F1E(&%U=&AE;G1I8V%T:6]N(&1R:79E<BX*
M6V-J:%T@061D(&%N($%U=&A?34-!3"!(;W)D92!A=71H96YT:6-A=&EO;B!D
M<FEV97(N"EMC:FA=(%1H92!(;W)D92!L;V=I;B!F;W)M(&YO=R!A8W1U86QL
M>2!D;V5S('-O;65T:&EN9RX@3&]G9VEN9R!I;B!T;R!I=`H@("`@("!G971S
M('EO=2!A('1O:V5N(&EN('EO=7(@<V5S<VEO;B!S87EI;F<@=&AA="!Y;W4G
M=F4@875T:&5N=&EC871E9"!A;F0*("`@("`@=VAO('EO=2!A<F4N($%P<',@
M8V%N('1H96X@=7-E('1H:7,@:6YF;W)M871I;VX@=&\@86QL;W<@;W(@9&5N
M>0H@("`@("!A8V-E<W,L(&%N9"!T;R!I9&5N=&EF>2!U<V5R<RX*6V-J:%T@
M5&AE(&9O<FUA="!O9B!T:&4@8V]N9FEG+W)E9VES=')Y+G!H<"!F:6QE(&AA
M<R!C:&%N9V5D(&1R87-T:6-A;&QY('1O"B`@("`@(&)E(&UO<F4@<F5A9&%B
M;&4@86YD(&QE<W,@:6YD:7)E8W0N(%1H97)E(&ES(&%L<V\@82!N97<@87!P
M('!A<F%M971E<BP*("`@("`@)V%L;&]W7V=U97-T<R<L('=H:6-H(&1E9FEN
M97,@=VAE=&AE<B!O<B!N;W0@82!U<V5R(&ES(&%L;&]W960@=&\*("`@("`@
M86-C97-S('1H92!A<'!L:6-A=&EO;B!W:71H;W5T(&QO9V=I;F<@:6X@=&\@
M2&]R9&4N"EMC:FA=(%1H92!!=71H.CH@8VQA<W-E<R!N;W<@97AP96-T('1O
M(')E8V5I=F4@82!U<V5R:60@86YD(&%N(&%R<F%Y(&]F"B`@("`@(&-R961E
M;G1I86QS+B!2:6=H="!N;W<@86QL(&)A8VME;F1S(&%S<W5M92!T:&%T('1H
M;W-E(&-R961E;G1I86QS"B`@("`@(&-O;G1A:6X@82!P87-S=V]R9"P@8G5T
M('1H92!W87D@:7,@8VQE87(@=&\@:&%V92!O=&AE<B!K:6YD<R!O9B!A=71H
M"B`@("`@("A)4"P@=&EM92UB87-E9"P@=VAA=&5V97(I+@I;:F]N72!!9&1E
M9"!A(&YE=R!P87)A;65T97(@=&\@=&AE($Q$05`@<')E9F5R96YC97,@9')I
M=F5R.B`G86QW87ES7V)I;F0G+@I;8VIH72!!9&1E9"!A($UE;G4Z.B!C;&%S
M<R!T:&%T(&%L;"!M;V1U;&5S(&-A;B!U<V4@=&\@9V5N97)A=&4@;65N=2!I
M=&5M<RX*6VIO;ET@0VQE86YE9"!U<"!T:&4@3$1!4"!P<F5F97)E;F-E<R!D
M<FEV97(@82!B:70N"EMJ;VY=($%D9&5D('-E<W-I;VXM;&5V96P@<')E9F5R
M96YC97,@8V%C:&EN9R!T;R!T:&4@<')E9F5R96YC97,@<WES=&5M+@I;8VIH
M72!(879E($AO<F1E.CIL:6YK*"D@;6%K92!S=7)E('1H870@=&AE('-T871U
M<R!T97AT(&ES('-A9F4@9F]R"B`@("`@(&IA=F%S8W)I<'0@*&AT;6QE;G1I
M=&EE<RP@861D<VQA<VAE<RDN"EMC:FA=($9I>"!/8FIE8W13=&]R92!T;R!W
M;W)K('=H96X@<F5G:7-T97)?9VQO8F%L<R`]($]N+@I;:F]N72!!9&1E9"!A
M(%-E<W-I;VXM8F%S960@<')E9F5R96YC97,@9')I=F5R+@H*"BTM+2TM+0IV
M,2XS+C,*+2TM+2TM"@I;8VIH72!&=7)T:&5R(')E=F%M<"!T:&4@34E-12!I
M;G1E<F9A8V4N($)E(&-O;G-I<W1E;G0@:6X@8V%P:71A;&EZ871I;VX*("`@
M("`@*&%C<F]N>6US(&%R92!C87!I=&%L:7IE9"DL(&)R96%K(&]U="!-24U%
M7U-T<G5C='5R92!A;F0@34E-15]-97-S86=E"B`@("`@(&EN=&\@<V5P97)A
M=&4@9FEL97,L(&%N9"!P=70@86QL(&UE=&AO9',@:6YT;R!C;&%S<V5S+@I;
M8VIH72!!9&0@2&]R9&4Z.F=E=$9O<FU$871A*"D@=&\@9F5T8V@@82!V87)I
M86)L92!F<F]M(&5I=&AE<@H@("`@("`D2%144%]03U-47U9!4E,@;W(@)$A4
M5%!?1T547U9!4E,@*&%N9"!T;R!C;&5A;B!M86=I8R!Q=6]T97,L(&EF"B`@
M("`@(&YE8V5S<V%R>2DN"EMC:FA=(%)E;6]V92!T:&4@3&]G.CH@8VQA<W,N
M(%1H:7,@:7,@<&%R="!O9B!014%2(&YO=RX*6V-J:%T@061D(&$@4V5S<VEO
M;D-A8VAE.CH@8VQA<W,N(%1H:7,@:7,@:6YT96YD960@9F]R('-T;W)I;F<@
M;V)J96-T<R!I;@H@("`@("!T:&4@<V5S<VEO;B!I;G1E;F1E9"!F;W(@;F5A
M<BUT97)M('5S92P@86YD('=I;&P@8W5R<F5N=&QY('-T87)T"B`@("`@('1H
M<F]W:6YG(&]U="!O8FIE8W1S('=H96X@;6]R92!T:&%N(#(P(&%R92!P=70@
M:6XN(%1H:7,@=VEL;"!H;W!E9G5L;'D*("`@("`@:V5E<"!A;GD@;VYE('-E
M<W-I;VX@9G)O;2!G<F]W:6YG('1O;R!L87)G92X*6V-J:%T@57-E('1H92!N
M97<@4$5!4B!C;&%S<R!-86EL7W)F8S@R,CHZ('1O('!A<G-E(&%D9')E<W,@
M;&ES=',L('-O('1H870*("`@("`@=V4@9V5T(')F8R`X,C(@9W)O=7`@<W5P
M<&]R="`H;7DM8G5D9&EE<SH@:F]N0&AO<F1E+&]R9RP*("`@("`@;6%X0&AO
M<F1E+F]R9SLI+"!W:&EC:"!I;6%P7W)F8S@R,E]P87)S95]A9')L:7-T*"D@
M9&]E<VXG="!H879E+@I;;6%X72!-86ME($AO<F1E(%A(5$U,(#$N,"!C;VUP
M;&EA;G0N"EMC:FA=($%D9"!A(&9E=R!F:65L9',@=&\@=&AE('!R;V)L96T@
M<F5P;W)T(&%N9"!T<GD@=&\@;6%K92!I="!M;W)E(&9R:65N9&QY+@I;8VIH
M72!&;&5S:"!O=70@=&AE($UI;64Z.B!C;&%S<RX*6V-J:%T@36]V92!T<FEM
M16UA:6Q!9&1R97-S*"D@:6YT;R!T:&4@;F5W($UI;64Z.B!C;&%S<RX*6V-J
M:%T@36]V92!S971?96YV7VEN7W-T<FEN9R@I('1O(%1E>'0Z.F5X<&%N9$5N
M=FER;VYM96YT*"DN"EMC:FA=(%)E;F%M92!H;W)D95]C;&5A;G5P*"D@=&\@
M7V9I;&5#;&5A;G5P*"DN"EMC:FA=(%1H92!Z;&EB(&UO9'5L92!N;W<@<W5P
M<&QI97,@82!G>F5N8V]D92@I(&9U;F-T:6]N('1H870@;V)S;VQE=&5S"B`@
M("`@($A45%!?0V%C:&4Z.F=Z16YC;V1E*"DN"EMC:FA=($UO9&EF>2!(;W)D
M93HZ=7)L*"D@<V\@=&AA="!I="!D969A=6QT<R`D8V]N9ELG=7-E7W-S;"==
M('1O(#(*("`@("`@*&%U=&\M9&5T96-T(&-U<G)E;G0@;6]D92DN"EMC:FA=
M($UO9&5R;FEZ92!S;VUE(&]F('1H92!(;W)D92!F<F]N=&5N9"`H<W1I;&P@
M;&]T<R!T;R!D;R!H97)E*3L@9V5T(')I9`H@("`@("!O9B!P86-K86=E+DA4
M34Q$;V-U;65N="YP:'`@;VYC92!A;F0@9F]R(&%L;"X*6V%V<VU=($)R96%K
M9&]W;B!A;&P@<W!E8VEA;"!C:&%R86-T97)S(&EN(%523',@=&\@96YT:71I
M97,L('1O(&%V;VED"B`@("`@(&%M8FEG=6ET>2!I;B!H;W<@=F%R:6]U<R!B
M<F]W<V5R<R!P87)S92!T:&5M+@I;8VIH72!!9&0@2&]R9&4Z.G)A:7-E365S
M<V%G92@I(&9O<B!C<F5A=&EN9R!(;W)D92!M97-S86=E<R!T;R!B92!D:7-P
M;&%Y960*("`@("`@=&\@=&AE('5S97(N"EMC:FA=(%-O;64@9V5N97)A;"!5
M22!T=V5A:W,@+2!F;VYT('-I>F4L(&5T8RX*6V-J:%T@4F5M;W9E(')F8V1A
M=&4H*2!I;B!F879O<B!O9B!T:&4@;F5W("=R)R!P87)A;65T97(@=&\@9&%T
M92X*6V-J:%T@061D960@87!P;&EC871I;VX@)W=E8G)O;W0G(&%N9"`G9FEL
M97)O;W0G('!R;W!E<G1I97,@=&\@=&AE(')E9VES=')Y"B`@("`@(&-O;F9I
M9R!F:6QE+B!4:&5S92!A;&QO=R!M;W)E(&9L97AI8FEL:71Y(&EN('!L86-I
M;F<@87!P<RP@86YD(&QE="!T:&4*("`@("`@<F5G:7-T<GD@=V]R:R!F<F]M
M(&UO<F4@<&QA8V5S+@I;8VIH72!-;W9E9"!P86-K86=E+E)E9VES=')Y+G!H
M<"!T;R!296=I<W1R>2YP:'`N"EMC:FA=($-O;6UE;G1E9"!C;VYF:6<O:&]R
M9&4N<&AP+F1I<W0@:&5A=FEL>2X*6V-J:%T@061D(&$@4V5C<F5T.CH@8VQA
M<W,@=&\@2&]R9&4N<&AP('1H870@<')O=FED97,@82!T<F%N<W!A<F5N=`H@
M("`@("!I;G1E<F9A8V4@=&\@96ET:&5R('1H92!M8W)Y<'0@97AT96YS:6]N
M("AP<F5F97)R960I(&]R('1H92!014%2"B`@("`@($-R>7!T7TA#14U$-3HZ
M(&-L87-S+@I;:F]N72!!8V-E<'0@82!U<V5R+61E9FEN960@9G5N8W1I;VX@
M9F]R('!E<F9O<FUI;F<@=7-E<FYA;64@;&]O:W5P<R!I;B!T:&4*("`@("`@
M<')E9F5R96YC97,@8V]D92X@(%1H92!P<F5F97)E;F-E<R!C;VYS=')U8W1O
M<B!L;V]K<R!F;W(@=&AE(&9U;F-T:6]N"B`@("`@(&EN("1P87)A;7-;)W5S
M97)?:&]O:R==+@I;8VIH72!#:&5C:R!(5%107T5.5E]605)3(&9O<B!T:&4@
M=7-E<BUA9V5N="!A<R!W96QL(&%S($A45%!?4T525D527U9!4E,N"EMC:FA=
M(%)E;6]V92!M86EL9G)O;2@I(&EN(&9A=F]R(&]F('1H92!014%2($UA:6PZ
M.B!I;G1E<F9A8V4N($%D:G5S="!T:&4*("`@("`@8V]N9B!F:6QE<R!A;F0@
M<')O8FQE;2YP:'`@86-C;W)D:6YG;'DN"EMC:FA=($%D9"!A('-E="!O9B!I
M;G9O:V4H*2!M971H;V1S('1O('1H92!296=I<W1R>3HZ(&-L87-S(&9O<B!D
M:7)E8W1L>0H@("`@("!I;G9O:VEN9R!S97)V:6-E<R`H:64L(&%C='5A;&QY
M('!O<'!I;F<@=7`@82!W:6YD;W<I(&EN<W1E860@;V8*("`@("`@<')I;G1I
M;F<@;&EN:W,@=&\@:6YV;VME('1H96TN"EMC:FA=($-L96%N('5P('!A8VMA
M9V4N36EM92YP:'`@82!B:70[(&1O;B=T('-E="!A(&-H87)S970@;VX@34E-
M12!P87)T<PH@("`@("!T:&%T(&%R96XG="!T97AT+@I;8VIH72!!9&1E9"!A
M(&9I;&4@9')I=F5R(&9O<B!T:&4@0V]N;F5C=&EO;CHZ(&-L87-S+@I;8VIH
M72!!9&1E9"!A(%=!4"!I;F1E>"!T;R!P<F]V:61E('%U:6-K(&QI;FMS('1O
M(&%L;"!(;W)D92!W:7)E;&5S<R!P86=E<RX*6V-J:%T@061D(&)A<VEC(%=!
M4"!B<F]W<V5R(&1E=&5C=&EO;B!T;R!"<F]W<V5R.CHN($-U<G)E;G1L>2!T
M:&ES(&ES(&]F('1H90H@("`@("`B:70@9&5T96-T<R!T:&4@<&AO;F4@22!H
M879E(&%N9"!T:&4@<VEM=6QA=&]R($D@=7-E(B!V87)I971Y.R!I="!I<PH@
M("`@("!?=F5R>5\@9F%R(&9R;VT@8V]M<&QE=&4N"EMC:FA=($%D9&5D($UA
M>"!+86QI:V$G<R!#;VYN96-T:6]N.CH@8VQA<W,@9F]R(&-O;FYE8W1I;VX@
M=')A8VMI;F<N"EMC:FA=($A45%!?0V%C:&4Z.B!N;W<@8V]M<')E<W-E<R!C
M;VYT96YT('=I=&AO=70@=&AE('5S92!O9B!A('1E;7`@9FEL92X*6V-J:%T@
M1FQE<VAE9"!O=70@=&AE($%U=&@Z.B!C;&%S<R!W:71H('1H92!A8FEL:71Y
M('1O(&-A8VAE(&%U=&AO<FEZ871I;VX*("`@("`@:6X@=&AE('-E<W-I;VXN
M"EMJ;VY=(%)E;6]V960@=&AE('-C<FEP=&5D('=O<F1W<F%P(&EN(&9A=F]R
M(&]F('1H92!N871I=F4@9G5N8W1I;VXN("!-;W9E9`H@("`@("!T:&4@=W)A
M<%]M97-S86=E*"D@9G5N8W1I;VX@=&\@5&5X=#HZ=W)A<"@I+@I;:F]N72!3
M=&%N9&%R9&EZ92!O;B!T:&4@<F9C9&%T92@I(&9U;F-T:6]N(&EN(&QI8B](
M;W)D92YP:'`N"EMC:FA=(%1H92!P<F5F<R!D<FEV97)S(&YO=R!E>'!E8W0@
M)'!A<F%M<ULG:&]S='-P96,G72P@9F]R(&-O;G-I<W1E;F-Y('=I=&@*("`@
M("`@4$5!4BX*6V-J:%T@5&AE(%!%05(@<W%L('!R969S(&1R:79E<B!N;W<@
M=V]R:W,N"EMC:FA=($UO=F4@:&]R9&4@8V]N9FEG=7)A=&EO;B!V86QU97,@
M=&AA="!S:&]U;&0@;F]T(&)E(&]V97)R:61D960@8GD*("`@("`@;6]D=6QE
M<R!I;G1O("1H;W)D95LG:&]R9&4G75M=('1O(&%L;&]W(&UO9'5L97,@=&\@
M9&\*("`@("`@;W9E<G)I9&EN9R]I;FAE<FET86YC92!O9B!O=&AE<B!O<'1I
M;VYS+@I;8VIH72!!9&0@=&AE($A45%!?0V%C:&4Z.B!C;&%S<R!T;R!(;W)D
M92YP:'`@9F]R($5486<@9V5N97)A=&EO;BP@9WII<`H@("`@("!C;VUP<F5S
M<VEO;B!O9B!H='1P(&-O;G1E;G0L(&5T8RX*6V-J:%T@4F5P;&%C92`D:&]R
M9&5;)VQO8V%L:&]S="==('=I=&@@)$A45%!?4T525D527U9!4E-;)U-%4E9%
M4E].04U%)UTN"EMC:FA=(%)E:F5C="!O=71R:6=H="!E;G9E;&]P92!&<F]M
M(&%D9')E<W-E<R!W:71H('-P86-E<R!I;B!T:&5M+@I;8VIH72!1=6]T92!T
M:&4@9G)O;2!A9&1R97-S('!A<W-E9"!T;R!S96YD;6%I;"!T;R!P<F5V96YT
M('-H96QL(&5X<&QO:71S+@I;8VIH72!5<&1A=&4@0G)O=W-E<BYP:'`@=&\@
M=7-E($A45%!?4T525D527U9!4E,L(&-O;G-O;&ED871E('1H92!J879A<V-R
M:7!T"B`@("`@('9E<G-I;VX@:6YF;W)M871I;VXL(&%N9"!A9&0@<W-L7V1O
M=VYL;V%D7VAA8VL@9F]R(&)R;W=S97)S('1H870@;F5E9`H@("`@("!D;W=N
M;&]A9',@=&\@8F4@8V%C:&5A8FQE+@I;:F]N72!!9&0@5&5X=#HZ9FEL=&5R
M('1O(&QI8B](;W)D92YP:'`N"EMC:FA=($-H96-K('1H92!R971U<FX@=F%L
M=64@;V8@<&-L;W-E*"D@8V]R<F5C=&QY(&EN(&UA:6QF<F]M*"DN"EMJ;VY=
M(%-E8W5R:71Y(&9I>"!F;W(@)&9R;VT@=F%L=64@:6X@;6%I;&9R;VTH*2X@
M/&-W0&-O8RUA9RYN970^"EMJ;VY=(%-I;&5N8V4@<V5S<VEO;E]S=&%R="!W
M87)N:6YG<RX*6VIO;ET@061D960@;F5W('QE>'1R87P@<W5B<W1I='5T:6]N
M('1O(&-O;F9I9R]R96=I<W1R>2YP:'`@9F]R(&5X=')A+`H@("`@("!N;VXM
M<W1A;F1A<F0@<&%R86UE=&5R('!A<W-I;F<N"EMJ;VY=(%)E;6]V92!B=6EL
M9%523"@I+B`@270G<R!B965N(')E<&QA8V5D(&)Y($AO<F1E.CIU<FPH*2X*
M6VIO;ET@4F5S=')U8W1U<F5D('1H92!344P@<')E9F5R96YC97,@<V-H96UA
M+@I;8VIH72!!9&1E9"`D:&]R9&5;)W-E<W-I;VY?;F%M92==('1O(&-O;G1R
M;VP@=&AE('-E<W-I;VX@;F%M92!G;&]B86QL>2X*6V-J:%T@4V5S<VEO;CHZ
M(&1O97-N)W0@<F5A;&QY(&)U>2!U<R!A;GET:&EN9RP@<V\@=V4G=F4@;6]V
M960@=&AE('5T:6QI='D*("`@("`@;65T:&]D<R!T:&%T(&1O(&EN=&\@2&]R
M9&4Z.BP@86YD(&%R92!J=7-T('5S:6YG('!H<#0@<V5S<VEO;B!C86QL<PH@
M("`@("!E;'-E=VAE<F4N"EMC:FA=($%D9&5D('1H92!B96=I;FYI;F=S(&]F
M(%5S97(@86YD($%U=&@@:6YT97)F86-E<RP@=VET:"!A(&)A<F4M8F]N97,*
M("`@("`@=V]R:VEN9R!!=71H7W-Q;"!I;7!L96UE;G1A=&EO;BX*6VIO;ET@
M4F5W<F]T92!T:&4@4V5S<VEO;B!C;&%S<R!F;W(@:6YS=&%N=&EA=&EO;B!W
M:71H(&AO;VMS(&9O<@H@("`@("!U<V5R+61E9FEN960@<V5S<VEO;B!H86YD
M;&5R<RX*6V-J:%T@5&AE(&)A<F4M8F]N97,@:6UP;&5M96YT871I;VX@;V8@
M=&AE(%!E<FUS('-C:&5M92P@=VET:"!A('-Q;"!D<FEV97(L"B`@("`@('=O
M<FMS+B!)9B!Y;W4@<&%S<R!I="!A(&9U;&P@<&%T:"!I="!W:6QL('1R879E
M<G-E('5P(&ET+"!R971U<FYI;F<*("`@("`@=&AE(&9I<G-T('!E<FUI<W-I
M;VX@:70@9FEN9',N"EMJ;VY=($UO=F5D('1H92!L86YG=6%G92!H86YD;&EN
M9R!F=6YC=&EO;G,@:6X@2&]R9&4N<&AP(&EN=&\@=&AE:7(@;W=N"B`@("`@
M(&-L87-S960@;F%M960@3&%N9RX*6V-J:%T@36]R92!C;VYS:7-T96YT+V-S
M<RUB87-E9"!L;V]K(&9O<B!T:&4@:&5L<"!S>7-T96TN"EMC:FA=(%-T87)T
M:6YG('1O(')E;6]V92!A;&P@=7-E<R!O9B!C86QL+71I;64@<&%S<RUB>2UR
M969E<F5N8V4N"EMC:FA=($%D9&5D(&-S<RYP:'`@9F]R(&%U=&]M86=I8V%L
M(&=E;F5R871I;VX@;V8@<W1Y;&5S:&5E=',@9F]R(&%P<',N"EMJ;VY=(%!R
M;VUO=&5D('1H92!796)#;&EE;G0@8VQA<W,@9G)O;2!L:6(O2&]R9&4N<&AP
M('1O(&ET<R!O=VX@8V]M<&]N96YT"B`@("`@(&YA;65D($)R;W=S97(N<&AP
M+@I;8VIH72!5<V4@=V]R9'=R87`@:6X@82!S;&EG:'1L>2!D:69F97)E;G0@
M=V%Y+"!W:&EC:"!S965M<R!T;R!P<F]D=6-E(&UU8V@*("`@("`@<')E='1I
M97(@<75O=&EN9R!O9B!M97-S86=E<RX*6VIO;ET@061D960@4')E9G,O;7ES
M<6PN<&AP(&1R:79E<B!F<F]M($UA>"!+86QI:V$@/&UA>$!T:&4M=')I=6UV
M:7)A=&4N;F5T/BX*6VIO;ET@3F5W(%A-3"UB87-E9"!H96QP('-U8G-Y<W1E
M;2X*6V-J:%T@4F5N86UE9"!P86-K86=E+FAO<F1E+G!H<"!T;R!(;W)D92YP
M:'`N"EMC:FA=($%D9"!I;6<H*2!A;F0@<&EM9R@I(&9U;F-T:6]N<R!T;R!T
M:&4@2&]R9&4Z.B!C;&%S<R!S;R!T:&%T(&UO9'5L97,*("`@("`@=7-I;F<@
M;VYL>2!S='EL97-H965T<R!D;VXG="!N965D('1H92!(5$U,1&]C=6UE;G0@
M<&%C:V%G92X*6V-J:%T@3VUI="!T:&4@<V5S<VEO;B!N86UE+VED(&9R;VT@
M=&AE(%523"!I9B!W92!C86X@=F5R:69Y('1H870@8V]O:VEE<PH@("`@("!A
M<F4@8F5I;F<@86-C97!T960N"EMJ;VY=($YE=R!W<F%P7VUE<W-A9V4@9G5N
M8W1I;VX@=&AA="!U<V5S('1H92!N871I=F4@=V]R9'=R87`@9G5N8W1I;VX@
M:68@:70*("`@("`@97AI<W1S+@I;:F]N72!5<&1A=&EN9R!H96%D97(@8V]M
M;65N="!C;W!Y<FEG:'0@:6YF;W)M871I;VXN"EMJ;VY=(%)E<&]R="!M;V1U
M;&4@=F5R<VEO;G,@:6X@=&5S="YP:'`@;W5T<'5T+@I;8VIH72!M:6UE7V5N
M8V%P<W5L871E*"D@;F]W('5S97,@86X@87)R87D@:6YS=&5A9"!O9B!A;B!O
M8FIE8W0N"EMJ;VY=(%)E;6]V960@=&AE("1?:'1M;%LG8V]M<&]S92HG72!S
M:7II;F<@<&%R86UE=&5R<R!F<F]M(&-O;F9I9R]H=&UL+G!H<"X*6V-J:%T@
M3&5A=F4@0F-C.B!O=70@;V8@=&AE(&AE861E<G,@=&AA="!A<F4@<&%S<V5D
M('1O('-E;F1M86EL+@I;:F]N72!297=R:71E(&$@9V]O9"!P;W)T:6]N(&]F
M('1H92!S8W)I<'1S+W-E=%]P97)M<RYS:"!S8W)I<'0@<V\*("`@("`@=&AA
M="!I="!E;F9O<F-E<R!A;B!E>'1R96UE;'D@:&EG:"!L979E;"!O9B!S96-U
M<FET>2X*6V-J:%T@5&AE('9A;&ED7VQA;F<H*2!F=6YC=&EO;B!N;W<@<F5Q
M=6ER97,@)&YL<ULG;&%N9W5A9V5S)UU;/&QA;F=U86=E/ET*("`@("`@=&\@
M8F4@<V5T(&9O<B!A(&QA;F=U86=E('1O(&)E(&-O;G-I9&5R960@=F%L:60@
M*&EN<W1E860@;V8@:G5S="!T:&4*("`@("`@;&]C86QE(&1I<F5C=&]R>2!E
M>&ES=&EN9RDN"EMC:FA=($%D9&5D(&$@)G-I;F=L971O;B@I(&UE=&AO9"!T
M;R!M86ME(&ET(&5A<VEE<B!T;R!O;FQY(&-R96%T92!O;F4@;&]G"B`@("`@
M(&EN<W1A;F-E+"!N;R!M871T97(@=VAE;B!Y;W4@;F5E9"!I="X*6V-J:%T@
M3F]W(&UA:6QF<F]M*"D@=V]R:W,@9F]R(')E8VEP:65N="!A9&1R97-S97,@
M=VET:"!S:6YG;&4@<75O=&5S(&]R"B`@("`@(&]T:&5R(&-H87)A8W1E<G,@
M=&AA="!N965D('1O(&)E(&5S8V%P960@:6X@=&AE;2X*6V-J:%T@3&]G(&-L
M87-S(&YO=R!H87,@86X@;6-A;"!I;G-T86YC92P@82!C;VUP;W-I=&4@*&9O
M<B!G<F]U<&EN9R!M=6QT:7!L90H@("`@("!L;V<@8F%C:V5N9',I+"!A;F0@
M;V)S97)V97)S(')E9VES=&5R('1H92!L979E;"!O9B!E=F5N=',@=&AE>2!W
M86YT('1O"B`@("`@(&AE87(@86)O=70L(&%N9"!O;FQY(&=E="!N;W1I9FEE
M9"!O9B!E=F5N=',@87,@:6UP;W)T86YT(&]R(&UO<F4*("`@("`@:6UP;W)T
M86YT('1H86X@=&AA="!L979E;"X*6V-J:%T@061D960@82!,;V<Z.B!F<F%M
M97=O<FL@86YD('-Y<VQO9R!I;7!L96UE;G1A=&EO;BP@:6YC;'5D:6YG(&$*
M("`@("`@3&]G7V]B<V5R=F5R(&-L87-S(&EN=&5N9&5D('1O('-I="!O;B!T
M;W`@;V8@3&]B(&]B:F5C=',@86YD('1A:V4*("`@("`@86-T:6]N(&EN(&5X
M8V5P=&EO;F%L(&-I<F-U;7-T86YC97,N"EMC:FA=($UA:V4@<W5R92!T;R!A
M;'=A>7,@<V5N9"!A(&-H87)S970@=VET:"!E;6%I;',N"EMC:FA=($EM<')O
M=F5D('1H92!M:6UE7V1E8V]D92@I(&%N9"!M:6UE7V5N8V]D92@I(&9U;F-T
M:6]N<RX*6V-J:%T@57!D871E9"!T97-T+G!H<"!T;R!R96-O9VYI>F4@<&AP
M-"!S=&%B;&4@<F5L96%S97,N"EMJ;VY=(%)E;6]V960@86QL(&]F('1H92!L
M;V-A;&4O*BYL86YG(&1E<&5N9&5N8VEE<RX*6VIO;ET@07-S=6UE('1H92!B
M<F]W<V5R(&ES(&9R86UE<RUC87!A8FQE(&)Y(&1E9F%U;'0N"EMC:FA=($%D
M9"!H;W)D95]C;&5A;G5P*"1F:6QE;F%M92DL('=H:6-H('1A:V5S(&-A<F4@
M;V8@9&5L971I;F<@9FEL97,@=&AA=`H@("`@("!S:&]U;&0@8F4@=6YL:6YK
M960@<F5G87)D;&5S<R!O9B!W:&5T:&5R(&]R(&YO="!T:&4@<F5Q=65S="!I
M<PH@("`@("!C86YC96QE9"!B>2!T:&4@=7-E<B!B969O<F4@=V4@9FEN:7-H
M(&5X96-U=&EN9RX*6V-J:%T@4F5M;W9E('!H<&QI8B!D97!E;F1A;F-Y(&EN
M(&9A=F]R(&]F('!H<#0@<V5S<VEO;G,O4$5!4BX*6V-J:%T@4F5P;&%C92!U
M<V4@=VET:"!R97%U:7)E7V]N8V4N"EMC:FA=($9I>&5D('5P('-E;&5C=%]L
M86YG*"D@=&\@=V]R:R`H:61E;G1I8V%L('1O(#$N,B!N;W<I"EMC:FA=($AO
M<F1E(&ES(&YO=R!U;F1E<B!T:&4@3$=03"X*6V-J:%T@1FEX(&UA:6QF<F]M
M*"D@<V\@:70@9&]E<VXG="!S96YD(&5X=')A(&AE861E<G,@=VAE;B!U<VEN
M9R!M86EL*"D*6V-J:%T@061D:6YG(&$@)VUA<F=I;G,G(&%T=')I8G5T92!T
M;R!(5$U,1&]C=6UE;G0@=&\@96YA8FQE('1U<FYI;F<@;V9F"B`@("`@(&1O
M8W5M96YT(&UA<F=I;G,N"@H*+2TM+2TM"G8Q+C,N,@HM+2TM+2T*"EMC:FA=
M(%)E<&QA8V5D(&UO9'5L92Y834Q?4D1&+G!H<"!W:71H(&$@=V]R:VEN9R!C
M;W!Y+@H*"BTM+2TM+0IV,2XS+C$*+2TM+2TM"@I;8VIH72!2979A;7!E9"!T
M:&4@36EM94UE<W-A9V4@8VQA<W,@=&\@8F4@;75C:"!S;6%L;&5R(&%N9"!S
M:6UP;&5R+@I;8VIH72!297!L86-E9"!T:&4@36EM95!A<G1$871A(&-L87-S
M('=I=&@@82!S970@;V8@9G5N8W1I;VYS('1H870@;6]R90H@("`@("!C;&5A
M;FQY(&%N9"!C;W)R96-T;'D@:6UP;&5M96YT('1H92!-24U%('-T86YD87)D
M+@I;8VIH72!S96QE8W1?;&%N9R@I(&YO=R!C:&5C:W,@9F]R(&5N('=H96X@
M=&AE(&)R;W=S97(@<F5Q=65S=',@96Y?1T(L(&5T8RX*6V-J:%T@4F5P;&%C
M960@86QL(&-A;&QS('1O(&5R96<J(&9U;F-T:6]N<R!W:71H('!R96<J(&9U
M;F-T:6]N<RP@9F]R('-P965D+@H@("`@("!"96-A=7-E(&]F('1H:7,@=V4@
M;F]W(')E<75I<F4@<&AP(#,N,"XQ,B!O<B!L871E<BX*"@HM+2TM+2T*=C$N
M,RXP"BTM+2TM+0H*6R`@(%T@1V5R;6%N('5P9&%T960*6R`@(%T@1FEX960@
M=&AE(&)R;VME;B`G8F%C:R<@;&EN:R!I;B!S971U<"YP:'`S(&9O<B!N;VXM
M16YG;&ES:"!U<V5R<PI;("`@72!M86YA9V5R+G!H<#,L(&1B+FQI8BP@86YD
M(&-O:&]R=',@87)E(&YO=R!G;VYE+B!4:&5Y('=E<F4@86QL('5N;6%I;G1A
M:6YE9"P@;W5T(&]F(&1A=&4L(&%N9"!N;W0@=F5R>2!U<V5F=6PN"B`@("`@
M(%9A<FEO=7,@8G5I;&0@<V-R:7!T<R!A<F4@=7!D871E9"!T;R!R969L96-T
M('1H:7,N"EMJ;VY=(%)E;6]V960@8V]N9FEG+V1E9F%U;'1S+G!H<#,@:6X@
M<')E9F5R96YC92!O9B!H;W)D92YP:'`S"EL@("!=($9I>&5D(&$@<V5T=7`N
M<&AP,R!B=6<@=VAE<F4@(B!W87,@=7-E9"!I;G-T96%D(&]F("<@9F]R("1D
M969A=6QT('9A;'5E<R`H;6EK92D*6R`@(%T@3F5W($9I;FYI<V@@=')A;G-L
M871I;VYS("A4:&%N:W,@=&\Z(&QE;RYJ86%S:V5L86EN96Y`:V]L=6UB=7,N
M9FDI"EL@("!=($9I>&5D(&QY;G@@<W5P<&]R="!I<W-U92!W:71H(&QO9VEN
M+G!H<#,*6R`@(%T@1FEX960@<VEG;G5P+G!H<#,@<')O8FQE;7,*6R`@(%T@
M1FEX960@<')O8FQE;2YP:'`S('!R;V)L96US("AL>6YX('-U<'!O<G0I"EL@
M("!=($%D9&5D(&1A=&%B87-E(&-R96%T:6]N('-C<FEP=',@9F]R(&)U:6QD
M:6YG('!H<&QI8B!C;VUP;&EA;B!T86)L97,*6R`@(%T@36]V960@86QL(&1O
M8W5M96YT871I;VX@*&5X8V5P="!214%$344@86YD($-/4%E)3D<I(&EN=&\@
M9&]C<R\@<W5B9&ER"EL@("!=($%D9&5D(&$@8V%C:&EN9R!C;&%S<R!S;R!T
M:&%T(&-A8VAI;F<@8V%N(&)E('1U<FYE9"!O;B!P97(@<&%G92!I9B!N965D
M960*"@HM+2TM+2T*=C$N,2XQ"BTM+2TM+0H*6R`@(%T@2&]R9&4@=6YD97)S
M=&%N9',@1G)E;F-H("AT:&%N:W,@=&\@36%T:&EE=2!#;&%B875T"B`@("`@
M(#QC;&%B875L=$!M=6QT:6UA;FEA+F-O;3XI"EL@("!=($UA:F]R(&9R86UE
M<V5T(')E9&5S:6=N"EL@("!=($%U=&\@<F5G:7-T<F%T:6]N+V-O;F=I<G5A
M=&EO;B!O9B!M;V1U;&5S"@H*+2TM+2TM"G8Q+C`N,PHM+2TM+2T*"EL@("!=
M($AO<F1E(&ES(&YO=R!W96(@<W5R9F%B;&4N"EL@("!=($AO<F1E(&AA;F1L
M97,@;'EN>"`H<'-E=61O;'DI"EL@("!=($5X=&5N9&%B;&4@;65N=7,N("AM
M96YU+G1X="!I;B!H;W)D92]C;VYF:6<I"EL@("!=(%-I9VYU<"P@<')O8FQE
M;2!R97!O<G1I;F<L(&AE;'`@9G5N8W1I;VYS(&%R92!N;W<@<&%R="!O9B!H
M;W)D90H``````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]#3T1)
M3D=?4U1!3D1!4D13````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`V,34P-@`Q,#4Q-30S,3`U-P`P,3<V-#,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"B!(;W)D92!#;V1I;F<@4W1A;F1A<F1S"CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`V+S`S+S$W
M(#`V.C$X.C`W("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XX-"XQ
M,"XQ-2`D"CI!=71H;W)S.B`@("`@("!*;VX@4&%R:7-E+"!#:'5C:R!(86=E
M;F)U8V@*.D-O;G1A8W0Z("`@("`@(&1E=D!L:7-T<RYH;W)D92YO<F<*"BXN
M(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*
M26YD96YT:6YG"CT]/3T]/3T]/0H*57-E(&%N(&EN9&5N="!O9B`T('-P86-E
M<RP@=VET:"!N;R!T86)S+@H*"D-O;G1R;VP@4W1R=6-T=7)E<PH]/3T]/3T]
M/3T]/3T]/3T]/3T*"E1H97-E(&EN8VQU9&4@8&!I9F!@+"!@8&9O<F!@+"!@
M8'=H:6QE8&`L(&!@<W=I=&-H8&`L(&5T8RX@($AE<F4@:7,@86X@97AA;7!L
M90I@8&EF8&`@<W1A=&5M96YT+"!S:6YC92!I="!I<R!T:&4@;6]S="!C;VUP
M;&EC871E9"!O9B!T:&5M.CH*"B`@:68@*"AC;VYD:71I;VXQ*2!\?"`H8V]N
M9&ET:6]N,BDI('L*("`@("`@86-T:6]N,3L*("!](&5L<V5I9B`H*&-O;F1I
M=&EO;C,I("8F("AC;VYD:71I;VXT*2D@>PH@("`@("!A8W1I;VXR.PH@('T@
M96QS92!["B`@("`@(&1E9F%U;'1A8W1I;VX["B`@?0H*375L=&DM;&EN92!I
M9B!C;VYD:71I;VYS(&%R92!B<F%C960@=&AI<R!W87DZ.@H*("!I9B`H*&-O
M;F1I=&EO;C$I('Q\("AC;VYD:71I;VXR*2!\?"`H8V]N9&ET:6]N,RD@?'P*
M("`@("`@*&-O;F1I=&EO;C0I*2!["B`@("`@(&%C=&EO;C$["B`@?0H*0V]N
M=')O;"!S=&%T96UE;G1S('-H;W5L9"!H879E(&]N92!S<&%C92!B971W965N
M('1H92!C;VYT<F]L(&ME>7=O<F0@86YD"F]P96YI;F<@<&%R96YT:&5S:7,L
M('1O(&1I<W1I;F=U:7-H('1H96T@9G)O;2!F=6YC=&EO;B!C86QL<RX*"D1O
M(&YO="!O;6ET('1H92!C=7)L>2!B<F%C97,@=6YD97(@86YY(&-I<F-U;7-T
M86YC92X@($EN('1H92!C87-E(&]F(&$@;&%R9V4*;G5M8F5R(&]F('-H;W)T
M('1E<W1S(&%N9"!A8W1I;VYS+"!T:&4@9F]L;&]W:6YG(&ES(&%C8V5P=&%B
M;&4Z.@H*("!I9B`H8V]N9&ET:6]N*2`@('L@86-T:6]N.R!]"B`@:68@*&-O
M;F1I=&EO;B`R*2![(&%C=&EO;B`R.R!]"B`@+BXN"@I&;W(@<W=I=&-H('-T
M871E;65N=',Z.@H*("!S=VET8V@@*&-O;F1I=&EO;BD@>PH@(&-A<V4@,3H*
M("`@("`@86-T:6]N,3L*("`@("`@8G)E86L["@H@(&-A<V4@,CH*("`@("`@
M86-T:6]N,CL*("`@("`@8G)E86L["@H@(&1E9F%U;'0Z"B`@("`@(&1E9F%U
M;'1A8W1I;VX["B`@("`@(&)R96%K.PH@('T*"@I&=6YC=&EO;B!#86QL<PH]
M/3T]/3T]/3T]/3T]/0H*1G5N8W1I;VYS('-H;W5L9"!B92!C86QL960@=VET
M:"!N;R!S<&%C97,@8F5T=V5E;B!T:&4@9G5N8W1I;VX@;F%M92P@=&AE"F]P
M96YI;F<@<&%R96YT:&5S:7,L(&%N9"!T:&4@9FER<W0@<&%R86UE=&5R.R!S
M<&%C97,@8F5T=V5E;B!C;VUM87,@86YD(&5A8V@*<&%R86UE=&5R+"!A;F0@
M;F\@<W!A8V4@8F5T=V5E;B!T:&4@;&%S="!P87)A;65T97(L('1H92!C;&]S
M:6YG('!A<F5N=&AE<VES+`IA;F0@=&AE('-E;6EC;VQO;BX@($AE<F4G<R!A
M;B!E>&%M<&QE.CH*"B`@)'9A<B`](&9O;R@D8F%R+"`D8F%Z+"`D<75U>"D[
M"@I!<R!D:7-P;&%Y960@86)O=F4L('1H97)E('-H;W5L9"!B92!O;F4@<W!A
M8V4@;VX@96ET:&5R('-I9&4@;V8@86X@97%U86QS('-I9VX*=7-E9"!T;R!A
M<W-I9VX@=&AE(')E='5R;B!V86QU92!O9B!A(&9U;F-T:6]N('1O(&$@=F%R
M:6%B;&4N("!);B!T:&4@8V%S92!O9B!A"F)L;V-K(&]F(')E;&%T960@87-S
M:6=N;65N=',L(&UO<F4@<W!A8V4@;6%Y(&)E(&EN<V5R=&5D('1O('!R;VUO
M=&4*<F5A9&%B:6QI='DZ.@H*("`D<VAO<G0@("`@("`@("`](&9O;R@D8F%R
M*3L*("`D;&]N9U]V87)I86)L92`](&9O;R@D8F%Z*3L*"@I&=6YC=&EO;B!$
M969I;FET:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T]/0H*1G5N8W1I;VX@9&5C
M;&%R871I;VYS(&9O;&QO=R!T:&4@(D)31"]!;&QM86XB(&-O;G9E;G1I;VXZ
M.@H*("!F=6YC=&EO;B!F;V]&=6YC=&EO;B@D87)G,2P@)&%R9S(@/2`G)RD*
M("!["B`@("`@(&EF("AC;VYD:71I;VXI('L*("`@("`@("`@('-T871E;65N
M=#L*("`@("`@?0H@("`@("!R971U<FX@)'9A;#L*("!]"@I!<F=U;65N=',@
M=VET:"!D969A=6QT('9A;'5E<R!G;R!A="!T:&4@96YD(&]F('1H92!A<F=U
M;65N="!L:7-T+B`@06QW87ES"F%T=&5M<'0@=&\@<F5T=7)N(&$@;65A;FEN
M9V9U;"!V86QU92!F<F]M(&$@9G5N8W1I;VX@:68@;VYE(&ES(&%P<')O<')I
M871E+@H*1G5N8W1I;VYS('5S960@;VYL>2!I;B!T:&4@8W5R<F5N="!S8W)I
M<'0O8VQA<W,@*&4N9RX@<')I=F%T92!M96UB97(@;65T:&]D<RD*<VAO=6QD
M(&)E9VEN('=I=&@@82!@8%]@8"!C:&%R86-T97(@*&4N9RX@8&!?97AA;7!L
M94QI8G)A<GE@8"DN("!4:&ES(&AE;'!S"F1I<W1I;F=U:7-H('1H97-E('!R
M:79A=&4@9G5N8W1I;VX@8V%L;',@9G)O;2!O=&AE<BP@<'5B;&EC(&9U;F-T
M:6]N(&-A;&QS+@H*"D-L87-S($1E9FEN:71I;VYS"CT]/3T]/3T]/3T]/3T]
M/3T]"@I#;&%S<R!D969I;FET:6]N<R!F;VQL;W<@=&AE(")+)E(O2V5R;F5L
M(B!C;VYV96YT:6]N.CH*"B`@8VQA<W,@4V]M95]#;&%S<R!["@H@("`@("!V
M87(@)%]V87)I86)L93L*"B`@("`@(&9U;F-T:6]N(&9O;T9U;F-T:6]N*"D*
M("`@("`@>PH@("`@("`@("`@<W1A=&5M96YT.PH@("`@("!]"@H@('T*"DYO
M=&4@=&AE(&)L86YK(&QI;F5S(&%T('1H92!B96=I;FYI;F<@86YD(&5N9"!O
M9B!T:&4@8VQA<W,@9&5F:6YI=&EO;BX*"@I.86UI;F<@3&EB<F%R:65S"CT]
M/3T]/3T]/3T]/3T]/3T*"DQI8G)A<FEE<R`H86YY(&9I;&4@;&]C871E9"!I
M;B!T:&4@8&!L:6(O8&`@9&ER96-T;W)Y(&]F('1H92!A<'!L:6-A=&EO;BD*
M<VAO=6QD(&)E(&YA;65D('=I=&@@8V%P:71A;"!L971T97)S(&%T('1H92!B
M96=I;FYI;F<@;V8@96%C:"!W;W)D+B`@57-E"G-T=61L>6-A<',@9F]R(&YA
M;6EN9SL@82!S97-S:6]N(&-A8VAE(&-L87-S('=O=6QD(&)E('-T;W)E9"!I
M;@I@8&QI8B]397-S:6]N0V%C:&4N<&AP8&`N"@I)9B!T:&4@;&EB<F%R>2]C
M;&%S<R!I<R!E>'1E;F1E9"P@=&AE(&5X=&5N9&EN9R!F:6QE<R!S:&]U;&0@
M8F4@<W1O<F5D(&EN(&$*9&ER96-T;W)Y('5N9&5R(&!@;&EB+V!@('=I=&@@
M=&AE('-A;64@;F%M92!A<R!T:&4@;W)I9VEN86P@;&EB<F%R>2X*4W5B8VQA
M<W-E<R!F;VQL;W<@=&AE(&5X86-T('-A;64@;F%M:6YG(')E<75I<F5M96YT
M<RP@97AC97!T('1H870@:68@=&AE"G-U8F-L87-S(&ES(&EN<W1A;G1I871E
M9"!B>2!A(&9A8W1O<GD@;65T:&]D+"!I="!S:&]U;&0@8F4@86QL(&QO=V5R
M8V%S92X*"D5X86UP;&4*+2TM+2TM+0H*5&AE(")%>&%M<&QE($QI8G)A<GDB
M(&QI8G)A<GD@<VAO=6QD(&)E('-A=F5D(&%S(&!@;&EB+T5X86UP;&5,:6)R
M87)Y+G!H<&!@+@I!;GD@9FEL92!E>'1E;F1I;F<@=&AE(&QI8G)A<GDO8VQA
M<W,@<VAO=6QD(&)E('-T;W)E9"!I;B!T:&4@9&ER96-T;W)Y"F!@;&EB+T5X
M86UP;&5,:6)R87)Y+V!@+@H*"D-O;6UE;G1S"CT]/3T]/3T]"@I);FQI;F4@
M9&]C=6UE;G1A=&EO;B!F;W(@8VQA<W-E<R!S:&]U;&0@9F]L;&]W('1H92!@
M2F%V861O8R!C;VYV96YT:6]N8%\N"@HN+B!?2F%V861O8R!C;VYV96YT:6]N
M.B!H='1P.B\O:F%V82YS=6XN8V]M+W!R;V1U8W1S+VID:R]J879A9&]C+W=R
M:71I;F=D;V-C;VUM96YT<R]I;F1E>"YH=&UL"@I1=6EC:R!E>&%M<&QE(&9O
M<B!P<FEV871E('9A<FEA8FQE(&1E9FEN:71I;VX@9F]R($AO<F1E.CH*"B`@
M("`O*BH*("`@("`J(%9A<FEA8FQE(&1E<V-R:7!T:6]N+@H@("`@("H*("`@
M("`J($!V87(@9&%T871Y<&4*("`@("`J+PH*475I8VL@97AA;7!L92!F=6YC
M=&EO;B!D969I;FET:6]N(&9O<B!(;W)D93HZ"@H@("`@+RHJ"B`@("`@*B!4
M:&4@9&5S8W)I<'1I;VX@;V8@=&AE(&9U;F-T:6]N(&=O97,@:&5R92X*("`@
M("`J"B`@("`@*B!`86-C97-S(%MP<FEV871E('P@<')O=&5C=&5D70H@("`@
M("H@6T1O;B=T(&)O=&AE<B!W:71H(")P=6)L:6,B('-I;F-E(&ET(&ES('1H
M92!D969A=6QT(&EF(&YO="!S<&5C:69I960N70H@("`@("H*("`@("`J($!P
M87)A;2!D871A='EP92`D=F%R:6%B;&5N86UE("`@1&5S8W)I<'1I;VX@;V8@
M=F%R:6%B;&4N"B`@("`@*B!`<&%R86T@9&%T871Y<&4@)'9A<FEA8FQE,FYA
M;64@($1E<V-R:7!T:6]N(&]F('9A<FEA8FQE,BX*("`@("`J("XN+@H@("`@
M("H@6TEN<V5R="`R('-P86-E<R!A9G1E<B!T:&4@;&]N9V5S="`D=F%R:6%B
M;&4@9&5F:6YI=&EO;BP@86YD('1H96X@;&EN90H@("`@("H@('5P(&%L;"!D
M97-C<FEP=&EO;G,@=VET:"!T:&ES(&1E<V-R:7!T:6]N70H@("`@("H*("`@
M("`J($!R971U<FX@9&%T871Y<&4@($1E<V-R:7!T:6]N(&]F(')E='5R;B!V
M86QU92X*("`@("`J(%M/;F-E(&%G86EN+"!I;G-E<G0@,B!S<&%C97,@869T
M97(@=&AE(&1A=&%T>7!E+"!A;F0@;&EN92!U<"!A;&P*("`@("`J("!S=6)S
M97%U96YT(&QI;F5S+"!I9B!A;GDL('=I=&@@=&AI<R!C:&%R86-T97(N70H@
M("`@("H*("`@("`J($!A8G-T<F%C="!;3VYL>2!I9B!N96-E<W-A<GE="B`@
M("`@*@H@("`@("H@0'-I;F-E($AO<F1E('@N>"!;3VYL>2!I9B!N96-E<W-A
M<GD@+2!U<V4@:68@9G5N8W1I;VX@:7,@861D960@=&\@=&AE"B`@("`@*B!C
M=7)R96YT(')E;&5A<V4@=F5R<VEO;G,@=&\@:6YD:6-A=&4@=&AA="!T:&4@
M9G5N8W1I;VX@:&%S(&YO="!B965N"B`@("`@*B!A=F%I;&%B;&4@:6X@<')E
M=FEO=7,@=F5R<VEO;G,N70H@("`@("HO"@H*26YC;'5D:6YG($-O9&4*/3T]
M/3T]/3T]/3T]/3T*"DEF('EO=2!A<F4@:6YC;'5D:6YG(&$@8VQA<W,L(&9U
M;F-T:6]N(&QI8G)A<GDL(&]R(&%N>71H:6YG(&5L<V4@=VAI8V@@=V]U;&0*
M8V%U<V4@82!P87)S92!E<G)O<B!I9B!I;F-L=61E9"!T=VEC92P@86QW87ES
M('5S92!@:6YC;'5D95]O;F-E8%\N("!4:&ES('=I;&P*96YS=7)E('1H870@
M;F\@;6%T=&5R(&AO=R!M86YY(&9A8W1O<GD@;65T:&]D<R!W92!U<V4@;W(@
M:&]W(&UU8V@@9'EN86UI8PII;F-L=7-I;VX@=V4@9&\L('1H92!L:6)R87)Y
M('=I;&P@;VYL>2!B92!I;F-L=61E9"!O;F-E+@H*268@>6]U(&%R92!I;F-L
M=61I;F<@82!S=&%T:6,@9FEL96YA;64L('-U8V@@87,@82!C;VYF(&9I;&4@
M;W(@82!T96UP;&%T92!T:&%T"FES("IA;'=A>7,J('5S960L('5S92!@<F5Q
M=6ER96!?+@H*268@>6]U(&%R92!D>6YA;6EC86QL>2!I;F-L=61I;F<@82!F
M:6QE;F%M92P@;W(@=V%N="!T:&4@8V]D92!T;R!O;FQY(&)E('5S960*8V]N
M9&ET:6]N86QL>2`H86X@;W!T:6]N86P@=&5M<&QA=&4I+"!U<V4@8&EN8VQU
M9&5@7RX*"BXN(%]I;F-L=61E7V]N8V4Z(&AT='`Z+R]W=W<N<&AP+FYE="]M
M86YU86PO96XO9G5N8W1I;VXN:6YC;'5D92UO;F-E+G!H<`HN+B!?<F5Q=6ER
M93H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYR97%U
M:7)E+G!H<`HN+B!?:6YC;'5D93H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A
M;"]E;B]F=6YC=&EO;BYI;F-L=61E+G!H<`H*"E!(4"!#;V1E(%1A9W,*/3T]
M/3T]/3T]/3T]/0H*06QW87ES('5S92!@8#P_<&AP(#\^8&`@=&\@9&5L:6UI
M="!02%`@8V]D92P@;F]T('1H92!@8#P_(#\^8&`@<VAO<G1H86YD+@I4:&ES
M(&ES(')E<75I<F5D(&9O<B!014%2(&-O;7!L:6%N8V4@86YD(&ES(&%L<V\@
M=&AE(&UO<W0@<&]R=&%B;&4@=V%Y('1O"FEN8VQU9&4@4$A0(&-O9&4@;VX@
M9&EF9F5R:6YG(&]P97)A=&EN9R!S>7-T96US(&%N9"!S971U<',N"@I);B!T
M96UP;&%T97,L(&UA:V4@<W5R92!T;R!U<V4@=&AI<R!A<R!W96QL("A@8#P_
M<&AP(&5C:&\@)'9A<FYA;64@/SY@8"DL(&%S"G1H92!S:&]R=&-U="!V97)S
M:6]N("A@8#P_/2`D=F%R(#\^8&`I(&1O97,@;F]T('=O<FL@=VET:"!@<VAO
M<G1?;W!E;E]T86=@7PIT=7)N960@;V9F+@H*+BX@7W-H;W)T7V]P96Y?=&%G
M.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V-O;F9I9W5R871I;VXN
M9&ER96-T:79E<RYP:'`C:6YI+G-H;W)T+6]P96XM=&%G"@H*2&5A9&5R($-O
M;6UE;G0@0FQO8VMS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/0H*06QL('-O=7)C
M92!C;V1E(&9I;&5S(&EN('1H92!(;W)D92!D:7-T<FEB=71I;VX@<VAO=6QD
M(&-O;G1A:6X@=&AE(&9O;&QO=VEN9PIC;VUM96YT(&)L;V-K(&%S('1H92!H
M96%D97(Z"@I%>&%M<&QE(&9O<B!@3$=03&!?)V5D($AO<F1E(&-O9&4Z.@H*
M("`@("\J*@H@("`@("H@5&AE($AO<F1E7T9O;SHZ(&-L87-S('!R;W9I9&5S
M(&%N($%022!F;W(@=F%R:6]U<R!F;V\*("`@("`J('1E8VAN:7%U97,@=&AA
M="!C86X@8F4@=7-E9"!B>2!(;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@*@H@
M("`@("H@)$AO<F1E"B`@("`@*@H@("`@("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M,2!/<FEG:6YA;"!!=71H;W(@/&%U=&AO<D!E>&%M<&QE+F-O;3X*("`@("`J
M($-O<'ER:6=H="`R,#`Q(%EO=7(@3F%M92`\>6]U0&5X86UP;&4N8V]M/@H@
M("`@("H*("`@("`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`@("`@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("`@("`J"B`@("`@*B!`875T:&]R
M("!/<FEG:6YA;"!!=71H;W(@/&%U=&AO<D!E>&%M<&QE+F-O;3X*("`@("`J
M($!A=71H;W(@(%EO=7(@3F%M92`\>6]U0&5X86UP;&4N8V]M/@H@("`@("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`@("`@*B!`<&%C:V%G92!(;W)D95]086-K
M86=E"B`@("`@*B\*"BXN(%],1U!,.B!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+VQG<&PM;&EC96YS92YP:'`*"D5X86UP;&4@9F]R(&!'
M4$Q@7R=E9"!A<'!L:6-A=&EO;B!C;V1E.CH*"B`@("`O*BH*("`@("`J(%1H
M92!!<'!?0F%R.CH@8VQA<W,@8V]N=&%I;G,@86QL(&9U;F-T:6]N<R!R96QA
M=&5D('1O(&AA;F1L:6YG"B`@("`@*B!B87)S(&EN($%P<"X*("`@("`J"B`@
M("`@*B`D2&]R9&4*("`@("`J"B`@("`@*B!#;W!Y<FEG:'0@,3DY.2TR,#`Q
M($]R:6=I;F%L($%U=&AO<B`\875T:&]R0&5X86UP;&4N8V]M/@H@("`@("H@
M0V]P>7)I9VAT(#(P,#$@66]U<B!.86UE(#QY;W5`97AA;7!L92YC;VT^"B`@
M("`@*@H@("`@("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@("`@("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]G<&PN:'1M;"X*("`@("`J"B`@("`@*B!`875T:&]R("!/
M<FEG:6YA;"!!=71H;W(@/&%U=&AO<D!E>&%M<&QE+F-O;3X*("`@("`J($!A
M=71H;W(@(%EO=7(@3F%M92`\>6]U0&5X86UP;&4N8V]M/@H@("`@("H@0'-I
M;F-E("`@07!P(#$N,`H@("`@("H@0'!A8VMA9V4@87!P"B`@("`@*B\*"@HN
M+B!?1U!,.B!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V=P
M;"UL:6-E;G-E+G!H<`H*5&AE<F4G<R!N;R!H87)D(')U;&4@=&\@9&5T97)M
M:6YE('=H96X@82!N97<@8V]D92!C;VYT<FEB=71E<B!S:&]U;&0@8F4@861D
M960*=&\@=&AE(&QI<W0@;V8@875T:&]R<R!F;W(@82!G:79E;B!S;W5R8V4@
M9FEL92X@($EN(&=E;F5R86PL('1H96ER(&-H86YG97,*<VAO=6QD(&9A;&P@
M:6YT;R!T:&4@(G-U8G-T86YT:6%L(B!C871E9V]R>2`H;65A;FEN9R!S;VUE
M=VAE<F4@87)O=6YD(#$P)2!T;PHR,"4@;V8@8V]D92!C:&%N9V5S*2X@($5X
M8V5P=&EO;G,@8V]U;&0@8F4@;6%D92!F;W(@<F5W<FET:6YG(&9U;F-T:6]N
M<R!O<@IC;VYT<FEB=71I;F<@;F5W(&QO9VEC+@H*4VEM<&QE(&-O9&4@<F5O
M<F=A;FEZ871I;VX@;W(@8G5G(&9I>&5S('=O=6QD(&YO="!J=7-T:69Y('1H
M92!A9&1I=&EO;B!O9B!A"FYE=R!I;F1I=FED=6%L('1O('1H92!L:7-T(&]F
M(&%U=&AO<G,N"@H*0U93(%1A9W,*/3T]/3T]/3T*"DEN8VQU9&4@=&AE(#QD
M;VQL87(^2&]R9&4Z(#QD;VQL87(^($-64R!V96YD;W(@=&%G(&EN(&5A8V@@
M9FEL92X@($%S(&5A8V@@9FEL90II<R!E9&ET960L(&%D9"!T:&ES('1A9R!I
M9B!I="=S(&YO="!Y970@<')E<V5N="`H;W(@<F5P;&%C92!E>&ES=&EN9R!F
M;W)M<PIS=6-H(&%S(#QD;VQL87(^260\9&]L;&%R/BP@(DQA<W0@36]D:69I
M960Z(BP@971C+BDN"@I%6$-%4%1)3TXZ($1O;B=T(&EN8VQU9&4@=&AE<V4@
M:6X@=&5M<&QA=&5S+@H*"D5X86UP;&4@55),<PH]/3T]/3T]/3T]/3T*"E5S
M92!@8&5X86UP;&4N8V]M8&`@9F]R(&%L;"!E>&%M<&QE(%523',L('!E<B!@
M4D9#(#(V,#9@7RX*"BXN(%]21D,@,C8P-CH@:'1T<#HO+W=W=RYF87%S+F]R
M9R]R9F-S+W)F8S(V,#8N:'1M;`H*"G!H<"YI;FD@<V5T=&EN9W,*/3T]/3T]
M/3T]/3T]/3T]/0H*06QL($AO<F1E(&-O9&4@<VAO=6QD('=O<FL@=VET:"!@
M<F5G:7-T97)?9VQO8F%L<V!?(&1I<V%B;&5D+B`@5&AI<R!M96%N<PIU<VEN
M9R!@8"1?0T]/2TE%8&`L(&!@)%]315-324].8&`L(&!@)%]315)615)@8"!A
M;F0@8&`D7T5.5F!@('1O(&%C8V5S<R!A;&P*8V]O:VEE+"!S97-S:6]N+"!S
M97)V97(@86YD(&5N=FER;VYM96YT(&1A=&$L(')E<W!E8W1I=F5L>2X*"E1O
M(')E=')I979E('!O<W1E9"!D871A("AI;B!T:&4@9VQO8F%L(&!@)%]'151@
M8"!A;F0@8&`D7U!/4U1@8"!V87)I86)L97,I+`IY;W4@<VAO=6QD(&YO<FUA
M;&QY('5S92!@571I;#HZ9V5T1F]R;41A=&$H*6!?('=H:6-H('=I;&P@875T
M;VUA=&EC86QL>2!R=6X*8%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"E@7RX@
M5&AI<R!W:6QL(&5N<W5R92!T:&%T(&%L;"!(;W)D92!C;V1E('=I;&P@=V]R
M:PIR96=A<F1L97-S(&]F('1H92!S971T:6YG(&]F(&!M86=I8U]Q=6]T97-?
M9W!C8%\N(%1H92!O;FQY('1I;64@>6]U('-H;W5L9"!N;W0*=7-E(&!5=&EL
M.CIG971&;W)M1&%T82@I8%\@:7,@:68@>6]U('=A;G0@=&\@9&ER96-T;'D@
M86-C97-S(&$@1T54(&]R(%!/4U0*=F%R:6%B;&4@:6YS=&5A9#L@:6X@=&AI
M<R!C87-E+"!Y;W4@<VAO=6QD('5S92!@571I;#HZ9V5T1V5T*"E@7R!O<@I@
M571I;#HZ9V5T4&]S="@I8%\@<F5S<&5C=&EV96QY+@H*06QL($AO<F1E(&-O
M9&4@<VAO=6QD('=O<FL@=VET:"!@97)R;W)?<F5P;W)T:6YG8%\@/2!%7T%,
M3"X@1F%I;'5R92!T;R!D;R!S;PIW;W5L9"!R97-U;'0@:6X@=6=L>2!O=71P
M=70L(&5R<F]R(&QO9W,@9V5T=&EN9R!F:6QL960@=VET:"!L;W1S(&]F('=A
M<FYI;F<*;65S<V%G97,L(&]R(&5V96X@9&]W;G)I9VAT(&)R;VME;B!S8W)I
M<'1S+@H*3F\@2&]R9&4@8V]D92!S:&]U;&0@87-S=6UE('1H870@)RXG(&ES
M(&EN('1H92!I;F-L=61E('!A=&@N($%L=V%Y<R!S<&5C:69Y"B<N+R<@:6X@
M9G)O;G0@;V8@82!F:6QE;F%M92!W:&5N('EO=2!A<F4@:6YC;'5D:6YG(&$@
M9FEL92!I;B!T:&4@<V%M90ID:7)E8W1O<GDN"@HN+B!?<F5G:7-T97)?9VQO
M8F%L<SH@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]S96-U<FET>2YR
M96=I<W1E<F=L;V)A;',N<&AP"BXN(%]M86=I8U]Q=6]T97-?9W!C.B!H='1P
M.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+W)E9BYI;F9O+G!H<"-I;FDN;6%G
M:6,M<75O=&5S+6=P8PHN+B!?97)R;W)?<F5P;W)T:6YG.B!H='1P.B\O=W=W
M+G!H<"YN970O;6%N=6%L+V5N+W)E9BYE<G)O<F9U;F,N<&AP(VEN:2YE<G)O
M<BUR97!O<G1I;F<*+BX@7U5T:6PZ.F=E=$9O<FU$871A*"DZ(&AT='`Z+R]D
M978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO2&]R9&5?571I;"]5=&EL+FAT
M;6PC;65T:&]D9V5T1F]R;41A=&$*+BX@7U5T:6PZ.F1I<W!E;$UA9VEC475O
M=&5S*"DZ(&AT='`Z+R]D978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO2&]R
M9&5?571I;"]5=&EL+FAT;6PC;65T:&]D9&ES<&5L36%G:6-1=6]T97,*+BX@
M7U5T:6PZ.F=E=$=E="@I.B!H='1P.B\O9&5V+FAO<F1E+F]R9R]A<&DO9G)A
M;65W;W)K+TAO<F1E7U5T:6PO571I;"YH=&UL(VUE=&AO9&=E=$=E=`HN+B!?
M571I;#HZ9V5T4&]S="@I.B!H='1P.B\O9&5V+FAO<F1E+F]R9R]A<&DO9G)A
M;65W;W)K+TAO<F1E7U5T:6PO571I;"YH=&UL(VUE=&AO9&=E=%!O<W0*"@I8
M2%1-3"`Q+C`@0V]M<&QI86YC90H]/3T]/3T]/3T]/3T]/3T]/3T]/0H*06QL
M('1A9R!N86UE<R!A;F0@<&%R86UE=&5R<R!M=7-T(&)E(&QO=V5R(&-A<V4@
M:6YC;'5D:6YG(&IA=F%S8W)I<'0@979E;G0*:&%N9&QE<G,Z.@H*("`@(#QF
M;VYT(&-O;&]R/2(C1D9&1D9&(CXN+BX\+V9O;G0^"B`@("`\82!H<F5F/2)H
M='1P.B\O97AA;7!L92YC;VTB(&]N;6]U<V5O=F5R/2)S=&%T=7,])R<B(&]N
M;6]U<V5O=70](G-T871U<STG)R(^+BXN/"]A/@H*06QL('1A9R!P87)A;65T
M97)S(&UU<W0@8F4@;V8@82!V86QI9"!P87)A;65T97(](G9A;'5E(B!F;W)M
M("AN=6UE<FEC('9A;'5E<PIM=7-T(&%L<V\@8F4@<W5R<F]U;F1E9"!B>2!Q
M=6]T97,I+B`@1F]R('!A<F%M971E<G,@=&AA="!H860@;F\@=F%L=64@:6X@
M2%1-3"P*=&AE('!A<F%M971E<B!N86UE(&ES('1H92!V86QU92X@($9O<B!E
M>&%M<&QE.CH*"B`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B(&-H96-K960]
M(F-H96-K960B/@H@("`@/'-E;&5C="!N86UE/2)E>&%M<&QE(CX*("`@("`@
M("`\;W!T:6]N('-E;&5C=&5D/2)S96QE8W1E9"(@=F%L=64](C$B/D5X86UP
M;&4\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@("`@/'1D(&YO=W)A<#TB;F]W
M<F%P(CY%>&%M<&QE/"]T9#X*"D%L;"!T86=S(&UU<W0@8F4@<')O<&5R;'D@
M8VQO<V5D+B`@5&%G<R!W:&5R92!C;&]S:6YG(&ES(&9O<F)I9&1E;B!M=7-T
M(&5N9`IW:71H(&$@<W!A8V4@86YD(&$@<VQA<V@Z.@H*("`@(#QB<B`O/@H@
M("`@/&AR("\^"B`@("`\:6UG('-R8STB97AA;7!L92YG:68B(&%L=#TB17AA
M;7!L92(@+SX*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B('9A;'5E/2)%>&%M
M<&QE(B`O/@H*06QL(&9O<FT@9&5F:6YI=&EO;G,@;75S="!B92!O;B!T:&5I
M<B!O=VX@;&EN92!A;F0@96ET:&5R(&9U;&QY(&1E9FEN960@=VET:&EN"F$@
M8&`\=&0^/"]T9#Y@8"!P86ER(&]R(&)E(&]U='-I9&4@=&%B;&4@=&%G<RX@
M($9O<FUS(&UU<W0@86QS;R!A;'=A>7,@:&%V92!A;@IA8W1I;VX@<&%R86UE
M=&5R.CH*"B`@("`\9F]R;2!M971H;V0](G!O<W0B(&%C=&EO;CTB:'1T<#HO
M+V5X86UP;&4N8V]M+V5X86UP;&4N8V=I(CX*("`@(#QT86)L93X*("`@("`@
M("`\='(^/'1D/F5X86UP;&4\+W1D/CPO='(^"B`@("`\+W1A8FQE/@H@("`@
M/"]F;W)M/@H*("`@(#QT86)L93X*("`@("`@("`\='(^/'1D/@H@("`@("`@
M("`@("`\9F]R;2!A8W1I;VX](FIA=F%S8W)I<'0Z=F]I9"@P*2(@;VYS=6)M
M:70](G)E='5R;B!F86QS93LB/@H@("`@("`@("`@("`\+V9O<FT^"B`@("`@
M("`@/"]T9#X\+W1R/@H@("`@/"]T86)L93X*"D%L;"!*879A4V-R:7!T('1A
M9W,@;75S="!H879E(&$@=F%L:60@='EP92!P87)A;65T97(Z.@H*("`@(#QS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@(#PA+2T*("`@("XN
M+@H@("`@+R\@+2T^"B`@("`\+W-C<FEP=#X*"DYO=&AI;F<@;6%Y(&%P<&5A
M<B!A9G1E<B!@8#PO:'1M;#Y@8"P@=&AE<F5F;W)E(&EN8VQU9&4@86YY(&-O
M;6UO;B!F;V]T97)S"F%F=&5R(&%L;"!O=&AE<B!O=71P=70N"@I!;&P@:6UA
M9V5S(&UU<W0@:&%V92!A;B!@8&%L=&!@(&%T=')I8G5T93HZ"@H@("`@/&EM
M9R!S<F,](F5X86UP;&4N9VEF(B!A;'0](CP_<&AP(&5C:&\@7R@B17AA;7!L
M92(I(#\^(B`O/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=E>&%M<&QE
M+F=I9B<L(%\H(D5X86UP;&4B*2D@/SX@("`@("`@("`@("`@("`@("`H3VX@
M=&AE($A%040@8G)A;F-H*0H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=E
M>&%M<&QE+F=I9B<L("=A;'0](B<@+B!?*")%>&%M<&QE(BD@+B`G(B<I(#\^
M("`H3VX@=&AE(%)%3$5.1U\R(&)R86YC:"D*"DEN<'5T(&9I96QD<R!O9B!T
M>7!E(")I;6%G92(@9&\@;F]T(&%L;&]W('1H92!B;W)D97(@871T<FEB=71E
M(&%N9"!M87D@<F5N9&5R"G=I=&@@82!B;W)D97(@;VX@<V]M92!B<F]W<V5R
M<RX@(%5S92!T:&4@9F]L;&]W:6YG(&EN<W1E860Z.@H*("`@/&$@:')E9CTB
M(B!O;F-L:6-K/2)D;V-U;65N="YF;W)M;F%M92YS=6)M:70H*3L@<F5T=7)N
M(&9A;'-E.R(^/#]P:'`@96-H;R!(;W)D93HZ:6UG*")E>&%M<&QE+F=I9B(L
M(%\H(D5X86UP;&4B*2D@/SX\+V$^"@H*1&%T86)A<V4@3F%M:6YG($-O;G9E
M;G1I;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*06QL(&1A=&%B
M87-E('1A8FQE<R!U<V5D(&)Y($AO<F1E(')E<V]U<F-E<R!A;F0@2&]R9&4@
M87!P;&EC871I;VYS(&YE960@=&\*;6%K92!S=7)E('1H870@=&AE:7(@=&%B
M;&4@86YD(&9I96QD(&YA;65S('=O<FL@:6X@86QL(&1A=&%B87-E<RX@($UA
M;GD*9&%T86)A<V5S(')E<V5R=F4@=V]R9',@;&EK92`G=6ED)RP@)W5S97(G
M+"!E=&,N(&9O<B!I;G1E<FYA;"!U<V4L(&%N9"!F;W)B:60*=V]R9',@=&AA
M="!A<F4@4U%,(&ME>7=O<F1S("AS96QE8W0L('=H97)E+"!E=&,N*2X@($%L
M<V\L(&%L;"!N86UE<R!S:&]U;&0@8F4*;&]W97)C87-E+"!W:71H('5N9&5R
M<V-O<F5S("@G7R<I('1O('-E<&%R871E('=O<F1S+"!T;R!A=F]I9"!C87-E
M('-E;G-I=&EV:71Y"FES<W5E<RX*"D$@9V]O9"!W87D@=&\@9&\@=&AI<R!F
M;W(@9FEE;&0@;F%M97,@:7,@=&\@;6%K92!T:&4@9FEE;&0@;F%M90IT86)L
M96YA;65?9FEE;&1N86UE+@H*3W1H97(@9V5N97)A;"!G=6ED96QI;F5S.B!4
M86)L92!N86UE<R!S:&]U;&0@8F4@<&QU<F%L("AU<V5R<RD[(&9I96QD(&YA
M;65S"G-H;W5L9"!B92!S:6YG=6QA<B`H=7-E<E]N86UE*2X*"@I296=U;&%R
M($5X<')E<W-I;VX@57-E"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"D%L=V%Y
M<R!U<V4@=&AE(&!P<F5G7V!?(&9U;F-T:6]N<R!I9B!P;W-S:6)L92!I;G-T
M96%D(&]F(&!E<F5G7V!?("AA;F0*8'!R96=?<W!L:70H*6!?(&EN<W1E860@
M;V8@8'-P;&ET*"E@7RD[('1H97D@87)E(&EN8VQU9&5D(&EN(%!(4"!B>2!D
M969A=6QT"F%N9"!M=6-H(&UO<F4@969F:6-I96YT(&%N9"!M=6-H(&9A<W1E
M<B!T:&%N(&!E<F5G7V!?+@H**BI.159%4BHJ('5S92!A(')E9W5L87(@97AP
M<F5S<VEO;B!T;R!M871C:"!O<B!R97!L86-E(&$@<W1A=&EC('-T<FEN9RX*
M8&5X<&QO9&4H*6!?("AI;B!P;&%C92!O9B!@<W!L:70H*6!?*2P@8'-T<E]R
M97!L86-E*"E@7RP@8'-T<G!O<R@I8%\L(&]R"F!S=')T<B@I8%\@9&\@=&AE
M(&IO8B!M=6-H(&UO<F4@969F:6-I96YT;'DN"@HN+B!?<')E9U\Z(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO96XO<F5F+G!C<F4N<&AP"BXN(%]E<F5G
M7SH@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]R968N<F5G97@N<&AP
M"BXN(%]P<F5G7W-P;&ET*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO
M96XO9G5N8W1I;VXN<')E9RUS<&QI="YP:'`*+BX@7W-P;&ET*"DZ(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN<W!L:70N<&AP"BXN
M(%]E>'!L;V1E*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N
M8W1I;VXN97AP;&]D92YP:'`*+BX@7W-T<E]R97!L86-E*"DZ(&AT='`Z+R]W
M=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN<W1R+7)E<&QA8V4N<&AP
M"BXN(%]S=')P;W,H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F
M=6YC=&EO;BYS=')P;W,N<&AP"BXN(%]S=')T<B@I.B!H='1P.B\O=W=W+G!H
M<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G-T<G1R+G!H<`H*"E!A<F%M971E
M<B!087-S:6YG"CT]/3T]/3T]/3T]/3T]/3T]"@I/8FIE8W1S('-H;W5L9"!B
M92!P87-S960@8GD@<F5F97)E;F-E+B`@179E<GET:&EN9R!E;'-E+"!I;F-L
M=61I;F<@87)R87ES+`IS:&]U;&0@8F4@<&%S<V5D(&)Y('9A;'5E('=H97)E
M=F5R('-E;6%N=&EC86QL>2!P;W-S:6)L92X*"EM:96YD($5N9VEN92`R.B!O
M8FIE8W1S('-H;W5L9"!A;'-O(&)E('!A<W-E9"!B>2!V86QU95T*"E1H:7,@
M<')A8W1I8V4@=&%K97,@9G5L;"!A9'9A;G1A9V4@;V8@<F5F97)E;F-E(&-O
M=6YT:6YG+@H*+BX@3F]T93HZ(%1H92!@=&5R;F%R>2!O<&5R871O<F!?(&%U
M=&]M871I8V%L;'D@<F5T=7)N<R!A(&-O<'D@;V8@:71S"B`@("`@("`@("!O
M<&5R86YD<RP@<V\@9&]N)W0@=7-E(&ET('=I=&@@;V)J96-T<RP@;W(@:68@
M>6]U(&%R92!S=7)E('EO=2!W86YT"B`@("`@("`@("!T;R!R971U<FX@86X@
M;V)J96-T(&-O<'DN"@HN+B!?8'1E<FYA<GD@;W!E<F%T;W)@.B!H='1P.B\O
M=W=W+G!H<"YN970O;6%N=6%L+V5N+VQA;F=U86=E+F]P97)A=&]R<RYC;VUP
M87)I<V]N+G!H<"-L86YG=6%G92YO<&5R871O<G,N8V]M<&%R:7-O;BYT97)N
M87)Y"@H*3&]N9R!,:6YE<PH]/3T]/3T]/3T]"@I7<F%P(&QI;F5S(&%T(#@P
M(&-H87)A8W1E<G,L(&EN8VQU9&EN9R!C;VUM96YT<RP@=6YL97-S('1H:7,@
M<V5V97)E;'D@:6UP86-T<PIT:&4@8VQA<FET>2!O9B!T:&4@8V]D92X@($%L
M=V%Y<R!W<F%P(&-O;6UE;G1S+@H*"DQI;F4@0G)E86MS"CT]/3T]/3T]/3T]
M"@I/;FQY('5S92!53DE8('-T>6QE(&]F(&QI;F5B<F5A:R`H8&!<;F!@*2P@
M;F]T(%=I;F1O=W,O1$]3+TUA8R!S='EL90HH8&!<<EQN8&`I+@H*57-I;F<@
M=FEM+"!T;R!C;VYV97)T(&9R;VT@1$]3('-T>6QE('1Y<&4Z.@H*("`@(#IS
M970@9F8]=6YI>`H*57-I;F<@=FDL('1O(&-O;G9E<G0@9G)O;2!$3U,@<W1Y
M;&4@='EP93HZ"@H@("`@.F<O7DTO<R\O+V<*"BA.;W1E('1H870@=&AE(&!@
M7DU@8"!I<R!A(&-O;G1R;VP@8VAA<F%C=&5R+"!A;F0@=&\@<F5P<F]D=6-E
M(&ET('=H96X@>6]U"G1Y<&4@:6X@=&AE('9I(&-O;6UA;F0@>6]U(&AA=F4@
M=&\@<&%D(&ET(&9I<G-T('5S:6YG('1H92!S<&5C:6%L(&!@7E9@8`IC:&%R
M86-T97(N*0H*"E!R:79A=&4@5F%R:6%B;&5S"CT]/3T]/3T]/3T]/3T]/3T]
M"@I687)I86)L97,@=7-E9"!E>&-L=7-I=F5L>2!W:71H:6X@82!C;&%S<R!S
M:&]U;&0@8F5G:6X@=VET:"!A('5N9&5R<V-O<F4@*"=?)RD*8VAA<F%C=&5R
M+B`@06X@97AA;7!L92!C;&%S<R!V87)I86)L92!D969I;FET:6]N.B`@8&!V
M87(@)%]V87)I86)L96YA;64[8&`*"@I!<G)A>2!$969I;FET:6]N<PH]/3T]
M/3T]/3T]/3T]/3T]/0H*5VAE;B!D969I;FEN9R!A<G)A>7,L(&]R(&YE<W1E
M9"!A<G)A>7,L('5S92!T:&4@9F]L;&]W:6YG(&9O<FUA="P@=VAE<F4*:6YD
M96YT871I;VX@:7,@;F]T960@=FEA('1H92!C;&]S:6YG('!A<F5N=&AE<VES
M(&-H87)A8W1E<G,Z.@H*("`@("1A<G)A>6YA;65;)VEN9&5X)UT@/2!A<G)A
M>2@*("`@("`@("`G;F%M93$G(#T^("=V86QU93$G+`H@("`@("`@("=N86UE
M,B<@/3X@87)R87DH"B`@("`@("`@("`@("=S=6)N86UE,2<@/3X@)W-U8G9A
M;'5E,2<L"B`@("`@("`@("`@("=S=6)N86UE,B<@/3X@)W-U8G9A;'5E,B<*
M("`@("`@("`I"B`@("`I.PH*5&AE(&]N;'D@97AC97!T:6]N('-H;W5L9"!B
M92!F;W(@96UP='D@;W(@<VAO<G0@87)R87ES('1H870@9FET(&]N(&]N92!L
M:6YE+`IW:&EC:"!M87D@8F4@=W)I='1E;B!A<SHZ"@H@("`@)&%R<F%Y;F%M
M95LG:6YD97@G72`](&%R<F%Y*"D["@H*26YT97)N871I;VYA;&EZ871I;VX@
M*$DQ.&XI"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*36%R:R!A;&P@
M<W1R:6YG<R!P<F5S96YT960@=&\@=&AE('5S97(@87,@9V5T=&5X="!S=')I
M;F=S(&)Y(&-A;&QI;F<@=&AE"F=E='1E>'0@<VAO<G1C=70@9G5N8W1I;VX@
M*&!@7R@I8&`I.CH*"B`@("!E8VAO(%\H(DAE;&QO('=O<FQD(BD["@I$;VXG
M="!U<V4@=&AE(&=E='1E>'0@9G5N8W1I;VYS(&9O<B!S=')I;F=S('1H870@
M=VEL;"!B92!W<FET=&5N('1O(&$@;&]G(&9I;&4*;W(@;W1H97)W:7-E('!R
M97-E;G1E9"!T;R!T:&4@861M:6YI<W1R871O<BX*"E1H92!3=')I;F<Z.B!C
M;&%S<R!C;VYT86EN<R!S979E<F%L('-T<FEN9R!M86YI<'5L871I;VX@;65T
M:&]D<R!T:&%T(&%R92P@87,*;W!P;W-E9"!T;R!T:&5I<B!02%`@97%U:79A
M;&5N=',L(&QO8V%L92!A;F0@8VAA<G-E="!S869E+@H*57-E(%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H*2!I9B!Y;W4@;F5E9"!T;R!C;VYV97)T(&)E='=E
M96X@9&EF9F5R96YT"F-H87)A8W1E<B!S970@96YC;V1I;F=S("AF;W(@97AA
M;7!L92P@8F5T=V5E;B!U<V5R(&EN<'5T(&%N9"!A('-T;W)A9V4@8F%C:V5N
M9`IO<B!D871A(&9R;VT@86X@97AT97)N86P@<V]U<F-E(&%N9"!T:&4@=7-E
M<B!I;G1E<F9A8V4I+B`@66]U(&1O;B=T(&YE960@=&\*8V%R92!I9B!T:&4@
M8VAA<F%C=&5R('-E=',@87)E(')E86QL>2!D:69F97)E;G0N"@I5<V4@=&AE
M(%-T<FEN9SHZ;&]W97(H*2!A;F0@4W1R:6YG.CIU<'!E<B@I(&UE=&AO9',@
M=VET:&]U="!A('-E8V]N9`IP87)A;65T97(@:68@>6]U(&YE960@=&\@<&5R
M9F]R;2!A(&QO8V%L92UI;F1E<&5N9&5N="!S=')I;F<@8V]N=F5R<VEO;BX*
M5&AA="=S('1H92!C87-E(&9O<B!A;&P@<W1R:6YG<R!T:&%T(&%R92!F=7)T
M:&5R('!R;V-E<W-E9"!O<B!I;G1E<G!R971E9"!B>0IC;V1E+B`@57-E('1H
M97-E(&UE=&AO9',@=VET:"!T:&4@<V5C;VYD('!A<F%M971E<B!S970@=&\@
M=')U92!F;W(@<W1R:6YG<PIT:&%T(&YE960@=&\@8F4@8V]N=F5R=&5D(&-O
M<G)E8W1L>2!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@*&]R('-P96-I9FEE
M9"D*8VAA<F%C=&5R('-E="X*"E5S92!T:&4@;W1H97(@4W1R:6YG.CH@97%U
M:79A;&5N=',@;V8@4$A0('-T<FEN9R!F=6YC=&EO;G,@=&\@;6%N:7!U;&%T
M90IS=')I;F=S(&-O<G)E8W1L>2!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@
M*&]R('-P96-I9FEE9"D@8VAA<F%C=&5R('-E="!B=70*=7-E('1H92!02%`@
M9G5N8W1I;VYS(&9O<B!C;V1E+VUA8VAI;F4@<')O8V5S<V5D('-T<FEN9W,N
M"@H*17)R;W(@8VAE8VMI;F<*/3T]/3T]/3T]/3T]/3T*"DAO<F1E(&-O9&4@
M<VAO=6QD('5S92!@4$5!4E]%<G)O<F!?(&]B:F5C=',@=&\@<F5T=7)N(&UO
M<W0@97)R;W(@8V]N9&ET:6]N<PIF<F]M(&QI8G)A<GD@8V%L;',L(&%N9"!M
M86YY('1I;65S('=E('=I;&P@<VEM<&QY('!A<W,@8F%C:R!A(&!014%27T5R
M<F]R8%\*;V)J96-T(&=E;F5R871E9"!B>2!A;B!U;F1E<FQY:6YG(&QI8G)A
M<GD@*'-U8V@@87,@36%I;"!O<B!014%2($1"*2X*"D9O<B!T:&5S92!C87-E
M<RP@=7-E('1H92!F;VQL;W=I;F<@<W1Y;&4@;V8@8V]D92!B;&]C:R!T;R!C
M:&5C:R!F;W(@<W5C8V5S<PIA9G1E<B!A;GD@8V%L;"!W:&EC:"!C;W5L9"!G
M96YE<F%T92!A;B!E<G)O<B!C;VYD:71I;VXZ.@H*("`@("1R97-U;'0@/2`D
M<V]M971H:6YG+3YC86QL*"=M87D@97)R;W(G*3L*("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`O+R!(86YD;&4@97)R
M;W(@8V]N9&ET:6]N+@H@("`@?2!E;'-E('L*("`@("`@("`O+R!3=6-C965D
M960N"B`@("!]"@I.;W1E('1H870@8&ES7V$H*6!?(&-H96-K<R!F;W(@<W5B
M8VQA<W-E<R!O9B!T:&4@;F%M960@8VQA<W,L(&%S('=E;&PL('-O(&EF"G1H
M92!O8FIE8W0@>6]U(&=E="!B86-K(&ES(')E86QL>2!A(&!$0E]%<G)O<F!?
M(&]B:F5C="P@=&AI<R!W:6QL('-T:6QL(&-A=&-H"FET("AS:6YC92!@1$)?
M17)R;W)@7R!E>'1E;F1S(&!014%27T5R<F]R8%\I+@H*0V%L;&EN9R!014%2
M.CII<T5R<F]R*"D@<F5S=6QT<R!I;B!T:&4@<V%M92!B96AA=FEO<BP@8G5T
M(&ES7V$H*0IA8V-O;7!L:7-H97,@=&AE('-A;64@<F5S=6QT('=I=&@@82!S
M:6YG;&4@;F%T:79E(%!(4"!F=6YC=&EO;B!C86QL+@H*+BX@7U!%05)?17)R
M;W(Z(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<&5A<BYP
M96%R+65R<F]R+G!H<`HN+B!?1$)?17)R;W(Z(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N9&(M97)R;W(N<&AP
M"BXN(%]I<U]A*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N
M8W1I;VXN:7,M82YP:'`*"@I%>&ES=&5N8V4@8VAE8VMI;F<*/3T]/3T]/3T]
M/3T]/3T]/3T]"@I/9G1E;B!Y;W4G;&P@;F5E9"!T;R!C:&5C:R!W:&5T:&5R
M(&]R(&YO="!A('9A<FEA8FQE(&]R('!R;W!E<G1Y(&5X:7-T<RX*5&AE<F4@
M87)E('-E=F5R86P@8V%S97,@:&5R93H*"F$N($EF('EO=2!N965D('1O(&MN
M;W<@:68@82!V87)I86)L92!E>&ES=',@870@86QL(&%N9"!I<R!N;W0@8&!N
M=6QL8&`L('5S90I@:7-S970H*6!?.CH*"B`@("`O+R!#:&5C:R!T;R!S964@
M:68@)'!A<F%M(&ES(&1E9FEN960N"B`@("!I9B`H:7-S970H)'!A<F%M*2D@
M>PH@("`@("`@("\O("1P87)A;2!M87D@8F4@9F%L<V4L(&)U="!I="=S('1H
M97)E+@H@("`@?0H*8BX@268@>6]U(&YE960@=&\@:VYO=R!I9B!A('9A<FEA
M8FQE(&5X:7-T<R!!3D0@:&%S(&$@;F]N+65M<'1Y('9A;'5E("AN;W0*8&!N
M=6QL8&`L(#`L(&!@9F%L<V5@8"P@96UP='D@<W1R:6YG(&]R('5N9&5F:6YE
M9"DL('5S92`A8&5M<'1Y*"E@7SHZ"@H@("`@+R\@36%K92!S=7)E('1H870@
M)&%N<W=E<B!E>&ES=',L(&ES(&YO="!A;B!E;7!T>2!S=')I;F<L(&%N9"!I
M<PH@("`@+R\@;F]T(#`Z"B`@("!I9B`H(65M<'1Y*"1A;G-W97(I*2!["B`@
M("`@("`@+R\@)&%N<W=E<B!H87,@<V]M92!N;VXM9F%L<V4@8V]N=&5N="X*
M("`@('T@96QS92!["B`@("`@("`@+R\@*&)O;VPI)&%N<W=E<B!W;W5L9"!B
M92!F86QS92X*("`@('T*"D%S('!O:6YT960@;W5T(&EN('1H92!C;VUM96YT
M(&]F('1H92!E;'-E(&-L875S92P@8&5M<'1Y*"E@7R!E<W-E;G1I86QL>2!D
M;V5S"G1H92!S86UE(&-H96-K(&%S(&!I<W-E="@I8%\@+2T@:7,@=&AI<R!V
M87)I86)L92!D969I;F5D(&EN('1H92!C=7)R96YT('-C;W!E/PHM+2!A;F0@
M=&AE;BP@:68@:70@:7,L(')E='5R;G,@=VAA="!T:&4@=F%R:6%B;&4@=V]U
M;&0@979A;'5A=&4@=&\@87,@80IB;V]L96%N+B!4:&ES(&UE86YS('1H870@
M,"P@=VAI;&4@<&]T96YT:6%L;'D@=F%L:60@:6YP=70L(&ES(")E;7!T>2(@
M+2!S;R!I9@HP(&ES('9A;&ED(&1A=&$@9F]R('EO=7(@8V%S92P@9&]N)W0@
M=7-E("%@96UP='DH*6!?+@H*8RX@268@>6]U(&MN;W<@>6]U(&%R92!W;W)K
M:6YG('=I=&@@82!M:7AE9"!V87)I86)L92!T:&5N('5S:6YG(&IU<W0*8&ES
M<V5T*"E@7R!A;F0@8&5M<'1Y*"E@7R!C;W5L9"!C875S92!U;F5X<&5C=&5D
M(')E<W5L=',L(&9O<B!E>&%M<&QE(&EF"G1E<W1I;F<@9F]R(&$@:V5Y(&%N
M9"!T:&4@=F%R:6%B;&4@:7,@86-T=6%L;'D@82!S=')I;F<Z.@H*("`@("1F
M;V\@/2`G8F%R)SL*("`@(&EF("AI<W-E="@D9F]O6R=S;VUE:V5Y)UTI*2![
M"B`@("`@("`@+R\@5&AI<R!W:6QL(&5V86QU871E('1O(%12544A"B`@("!]
M"@I)9B!Y;W4@:VYO=R!T:&%T('1H97)E(&ES(&$@<&]S<VEB:6QI='D@;V8@
M82!M:7AE9"!T>7!E('9A<FEA8FQE('1H92!S;VQU=&EO;@II;B!T:&ES(&-A
M<V4@=V]U;&0@8F4@=&\@861D(&%N(&!I<U]A<G)A>2@I8%\@8VAE8VL@:6X@
M=&AE(&!@:68H*6!@('-T871E;65N="X*"F0N(%5S92!@87)R87E?:V5Y7V5X
M:7-T<R@I8%\@=VAE;B!Y;W4@=V%N="!T;R!C:&5C:R!I9B!A;B!A<G)A>2!K
M97D@:7,@9&5F:6YE9`IE=F5N(&EF(&ET(&AA<R!A('9A;'5E(&]F(&!@;G5L
M;&!@.CH*"B`@("`O+R!-86ME('-U<F4@=V4@:&%V92!A(&-H87)S970@<&%R
M86UE=&5R+B!686QU92!C;W5L9"!A;'-O(&)E(&YU;&PN"B`@("!I9B`H(6%R
M<F%Y7VME>5]E>&ES=',H)V-H87)S970G+"`D<&%R86US*2D@>PH@("`@("`@
M($AO<F1E.CIF871A;"@G26YC;VUP;&5T92!C;VYF:6=U<F%T:6]N+B<I.PH@
M("`@?0H*4&QE87-E(&YO=&4@=&AA="!@87)R87E?:V5Y7V5X:7-T<R@I8%\@
M:7,@82!P97)F;W)M86YC92!H:70@*#(U)2TQ,#`E*2!A;F0*<VAO=6QD(&]N
M;'D@8F4@=7-E9"!W:&5N(&YE8V5S<V%R>2X@26YS=&5A9"!T<GD@=&\@=7-E
M("%@96UP='DH*6!?(&]R"F!I<W-E="@I8%\@:6YS=&5A9"X*"BXN(%]I<W-E
M="@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+FES
M<V5T+G!H<`HN+B!?96UP='DH*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A
M;"]E;B]F=6YC=&EO;BYE;7!T>2YP:'`*+BX@7VES7V%R<F%Y*"DZ(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN:7,M87)R87DN<&AP
M"BXN(%]A<G)A>5]K97E?97AI<W1S*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M
M86YU86PO96XO9G5N8W1I;VXN87)R87DM:V5Y+65X:7-T<RYP:'`*"@I1=6]T
M97,*/3T]/3T]"@I9;W4@<VAO=6QD(&%L=V%Y<R!U<V4@<VEN9VQE('%U;W1E
M("@G*2!C:&%R86-T97)S(&%R;W5N9"!S=')I;F=S+"!E>&-E<'0@=VAE<F4*
M9&]U8FQE('%U;W1E("@B*2!C:&%R86-T97)S(&%R92!R97%U:7)E9"X@($%L
M;"!L:71E<F%L('-T<FEN9W,@<VAO=6QD(&)E(&EN"G-I;F=L92!Q=6]T97,N
M("!!(&-O;7!A<FES;VX@;V8@<VEN9VQE(&%N9"!D;W5B;&4@<75O=&4@=7-A
M9V4@9F]L;&]W<SH*"E-I;F=L92!1=6]T97,Z"B`@*B!687)I86)L97,@:6X@
M=&AE('-T<FEN9R!A<F4@;F]T('!A<G-E9"!O<B!E>'!A;F1E9"X*("`J($YE
M=R!L:6YE('-Y;6)O;',@8V%N(&)E(&EN8VQU9&5D(&%S(&QI=&5R86P@;&EN
M92!E;F1S("AN;W0@<F5C;VUM96YD960I+@H@("H@5&\@:6YC;'5D92!A('-I
M;F=L92!Q=6]T92!C:&%R86-T97(L(&5S8V%P92!I="!W:71H(&$@8&!<8&`@
M*&)A8VMS;&%S:"D*("`@(&-H87)A8W1E<BP@87,@:6XZ(&!@96-H;R`G2&5R
M95PG<R!A;B!E>&%M<&QE)SM@8`H@("H@5&\@<W!E8VEF>2!A(&!@7&!@("AB
M86-K<VQA<V@I(&-H87)A8W1E<BP@9&]U8FQE(&ET.B!@8&5C:&\@)V,Z7%QT
M96UP)SM@8`H*1&]U8FQE(%%U;W1E<SH*("`J(%!A<G-E<R!A;F0@97AP86YD
M<R!V87)I86)L97,@:6X@=&AE('-T<FEN9RX*("`J(%5S97,@861V86YC960@
M*&!S<')I;G1F8%\M<W1Y;&4I(&5S8V%P92!S97%U96YC97,@;&EK92!@8%QN
M8&`L(&!@7"1@8"P*("`@(&!@7'1@8"P@971C+@H@("H@4VAO=6QD(&)E('5S
M960@:6X@=&AE(&=E='1E>'0@<VAO<G1C=70@8&!?*"(B*6!@(&9O<FUA="X*
M("`J(%5S92!W:71H(&-A<F4L(&%S(&UA;GD@8V]R<F5C="!L;V]K:6YG('-T
M<FEN9W,@87)E(')E86QL>2!I;G9A;&ED+@H*5&AE(&9O;&QO=VEN9R!A<F4@
M86QL(&EN8V]R<F5C=#HZ"@H@("`@96-H;R`B5&]D87D@:7,@=&AE("1D871E
M6R=D87DG72!O9B`D9&%T95LG;6]N=&@G72(*("`@("1?4T534TE/3EMI;F1E
M>%T@/2`D7U-%4U-)3TY;(F]L9%]I;F1E>")=.PH*+BX@7W-P<FEN=&8Z(&AT
M='`Z+R]W=W<N<&AP+FYE="]S<')I;G1F"@H*9&5F:6YE*"D*/3T]/3T]/3T*
M"E-U<G!R:7-I;F=L>2!E;F]U9V@L(&!D969I;F4H*6!?(&ES(&$@<V]M97=H
M870@<VQO=R!F=6YC=&EO;B!I;B!02%`@*&%S(&]F(%!(4`HT+C,N>"D@<V\@
M97AC97-S:79E('5S92!I<R!D:7-C;W5R86=E9"X*"E5S:6YG(&!D969I;F4H
M*6!?(&EN(&-L87-S97,@<VAO=6QD(&)E($]+("T@=V4@=VEL;"!S86-R:69I
M8V4@82!T:6YY(&)I="!O9@IS<&5E9"!F;W(@<F5A9&%B:6QI='D@;V8@8V]D
M92X@(&!D969I;F4H*6!?('-H;W5L9"!.3U0@8F4@=7-E9"!F;W(@86-T:6]N
M241S("T*=7-E(&$@<&QA:6X@;VQD('-T<FEN9R!I;G-T96%D+B`@1F]R(&%N
M>71H:6YG(&5L<V4L('5S92!Y;W5R(&)E<W0@:G5D9VUE;G0N"@I!9&1I=&EO
M;F%L;'DL(&5V97)Y(&-O;G-T86YT('-H;W5L9"!B92!P<F5F:7AE9"!W:71H
M(&!@2$]21$5?8&`L(&ET<R!P86-K86=E"FYA;64L(&]R('1H92!A<'!L:6-A
M=&EO;B!N86UE+@H*+BX@7V1E9FEN92@I.B!H='1P.B\O=W=W+G!H<"YN970O
M;6%N=6%L+V5N+V9U;F-T:6]N+F1E9FEN92YP:'`*"@I396-U<FET>2!#;VYS
M:61E<F%T:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE(&9O;&QO
M=VEN9R!A<F4@82!N;VXM97AH875S=&EV92!L:7-T(&]F(&9E871U<F5S+V9U
M;F-T:6]N<R!T;R!T86ME"G-P96-I86P@8V%R92!W:71H.@H*4$A0($-O9&4@
M17AE8W5T:6]N.@HM+2TM+2TM+2TM+2TM+2TM+2TM"@IR97%U:7)E+"!I;F-L
M=61E+"!R97%U:7)E7V]N8V4L(&EN8VQU9&5?;VYC92`M($-A<F5F=6QL>2!A
M=61I="!A;GD*=F%R:6%B;&5S('5S960@:6X@=&AE<V4@9G5N8W1I;VYS+"!A
M;F0@8VAE8VL@=&AE('-O=7)C92!O9B!A;GD*8V]N<W1A;G1S(&%S('=E;&PN
M"@IE=F%L("T@3V)V:6]U<R!D86YG97(@:68@=7-E<B!I;G!U="!I<R!S=7!P
M;&EE9"!T;R!I="!I;B!U;F-O;G1R;VQL960@8V]N9&ET:6]N<RX*"G!R96=?
M<F5P;&%C92`M(%1H92`O92!M;V1I9FEE<B!C875S97,@=&AE(')E<&QA8V5M
M96YT('-T<FEN9R!T;R!B90IE=F%L=6%T960@87,@4$A0(&-O9&4N"@I#;VUM
M86YD($5X96-U=&EO;CH*+2TM+2TM+2TM+2TM+2TM+2TM"@IE>&5C("T@17AE
M8W5T97,@82!S<&5C:69I960@8V]M;6%N9"!A;F0@<F5T=7)N<R!T:&4@;&%S
M="!L:6YE(&]F(&]U='!U="X*"G!A<W-T:')U("T@17AE8W5T97,@82!S<&5C
M:69I960@8V]M;6%N9"!A;F0@=W)I=&5S('1H92!O=71P=70@=&\@4U1$3U54
M+@H*8&`@*&)A8VMT:6-K<RD@+2!%>&5C=71E<R!T:&4@<W!E8VEF:65D(&-O
M;6UA;F0@86YD(')E='5R;G,@86QL('1H90IO=71P=70@:6X@86X@87)R87DN
M"@IS>7-T96T@+2!,:6ME('!A<W-T:')U*"D@8G5T(&1O97-N)W0@:&%N9&QE
M(&)I;F%R>2!D871A+@H*<&]P96X@+2!%>&5C=71E<R!A('-P96-I9FEE9"!C
M;VUM86YD(&%N9"!C;VYN96-T<R!I=',@;W5T<'5T(&]R(&EN<'5T"G-T<F5A
M;2!T;R!A(%!(4"!F:6QE(&1E<V-R:7!T;W(N"@I&:6QE($1I<V-L;W-U<F4Z
M"BTM+2TM+2TM+2TM+2TM+2T*"D9I;&4@9G5N8W1I;VYS('=H:6-H(&-A;B!B
M92!P;W1E;G1I86QL>2!U<V5D('1O(&]P96X@<F5M;W1E(&]R"G5N:6YT96YD
M960@9FEL97,Z(&9O<&5N+"!R96%D9FEL92P@9FEL92P@9FEL95]G971?8V]N
M=&5N=',N"@H*3W!T:6UI>F%T:6]N<PH]/3T]/3T]/3T]/3T]"@I4:&4@9F]L
M;&]W:6YG(&]P=&EM:7IA=&EO;G,@<VAO=6QD(&)E('5S960L(&EF('!O<W-I
M8FQE.@H*97AT96YS:6]N7VQO861E9"@I"BTM+2TM+2TM+2TM+2TM+2TM+0I4
M:&ES(&%P<&5A<G,@=&\@8F4@86X@97AP96YS:79E(%!(4"!C86QL+B`@57-E
M(%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@I"FEN<W1E860L('=H:6-H('=I;&P@
M8V%C:&4@=&AE(')E<W5L=',@;V8@=&AE(&-A;&PN"@I#;VYC871E;F%T92!S
M=')I;F=S"BTM+2TM+2TM+2TM+2TM+2TM+2T*0G5I;&1I;F<@82!S=')I;F<@
M=VET:"!C;VYC871E;F%T:6]N("AT:&4@(BXB(&]P97)A=&]R*2!U<VEN9PIS
M:6YG;&4M<75O=&5D('-T<FEN9W,@86YD('9A<FEA8FQE<R!I<R!F87-T97(@
M=&AA;B!U<VEN9R!A;@II;G1E<G!O;&%T960@<W1R:6YG("AA('-T<FEN9R!I
M;G-I9&4@9&]U8FQE('%U;W1E<R!W:71H('9A<FEA8FQE<PII;G-I9&4@=&AE
M('-T<FEN9R!I='-E;&8I+B`@26X@861D:71I;VXL(&-O;F-A=&5N871I;VX@
M:7,@96%S:65R('1O"G)E860@86YD(&%U9&ET(&9O<B!L;V=I8R!A;F0@<V5C
M=7)I='D@<')O8FQE;7,N"@I0<F4M:6YC<F5M96YT+V1E8W)E;65N=`HM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0I"96-A=7-E(&]F('1H92!W87D@8V]M<&EL
M97)S+VEN=&5R<')E=&5R<R!W;W)K+"!P;W-T+6EN8W)E;65N=&EN9PHH)'9A
M<BLK*2!R97%U:7)E<R!S=&]R:6YG(&)O=&@@=&AE(&]R:6=I;F%L(&%N9"!N
M97<@=F%L=65S(&]F('1H90IV87)I86)L92!I;B!M96UO<GD@8F5C875S92!T
M:&4@;VQD('9A;'5E(&UA>2!B92!U<V5D(&%F=&5R('1H90IO<&5R871I;VX@
M:6X@<75E<W1I;VX@:7,@8V]M<&QE=&4N("!">2!C;VUP87)I<V]N+"!P<F4M
M:6YC<F5M96YT:6YG"B@K*R1V87(I(&%L;6]S="!N979E<B!N965D<R!T;R!S
M=&]R92!B;W1H('9A;'5E<RX@($ET)W,@82!M87)G:6YA;`IS<&5E9'5P(&)U
M="!I="=S(&%L<V\@<VEM<&QY(&-H86YG:6YG('1H92!O<F1E<B!O9B!A(&9E
M=R!C:&%R86-T97)S+@H*3&]O<',*+2TM+2T*36%K92!S=7)E('1H870@>6]U
M(&1O(&YO="!C;VYT:6YU92!T;R!D969I;F4@=&AE('-A;64@=F%R:6%B;&4@
M=VET:&EN(&$*;&]O<"X@($EN<W1E860L(&1E8VQA<F4@=&AE('9A<FEA8FQE
M(&$@<VEN9VQE('1I;64@8F5F;W)E('1H92!L;V]P(&ES(')U;BX*"D%R<F%Y
M"BTM+2TM"D%V;VED(&9R97%U96YT(&%R<F%Y(&%C8V5S<V5S+B`@268@>6]U
M('5S92!A;B!A<G)A>2!O<B!A;B!A<G)A>2!M96UB97(@:6X@80IL;V]P+"!A
M<W-I9VX@:70@=&\@82!V87)I86)L92!F:7)S=#HZ"@H@("`@)&$@/2!A<G)A
M>2@G>"<@/3X@)WDG*3L*("`@("1E;G1R:65S(#T@87)R87DH+BXN*3L*"B`@
M("`D;&5N9W1H(#T@8V]U;G0H)&5N=')I97,I.PH@("`@)'@@/2`D85LG>"==
M.PH@("`@9F]R("@D:2`](#`[("1I(#P@)&QE;F=T:#L@*RLD:2D@>PH@("`@
M("`@(&5C:&\@)'@["B`@("!]"@I5<V5R(&1E9FEN960@9G5N8W1I;VYS"BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T*57-E<B!D969I;F5D(&9U;F-T:6]N<R!A
M<F4@;6]R92!E>'!E;G-I=F4@=&AA;B`B<F5G=6QA<B(@9G5N8W1I;VYS+B`@
M57-E('1H96T*;VYL>2!I9B!T:&5Y(&EM<')O=F4@=&AE(&-O9&4@<F5A9&%B
M:6QI='D@;6]R92!T:&5N(')E9W5L87(@9G5N8W1I;VYS+@H*1&ES:R!)+T\*
M+2TM+2TM+2T*1&ES:R!R96%D(&%N9"!W<FET92!O<&5R871I;VYS(&%R92!S
M;&]W+B`@268@<&]S<VEB;&4@<F5A9"!A;F0@=W)I=&4@9FEL97,@:6X*;&%R
M9V4@8VAU;FMS+B`@06-C;W)D:6YG('1O(%!(4"!D;V-U;65N=&%T:6]N+"!F
M:6QE7V=E=%]C;VYT96YT<R@I(&ES"G!O=&5N=&EA;&QY(&UU8V@@9F%S=&5R
M('1H86X@=7-I;F<@9F]P96XH*2]F<F5A9"@I+V9C;&]S92@I+@H*"E-41$E.
M+U-41$]55"]35$1%4E(*/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&\@86-C97-S
M(&5I=&AE<B!35$1)3BP@4U1$3U54+"!O<B!35$1%4E(L('1H92!F;VQL;W=I
M;F<@8V]D92!S:&]U;&0@8F4@=7-E9#HZ"@H@("`@=VAI;&4@*"%F96]F*%M3
M5$1)3GQ35$1/551\4U1$15)272DI('L*("`@("`@("`D;&EN92`](&9G971S
M*%M35$1)3GQ35$1/551\4U1$15)272D["B`@("`@("`@+R\@<')O8V5S<R`D
M;&EN92!H97)E"B`@("!]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O9&]C<R]#3TY44DE"551)3D<`````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S$T-``Q,#4Q-30S,3`U-P`P,3<Q-S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*($AO<F1E.B!(;W<@=&\@2&5L<`H]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`T+S`Y+S(T
M(#(Q.C`R.C`Q("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XT("0*
M.D-O;G1A8W0Z("`@("`@(&-O<F5`:&]R9&4N;W)G"@I4:&5R92!A<F4@;6%N
M>2!W87ES(&EN('=H:6-H('EO=2!C86X@:&5L<"!O=70@:6X@=&AE(&1E=F5L
M;W!M96YT(&]F(&%N>2!O9B!T:&4*2&]R9&4@<')O:F5C=',N(%1H92!F:7)S
M="!A;F0@8F5S="!W87D@>6]U(&%R92!A;')E861Y(&1O:6YG.B!Y;W4G<F4@
M=7-I;F<*=&AE;2X@3VYE(&]F('1H92!K97ES('1O(&$@9W)E870@<')O9'5C
M="!I<R!I=',@=7-E<G,N(%=I=&AO=70@=7-E<G,@=V4@8V%N)W0*9FEN9"!B
M=6=S(&]R(&=E="!F965D8F%C:R!O;B!W:&%T)W,@9V]O9"!A;F0@=VAA="=S
M(&)A9"X*"DET(&ES(&1A<FX@;F5A<B!I;7!O<W-I8FQE(&9O<B!T:&4@9&5V
M96QO<&5R<R!T;R!T97-T('1H92!C;V1E(&]N(&5V97)Y"D]P97)A=&EN9R!3
M>7-T96T@86YD(&5V97)Y(&1I9F9E<F5N="!V97)S:6]N(&]F(%=E8B!"<F]W
M<V5R(&%V86EL86)L92!T;R!M86ME"G-U<F4@=&AE(&-O9&4@<G5N<R!S;6]O
M=&AL>2!E=F5R>7=H97)E+B`@3&EN=7@@:7,@;F]T(%=I;F1O=W,L(&%N9"!)
M12!I<R!N;W0*36]Z:6QL82P@86YD(&ET(&ES("AF<F5Q=65N=&QY*2!D:69F
M:6-U;'0@=&\@=&\@<')E9&EC="!B96AA=FEO<B!B971W965N"G!L871F;W)M
M<R]B<F]W<V5R<RX*"E=I=&@@=&AI<R!S86ED+"!O;F4@;V8@=&AE(&)E<W0@
M=V%Y<R!Y;W4@8V%N(&AE;'`@:7,@=&\@=&5S="X@268@>6]U(&-A;B!H96QP
M"G5S('-M;V]T:"!O=70@=&AE(&-O9&4@86-R;W-S(&%L;"`H;W(@979E;B!A
M;GDI('!L871F;W)M<RP@>6]U)W)E(&1O:6YG(&$*9W)E870@<V5R=FEC92!T
M;R!T:&4@<')O:F5C="X*"DYO=RP@:68@=&AA="=S(&YO="!E;F]U9V@@86YD
M('EO=2!W86YT('1O(&1I9R!I;B!A;F0@:&5L<"!C;V1E+"!Y;W4@<VAO=6QD
M"F9I<G-T('-U8G-C<FEB92!T;R!T:&4@<')O:F5C="!L:7-T<RP@<&%R=&EC
M=6QA<FQY('1H92!G96YE<F%L($AO<F1E"F1E=F5L;W!E<G,@;&ES="!D979`
M;&ES=',N:&]R9&4N;W)G("AS964@:'1T<#HO+W=W=RYH;W)D92YO<F<O;6%I
M;"\@9F]R"FEN9F]R;6%T:6]N(&]N('-U8G-C<FEB:6YG('1O('1H92!M86EL
M:6YG(&QI<W1S*2X@($%D9&ET:6]N86QL>2P@>6]U("HJ35535"HJ"G)E860@
M=&AE(&!(;W)D92!#;V1I;F<@4W1A;F1A<F1S8%\@=&\@96YS=7)E('1H870@
M=&AE(&-O9&4@>6]U<B!S=6)M:71T:6YG"G=I;&P@=V%N="!T;R!B92!A;F%L
M>7IE9"!A;F0@<&]T96YT:6%L;'D@8V]M;6ET=&5D(&)Y('1H92!D979E;&]P
M97)S+B`@66]U"G-H;W5L9"!P<F]B86)L>2!R96%D('1H92!V87)I;W5S(%)%
M041-12!F:6QE<R`H9F]R('1H870@;6%T=&5R+"!A;&P@=&AE"F1O8W5M96YT
M871I;VX@:6X@=&AE(&!@9&]C<R]@8"!D:7)E8W1O<GDI(&9O<B!T:&4@<&%R
M=&EC=6QA<B!A<'!L:6-A=&EO;B!Y;W4*87)E('=O<FMI;F<@;VX@86QS;RX*
M"BXN(%]@2&]R9&4@0V]D:6YG(%-T86YD87)D<V`Z(#]F/4-/1$E.1U]35$%.
M1$%21%,N:'1M;```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O
M8W,O0U)%1$E44P``````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,30S,S``,3`U,34T,S$P-3<`,#$V,S8S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&5V96QO<&UE;G0@5&5A;0H]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*"@I#;W)E($1E=F5L;W!E<G,*/3T]/3T]/3T]
M/3T]/3T]"@I#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&AO<F1E+F]R9SX*"@I,;V-A;&EZ871I;VX*/3T]/3T]/3T]/3T]
M"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*07)A8FEC("A3
M>7)I82D@("`@("`@("`@4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\9&5V
M=&5A;4!P;&%T:6YU;2US>2YN970^"D)O<VYI86X@("`@("`@("`@("`@("`@
M($%L96X@4V%R:VEN;W9I8R`\86QE;D!L:6YU>"YO<F<N8F$^"B`@("`@("`@
M("`@("`@("`@("`@("`@(%9E9')A;B!,:G5B;W9I8R`\=FQJ=6)O=FEC0'-M
M87)T;F5T+F)A/@I"<F%Z:6QI86X@4&]R='5G=65S92`@("!#87)L;W,@1&%N
M:65L($MI8G)I="`\:VEB<FET0'1E<G)A+F-O;2YB<CX*("`@("`@("`@("`@
M("`@("`@("`@("`@1F%B:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/@I"
M=6QG87)I86X@("`@("`@("`@("`@("!-:7)O<VQA=B!096YD978@/'!E;F1E
M=D!H;W1M86EL+F-O;3X*0V%T86QA;B`@("`@("`@("`@("`@("`@06YG96QS
M($=U:6UE<N`@/&%N9V5L<RY'=6EM97)A0'5A8BYE<SX*("`@("`@("`@("`@
M("`@("`@("`@("`@2F]R9&D@1VER86QT(#QP<F]J96-T92YK,D!U<&-N970N
M97,^"D-H:6YE<V4@*%-I;7!L:69I960I("`@(%=A;F=(96YG5V5N(#QW:'=`
M;7DQ-CDN8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!,:6%O8FEN(#QL
M:6%O8FEN0&II=&4N;F5T/@I#:&EN97-E("A4<F%D:71I;VYA;"D@("!$879I
M9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SX*0WIE8V@@("`@("`@("`@("`@
M("`@("`@4&%V96P@0VAY=&EL(#QP86IA0&%S<"YO9VDN961U/@I$86YI<V@@
M("`@("`@("`@("`@("`@("!-87)T:6X@3&ES="U0971E<G-E;B`\;6%R=&EN
M0&QI<W0M<&5T97)S96XN9&L^"B`@("`@("`@("`@("`@("`@("`@("`@($)R
M:6%N(%1R=65L<V5N(#QH;W)D92MI,3AN0&)R:6%N=')U96QS96XN9&L^"D1U
M=&-H("`@("`@("`@("`@("`@("`@($IA;B!+=6EP97)S(#QJ<FMU:7!E<G-`
M;&%U=V5R<V-O;&QE9V4N;FP^"B`@("`@("`@("`@("`@("`@("`@("`@(%!E
M=&5R($%R:65N(#QP971E<BYA<FEE;D!C8RYK=6QE=79E;BYA8RYB93X*("`@
M("`@("`@("`@("`@("`@("`@("`@2&%N(%-P<G5Y="`\:&%N+G-P<G5Y=$!I
M:G-S96QG<F]E<"YN;#X*17-T;VYI86X@("`@("`@("`@("`@("`@5&]O;6%S
M($%A<R`\=&]O;6%S+F%A<T!R86%D+G1A<G1U+F5E/@I&:6YN:7-H("`@("`@
M("`@("`@("`@("!,965N82!(96EN;R`\;&EI;G5`=71A+F9I/@I&<F5N8V@@
M("`@("`@("`@("`@("`@("!&<F5D97)I8R!4<G5D96%U(#QF=')U9&5A=4!C
M86TN;W)G/@H@("`@("`@("`@("`@("`@("`@("`@("!4:&EE<G)Y(%1H;VUA
M<R`\=&AI97)R>4!P;VUP;RYN970^"B`@("`@("`@("`@("`@("`@("`@("`@
M($)E;F]I="!3="U!;F1RZ2`\8F5N0&)E;F]I='-T+6%N9')E+FYE=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@4&EE<G)E($QA8VAA;F-E(#QP;$!P:65R
M<F5L86-H86YC92YN970^"B`@("`@("`@("`@("`@("`@("`@("`@($=R96=O
M<GD@0V]L<&%R="`\9V-O;'!A<G1`979O;&EX+FYE=#X*1V%L:6-I86X@("`@
M("`@("`@("`@("`@4F%F865L(%9A<F5L82`\<F%F865L+G9A<F5L84!U<V,N
M97,^"B`@("`@("`@("`@("`@("`@("`@("`@($=U:6QL97)M;R!-96YD97H@
M/&=U:6QL94!U<V,N97,^"D=E<FUA;B`@("`@("`@("`@("`@("`@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"D=R965K("`@("`@("`@("`@("`@
M("`@(%-T969A;F]S($DN($1I;6ET<FEO=2`\<W5P<&]R=$!T96EA=&@N9W(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(%-I;&QI9V%R9&]S(%AR:7-T;V9O
M<F]S"B`@("`@("`@("`@("`@("`@("`@("`@($%N86=N;W-T;W!O=6QO<R!!
M<&]S=&]L:7,*("`@("`@("`@("`@("`@("`@("`@("`@2V]N<W1A;G1I;F]S
M($,N($UI;&]S:7,@/&MM:6QO<VES0'EA:&]O+F-O;3X*2&5B<F5W("`@("`@
M("`@("`@("`@("`@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^
M"DAU;F=A<FEA;B`@("`@("`@("`@("`@($QA<WIL;R!,+B!4;W)N;V-I(#QT
M;W)L87-Z0'AE;FEA+G-O=&4N:'4^"DEC96QA;F1I8R`@("`@("`@("`@("`@
M($)J;W)N($1A=FED<W-O;B`\8FIO<W-I0'-N97)P82YI<SX*26YD;VYE<VEA
M;B`@("`@("`@("`@("`@4VQA;6EN(#QS;&%M:6Y`=6YE:BYA8RYI9#X*("`@
M("`@("`@("`@("`@("`@("`@("`@2F%M97,@1&]E(#QJ86UE<T!A8W1I;VYM
M97-S86=E+F-O;3X*271A;&EA;B`@("`@("`@("`@("`@("`@4&%O;&$@0V%R
M<&5N=&5R(#QP8V%R<&5N=&5R0&EN9G9I8RYI=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@1VEO=F%N;FD@365N96=H971T:2`\9VUE;F5G:&5T=&E`:6YF
M=FEC+FET/@H@("`@("`@("`@("`@("`@("`@("`@("!&961E<FEC;R!':6%N
M;FEC:2`\9VEA;FYI8VE`;F5O;65D:6$N:70^"B`@("`@("`@("`@("`@("`@
M("`@("`@($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O=F%N;T!U;FEB;V-C
M;VYI+FET/@H@("`@("`@("`@("`@("`@("`@("`@("!#<FES=&EA;B!-86YO
M;FD@/&-R:7-T:6%N+FUA;F]N:4!N971H97-I<RYI=#X*2F%P86YE<V4@("`@
M("`@("`@("`@("`@0BY*+B!";&%C:R`\=VEL;&EA;2YB;&%C:T!S=6XN8V]M
M/@H@("`@("`@("`@("`@("`@("`@("`@("!486ME<VAI($UO<FES:&EM82`\
M=&U`;VYE<&]S="YN970^"B`@("`@("`@("`@("`@("`@("`@("`@($AI<F]M
M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U:W5B82YA8RYJ<#X*2VAM97(@("`@
M("`@("`@("`@("`@("`@3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K:&UE<F]S
M+FEN9F\^"DMO<F5A;B`@("`@("`@("`@("`@("`@($HN22!+:6T@/&%P;W)I
M94!N971I86XN8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!*:6YH>6]K
M($AE;R`\;F]V96UB<F5`;W5R;F%T=7)E+F]R9SX*3&%T=FEA;B`@("`@("`@
M("`@("`@("`@2V%S<&%R<R!+87!E;FEE:W,@/&MA<W!A<G-`<F-C+FQV/@I,
M:71H=6%N:6%N("`@("`@("`@("`@("!$87)I=7,@36%T=6QI875S:V%S(#QD
M87)I=7-`;&YK+FQT/@H@("`@("`@("`@("`@("`@("`@("`@("!6:6QI=7,@
M4W5M<VMA<R`\=FEL:75S0&QN:RYL=#X*36%C961O;FEA;B`@("`@("`@("`@
M("`@4W1O:F%N(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SX*3F]R=V5G:6%N
M($)O:VUA86P@("`@("`@3WES=&5I;B!3=&5I;6QE<B`\;WES=&5I;D!R97AT
M82YN970^"B`@("`@("`@("`@("`@("`@("`@("`@(%1O<G-T96EN(%,N($AA
M;G-E;B`\:'5L96)O97)`=&5C:&)E92YN;SX*("`@("`@("`@("`@("`@("`@
M("`@("`@06YD<F5A<R!'=6YL96EK<VMA87,@/&%N9')E87-`9W5N;&5I:W-K
M86%S+FYO/@H@("`@("`@("`@("`@("`@("`@("`@("!4<F]N9"!":OAR<W1A
M9"`\=')B0&YD;BYN;SX*("`@("`@("`@("`@("`@("`@("`@("`@5&AO;6%S
M($-H<BX@1&%H;"`\=&-D0&YD;BYN;SX*("`@("`@("`@("`@("`@("`@("`@
M("`@1V5I<B!/+B!(;V=B97)G(#QH;W)D94!S:WED:79E<BYN;SX*3F]R=V5G
M:6%N($YY;F]R<VL@("`@("`@4&5R+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N
M;W)G/@I097)S:6%N("`@("`@("`@("`@("`@("!-971A3D54($%M:7)K86)I
M<B`\<&5R<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RYC;VT^"E!O;&ES:"`@
M("`@("`@("`@("`@("`@($UA<FEU<WH@6GEN96P@/&UA<FEU<WI`;6%T:"YU
M=V(N961U+G!L/@H@("`@("`@("`@("`@("`@("`@("`@("!+<GIY<WIT;V8@
M2V]Z;&]W<VMI(#QK;WII:S%`;S(N<&P^"E!O<G1U9W5E<V4@("`@("`@("`@
M("`@($YU;F\@3&]U<F5I<F\@/&YU;F]`971H+G!T/@H@("`@("`@("`@("`@
M("`@("`@("`@("!-86YU96P@365N97IE<R!D92!397%U96ER82`\36%N=65L
M+E-E<75E:7)A/@I2;VUA;FEA;B`@("`@("`@("`@("`@("!#;W)N96QI=2!-
M=7-A="`\8VUU<V%T0'1I86UA="YK97ES>7,N<F\^"E)U<W-I86X@("`@("`@
M("`@("`@("`@($EG;F%T($EK<GEA;F]V(#QI9VYA=$!I8F0N<G4^"B`@("`@
M("`@("`@("`@("`@("`@("`@($9E9&]R($$N($9E=&ES;W8@/&9A9D!S<V,N
M<G4^"B`@("`@("`@("`@("`@("`@("`@("`@($%L97AE>2!:86MH87)O=B`\
M86QE>$!B:W,N8GD^"E-L;W9A:R`@("`@("`@("`@("`@("`@($QE;R!-<F%F
M:V\@/&QE;T!O96PN<VL^"B`@("`@("`@("`@("`@("`@("`@("`@($EV86X@
M3F]R:7,@/&YO<FES0&)G<RYS:SX*4VQO=F5N:6%N("`@("`@("`@("`@("`@
M2G5R92!+<F%S;W9I8R`\:G5R96M`<F-C+6ER8RYS:3X*("`@("`@("`@("`@
M("`@("`@("`@("`@36%T:6,@1&]L87(@/&UA=&EC0&UE9&EU;2YS:3X*4W!A
M;FES:"`@("`@("`@("`@("`@("`@4F'Z;"!!;'9A<F5Z(%9E;F5G87,@/')A
M=D!T96-O;6%N+G5C;VPN;7@^"B`@("`@("`@("`@("`@("`@("`@("`@($UA
M;G5E;"!097)E>B!!>6%L82`\;7!E<F%Y84!A;&-A>F%B82YU;F5X+F5S/@I3
M=V5D:7-H("`@("`@("`@("`@("`@("!!;F1R96%S($1A:&SI;B`\86YD<F5A
M<T!D86AL96XN=W,^"B`@("`@("`@("`@("`@("`@("`@("`@($IO87%U:6T@
M2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/@I4=7)K:7-H("`@
M("`@("`@("`@("`@("!'96YC;R!9:6QM87H@/&=E;F-O>6EL;6%Z0'EA:&]O
M+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@27-T86YB=6P@5&5C:&YI
M8V%L(%5N:79E<G-I='D@250@1&5P87)T;65N=`H@("`@("`@("`@("`@("`@
M("`@("`@("`\:71U8FEM0&ET=2YE9'4N='(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(%-E<G9E="!'_&YE>2`\<V=U;F5Y0&UE='4N961U+G1R/@H@("`@
M("`@("`@("`@("`@("`@("`@("!!:&UE="#6>G3\<FL@/&]A:&UE=$!M971U
M+F5D=2YT<CX*56MR86EN:6%N("`@("`@("`@("`@("`@06YD<FEY($MO<'ES
M='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV:78N=6$^"CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H*"E1H96UE<PH]/3T]/3T*"CT]/3T]/3T]
M/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0I"87)B:64@("`@("`@("`@071I9B!':&%F9F%R(#QA9VAA9F9A<D!D
M979E;&]P97(N8V@^"D)R;W=N("`@("`@("`@("!-87)C;R!/8F%I9"`\;6%R
M8V]`;75W+F5D=3X*0V%M;W5F;&%G92`@("`@($%T:68@1VAA9F9A<B`\86=H
M869F87)`9&5V96QO<&5R+F-H/@I#:&5R<GD@("`@("`@("`@0VAR:7-T;W!H
M92!'=6EL;&]U>"`\<F]O=&EX0&)O;W1I>"YN970^"D=R965N("`@("`@("`@
M("!.86-E<B!,87)A9&II(#QL87)A9&II0'1U>&9A;6EL>2YO<F<^"D=R97D@
M("`@("`@("`@("!.86-E<B!,87)A9&II(#QL87)A9&II0'1U>&9A;6EL>2YO
M<F<^"DQA=F5N9&5R("`@("`@("!::6%U<B!286AM86X@/'II84!Q86QA8V]M
M+F-O;3X*3&EG:'0M0FQU92`@("`@($%T:68@1VAA9F9A<B`\86=H869F87)`
M9&5V96QO<&5R+F-H/@I-;WII;&QA("`@("`@("`@36EC:&%E;"!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*3W)A;F=E("`@("`@("`@(%)O
M;FYI92!'87)C:6$@/')O;FYI94!M:S(N;F5T/@I3:6UP;&5X("`@("`@("`@
M0V%R:6%D($EL;>!R82`\8V%R:6%D0&%D;G@N;F5T/@I3=6X@("`@("`@("`@
M("`@0VAR:7-T;W!H92!'=6EL;&]U>"`\<F]O=&EX0&)O;W1I>"YN970^"CT]
M/3T]/3T]/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H*"D-O;G1R:6)U=&EO;G,*/3T]/3T]/3T]/3T]/0H*2%1-
M3"!T;R!497AT($-O;G9E<G1E<CH@2F]N($%B97)N871H>2`\:F]N0&-H=6=G
M;G5T="YC;VT^"@H*26YA8W1I=F4@1&5V96QO<&5R<PH]/3T]/3T]/3T]/3T]
M/3T]/3T]"@HM($EV86X@12X@36]O<F4@24D@/')K<G5S='E`=&1Y8RYC;VT^
M"BT@36EK92!(87)D>2`\;6EK94!I='-P<F]J96-T<RYC;VT^"BT@2F]N(%!A
M<FES92`\:F]N0&-S:"YR:70N961U/@HM($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"BT@4FEC:"!,869F97)T>2`\<FEC:$!H;W)D92YO
M<F<^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]D;V-S+TA!0TM)3D<`````````````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V-S(R`#$P-3$U-#,Q,#4W`#`Q
M-C,T,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&5V96QO
M<&UE;G0@4F5S;W5R8V5S"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#8O,#(O,#$@,#DZ,C`Z,CD@
M)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C<N,3`N,2`D"CI!=71H
M;W(Z("`@("`@("!)=F%N($4N($UO;W)E($E)(#QR:W)U<W1Y0'1D>6,N8V]M
M/BP@36EK92!(87)D>0H@("`@("`@("`@("`@("`@/&UI:V5H0'-P87)K+F-O
M;3X*.D-O;G1A8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*+BX@
M8V]N=&5N=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I/
M;FQI;F4@<F5S;W5R8V5S(&9O<B!D979E;&]P:6YG('=I=&@@2&]R9&4@*&EN
M8VQU9&EN9R!(;W)D92!&<F%M97=O<FL@05!)"F1O8W5M96YT871I;VXI(&%R
M92!A=F%I;&%B;&4@870Z"@H@("!H='1P.B\O9&5V+FAO<F1E+F]R9R\@("`*
M"@I(86-K:6YG(&]N($AO<F1E(&9R;VT@0U93"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"DAO<F1E(&%N9"!I=',@;6]D=6QE<R!U<V4@0U93(&9O<B!S
M;W5R8V4@8V]N=')O;"X@($-64R!I<R!W96QL+61O8W5M96YT960L(&)U=`IT
M:&4@;6%N=6%L('!A9V4@87-S=6UE<R!Y;W4@86QR96%D>2!K;F]W(&AO=R!I
M="!W;W)K<RX@($%N(&5X8V5L;&5N="!G=6ED92!T;PIG971T:6YG('-T87)T
M960@=VET:"!#5E,@:7,@(D]P96X@4V]U<F-E($1E=F5L;W!M96YT('=I=&@@
M0U93(B!B>2!+87)L($9O9V5L+@I)="=S('!U8FQI<VAE9"!B>2!#;W)I;VQI
M<RP@86YD('1H92!T96-H;FEC86P@<&%R="!O9B!T:&4@8F]O:R!I<R!A=F%I
M;&%B;&4*9F]R(&9R964@;VX@=&AE(%=E8B!A=`H*("`@:'1T<#HO+V-V<V)O
M;VLN<F5D+6)E86XN8V]M+PH*5&AE('!A<&5R('9E<G-I;VX@:6YC;'5D97,@
M8VAA<'1E<G,@;VX@;W)G86YI>FEN9R!A;F0@;6%N86=I;F<@3W!E;B!3;W5R
M8V4*9&5V96QO<&UE;G0N("!9;W4@8V%N(&]B=&%I;B!A($-64R!C;&EE;G0@
M9F]R('EO=7(@;W!E<F%T:6YG('-Y<W1E;2!A=`I#5E-(3TU%+"!A=`H*("`@
M:'1T<#HO+W=W=RYC=G-H;VUE+F]R9R]D;W=N;&]A9',N:'1M;`H*;V8@=&AE
M;2!M87D@8F4@9F]U;F0@870@:'1T<#HO+W=W=RYC>6-L:6,N8V]M("T@=&AE
M>2!S=7!P;W)T($-64R!C;VUM97)C:6%L;'DL"F5V96X@=&AO=6=H(&ET(&ES
M(&%N(&]P96X@<V]U<F-E('!R;V=R86TN"@I9;W4@=VEL;"!N965D(&$@0U93
M(&-L:65N="!T;R!D;R!A;GD@;V8@=&AE(&9O;&QO=VEN9R`H8VAE8VL@;W5T
M('1H92!#>6-L:6,*:&]M97!A9V4@:68@>6]U(&1O;B=T(&AA=F4@;VYE*2X*
M"D9O<B!T:&]S92!A;')E861Y(&9A;6EL:6%R('=I=&@@0U93+"!T:&4@86YO
M;GEM;W5S($-64U)/3U0@:7,Z.@H*("`@.G!S97)V97(Z8W9S<F5A9$!A;F]N
M8W9S+FAO<F1E+F]R9SHO<F5P;W-I=&]R>0H*"D1O=VYL;V%D:6YG($AO<F1E
M(&UO9'5L97,@9G)O;2!#5E,*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*66]U('=I;&P@=V%N="!T;R!D;R!T:&ES(&EF('EO=2!W86YT
M(&)L965D:6YG(&5D9V4@8V]D92X*"C$N($=O('1O('1H92!D:7)E8W1O<GD@
M>6]U('=A;G0@=&\@9&]W;FQO860@=&AE(&-O9&4@=&\Z.@H*("`@("`@8V0@
M?B]W;W)K"@HR+B!3970@8&!#5E-23T]48&`@=&\@=&AE(&QO8V%T:6]N(&]F
M('1H92!#5E,@<F5P;W-I=&]R>2X@(%EO=2!C;W5L9"!A;'-O('!A<W,*("`@
M8W9S('1H92!N86UE(&]F('1H92!#5E,@<F]O="!W:71H('1H92!@8"UD8&`@
M;W!T:6]N+B`@0F4@<W5R92!T;R!N;W1E('1H90H@("!C;VQO;B!@8#I@8"!I
M;B!F<F]N="!O9B!@8'!S97)V97)@8"X*"B`@("AI;B!S:"P@:W-H+"!B87-H
M+"!Z<V@I.CH*"B`@("`@($-64U)/3U0].G!S97)V97(Z8W9S<F5A9$!A;F]N
M8W9S+FAO<F1E+F]R9SHO<F5P;W-I=&]R>0H@("`@("!E>'!O<G0@0U934D]/
M5`H*("`@*&EN(&-S:"P@=&-S:"DZ.@H*("`@("`@<V5T96YV($-64U)/3U0@
M.G!S97)V97(Z8W9S<F5A9$!A;F]N8W9S+FAO<F1E+F]R9SHO<F5P;W-I=&]R
M>0H*,RX@3&]G:6X@=&\@=&AE(&%N;VYY;6]U<R!#5E,@<F5P;W-I=&]R>2X@
M(%=H96X@<')O;7!T960@9F]R(&$@<&%S<W=O<F0L(&5N=&5R"B`@(&!@:&]R
M9&5@8#HZ"B`@("`@(`H@("`@("!C=G,@;&]G:6X*"C0N($-H96-K(&]U="!T
M:&4@;6]D=6QE('EO=2!W86YT('1O(&1O=VYL;V%D(&9R;VT@=&AE(')E<&]S
M:71O<GDN("!297!L86-E"B`@(&!@34]$54Q%8&`@=VET:"!H;W)D92P@:6UP
M+"!T=7)B82P@=')O;&PL(&%N9"!S;R!F;W)T:"X@("A4:&4@8&`M>C-@8"!T
M96QL<PH@("!C=G,@=&\@8V]M<')E<W,@=&AE(&1A=&$@:70@<V5N9',@;W9E
M<B!T:&4@;F5T=V]R:RP@=6YC;VUP<F5S<VEN9R!I="!W:&5N"B`@('EO=2`_
M/S\_.CH*"B`@("`@(&-V<R`M>C,@8V\@34]$54Q%"@H@("!)9B!Y;W4@=V%N
M="!T;R!C:&5C:R!O=70@82!P87)T:6-U;&%R(&)R86YC:"!O9B!A(&UO9'5L
M92`H9F]R(&5X86UP;&4L('1H90H@("!@8%)%3$5.1U\S8&`@8G)A;F-H(&]F
M($E-4"DL(&EN8VQU9&4@=&AE(&)R86YC:"!T86<@;&EK92!S;RP@<F5P;&%C
M:6YG"B`@(&!@5$%'8&`@=VET:"!T:&4@;F%M92!O9B!T:&4@8G)A;F-H.CH*
M"B`@("`@(&-V<R`M>C,@8V\@+7(@5$%'($U/1%5,10H*-2X@07,@>6]U('=O
M<FL@=VET:"!T:&4@<V]F='=A<F4L('EO=2!C86X@<&5R:6]D:6-A;&QY('5P
M9&%T92!Y;W5R('1R964@=&\*("`@;6%T8V@@=&AE(&UA<W1E<B!T<F5E(&%T
M(&%N>2!T:6UE+"!F<F]M('1H92!T;W`@9&ER96-T;W)Y(&]F('1H90H@("!M
M;V1U;&4N("!5<VEN9R!@8&AO<F1E8&`@87,@86X@97AA;7!L92!M;V1U;&4Z
M.@H*("`@("`@8V0@?B]W;W)K+VAO<F1E"B`@("`@(&-V<R`M>C,@=7!D871E
M"@H*3V)T86EN:6YG(&$@0U93(&%C8V]U;G0*+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*"DEF('EO=2=R92!G;VEN9R!T;R!B92!A(')E9W5L87(@8V]N=')I
M8G5T;W(@=&\@2&]R9&4L('1H96X@>6]U(&-A;B!R97%U97-T(&$*0U93(&%C
M8V]U;G0@:6X@;W)D97(@=&\@8V]M;6ET('EO=7(@8VAA;F=E<R!T;R!T:&4@
M<F5P;W-I=&]R>2!Y;W5R<V5L9BX@("A)9@IY;W4G<F4@;VYL>2!G;VEN9R!T
M;R!B92!C;VYT<FEB=71I;F<@;VYC92!I;B!A('=H:6QE+"!T:&5R92!T<G5L
M>2!I<R!N;R!N965D"F9O<B!Y;W4@=&\@:&%V92!O;F4L(&%S('!O<W1I;F<@
M>6]U<B!C:&%N9V5S('1O('1H92!A<'!L:6-A=&EO;B=S(&UA:6QI;F<@;&ES
M=`IW:6QL('-U9F9I8V4@=&\@9V5T('EO=7(@8VAA;F=E<R!R979I97=E9"!A
M;F0@:6YC;'5D960N*0H*268@>6]U(&1O(&=E="!C;VUM:70@86-C97-S('1O
M('1H92!#5E,@=')E92P@>6]U('=I;&P@:&%V92!T:&4@86)I;&ET>2!T;R!M
M97-S"G-O;64@=&AI;F=S('5P+B`@3F]T(&9O<B!G;V]D+"!M:6YD('EO=2P@
M87,@0U93(&%L;&]W<R!U<&1A=&5S('1O(&)E(&)A8VME9`IO9F8L(&)U="!Y
M;W4@<W1I;&P@;F5E9"!T;R!R96UE;6)E<B!W:&%T('EO=2=R92!D;VEN9R!A
M;F0@8F4@8V%R969U;"!W:&%T('EO=0IC;VUM:70@86YD('=H96X@>6]U(&-O
M;6UI="!I="X@($)E8V%U<V4@;V8@=&AI<RP@=V4@<')E9F5R('1H870@>6]U
M('-U8FUI=`IY;W5R('=O<FL@=&\@=&AE(&UA:6QI;F<@;&ES="!F;W(@82!W
M:&EL92!S;R!W92!C86X@=&5L;"!Y;W4@:VYO=R!W:&%T('EO=2=R90ID;VEN
M9RX*"DEF('EO=2=R92!N;W0@82!C;VUM:71T97(L('1H92!B97-T('=A>2!T
M;R!S=6)M:70@82!P871C:"!I<R!T;R!S96YD(&ET(&5I=&AE<@IT;R!T:&4@
M87!P;&EC871I;VXG<R!M86EL:6YG(&QI<W0@;W(@=&\@9&5V0&QI<W1S+FAO
M<F1E+F]R9RX@($9O<B!M;W)E"FEN9F]R;6%T:6]N(&]N($AO<F1E(&UA:6QI
M;F<@;&ES=',L('-E90H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O;6%I;"\*
M"@I#;VUM:71T:6YG(&-H86YG97,@=&\@0U93"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*"D]N8V4@>6]U(&AA=F4@82!#5E,@86-C;W5N="P@>6]U('=I
M;&P@;F5E9"!T;R!L;V<@:6YT;R!T:&4@0U93('-E<G9E<B!S;R!I=`IK;F]W
M<R!W:&\@>6]U(&%R92!A;F0@8V%N(&=R86YT('EO=2!T:&4@87!P<F]P<FEA
M=&4@<FEG:'1S('1O('=O<FL@;VX@=&AE"G-O=7)C97,N"@I4:&4@8&!#5E-2
M3T]48&`@:7,@9&EF9F5R96YT(&9O<B!C;VUM:71T97)S.R!I;G-T96%D(&]F
M('1H92!R97!O<VET;W)Y(&QI<W1E9`IA8F]V92P@<V5T(&!@0U934D]/5&!@
M('1O.CH*"B`@(#IE>'0Z55-%4DY!345`8W9S+FAO<F1E+F]R9SHO<F5P;W-I
M=&]R>0H*<F5P;&%C:6YG(&!@55-%4DY!345@8"!W:71H('EO=7(@8W9S('5S
M97)N86UE+@H*5&AE(&-O;6UI='1E<G,G(')E<&]S:71O<GD@9&]E<R!N;W0@
M=7-E('!S97)V97(N("!9;W4@=VEL;"!N965D('1O(&AA=F4@<W-H"FEN<W1A
M;&QE9"!O;B!Y;W5R('-Y<W1E;2P@86YD(&AA=F4@87)R86YG960@=VET:"!O
M;F4@;V8@=&AE(&-O<F4@9&5V96QO<&5R<R!T;PIP=70@>6]U<B!34T@@:V5Y
M(&]N('1H92!S>7-T96TN("!)9B!Y;W4@:&%V92!N;W0@9&]N92!T:&ES+"!T
M86QK('1O(&]N92!O9B!T:&4*8V]R92!D979E;&]P97)S+@H*5&\@9V5T(&-V
M<R!T;R!U<V4@<W-H+"!Y;W4@=VEL;"!N965D('1O('-E="!T:&4@96YV:7)O
M;FUE;G0@=F%R:6%B;&4*8&!#5E-?4E-(8&`@=&\@8&!S<VA@8"!I;B!Y;W5R
M('-H96QL+@H*66]U(&1O(&YO="!N965D('1O(&1O(&!@8W9S(&QO9VEN8&`[
M('EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!T:&4@<&%S<W!H<F%S90IF;W(@
M>6]U<B!34T@@:V5Y('=H96YE=F5R('EO=2!A8V-E<W,@=&AE(')E<&]S:71O
M<GDN"@I9;W4@;6%Y(&%L<V\@=VES:"!T;R!S970@=&AE(&5N=FER;VYM96YT
M('9A<FEA8FQE(&!@141)5$]28&`@=&\@<&]I;G0@=&\@>6]U<@IF879O<FET
M92!T97AT(&5D:71O<BX@5&AI<R!W87D@=VAE;B!Y;W4@8V]M;6ET('-O9G1W
M87)E(&-H86YG97,@86YD(&ET(&%S:W,*>6]U('1O(&5N=&5R(&$@8VAA;F=E
M(&1E<V-R:7!T:6]N+"!Y;W4@8V%N(&1O('-O(&EN('EO=7(@9F%V;W)I=&4@
M961I=&]R+@H*5&AE;BP@9F]R('=O<FL@;VX@9&5V96QO<&UE;G1A;"P@8FQE
M961I;F<M961G92!V97)S:6]N<SH*"C$I($-H96-K(&]U="!T:&4@8V]D92!B
M>2!T>7!I;F<@8&!C=G,@8V\@34]$54Q%8&`*,BD@5V]R:R!O;B!T:&4@8V]D
M92`\:&%C:RP@:&%C:RP@:&%C:SX*,RD@0V]M;6ET(&%N>2!C:&%N9V5S('=I
M=&@@8&!C=G,@8V]M;6ET($9)3$5.04U%4V!@(&EN('1H92!D:7)E8W1O<GD@
M=&AE(&9I;&5S"B`@(&%R92!I;BX*"E-O;65T:6UE<RP@;W1H97)S('=I;&P@
M;6%K92!C:&%N9V5S(&%N9"!Y;W4@=VEL;"!N965D('1O('5P9&%T92!Y;W5R
M('1R964@<V\*=&AE(&-H86YG97,@<VAO=R!U<"!I;B!Y;W5R(&QO8V%L('-O
M=7)C97,N("!9;W4@9&\@=&AI<R!W:71H('1H92!@8&-V<PIU<&1A=&5@8"!C
M;VUM86YD(&EN('1H92!H;W)D92!D:7)E8W1O<GDN("!0;&5A<V4@8F4@<W5R
M92!T;R!U<&1A=&4@>6]U<B!T<F5E"G)E9W5L87)L>3L@;65R9VEN9R!C:&%N
M9V5S(&ES(&-O;G-I9&5R86)L>2!M;W)E('=O<FL@=&AA;B!R=6YN:6YG(&!@
M8W9S"G5P9&%T96!@+@H*5&\@=V]R:R!W:71H(&%N>2!T86=G960@8G)A;F-H
M("AT;R!P871C:"!A('-T86)L92!R96QE87-E+"!F;W(@:6YS=&%N8V4I.@H*
M,2D@0VAE8VL@;W5T('1H92!C;V1E('=I=&@@8&!C=G,@8V\@+7(@5$%'($U/
M1%5,16!@"C(I(%=O<FL@;VX@=&AE(&-O9&4@/&AA8VLL(&AA8VLL(&AA8VL^
M"C,I($-O;6UI="!A;GD@8VAA;F=E<R!W:71H(&!@8W9S(&-O;6UI="!&24Q%
M3D%-15-@8"!I;B!T:&4@9&ER96-T;W)Y('1H92!F:6QE<PH@("!A<F4@:6XN
M"@I)9B!S;VUE8F]D>2!E;'-E(&%L<V\@;6%K97,@8VAA;F=E<R!T;R!T:&4@
M;&%B96QE9"!V97)S:6]N+"!Y;W4@8V%N(&=E="!T:&5M"FEN('EO=7(@;&]C
M86P@<V]U<F-E('1R964@=VET:"!T:&4@8&!C=G,@=7!D871E8&`@8V]M;6%N
M9"!I<W-U960@:6X@=&AE(&UO9'5L90ID:7)E8W1O<GDN"@I)9B!Y;W4@87)E
M(&1O;F4@=V]R:VEN9R!W:71H('1H92!L86)E;&5D('-O=7)C92!B<F%N8V@L
M(&%N9"!W;W5L9"!L:6ME('1O(&UO=F4*8F%C:R!I;G1O('1H92!B;&5E9&EN
M9RUE9&=E(&1E=F5L;W!M96YT('-O=7)C92!T<F5E+"!Y;W4@8V%N(&ES<W5E
M('1H92!C;VUM86YD"F!@8W9S('5P9&%T92`M06!@('1O('5P9&%T92!E=F5R
M>71H:6YG('1O('1H92!C=7)R96YT(&!@2$5!1&!@('9E<G-I;VXN"@HH5V4@
M=7-E9"!T;R!D;V-U;65N="!H;W<@=&\@;65R9V4@8V]D92!F<F]M($A%040@
M:6YT;R!A(&QA8F5L960@8G)A;F-H(&AE<F4L"F)U="!S:6YC92!I="!W87,@
M:&5A=FEL>2!P97!P97)E9"!W:71H(")T86QK('1O(&-O<F4@9&5V96QO<&5R
M<R!F:7)S="(L(&ET)W,*8F5E;B!E;&ED960@=&\@<')E=F5N="!E<G)O<G,@
M;V8@97AP97)I;65N=&%T:6]N+B`@268@>6]U('1H:6YK('EO=2!N965D('1O
M(&1O"G1H870L('EO=2!H879E('1O('1A;&L@=&\@8V]R92!D979E;&]P97)S
M(&%N>6AO=R`M+2!T:&5Y)VQL(&5X<&QA:6X@:&]W+BD*"@I/=&AE<B!#5E,@
M3F]T97,*+2TM+2TM+2TM+2TM+2TM"@I)9B!Y;W4@9&\@96YD('5P(&=E='1I
M;F<@82!#5E,@86-C;W5N="P@:&5R92!A<F4@<V]M92!T:7!S('1O(&AE;'`@
M:V5E<"!T:&EN9W,*9V]I;F<@<VUO;W1H;'DZ"@HQ+B!3=6)S8W)I8F4@=&\@
M=&AE(&-V<T!L:7-T<RYH;W)D92YO<F<@86YD(&1E=D!L:7-T<RYH;W)D92YO
M<F<@;6%I;&EN9R!L:7-T<RX*"C(N($)E('-U<F4@=&\@;6]D:69Y('1H92!F
M:6QE(&!@9&]C<R]#2$%.1T538&`@=&\@<F5F;&5C="!T:&4@8VAA;F=E<R!T
M;R!T:&4*("`@8V]D92!Y;W4@87)E(&-O;6UI='1I;F<N"@HS+B!)9B!Y;W4G
M<F4@<&QA;FYI;F<@;VX@9&]I;F<@86YY=&AI;F<@;6%J;W(L('!L96%S92!L
M970@<&5O<&QE(&MN;W<@:6X*("`@861V86YC92!O;B!T:&4@9&5V0"!O<B!A
M<'!L:6-A=&EO;B!M86EL:6YG(&QI<W1S(&%S(&%P<')O<')I871E+@H*("`@
M1&5V96QO<&5R<R!N965D('1O(&-O;6UU;FEC871E(&5X=&5N<VEV96QY(&EN
M(&]R9&5R('1O(&UA:V4@<W5R92!E=F5R>6]N90H@("!K;F]W<R!W:&%T)W,@
M9V]I;F<@;VXN("!4:&ES(&ES(&5X=')E;65L>2!I;7!O<G1A;G0@=VAE;B!Y
M;W4@=V]R:R!O;B!K97D*("`@8V]M<&]N96YT<RX*"C0N(%5S92!T:&4@0G5G
M(%1R86-K:6YG(%-Y<W1E;2!O;B!H='1P.B\O8G5G<RYH;W)D92YO<F<N("!!
M;&P@;F5W('-U8FUI<W-I;VYS"B`@(&%R92!B96EN9R!C8R=D('1O('1H92!B
M=6=S0&QI<W1S+FAO<F1E+F]R9R!M86EL:6YG(&QI<W0@<V\@=&AA="!I9B!W
M92!A<F5N)W0*("`@<&%Y:6YG(&%T=&5N=&EO;BP@=V4G;&P@870@;&5A<W0@
M9V5T(&UA:6P@86)O=70@:70N("!5<VEN9R!T:&4@0G5G<PH@("!D871A8F%S
M92!H96QP<R!U<R!K965P('1R86-K(&]F(&ES<W5E<R!W92!A<F4@:&%V:6YG
M(&%N9"!W:&5R92!W92!S=&%N9`H@("!W:71H('1H92!P<F]D=6-T+@H*-2X@
M4F5M96UB97(@=&\@861V86YC92!T:&4@;&EB<F%R>2!V97)S:6]N('=H96YE
M=F5R(&%N>71H:6YG(&UA:F]R(&ES(&-H86YG960N"@``````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+V1O8W,O24Y35$%,3```````````````````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C4R,S(`,3`U,34T,S$P-3<`
M,#$V-#`S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@26YS
M=&%L;&EN9R!T:&4@2&]R9&4@,RXQ($9R86UE=V]R:PH]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T
M93H@,C`P-B\P."\Q-2`P.3HS,#HT,R`D"CI2979I<VEO;CH@("`@("`D4F5V
M:7-I;VXZ(#$N.3`N-BXQ-B`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L:7-T
M<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO
M;BUN=6UB97)I;F<Z.@H*5&AI<R!D;V-U;65N="!C;VYT86EN<R!I;G-T<G5C
M=&EO;G,@9F]R(&EN<W1A;&QI;F<@=&AE($AO<F1E($9R86UE=V]R:R!O;B!Y
M;W5R"G-Y<W1E;2X*"E1H92!(;W)D92!&<F%M97=O<FLL(&)Y(&ET<V5L9BP@
M9&]E<R!N;W0@<')O=FED92!A;GD@<VEG;FEF:6-A;G0@96YD('5S97(*9G5N
M8W1I;VYA;&ET>3L@:70@<')O=FED97,@82!B87-E(&9O<B!O=&AE<B!A<'!L
M:6-A=&EO;G,@86YD('1O;VQS(&9O<@ID979E;&]P97)S+B!7:&5N('EO=2!H
M879E(&EN<W1A;&QE9"!(;W)D92!A<R!D97-C<FEB960@8F5L;W<L('EO=2!W
M:6QL"G!R;V)A8FQY('=A;G0@=&\@:6YS=&%L;"!S;VUE(&]F('1H92!A=F%I
M;&%B;&4@2&]R9&4@87!P;&EC871I;VYS+"!S=6-H(&%S"DE-4%\@*&$@=V5B
M;6%I;"!C;&EE;G0I+"!O<B!+<F]N;VQI=&A?("AA(&-A;&5N9&%R*2X@5&AE
M<F4@:7,@82!L:7-T(&]F($AO<F1E"F%P<&QI8V%T:6]N<R!A;F0@<')O:F5C
M=',@870@:'1T<#HO+W=W=RYH;W)D92YO<F<O<')O:F5C=',N<&AP+@H*268@
M>6]U(&%R92!I;G1E<F5S=&5D(&EN(&1E=F5L;W!I;F<@87!P;&EC871I;VYS
M(&9O<B!(;W)D92P@=&AE<F4@:7,@9&5V96QO<&5R"F1O8W5M96YT871I;VX@
M86YD(')E9F5R96YC97,@879A:6QA8FQE(&%T(&AT='`Z+R]D978N:&]R9&4N
M;W)G+RP@86YD('-O;64*='5T;W)I86QS(&%N9"!P87!E<G,@;VX@2&]R9&4@
M879A:6QA8FQE(&%T(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W!A<&5R<R\N"@I&
M;W(@:6YF;W)M871I;VX@;VX@=&AE(&-A<&%B:6QI=&EE<R!A;F0@9F5A='5R
M97,@;V8@2&]R9&4L('-E92!T:&4@9FEL90I214%$345?(&EN('1H92!T;W`M
M;&5V96P@9&ER96-T;W)Y(&]F('1H92!(;W)D92!D:7-T<FEB=71I;VXN"@HN
M+B!?24U0.B!H='1P.B\O=W=W+FAO<F1E+F]R9R]I;7`O"BXN(%]+<F]N;VQI
M=&@Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VMR;VYO;&ET:"\*"@I/8G1A:6YI
M;F<@2&]R9&4*/3T]/3T]/3T]/3T]/3T]"@I4:&4@2&]R9&4@1G)A;65W;W)K
M(&-A;B!B92!O8G1A:6YE9"!F<F]M('1H92!(;W)D92!W96)S:71E(&%N9"!&
M5%`@<V5R=F5R+"!A=`H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R9&4O
M"@H@("!F='`Z+R]F='`N:&]R9&4N;W)G+W!U8B]H;W)D92\*"D]R+"!B971T
M97(@>65T+"!U<V4@82!M:7)R;W(@=&AA="!I<R!C;&]S97(@=&\@>6]U+B`@
M5&AE(&UI<G)O<B!L:7-T(&-A;B!B90IF;W5N9"!A=#H*"B`@(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+VUI<G)O<G,N<&AP"@I4:&4@1E10(&1I<F5C=&]R>2!C
M;VYT86EN<R!T:&4@2&]R9&4@4$A0(&9I;&5S('=H:6-H(&-A;B!B92!U;G!A
M8VME9"!U<VEN9PI@8'1A<F!@(&%N9"!@8&=U;GII<&!@("AS964@8$EN<W1A
M;&QI;F<@2&]R9&5@7RP@8F5L;W<I+@H*0FQE961I;F<M961G92!D979E;&]P
M;65N="!V97)S:6]N<R!O9B!(;W)D92!A;F0@:71S(&%P<&QI8V%T:6]N<R!A
M<F4@879A:6QA8FQE"G9I82!#5E,[('-E92!T:&4@9FEL92!@9&]C<R](04-+
M24Y'8%\L(&]R('9I<VET('1H92!W96)S:71E"FAT='`Z+R]W=W<N:&]R9&4N
M;W)G+W-O=7)C92\L(&9O<B!I;F9O<FUA=&EO;B!O;B!A8V-E<W-I;F<@=&AE
M($AO<F1E($-64PIR97!O<VET;W)Y+@H*66]U('=I;&P@<')O8F%B;'D@86QS
M;R!W86YT(&]N92!O<B!M;W)E($AO<F1E(&%P<&QI8V%T:6]N<RP@<VEN8V4@
M2&]R9&4*9&]E<VXG="!D;R!M=6-H(&)Y(&ET<V5L9CL@82!L:7-T(&]F(&%V
M86EL86)L92!A<'!L:6-A=&EO;G,L('=I=&@@;&EN:W,@=&\*9&5S8W)I<'1I
M;VYS(&%N9"!D;W=N;&]A9',L(&-A;B!B92!F;W5N9"!A=`H*("`@:'1T<#HO
M+W=W=RYH;W)D92YO<F<O<')O:F5C=',N<&AP"@I7:&EL92!P<F5V:6]U<R!V
M97)S:6]N<R!O9B!(;W)D92!W97)E(&YU;6)E<F5D('1O(&-O<G)E<W!O;F0@
M=VET:"!A('!A<G1I8W5L87(*=F5R<VEO;B!O9B!T:&4@24U0('=E8FUA:6P@
M87!P;&EC871I;VXL('1H870@:7,@;F\@;&]N9V5R('1R=64@87,@;V8@2&]R
M9&4*=F5R<VEO;B`R+C`N(%1H92!C=7)R96YT('9E<G-I;VX@;V8@2&]R9&4@
M=VEL;"!W;W)K('=I=&@@=&AE(&-U<G)E;G0@=F5R<VEO;@IO9B!(;W)D92!A
M<'!L:6-A=&EO;G,N($9O<B!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('=H:6-H
M('9E<G-I;VYS(&%R90IC;VUP871I8FQE('-E92!H='1P.B\O=W=W+FAO<F1E
M+F]R9R]S;W5R8V4O=F5R<VEO;G,N<&AP+@H*"E%U:6-K($EN<W1A;&P*/3T]
M/3T]/3T]/3T]/0H*5&AE<V4@87)E('9E<GD@=&5R<V4@:6YS=')U8W1I;VYS
M(&AO=R!T;R!I;G-T86QL($AO<F1E(&%N9"!I=',@<')E<F5Q=6ES:71E<PIO
M;B!A($Q!35`@<WET96TN("!4:&5Y(&%R92!A9&1R97-S960@=&\@97AP97)I
M96YC960@861M:6YI<W1R871O<G,@=VAO(&MN;W<*97AA8W1L>2!W:&%T('1H
M97D@87)E(&1O:6YG+B`@1F]R(&UO<F4@9&5T86EL960@:6YS=')U8W1I;VYS
M+"!S=&%R="!R96%D:6YG"F)E;&]W(&%T(%!R97)E<75I<VET97-?+@H*,2X@
M0V]M<&EL:6YG(%!(4"!F;W(@07!A8VAE.CH*"B`@("`@8V0@<&AP+7@N>"YX
M+PH@("`@("XO8V]N9FEG=7)E("TM=VET:"UA<'AS/2]U<W(O<V)I;B]A<'AS
M(%P*("`@("`@("`@("`@("`@("`M+7=I=&@M9V5T=&5X="`M+7=I=&@M9&]M
M("TM=VET:"UM8W)Y<'0@7`H@("`@("`@("`@("`@("`@("TM=VET:"UI8V]N
M=B`M+65N86)L92UM8G-T<FEN9SUA;&P@+2UE;F%B;&4M;6)R96=E>"!<"B`@
M("`@("`@("`@("`@("`@+2UW:71H+6=D("TM=VET:"UP;F<M9&ER/2]U<W(@
M+2UW:71H+6IP96<M9&ER/2]U<W(@7`H@("`@("`@("`@("`@("`@("TM=VET
M:"UM:6UE+6UA9VEC/2]U<V5R+W-H87)E+VUI<V,O;6%G:6,N;6EM92!<"B`@
M("`@("`@("`@("`@("`@6RTM=VET:"UM>7-Q;'PM+7=I=&@M<&=S<6Q\+2UW
M:71H+6]C:3A\+2UW:71H+6QD87!="B`@("`@;6%K90H@("`@(&UA:V4@:6YS
M=&%L;`H*,BX@4F5S=&%R="!!<&%C:&4N"@HS+B!);G-T86QL(%!%05(@<&%C
M:V%G97,Z.@H*("`@("!P96%R(&EN<W1A;&P@+6\@3&]G($UA:6P@36%I;%]-
M:6UE($1"($1A=&4@1FEL90H@("`@('!E87(@+60@<')E9F5R<F5D7W-T871E
M/6)E=&$@:6YS=&%L;"`M82!397)V:6-E<U]796%T:&5R"@HT+B!%>'1R86-T
M('1A<F)A;&PZ.@H*("`@("!C9"`O=7-R+VQO8V%L+V%P86-H92]H=&1O8W,*
M("`@("!T87(@>GAV9B`O<&%T:"]T;R]H;W)D92UX+GDN>BYT87(N9WH*("`@
M("!M=B!H;W)D92UX+GDN>B!H;W)D90H*-2X@0V]N9FEG=7)E($AO<F1E.CH*
M"B`@("`@8V0@8V]N9FEG+PH@("`@(&9O<B!F(&EN("HN9&ES=#L@9&\@8W`@
M)&8@8&)A<V5N86UE("1F("YD:7-T8#L@9&]N90H*-BX@0W)E871E(&1A=&%B
M87-E('1A8FQE<SHZ"@H@("`@(&-D("XN+W-C<FEP=',O<W%L"B`@("`@=FD@
M8W)E871E+FUY<W%L+G-Q;`H@("`@(&UY<W%L("UU(')O;W0@+7`@/"!C<F5A
M=&4N;7ES<6PN<W%L"@HW+B!497-T($AO<F1E.CH*"B`@("`@:'1T<#HO+WEO
M=7(M<V5R=F5R+VAO<F1E+W1E<W0N<&AP"@HX+B!&:6YI<V@@8V]N9FEG=7)A
M=&EO;CHZ"@H@("`@(&AT='`Z+R]Y;W5R+7-E<G9E<B]H;W)D92\*"B`@($=O
M('1O($%D;6EN<W1R871I;VX@/3X@4V5T=7`@/3X@2&]R9&4*"@I0<F5R97%U
M:7-I=&5S"CT]/3T]/3T]/3T]/3T*"E1H92!F;VQL;W=I;F<@<')E<F5Q=6ES
M:71E<R!A<F4@*BI215%525)%1"HJ(&9O<B!(;W)D92!T;R!F=6YC=&EO;B!P
M<F]P97)L>2X*"C$N($$@=V5B<V5R=F5R('1H870@<W5P<&]R=',@4$A0+@H*
M("`@2&]R9&4@86YD(&ET<R!A<'!L:6-A=&EO;G,@87)E(&1E=F5L;W!E9"!U
M;F1E<B!T:&4@07!A8VAE('=E8G-E<G9E<BP@=VAI8V@*("`@=V4@<F5C;VUM
M96YD+B!!<&%C:&4@:7,@879A:6QA8FQE(&9R;VT*"B`@("`@(&AT='`Z+R]H
M='1P9"YA<&%C:&4N;W)G+PH*("`@2&]R9&4@:&%S(&%L<V\@8F5E;B!R97!O
M<G1E9&QY('5S960@<W5C8V5S<V9U;&QY('5N9&5R($UI8W)O<V]F="!)25,L
M(&%M;VYG"B`@(&]T:&5R<RX*"C(N(%!(4"`T+C,N,"!O<B!A8F]V92X*"B`@
M(%!(4"!I<R!T:&4@:6YT97)P<F5T960@;&%N9W5A9V4@:6X@=VAI8V@@2&]R
M9&4@:7,@=W)I='1E;BX*("`@66]U(&-A;B!O8G1A:6X@4$A0(&%T"@H@("`@
M("!H='1P.B\O=W=W+G!H<"YN970O"@H@("!&;VQL;W<@=&AE(&EN<W1R=6-T
M:6]N<R!I;B!T:&4@4$A0('!A8VMA9V4@=&\@8G5I;&0@4$A0(&9O<B!Y;W5R
M('-Y<W1E;2X@268*("`@>6]U('5S92!!<&%C:&4L(&)E('-U<F4@=&\@8G5I
M;&0@4$A0(&%S(&$@;&EB<F%R>2!W:71H(&]N92!O9B!T:&4@9F]L;&]W:6YG
M"B`@(&]P=&EO;G,Z.@H*("`@("`@("TM=VET:"UA<&%C:&4*("`@("`@("TM
M=VET:"UA<'AS"B`@("`@("`M+7=I=&@M87!X<S(*"B`@(&]P=&EO;G,@=&\@
M8&`N+V-O;F9I9W5R96!@+"!A;F0@;F]T(&%S(&$@<W1A;F1A;&]N92!E>&5C
M=71A8FQE+@H*("`@5&AE(&9O;&QO=VEN9R!02%`@;W!T:6]N<R!A<F4@*BI2
M15%525)%1"HJ(&)Y($AO<F1E("AL:7-T960@=VET:"!T:&5I<B!O=VX*("`@
M<')E<F5Q=6ES:71E<R!A;F0@8V]N9FEG=7)E(&]P=&EO;G,I+B!);B!M86YY
M(&-A<V5S+"!T:&4@<F5Q=6ER960@;&EB<F%R:65S"B`@(&%N9"!T;V]L<R!C
M86X@8F4@;V)T86EN960@87,@<&%C:V%G97,@9G)O;2!Y;W5R(&]P97)A=&EN
M9R!S>7-T96T@=F5N9&]R+@H*("`@82X@1V5T=&5X="!S=7!P;W)T+B!@8"TM
M=VET:"UG971T97AT8&`*"B`@("`@($=E='1E>'0@:7,@=&AE($=.52!4<F%N
M<VQA=&EO;B!0<F]J96-T)W,@;&]C86QI>F%T:6]N(&QI8G)A<GDN"B`@("`@
M($AO<F1E('5S97,@9V5T=&5X="!T;R!P<F]V:61E(&QO8V%L('1R86YS;&%T
M:6]N<R!O9B!T97AT(&1I<W!L87EE9"!B>0H@("`@("!A<'!L:6-A=&EO;G,N
M($EN9F]R;6%T:6]N(&]N(&]B=&%I;FEN9R!T:&4@9V5T=&5X="!P86-K86=E
M(&ES(&%V86EL86)L90H@("`@("!A=`H*("`@("`@("`@:'1T<#HO+W=W=RYG
M;G4N;W)G+W-O9G1W87)E+V=E='1E>'0O9V5T=&5X="YH=&UL"@H@("`@("!3
M964@86QS;R!N;W1E(&)E;&]W(&]N(&-O;F9I9W5R:6YG(%1R86YS;&%T:6]N
M<U\N"@H@("!B+B!834P@86YD($1/35A-3"!S=7!P;W)T+B!@8"TM=VET:"UD
M;VU@8`H*("`@("`@2&]R9&4G<R!H96QP(&5N9VEN92!A;F0@8V]M<&]N96YT
M('-E='5P(')E<75I<F4@6$U,('-U<'!O<G0N(%=H:6QE('-O;64*("`@("`@
M=V5B<V5R=F5R<R`H:6YC;'5D:6YG(')E8V5N="!!<&%C:&4@=F5R<VEO;G,I
M(&AA=F4@6$U,(&QI8G)A<FEE<PH@("`@("!B=6EL="UI;BP@;W1H97)S('=I
M;&P@<F5Q=6ER92!T:&4@97AP870@6$U,('!A<G-E<B!L:6)R87)I97,L(&%V
M86EL86)L90H@("`@("!F<F]M"@H@("`@("`@(&AT='`Z+R]E>'!A="YS;W5R
M8V5F;W)G92YN970O"@H@("`@("`N+B!);7!O<G1A;G0Z.B!9;W4@;75S="!H
M879E("HJ8F]T:"HJ(%A-3"!L:6)R87)I97,@:6YS=&%L;&5D(&9O<B!(;W)D
M90H@("`@("`@("`@("`@("`@("`@("!T;R!W;W)K('!R;W!E<FQY(0H*("`@
M("`@3VQD97(@=F5R<VEO;G,@;V8@4$A0(&%L<V\@<F5Q=6ER92!@8"TM=VET
M:"UX;6Q@8"!T;R!E;F%B;&4@=&AE"B`@("`@(%-!6"!834P@9G5N8W1I;VYS
M+B!7:71H(')E8V5N="!V97)S:6]N<R!O9B!02%`L('1H:7,@:7,@96YA8FQE
M9`H@("`@("!B>2!D969A=6QT+@H*("`@5&AE(&9O;&QO=VEN9R!02%`@;W!T
M:6]N<R!A<F4@*BI214-/34U%3D1%1"HJ('1O(&5N86)L92!A9'9A;F-E9"!F
M96%T=7)E<R!I;@H@("!(;W)D93H*"B`@(&$N($$@<')E9F5R96YC97,@8V]N
M=&%I;F5R+@H*("`@("`@2&]R9&4@87!P;&EC871I;VYS(&-A;B!S=&]R92!U
M<V5R('!R969E<F5N8V5S(&EN(&%N(%-13"!D871A8F%S92P@86X*("`@("`@
M3$1!4"!D:7)E8W1O<GDL(&%N($E-4U`@<V5R=F5R+"!A($MO;&%B('-E<G9E
M<BP@;W(@:6X@4$A0('-E<W-I;VYS+@H*("`@("`@1F]R(%-13"!D871A8F%S
M92!P<F5F97)E;F-E<R!S=&]R86=E+"!(;W)D92!I<R!T:&]R;W5G:&QY('1E
M<W1E9"!O;@H@("`@("!->5-13"`H8&`M+7=I=&@M;7ES<6Q@8"D@86YD(%!O
M<W1G<F5344P@*&!@+2UW:71H+7!G<W%L8&`I(&%N9"!H87,@8F5E;@H@("`@
M("!R97!O<G1E9"!T;R!W;W)K('=I=&@@3W)A8VQE("A@8"TM=VET:"UO8VDX
M8&`I(&%N9"!344P@4V5R=F5R"B`@("`@("A@8"TM=VET:"UM<W-Q;&!@*2X@
M($ET(&UA>2!A;'-O('=O<FL@=VET:"!A;GD@;W1H97(@9&%T86)A<V4@<W5P
M<&]R=&5D"B`@("`@(&)Y(%!%05(L(&)U="!T:&5Y(&%R92!U;G1E<W1E9"X*
M"B`@("`@(%!R969E<F5N8V5S(&-A;B!A;'-O(&)E('-T;W)E9"!V:6$@3$1!
M4"`H8&`M+7=I=&@M;&1A<&!@*2P@2V]L86(*("`@("`@*&!@+2UW:71H+6QD
M87!@8"DL(&%N9"!)35-0+@H*("`@("`@06QT97)N871I=F5L>2P@<')E9F5R
M96YC97,@8V%N(&)E('-T;W)E9"!I;B!02%`@<V5S<VEO;G,L('=H:6-H"B`@
M("`@(')E<75I<F5S(&YO(&5X=&5R;F%L('!R;V=R86US(&]R(&-O;F9I9W5R
M92!O<'1I;VYS+"!B=70@=VAI8V@@=VEL;"!N;W0*("`@("`@;6%I;G1A:6X@
M<')E9F5R96YC97,@8F5T=V5E;B!S97-S:6]N<RX*"B`@("`@(%=H:6QE('1H
M92!,1$%0+"!D871A8F%S92P@2V]L86(L(&]R($E-4U`@<V5R=F5R(&YE960@
M;F]T(&)E(')U;FYI;F<@;VX*("`@("`@=&AE(&UA8VAI;F4@;VYT;R!W:&EC
M:"!Y;W4@87)E(&EN<W1A;&QI;F<@2&]R9&4L('1H92!A<'!R;W!R:6%T90H@
M("`@("!C;&EE;G0@;&EB<F%R:65S('1O(&%C8V5S<R!T:&4@<V5R=F5R(&UU
M<W0@8F4@879A:6QA8FQE(&QO8V%L;'DN"@H@("`@("!)9B!A('!R969E<F5N
M8V4@8V]N=&%I;F5R(&ES(&YO="!C;VYF:6=U<F5D+"!N;R!P<F5F97)E;F-E
M(&]P=&EO;G,*("`@("`@=VEL;"!B92!C;VYF:6=U<F%B;&4@=FEA($AO<F1E
M)W,@=V5B(&EN=&5R9F%C92`M('1H92!D969A=6QT('9A;'5E<PH@("`@("!S
M=&]R960@:6X@96%C:"!A<'!L:6-A=&EO;G,@8&!C;VYF:6<O<')E9G,N<&AP
M8&`@9FEL92!W:6QL(&)E('5S960N"@H@("!B+B!-8W)Y<'0@<W5P<&]R="!@
M8"TM=VET:"UM8W)Y<'1@8`H*("`@("`@36-R>7!T(&ES(&$@9V5N97)A;"UP
M=7)P;W-E(&-R>7!T;V=R87!H>2!L:6)R87)Y('=H:6-H(&ES(&)R;V%D97(@
M86YD"B`@("`@('-I9VYI9FEC86YT;'D@;6]R92!E9F9I8VEE;G0@*$9!4U1%
M4B$I('1H86X@4$A0)W,@;W=N(&-R>7!T;V=R87!H:6,*("`@("`@8V]D92X@
M66]U(&-A;B!O8G1A:6X@;6-R>7!T(&9R;VT*"B`@("`@("`@(&AT='`Z+R]M
M8W)Y<'0N<V]U<F-E9F]R9V4N;F5T+PH*("`@("`@0G5I;&1I;F<@4$A0('=I
M=&AO=70@;6-R>7!T('-U<'!O<G0@=VEL;"!N;W0@<W1O<"!(;W)D92!F<F]M
M('=O<FMI;F<L"B`@("`@(&)U="!W:6QL(&9O<F-E(&ET('1O('5S92!W96%K
M97(@*&%N9"!M=6-H('-L;W=E<BD@96YC<GEP=&EO;BX*"B`@(&,N(%541BTX
M('-U<'!O<G0@8&`M+7=I=&@M:6-O;G8@+2UE;F%B;&4M;6)S=')I;F<]86QL
M("TM96YA8FQE+6UB<F5G97A@8`H*("`@("`@268@=&AE<V4@97AT96YS:6]N
M<R!A<F4@96YA8FQE9"P@2&]R9&4@8V%N('-U<'!O<G0@;75L=&EB>71E(&-H
M87)A8W1E<@H@("`@("!S971S(&QI:V4@551&+3@@*&UE86YI;F<@=&AA="!C
M;VYT96YT('=I=&@@86YY(&-H87)S970@8V%N(&)E('9I97=E9`H@("`@("!W
M:71H(&%N>2!T<F%N<VQA=&EO;BDN"@H@("!D+B!'1"!S=7!P;W)T(&!@+2UW
M:71H+6=D8&`*"B`@("`@($AO<F1E('=I;&P@=7-E('1H92!'1"!E>'1E;G-I
M;VX@=&\@<&5R9F]R;2!M86YI<'5L871I;VYS(&]N(&EM86=E(&1A=&$*("`@
M("`@=&AR;W5G:"!T:&4@2&]R9&5?26UA9V4@;&EB<F%R>2X*"B`@("`@($EF
M('EO=2!W86YT($=$('1O(&)E(&%B;&4@=&\@=V]R:R!W:71H(%!.1R!I;6%G
M97,L('EO=2!S:&]U;&0@=7-E('1H90H@("`@("!@8"TM=VET:"UP;F<M9&ER
M8&`@;W!T:6]N('1O(&UA:V4@<W5R92!02%`@8V%N(&9I;F0@=&AE(%!.1R!L
M:6)R87)I97,*("`@("`@:70@;F5E9',@=&\@8V]M<&EL92X*"B`@("`@($EF
M('EO=2!W86YT($=$('1O(&)E(&%B;&4@=&\@=V]R:R!W:71H($I014<@:6UA
M9V5S+"!Y;W4@<VAO=6QD('5S92!T:&4*("`@("`@8&`M+7=I=&@M:G!E9RUD
M:7)@8"!O<'1I;VX@=&\@;6%K92!S=7)E(%!(4"!C86X@9FEN9"!T:&4@2E!%
M1R!L:6)R87)I97,*("`@("`@:70@;F5E9',@=&\@8V]M<&EL92X*"B`@("`@
M(%EO=2!C86X@86QS;R!U<V4@=&AE($EM86=E36%G:6-K7R!P86-K86=E('1O
M(&1O('1H97-E(&UA;FEP=6QA=&EO;G,*("`@("`@:6YS=&5A9"X@(%-E92!T
M:&4@8&!);6%G92!-86YI<'5L871I;VY@8"!T86(@;V8@=&AE($AO<F1E('-E
M='5P(&9O<B!M;W)E"B`@("`@(&1E=&%I;',N"@H@("`@("`N+B!?26UA9V5-
M86=I8VLZ(&AT='`Z+R]W=W<N:6UA9V5M86=I8VLN;W)G"@H@("!E+B!-24U%
M($UA9VEC('-U<'!O<G0@8&`M+7=I=&@M;6EM92UM86=I8V!@"@H@("`@("!(
M;W)D92!W:6QL('5S92!T:&4@34E-12!-86=I8R!E>'1E;G-I;VX@=&\@9W5E
M<W,@=&AE($U)344@='EP92!O9B!F:6QE<PH@("`@("!B>2!A;F%L>7II;F<@
M=&AE:7(@8V]N=&5N=',N"@H@("`@("`N+B!.;W1E.CH@5&AI<R!E>'1E;G-I
M;VX@:7,@<F5P;W)T960@=&\@8F4@9&5P<F5C871E9%\@:6X@9F%V;W(@;V8@
M=&AE"B`@("`@("`@("`@("`@("!F:6QE:6YF;R!014-,(&5X=&5N<VEO;B`H
M<V5E(&)E;&]W*2X@($AO=V5V97(L('-O;64@=7-E<G,@:&%V90H@("`@("`@
M("`@("`@("`@<F5P;W)T960@=&AA="!T:&4@9FEL96EN9F\@97AT96YS:6]N
M('=I;&P@;F]T(&)U:6QD(&-O<G)E8W1L>0H@("`@("`@("`@("`@("`@;VX@
M=&AE:7(@<WES=&5M+B!)9B!S;RP@=&AE;B!T:&4@34E-12!-86=I8R!E>'1E
M;G-I;VX@<VAO=6QD"B`@("`@("`@("`@("`@("!B92!U<V5D(&EN<W1E860N
M(%!I8VL@;VYE(&]R('1H92!O=&AE<B`M('1H97)E(&ES(&YO(&YE960@=&\*
M("`@("`@("`@("`@("`@(&-O;7!I;&4@8F]T:"X*"B`@("`@($EF('5S:6YG
M(%!(4"`T+C,N,"`M/B`T+C,N,2P@>6]U('-H;W5L9"!U<V4@8&`M+65N86)L
M92UM:6UE+6UA9VEC8&`*("`@("`@:6YS=&5A9"!O9B!@8"TM=VET:"UM:6UE
M+6UA9VEC8&`N"@H@("`@("`N+B!?9&5P<F5C871E9#H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VUI;65?;6%G:6,*"B`@("XN($EM<&]R=&%N=#HZ($%D9&ET:6]N
M86QL>2P@:6YD:79I9'5A;"!(;W)D92!A<'!L:6-A=&EO;G,@;6%Y("HJ4D51
M54E212HJ"B`@("`@("`@("`@("`@("`@(&]R("HJ4D5#3TU-14Y$*BH@;W1H
M97(@;W!T:6]N<R!T;R!B92!B=6EL="!I;G1O(%!(4`H@("`@("`@("`@("`@
M("`@("!A;'-O+B!0;&5A<V4@8VAE8VL@8&!D;V-S+TE.4U1!3$Q@8"!F;W(@
M86QL(&%P<&QI8V%T:6]N<R!Y;W4*("`@("`@("`@("`@("`@("`@=VES:"!T
M;R!U<V4@=&\@<V5E(&EF(&]T:&5R(%!(4"!O<'1I;VYS(&%R92!N965D960N
M"@HS+B!!9&1I=&EO;F%L(%!%05(@36]D=6QE<PH*("`@4$5!4B!I<R!S:&]R
M="!F;W(@(E!(4"!%>'1E;G-I;VX@86YD($%P<&QI8V%T:6]N(%)E<&]S:71O
M<GDB+B`@5&AE(&=O86P@;V8*("`@4$5!4B!I<R!T;R!P<F]V:61E(&$@;65A
M;G,@;V8@9&ES=')I8G5T:6YG(')E=7-A8FQE(&-O9&4N"@H@("!&;W(@;6]R
M92!I;F9O<FUA=&EO;BP@<V5E(&AT='`Z+R]P96%R+G!H<"YN970O"@H@("`N
M+B!);7!O<G1A;G0Z.B!-86ME('-U<F4@>6]U(&%R92!R=6YN:6YG(&$@<W5P
M<&]R=&5D("AI+F4N(&YE=R!E;F]U9V@I"B`@("`@("`@("`@("`@("`@('9E
M<G-I;VX@;V8@4$5!4CH@=7-E('1H92!T97-T('-C<FEP="!D97-C<FEB960@
M8F5L;W<@=6YD97(*("`@("`@("`@("`@("`@("`@(F!#;VYF:6=U<FEN9R!(
M;W)D96!?(BX@($1O("HJ;F]T*BH@=7-E('1H92!014%2('9E<G-I;VX*("`@
M("`@("`@("`@("`@("`@9G)O;2!F='`N:&]R9&4N;W)G+@H*("`@0VAE8VL@
M=&AA="!T:&4@<&%T:"!W:&5R92!T:&4@4$5!4B!P86-K86=E<R!A<F4@:6YS
M=&%L;&5D(&%R92!P87)T(&]F('1H90H@("!@8&EN8VQU9&5?<&%T:&!@('!A
M<F%M971E<B!T:&%T(%!(4"!U<V5S('1O(&9I;F0@4$5!4B!P86-K86=E<RX*
M"B`@(%)U;B!T:&4@8V]M;6%N9#HZ"@H@("`@('!E87(@8V]N9FEG+7-H;W<*
M"B`@(%EO=2!W:6QL('-E92!S;VUE=&AI;F<@;&EK93HZ"@H@("`@(%!%05(@
M9&ER96-T;W)Y("`@("`@("`@("`@("`@("!P:'!?9&ER("`@("`@("`@+W5S
M<B]S:&%R92]P:'`*"B`@($YO=R!O<&5N('1H92!P:'`N:6YI(&9I;&4@;V8@
M>6]U<B!S>7-T96TL(&9O<B!E>&%M<&QE(&!@+V5T8R]P:'`N:6YI8&`L"B`@
M(&9I;F0@=&AE(&!@:6YC;'5D95]P871H8&`@86YD(&UA:V4@<W5R92!T:&%T
M(&!@+W5S<B]S:&%R92]P:'!@8"!I<R!P87)T(&]F"B`@('1H92!L:7-T+B`@
M268@>6]U(&AA9"!T;R!C:&%N9V4@=&AA="!V86QU92P@<F5S=&%R="!T:&4@
M=V5B('-E<G9E<B!A9G1E<@H@("!S879I;F<@8&!P:'`N:6YI8&`N"@H@("!4
M:&5S92!014%2(&UO9'5L97,@87)E("HJ4D5154E2140J*B!T;R!B92!I;G-T
M86QL960@9F]R(&-O;7!L971E($AO<F1E"B`@(&9U;F-T:6]N86QI='DZ"@H@
M("!A+B!,;V<*("`@8BX@36%I;`H@("!C+B!-86EL7TUI;64*"B`@("`@(%1O
M(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@
M<')O;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T86QL($QO9R!-86EL($UA:6Q?
M36EM90H*("`@5&AE<V4@4$5!4B!M;V1U;&5S(&%R92`J*E)%0T]-345.1$5$
M*BH@=&\@8F4@:6YS=&%L;&5D.@H*("`@82X@1$(@*#X](#$N-BXP*0H*("`@
M("`@*BI215%525)%1"HJ(&%S('-O;VX@87,@>6]U('=A;G0@;W(@;F5E9"!T
M;R!S=&]R92!A;GET:&EN9R!I;B!A(&1A=&%B87-E+@H@("`@("!4;R!I;G-T
M86QL+"!E;G1E<B!T:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R;VUP
M=#HZ"@H@("`@("`@('!E87(@:6YS=&%L;"!$0@H*("`@("`@5&\@=7!G<F%D
M92P@96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M<'0Z
M.@H*("`@("`@("!P96%R('5P9W)A9&4@1$(*"B`@(&(N($9I;&4*"B`@("`@
M("HJ4D5154E2140J*B!O;FQY(&EF('EO=2!W:7-H('1O(&EM<&]R="!#4U8@
M9FEL97,N"B`@("`@(%1O(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@
M870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T86QL
M($9I;&4*"B`@(&,N($1A=&4*"B`@("`@("HJ4D5154E2140J*B!O;FQY(&EF
M('EO=2!A<F4@9&5A;&EN9R!W:71H(&-A;&5N9&%R(&1A=&$N"B`@("`@(%1O
M(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@
M<')O;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T86QL($1A=&4*"B`@(&0N(%-E
M<G9I8V5S7U=E871H97(@*#X](#$N,RXQ*0H*("`@("`@*BI215%525)%1"HJ
M(&]N;'D@:68@>6]U('=I<V@@=&\@=7-E('1H92!W96%T:&5R+F-O;2!B;&]C
M:R!O;@H@("`@("!T:&4@<&]R=&%L('!A9V4N"B`@("`@(%1O(&EN<W1A;&PL
M(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*
M"B`@("`@("`@<&5A<B`M9"!P<F5F97)R961?<W1A=&4]8F5T82!I;G-T86QL
M("UA(%-E<G9I8V5S7U=E871H97(*"B`@("`@($%D9&ET:6]N86P@<W1E<',@
M87)E(')E<75I<F5D(&EF('EO=2!W86YT('5S92!T:&4@345405(@=V5A=&AE
M<B!B;&]C:R!O;@H@("`@("!T:&4@<&]R=&%L('!A9V4N(%-E92!T:&4@9FEL
M92!@8&1A=&$O4V5R=FEC97-?5V5A=&AE<B]B=6EL9$UE=&%R1$(N<&AP8&`*
M("`@("`@:6X@>6]U<B!014%2(&1I<F5C=&]R>2!F;W(@9&5T86EL<RX*"B`@
M(%1H:7,@;65T:&]D(&]F(&EN<W1A;&QI;F<@4$5!4B!M;V1U;&5S(')E<75I
M<F5S('1H870@>6]U(&AA=F4@82!02%`@=F5R<VEO;@H@("!T:&%T(&AA<R!B
M965N(&-O;7!I;&5D(&%S(&$@<W1A=&EC(&)I;F%R>2X@($%L;"!V97)S:6]N
M<R!O9B!02%`@-"XS+C`K"B`@(&)U:6QD(&)O=&@@82!305!)(&UO9'5L92`H
M07!A8VAE+"!#1TDL(&5T8RXI(&%N9"!A(&-O;6UA;F0M;&EN92`H0TQ)*0H@
M("!B:6YA<GD@870@=&AE('-A;64@=&EM92X@($-H96-K(&EF('EO=2!H879E
M(&$@<&AP(&)I;F%R>2!I;@H@("!@8"]U<W(O;&]C86PO8FEN8&`@*&!@+W5S
M<B]B:6Y@8"!I9B!I9B!Y;W4@:6YS=&%L;&5D(&9R;VT@86X@;W!E<F%T:6YG
M"B`@('-Y<W1E;2!P86-K86=E*2!B969O<F4@<F5C;VUP:6QI;F<N"@H@("!)
M9B!Y;W4@<F5C96EV92!T:&4@97)R;W(@8&!#;W5L9"!N;W0@<F5A9"!C;60@
M87)G<V!@('EO=2!S:&]U;&0@<G5N('1H92!P96%R"B`@('-C<FEP="!T:&ES
M('=A>3HZ"@H@("`@('!H<"`M9"!R96=I<W1E<E]A<F=C7V%R9W8],2!?4$5!
M4E\@:6YS=&%L;"!?34]$54Q%7PH*("`@7U!%05)?(&ES('1H92!C;VUP;&5T
M92!P871H(&]F('1H92!P96%R('-C<FEP="!I;G-T86QL960@8GD@4$A0(&1U
M<FEN9PH@("!I;G-T86QL871I;VX@*&4N9RX@8&`O=7-R+VQO8V%L+V)I;B]P
M96%R8&`I+B`@36%K92!S=7)E('1H92!@8'!E87)@8"!S8W)I<'0*("`@87!P
M96%R<R!I;B!Y;W5R('!A=&@N(%1H92!D969A=6QT(&EN<W1A;&QA=&EO;B!P
M871H(&9O<B!P96%R(&ES"B`@(&!@+W5S<B]L;V-A;"]B:6XO<&5A<F!@+@H*
M("`@7TU/1%5,15\@:7,@=&AE(%!%05(@;6]D=6QE+"!L:7-T960@86)O=F4L
M('=H:6-H('EO=2!W:7-H('1O(&EN<W1A;&PN"@H@("!&;W(@;6]R92!D971A
M:6QE9"!D:7)E8W1I;VYS(&]N(&EN<W1A;&QI;F<@4$5!4B!M;V1U;&5S+"!S
M964@=&AE(%!%05(*("`@9&]C=6UE;G1A=&EO;B!A="!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"\*"C0N($%D9&ET:6]N86P@4$5#3"!-;V1U;&5S"@H@
M("!014-,(&ES('-H;W)T(&9O<B`B4$A0($5X=&5N<VEO;B!#;VUM=6YI='D@
M3&EB<F%R>2(N("!4:&4@9V]A;"!O9B!014-,(&ES"B`@('1O('!R;W9I9&4@
M82!M96%N<R!O9B!E87-I;'D@9&ES=')I8G5T:6YG(%!(4"!E>'1E;G-I;VYS
M+@H*("`@1F]R(&UO<F4@:6YF;W)M871I;VXL('-E92!H='1P.B\O<&5C;"YP
M:'`N;F5T+PH*("`@4$5#3"!I<R!T:&4@(G-I<W1E<B(@;V8@4$5!4B!A;F0@
M=7-E<R!T:&4@<V%M92!P86-K86=I;F<@86YD(&1I<W1R:6)U=&EO;@H@("!S
M>7-T96T@87,@4$5!4BP@<V\@=&AE(&-O;F9I9W5R871I;VXO<V5T=7`@:7,@
M97-S96YT:6%L;'D@:61E;G1I8V%L('1O('1H90H@("!014%2(&EN<W1R=6-T
M:6]N<R!A8F]V92X*"B`@(%=H96X@>6]U(&EN<W1A;&P@82!014-,(&5X=&5N
M<VEO;BP@>6]U(&AA=F4@=&\@861D(&ET('1O('EO=7(@8&!P:'`N:6YI8&`*
M("`@<V\@:70@9V5T<R!L;V%D960N("!!9&0@=&AE(&9O;&QO=VEN9R!L:6YE
M('1O('EO=7(@8&!P:'`N:6YI8&`@9FEL92!T;R!L;V%D"B`@('1H92!E>'1E
M;G-I;VX@*'1H92!E>'1E;G-I;VX@<VAO=6QD(&)E(&EN<W1A;&QE9"!I;B!T
M:&4@9&ER96-T;W)Y('-P96-I9FEE9`H@("!B>2!T:&4@8&!E>'1E;G-I;VY?
M9&ER8&`@;W!T:6]N(&EN(&!@<&AP+FEN:6!@*3HZ"@H@("`@(&5X=&5N<VEO
M;CUF:6QE:6YF;RYS;PH*("`@3W(@;VX@5VEN9&]W<SHZ"@H@("`@(&5X=&5N
M<VEO;CUF:6QE:6YF;RYD;&P*"B`@($%F=&5R('1H870L(')E<W1A<G0@>6]U
M<B!W96)S97)V97(N"@H@("!4:&5S92!014-,(&UO9'5L97,@87)E("HJ4D5#
M3TU-14Y$140J*B!T;R!B92!I;G-T86QL960Z"@H@("!A+B!F:6QE:6YF;PH*
M("`@("`@06QL;W=S($AO<F1E(&UO9'5L97,@=&\@9W5E<W,@=&AE($U)344@
M='EP92!O9B!F:6QE<R!B>2!A;F%L>7II;F<*("`@("`@=&AE:7(@8V]N=&5N
M=',N"@H@("`@("!)9B!N;W0@96YA8FQE9"P@2&]R9&4@=VEL;"!U<V4@:71S
M(&]W;B!02%`@8V]D92!T;R!P97)F;W)M($U)344@;6%G:6,*("`@("`@;&]O
M:W5P<RX@($AO=V5V97(L('1H:7,@;&]O:W5P(&ES('-L;W=E<BP@;&5S<R!A
M8V-U<F%T92P@86YD(&1E=&5C=',*("`@("`@9F5W97(@34E-12!T>7!E<R!T
M:&%N('1H92!014-,(&5X=&5N<VEO;B!W:6QL+@H*("`@("`@5&\@:6YS=&%L
M;"P@96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M<'0Z
M.@H*("`@("`@("!P96%R(&EN<W1A;&P@9FEL96EN9F\*"B`@(%1H97-E(%!%
M0TP@;6]D=6QE<R!A<F4@*BI214-/34U%3D1%1"HJ('1O(&)E(&EN<W1A;&QE
M9"!I9B!Y;W4@;F5E9`H@("!A9'9A;F-E9"!F=6YC=&EO;F%L:71Y.@H*("`@
M82X@;65M8V%C:&4*"B`@("`@($EF('5S:6YG('1H92!M96UC86-H960@4V5S
M<VEO;DAA;F1L97(L('1H92!M96UC86-H92!014-,(&5X=&5N<VEO;B!M=7-T
M"B`@("`@(&)E(&EN<W1A;&QE9"X*"B`@("`@(%1O(&EN<W1A;&PL(&5N=&5R
M('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@("`@
M("`@<&5A<B!I;G-T86QL(&UE;6-A8VAE"@H@("!&;W(@861D:71I;VYA;"!H
M96QP(&]N('5S:6YG('1H92!P96%R(&-O;6UA;F0M;&EN92!P<F]G<F%M('1O
M(&EN<W1A;&P@4$5#3`H@("!E>'1E;G-I;VYS+"!S964@=&AE(%!%05(@:6YS
M=&%L;&%T:6]N('-E8W1I;VX@86)O=F4N"@H*5&AE(&9O;&QO=VEN9R!N;VXM
M4$A0('!R97)E<75I<VET97,@87)E("HJ4D5#3TU-14Y$140J*BP@;W(@87)E
M("HJ4D5154E2140J*@II9B!Y;W4@=7-E(&$@<W!E8VEF:6,@2&]R9&4@87!P
M;&EC871I;VX@*&%S(&YO=&5D(&EN(%MB<F%C:V5T<UTI.@H*,2X@4V5N9&UA
M:6P@;W(@97%U:79A;&5N="X*"B`@($AO<F1E('5S97,@<V5N9&UA:6PL(&]R
M(&$@<')O9W)A;2!T:&%T(&EM<&QE;65N=',@=&AE(&!@<V5N9&UA:6PH."E@
M8"!!4$D*("`@*&%S(&EN8VQU9&5D('=I=&@@<&]S=&9I>"P@<6UA:6PL(&%N
M9"!E>&EM+"!A;6]N9R!O=&AE<G,I+B!)9B!Y;W5R('-Y<W1E;0H@("!D;V5S
M(&YO="!A;')E861Y(&AA=F4@82!F=6QL(&UA:6P@=')A;G-P;W)T('=I=&@@
M82!S96YD;6%I;"!I;G1E<F9A8V4L('EO=0H@("!C86X@8V]N9FEG=7)E($AO
M<F1E('1O('-P96%K(&1I<F5C=&QY('=I=&@@82!R96UO=&4@4TU44"!S97)V
M97(L(&)U="!T:&ES"B`@(&UA>2!I;F-U<B!A('!E<F9O<FUA;F-E('!E;F%L
M='DN"@H*26YS=&%L;&EN9R!(;W)D90H]/3T]/3T]/3T]/3T]/3T]"@I(;W)D
M92!I<R!W<FET=&5N(&EN(%!(4"P@86YD(&UU<W0@8F4@:6YS=&%L;&5D(&EN
M(&$@=V5B+6%C8V5S<VEB;&4@9&ER96-T;W)Y+@I4:&4@<')E8VES92!L;V-A
M=&EO;B!O9B!T:&ES(&1I<F5C=&]R>2!W:6QL(&1I9F9E<B!F<F]M('-Y<W1E
M;2!T;R!S>7-T96TN($EF"GEO=2!H879E(&YO(&ED96$@=VAE<F4@>6]U('-H
M;W5L9"!B92!I;G-T86QL:6YG($AO<F1E+"!I;G-T86QL(&ET(&1I<F5C=&QY
M"G5N9&5R('1H92!R;V]T(&]F('EO=7(@=V5B<V5R=F5R)W,@9&]C=6UE;G0@
M=')E92X*"@I);G-T86QL:6YG(&9R;VT@4F5L96%S92!487)B86QL<PI^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@H*4VEN8V4@2&]R9&4@:7,@
M=W)I='1E;B!I;B!02%`L('1H97)E(&ES(&YO(&-O;7!I;&%T:6]N(&YE8V5S
M<V%R>3L@<VEM<&QY"F5X<&%N9"!T:&4@9&ES=')I8G5T:6]N('=H97)E('EO
M=2!W86YT(&ET('1O(')E<VED92!A;F0@<F5N86UE('1H92!R;V]T"F1I<F5C
M=&]R>2!O9B!T:&4@9&ES=')I8G5T:6]N('1O('=H871E=F5R('EO=2!W:7-H
M('1O(&%P<&5A<B!I;B!T:&4*55),+B!0;&5A<V4@;F]T92!T:&%T('1H92!D
M969A=6QT(&-O;F9I9W5R871I;VX@97AP96-T<R!(;W)D92!T;R!B92!I;G-T
M86QL960*:6X@=&AE(&1I<F5C=&]R>2!@8"]H;W)D96!@('1H;W5G:"X@1F]R
M(&5X86UP;&4L('=I=&@@=&AE($%P86-H92!W96)S97)V97(G<PID969A=6QT
M(&1O8W5M96YT(')O;W0@;V8@8&`O=7-R+VQO8V%L+V%P86-H92]H=&1O8W-@
M8"P@>6]U('=O=6QD('1Y<&4Z.@H*("`@8V0@+W5S<B]L;V-A;"]A<&%C:&4O
M:'1D;V-S"B`@('1A<B!Z>'9F("]P871H+W1O+VAO<F1E+7@N>2YZ+G1A<BYG
M>@H@("!M=B!H;W)D92UX+GDN>B!H;W)D90H*66]U('=O=6QD('1H96X@9FEN
M9"!(;W)D92!A="!T:&4@55),.CH*"B`@(&AT='`Z+R]Y;W5R+7-E<G9E<B]H
M;W)D92\*"E-K:7`@=&AE(&YE>'0@<&%R86=R87!H(&EF('EO=2!I;G-T86QL
M960@2&]R9&4@9G)O;2!A(')E;&5A<V4@=&%R8F%L;"X*"@I);G-T86QL:6YG
M(&9R;VT@0U93(&]R(%-N87!H;W1S"GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GX*"D%T('1H:7,@<&]I;G0L('1H92!(;W)D92!F<F%M97=O<FL@
M;6]D=6QE<R!N965D('1O(&)E(&-H96-K960@;W5T(&9R;VT@0U93(&%N9`II
M;G-T86QL960N(%1H:7,@;75S="!B92!D;VYE(&%S(')O;W0@*&]R(&%N;W1H
M97(@=7-E<B!W:71H('-U9F9I8VEE;G0*861M:6YI<W1R871O<B!P<FEV:6QE
M9&=E<RDZ.@H*("`@8V0@:&]R9&4*("`@8W9S(&-O(&9R86UE=V]R:PH@("!C
M9"!F<F%M97=O<FL*("`@<&AP("UQ(&EN<W1A;&PM<&%C:V%G97,N<&AP"@I&
M;W(@5VEN9&]W<R!S>7-T96US("T@=7-E('1H92!@8&EN<W1A;&PM<&%C:V%G
M97,N8F%T8&`@9FEL92!I;G-T96%D+@I&;W(@1&5B:6%N('-Y<W1E;7,@+2!T
M:&4@8V]M;6%N9"UL:6YE(%!(4"!I;G1E<G!R971E<B!M:6=H="!B92!C86QL
M960@8&!P:'`T8&`*:6YS=&5A9"!O9B!@8'!H<&!@+@H*"D-O;F9I9W5R:6YG
M($AO<F1E"CT]/3T]/3T]/3T]/3T]/3T]"@HQ+B!#;VYF:6=U<FEN9R!T:&4@
M=V5B('-E<G9E<@H*("`@2&]R9&4@<F5Q=6ER97,@=&AE(&9O;&QO=VEN9R!W
M96)S97)V97(@<V5T=&EN9W,N($5X86UP;&5S('-H;W=N(&%R92!F;W(*("`@
M07!A8VAE.R!O=&AE<B!W96)S97)V97)S)R!C;VYF:6=U<F%T:6]N<R!W:6QL
M(&1I9F9E<BX*"B`@(&$N(%!(4"!I;G1E<G!R971A=&EO;B!F;W(@9FEL97,@
M;6%T8VAI;F<@8&`J+G!H<&!@.CH*"B`@("`@("`@($%D9%1Y<&4@87!P;&EC
M871I;VXO>"UH='1P9"UP:'`@+G!H<`H*("`@("`@+BX@3F]T93HZ(%1H92!A
M8F]V92!I;G-T<G5C=&EO;G,@;6%Y(&YO="!W;W)K(&EF('EO=2!H879E('-P
M96-I9FEE9"!02%`*("`@("`@("`@("`@("`@(&%S(&%N(&]U='!U="!F:6QT
M97(@=VET:"!@8%-E=$]U='!U=$9I;'1E<F!@(&1I<F5C=&EV92!I;@H@("`@
M("`@("`@("`@("`@07!A8VAE(#(N>"!V97)S:6]N<RX@($EN('!A<G1I8W5L
M87(L(%)E9"!(870@."XP(&%N9"!A8F]V90H@("`@("`@("`@("`@("`@07!A
M8VAE(#(N>"!24$U3(&AA=F4@=&AE(&]U='!U="!F:6QT97(@<V5T+"!A;F0@
M*BI-55-4($Y/5"HJ"B`@("`@("`@("`@("`@("!H879E('1H92!A8F]V92!@
M8$%D9%1Y<&5@8"!D:7)E8W1I=F4@861D960N"@H@("!B+B!@8&EN9&5X+G!H
M<&!@(&%S(&%N(&EN9&5X(&9I;&4@*&)R;W5G:'0@=7`@=VAE;B!A('5S97(@
M<F5Q=65S=',@82!54DP@9F]R"B`@("`@(&$@9&ER96-T;W)Y*3HZ"@H@("`@
M("`@("!$:7)E8W1O<GE);F1E>"!I;F1E>"YP:'`*"C(N($-R96%T:6YG(&1A
M=&%B87-E<PH*("`@5&AE('-P96-I9FEC('-T97!S('1O(&-R96%T92!A('!R
M969E<F5N8V5S('-T;W)A9V4@8V]N=&%I;F5R(&1E<&5N9"!O;@H@("!W:&EC
M:"!D871A8F%S92!Y;W4G=F4@8VAO<V5N('1O('5S92X*"B`@($9I<G-T+"!L
M;V]K(&EN(&!@<V-R:7!T<R]S<6PO8&`@=&\@<V5E(&EF(&$@8&!C<F5A=&4N
M8&`@<V-R:7!T(&%L<F5A9'D*("`@97AI<W1S(&9O<B!Y;W5R(&1A=&%B87-E
M+B`@268@<V\L('EO=2!S:&]U;&0@8F4@86)L92!T;R!S:6UP;'D@97AE8W5T
M92!T:&%T"B`@('-C<FEP="!A<R!S=7!E<G5S97(@:6X@>6]U<B!D871A8F%S
M92X@($-O;G-U;'0@=&AE(&!@<V-R:7!T<R]S<6PO4D5!1$U%8&`*("`@9FEL
M92!F;W(@;6]R92!I;F9O<FUA=&EO;BX*"B`@($)E('-U<F4@=&\@8VAA;F=E
M('1H92!D969A=6QT('!A<W-W;W)D+"!@8&AO<F1E8&`L('1O('-O;65T:&EN
M9R!E;'-E(&)E9F]R90H@("!C<F5A=&EN9R!T:&4@=&%B;&5S(2`H4F5M96UB
M97(@=&\@=7-E('1H:7,@<&%S<W=O<F0@=VAE;B!Y;W4@8V]N9FEG=7)E"B`@
M($AO<F1E(&EN('1H92!N97AT('-T97`N*0H*("`@268@<W5C:"!A('-C<FEP
M="!D;V5S(&YO="!E>&ES="P@>6]U)VQL(&YE960@=&\@8G5I;&0@>6]U<B!O
M=VXL('5S:6YG('1H90H@("!F:6QE<R!@8&AO<F1E7W5S97)S+G-Q;&!@+"!@
M8&AO<F1E7W!R969S+G-Q;&!@+"!A;F0@8&!H;W)D95]D871A=')E92YS<6Q@
M8`H@("!A<R!A('-T87)T:6YG('!O:6YT+B`@268@>6]U(&YE960@87-S:7-T
M86YC92!I;B!C<F5A=&EN9R!D871A8F%S97,@9F]R(&$*("`@9&%T86)A<V4@
M9F]R('=H:6-H(&YO(&!@8W)E871E+F!@('-C<FEP="!E>&ES=',L('EO=2!M
M87D@=VES:"!T;R!L970@=7,*("`@:VYO=R!O;B!T:&4@8$AO<F1E(&UA:6QI
M;F<@;&ES=&!?+@H*("`@268@>6]U(&%R92!G;VEN9R!T;R!U<V4@9&%T86)A
M<V4@8F%S960@<V5S<VEO;G,L(&-R96%T92!A('1A8FQE('5S:6YG('1H90H@
M("!F:6QE<R!@8'-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R*BYS
M<6Q@8"!A<R!A('-T87)T:6YG('!O:6YT+@H*("`@+BX@7V!(;W)D92!M86EL
M:6YG(&QI<W1@.B!H;W)D94!L:7-T<RYH;W)D92YO<F<*"C,N($-O;F9I9W5R
M:6YG($AO<F1E"@H@("!4;R!C;VYF:6=U<F4@2&]R9&4L(&-H86YG92!T;R!T
M:&4@8&!C;VYF:6<O8&`@9&ER96-T;W)Y(&]F('1H92!I;G-T86QL960*("`@
M9&ES=')I8G5T:6]N+"!A;F0@;6%K92!C;W!I97,@;V8@86QL(&]F('1H92!C
M;VYF:6=U<F%T:6]N(&!@+F1I<W1@8"!F:6QE<PH@("!W:71H;W5T('1H92!@
M8"YD:7-T8&`@<W5F9FEX.CH*"B`@("`@(&-D(&-O;F9I9R\*("`@("`@9F]R
M(&8@:6X@*BYD:7-T.R!D;R!C<"`D9B!@8F%S96YA;64@)&8@+F1I<W1@.R!D
M;VYE"@H@("!/<B!I9B!Y;W4@87)E(&EN<W1A;&QI;F<@2&]R9&4@86X@82!7
M:6YD;W=S('-Y<W1E;3HZ"@H@("`@("!C9"!C;VYF:6<*("`@("`@8V]P>2`J
M+F1I<W0@*BX*"B`@("XN($YO=&4Z.B!9;W4@;VYL>2!N965D('1H92!@8&AO
M;VMS+G!H<&!@(&9I;&4@:68@>6]U('=A;G0@=&\@8W)E871E(&-U<W1O;0H@
M("`@("`@("`@("`@:&]O:W,@9F]R('-O;64@;V8@2&]R9&4G<R!F96%T=7)E
M<R!A;F0@9&5F875L="!V86QU97,N($)E<VED90H@("`@("`@("`@("`@=&AA
M="P@=&AI<R!F:6QE(&]N;'D@8V]N=&%I;G,@97AA;7!L97,@=&AA="!Y;W4@
M<VAO=6QD(&YO="!U<V4@87,*("`@("`@("`@("`@('1H97D@87)E+B!)9B!Y
M;W4@9&]N)W0@;F5E9"!H;V]K<R!I="=S(&$@9V]O9"!I9&5A('1O(')E;6]V
M92!T:&ES"B`@("`@("`@("`@("!F:6QE(&YO=SHZ"@H@("`@("`@("`@("`@
M("`@("`@<FT@:&]O:W,N<&AP"@H@("!$;V-U;65N=&%T:6]N(&]N('1H92!F
M;W)M870@;V8@=&AO<V4@9FEL97,@8V%N(&)E(&9O=6YD(&EN(&5A8V@@9FEL
M92X*"B`@("XN(%=A<FYI;F<Z.B!!;&P@8V]N9FEG=7)A=&EO;B!F:6QE<R!I
M;B!(;W)D92!A<F4@4$A0('-C<FEP=',@=&AA="!A<F4*("`@("`@("`@("`@
M("`@(&5X96-U=&5D(&)Y('1H92!W96(@<V5R=F5R+B!)9B!Y;W4@;6%K92!A
M;B!E<G)O<B!I;B!O;F4@;V8*("`@("`@("`@("`@("`@('1H97-E(&9I;&5S
M+"!(;W)D92!M:6=H="!S=&]P('=O<FMI;F<N(%1H=7,@:70@:7,@86QW87ES
M(&$*("`@("`@("`@("`@("`@(&=O;V0@:61E82!T;R!T97-T('1H92!C;VYF
M:6=U<F%T:6]N(&9I;&5S(&%F=&5R('EO=2!E9&ET960*("`@("`@("`@("`@
M("`@('1H96TN($EF('EO=2!W86YT('1O('1E<W0@;6EM95]D<FEV97)S+G!H
M<"!F;W(@97AA;7!L92!R=6XZ.@H*("`@("`@("`@("`@("`@("`@('!H<"`M
M;"!M:6UE7V1R:79E<G,N<&AP"@HT+B!497-T:6YG($AO<F1E"@H@("!/;F-E
M('EO=2!H879E(&-O;F9I9W5R960@>6]U<B!W96)S97)V97(L(%!(4"P@86YD
M($AO<F1E+"!B<FEN9R!U<"!T:&4*("`@:6YC;'5D960@=&5S="!P86=E(&EN
M('EO=7(@5V5B(&)R;W=S97(@=&\@96YS=7)E('1H870@86QL(&YE8V5S<V%R
M>0H@("!P<F5R97%U:7-I=&5S(&AA=F4@8F5E;B!M970N($EF('EO=2!I;G-T
M86QL960@2&]R9&4@87,@9&5S8W)I8F5D(&%B;W9E+"!T:&4*("`@55),('1O
M('1H92!T97-T('!A9V4@=V]U;&0@8F4Z.@H*("`@("`@:'1T<#HO+WEO=7(M
M<V5R=F5R+VAO<F1E+W1E<W0N<&AP"@H@("!#:&5C:R!T:&%T('EO=7(@4$A0
M(&%N9"!014%2('9E<G-I;VYS(&%R92!A8V-E<'1A8FQY(')E8V5N="P@=&AA
M="!A;&P*("`@<F5Q=6ER960@;6]D=6QE(&-A<&%B:6QI=&EE<R!A<F4@<')E
M<V5N="P@86YD('1H870@8&!M86=I8U]Q=6]T97-?<G5N=&EM96!@"B`@(&ES
M('-E="!T;R!@8$]F9F!@+B!4:&5N(&YO=&4@=&AE(&!@4V5S<VEO;B!C;W5N
M=&5R.B`Q8&`@;&EN92!U;F1E<B!@8%!(4`H@("!397-S:6]N<V!@+"!A;F0@
M<F5L;V%D('1H92!P86=E+B!4:&4@<V5S<VEO;B!C;W5N=&5R('-H;W5L9"!I
M;F-R96UE;G0N"@H@("!)9B!Y;W4@9V5T(&$@=V%R;FEN9R!L:6ME(&!@1F%I
M;&5D(&]P96YI;F<@)R]P871H+W1O+W1E<W0N<&AP)R!F;W(*("`@:6YC;'5S
M:6]N8&`L(&UA:V4@<W5R92!T:&%T('1H92!W96(@<V5R=F5R(&AA<R!T:&4@
M<&5R;6ES<VEO;B!T;R!R96%D('1H90H@("!@8'1E<W0N<&AP8&`@9FEL92X*
M"C4N($-O;7!L971I;F<@0V]N9FEG=7)A=&EO;@H*("`@66]U(&-A;B!N;W<@
M86-C97-S($AO<F1E('=I=&AO=70@82!P87-S=V]R9"P@86YD('EO=2!W:6QL
M(&)E(&QO9V=E9"!I;B!A<PH@("!A;B!A9&UI;FES=')A=&]R+B!9;W4@<VAO
M=6QD(&9I<G-T(&-O;F9I9W5R92!A(')E86P@875T:&5N=&EC871I;VX@8F%C
M:V5N9"X*("`@0VQI8VL@;VX@8&!3971U<&!@(&EN('1H92!@8$%D;6EN:7-T
M<F%T:6]N8&`@;65N=2!A;F0@8V]N9FEG=7)E"B`@($AO<F1E+B`@4W1A<G0@
M:6X@=&AE(&!@075T:&5N=&EC871I;VY@8"!T86(N"@H@("!(97)E(&ES(&%N
M(&5X86UP;&4@9F]R(&-O;F9I9W5R:6YG(&%U=&AE;G1I8V%T:6]N(&%G86EN
M<W0@82!R96UO=&4@24U!4`H@("!S97)V97(N("!3:6UI;&%R('-T97!S(&%P
M<&QY(&9O<B!A=71H96YT:6-A=&EN9R!A9V%I;G-T(&$@9&%T86)A<V4L(&%N
M($Q$05`*("`@<V5R=F5R+"!E=&,N"@H@("!A+B!);B!T:&4@8&!7:&EC:"!U
M<V5R<R!S:&]U;&0@8F4@=')E871E9"!A<R!A9&UI;FES=')A=&]R<V!@(&9I
M96QD(&5N=&5R(&$*("`@("`@8V]M;6$@<V5P87)A=&5D(&QI<W0@;V8@=7-E
M<B!N86UE<R!O9B!Y;W5R(&-H;V]S:6YG+B!4:&ES('=I;&P@8V]N=')O;`H@
M("`@("!W:&\@:7,@86QL;W=E9"!T;R!M86ME(&-O;F9I9W5R871I;VX@8VAA
M;F=E<RP@<V5E('!A<W-W;W)D<RP@<&]T96YT:6%L;'D*("`@("`@861D('5S
M97)S+"!E=&,N"@H@("!B+B!);B!T:&4@8&!7:&%T(&)A8VME;F0@<VAO=6QD
M('=E('5S92!F;W(@875T:&5N=&EC871I;F<@=7-E<G,@=&\@2&]R9&5@8`H@
M("`@("!P=6QL9&]W;B!M96YU('-E;&5C="!@8$E-05`@875T:&5N=&EC871I
M;VY@8"X@5&AE('!A9V4@=VEL;"!R96QO860@86YD"B`@("`@('EO=2!W:6QL
M(&AA=F4@<W!E8VEF:6,@;W!T:6]N<R!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX*"B`@(&,N($EN('1H92!@8$-O;F9I9W5R871I;VX@='EP96!@('!U;&QD
M;W=N(&UE;G4@<V5L96-T(&!@4V5P87)A=&4@=F%L=65S8&`N"B`@("`@(%1H
M92!P86=E('=I;&P@<F5L;V%D('=I=&@@861D:71I;VYA;"!O<'1I;VYS+B!&
M:6QL(&EN('1H92!R96UA:6YI;F<*("`@("`@=&AR964@9FEE;&1S(&%P<')O
M<')I871E;'DZ"@H@("`@("`M($E0(&YA;64O;G5M8F5R(&]F('1H92!)34%0
M('-E<G9E<@H@("`@("`M($9O<B!A('-E8W5R92!C;VYN96-T:6]N+"!S96QE
M8W0@<&]R="`Y.3,N"B`@("`@("T@4V5L96-T('1H92!P<F]T;V-O;#L@9F]R
M(&$@<V5C=7)E(&-O;FYE8W1I;VX@96ET:&5R(&!@:6UA<"]S<VQ@8"!O<@H@
M("`@("`@(&!@:6UA<"]S<VPO;F]V86QI9&%T92UC97)T8&`@*&9O<B!S96QF
M+7-I9VYE9"!C97)T:69I8V%T97,I+@H*("`@0V]N=&EN=64@=&\@8V]N9FEG
M=7)E($AO<F1E('1H<F]U9V@@86QL('1H92!T86)S(&]F('1H92!S971U<"!I
M;G1E<F9A8V4@86YD"B`@(&-L:6-K(&]N(&!@1V5N97)A=&4@2&]R9&4@0V]N
M9FEG=7)A=&EO;F!@+B!);7!O<G1A;G0@:71E;7,@=&AA="!Y;W4*("`@<')O
M8F%B;'D@=V%N="!T;R!C;VYF:6=U<F4@87)E('1H92!@8%!R969E<F5N8V4@
M4WES=&5M8&`@=&AA="!L971S('5S97)S"B`@('-A=F4@=&AE:7(@<&5R<V]N
M86P@;W!T:6]N<RP@86YD('1H92!@8$1A=&%4<F5E(%-Y<W1E;6!@('1H870@
M:7,@<F5Q=6ER960*("`@9F]R('-O;64@87!P;&EC871I;VYS('1O('=O<FL@
M870@86QL+@H*("`@0V]N9FEG=7)A=&EO;B!O9B!A<'!L:6-A=&EO;G,@:6X@
M8&!R96=I<W1R>2YP:'!@8"!I<R!D;V-U;65N=&5D(&EN('1H90H@("!@8$E.
M4U1!3$Q@8"!F:6QE(&]F(&5A8V@@87!P;&EC871I;VXN("!-;W-T(&%P<&QI
M8V%T:6]N<R!R97%U:7)E('EO=2!T;PH@("!C;VYF:6=U<F4@=&AE;2!W:71H
M(&$@(DAO<F1E(&%D;6EN:7-T<F%T;W(B(&%C8V]U;G0N("!!($AO<F1E(&%D
M;6EN:7-T<F%T;W(*("`@86-C;W5N="!I<R!A;GD@;F]R;6%L($AO<F1E(&%C
M8V]U;G0@=&AA="!H87,@8F5E;B!A9&1E9"!T;R!T:&4*("`@861M:6YI<W1R
M871O<B!L:7-T(&EN('1H92!@8$%U=&AE;G1I8V%T:6]N8&`@=&%B(&]F('1H
M92!(;W)D92!S971U<"X*"B`@(%1H92!O=&AE<B!F:6QE<R!I;B!T:&%T(&1I
M<F5C=&]R>2!N965D(&]N;'D@8F4@;6]D:69I960@:68@>6]U('=I<V@@=&\*
M("`@8W5S=&]M:7IE($AO<F1E)W,@87!P96%R86YC92!O<B!B96AA=FEO=7(@
M+2T@=&AE(&1E9F%U;'1S('=I;&P@=V]R:R!A="!M;W-T"B`@('-I=&5S+@H*
M-BX@4V5C=7)I;F<@2&]R9&4*"B`@(&$N(%!A<W-W;W)D<PH*("`@("`@4V]M
M92!O9B!(;W)D92=S(&-O;F9I9W5R871I;VX@9FEL97,@8V]N=&%I;B!P87-S
M=V]R9',@=VAI8V@@;&]C86P@=7-E<G,*("`@("`@8V]U;&0@=7-E('1O(&%C
M8V5S<R!Y;W5R(&1A=&%B87-E+B`@270@:7,@<F5C;VUM96YD960@=&\@96YS
M=7)E('1H870@870*("`@("`@;&5A<W0@=&AE($AO<F1E(&-O;F9I9W5R871I
M;VX@9FEL97,@*&EN(&!@8V]N9FEG+V!@*2!A<F4@;F]T(')E861A8FQE('1O
M"B`@("`@('-Y<W1E;2!U<V5R<RX@(%1H97)E(&%R92!@8"YH=&%C8V5S<V!@
M(&9I;&5S(')E<W1R:6-T:6YG(&%C8V5S<R!T;PH@("`@("!D:7)E8W1O<FEE
M<R!T:&%T(&1O(&YO="!N965D('1O(&)E(&%C8V5S<V5D(&1I<F5C=&QY.R!B
M969O<F4@<F5L>6EN9R!O;@H@("`@("!T:&]S92P@96YS=7)E('1H870@>6]U
M<B!W96)S97)V97(@<W5P<&]R=',@8&`N:'1A8V-E<W-@8"!A;F0@:7,*("`@
M("`@8V]N9FEG=7)E9"!T;R!U<V4@=&AE;2P@86YD('1H870@=&AE(&9I;&5S
M(&EN('1H;W-E(&1I<F5C=&]R:65S(&%R92!I;@H@("`@("!F86-T(&EN86-C
M97-S:6)L92!V:6$@=&AE(&)R;W=S97(N"@H@("`@("!!;B!A9&1I=&EO;F%L
M(&%P<')O86-H(&ES('1O(&UA:V4@2&]R9&4G<R!C;VYF:6=U<F%T:6]N(&9I
M;&5S(&]W;F5D(&)Y"B`@("`@('1H92!U<V5R(&!@<F]O=&!@(&%N9"!B>2!A
M(&=R;W5P('=H:6-H(&]N;'D@=&AE('=E8G-E<G9E<B!U<V5R(&)E;&]N9W,*
M("`@("`@=&\L(&%N9"!T:&5N(&UA:VEN9R!T:&5M(')E861A8FQE(&]N;'D@
M=&\@;W=N97(@86YD(&=R;W5P+B`@1F]R(&5X86UP;&4L"B`@("`@(&EF('EO
M=7(@=V5B<V5R=F5R(')U;G,@87,@8&!W=W<N=W=W8&`L(&1O(&%S(&9O;&QO
M=W,Z.@H*("`@("`@("`@8VAO=VX@<F]O="YW=W<@8V]N9FEG+RH*("`@("`@
M("`@8VAM;V0@,#0T,"!C;VYF:6<O*@H*("`@8BX@4V5S<VEO;G,*"B`@("`@
M(%-E<W-I;VX@9&%T82`M+2!I;F-L=61I;F<@:&%S:&5D('9E<G-I;VYS(&]F
M('EO=7(@=7-E<G,G('!A<W-W;W)D<RP@:6X*("`@("`@<V]M92!A<'!L:6-A
M=&EO;G,@+2T@;6%Y(&YO="!B92!S=&]R960@87,@<V5C=7)E;'D@87,@;F5C
M97-S87)Y+@H*("`@("`@268@>6]U(&%R92!U<VEN9R!F:6QE+6)A<V5D(%!(
M4"!S97-S:6]N<R`H=VAI8V@@87)E('1H92!D969A=6QT*2P@8F4*("`@("`@
M<W5R92!T:&%T('-E<W-I;VX@9FEL97,@87)E(&YO="!B96EN9R!W<FET=&5N
M(&EN=&\@8&`O=&UP8&`@=VET:`H@("`@("!P97)M:7-S:6]N<R!T:&%T(&%L
M;&]W(&]T:&5R('5S97)S('1O(')E860@=&AE;2X@261E86QL>2P@8VAA;F=E
M('1H90H@("`@("!@8'-E<W-I;VXN<V%V95]P871H8&`@<V5T=&EN9R!I;B!@
M8'!H<"YI;FE@8"!T;R!A(&1I<F5C=&]R>2!O;FQY"B`@("`@(')E861A8FQE
M(&%N9"!W<FET96%B;&4@8GD@>6]U<B!W96)S97)V97(N"@H@("`@("!!9&1I
M=&EO;F%L;'DL('EO=2!C86X@8VAA;F=E('1H92!S97-S:6]N(&AA;F1L97(@
M;V8@4$A0('1O('5S92!A;GD*("`@("`@<W1O<F%G92!B86-K96YD(')E<75E
M<W1E9"`H92YG+B!344P@9&%T86)A<V4I('9I82!T:&4@8&!#=7-T;VT@4V5S
M<VEO;@H@("`@("!(86YD;&5R8&`@=&%B(&EN('1H92!(;W)D92!S971U<"X*
M"B`@($9O<B!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('-E8W5R:6YG('EO=7(@
M=V5B<V5R=F5R+"!02%`@86YD($AO<F1E+"!S964@=&AE"B`@(&!D;V-S+U-%
M0U5225198%\@9FEL92X*"C<N($5N=&5R:6YG('1H92!S=7)V97D*"B`@($EF
M('EO=2!L:6ME+"!G;R!T;R!H='1P.B\O=W=W+FAO<F1E+F]R9R]S=7)V97DO
M(&%N9"!E;G1E<B!T:&4@9&5T86EL<R!O9@H@("!Y;W5R('-Y<W1E;2X*"@I#
M;VYF:6=U<FEN9R!!<'!L:6-A=&EO;G,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@I!(&QI<W0@;V8@879A:6QA8FQE($AO<F1E(&%P<&QI8V%T:6]N<R!C
M86X@8F4@9F]U;F0@870*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W!R;VIE
M8W1S+G!H<`H*26YS=')U8W1I;VYS(&]N(&-O;F9I9W5R:6YG($AO<F1E(&%P
M<&QI8V%T:6]N<R!C86X@8F4@9F]U;F0@:6X@=&AE(&!@24Y35$%,3&!@"F9I
M;&4@:6X@=&AE(&%P<&QI8V%T:6]N)W,@8&!D;V-S+V!@(&1I<F5C=&]R>2X*
M"@I496UP;W)A<GD@1FEL97,*/3T]/3T]/3T]/3T]/3T]"@I687)I;W5S($AO
M<F1E(&%P<&QI8V%T:6]N<R!W:6QL(&=E;F5R871E('1E;7!O<F%R>2!F:6QE
M<R!I;B!02%`G<R!T96UP;W)A<GD*9&ER96-T;W)Y("AS964@=&AE(&!@1V5N
M97)A;&!@('1A8B!I;B!T:&4@2&]R9&4@<V5T=7`I+B`@1F]R('9A<FEO=7,@
M<F5A<V]N<RP*<V]M92!O9B!T:&5S92!F:6QE<R!M87D@;F]T(&)E(')E;6]V
M960@=VAE;B!T:&4@=7-E<B=S('-E<W-I;VX@96YD<RX@5&\*<F5C;&%I;2!T
M:&ES(&1I<VL@<W!A8V4L(&ET(&UA>2!B92!N96-E<W-A<GD@=&\@<&5R:6]D
M:6-A;&QY(&1E;&5T92!T:&5S92!O;&0*=&5M<&]R87)Y(&9I;&5S+@H*06X@
M97AA;7!L92!C<F]N+6)A<V5D('-O;'5T:6]N(&-A;B!B92!F;W5N9"!A="!@
M8'-C<FEP=',O=&5M<"UC;&5A;G5P+F-R;VY@8"X*06YO=&AE<B!P;W-S:6)L
M92!S;VQU=&EO;B!I<R!T;R!U<V4@4F5D($AA="=S(&!@=&UP=V%T8VA@8"!U
M=&EL:71Y(&]R(&%N>71H:6YG"G-I;6EL87(@=&\@<F5M;W9E(&]L9"!F:6QE
M<R`H<V5E(&AT='`Z+R]W=W<N<F5D:&%T+F-O;2\I+@H*"E1R86YS;&%T:6]N
M<PH]/3T]/3T]/3T]/3T*"DYO=&4@9F]R(&EN=&5R;F%T:6]N86P@=7-E<G,Z
M($AO<F1E('5S97,@1TY5(&=E='1E>'0@=&\@<')O=FED92!L;V-A;`IT<F%N
M<VQA=&EO;G,@;V8@=&5X="!D:7-P;&%Y960@8GD@87!P;&EC871I;VYS.R!T
M:&4@=')A;G-L871I;VYS(&%R92!F;W5N9"!I;@IT:&4@<&\O(&1I<F5C=&]R
M>2X@($EF(&$@=')A;G-L871I;VX@:7,@;F]T('EE="!A=F%I;&%B;&4@9F]R
M('EO=7(@;&]C86QE("AA;F0*>6]U('=I<V@@=&\@8W)E871E(&]N92DL('-E
M92!T:&4@8&!H;W)D92]P;R]214%$345@8"!F:6QE+"!O<B!I9B!Y;W4G<F4@
M:&%V:6YG"G1R;W5B;&4@=7-I;F<@82!P<F]V:61E9"!T<F%N<VQA=&EO;BP@
M<&QE87-E('-E92!T:&4*8&AO<F1E+V1O8W,O5%)!3E-,051)3TY38%\@9FEL
M92!F;W(@:6YS=')U8W1I;VYS+@H*"D]B=&%I;FEN9R!3=7!P;W)T"CT]/3T]
M/3T]/3T]/3T]/3T]"@I)9B!Y;W4@96YC;W5N=&5R('!R;V)L96US('=I=&@@
M2&]R9&4L(&AE;'`@:7,@879A:6QA8FQE(0H*5&AE($AO<F1E($9R97%U96YT
M;'D@07-K960@475E<W1I;VYS($QI<W0@*$9!42DL(&%V86EL86)L92!O;B!T
M:&4@5V5B(&%T"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+V9A<2\*"E1H92!(
M;W)D92!0<F]J96-T(')U;G,@82!N=6UB97(@;V8@;6%I;&EN9R!L:7-T<RP@
M9F]R(&EN9&EV:61U86P@87!P;&EC871I;VYS"F%N9"!F;W(@:7-S=65S(')E
M;&%T:6YG('1O('1H92!P<F]J96-T(&%S(&$@=VAO;&4N($EN9F]R;6%T:6]N
M+"!A<F-H:79E<RP@86YD"G-U8G-C<FEP=&EO;B!I;F9O<FUA=&EO;B!C86X@
M8F4@9F]U;F0@870*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O;6%I;"\*"D9I
M;F%L;'DL($AO<F1E(&1E=F5L;W!E<G,L(&-O;G1R:6)U=&]R<R!A;F0@=7-E
M<G,@86QS;R!M86ME(&]C8V%S:6]N86P*87!P96%R86YC97,@;VX@25)#+"!O
M;B!T:&4@8VAA;FYE;"`C:&]R9&4@;VX@=&AE(&9R965N;V1E($YE='=O<FL*
M*&ER8RYF<F5E;F]D92YN970I+@H*4&QE87-E(&ME97`@:6X@;6EN9"!T:&%T
M($AO<F1E(&ES(&9R964@<V]F='=A<F4@=W)I='1E;B!B>2!V;VQU;G1E97)S
M+@I&;W(@:6YF;W)M871I;VX@;VX@<F5A<V]N86)L92!S=7!P;W)T(&5X<&5C
M=&%T:6]N<RP@<&QE87-E(')E860*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M<W5P<&]R="YP:'`*"E1H86YK<R!F;W(@=7-I;F<@2&]R9&4A"@I4:&4@2&]R
M9&4@5&5A;0H*"BXN(%]214%$344Z(#]F/5)%041-12YH=&UL"BXN(%]D;V-S
M+TA!0TM)3D<Z(#]F/4A!0TM)3D<N:'1M;`HN+B!?9&]C<R]314-54DE463H@
M/V8]4T5#55))5%DN:'1M;`HN+B!?8&AO<F1E+V1O8W,O5%)!3E-,051)3TY3
M8#H@/V8]5%)!3E-,051)3TY3+FAT;6P*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O9&]C<R]015)&3U)-04Y#10``````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q-3$S,@`Q,#4Q-30S,3`U-P`P,3<P,S``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@4&5R9F]R;6%N8V4@1W5I9&4*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$
M871E.B`R,#`V+S`U+S,Q(#$Y.C$T.C$T("0*.E)E=FES:6]N.B`@("`@("12
M979I<VEO;CH@,2XY+C$P+C$S("0*.D-O;G1A8W0Z("`@("`@(&AO<F1E0&QI
M<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z.B!#;VYT96YT<PH*"E-O;64@
M=&EP<R!O;B!P97)F;W)M86YC92!T=6YI;F<@<WES=&5M<R!F;W(@2&]R9&4N
M("!4:&ES(&1O97,@;F]T(&-O=F5R"FAA<F1W87)E('1U;FEN9R!O<B!E=F5N
M(&QO=R!L979E;"!S>7-T96T@*&YE='=O<FLL(&9I;&5S>7-T96TL(&5T8RD@
M='5N:6YG+@H*1&]N)W0@87!P;'D@=&AE(&9O;&QO=VEN9R!T=6YI;F<@:&EN
M=',@8FQI;F1L>2X@(%1E<W0@>6]U<B!A<'!L:6-A=&EO;G,@8F5F;W)E"F%N
M9"!A9G1E<B!T:&4@8VAA;F=E<R!U;F1E<B!T:&4@8V]N9&ET:6]N<R!T:&%T
M(&%R92!I;7!O<G1A;G0@9F]R('EO=2X@($9O<@IS;VUE('!E;W!L92!I="=S
M(&UO<F4@:6UP;W)T86YT('1O(&UA:V4@=&AE;2!A<R!F87-T(&%S('!O<W-I
M8FQE(&9O<B!A('-M86QL"G5S97(@8F%S92P@;W1H97)S(')E<75I<F4@=&AE
M(&%P<&QI8V%T:6]N<R!T;R!S8V%L92!W96QL('5N9&5R(&$@:&EG:"!L;V%D
M+@I3;VUE(&]F('1H97-E(&AI;G1S(&UI9VAT(&5V96X@;6%K92!T:&4@87!P
M;&EC871I;VYS('-L;W=E<B!U;F1E<B!C97)T86EN"F-O;F1I=&EO;G,@;W(@
M=7-I;F<@82!C97)T86EN(&AA<F1W87)E+@H*"DQI;G5X(%1U;FEN9PH]/3T]
M/3T]/3T]/3T*"BH@4F5C;VUP:6QE(%)035,@9F]R('EO=7(@87)C:&ET96-T
M=7)E("AE+F<N(&DU.#8L(&DV.#8L(&%T:&QO;BP@971C*2X*("!4:&ES(&%P
M<&QI97,@;6]S="!T;R!Y;W5R($%P86-H92P@4$A0+"!)34%0+"!A;F0@4$]0
M,R!P86-K86=E<RX*"@I!<&%C:&4O4$A0('1U;FEN9PH]/3T]/3T]/3T]/3T]
M/3T]/0H**B!#;VYS:61E<B!A(%!(4"!A8V-E;&5R871O<B!P<F]G<F%M+B`@
M4V5E(&9O<B!E>&%M<&QE(&!4:&4@6F5N9"!097)F;W)M86YC90H@(%-U:71E
M8%\L(%1H92!@:6]N0W5B92!02%`@06-C96QE<F%T;W)@7RP@8%1U<F-K($U-
M0V%C:&4@9F]R(%!(4&!?+"!O<@H@(&5!8V-E;&5R871O<E\N("!4:&5S92!A
M8V-E;&5R871O<G,@<W!E960@=7`@86-C97-S(&)Y(&-A8VAI;F<@=&AE(&-O
M;7!I;&5D"B`@4$A0(&-O9&4L(&5L:6UI;F%T:6YG('1H92!N965D('1O(')E
M8V]M<&EL92!T:&4@8V]D92!F;W(@979E<GD@<VEN9VQE('!A9V4*("!L;V%D
M+B`@*BI4:&ES(&ES('!R;V)A8FQY('1H92!E87-I97-T('=A>2!T;R!I;7!R
M;W9E('1H92!P97)F;W)M86YC92!O9@H@($AO<F1E*BHN("!)9B!U<VEN9R!4
M=7)C:R!-34-A8VAE+"`J*E!,14%312HJ(')E860@8%1U<F-K($U-0V%C:&4*
M("!4<F]U8FQE<VAO;W1I;F=@7RX*"BH@0V]M<&EL92!02%`@=VET:"!T:&4@
M8&`M+65N86)L92UI;FQI;F4M;W!T:6UI>F%T:6]N8&`@;W!T:6]N('1O(&=E
M;F5R871E('1H90H@(&9A<W1E<W0@<&]S<VEB;&4@4$A0(&5X96-U=&%B;&4N
M"@HJ(%5S92!O9B!T:&4@;6-R>7!T(%!(4"!E>'1E;G-I;VX@<VAO=6QD('-I
M9VYI9FEC86YT;'D@:6YC<F5A<V4@<&5R9F]R;6%N8V4*("!W:&EL92!A;'-O
M(&EN8W)E87-I;F<@<V5C=7)I='DN"@HJ($5N86)L92!02%`@;W5T<'5T(&-O
M;7!R97-S:6]N("AE:71H97(@:6X@8&!P:'`N:6YI8&`@;W(*("!@8&AO<F1E
M+V-O;F9I9R]C;VYF+G!H<&!@*2X*"BH@1&ES86)L92!T:&4@;65M;W)Y(&QI
M;6ET(&EN(&!@<&AP+FEN:6!@+@H**B!+965P('1H92!I;F-L=61E('!A=&@@
M9&5F:6YE9"!I;B!@8'!H<"YI;FE@8"!A<R!S:&]R="!A<R!P;W-S:6)L92P@
M=VET:"!T:&4*("!M;W-T(&9R97%U96YT;'D@=7-E9"!L:6)R87)Y('!A=&AS
M(&9I<G-T+B`@66]U(&1O;B=T(&YE960@=&\@:6YC;'5D92!T:&4*("!L;V-A
M;"!D:7)E8W1O<GD@8&`N8&`@8F5C875S92!(;W)D92!A;'=A>7,@=7-E<R!F
M=6QL('!A=&AS(&EN<W1E860@;V8*("!R96QA=&EV92!P871H<RX*"BH@57-E
M(&%N(&]P=&EM:7IE9"!@8'!H<"YI;FE@8"P@<W1A<G0@9G)O;2!@8'!H<"YI
M;FDM<F5C;VUM96YD961@8"!O9B!Y;W5R(%!(4`H@(&1S:71R:6)U=&EO;BX*
M"BH@1&]N)W0@<G5N(%!(4"!S97-S:6]N(&=A<F)A9V4@8V]L;&5C=&EO;B!T
M;V\@;V9T96X@:68@=7-I;F<@82!S;&]W('-T;W)A9V4*("!M961I=6T@*&QI
M:V4@4U%,*2X@*%-E92!@8'-E<W-I;VXN9V-?<')O8F%B:6QI='E@8"!I;B!@
M8'!H<"YI;FE@8"D*"BH@268@>6]U(&AA=F4@82!L87)G92!N=6UB97(@;V8@
M<V5S<VEO;G,L(&-O;G-I9&5R('-T;W)I;F<@=&AE;2!I;B!H87-H960*("!D
M:7)E8W1O<GD@;&5V96QS+B`H4V5E(&!@<V5S<VEO;BYS879E7W!A=&A@8"!A
M="!H='1P.B\O=W=W+G!H<"YN970O<V5S<VEO;BD*"BH@0V]N<VED97(@=7-I
M;F<@82!F87-T97(@<W1O<F%G92!M961I=6T@9F]R('-E<W-I;VYS+"!S=6-H
M(&%S(&$@=&UP9G,@;W(*("!O=&AE<B!M96UO<GD@8F%S960@9FEL92!S>7-T
M96TN("!)9B!Y;W4@87)E('-U<F4@>6]U<B!A<&%C:&4@<V5T=7`@:7,@<F]C
M:PH@('-O;&ED(&%N9"!Y;W4@9&]N)W0@<F5S=&%R="!I="!T:&5R92!I<R!A
M(&UM('-E<W-I;VX@9')I=F5R+B`@2&]W979E<BP@8F4*("!A=V%R92!T:&%T
M(&-E<G1A:6X@2&]R9&4@87!P;&EC871I;VYS("AL:6ME($E-4"D@;6%K92!H
M96%V>2!U<V4@;V8@8V%C:&EN9PH@(&1A=&$@:6X@<V5S<VEO;G,@<V\@;65M
M;W)Y(&)A<V5D('-O;'5T:6]N<R!M87D@8F4@97AH875S=&5D('%U:6-K;'DL
M"B`@<&%R=&EC=6QA<FQY(&EF('1H97)E('=I;&P@8F4@;6]R92!T:&%N(&$@
M<VEN9VQE('5S97(N"@HJ($]N;'D@;&]A9"!A<R!M86YY($%P86-H92!A;F0@
M4$A0(&5X=&5N<VEO;G,@87,@;F5E9&5D("AT;R!R961U8V4@;65M;W)Y"B`@
M=7-A9V4I+@H**B!5<V4@<W1A=&EC86QL>2!C;VUP:6QE9"!!<&%C:&4@;6]D
M=6QE<RP@:6YC;'5D:6YG('1H92!02%`@;6]D=6QE+@H**B!5<V4@8V]M<&EL
M97(@;W!T:6UI>F%T:6]N<R`H+2UP<F5F97(M;F]N+7!I8RP@+4\S+"`M;6%R
M8V@@+6UC<'4L("UM<W-E+`H@("UM;6UX+"`M;69P;6%T:#US<V4L(&5T8RXI
M"@HJ($EF('5S:6YG(%-33"!W:71H(&$@;&%R9V4@<VET92P@8V]N<VED97(@
M82!H87)D=V%R92!34TP@86-C96QE<F%T;W(N"@HJ(%5S92!S:&%R960@;65M
M;W)Y(&9O<B!T:&4@07!A8VAE(%-33"!C86-H92!I9B!P;W-S:6)L92X*"BH@
M5&\@:6UP<F]V92!C86-H:6YG(&]F('-T871I8R!C;VYT96YT(&EF(&%C8V5S
M<VEN9R!!<&%C:&4@4U-,('=I=&@@26YT97)N970*("!%>'!L;W)E<BP@=')Y
M('-E='1I;F<@;&]N9V5R(&5X<&ER871I;VX@<&5R:6]D<SHZ"@H@("`@17AP
M:7)E<T%C=&EV92!/;@H@("`@17AP:7)E<T)Y5'EP92!I;6%G92]P;F<@(FYO
M=R!P;'5S(#$@;6]N=&@B"B`@("!%>'!I<F5S0GE4>7!E(&EM86=E+V=I9B`B
M;F]W('!L=7,@,2!M;VYT:"(*("`@($5X<&ER97-">51Y<&4@=&5X="]J879A
M<V-R:7!T(")N;W<@<&QU<R`Q(&UO;G1H(@H@("`@17AP:7)E<T)Y5'EP92!A
M<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0@(FYO=R!P;'5S(#$@;6]N=&@B"B`@
M("!%>'!I<F5S0GE4>7!E('1E>'0O8W-S(")N;W<@<&QU<R`Q(&UO;G1H(@H*
M("`N+B!.;W1E.CH@66]U(&UU<W0@8V]M<&EL92!T:&4@8&!M;V1?97AP:7)E
M<V!@(&5X=&5N<VEO;B!I;G1O($%P86-H92!I;@H@("`@("`@("`@("!O<F1E
M<B!T;R!U<V4@=&AE<V4@9&ER96-T:79E<RX*"B`@+BX@5V%R;FEN9SHZ(%1H
M:7,@;6EG:'0@8V%U<V4@<')O8FQE;7,@:68@>6]U('5P9W)A9&4@2&]R9&4@
M86YD('1H92!U<V5R<R<*("`@("`@("`@("`@("`@8G)O=W-E<G,@<W1I;&P@
M=7-E('1H92!O;&0@9FEL92!V97)S:6]N<RX*"BH@1&ES86)L92!$3E,@;&]O
M:W5P<R!I;B!Y;W5R($%P86-H92!L;V=G:6YG+"!O<B!U<V4@82!C86-H:6YG
M($1.4R!S97)V97(@;VX*("!T:&4@=V5B('-E<G9E<B!H;W-T+@H**B!%;F%B
M;&4@07!A8VAE(&ME97!A;&EV97,N"@HN+B!?8%1H92!:96YD(%!E<F9O<FUA
M;F-E(%-U:71E8#H@:'1T<#HO+W=W=RYZ96YD+F-O;2]H;W)D92YP:'`*+BX@
M7V!I;VY#=6)E(%!(4"!!8V-E;&5R871O<F`Z(&AT='`Z+R]W=W<N<&AP+6%C
M8V5L97)A=&]R+F-O+G5K"BXN(%]@5'5R8VL@34U#86-H92!F;W(@4$A08#H@
M:'1T<#HO+W1U<F-K+6UM8V%C:&4N<V]U<F-E9F]R9V4N;F5T"BXN(%]E06-C
M96QE<F%T;W(Z(&AT='`Z+R]E86-C96QE<F%T;W(N;F5T"BXN(%]@5'5R8VL@
M34U#86-H92!4<F]U8FQE<VAO;W1I;F=@.B!H='1P.B\O=VEK:2YH;W)D92YO
M<F<O5'5R8VM-34-A8VAE5')O=6)L97-H;V]T:6YG"@H*4V5N9&EN9R!-86EL
M"CT]/3T]/3T]/3T]/0H**B!'96YE<F%L;'D@=7-I;F<@82!L;V-A;"!S96YD
M;6%I;"!C;VUM86YD('1O('-E;F0@;6%I;"!W:6QL(')E<W5L="!I;B!B971T
M97(*("!P969O<FUA;F-E('1H86X@=7-I;F<@82!33510(&-O;FYE8W1I;VXN
M"@HJ(%-O;64@351!('-E<G9E<G,@;6%Y(&)E(&9A<W1E<B!O<B!M;W)E(&5F
M9FEC:65N="!T:&%N(&]T:&5R<RX@($-O;G-I9&5R"B`@<W=I=&-H:6YG('1O
M(&$@9F%S=&5R(&9O<FUA="!I9B!N965D960N"@H*24U!4"!T=6YI;F<*/3T]
M/3T]/3T]/3T*"BH@0V]N<VED97(@86X@24U!4"!P<F]X>2!F;W(@;6]R92!P
M97)S:7-T96YT(&-O;FYE8W1I;VYS+B`@4V]M92!)34%0('!R;WAI97,*("!A
M<F4@=7`M:6UA<'!R;WAY7R!A;F0@4&5R9&ET:6]N7RX@(%1O(&UA:V4@<V5N
M<V4L('1H92!P<F]X>0H@('-H;W5L9"!B92!I;G-T86QL960@;VX@=&AE('-E
M<G9E<B!R=6YN:6YG($AO<F1E+"!A;F0@=&AI<R!S97)V97(@;F5E9',*("!E
M;F]U9V@@0U!5('!O=V5R('1O(&AA;F1L92!T:&4@861D:71I;VYA;"!L;V%D
M+@H**B!3;VUE($E-05`@<V5R=F5R<R`H;W(@24U!4"!M86EL8F]X('-T;W)E
M(&9O<FUA=',I('!E<F9O<FT@8F5T=&5R('1H86X*("!O=&AE<G,N("!#;VYS
M:61E<B!S=VET8VAI;F<@=&\@82!F87-T97(@9F]R;6%T(&EF(&YE961E9"X*
M"BH@1F]L;&]W('1H92!)34%0('-E<G9E<G,G('!E<F9O<FUA;F-E(&AI;G1S
M.@H*("`M($-Y<G5S.B!H='1P.B\O87-G+G=E8BYC;74N961U+V-Y<G5S+V1O
M=VYL;V%D+VEM87!D+VEN<W1A;&PM<&5R9BYH=&UL"@HN+B!?=7`M:6UA<'!R
M;WAY.B!H='1P.B\O=W=W+FEM87!P<F]X>2YO<F<O"BXN(%]097)D:71I;VXZ
M(&AT='`Z+R]W=W<N=F5R9V5N970N;F5T+VQI;G5X+W!E<F1I=&EO;B\*"@I0
M;W-T9W)E<W%L('1U;FEN9PH]/3T]/3T]/3T]/3T]/3T]/0H**B!$;R!A('9A
M8W5U;2!C;VUM86YD('!E<FEO9&EC86QL>2!T;R!T=6YE('EO=7(@9&%T86)A
M<V4*"BH@26YC<F5A<V4@8&!S:&%R961?8G5F9F5R<V!@(&%N9"!@8'-O<G1?
M;65M8&`@;65M;W)Y('-E='1I;F=S+@H**B!)9B!W96(@<V5R=F5R(&%N9"!D
M871A8F%S92!I<R!O;B!T:&4@<V%M92!U;FEX(&AO<W0L('5S92!U;FEX('-O
M8VME=',*("!I;G-T96%D(&]F(&YE='=O<FL@8V]N;F5C=&EO;G,@9F]R(&1A
M=&%B87-E(&%C8V5S<RX*"@I->5-13"!T=6YI;F<*/3T]/3T]/3T]/3T]"@HJ
M($EF('=E8B!S97)V97(@86YD(&1A=&%B87-E(&ES(&]N('1H92!S86UE('5N
M:7@@:&]S="P@=7-E('5N:7@@<V]C:V5T<PH@(&EN<W1E860@;V8@;F5T=V]R
M:R!C;VYN96-T:6]N<R!F;W(@9&%T86)A<V4@86-C97-S+@H**B!%;F%B;&4@
M;7ES<6P@<75E<GD@8V%C:&4@:68@>6]U(&AA=F4@<W5F9FEC:65N="!204TN
M("!%9&ET('EO=7(@8&!M>2YC;F9@8`H@(&9I;&4@86YD(&%D9"!T:&4@9F]L
M;&]W:6YG('1O('1H92!@8%MM>7-Q;&1=8&`@<V5C=&EO;B`H8VAA;F=E('1H
M92!M96UO<GD*("!S:7IE('1O(&UE970@>6]U<B!N965D<RDZ.@H*("`@('-E
M="UV87)I86)L92`]('%U97)Y7V-A8VAE7W-I>F4],3(X30H*"DAO<F1E('1U
M;FEN9PH]/3T]/3T]/3T]/3T*"BH@66]U(&-A;B!C;VYF:6=U<F4@2&]R9&4@
M=&\@<V5R=F4@86QL(&EM86=E<R!A;F0@<W1Y;&4@<VAE971S(&9R;VT@80H@
M(&1I9F9E<F5N="!S97)V97(N(%1H:7,@8V]U;&0@8F4@82!V97)Y(&QI9VAT
M=V5I9VAT('-E<G9E<B!W:71H;W5T(&%L;"!T:&4*("!O=F5R:&5A9"!F;W(@
M<')O8V5S<VEN9R!02%`@9FEL97,L(&QI:V4@;&EG:'1T<&0N(%EO=2!N965D
M('1O('-E="!T:&4*("!@8'1H96UE<W5R:6!@('!A<F%M971E<B!I;B!@8&-O
M;F9I9R]R96=I<W1R>2YP:'!@8"!F;W(@86QL(&%P<&QI8V%T:6]N<R!A;F0*
M("!C;W!Y(&%L;"!@8'1H96UE<V!@(&1I<F5C=&]R:65S(&EN('1H92!S86UE
M(&1I<F5C=&]R>2!L87EO=70@=&\@=&AE(&]T:&5R"B`@<V5R=F5R+@H*+BX@
M7VQI9VAT='!D.B!H='1P.B\O=W=W+FQI9VAT='!D+FYE="\*"@I!<'!L:6-A
M=&EO;B!T=6YI;F<*/3T]/3T]/3T]/3T]/3T]/3T]"@HJ(%-O;64@87!P;&EC
M871I;VYS(&-O;G1A:6X@861V86YC960@9F5A='5R97,@=&AA="!M:6=H="!H
M879E(&$@8V5R=&%I;B!I;7!A8W0*("!O;B!T:&4@<&5R9F]R;6%N8V4N("!4
M:&5S92!F96%T=7)E<R!C86X@=7-U86QL>2!B92!T=7)N960@;V9F(&EN('1H
M90H@(&%P<&QI8V%T:6]N)W,@8V]N9FEG=7)A=&EO;B!A;F0@87)E(&5X<&QI
M8VET;'D@9&5S8W)I8F5D(&%S(&)E:6YG(&$*("!P97)F;W)M86YC92!H:70@
M:6X@=&AE(&-O;F9I9W5R871I;VX@=V5B(&9R;VYT96YD+@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]314-54DE4
M60``````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R-#0T-@`Q,#4Q-30S,3`U-P`P,38U-#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@2&]R9&4@4V5C=7)I='D@3F]T97,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`T+S`Y+S(V(#(S.C,S.C`W
M("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XY("0*.D-O;G1A8W0Z
M("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z.B!#
M;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@H*5&5M<&]R87)Y(&9I
M;&5S"CT]/3T]/3T]/3T]/3T]/0H*2&]R9&4@87!P;&EC871I;VYS(&UA:V4@
M97AT96YS:79E('5S92!O9B!T96UP;W)A<GD@9FEL97,N("!);B!O<F1E<B!T
M;R!M86ME"G-U<F4@=&AE<V4@9FEL97,@87)E('-E8W5R92P@>6]U('-H;W5L
M9"!M86ME('-U<F4@>6]U<B!I;G-T86QL871I;VX@;65E=',@=&AE"F9O;&QO
M=VEN9R!C<FET97)I82X*"E-I=&5S(&UA>2!G86EN(&EN8W)E87-E9"!S96-U
M<FET>2!B>2!D969I;FEN9R!A('1E;7!O<F%R>2!D:7)E8W1O<GD@:6X@=&AE
M"DAO<F1E(&-O;F9I9W5R871I;VX@=VAI8V@@:7,@=W)I=&%B;&4@8GD@=&AE
M('=E8B!S97)V97(L(&)U="!N;W0@=W)I=&%B;&4@8GD*;W1H97(@=7-E<G,N
M("!3:6YC92!T:&4@=&5M<&]R87)Y(&9I;&5S(&UA>2!C;VYT86EN('-E;G-I
M=&EV92!I;F9O<FUA=&EO;B!I=`II<R!B97-T('1O(&%L<V\@;6%K92!T:&5S
M92!F:6QE('5N<F5A9&%B;&4@8GD@;W1H97(@=7-E<G,N("!4:&%T(&ES+"!T
M:&5Y(&-A;@IB92!M861E(')E861A8FQE(&%N9"!W<FET86)L92!O;FQY(&)Y
M('1H92!W96(@<V5R=F5R('5S97(N"@H*4$A0(%-E<W-I;VYS"CT]/3T]/3T]
M/3T]/0H*1F]R('1H92!M;W-T('-E8W5R:71Y+"!Y;W4@<VAO=6QD(&5N86)L
M92!02%`@<V5S<VEO;B!C;V]K:65S(&)Y(&5N86)L:6YG('1H90IP:'`@<V5T
M=&EN9R!@8'-E<W-I;VXN=7-E7V-O;VMI97-@8"X@(%=H96X@9&]I;F<@<V\L
M(&)E('-U<F4@=&\@<V5T(&%N"F%P<')O<')I871E(&!@<V5S<VEO;BYC;V]K
M:65?<&%T:&!@(&%N9"!@8'-E<W-I;VXN8V]O:VEE7V1O;6%I;F!@(&%L<V\@
M=&\*<V5C=7)E('EO=7(@8V]O:VEE<RX*"DEF(%!(4"!S97-S:6]N<R!A<F4@
M<V5T('1O('5S92!T:&4@8&!F:6QE<V!@('-A=F5?:&%N9&QE<BP@=&AE;B!T
M:&5S92!F:6QE<PIS:&]U;&0@8F4@<V5C=7)E9"!P<F]P97)L>2X@(%-I=&5S
M(&-A;B!I;F-R96%S92!S96-U<FET>2!B>2!S971T:6YG('1H92!P:'`*<V5T
M=&EN9R!@8'-E<W-I;VXN<V%V95]P871H8&`@=&\@82!D:7)E8W1O<GD@=&AA
M="!I<R!O;FQY(')E861A8FQE(&%N9`IW<FET86)L92!B>2!T:&4@=V5B('-E
M<G9E<B!P<F]C97-S+@H*4VET97,@=VET:"!A(&QA<F=E('5S97(@8F%S92!S
M:&]U;&0@8V]N<VED97(@<V5T=&EN9R!T:&4*8&!S97-S:6]N+F5N=')O<'E?
M9FEL96!@(&%N9"!@8'-E<W-I;VXN96YT<F]P>5]L96YG=&A@8"!T;R!A<'!R
M;W!R:6%T92!V86QU97,N"@I(;W)D92!W:6QL(&5N8W)Y<'0@=&AE('5S97(@
M8W)E9&5N=&EA;',@8F5F;W)E('-T;W)I;F<@=&AE;2!I;B!T:&4@<V5S<VEO
M;BX*2&]W979E<BP@=&AI<R!E;F-R>7!T:6]N(&-A;B!B92!I;7!R;W9E9"!I
M9B!Y;W4@:&%V92!A;F0@96YA8FQE('1H92!P:'`*97AT96YS:6]N(")M8W)Y
M<'0B('=H:6-H(&%L;&]W<R!F;W(@<W1R;VYG97(@96YC<GEP=&EO;B!T:&%N
M(&ES(&]T:&5R=VES90IP<F]V:61E9"!B>2!(;W)D92X*"@I$969A=6QT(&1A
M=&%B87-E('!A<W-W;W)D<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M5&AE($AO<F1E(&1O8W5M96YT871I;VX@86YD('-A;7!L92!D871A8F%S92!C
M<F5A=&EO;B!S8W)I<'1S(&-R96%T92!A(&1E9F%U;'0*=7-E<B!A;F0@<&%S
M<W=O<F0@9F]R(&%C8V5S<VEN9R!T:&4@:&]R9&4@9&%T86)A<V4N("!5<VEN
M9R!T:&ES('!A<W-W;W)D(&EN(&$*<')O9'5C=&EO;B!E;G9I<F]N;65N="!I
M<R!A('-E8W5R:71Y(&AO;&4L('-I;F-E(&%N(&%T=&%C:V5R('=I;&P@96%S
M:6QY(&=U97-S"FET+@H*270@:7,@=F5R>2!I;7!O<G1A;G0@=&AA="!S:71E
M<R!C:&%N9V4@870@;&5A<W0@=&AE('!A<W-W;W)D('1O('-O;65T:&EN9PIS
M96-U<F4N"@H*4')E=F5N="!C;VYF:6=U<F%T:6]N(&9I;&4@<F5A9&EN9R!A
M;F0@=W)I=&EN9R`*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*5&AE(&-O;F9I9W5R871I;VX@9FEL97,@;6%Y(&-O
M;G1A:6X@<V5N<VET:79E(&1A=&$@*'-U8V@@87,@9&%T86)A<V4*<&%S<W=O
M<F1S*2!T:&%T('-H;W5L9"!N;W0@8F4@<F5A9"!O<B!W<FET=&5N(&)Y(&QO
M8V%L('-Y<W1E;2!U<V5R<R!O<B!R96UO=&4*=V5B('5S97)S+@H*268@>6]U
M('5S92!A(%5N:7@@<WES=&5M+"!O;F4@=V%Y('1O(&UA:V4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL97,@86YD"F1I<F5C=&]R:65S(&%C8V5S<VEB;&4@;VYL
M>2!T;R!T:&4@=V5B('-E<G9E<B!I<R!A<R!F;VQL;W=S+B`@2&5R92!W92!A
M<W-U;64*=&AA="!T:&4@=V5B('-E<G9E<B!R=6YS(&%S('1H92!U<V5R(&!@
M87!A8VAE8&`@86YD('1H92!F:6QE<R!A<F4@;&]C871E9"!I;@I@8"]H;VUE
M+VAT='!D+VAT;6Q@8"`M+2!S=6)S=&ET=71E('1H92!C;W)R96-T('5S97(@
M;W(@9FEL92!P871H(&EF(&YE961E9#HZ"@HD(&-H;W=N("U2(&%P86-H92`O
M:&]M92]H='1P9"]H=&UL+VAO<F1E+V-O;F9I9PHD(&-H;W=N("U2(&%P86-H
M92`O:&]M92]H='1P9"]H=&UL+VAO<F1E+RHO8V]N9FEG"B0@8VAM;V0@+5(@
M9V\M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O8V]N9FEG"B0@8VAM;V0@
M+5(@9V\M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O*B]C;VYF:6<*"D9O
M<B!C;VUP;&5T96QY(&9A<V-I<W0@<&5R;6ES<VEO;G,L('EO=2!C86X@;6%K
M92!T:&4@96YT:7)E($AO<F1E('1R964*:6YA8V-E<W-I8FQE(&)Y(&%N>6]N
M92!E>&-E<'0@=&AE('=E8B!S97)V97(@=7-E<B`H86YD(')O;W0I.CH*"B0@
M8VAO=VX@+5(@87!A8VAE("]H;VUE+VAT='!D+VAT;6PO:&]R9&4*)"!C:&UO
M9"`M4B!G;RUR=W@@("]H;VUE+VAT='!D+VAT;6PO:&]R9&4*)"!C:&UO9"`M
M4B!A+7<@("`O:&]M92]H='1P9"]H=&UL+VAO<F1E+PH*3F]T92!T:&%T('1H
M92!L87-T(&QI;F4@;6%K97,@86QL(&9I;&5S('5N=W)I=&%B;&4@8GD@86YY
M('5S97(@*&]N;'D@<F]O="!C86X*;W9E<G)I9&4@=&AI<RDN("!4:&ES(&UA
M:V5S('1H92!S:71E('-E8W5R92P@8G5T(&UA>2!M86ME(&ET(&UO<F4@9&EF
M9FEC=6QT('1O"F%D;6EN:7-T<F%T92X@($EN('!A<G1I8W5L87(L(&ET('=I
M;&P@9&5F96%T('1H92!(;W)D92!A9&UI;FES=')A=&EV90IC;VYF:6=U<F%T
M:6]N(&EN=&5R9F%C92P@9F]R8VEN9R!Y;W4@=&\@=7!D871E('1H92!(;W)D
M92!C;VYF:6=U<F%T:6]N(&9I;&5S"FUA;G5A;&QY("AA<R!P97(@=&AE($E.
M4U1!3$Q?(&EN<W1R=6-T:6]N<RDN"@I4:&4@86)O=F4@=VEL;"!N;W0@<V5C
M=7)E('1H92!F:6QE<R!I9B!O=&AE<B!U<V5R)W,@;VX@=&AE('-A;64@;6%C
M:&EN92!C86X*<G5N('-C<FEP=',@87,@=&AE(&%P86-H92!U<V5R+B`@268@
M>6]U(&YE960@=&\@<')O=&5C="!A9V%I;G-T('1H:7,@>6]U"G-H;W5L9"!M
M86ME(&]T:&5R('5S97(G<R!S8W)I<'1S(')U;B!U;F1E<B!T:&5I<B!O=VX@
M86-C;W5N="!W:71H('-O;64*9F%C:6QI='D@<W5C:"!A<R!A<&%C:&4G<R!S
M=65X96,@;6]D=6QE+B`@66]U(&YE960@=&\@=V%T8V@@;W5T(&YO="!O;FQY
M(&9O<@IC9VD@<V-R:7!T<RP@8G5T(&%L<V\@9F]R(&]T:&5R(&UO9'5L97,@
M;&EK92!M;V1?<&AP+"!M;V1?<&5R;"P@;6]D7W!Y=&AO;BP*971C+B!T:&%T
M(&UA>2!B92!I;B!U<V4@;VX@>6]U<B!S97)V97(N"@HN+B!?24Y35$%,3#H@
M/V8]24Y35$%,3"YH=&UL"@H*4F5S=')I8W1I;F<@=&5S="YP:'`@9FEL97,*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!@8'1E<W0N<&AP8&`@
M9FEL97,@<')O=FED92!A('=E86QT:"!O9B!I;F9O<FUA=&EO;B!T:&%T(&-A
M;B!B92!U<V5D"F%G86EN<W0@=&AE('-I=&4@8GD@871T86-K97)S+B`@3VYE
M('EO=2!H879E(&-O;F9I<FUE9"!T:&%T(&5V97)Y=&AI;F<@:7,*=V]R:VEN
M9RP@>6]U('-H;W5L9"!D:7-A8FQE(&%C8V5S<R!T;R!T:&4@=&5S="YP:'`@
M9FEL97,N("!9;W4@8V%N(&1O('1H:7,@=FEA"G1H92!W96(@<V5R=F5R+"!O
M<B!V:6$@<WES=&5M(&9I;&4@<&5R;6ES<VEO;G,N("!/;B!A('5N:7@@<WES
M=&5M+"!Y;W4@;6EG:'0*:7-S=64@82!C;VUM86YD('-U8V@@87,Z.@H*)"!C
M:&UO9"!A+7)W>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+W1E<W0N<&AP"B0@
M8VAM;V0@82UR=W@@+VAO;64O:'1T<&0O:'1M;"]H;W)D92\J+W1E<W0N<&AP
M"@H*4')E=F5N=&EN9R!!<&%C:&4@9G)O;2!S97)V:6YG(&-O;F9I9W5R871I
M;VX@86YD('-O=7)C92!F:6QE<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE($AO
M<F1E(&-O;F9I9W5R871I;VX@9FEL97,@;6%Y(&-O;G1A:6X@<V5N<VET:79E
M(&1A=&$@*'-U8V@@87,@9&%T86)A<V4*<&%S<W=O<F1S*2!T:&%T('-H;W5L
M9"!N;W0@8F4@<V5R=F5D(&)Y('1H92!W96(@<V5R=F5R+B!/=&AE<B!D:7)E
M8W1O<FEE<PIC;VYT86EN(%!(4"!S;W5R8V4@8V]D92!T:&%T(&ES;B=T(&EN
M=&5N9&5D(&9O<B!V:65W:6YG(&)Y(&5N9"UU<V5R<RX@5&AE"DAO<F1E(&=R
M;W5P(&AA<R!P<F]V:61E9"!@8"YH=&%C8V5S<V!@(&9I;&5S(&EN('9A<FEO
M=7,@9&ER96-T;W)I97,@=&\@:&5L<`IP<F]T96-T('1H97-E(&9I;&5S+B`@
M2&]W979E<BP@=&AA="!D97!E;F1S(&]N('EO=7(@=V5B('-E<G9E<B!H;VYO
M<FEN9PI@8"YH=&%C97-S8&`@9FEL97,@*'=H:6-H(&ES(&$@<&5R9F]R;6%N
M8V4@:&ET+"!A;F0@;6%Y(&YO="!B92!A=F%I;&%B;&4@:6X*86QL('=E8B!S
M97)V97)S*2X*"D%N($%P86-H92!S:71E(&-A;B!A;'-O('!R979E;G0@=&AE
M('=E8B!S97)V97(@9G)O;2!S97)V:6YG('1H97-E"F9I;&5S(&)Y(&%D9&EN
M9R!S96-T:6]N<R!T;R!@8&AT='!D+F-O;F9@8"!S=6-H(&%S('1H92!F;VQL
M;W=I;F<Z.@H*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D
M92]C;VYF:6<B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N
M>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO
M;64O:'1T<&0O:'1M;"]H;W)D92]L:6(B/@H@("`@("`@;W)D97(@9&5N>2QA
M;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@
M/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]L;V-A;&4B/@H@
M("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@
M("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M
M;"]H;W)D92]P;R(^"B`@("`@("!O<F1E<B!D96YY+&%L;&]W"B`@("`@("!D
M96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@("`\1&ER96-T;W)Y("(O
M:&]M92]H='1P9"]H=&UL+VAO<F1E+W-C<FEP=',B/@H@("`@("`@;W)D97(@
M9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R
M>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]T96UP
M;&%T97,B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F
M<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*"E)E<&5A="!T:&ES('!A='1E<FX@
M9F]R(&5A8V@@2&]R9&4@87!P;&EC871I;VXN("!&;W(@97AA;7!L92P@9F]R
M($E-4"!Y;W4*=V]U;&0@=&AE;B!A9&0Z.@H*("`@/$1I<F5C=&]R>2`B+VAO
M;64O:'1T<&0O:'1M;"]H;W)D92]I;7`O8V]N9FEG(CX*("`@("`@(&]R9&5R
M(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E8W1O
M<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O:6UP
M+VQI8B(^"B`@("`@("!O<F1E<B!D96YY+&%L;&]W"B`@("`@("!D96YY(&9R
M;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@("`\1&ER96-T;W)Y("(O:&]M92]H
M='1P9"]H=&UL+VAO<F1E+VEM<"]L;V-A;&4B/@H@("`@("`@;W)D97(@9&5N
M>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*
M("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]I;7`O<&\B
M/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L
M;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O
M:'1M;"]H;W)D92]I;7`O<V-R:7!T<R(^"B`@("`@("!O<F1E<B!D96YY+&%L
M;&]W"B`@("`@("!D96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@("`\
M1&ER96-T;W)Y("(O:&]M92]H='1P9"]H=&UL+VAO<F1E+VEM<"]T96UP;&%T
M97,B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M
M(&%L;`H@("`\+T1I<F5C=&]R>3X*"@I3971U<"!S8W)I<'1S"CT]/3T]/3T]
M/3T]/3T*"E1H97)E(&%R92!V87)I;W5S('-C<FEP=',@=7-E('1O('-E='5P
M(&]R(&-O;F9I9W5R92!(;W)D92X@($EF('EO=2!A;&QO=R!O=&AE<@IU<V5R
M<R!O;B!T:&4@=V5B('-E<G9E<B!M86-H:6YE+"!Y;W4@<VAO=6QD('!R;W1E
M8W0@=&AE<V4@9FEL97,@9G)O;2!B96EN9PIA8V-E<W-E9"!B>2!T:&5M+B`@
M3VX@82!U;FEX('-Y<W1E;2P@>6]U(&UI9VAT(')E<W1R:6-T('1H97-E(&9I
M;&5S('1O(')O;W0*86-C97-S(&)Y('5S:6YG('1H92!F;VQL;W=I;F<@='EP
M92!O9B!C;VUM86YD<SHZ"@HD(&-H;W=N("U2(')O;W0@+VAO;64O:'1T<&0O
M:'1M;"]H;W)D92]S8W)I<'1S"B0@8VAO=VX@+5(@<F]O="`O:&]M92]H='1P
M9"]H=&UL+VAO<F1E+RHO<V-R:7!T<PHD(&-H;6]D("U2(&=O+7)W>"`O:&]M
M92]H='1P9"]H=&UL+VAO<F1E+W-C<FEP=',*)"!C:&UO9"`M4B!G;RUR=W@@
M+VAO;64O:'1T<&0O:'1M;"]H;W)D92\J+W-C<FEP=',*"@I5<VEN9R!A(&-H
M<F]O="!W96(@<V5R=F5R('-E='5P"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"E5N:7@@=7-E<G,@;6%Y('=A;G0@=&\@8V]N<VED97(@=7-I
M;F<@82!C:')O;W0@96YV:7)O;FUE;G0@9F]R('1H96ER('=E8@IS97)V97(N
M("!(;W<@=&\@9&\@=&AI<R!I<R!B97EO;F0@=&AE('-C;W!E(&]F('1H:7,@
M9&]C=6UE;G0L(&)U="!S=69F:6-I96YT"FEN9F]R;6%T:6]N(&5X:7-T<R!O
M;B!T:&4@=V]R;&0@=VED92!W96(@86YD+V]R(&EN('EO=7(@<V5R=F5R(&1O
M8W5M96YT871I;VX*=&\@8V]M<&QE=&4@=&AI<R!T87-K+@H*"DAI9&EN9R!0
M2%`@:6YF;R!F<F]M('1H92!U<V5R"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"@I9;W4@<VAO=6QD(&-O;G-I9&5R('-E='1I;F<@=&AE(&9O;&QO
M=VEN9R!02%`@=F%R:6%B;&5S(&EN('EO=7(@8&!P:'`N:6YI8&`*9FEL92!T
M;R!P<F5V96YT(&EN9F]R;6%T:6]N(&QE86L@=&\@=&AE('5S97(L(&]R(&=L
M;V)A;"!I;G-E<G1I;VX@8GD@=&AE"G5S97(Z.@H*("`@97AP;W-E7W!H<"`]
M($]F9@H@("!D:7-P;&%Y7V5R<F]R<R`]($]F9@H@("!L;V=?97)R;W)S(#T@
M3VX*("`@<F5G:7-T97)?9VQO8F%L<R`]($]F9@H*66]U('-H;W5L9"!A;'-O
M('-E="!U<"!E<G)O<B!L;V=G:6YG("AU<VEN9R!T:&4@4$A0(&!@97)R;W)?
M;&]G8&`@=F%R:6%B;&4I"G1O(&QO9R!T;R!A(&9I;&4L('-Y<VQO9RP@;W(@
M;W1H97(@;&]G(&1E<W1I;F%T:6]N+@H*"E5S:6YG(&$@<V5C=7)E('=E8B!S
M97)V97(*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*2&]R9&4@9&5P96YD
M<R!O;B!P87-S:6YG('-E;G-I=&EV92!I;F9O<FUA=&EO;B`H<W5C:"!A<R!P
M87-S=V]R9',@86YD('-E<W-I;VX*:6YF;W)M871I;VXI(&)E='=E96X@=&AE
M('=E8B!S97)V97(@86YD('1H92!W96(@8VQI96YT+B`@57-I;F<@82!S96-U
M<F4**%-33"UE;F%B;&5D*2!W96(@<V5R=F5R('=I;&P@:&5L<"!P<F]T96-T
M('1H:7,@:6YF;W)M871I;VX@87,@:70@=')A=F5R<VEN9PIT:&4@;F5T=V]R
M:RX*"@I5<VEN9R!A('-E8W5R92!03U`S+TE-05`@<V5R=F5R"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DEF('EO=2!A<F4@=7-I;F<@82!0
M3U`S+TE-05`@<V5R=F5R('=I=&@@2&]R9&4@*&4N9RX@9F]R(&%U=&AE;G1I
M8V%T:6]N(&]R(&9O<@I)35`I('1H96X@2&]R9&4@:7,@<&%S<VEN9R!T:&4@
M=7-E<B=S(&QO9VEN(&-R961E;G1I86QS(&)E='=E96X@=&AE('=E8B!S97)V
M97(*86YD('1H92!M86EL('-E<G9E<BX*"DEF('EO=7(@=V5B('-E<G9E<B!A
M;F0@24U!4"!S97)V97(@87)E(&]N('1H92!S86UE(&AO<W0L('EO=2!C86X@
M:6YC<F5A<V4*<V5C=7)I='D@8GD@9F]R8VEN9R!A;&P@=')A9F9I8R!O=F5R
M('1H92!L;V]P8F%C:R!O<B!L;V-A;&AO<W0@:6YT97)F86-E('-O"G1H870@
M:70@:7,@;F]T(&5X<&]S960@=&\@>6]U<B!N971W;W)K+@H*26X@8V%S97,@
M=VAE<F4@=&AA="!I<R!N;W0@<&]S<VEB;&4L('=E(')E8V]M;65N9"!U<VEN
M9R!A('-E8W5R92!M86EL"F-O;FYE8W1I;VX@<W5C:"!A<R!)34%0+5-33"!O
M<B!03U`S+5-33"!T;R!E;G-U<F4@=&AA="!P87-S=V]R9',@<F5M86EN('-A
M9F4N"@H*3$1!4"!396-U<FET>0H]/3T]/3T]/3T]/3T]"@I,1$%0('-E8W5R
M:71Y(&ES('-I;6EL87(@=&\@=&AE(&%B;W9E(%!/4#,O24U!4"!S97)V97(@
M<V5C=7)I='D@:7-S=64N("!)9B!Y;W4*87)E('5S:6YG($Q$05`L('EO=2!S
M:&]U;&0@;6%K92!S=7)E('1H870@>6]U(&%R92!N;W0@97AP;W-I;F<@;&1A
M<"!P87-S=V]R9',*;W(@86YY('-E;G-I=&EV92!D871A(&EN('EO=7(@3$1!
M4"!D871A8F%S92X*"@I$871A8F%S92!S;V-K970@<V5C=7)I='D*/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W5R(&1A=&%B87-E("AE+F<N($UY
M4U%,(&]R(%!O<W1G<F5344PI(&ES(&]N('1H92!S86UE(&AO<W0@87,@>6]U
M<B!W96(*<V5R=F5R+"!Y;W4@;6%Y('5S92!U;FEX('-O8VME=',@<F%T:&5R
M('1H86X@=&-P(&-O;FYE8W1I;VYS('1O(&AE;'`@:6UP<F]V90IY;W5R('-E
M8W5R:71Y("AA;F0@<&5R9F]R;6%N8V4I+B`@268@:70@9&]E<VXG="!S=7!P
M;W)T('5N:7@@<V]C:V5T<RP@>6]U(&-A;@IA8VAI979E('-O;64@8F5T=&5R
M('-E8W5R:71Y(&)Y(')E<W1R:6-T:6YG('1H92!T8W`@<W5P<&]R="!T;R!T
M:&4@;&]O<&)A8VL@;W(*;&]C86QH;W-T(&EN=&5R9F%C92X*"DEF('1H92!D
M871A8F%S92!K965P<R!I=',@<V]C:V5T(&9I;&4@*&4N9RX@8&!M>7-Q;"YS
M;V-K8&`I(&EN(&$@9&ER96-T;W)Y"FQI:V4@8&`O=&UP8&`@;W(@8&`O=F%R
M+W1M<&!@+"!Y;W4@<VAO=6QD('-E="!P97)M:7-S:6]N<R!C87)E9G5L;'D@
M=&\@96YS=7)E"G1H870@;&]C86P@=7-E<G,@*&EF('EO=2!H879E(&%N>2D@
M8V%N)W0@9&5L971E('1H92!S;V-K970N("!4:&4@=6YI>"`B<W1I8VMY(@IB
M:70@<VAO=6QD(&%L<F5A9'D@8F4@<V5N="!O;B!T:&4@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!I='-E;&8L(&)U="!Y;W4@86QS;PIN965D('1O(&UA:V4@<W5R
M92!T:&4@<V]C:V5T(&ET<V5L9B!I<VXG="!W<FET86)L92!B>2`B;W1H97(B
M(&]R('5S97)S(&-A;@ID96QE=&4@:70N"@I9;W4@;6EG:'0@8V]N<VED97(@
M;6]V:6YG('1H92!S;V-K970@9FEL92!T;R!A;F]T:&5R(&QO8V%T:6]N('-U
M8V@@87,*8&`O=F%R+W)U;F!@(&]R('1H92!T;W`M;&5V96P@9&ER96-T;W)Y
M(&]F('EO=7(@9&%T86)A<V4@<')O9W)A;2`H92YG+@I@8"]V87(O;&EB+VUY
M<W%L8&`@;W(@8&`O=F%R+VQI8B]P9W-Q;&!@*2X*"@I396YD;6%I;"!O<B!3
M3510(&-O;G-I9&5R871I;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"DEN('-O;64@8V%S97,L('EO=2!C86X@:6YC<F5A<V4@<V5C=7)I
M='D@8GD@<V5N9&EN9R!M86EL('9I82!T:&4@;&]C86P*8V]M;6%N9"UL:6YE
M('-E;F1M86EL('!R;V=R86T@;VX@>6]U<B!W96(@<V5R=F5R+"!R871H97(@
M=&AA;B!U<VEN9R!33510+@I(;W=E=F5R+"!T:&5R92!M87D@8F4@<F5A<V]N
M<R!T;R!U<V4@4TU44"!I;G-T96%D+"!S=6-H(&%S(&EF('EO=7(@<VUT<"!S
M97)V97(*9&]E<R!S<&%M(&]R('9I<G5S(&-H96-K:6YG('=H:6-H('=O=6QD
M(&)E('-K:7!P960@=7-I;F<@=&AE(&QO8V%L('-E;F1M86EL"G!R;V=R86TN
M"@H*061D:71I;VYA;"!.;W1E<PH]/3T]/3T]/3T]/3T]/3T]"@I4:&ES(&ES
M(&)Y(&9A<B!N;W0@82!C;VUP;&5T92!S96-U<FET>2!(3U=43RX@5&AI<R!I
M<R!J=7-T(&$@8V]M<&EL960@;&ES="!O9@IW:&%T('!E;W!L92!H879E(&-O
M;G1R:6)U=&5D('-O(&9A<BX@268@>6]U(&AA=F4@=&EP<RP@:61E87,L('-U
M9V=E<W1I;VYS(&]R"F%N>71H:6YG(&5L<V4@=&AA="!Y;W4@=&AI;FL@8V]U
M;&0@:&5L<"!O=&AE<G,@:6X@<V5C=7)I;F<@=&AE:7(@2&]R9&4*:6YS=&%L
M;&%T:6]N+"!P;&5A<V4@;&5T('5S(&MN;W<N"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]D;V-S+U1/1$\`````````````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S-S(Q`#$P-3$U-#,Q,#4W`#`Q-C`S-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&5V96QO<&UE;G0@5$]$
M3R!,:7-T"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U
M<&1A=&4Z("`@)$1A=&4Z(#(P,#0O,3(O,3@@,3DZ-3<Z,S(@)`HZ4F5V:7-I
M;VXZ("`@("`@)%)E=FES:6]N.B`Q+C(W("0*.D-O;G1A8W0Z("`@("`@(&AO
M<F1E0&QI<W1S+FAO<F1E+F]R9PH*26X@;F\@<&%R=&EC=6QA<B!O<F1E<CH*
M"BT@*$]P=&EO;F%L;'DI($)U;F1L92!014%2('!A8VMA9V5S('=I=&@@=&AE
M('1A<F)A;&QS+B!':79E;B!A('!A8VMA9V4@;&ES="P*("!M86ME+7)E;&5A
M<V4N<&AP('-H;W5L9"!G970@=&AE('!A8VMA9V5S(&%N9"!U;G!A8VL@=&AE
M;2!I;G1O(&QI8B\@=VAE<F4@=V4*("!I;G-T86QL(&]U<B!O=VX@<&%C:V%G
M97,@86YY=V%Y+B!4;V=E=&AE<B!W:71H('!E87(N:&]R9&4N;W)G('1H:7,@
M<VAO=6QD"B`@;&5A9"!T;R`B;&ET92(@=&%R8F%L;',@;VYL>2!C;VYT86EN
M:6YG(&%P<&QI8V%T:6]N(&-O9&4@86YD(")F=6QL(B!T87)B86QL<PH@('1H
M870@9&]N)W0@;F5E9"!A;GD@97AT97)N86P@9&5P96YC96YC:65S(&%N>6UO
M<F4N"@HM(")B<F]W<V4B(&1R:79E<B!F;W(@5D93('1H870@=7-E<R!(;W)D
M92=S(&)R;W=S92!!4$DN"@HM($-A8VAE('1H92!296=I<W1R>2!O8FIE8W0@
M<V\@=&AA="!F:6QE(&]V97)H96%D(&]F(')E861I;F<@:6X@96YT<FEE<R!F
M<F]M(&$*("!D:7)E8W1O<GD@*')E9VES=')Y+F0I(&ES(&UI=&EG871E9"X*
M"BT@26UP;&5M96YT(&%D;6EN+V1E;&5T955S97(@;65T:&]D<R!I;B!A<'!L
M:6-A=&EO;G,G($%027,@=&\@9&5L971E('5S97(*("!S<&5C:69I8R!D871A
M+@H*+2!!9&0@82`O<V5R=FEC97,O9W)O=7!S+R!S96-T:6]N+B!);F-L=61E
M('!U8FQI8R!G<F]U<"!H;VUE<&%G97,L(&EN8VQU9&EN9PH@(&%N>2!I;F9O
M<FUA=&EO;B!M87)K960@<'5B;&EC(&9O<B!T:&4@9W)O=7`@*&QE="!T:&4@
M;65M8F5R<R!L:7-T(&)E(&UA<FME9`H@('!U8FQI8R]G<F]U<"!O;FQY+V%D
M;6EN(&]N;'DI+"!A9&0@9W)O=7`@861M:6YI<W1R871O<G,@*&IU<W0@82!F
M;&%G(&9O<@H@('5S97)S*2P@861D('1H92!A8FEL:71Y('1O('-H;W<@86QL
M(&-A;&5N9&%R<R]O=&AE<B!S:&%R97,@=&AA="!A(&=R;W5P(&AA<PH@('!E
M<FUI<W-I;VYS('1O+"!A;&QO=R!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B]P
M;VQL+V5T8RX@9F]R(&$@9W)O=7`N"@HM($%D9"!T:&4@86)I;&ET>2!T;R!B
M<F5A:R!O=70@1&%T851R964@9W)O=7!?=6ED<R!I;G1O('1H96ER(&]W;B!T
M86)L97,@*&]N90H@('1A8FQE('!E<B!G<F]U<"DN"@HM(%5S92!T:&4@9G)E
M961E<VMT;W`@<VAA<F5D+6UI;64M:6YF;U\@6$U,(&9I;&4@=&\@8G5I;&0@
M;W5R($U)345?36%G:6,@;6%G:6,*("!D871A(&9I;&5S+@H*+2!!9&0@<W5P
M<&]R="!F;W(@=&AE(%-232!A<'!L:6-A=&EO;B!S97)V97(@*&AT='`Z+R]W
M=W<N=FPM<W)M+FYE="\I+@H*+2!!9&0@54D@<W5P<&]R="!F;W(@;6]R92!C
M;VYF:6=U<F%T:6]N(&9I;&5S+@H*+2!3:6YC92!#;VYT96YT+41I<W!O<VET
M:6]N("A21D,@,C$X,RD@:7,@;F]T(&$@35535"!I;7!L96UE;G0L(&%L;&]W
M"B`@:6YD:79I9'5A;"!-24U%(%9I97=E<G,@=&\@86QL;W<@97AP;&EC:70@
M;W9E<G)I9&4@*&DN92X@=&\@875T;R!I;FQI;F4@"B`@9&ES<&QA>2!A('!A
M<G0@:6YS=&5A9"!O9B!R96YD97)I;F<@87,@86X@871T86-H;65N="`M('5S
M969U;"!F;W(@4R]-24U%"B`@96YC<GEP=&5D('!A<G1S+"!F;W(@97AA;7!L
M92DN"@HM(%-H;W<@<VAA<F5D('!R969E<F5N8V5S(&]N(&%L;"!P<F5F<R!S
M=6UM87)Y('-C<F5E;G,@=&\@;6%K92!I=`H@(&5A<VEE<B!F;W(@=7-E<B!T
M;R!F:6YD(&=L;V)A;"!P<F5F97)E;F-E<RX*"@HN+B!?<VAA<F5D+6UI;64M
M:6YF;SH@:'1T<#HO+W=W=RYF<F5E9&5S:W1O<"YO<F<O4V]F='=A<F4O<VAA
M<F5D+6UI;64M:6YF;PH`````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C
M<R]44D%.4TQ!5$E/3E,`````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,C4W,0`Q,#4Q-30S,3`U-P`P,3<R,30`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H@2&]R9&4@5')A;G-L871I;VX@1W5I9&4*/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R
M,#`U+S$P+S$X(#$Q.C,S.C,X("0*.E)E=FES:6]N.B`@("`@("12979I<VEO
M;CH@,2XX+C$P+C(@)`HZ075T:&]R.B`@("`@("`@2F]R:7,@0G)A86MM86X@
M/&IB<F%A:VUA;D!Y86AO;RYC;VT^"CI!=71H;W(Z("`@("`@("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*.D%U=&AO<CH@("`@("`@($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"CI#;VYT86-T.B`@("`@("!H
M;W)D94!L:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*
M"@I'3E4@9V5T=&5X="P@4$A0(&%N9"!(;W)D90H]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H*2&]R9&4@=7-E<R!'3E4@9V5T=&5X="!F;W(@:6YT97)N
M871I;VYA;&EZ871I;VX@*&DQ.&XI(&%N9"!L;V-A;&EZ871I;VX**&PQ,&XI
M+B`@5&AE(&UA;G5A;"!A="!H='1P.B\O=W=W+F=N=2YO<F<O;6%N=6%L+V=E
M='1E>'0O:6YD97@N:'1M;"!I<R!B:6%S960*86=A:6YS="!#(&%N9"!U<VEN
M9R!%;6%C<RX@(%1H:7,@:7,@;6]R92!F;W(@2&]R9&4N"@I4:&5R92!I<R!A
M(&=O;V0@97AP;&%N871I;VX@9F]R(%!(4"!A;F0@9V5T=&5X="!A=#H*:'1T
M<#HO+W=W=RYF87%T<RYC;VTO:VYO=VQE9&=E+6)A<V4O=FEE=RYP:'1M;"]A
M:60O,CDU,R]F:60O-#(R"@I096]P;&4@<V5E;2!T;R!L:6ME(&QE87)N:6YG
M(&9R;VT@97AA;7!L97,@8F5T=&5R+"!S;R!)(&AA=F4@=7-E9"!D=71C:`HH
M;FQ?3DPI(&%S(&%N(&5X86UP;&4@979E<GEW:&5R92X*"E1H97)E(&ES(&$@
M8V]M;6%N9"!L:6YE('1O;VP@=W)I='1E;B!I;B!02%`@9F]R(&-R96%T:6YG
M(&%N9"!M86YA9VEN9PIT<F%N<VQA=&EO;G,@:6X@=&AE(&!@:&]R9&4O<&\O
M8&`@9&ER96-T;W)Y+B`@57-A9V4@:6YS=')U8W1I;VYS(&-A;B!B92!F;W5N
M9`II;B!@8&AO<F1E+W!O+U)%041-16!@(&%S('=E;&P@87,@:6YS=')U8W1I
M;VYS(&]N(&AO=R!T;R!S=&%R="!A;F0@;6%I;G1A:6X*=')A;G-L871I;VYS
M+@H*"E1R86YS;&%T:6]N<R!D;VXG="!W;W)K"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"@I)9B!A;&P@;W(@<V]M92!T<F%N<VQA=&EO;G,@9&]N)W0@=V]R
M:R!O;B!Y;W5R('-Y<W1E;2P@<&QE87-E(&9O;&QO=R!T:&4@<W1E<',*9&5S
M8W)I8F5D(&)E;&]W+B`@268@>6]U('=A;G0@=&\@87-K(&9O<B!H96QP(&5I
M=&AE<B!O;B!T:&4@8&DQ.&X@;6%I;&EN9PIL:7-T8%\@;W(@;VX@8$AO<F1E
M)W,@8G5G('-Y<W1E;6!?+"!P;&5A<V4@97AP;&%I;B!W:&EC:"!S=&5P<R!Y
M;W4@=')I960@86YD"G=H:6-H(&9A:6QE9"X*"EEO=2!M:6=H="!A;'-O(&9I
M;F0@<V]M92!M;W)E(&EN9F]R;6%T:6]N(&EN('1H92!&05%?+@H*4&QE87-E
M(&YO=&4@=&AA="!$=71C:"`H;FQ?3DPI(&ES(&]N;'D@=7-E9"!A<R!A;B!E
M>&%M<&QE(&AE<F4N("!)9B!Y;W4@:&%V90IP<F]B;&5M<R!W:71H(&$@8V5R
M=&%I;B!T<F%N<VQA=&EO;B!U<V4@=&AI<R!T<F%N<VQA=&EO;B=S(&QA;F=U
M86=E(&-O9&4*:6YS=&5A9"X*"C$N($ES('1H:7,@;&]C86QE("AN;%].3"D@
M:6YS=&%L;&5D(&%T(&%L;#\*"B`@(&!@;&]C86QE("UA8&`@<VAO=6QD(&QI
M<W0@86QL(&QO8V%L97,@:6YS=&%L;&5D(&]N('EO=7(@<WES=&5M+@H*("`@
M3VX@1&5B:6%N(&YO="!A;&P@;&]C86QE<R!M87D@8F4@96YA8FQE9"!B>2!D
M969A=6QT+B`@161I=`H@("!@8"]E=&,O;&]C86QE+F=E;F!@(&%N9"!R=6X@
M8&!L;V-A;&4M9V5N8&`@:68@>6]U(&-H86YG960@=&AE(&QI<W0@;V8*("`@
M96YA8FQE9"!L;V-A;&5S+@H*,BX@1&\@>6]U(&AA=F4@86YY("YM;R!F:6QE
M<S\*"B`@(%5S=6%L;'D@:6X@8&`O=7-R+W-H87)E+VQO8V%L92]@8`H@("!E
M+F<N(&!@+W5S<B]S:&%R92]L;V-A;&4O;FPO3$-?34534T%'15,O=&%R+FUO
M8&`*"C,N($1O97,@9V5T=&5X="!E=F5N('=O<FL_"@H@("!'970@82!S=')I
M;F<@=&\@=')A;G-L871E.CH*"B`@("`@("0@<W1R:6YG<R`O8FEN+W1A<B!\
M(&=R97`@365M;W)Y"B`@("`@($UE;6]R>2!E>&AA=7-T960*("`@("`@)"`H
M3$%.1SUN;%].3#L@3$%.1U5!1T4];FQ?3DP[($Q#7TU%4U-!1T53/6YL7TY,
M.R!G971T97AT('1A<B`B365M;W)Y(&5X:&%U<W1E9"(@*0H@("`@("!'96AE
M=6=E;B!U:71G97!U=`H*-"X@1&]E<R!T:&4@;&]C86P@2&]R9&4@9FEL92!W
M;W)K/PH*("`@07-S=6UI;F<@=&AA="!Y;W4@:&%V92!P=70@=&AE('1R86YS
M;&%T960@2&]R9&4@9FEL92!I;@H@("!@8"]D871A+W=W=R]H;W)D92]L;V-A
M;&4O;FQ?3DPO3$-?34534T%'15,O:&]R9&4N;6]@8#HZ"@H@("`@("`D(&5X
M<&]R="!415A41$]-04E.1$E2/2]D871A+W=W=R]H;W)D92]L;V-A;&4*("`@
M("`@)"`H3$%.1SUN;%].3#L@3$%.1U5!1T4];FQ?3DP[($Q#7TU%4U-!1T53
M/6YL7TY,.R!G971T97AT(&AO<F1E(")-97-S86=E(B`I"B`@("`@($)E<FEC
M:'0*"B`@($-R96%T92!A(&9I;&4@:6X@=&AE(&AO<F1E(&1I<F5C=&]R>2P@
M;&%N9W1E<W0N<&AP.CH*"B`@("`@(#P_<&AP"@H@("`@("!S971L;V-A;&4H
M3$-?34534T%'15,L("=N;%].3"<I.PH@("`@("!P=71E;G8H)TQ!3D<];FQ?
M3DPG*3L*("`@("`@<'5T96YV*"=,04Y'54%'13UN;%].3"<I.PH@("`@("`O
M+R!U<V4@=&AE('1A<B!T97-T+@H@("`@("!E8VAO(&1G971T97AT*"=T87(G
M+"`G365M;W)Y(&5X:&%U<W1E9"<I.PH@("`@("!E8VAO("<\8G(@+SXG.PH*
M("`@("`@+R\@4W!E8VEF>2!L;V-A=&EO;B!O9B!T<F%N<VQA=&EO;B!T86)L
M97,*("`@("`@8FEN9'1E>'1D;VUA:6XH)VAO<F1E)RP@)RXO;&]C86QE)RD[
M"@H@("`@("`O+R!#:&]O<V4@9&]M86EN"B`@("`@('1E>'1D;VUA:6XH)VAO
M<F1E)RD["@H@("`@("`O+R!0<FEN="!T:&4@86QR96%D>2!T97-T960@;65S
M<V%G90H@("`@("!E8VAO(%\H(DUE<W-A9V4B*3L*("`@("`@96-H;R`G/&)R
M("\^)SL*"B`@("`@("\O('1H:7,@<VAO=6QD('!R:6YT('1H92!S86UE+@H@
M("`@("!E8VAO(&1G971T97AT*"=H;W)D92<L("=-97-S86=E)RD["@H@("`@
M("`_/@H*("`@3W5T<'5T('=E8B!B<F]W<V5R.CH*"B`@("`@($=E:&5U9V5N
M('5I=&=E<'5T"B`@("`@($)E<FEC:'0*("`@("`@0F5R:6-H=`H*"BXN(%]@
M:3$X;B!M86EL:6YG(&QI<W1@.B!H='1P.B\O:&]R9&4N;W)G+VUA:6PO"BXN
M(%]@2&]R9&4G<R!B=6<@<WES=&5M8#H@:'1T<#HO+V)U9W,N:&]R9&4N;W)G
M"BXN(%]&05$Z(&AT='`Z+R]H;W)D92YO<F<O9F%Q+PH*"E-O;&%R:7,*/3T]
M/3T]/0H*4VEN8V4@=&AE("YM;R!F:6QE<R!A<F4@8FEN87)Y+"!T:&5Y(&%R
M92!P;&%T9F]R;2!S<&5C:69I8RX@(%EO=2!H879E('1O(')E<G5N"FUA:V4@
M:6X@86QL('!O(&1I<F5C=&]R:65S+@H*3VX@4V]L87)I<R`W+"!Y;W4@9&]N
M)W0@:&%V92!T:&4@8&!087)T:6%L($QO8V%L97,@*%-53E=P;&]C*6!@(&%N
M9`I@8%-U<'!L96UE;G1A<GD@4&%R=&EA;"!,;V-A;&5S("A354Y7<&QO8S$I
M8&`@<&%C:V%G97,@:6YS=&%L;&5D(&EF('EO=2!G970Z.@H*("`@)"!,04Y'
M/6YL7TY,"B`@(&-O=6QD;B=T('-E="!L;V-A;&4@8V]R<F5C=&QY"@I/;B!3
M;VQA<FES(#@L('EO=2!M=7-T(&EN<W1A;&P@=&AE(&QO8V%L('!A8VMA9V5S
M(')E<75I<F5D(&9O<B!T:&4@;&]C86QE<R!Y;W4*9&5S:7)E("AF;W(@97AA
M;7!L92P@>6]U(&UA>2!N965D('1O(&EN<W1A;&P@8&!354Y7=V5U;W-@8"!F
M;W(@5V5S=&5R;@I%=7)O<&5A;B!L;V-A;&5S(&]R(&!@4U5.5VUE86]S8&`@
M9F]R($UI9&1L92!%87-T97)N(&QO8V%L97,I+B`@5&AE('!A8VMA9V5S"F%R
M92!L;V-A=&5D(&]N(%-O9G1W87)E($1I<VL@,2!O9B`R(&EN('1H92!D:7)E
M8W1O<GDZ"F!@<V]L7SA?,3`P,5]S<&%R8R]S,"]3;VQA<FES7S@O4')O9'5C
M=&!@"@I4:&ES(&ES('=H870@:70@<VAO=6QD('-A>3H*"E-O;&%R:7,@-SHZ
M"@H@("`D('!K9VEN9F\@?"!G<F5P('!L;V,*("`@<WES=&5M("`@("`@4U5.
M5W!L;V,@("`@("`@4&%R=&EA;"!,;V-A;&5S"B`@('-Y<W1E;2`@("`@(%-5
M3E=P;&]C,2`@("`@(%-U<'!L96UE;G1A<GD@4&%R=&EA;"!,;V-A;&5S"@I3
M;VQA<FES(#@Z.@H*("`@)"!P:V=I;F9O('P@9W)E<"!E=6\*("`@<WES=&5M
M("`@("`@4U5.5V-E=6]S("`@("`@0V5N=')A;"!%=7)O<&4@3U,@4W5P<&]R
M=`H@("!S>7-T96T@("`@("!354Y78V5U;W@@("`@("!#96YT<F%L($5U<F]P
M92`V-"UB:70@3U,@4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y7965U;W,@
M("`@("!%87-T97)N($5U<F]P92!/4R!3=7!P;W)T"B`@('-Y<W1E;2`@("`@
M(%-53E=E975O>"`@("`@($5A<W1E<FX@175R;W!E(#8T+6)I="!/4R!3=7!P
M;W)T"B`@('-Y<W1E;2`@("`@(%-53E=N975O<R`@("`@($YO<G1H97)N($5U
M<F]P92!/4R!3=7!P;W)T"B`@('-Y<W1E;2`@("`@(%-53E=N975O>"`@("`@
M($YO<G1H97)N($5U<F]P92`V-"UB:70@3U,@4W5P<&]R=`H@("!S>7-T96T@
M("`@("!354Y7<V5U;W,@("`@("!3;W5T:&5R;B!%=7)O<&4@3U,@4W5P<&]R
M=`H@("!S>7-T96T@("`@("!354Y7<V5U;W@@("`@("!3;W5T:&5R;B!%=7)O
M<&4@-C0M8FET($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@4U5.5W=E=6]S
M("`@("`@5V5S=&5R;B!%=7)O<&4@3U,@4W5P<&]R=`H@("!S>7-T96T@("`@
M("!354Y7=V5U;W@@("`@("!797-T97)N($5U<F]P92`V-"UB:70@3U,@4W5P
M<&]R=`H*5&AE('-T=69F(&ES(&EN<W1A;&QE9"!I;B!@8"]U<W(O;&EB+VQO
M8V%L96!@.CH*"B`@("0@;',@+W5S<B]L:6(O;&]C86QE+VYL"B`@($Q#7T-/
M3$Q!5$4@("!,0U]#5%E012`@("`@3$-?34534T%'15,@($Q#7TU/3D5405)9
M("!,0U].54U%4DE#("`@3$-?5$E-12`@("`@(&YL+G-O+C$*"DET('=A<R!R
M97!O<G1E9"!T:&%T('1H92!(5%10('-E<G9E<B!H87,@=&\@8F4@;&EN:V5D
M('1O('1H92!S86UE(&QI8FEN=&PN<V\*9FEL92!A<R!02%`@;VX@4V]L87)I
M<RX@($%L<V\L(&ET(&UA>2!B92!R97%U:7)E9"!T:&%T(&QI8FEN=&PN<V\@
M8F4@;&]A9&5D"F)E9F]R92!L:6)C(&ES(&QO861E9"X@($EF('EO=2!A<F4@
M:&%V:6YG(&-O;F9L:6-T<RP@>6]U(&UA>2!B92!A8FQE('1O(')E<VED90IT
M:&5M(&)Y('-T87)T:6YG(&%P86-H92!W:71H(&]N92!O9B!T:&4@9F]L;&]W
M:6YG(&-O;6UA;F1S.CH*"B`@("0@3$1?4%)%3$]!1#UL:6)I;G1L+G-O(&%P
M86-H96-T;"!S=&%R=`H*"D9R965"4T0*/3T]/3T]/0H*5&\@96YA8FQE(%54
M1BTX('-U<'!O<G0@:6X@2&]R9&4L('EO=2!A;'-O(&YE960@551&+3@@<W5P
M<&]R="!I;@I&<F5E0E-$+B`@5&AI<R!I<R!N;W0@:6YS=&%L;&5D(&)Y(&1E
M9F%U;'0L('EO=2!N965D('1O(&EN<W1A;&P@=&AE"F!@=71F.&QO8V%L92UW
M:71H;W5T+7-W:61T:"TP-#`S,3E@8"!P86-K86=E(&]R('!O<G0N"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]54$=2041)3D<`````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#,P-0`Q,#4Q
M-30S,3`U-P`P,38V,#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/3T]/3T]/3T]/3T]/3T]/3T*(%5P9W)A9&EN9R!(;W)D
M90H]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R
M,#`V+S`V+S(Y(#$V.C(Y.C`R("0*.E)E=FES:6]N.B`@("`@("12979I<VEO
M;CH@,2XT+C0N,3$@)`HZ0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES=',N:&]R
M9&4N;W)G"@H*5&AE<V4@87)E(&EN<W1R=6-T:6]N<R!T;R!U<&=R861E(&9R
M;VT@96%R;&EE<B!(;W)D92!V97)S:6]N<RX@4&QE87-E(&)A8VMU<`IY;W5R
M(&5X:7-T:6YG(&1A=&$@8F5F;W)E(')U;FYI;F<@86YY(&]F('1H92!S=&5P
M<R!D97-C<FEB960@8F5L;W<N(%EO=2!C86XG=`IU<V4@=&AE('5P9&%T960@
M9&%T82!W:71H('EO=7(@;VQD($AO<F1E('9E<G-I;VX@86YY;6]R92X*"D%F
M=&5R('5P9&%T:6YG('1O(&$@;F5W97(@2&]R9&4@=F5R<VEO;BP@;W(@82!N
M97=E<B!V97)S:6]N(&]F("HJ86YY*BH@2&]R9&4*87!P;&EC871I;VXL('EO
M=2`J*F%L=V%Y<RHJ(&YE960@=&\@=7!D871E("HJ86QL*BH@8V]N9FEG=7)A
M=&EO;B!F:6QE<RX*"@I5<&=R861I;F<@2&]R9&4@9G)O;2`S+C$N,2!T;R`S
M+C$N,@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*"E-E
M<W-I;VX@0V]N9FEG=7)A=&EO;@HM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"D$@
M;F5W(&-O;F9I9W5R871I;VX@<V5T=&EN9R!H87,@8F5E;B!A9&1E9"!T;R!D
M:7-A8FQE($=%5"UB87-E9`IS97-S:6]N<RX@($EF('1H:7,@<V5T=&EN9R!I
M<R!E;F%B;&5D+"!S97-S:6]N($E$<R!W:6QL(&]N;'D@8F4@<W1O<F5D"FEN
M('-E<W-I;VX@8V]O:VEE<RP@<F5Q=6ER:6YG('1H92!U<V5R<R!T;R!E;F%B
M;&4@8V]O:VEE<R!I;B!T:&5I<@IB<F]W<V5R(&%N9"!T:&4@8V]O:VEE('-E
M='1I;F=S(&EN($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!T;R!B92!C;W)R96-T
M+@H*57-I;F<@<V5S<VEO;B!C;V]K:65S(&ES(&UU8V@@<V%F97(@<VEN8V4@
M;F\@<V5S<VEO;B!I;F9O<FUA=&EO;B!C86X*8F4@<W1O<F5D(&EN(&%N>2!W
M96(@<V5R=F5R(&]R('!R;WAY(&QO9R!F:6QE<RP@<F5F97)R97(@:&5A9&5R
M<RP*8G)O=W-E<B!C86-H97,L(&]R(&)R;W=S97(@8F]O:VUA<FMS+@H*+BX@
M5V%R;FEN9SHZ(%1H:7,@<V5T=&EN9R!I;B!E;F%B;&5D(&)Y(&1E9F%U;'0N
M"@H*061D:71I;VYA;"!);F1E>&5S(&9O<B!T:&4@4')E9F5R96YC92!486)L
M90HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"@I/<'1I;VYA;&QY(&5X96-U=&4@=&AE('!R;W9I9&5D(%-13"!S8W)I<'0@
M,C`P-BTP-BTR.5]H;W)D95]P<F5F<U]I;F1E>&5S+G-Q;`IT;R!C<F5A=&4@
M='=O(&%D9&ET:6]N86P@:6YD97AE<R!I;B!T:&4@<')E9F5R96YC92!T86)L
M92P@92YG+CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D/3Q-
M>5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"!S8W)I<'1S+W5P9W)A
M9&5S+S(P,#8M,#8M,CE?:&]R9&5?<')E9G-?:6YD97AE<RYS<6P*"E1H:7,@
M:6YC<F5A<V5S(&1A=&%B87-E('!E<F9O<FUA;F-E(&9O<B!S;VUE(&1A=&%B
M87-E('-Y<W1E;7,L(&4N9RX@4&]S=&=R95-13`II9B!Y;W4@:&%V92!L87)G
M92!P<F5F97)E;F-E('1A8FQE<RX*"@I5<&=R861I;F<@2&]R9&4@9G)O;2`S
M+C$@=&\@,RXQ+C$*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"@H*37E344P@4V5S<VEO;B!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+2TM
M+0H*5&AE(&UY<W%L('-E<W-I;VX@:&%N9&QE<B!H87,@8F5E;B!I;7!R;W9E
M9"!T;R!C;W)R96-T;'D@;&]C:R!C;VYC=7)R96YT"F%C8V5S<V5S('1O('1H
M92!S86UE('-E<W-I;VXN(%EO=2!N965D('1O('-E="!I;B!T:&4@2&]R9&4@
M8V]N9FEG=7)A=&EO;B!I9@IY;W4@=V%N="!T;R!U<V4@<F]W+6QE=F5L(&QO
M8VMI;F<@86YD('1R86YS86-T:6]N<R!O<B!T86)L92UL979E;`IL;V-K:6YG
M+B!2;W<M;&5V96P@;&]C:VEN9R!A;F0@=')A;G-A8W1I;VYS(&%R92!O;FQY
M('-U<'!O<G1E9"!B>2!S;VUE('1A8FQE"F5N9VEN97,@;&EK92!);FYO1$(L
M(&%N9"!I<R!R96-O;6UE;F1E9"!F;W(@<V5S<VEO;B!T86)L97,N(%1H92!D
M969A=6QT('1A8FQE"G1Y<&4@9F]R($UY4U%,(&ES($UY25-!32!T:&]U9V@L
M('1H870@;VYL>2!S=7!P;W)T<R!T86)L92UL979E;"!L;V-K:6YG+B!)9@IY
M;W4@=7-E9"!T:&4@4U%,('-C<FEP=',@9G)O;2!(;W)D92`S+C$@;W(@96%R
M;&EE<B!T;R!C<F5A=&4@=&AE('-E<W-I;VX*=&%B;&4L('1H:7,@:7,@<')O
M8F%B;'D@=&AE(&-U<G)E;G0@96YG:6YE(&]F('EO=2!S97-S:6]N('1A8FQE
M+B!)9B!Y;W4@=V%N=`IT;R!C:&%N9V4@=&AE('1A8FQE('1Y<&4@=&\@26YN
M;T1"+"!E>&5C=71E('1H92!F;VQL;W=I;F<@4U%,('-T871E;65N=#HZ"@H@
M("!!3%1%4B!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B!%3D=)3D4@/2!)
M;FYO1$(*"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,RXP+G@@=&\@,RXQ+G@*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"@I344P@0F%C
M:V5N9',*+2TM+2TM+2TM+2TM"@I!(&9E=R!N97<@=&%B;&5S(&AA=F4@8F5E
M;B!A9&1E9"!T;R!(;W)D92X*"D5X96-U=&4@;VYE(&]F('1H92!P<F]V:61E
M9"!344P@<V-R:7!T<R!T;R!U<&1A=&4@>6]U<B!D871A('1O('1H92!N97<@
M2&]R9&4*=F5R<VEO;BP@92YG+CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O="`M
M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"!S
M8W)I<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N;7ES<6PN<W%L"@H*1W)O=7!S
M"BTM+2TM+0H*5&AE($AO<F1E7T=R;W5P($%022!U<V5S(&=R;W5P($E$<R!I
M;G-T96%D(&]F(&=R;W5P(&YA;65S('1O(&%V;VED(&%M8FEG=6ET>2X*0F4@
M<W5R92!T;R!U<&1A=&4@86YY(&-U<W1O;2!C;V1E('1H870@=7-E<R!(;W)D
M95]'<F]U<"X*"@I(:7-T;W)Y"BTM+2TM+2T*"E1H92!(;W)D95](:7-T;W)Y
M('-T;W)A9V4@:&%S(&)E96X@;6]V960@;W5T('1O(&$@<V5P87)A=&4@9&%T
M86)A<V4@=&%B;&4@=&\*9')A<W1I8V%L;'D@:6UP<F]V92!P97)F;W)M86YC
M92X*"BXN(%=A<FYI;F<Z.B!-:6=R871I;VX@;V8@=&AE($AO<F1E7TAI<W1O
M<GD@9&%T82!M87D@=&%K92!A('9E<GD@;&]N9R!T:6UE+`H@("`@("`@("`@
M("`@<&]S<VEB;'D@9&%Y<RP@9&5P96YD:6YG(&]N('1H92!N=6UB97(@;V8@
M96YT<FEE<RX@($)E('-U<F4@=&\*("`@("`@("`@("`@(&5X96-U=&4@=&AI
M<R!S8W)I<'0@9G)O;2!A(&QO8V%T:6]N('=H97)E(&ET('=I;&P@;F]T(&)E
M('1I;65D"B`@("`@("`@("`@("!O=70@8GD@9FER97=A;&P@;W(@=&5R;6EN
M86P@=&EM96]U=',N"@I%>&5C=71E('1H92!P<F]V:61E9"!02%`@<V-R:7!T
M('1O(&UI9W)A=&4@>6]U<B!H:7-T;W)I97,@=&\@=&AE(&YE=R!T86)L93HZ
M"@H@("!P:'`@<V-R:7!T<R]U<&=R861E<R]M;W9E7VAI<W1O<GE?;W5T7V]F
M7V1A=&%T<F5E+G!H<`H*"@I5<&=R861I;F<@2&]R9&4@9G)O;2`R+G@@=&\@
M,RXP+G@*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@H*0V]N
M9FEG=7)A=&EO;B!F:6QE<PHM+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE<R!H879E(&)E96X@8VAA;F=E9"!T;R!834P@9F]R
M;6%T+B`@5&\@9V5N97)A=&4@82!V86QI9`IC;VYF:6=U<F%T:6]N(&9I;&4@
M9G)O;2!T:&4@6$U,(&9I;&4L(&9O;&QO=R!T:&4@8V]N9FEG=7)A=&EO;B!I
M;G-T<G5C=&EO;G,*:6X@=&AE(&%P<&QI8V%T:6]N<R<@8&!D;V-S+TE.4U1!
M3$Q@8"!F:6QE+@H*"E!R969E<F5N8V5S"BTM+2TM+2TM+2TM"@I4:&4@8&!L
M87-T7VQO9VEN8&`@86YD(&!@9&%T95]F;W)M871@8"!P<F5F97)E;F-E<R!H
M879E(&-H86YG960@=&AE:7(@9F]R;6%T"F%N9"]O<B!S8V]P92X@($IU<W0@
M<F5M;W9E(&%L;"!@8&QA<W1?;&]G:6Y@8"!A;F0@8&!D871E7V9O<FUA=&!@
M('!R969E<F5N8V5S"F9R;VT@=&AE('!R969E<F5N8V5S(&)A8VME;F0N"@H*
M4U%,($)A8VME;F1S"BTM+2TM+2TM+2TM+0H*02!F97<@;F5W('1A8FQE<R!H
M879E(&)E96X@861D960@=&\@2&]R9&4N"@I%>&5C=71E('1H92!P<F]V:61E
M9"!344P@<V-R:7!T('1O('5P9&%T92!Y;W5R(&1A=&$@=&\@=&AE(&YE=R!(
M;W)D92!V97)S:6]N.CH*"B`@(&UY<W%L("TM=7-E<CUR;V]T("TM<&%S<W=O
M<F0]/$UY4U%,+7)O;W0M<&%S<W=O<F0^(#QD8B!N86UE/B`\('-C<FEP=',O
M=7!G<F%D97,O,BXR7W1O7S,N,"YM>7-Q;"YS<6P*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T97-T+G!H<```````````````````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,C,U`#$P-3$U-#,Q,#4W`#`Q
M-C$Q,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T97-T+G!H<"QV(#$N,3(R
M+C8N,3<@,C`P-B\P-B\Q,"`R,SHQ-CHU,2!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO
M<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@HO*B!296=I<W1E<B!A('-E<W-I;VXN("HO"G-E<W-I;VY?<W1A<G0H
M*3L*:68@*"%I<W-E="@D7U-%4U-)3TY;)VAO<F1E7W1E<W1?8V]U;G0G72DI
M('L*("`@("1?4T534TE/3ELG:&]R9&5?=&5S=%]C;W5N="==(#T@,#L*?0H*
M+RH@26YC;'5D92!(;W)D92=S(&-O<F4N<&AP(&9I;&4N("HO"FEN8VQU9&5?
M;VYC92`G;&EB+V-O<F4N<&AP)SL*"B\J(%=E('-H;W5L9"!H879E(&QO861E
M9"!T:&4@4W1R:6YG(&-L87-S+"!F<F]M('1H92!(;W)D95]5=&EL('!A8VMA
M9V4L(&EN"B`J(&-O<F4N<&AP+B!)9B!3=')I;F<Z.B!I<VXG="!D969I;F5D
M+"!T:&5N('=E)W)E(&YO="!F:6YD:6YG('-O;64@8W)I=&EC86P*("H@;&EB
M<F%R:65S+B`J+PII9B`H(6-L87-S7V5X:7-T<R@G4W1R:6YG)RDI('L*("`@
M(&5C:&\@)SQB<B`O/CQS<&%N('-T>6QE/2)C;VQO<CH@<F5D.R!F;VYT+7-I
M>F4Z(#$X<'@[(&9O;G0M=V5I9VAT.B!B;VQD.R(^5&AE($AO<F1E7U5T:6P@
M<&%C:V%G92!W87,@;F]T(&9O=6YD+B!)9B!02%!<)W,@97)R;W)?<F5P;W)T
M:6YG('-E='1I;F<@:7,@:&EG:"!E;F]U9V@L('1H97)E('-H;W5L9"!B92!E
M<G)O<B!M97-S86=E<R!P<FEN=&5D(&%B;W9E('1H870@;6%Y(&AE;'`@>6]U
M(&EN(&1E8G5G9VEN9R!T:&4@<')O8FQE;2X@268@>6]U(&%R92!S:6UP;'D@
M;6ES<VEN9R!T:&5S92!F:6QE<R!!3D0@87)E(&EN<W1A;&QI;F<@82!#5E,@
M8VAE8VMO=70L('1H96X@>6]U(&YE960@=&\@9V5T('1H92`\82!H<F5F/2)H
M='1P.B\O8W9S+FAO<F1E+F]R9R]C=G,N<&AP+V9R86UE=V]R:R(^9G)A;65W
M;W)K/"]A/B!M;V1U;&4@9G)O;2`\82!H<F5F/2)H='1P.B\O:&]R9&4N;W)G
M+W-O=7)C92\B/DAO<F1E($-64SPO83XL(&%N9"!I;G-T86QL('1H92!P86-K
M86=E<R!I;B!I="!W:71H('1H92!I;G-T86QL+7!A8VMA9V5S+G!H<"!S8W)I
M<'0N/"]S<&%N/B<["B`@("!E>&ET.PI]"@HO*B!);FET:6%L:7IE('1H92!(
M;W)D95]497-T.CH@8VQA<W,N("HO"FEF("@A:6YC;'5D95]O;F-E("=L:6(O
M5&5S="YP:'`G*2!["B`@("`O*B!4<GD@86YD('!R;W9I9&4@96YO=6=H(&EN
M9F]R;6%T:6]N('1O(&1E8G5G('1H92!M:7-S:6YG(&9I;&4N("HO"B`@("!E
M8VAO("<\8G(@+SX\<W!A;B!S='EL93TB8V]L;W(Z(')E9#L@9F]N="US:7IE
M.B`Q.'!X.R!F;VYT+7=E:6=H=#H@8F]L9#LB/E5N86)L92!T;R!F:6YD(&AO
M<F1E+VQI8B]497-T+G!H<"X@66]U<B!(;W)D92!I;G-T86QL871I;VX@;6%Y
M(&)E(&UI<W-I;F<@8W)I=&EC86P@9FEL97,L(&]R(%!(4"!M87D@;F]T(&AA
M=F4@<W5F9FEC:65N="!P97)M:7-S:6]N<R!T;R!I;F-L=61E(&9I;&5S+B!4
M:&5R92!M87D@8F4@97)R;W(@;65S<V%G97,@<')I;G1E9"!A8F]V92!T:&ES
M(&UE<W-A9V4@=&AA="!W:6QL(&AE;'`@>6]U(&EN(&1E8G5G9VEN9R!T:&4@
M<')O8FQE;2X\+W-P86X^)SL*("`@(&5X:70["GT*"B\J($EF('=E)W9E(&=O
M='1E;B!T:&ES(&9A<BP@=V4@<VAO=6QD(&AA=F4@9F]U;F0@96YO=6=H(&]F
M($AO<F1E('1O(')U;@H@*B!T97-T<RX@0W)E871E('1H92!T97-T:6YG(&]B
M:F5C="X@*B\*)&AO<F1E7W1E<W0@/2`F;F5W($AO<F1E7U1E<W0H*3L*"B\J
M($AO<F1E(&1E9FEN:71I;VYS+B`J+PHD;6]D=6QE(#T@)TAO<F1E)SL*<F5Q
M=6ER95]O;F-E("<N+VQI8B]V97)S:6]N+G!H<"<["B1M;V1U;&5?=F5R<VEO
M;B`]($A/4D1%7U9%4E-)3TX["@HO*B!02%`@;6]D=6QE(&-A<&%B:6QI=&EE
M<RX@*B\*)&UO9'5L95]L:7-T(#T@87)R87DH"B`@("`G8W1Y<&4G(#T^("=#
M='EP92!3=7!P;W)T)RP*("`@("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO
M;B@I+"`G-2<I(#P@,"`_("=D;VUX;6PG(#H@)V1O;2<I(#T^("=$3TT@6$U,
M(%-U<'!O<G0G+`H@("`@)V9T<"<@/3X@)T944"!3=7!P;W)T)RP*("`@("=G
M9"<@/3X@)T=$(%-U<'!O<G0G+`H@("`@)V=E='1E>'0G(#T^(&%R<F%Y*`H@
M("`@("`@("=D97-C<FEP)R`]/B`G1V5T=&5X="!3=7!P;W)T)RP*("`@("`@
M("`G97)R;W(G(#T^("=(;W)D92!W:6QL(&YO="!R=6X@=VET:&]U="!G971T
M97AT('-U<'!O<G0N($-O;7!I;&4@4$A0('=I=&@@/&-O9&4^+2UW:71H+6=E
M='1E>'0\+V-O9&4^(&)E9F]R92!C;VYT:6YU:6YG+B<L"B`@("`@("`@)V9A
M=&%L)R`]/B!T<G5E"B`@("`I+`H@("`@)VEC;VYV)R`]/B!A<G)A>2@*("`@
M("`@("`G9&5S8W)I<"<@/3X@)TEC;VYV(%-U<'!O<G0G+`H@("`@("`@("=E
M<G)O<B<@/3X@)TEF('EO=2!W86YT('1O('1A:V4@9G5L;"!A9'9A;G1A9V4@
M;V8@2&]R9&5<)W,@;&]C86QI>F%T:6]N(&9E871U<F5S(&%N9"!C:&%R86-T
M97(@<V5T('-U<'!O<G0L('EO=2!W:6QL(&YE960@=&AE(&EC;VYV(&5X=&5N
M<VEO;BXG"B`@("`I+`H@("`@)VEM87`G(#T^("=)34%0(%-U<'!O<G0G+`H@
M("`@)VQD87`G(#T^("=,1$%0(%-U<'!O<G0G+`H@("`@)VUB<W1R:6YG)R`]
M/B!A<G)A>2@*("`@("`@("`G9&5S8W)I<"<@/3X@)TUB<W1R:6YG(%-U<'!O
M<G0G+`H@("`@("`@("=E<G)O<B<@/3X@)TEF('EO=2!W86YT('1O('1A:V4@
M9G5L;"!A9'9A;G1A9V4@;V8@2&]R9&5<)W,@;&]C86QI>F%T:6]N(&9E871U
M<F5S(&%N9"!C:&%R86-T97(@<V5T('-U<'!O<G0L('EO=2!W:6QL(&YE960@
M=&AE(&UB<W1R:6YG(&5X=&5N<VEO;BXG"B`@("`I+`H@("`@)VUC<GEP="<@
M/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-8W)Y<'0@4W5P<&]R
M="<L"B`@("`@("`@)V5R<F]R)R`]/B`G36-R>7!T(&ES(&$@9V5N97)A;"UP
M=7)P;W-E(&-R>7!T;V=R87!H>2!L:6)R87)Y('=H:6-H(&ES(&)R;V%D97(@
M86YD('-I9VYI9FEC86YT;'D@;6]R92!E9F9I8VEE;G0@*$9!4U1%4B$I('1H
M86X@4$A07"=S(&]W;B!C<GEP=&]G<F%P:&EC(&-O9&4@86YD('=I;&P@<')O
M=FED97(@9F%S=&5R(&QO9VEN<RXG"B`@("`I+`H@("`@)V9I;&5I;F9O)R`]
M/B!A<G)A>2@*("`@("`@("`G9&5S8W)I<"<@/3X@)TU)344@36%G:6,@4W5P
M<&]R="`H9FEL96EN9F\I)RP*("`@("`@("`G97)R;W(G(#T^("=4:&4@9FEL
M96EN9F\@4$5#3"!M;V1U;&4@;W(@=&AE(&UI;65?;6%G:6,@4$A0(&5X=&5N
M<VEO;B`H<V5E(&)E;&]W*2!W:6QL(&UO<W0@;&EK96QY('!R;W9I9&4@9F%S
M=&5R($U)344@36%G:6,@;&]O:W5P<R!T:&%N('1H92!B=6EL="UI;B!(;W)D
M92!02%`@;6%G:6,@8V]D92X@4V5E(&AO<F1E+V1O8W,O24Y35$%,3"!F;W(@
M:6YF;W)M871I;VX@;VX@:&]W('1O(&EN<W1A;&P@4$5#3"]02%`@97AT96YS
M:6]N<RXG"B`@("`I+`H@("`@)VUE;6-A8VAE)R`]/B!A<G)A>2@*("`@("`@
M("`G9&5S8W)I<"<@/3X@)VUE;6-A8VAE9"!3=7!P;W)T("AM96UC86-H92DG
M+`H@("`@("`@("=E<G)O<B<@/3X@)U1H92!M96UC86-H92!014-,(&UO9'5L
M92!I<R!N965D960@;VYL>2!I9B!Y;W4@87)E('5S:6YG('1H92!M96UC86-H
M960@4V5S<VEO;DAA;F1L97(N(%-E92!H;W)D92]D;V-S+TE.4U1!3$P@9F]R
M(&EN9F]R;6%T:6]N(&]N(&AO=R!T;R!I;G-T86QL(%!%0TPO4$A0(&5X=&5N
M<VEO;G,N)PH@("`@*2P*("`@("=M:6UE7VUA9VEC)R`]/B!A<G)A>2@*("`@
M("`@("`G9&5S8W)I<"<@/3X@)TU)344@36%G:6,@4W5P<&]R="`H;6EM95]M
M86=I8RDG+`H@("`@("`@("=E<G)O<B<@/3X@)U1H92!F:6QE:6YF;R!014-,
M(&UO9'5L92`H<V5E(&%B;W9E*2!O<B!T:&4@;6EM95]M86=I8R!02%`@97AT
M96YS:6]N('=I;&P@;6]S="!L:6ME;'D@<')O=FED92!F87-T97(@34E-12!-
M86=I8R!L;V]K=7!S('1H86X@=&AE(&)U:6QT+6EN($AO<F1E(%!(4"!M86=I
M8R!C;V1E+B!3964@:&]R9&4O9&]C<R])3E-404Q,(&9O<B!I;F9O<FUA=&EO
M;B!O;B!H;W<@=&\@:6YS=&%L;"!014-,+U!(4"!E>'1E;G-I;VYS+B<*("`@
M("DL"B`@("`G;7ES<6PG(#T^("=->5-13"!3=7!P;W)T)RP*("`@("=O<&5N
M<W-L)R`]/B`G3W!E;E-33"!3=7!P;W)T)RP*("`@("=P9W-Q;"<@/3X@)U!O
M<W1G<F5344P@4W5P<&]R="<L"B`@("`G<V5S<VEO;B<@/3X@87)R87DH"B`@
M("`@("`@)V1E<V-R:7`G(#T^("=397-S:6]N(%-U<'!O<G0G+`H@("`@("`@
M("=F871A;"<@/3X@=')U92DL"B`@("`G>&UL)R`]/B`G6$U,(%-U<'!O<G0G
M+`H@("`@)WIL:6(G(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G
M6FQI8B!3=7!P;W)T)RP*("`@("`@("`G97)R;W(G(#T^("=4:&4@>FQI8B!M
M;V1U;&4@:7,@:&EG:&QY(')E8V]M;65N9&5D(&9O<B!U<V4@=VET:"!(;W)D
M92X@($ET(&%L;&]W<R!P86=E(&-O;7!R97-S:6]N(&%N9"!H86YD;&EN9R!O
M9B!:25`@86YD($=:(&1A=&$N($-O;7!I;&4@4$A0('=I=&@@/&-O9&4^+2UW
M:71H+7IL:6(\+V-O9&4^('1O(&%C=&EV871E+B<L"B`@("`@("`@)V9A=&%L
M)R`]/B!F86QS90H@("`@*2P**3L*"@HO*B!02%`@4V5T=&EN9W,N("HO"B1S
M971T:6YG7VQI<W0@/2!A<G)A>2@*("`@("=M86=I8U]Q=6]T97-?<G5N=&EM
M92<@/3X@87)R87DH"B`@("`@("`@)W-E='1I;F<G(#T^(&9A;'-E+`H@("`@
M("`@("=E<G)O<B<@/3X@)VUA9VEC7W%U;W1E<U]R=6YT:6UE(&UA>2!C875S
M92!P<F]B;&5M<R!W:71H(&1A=&%B87-E(&EN<V5R=',L(&5T8RX@5'5R;B!I
M="!O9F8N)PH@("`@*2P*("`@("=M96UO<GE?;&EM:70G(#T^(&%R<F%Y*`H@
M("`@("`@("=S971T:6YG)R`]/B!F86QS92P*("`@("`@("`G97)R;W(G(#T^
M("=)9B!02%!<)W,@:6YT97)N86P@;65M;W)Y(&QI;6ET(&ES('1U<FYE9"!O
M;B!A;F0@:68@;F]T('-E="!H:6=H(&5N;W5G:"!(;W)D92!W:6QL(&YO="!B
M92!A8FQE('1O(&AA;F1L92!L87)G92!D871A(&ET96US("AE+F<N(&QA<F=E
M(&UA:6P@871T86-H;65N=',@:6X@24U0*2X@268@<&]S<VEB;&4L('EO=2!S
M:&]U;&0@9&ES86)L92!T:&4@4$A0(&UE;6]R>2!L:6UI="!B>2!R96-O;7!I
M;&EN9R!02%`@/&5M/G=I=&AO=70\+V5M/B!T:&4@(BTM96YA8FQE+6UE;6]R
M>2UL:6UI="(@9FQA9RX@268@=&AI<R!I<R!N;W0@<&]S<VEB;&4L('1H96X@
M>6]U('-H;W5L9"!S970@=&AE('9A;'5E(&]F(&UE;6]R>5]L:6UI="!I;B!P
M:'`N:6YI('1O(&$@<W5F9FEC:65N=&QY(&AI9V@@=F%L=64@*$-U<G)E;G0@
M=F%L=64@;V8@;65M;W)Y7VQI;6ET.B`G("X@:6YI7V=E="@G;65M;W)Y7VQI
M;6ET)RD@+B`G*2XG"B`@("`I+`H@("`@)W-A9F5?;6]D92<@/3X@87)R87DH
M"B`@("`@("`@)W-E='1I;F<G(#T^(&9A;'-E+`H@("`@("`@("=E<G)O<B<@
M/3X@)TEF('-A9F5?;6]D92!I<R!E;F%B;&5D+"!(;W)D92!C86YN;W0@<V5T
M(&5N=FER;VUE;G0@=F%R:6%B;&5S+"!W:&EC:"!M96%N<R!(;W)D92!W:6QL
M(&)E('5N86)L92!T;R!T<F%N<VQA=&4@=&AE('5S97(@:6YT97)F86-E(&EN
M=&\@9&EF9F5R96YT(&QA;F=U86=E<RXG"B`@("`I+`H@("`@)W-E<W-I;VXN
M=7-E7W1R86YS7W-I9"<@/3X@87)R87DH"B`@("`@("`@)W-E='1I;F<G(#T^
M(&9A;'-E+`H@("`@("`@("=E<G)O<B<@/3X@)TAO<F1E('=I;&P@=V]R:R!W
M:71H('-E<W-I;VXN=7-E7W1R86YS7W-I9"!T=7)N960@;VXL(&)U="!Y;W4@
M;6%Y('-E92!D;W5B;&4@<V5S<VEO;BUI9',@:6X@>6]U<B!54DQS+"!A;F0@
M:68@=&AE('-E<W-I;VX@;F%M92!I;B!P:'`N:6YI(&1I9F9E<G,@9G)O;2!T
M:&4@<V5S<VEO;B!N86UE(&-O;F9I9W5R960@:6X@2&]R9&4L('EO=2!M87D@
M9V5T('1W;R!S97-S:6]N(&ED<R!A;F0@<V5E(&]T:&5R(&]D9"!B96AA=FEO
M<BX@5&AE(%523"UR97=R:71I;F<@=&AA="!U<V5?=')A;G-?<VED(&1O97,@
M86QS;R!T96YD<R!T;R!B<F5A:R!82%1-3"!C;VUP;&EA;F-E+B!);B!S:&]R
M="P@>6]U('-H;W5L9"!R96%L;'D@9&ES86)L92!T:&ES+B<*("`@("DL"B`@
M("`G<V5S<VEO;BYA=71O7W-T87)T)R`]/B!A<G)A>2@*("`@("`@("`G<V5T
M=&EN9R<@/3X@9F%L<V4L"B`@("`@("`@)V5R<F]R)R`]/B`G2&]R9&4@=V]N
M7"=T('=O<FL@=VET:"!A=71O;6%T:6-A;&QY('-T87)T960@<V5S<VEO;G,L
M(&)E8V%U<V4@:70@97AP;&EC:71L>2!C<F5A=&5S(&YE=R!S97-S:6]N('=H
M96X@;F5C97-S87)Y('1O('!R;W1E8W0@86=A:6YS="!S97-S:6]N(&9I>&%T
M:6]N<RXG"B`@("`I"BD["@H*+RH@4$5!4B`J+PHD<&5A<E]L:7-T(#T@87)R
M87DH"B`@("`G36%I;"<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=-
M86EL+U)&0S@R,BYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)UEO=2!D;R!N
M;W0@:&%V92!T:&4@36%I;"!P86-K86=E(&EN<W1A;&QE9"!O;B!Y;W5R('-Y
M<W1E;2X@4V5E('1H92!)3E-404Q,(&9I;&4@9F]R(&EN<W1R=6-T:6]N<R!O
M;B!H;W<@=&\@:6YS=&%L;"!T:&4@<&%C:V%G92XG"B`@("`I+`H@("`@)TUA
M:6Q?36EM92<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=-86EL+VUI
M;65$96-O9&4N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=9;W4@9&\@;F]T
M(&AA=F4@=&AE($UA:6Q?36EM92!P86-K86=E(&EN<W1A;&QE9"!O;B!Y;W5R
M('-Y<W1E;2X@4V5E('1H92!)3E-404Q,(&9I;&4@9F]R(&EN<W1R=6-T:6]N
M<R!O;B!H;W<@=&\@:6YS=&%L;"!T:&4@<&%C:V%G92XG+`H@("`@("`@("=R
M97%U:7)E9"<@/3X@=')U90H@("`@*2P*("`@("=,;V<G(#T^(&%R<F%Y*`H@
M("`@("`@("=P871H)R`]/B`G3&]G+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]
M/B`G36%K92!S=7)E('EO=2!A<F4@=7-I;F<@82!V97)S:6]N(&]F(%!%05(@
M=VAI8V@@:6YC;'5D97,@=&AE($QO9R!C;&%S<V5S+"!O<B!T:&%T('EO=2!H
M879E(&EN<W1A;&QE9"!T:&4@3&]G('!A8VMA9V4@<V5P97)A=&5L>2X@4V5E
M('1H92!)3E-404Q,(&9I;&4@9F]R(&EN<W1R=6-T:6]N<R!O;B!I;G-T86QL
M:6YG($QO9RXG+`H@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@
M("`G9G5N8W1I;VXG(#T^("=?8VAE8VM?<&5A<E]L;V=?=F5R<VEO;B<*("`@
M("DL"B`@("`G1$(G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G1$(N
M<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=9;W4@=VEL;"!N965D($1"(&EF
M('EO=2!A<F4@=7-I;F<@4U%,(&1R:79E<G,@9F]R('!R969E<F5N8V5S+"!C
M;VYT86-T<R`H5'5R8F$I+"!E=&,N)RP*("`@("`@("`G9G5N8W1I;VXG(#T^
M("=?8VAE8VM?<&5A<E]D8E]V97)S:6]N)PH@("`@*2P*("`@("=.971?4V]C
M:V5T)R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)TYE="]3;V-K970N
M<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=-86ME('-U<F4@>6]U(&%R92!U
M<VEN9R!A('9E<G-I;VX@;V8@4$5!4B!W:&EC:"!I;F-L=61E<R!T:&4@3F5T
M7U-O8VME="!C;&%S<RP@;W(@=&AA="!Y;W4@:&%V92!I;G-T86QL960@=&AE
M($YE=%]3;V-K970@<&%C:V%G92!S97!E<F%T96QY+B!3964@=&AE($E.4U1!
M3$P@9FEL92!F;W(@:6YS=')U8W1I;VYS(&]N(&EN<W1A;&QI;F<@3F5T7U-O
M8VME="XG"B`@("`I+`H@("`@)T1A=&4G(#T^(&%R<F%Y*`H@("`@("`@("=P
M871H)R`]/B`G1&%T92]#86QC+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G
M2&]R9&4@<F5Q=6ER97,@=&AE($1A=&5?0V%L8R!C;&%S<R!F;W(@2W)O;F]L
M:71H('1O(&-A;&-U;&%T92!D871E<RXG"B`@("`I+`H@("`@)T%U=&A?4T%3
M3"<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=!=71H+U-!4TPN<&AP
M)RP*("`@("`@("`G97)R;W(G(#T^("=(;W)D92!W:6QL('=O<FL@=VET:&]U
M="!T:&4@075T:%]305-,(&-L87-S+"!B=70@:68@>6]U('5S92!!8V-E<W,@
M0V]N=')O;"!,:7-T<R!I;B!)35`@>6]U('-H;W5L9"!B92!A=V%R92!T:&%T
M('=I=&AO=70@=&AI<R!C;&%S<R!P87-S=V]R9',@=VEL;"!B92!S96YT('1O
M('1H92!)34%0('-E<G9E<B!I;B!P;&%I;B!T97AT('=H96X@<F5T<FEE=FEN
M9R!!0TQS+B<*("`@("DL"B`@("`G2%144%]297%U97-T)R`]/B!A<G)A>2@*
M("`@("`@("`G<&%T:"<@/3X@)TA45%`O4F5Q=65S="YP:'`G+`H@("`@("`@
M("=E<G)O<B<@/3X@)U!A<G1S(&]F($AO<F1E("A(5$U,(&-O;7!O<VET:6]N
M(&EN($E-4"P@2F]N86@L('1H92!834PM4E!#(&-L:65N="]S97)V97(I('5S
M92!T:&4@2%144%]297%U97-T(&QI8G)A<GD@=&\@<F5T<FEE=F4@55),<R!A
M;F0@9&\@;W1H97(@2%144"!R97%U97-T<RXG"B`@("`I+`H@("`@)T9I;&4G
M(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G1FEL92YP:'`G+`H@("`@
M("`@("=E<G)O<B<@/3X@)TAO<F1E('=I;&P@<F5Q=6ER92!T:&4@1FEL92!C
M;&%S<R!W:&5N(&EM<&]R=&EN9R!#4U8@9FEL97,N)PH@("`@*2P*("`@("=.
M971?4TU44"<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=.970O4TU4
M4"YP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)TUA:V4@<W5R92!Y;W4@87)E
M('5S:6YG('1H92!.971?4TU44"!M;V1U;&4@:68@>6]U('=A;G0@(G-M='`B
M('1O('=O<FL@87,@82!M86EL97(@;W!T:6]N+B<*("`@("DL"B`@("`G4V5R
M=FEC97-?5V5A=&AE<B<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=3
M97)V:6-E<R]796%T:&5R+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G4V5R
M=FEC97-?5V5A=&AE<B!I<R!U<V5D(&)Y('1H92!W96%T:&5R(&%P<&QE="]B
M;&]C:R!O;B!T:&4@<&]R=&%L('!A9V4N)PH@("`@*2P*("`@("=#86-H92<@
M/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=#86-H92YP:'`G+`H@("`@
M("`@("=E<G)O<B<@/3X@)T-A8VAE(&ES('5S960@8GD@=&AE(%-E<G9I8V5S
M7U=E871H97(@;6]D=6QE(&]N('1H92!W96%T:&5R(&%P<&QE="]B;&]C:R!O
M;B!T:&4@<&]R=&%L('!A9V4N)PH@("`@*2P*("`@("=834Q?4V5R:6%L:7IE
M<B<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=834PO4V5R:6%L:7IE
M<BYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)UA-3%]397)I86QI>F5R(&ES
M('5S960@8GD@=&AE(%-E<G9I8V5S7U=E871H97(@;6]D=6QE(&]N('1H92!W
M96%T:&5R(&%P<&QE="]B;&]C:R!O;B!T:&4@<&]R=&%L('!A9V4N)PH@("`@
M*0HI.PH*+RH@061D:71I;VYA;"!C:&5C:R!F;W(@4$5!4B!,;V<@;6]D=6QE
M(&9O<B!I=',@=F5R<VEO;BX@*B\*9G5N8W1I;VX@7V-H96-K7W!E87)?;&]G
M7W9E<G-I;VXH*0I["B`@("!I9B`H(61E9FEN960H)U!%05)?3$]'7TE.1D\G
M*2D@>PH@("`@("`@(')E='5R;B`G66]U<B!V97)S:6]N(&]F($QO9R!I<R!N
M;W0@<F5C96YT(&5N;W5G:"XG.PH@("`@?0I]"@HO*B!!9&1I=&EO;F%L(&-H
M96-K(&9O<B!014%2($1"(&UO9'5L92!F;W(@:71S('9E<G-I;VXN("HO"F9U
M;F-T:6]N(%]C:&5C:U]P96%R7V1B7W9E<G-I;VXH*0I["B`@("!I9B`H(61E
M9FEN960H)T1"7U!/4E1!0DE,25197TQ/5T520T%312<I*2!["B`@("`@("`@
M<F5T=7)N("=9;W5R('9E<G-I;VX@;V8@1$(@:7,@;F]T(')E8V5N="!E;F]U
M9V@N)SL*("`@('T*?0H*+RH@5&AE<F4@:7,@82!V97)S:6]N(&]F('1H92!&
M:6QE+G!H<"!T:&%T('=A;G1S(&$@4$5!4CHZ<F5G:7-T97)3:'5T9&]W;D9U
M;F,*("H@=VAI8V@@:7,@=VAA="!N97=P96%R('1E<W1S(&9O<BX@(%1H:7,@
M9G5N8W1I;VX@<V5E;7,@=&\@;VYL>2!H879E(&5X:7-T960*("H@9F]R(&$@
M;&ET=&QE('=H:6QE+"!B=70@=&AE(%!%05(@9W)O=7`@:&%S;B=T(&9I>&5D
M('1H:7,@>65T+"!S;R!S;VUE"B`J('!E;W!L92!G970@86X@97)R;W(@:68@
M=&AE>2!H879E(&$@8V5R=&%I;B`H<F5L96%S92D@=F5R<VEO;B!O9B!014%2
M+B`@5V4*("H@=&5S="!F;W(@:70@:&5R92X@($EF(&ET)W,@82!S869E('9E
M<G-I;VXL('1E<W0@87,@;F]R;6%L+"!O=&AE<G=I<V4@=')Y(&$*("H@;&5S
M<R!E9F9E8W1I=F4@8G5T(&YO;BUE<G)O<FEN9R!T97-T(&9O<B!&:6QE.CI#
M4U8N("HO"FEF("@A)&AO<F1E7W1E<W0M/FES4F5C96YT4$5!4B@I*2!["B`@
M("`D<&%T:"`](&EN:5]G970H)VEN8VQU9&5?<&%T:"<I.PH@("`@:68@*&5M
M<'1Y*"1P871H*2D@>PH@("`@("`@("1P871H(#T@)RXG.PH@("`@?0H@("`@
M)'!E87)?;&ES=%LG1FEL95]#4U8G75LG<&%T:"==(#T@)UA86%A86"YP:'`G
M.PH@("`@9F]R96%C:"`H97AP;&]D92@G.B<L("1P871H*2!A<R`D9&ER*2![
M"B`@("`@("`@:68@*'-U8G-T<B@D9&ER+"`M,2D@(3T@)R\G*2!["B`@("`@
M("`@("`@("1D:7(@+CT@)R\G.PH@("`@("`@('T*("`@("`@("`D9FEL93$@
M/2`D9&ER("X@)T9I;&4O0U-6+G!H<"<["B`@("`@("`@)&9I;&4R(#T@)&1I
M<B`N("=&:6QE+G!H<"<["B`@("`@("`@)&9I;&4S(#T@)&1I<B`N("=014%2
M+G!H<"<["B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE,2D@)B8@9FEL
M95]E>&ES=',H)&9I;&4R*2`F)B!F:6QE7V5X:7-T<R@D9FEL93,I*2!["B`@
M("`@("`@("`@("\J($-H86YG92!T:&4@9FEL96YA;64@=&\@<V]M971H:6YG
M('=E(&MN;W<@=VEL;"!B92!F;W5N9"X@*B\*("`@("`@("`@("`@)'!E87)?
M;&ES=%LG1FEL95]#4U8G75LG<&%T:"==(#T@)U!%05(N<&AP)SL*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0I]"@HO*B!297%U:7)E9"!C
M;VYF:6=U<F%T:6]N(&9I;&5S+B`J+PHD9FEL95]L:7-T(#T@87)R87DH"B`@
M("`G8V]N9FEG+V-O;F8N<&AP)R`]/B!N=6QL+`H@("`@)V-O;F9I9R]M:6UE
M7V1R:79E<G,N<&AP)R`]/B!N=6QL+`H@("`@)V-O;F9I9R]N;',N<&AP)R`]
M/B!N=6QL+`H@("`@)V-O;F9I9R]P<F5F<RYP:'`G(#T^(&YU;&PL"B`@("`G
M8V]N9FEG+W)E9VES=')Y+G!H<"<@/3X@;G5L;`HI.PH*"B\J($=E="!T:&4@
M<W1A='5S(&]U='!U="!N;W<N("HO"B1M;V1U;&5?;W5T<'5T(#T@)&AO<F1E
M7W1E<W0M/G!H<$UO9'5L94-H96-K*"1M;V1U;&5?;&ES="D["B1S971T:6YG
M7V]U='!U="`]("1H;W)D95]T97-T+3YP:'!3971T:6YG0VAE8VLH)'-E='1I
M;F=?;&ES="D["B1P96%R7V]U='!U="`]("1H;W)D95]T97-T+3Y014%236]D
M=6QE0VAE8VLH)'!E87)?;&ES="D["B1C;VYF:6=?;W5T<'5T(#T@)&AO<F1E
M7W1E<W0M/G)E<75I<F5D1FEL94-H96-K*"1F:6QE7VQI<W0I.PH*"B\J($AA
M;F1L92!S<&5C:6%L(&UO9&5S+B`J+PII9B`H(65M<'1Y*"1?1T546R=M;V1E
M)UTI*2!["B`@("`D=7)L(#T@(65M<'1Y*"1?1T546R=U<FPG72D@/R`D7T=%
M5%LG=7)L)UT@.B`G=&5S="YP:'`G.PH@("`@96-H;R`G/"%$3T-465!%(&AT
M;6P@4%5"3$E#("(M+R]7,T,O+T141"!82%1-3"`Q+C`@5')A;G-I=&EO;F%L
M+R]%3B(@(D141"]X:'1M;#$M=')A;G-I=&EO;F%L+F1T9"(^)SL*("`@('-W
M:71C:"`H)%]'151;)VUO9&4G72D@>PH@("`@8V%S92`G97AT96YS:6]N<R<Z
M"B`@("`@("`@<F5Q=6ER92!415-47U1%35!,051%4R`N("=E>'1E;G-I;VYS
M+FEN8R<["B`@("`@("`@97AI=#L*"B`@("!C87-E("=P:'!I;F9O)SH*("`@
M("`@("!E8VAO("<\82!H<F5F/2(G("X@:'1M;'-P96-I86QC:&%R<R@D=7)L
M*2`N("<_;6]D93UT97-T(CXF;'0[)FQT.R!"86-K('1O('1E<W0N<&AP/"]A
M/B<["B`@("`@("`@<&AP:6YF;R@I.PH@("`@("`@(&5X:70["@H@("`@8V%S
M92`G9FEL971E<W0G.@H@("`@("`@(&5C:&\@)SQA(&AR968](B<@+B!H=&UL
M<W!E8VEA;&-H87)S*"1U<FPI("X@)S]M;V1E/71E<W0B/B9L=#LF;'0[($)A
M8VL@=&\@=&5S="YP:'`\+V$^)SL*("`@("`@("`_/@H@("`@("`@(#QH=&UL
M/@H@("`@("`@(#QB;V1Y(&)G8V]L;W(](G=H:71E(B!T97AT/2)B;&%C:R(^
M"B`@("`@("`@/'`^/&9O;G0@9F%C93TB2&5L=F5T:6-A+"!!<FEA;"P@<V%N
M<RUS97)I9B(@<VEZ93TB,B(^"B`@("`@("`@5&AE<F4@87)E('-O;64@=F5R
M<VEO;G,@;V8@4$5!4B!T:&%T('=E<F4@<F5L96%S960@870@=&EM97,@=&AA
M=`H@("`@("`@(&1I9"!N;W0@8V]N=&%I;B!A(&9U;F-T:6]N('1H870@1FEL
M92YP:'`@97AP96-T<RX@(%1H:7,@9&]E<R!N;W0*("`@("`@("!S965M('1O
M(&AA=F4@8V%U<V5D('!R;V)L96US(&9O<B!A;GEO;F4@97AC97!T('=H96X@
M<G5N;FEN9R!O=7(*("`@("`@("!T97-T('-C<FEP="P@8G5T('EO=2!N965D
M('1O(&)E(&%W87)E(&]F(&ET+B`@268@>6]U('-E92!A(&9A=&%L"B`@("`@
M("`@97)R;W(@:6X@1FEL92YP:'`@;&ES=&5D(&)E;&]W('1H:7,@=&5X="P@
M>6]U(&AA=F4@;VYE(&]F('1H90H@("`@("`@(&-O;6)I;F%T:6]N<R!O9B!P
M<F]B;&5M(&9I;&5S+B`@36%K92!S=7)E('EO=2!H879E('1H92!L871E<W0*
M("`@("`@("!014%2(&%N9"!&:6QE('!A8VMA9V5S(&%V86EL86)L92`H/&$@
M:')E9CTB:'1T<#HO+W!E87(N<&AP+FYE="\B/@H@("`@("`@('-E92!H='1P
M.B\O<&5A<BYP:'`N;F5T/"]A/BDN("!)9B!Y;W4@9&\@;F]T(&=E="!T:&4@
M97)R;W(L('EO=2!A<F4*("`@("`@("!I;B!F:6YE('-H87!E+CPO<#X*("`@
M("`@("`\/W!H<"!I;F-L=61E7V]N8V4@)T9I;&4O0U-6+G!H<"<["B`@("`@
M("`@97AI=#L*"B`@("!C87-E("=U;G)E9VES=&5R)SH*("`@("`@("!U;G-E
M="@D7U-%4U-)3TY;)VAO<F1E7W1E<W1?8V]U;G0G72D["B`@("`@("`@/SX*
M("`@("`@("`\:'1M;#X*("`@("`@("`\8F]D>2!B9V-O;&]R/2)W:&ET92(@
M=&5X=#TB8FQA8VLB/@H@("`@("`@(#QF;VYT(&9A8V4](DAE;'9E=&EC82P@
M07)I86PL('-A;G,M<V5R:68B('-I>F4](C(B/@H@("`@("`@(%1H92!T97-T
M('-E<W-I;VX@:&%S(&)E96X@=6YR96=I<W1E<F5D+CQB<CX*("`@("`@("`\
M82!H<F5F/2)T97-T+G!H<"(^1V\@8F%C:SPO83X@=&\@=&AE('1E<W0N<&AP
M('!A9V4N/&)R/@H@("`@("`@(#P_<&AP"B`@("`@("`@97AI=#L*("`@('T*
M?0H*<F5Q=6ER92!415-47U1%35!,051%4R`N("=H96%D97(N:6YC)SL*<F5Q
M=6ER92!415-47U1%35!,051%4R`N("=V97)S:6]N+FEN8R<["@H_/@H*/&@Q
M/DAO<F1E($%P<&QI8V%T:6]N<SPO:#$^"CQU;#X*/#]P:'`*"B\J($=E="!(
M;W)D92!M;V1U;&4@=F5R<VEO;B!I;F9O<FUA=&EO;BX@*B\*)&UO9'5L97,@
M/2`D:&]R9&5?=&5S="T^87!P;&EC871I;VY,:7-T*"D["F9O<F5A8V@@*"1M
M;V1U;&5S(&%S("1A<'`@/3X@)'9A;"D@>PH@("`@)&%P<"`]('5C9FER<W0H
M)&%P<"D["B`@("!E8VAO("<\;&D^)R`N("1A<'`@+B`G.B`G("X@)'9A;"T^
M=F5R<VEO;CL*("`@(&EF("AI<W-E="@D=F%L+3YT97-T*2D@>PH@("`@("`@
M(&5C:&\@)R`H/&$@:')E9CTB)R`N("1V86PM/G1E<W0@+B`G(CYR=6X@)R`N
M("1A<'`@+B`G('1E<W1S/"]A/BDG.PH@("`@?0H@("`@96-H;R`B/"]L:3Y<
M;B(["GT*"C\^"CPO=6P^"@H\/W!H<`H*+RH@1&ES<&QA>2!02%`@5F5R<VEO
M;B!I;F9O<FUA=&EO;BX@*B\*)'!H<%]I;F9O(#T@)&AO<F1E7W1E<W0M/F=E
M=%!H<%9E<G-I;VY);F9O<FUA=&EO;B@I.PIR97%U:7)E(%1%4U1?5$5-4$Q!
M5$53("X@)W!H<%]V97)S:6]N+FEN8R<["@H_/@H*/&@Q/E!(4"!-;V1U;&4@
M0V%P86)I;&ET:65S/"]H,3X*/'5L/@H@("`@/#]P:'`@96-H;R`D;6]D=6QE
M7V]U='!U="`_/@H\+W5L/@H*/&@Q/DUI<V-E;&QA;F5O=7,@4$A0(%-E='1I
M;F=S/"]H,3X*/'5L/@H@("`@/#]P:'`@96-H;R`D<V5T=&EN9U]O=71P=70@
M/SX*/"]U;#X*"CQH,3Y&:6QE(%5P;&]A9',\+V@Q/@H\=6P^"B`@("`\/W!H
M<"!E8VAO("1H;W)D95]T97-T+3YP:'!3971T:6YG0VAE8VLH87)R87DH)V9I
M;&5?=7!L;V%D<R<@/3X@87)R87DH)W-E='1I;F<G(#T^('1R=64L("=E<G)O
M<B<@/3X@)V9I;&5?=7!L;V%D<R!M=7-T(&)E(&5N86)L960@9F]R('-O;64@
M9F5A='5R97,@;&EK92!S96YD:6YG(&5M86EL<R!W:71H($E-4"XG("DI*2`_
M/@H\/W!H<"!I9B`H)&1I<B`](&EN:5]G970H)W5P;&]A9%]T;7!?9&ER)RDI
M.B`_/@H@("`@/&QI/G5P;&]A9%]T;7!?9&ER.B`\9F]N="!C;VQO<CTB/#]P
M:'`@96-H;R!I<U]W<FET86)L92@D9&ER*2`_("=G<F5E;B<@.B`G<F5D)R`_
M/B(^/'-T<F]N9SX\/W!H<"!E8VAO("1D:7(@/SX\+W-T<F]N9SX\+V9O;G0^
M/"]L:3X*/#]P:'`@96YD:68[(#\^"B`@("`\;&D^=7!L;V%D7VUA>%]F:6QE
M<VEZ93H@/#]P:'`@96-H;R!I;FE?9V5T*"=U<&QO861?;6%X7V9I;&5S:7IE
M)RD@/SX\+VQI/@H@("`@/&QI/G!O<W1?;6%X7W-I>F4Z(#P_<&AP(&5C:&\@
M:6YI7V=E="@G<&]S=%]M87A?<VEZ92<I(#\^/"]L:3X*/"]U;#X*"CQH,3Y2
M97%U:7)E9"!(;W)D92!#;VYF:6=U<F%T:6]N($9I;&5S/"]H,3X*/'5L/@H@
M("`@/#]P:'`@96-H;R`D8V]N9FEG7V]U='!U="`_/@H\+W5L/@H*/&@Q/E!(
M4"!397-S:6]N<SPO:#$^"CP_<&AP("1?4T534TE/3ELG:&]R9&5?=&5S=%]C
M;W5N="==*RL[(#\^"CQU;#X*("`@(#QL:3Y397-S:6]N(&-O=6YT97(Z(#P_
M<&AP(&5C:&\@)%]315-324].6R=H;W)D95]T97-T7V-O=6YT)UT[(#\^/"]L
M:3X*("`@(#QL:3Y4;R!U;G)E9VES=&5R('1H92!S97-S:6]N.B`\82!H<F5F
M/2)T97-T+G!H<#]M;V1E/75N<F5G:7-T97(B/F-L:6-K(&AE<F4\+V$^/"]L
M:3X*/"]U;#X*"CQH,3Y014%2/"]H,3X*/'5L/@H@("`@/#]P:'`@96-H;R`D
M<&5A<E]O=71P=70@/SX*/"]U;#X*"CP_<&AP"G)E<75I<F4@5$535%]414U0
M3$%415,@+B`G9F]O=&5R+FEN8R<["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-I
M9VYU<"YP:'``````````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#0W,#<`,3`U,34T,S$P-3<`,#$V-#0P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W-I9VYU<"YP:'`L=B`Q+C$W+C$P+C@@,C`P-B\P
M,2\P,2`R,3HR.#HP-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN
M92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*<F5Q=6ER95]O
M;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O075T:"]3:6=N=7`N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]687)I86)L97,N<&AP)SL*"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D
M8V]N9ELG875T:"==6R=D<FEV97(G72D["@HO+R!-86ME('-U<F4@<VEG;G5P
M<R!A<F4@96YA8FQE9"!B969O<F4@<')O8V5E9&EN9PII9B`H)&-O;F9;)W-I
M9VYU<"==6R=A;&QO=R==("$]/2!T<G5E('Q\"B`@("`A)&%U=&@M/FAA<T-A
M<&%B:6QI='DH)V%D9"<I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H
M(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N($%U=&@Z.F=E=$QO9VEN4V-R965N*"DI.PH@("`@97AI=#L*?0H*
M)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B;&5S*"D["B1S
M:6=N=7`@/2`F075T:%]3:6=N=7`Z.G-I;F=L971O;B@I.PHD<F5N9&5R97(@
M/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H*3L*"B1F;W)M<VEG;G5P(#T@
M)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G2&]R9&53:6=N=7!&;W)M)RP@)'9A
M<G,I.PHD9F]R;7-I9VYU<"T^=F%L:61A=&4H)'9A<G,I.PH*:68@*"1V87)S
M+3YG970H)V9O<FUN86UE)RD@(3T@)VAO<F1E<VEG;G5P9F]R;2<I('L*("`@
M("\J($YO="!Y970@<W5B;6ET=&5D+B`J+PH@("`@)&9O<FUS:6=N=7`M/F-L
M96%R5F%L:61A=&EO;B@I.PI]"@II9B`H)&9O<FUS:6=N=7`M/FES5F%L:60H
M*2`F)B`D=F%R<RT^9V5T*"=F;W)M;F%M92<I(#T]("=H;W)D97-I9VYU<&9O
M<FTG*2!["B`@("`D9F]R;7-I9VYU<"T^9V5T26YF;R@D=F%R<RP@)&EN9F\I
M.PH*("`@(&EF("@A)&-O;F9;)W-I9VYU<"==6R=A<'!R;W9E)UTI('L*("`@
M("`@("`O*B!5<V5R(&-A;B!S:6=N('5P(&1I<F5C=&QY+"!N;R!I;G1E<G9E
M;G1I;VX@;F5C97-S87)Y+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'-I9VYU
M<"T^861D4VEG;G5P*"1I;F9O*3L*("`@("`@("`D<W5C8V5S<U]M97-S86=E
M(#T@<W!R:6YT9BA?*")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;B!L;V<@:6X@;F]W+B(I+"`D:6YF;ULG=7-E<E]N86UE)UTI.PH@("`@
M?2!E;'-E:68@*"1C;VYF6R=S:6=N=7`G75LG87!P<F]V92==*2!["B`@("`@
M("`@+RH@26YS97)T('1H:7,@=7-E<B!I;G1O(&$@<75E=64@9F]R(&%D;6EN
M(&%P<')O=F%L+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'-I9VYU<"T^<75E
M=653:6=N=7`H)&EN9F\I.PH@("`@("`@("1S=6-C97-S7VUE<W-A9V4@/2!S
M<')I;G1F*%\H(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U
M97-T(&AA<R!B965N(&%P<')O=F5D+B(I+"`D:6YF;ULG=7-E<E]N86UE)UTI
M.PH@("`@?0H*("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M
M.B`E<R(I+"`D:6YF;ULG=7-E<E]N86UE)UTL("1S=6-C97-S+3YG971-97-S
M86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92!["B`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"@D<W5C8V5S<U]M97-S86=E+"`G:&]R9&4N
M<W5C8V5S<R<I.PH@("`@("`@("1U<FP@/2!!=71H.CIG971,;V=I;E-C<F5E
M;B@G)RP@)&EN9F];)W5R;"==*3L*("`@("`@("!H96%D97(H)TQO8V%T:6]N
M.B`G("X@)'5R;"D["B`@("`@("`@97AI=#L*("`@('T*?0H*)'1I=&QE(#T@
M7R@B57-E<B!296=I<W1R871I;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T
M:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["B1F;W)M<VEG
M;G5P+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D=F%R<RP@)W-I9VYU<"YP
M:'`G+"`G<&]S="<I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W)P8RYP:'``````````````````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4U-3,`,3`U,34T,S$P-3<`,#$U
M-S$W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W)P8RYP:'`L=B`Q+C,P+C$P
M+C,@,C`P-B\P,2\P,2`R,3HR.#HP-"!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E
M*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I*3L*
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E
M<75I<F5?;VYC92`G2&]R9&4O4E!#+G!H<"<["@HO*B!,;V]K(&%T('1H92!#
M;VYT96YT+71Y<&4@;V8@=&AE(')E<75E<W0L(&EF(&ET(&ES(&%V86EL86)L
M92P@=&\@=')Y"B`J(&%N9"!D971E<FUI;F4@=VAA="!K:6YD(&]F(')E<75E
M<W0@=&AI<R!I<RX@*B\*)&EN<'5T(#T@;G5L;#L*)'!A<F%M<R`](&YU;&P[
M"@II9B`H(65M<'1Y*"1?4T525D526R=0051(7TE.1D\G72D@?'P*("`@(&EN
M7V%R<F%Y*"1?4T525D526R=215%515-47TU%5$A/1"==+"!A<G)A>2@G4%)/
M4$9)3D0G*2DI('L*("`@("1S97)V97)4>7!E(#T@)W=E8F1A=B<["GT@96QS
M96EF("AI<W-E="@D7U-%4E9%4ELG4D5154535%]-151(3T0G72D@)B8*("`@
M("`@("`@("1?4T525D526R=215%515-47TU%5$A/1"==(#T]("='150G("8F
M"B`@("`@("`@("!5=&EL.CIG971'970H)W)E<W1#86QL)RDI('L*("`@("1S
M97)V97)4>7!E(#T@)W)E<W0G.PI](&5L<V5I9B`H(65M<'1Y*"1?4T525D52
M6R=#3TY414Y47U194$4G72DI('L*("`@(&EF("AS=')P;W,H)%]315)615);
M)T-/3E1%3E1?5%E012==+"`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"MX;6PG
M*2`A/3T@9F%L<V4I('L*("`@("`@("`D<V5R=F5R5'EP92`]("=S>6YC;6PG
M.PH@("`@("`@("\J(%-Y;F-M;"!D;V5S(&ET<R!O=VX@<V5S<VEO;B!H86YD
M;&EN9RX@*B\*("`@("`@("`D<V5S<VEO;E]C;VYT<F]L(#T@)VYO;F4G.PH@
M("`@?2!E;'-E:68@*'-T<G!O<R@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTL
M("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL*W=B>&UL)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@)'-E<G9E<E1Y<&4@/2`G<WEN8VUL7W=B>&UL)SL*("`@("`@
M("`O*B!3>6YC;6P@9&]E<R!I=',@;W=N('-E<W-I;VX@:&%N9&QI;F<N("HO
M"B`@("`@("`@)'-E<W-I;VY?8V]N=')O;"`]("=N;VYE)SL*("`@('T@96QS
M96EF("AS=')P;W,H)%]315)615);)T-/3E1%3E1?5%E012==+"`G=&5X="]X
M;6PG*2`A/3T@9F%L<V4I('L*("`@("`@("`D:6YP=70@/2!(;W)D95]24$,Z
M.F=E=$EN<'5T*"D["B`@("`@("`@+RH@0VAE8VL@9F]R(%-/05`@;F%M97-P
M86-E(%5222X@*B\*("`@("`@("!I9B`H<W1R<&]S*"1I;G!U="P@)VAT='`Z
M+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YV96QO<&4O)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1S97)V97)4>7!E(#T@)W-O87`G.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S97)V97)4>7!E(#T@)WAM;')P
M8R<["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!H96%D97(H)TA4
M5%`O,2XP(#4P,2!.;W0@26UP;&5M96YT960G*3L*("`@("`@("!E>&ET.PH@
M("`@?0I](&5L<V4@>PH@("`@)'-E<G9E<E1Y<&4@/2`G<V]A<"<["GT*"FEF
M("@D<V5R=F5R5'EP92`]/2`G<V]A<"<@)B8*("`@("@A:7-S970H)%]315)6
M15);)U)%455%4U1?34542$]$)UTI('Q\"B`@("`@)%]315)615);)U)%455%
M4U1?34542$]$)UT@(3T@)U!/4U0G*2D@>PH@("`@)'-E<W-I;VY?8V]N=')O
M;"`]("=N;VYE)SL*("`@(&EF("AI<W-E="@D7T=%5%LG=W-D;"==*2D@>PH@
M("`@("`@("1P87)A;7,@/2`G=W-D;"<["B`@("!](&5L<V4@>PH@("`@("`@
M("1P87)A;7,@/2`G9&ES8V\G.PH@("`@?0I]"@HO*B!,;V%D(&)A<V4@;&EB
M<F%R:65S+B`J+PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*"B\J($QO860@=&AE(%)00R!B86-K96YD(&)A<V5D(&]N("1S
M97)V97)4>7!E+B`J+PHD<V5R=F5R(#T@)DAO<F1E7U)00SHZ<VEN9VQE=&]N
M*"1S97)V97)4>7!E+"`D<&%R86US*3L*"B\J($QE="!T:&4@8F%C:V5N9"!C
M:&5C:R!A=71H96YT:6-A=&EO;BX@0GD@9&5F875L="P@=V4@;&]O:R!F;W(@
M2%144`H@*B!B87-I8R!A=71H96YT:6-A=&EO;B!A9V%I;G-T($AO<F1E+"!B
M=70@8F%C:V5N9',@8V%N(&]V97)R:61E('1H:7,*("H@87,@;F5E9&5D+B`J
M+PHD<V5R=F5R+3YA=71H;W)I>F4H*3L*"B\J($=E="!T:&4@<V5R=F5R)W,@
M<F5S<&]N<V4N(%=E(&-A;&P@)'-E<G9E<BT^9V5T26YP=70H*2!T;R!A;&QO
M=PH@*B!B86-K96YD<R!T;R!H86YD;&4@:6YP=70@<')O8V5S<VEN9R!D:69F
M97)E;G1L>2X@*B\*:68@*"1I;G!U="`]/3T@;G5L;"D@>PH@("`@)&EN<'5T
M(#T@)'-E<G9E<BT^9V5T26YP=70H*3L*?0H*)&]U="`]("1S97)V97(M/F=E
M=%)E<W!O;G-E*"1I;G!U="P@)'!A<F%M<RD["@II9B`H:7-?82@D;W5T+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("!H96%D97(H)TA45%`O,2XP(#4P,"!);G1E
M<FYA;"!397)V97(@17)R;W(G*3L*("`@(&5X:70["GT*"B\J(%)E='5R;B!T
M:&4@<F5S<&]N<V4@=&\@=&AE(&-L:65N="X@*B\*:&5A9&5R*"=#;VYT96YT
M+51Y<&4Z("<@+B`D<V5R=F5R+3YG971297-P;VYS94-O;G1E;G14>7!E*"DI
M.PIH96%D97(H)T-O;G1E;G0M;&5N9W1H.B`G("X@<W1R;&5N*"1O=70I*3L*
M:&5A9&5R*"=!8V-E<'0M0VAA<G-E=#H@551&+3@G*3L*96-H;R`D;W5T.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]G:6XN
M<&AP````````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q-C$R-P`Q,#4Q-30S,3`U-P`P,38R-#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O;&]G:6XN<&AP+'8@,BXQ-S4N,BXQ,2`R,#`V+S`Q+S$V
M(#$U.C4W.C4S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U
M92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]396-R970N<&AP)SL*"B\J($EN:71I86QI>F4@=&AE($%U=&@@8W)E
M9&5N=&EA;',@:V5Y+B`J+PI396-R970Z.G-E=$ME>2@G875T:"<I.PH*+RH@
M1V5T(&%N($%U=&@@;V)J96-T+B`J+PHD875T:"`]("9!=71H.CIS:6YG;&5T
M;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PII9B`H:7-?82@D875T:"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"1A=71H+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PI]"@HO*B!'970@<&%R86UE=&5R<RX@*B\*)&QO
M9V]U=%]R96%S;VX@/2`D875T:"T^9V5T3&]G;W5T4F5A<V]N*"D["B1U<FQ?
M<&%R86T@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD["B1I95]V97)S:6]N
M(#T@571I;#HZ9V5T1F]R;41A=&$H)VEE7W9E<G-I;VXG*3L*"FEF("@D;&]G
M;W5T7W)E87-O;BD@>PH@("`@)&QO9VEN7W-C<F5E;B`]("1A=71H+3YG971,
M;V=I;E-C<F5E;B@I.PH@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=N;W-I
M9&5B87(G*2`F)@H@("`@("`@(&ES<V5T*"1'3$]"04Q36R=N;W1I9FEC871I
M;VXG72DI('L*("`@("`@("`D=7)L(#T@075T:#HZ861D3&]G;W5T4&%R86UE
M=&5R<R@D;&]G:6Y?<V-R965N*3L*("`@("`@("!I9B`H)'5R;%]P87)A;2D@
M>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL
M("=U<FPG+"`D=7)L7W!A<F%M*3L*("`@("`@("!]"B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@G=VEN9&]W+G!A<F5N="YL;V-A=&EO;BYH<F5F(#T@
M7"<G("X@)'5R;"`N("=<)SLG+"`G:F%V87-C<FEP="<I.PH@("`@("`@(&5C
M:&\@)SQH=&UL/CQB;V1Y/B<@+B`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM
M/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B!A<G)A>2@G:F%V87-C<FEP
M="<I*2D@+B`G/"]B;V1Y/CPO:'1M;#XG.PH@("`@("`@(&5X:70["B`@("!]
M"@H@("`@:68@*%5T:6PZ.G)E;6]V95!A<F%M971E<B@D;&]G:6Y?<V-R965N
M+"!A<G)A>2@G=7)L)RP@)VYO8V%C:&4G*2D@(3T*("`@("`@("!5=&EL.CIR
M96UO=F5087)A;65T97(H2&]R9&4Z.G-E;&95<FPH9F%L<V4L(&9A;'-E+"!T
M<G5E*2P@87)R87DH)W5R;"<L("=N;V-A8VAE)RDI*2!["B`@("`@("`@)'5R
M;"`]($%U=&@Z.F%D9$QO9V]U=%!A<F%M971E<G,H)&QO9VEN7W-C<F5E;BD[
M"B`@("`@("`@:68@*"1U<FQ?<&%R86TI('L*("`@("`@("`@("`@)'5R;"`]
M(%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G=7)L)RP@)'5R;%]P87)A;2D[
M"B`@("`@("`@?0H@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L
M*3L*("`@("`@("!E>&ET.PH@("`@?0H*("`@("1L86YG=6%G92`](&ES<V5T
M*"1P<F5F<RD@/R`D<')E9G,M/F=E=%9A;'5E*"=L86YG=6%G92<I(#H@3DQ3
M.CIS96QE8W0H*3L*"B`@("`D96YT<GD@/2!S<')I;G1F*"=5<V5R("5S(%LE
M<UT@;&]G9V5D(&]U="!O9B!(;W)D92<L"B`@("`@("`@("`@("`@("`@("`@
M($%U=&@Z.F=E=$%U=&@H*2P@)%]315)615);)U)%34]415]!1$12)UTI.PH@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7TY/5$E#12D["B`@("!!=71H.CIC;&5A<D%U=&@H*3L*
M("`@($!S97-S:6]N7V1E<W1R;WDH*3L*"B`@("`O*B!2961I<F5C="!T:&4@
M=7-E<B!O;B!L;V=O=70@:68@<F5D:7)E8W1I;VX@:7,@96YA8FQE9"X@*B\*
M("`@(&EF("@A96UP='DH)&-O;F9;)V%U=&@G75LG<F5D:7)E8W1?;VY?;&]G
M;W5T)UTI*2!["B`@("`@("`@)&QO9V]U=%]U<FP@/2`D8V]N9ELG875T:"==
M6R=R961I<F5C=%]O;E]L;V=O=70G73L*("`@("`@("!I9B`H(6ES<V5T*"1?
M0T]/2TE%6W-E<W-I;VY?;F%M92@I72DI('L*("`@("`@("`@("`@)&QO9V]U
M=%]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&QO9V]U=%]U<FPL('-E<W-I
M;VY?;F%M92@I+"!S97-S:6]N7VED*"DI.PH@("`@("`@('T*("`@("`@("!H
M96%D97(H)TQO8V%T:6]N.B`G("X@)&QO9V]U=%]U<FPI.PH@("`@("`@(&5X
M:70["B`@("!]"@H@("`@2&]R9&4Z.G-E='5P4V5S<VEO;DAA;F1L97(H*3L*
M("`@($!S97-S:6]N7W-T87)T*"D["@H@("`@3DQ3.CIS971,86YG*"1L86YG
M=6%G92D["@H@("`@+RH@2&]O:R!T;R!P<F5S96QE8W0@=&AE(&-O<G)E8W0@
M;&%N9W5A9V4@:6X@=&AE('=I9&=E="X@*B\*("`@("1?1T546R=N97=?;&%N
M9R==(#T@)&QA;F=U86=E.PI]"@II9B`H:7-S970H)%]03U-46R=H;W)D95]U
M<V5R)UTI("8F(&ES<V5T*"1?4$]35%LG:&]R9&5?<&%S<R==*2D@>PH@("`@
M+RH@1&5S=')O>2!A;GD@97AI<W1I;F<@<V5S<VEO;B!O;B!L;V=I;B!A;F0@
M;6%K92!S=7)E('1O('5S92!A"B`@("`@*B!N97<@<V5S<VEO;B!)1"P@=&\@
M879O:60@<V5S<VEO;B!F:7AA=&EO;B!I<W-U97,N("HO"B`@("!(;W)D93HZ
M9V5T0VQE86Y397-S:6]N*"D["B`@("!I9B`H)&%U=&@M/F%U=&AE;G1I8V%T
M92A5=&EL.CIG9710;W-T*"=H;W)D95]U<V5R)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G<&%S<W=O<F0G(#T^(%5T:6PZ.F=E=%!O
M<W0H)VAO<F1E7W!A<W,G*2DI*2!["B`@("`@("`@)&5N=')Y(#T@<W!R:6YT
M9B@G3&]G:6X@<W5C8V5S<R!F;W(@)7,@6R5S72!T;R!(;W)D92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("!!=71H.CIG971!=71H*"DL("1?4T525D52
M6R=214U/5$5?041$4B==*3L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D
M96YT<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?3D]424-%*3L*
M"B`@("`@("`@:68@*"1I95]V97)S:6]N*2!["B`@("`@("`@("`@("1B<F]W
M<V5R+3YS971)159E<G-I;VXH)&EE7W9E<G-I;VXI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1U<FQ?<&%R86TI('L*("`@("`@("`@("`@)'5R;"`]($AO
M<F1E.CIU<FPH571I;#HZ<F5M;W9E4&%R86UE=&5R*"1U<FQ?<&%R86TL('-E
M<W-I;VY?;F%M92@I*2P@=')U92D["B`@("`@("`@("`@("1H;W)D95]U<FP@
M/2`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]I;F1E
M>"YP:'`G.PH@("`@("`@("`@("`D:&]R9&5?=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1H;W)D95]U<FPL("=U<FPG+"`D=7)L*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D:&]R9&5?=7)L(#T@2&]R9&4Z.G5R;"@D<F5G
M:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]I;F1E>"YP:'`G
M*3L*("`@("`@("!]"@H@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)&AO<F1E7W5R;"P@=')U92D["B`@("`@("`@:68@*"1B<F]W<V5R
M+3YI<T)R;W=S97(H)VUS:64G*2`F)@H@("`@("`@("`@("`D8V]N9ELG=7-E
M7W-S;"==(#T](#,@)B8*("`@("`@("`@("`@<W1R;&5N*"1U<FPI(#P@,38P
M*2!["B`@("`@("`@("`@(&AE861E<B@G4F5F<F5S:#H@,#L@55),/2<@+B`D
M=7)L*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@?0H@("`@("`@(&5X:70["B`@
M("!](&5L<V4@>PH@("`@("`@("1E;G1R>2`]('-P<FEN=&8H)T9!24Q%1"!,
M3T=)3B!F;W(@)7,@6R5S72!T;R!(;W)D92<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("!5=&EL.CIG971&;W)M1&%T82@G:&]R9&5?=7-E<B<I+"`D7U-%
M4E9%4ELG4D5-3U1%7T%$1%(G72D["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@:68@*"1C;VYF6R=M96YU)UU;)V%L=V%Y<R==*2!["B`@("`@
M("`@("`@("1M86EN7W!A9V4@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z
M.G-E;&95<FPH*2P@)W)E87-O;B<L("1A=71H+3YG971,;V=O=71296%S;VY3
M=')I;F<H*2D["B`@("`@("`@("`@(&EF("@D8G)O=W-E<BT^:&%S475I<FLH
M)W-C<F]L;&)A<E]I;E]W87DG*2D@>PH@("`@("`@("`@("`@("`@)'-C<F]L
M;&)A<B`]("=Y97,G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'-C<F]L;&)A<B`]("=A=71O)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O:6YD97@O9G)A
M;65S7VEN9&5X+FEN8R<["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H@
M("`@?0I]"@II9B`H075T:#HZ9V5T075T:"@I*2!["B`@("!I9B`H)&)R;W=S
M97(M/FES36]B:6QE*"DI('L*("`@("`@("`D=7)L(#T@)W-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP)SL*("`@('T@96QS92!["B`@("`@("`@)'5R;"`]
M("=S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP)SL*("`@('T*("`@(')E<75I
M<F4@2$]21$5?0D%312`N("<O)R`N("1U<FP["B`@("!E>&ET.PI]"@HO*B!4
M<GD@=')A;G-P87)E;G0@875T:&5N=&EC871I;VXN("HO"FEF("A!=71H.CII
M<T%U=&AE;G1I8V%T960H*2D@>PH@("`@<F5Q=6ER92!(3U)$15]"05-%("X@
M)R]I;F1E>"YP:'`G.PH@("`@97AI=#L*?0H*+RH@4F5D:7)E8W0@=&AE('5S
M97(@:68@86X@86QT97)N871E(&QO9VEN('!A9V4@:&%S(&)E96X@<W!E8VEF
M:65D+B`J+PII9B`H(65M<'1Y*"1C;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L
M;V=I;B==*2D@>PH@("`@)'5R;"`]($%U=&@Z.F%D9$QO9V]U=%!A<F%M971E
M<G,H)&-O;F9;)V%U=&@G75LG86QT97)N871E7VQO9VEN)UTI.PH@("`@:68@
M*"%I<W-E="@D7T-/3TM)15MS97-S:6]N7VYA;64H*5TI*2!["B`@("`@("`@
M)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!S97-S:6]N7VYA;64H
M*2P@<V5S<VEO;E]I9"@I+"!F86QS92D["B`@("!]"B`@("!I9B`H)'5R;%]P
M87)A;2D@>PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R
M;"P@)W5R;"<L("1U<FQ?<&%R86TL(&9A;'-E*3L*("`@('T*("`@(&AE861E
M<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70["GT*"B1L;V=I;E]S
M8W)E96X@/2`D875T:"T^7V=E=$QO9VEN4V-R965N*"D["FEF("A5=&EL.CIR
M96UO=F5087)A;65T97(H)&QO9VEN7W-C<F5E;BP@87)R87DH)W5R;"<L("=N
M;V-A8VAE)RDI("$]"B`@("!(;W)D93HZ<V5L9E5R;"AF86QS92P@9F%L<V4L
M('1R=64I*2!["B`@("!I9B`H)'5R;%]P87)A;2D@>PH@("`@("`@("1L;V=I
M;E]S8W)E96X@/2!5=&EL.CIA9&1087)A;65T97(H)&QO9VEN7W-C<F5E;BP@
M)W5R;"<L("1U<FQ?<&%R86TL(&9A;'-E*3L*("`@('T*("`@(&EF("@D:65?
M=F5R<VEO;BD@>PH@("`@("`@("1L;V=I;E]S8W)E96X@/2!5=&EL.CIA9&10
M87)A;65T97(H)&QO9VEN7W-C<F5E;BP@)VEE7W9E<G-I;VXG+"`D:65?=F5R
M<VEO;BP@9F%L<V4I.PH@("`@?0H@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M("1L;V=I;E]S8W)E96XI.PH@("`@97AI=#L*?0H*:68@*"1B<F]W<V5R+3YI
M<TUO8FEL92@I*2!["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TUO8FEL92YP
M:'`G.PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+VQO9VEN+VUO
M8FEL92YI;F,G.PH@("`@97AI=#L*?0H*+RH@0G5I;&0@=&AE(#QS96QE8W0^
M('=I9&=E="!C;VYT86EN:6YG('1H92!A=F%I;&%B;&4@;&%N9W5A9V5S+B`J
M+PII9B`H(21P<F5F<RT^:7-,;V-K960H)VQA;F=U86=E)RDI('L*("`@("1?
M4T534TE/3ELG:&]R9&5?;&%N9W5A9V4G72`]($Y,4SHZ<V5L96-T*"D["B`@
M("`D;&%N9W,@/2`G/'-E;&5C="!N86UE/2)N97=?;&%N9R(@;VYC:&%N9V4]
M(G-E;&5C=$QA;F<H*2(^)SL*("`@(&9O<F5A8V@@*"1N;'-;)VQA;F=U86=E
M<R==(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("1S96P@/2`H)&ME>2`]
M/2`D7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UTI(#\@)R!S96QE8W1E9#TB
M<V5L96-T960B)R`Z("<G.PH@("`@("`@("1L86YG<R`N/2`B/&]P=&EO;B!V
M86QU93U<(B1K97E<(B1S96P^)'9A;#PO;W!T:6]N/B(["B`@("!]"B`@("`D
M;&%N9W,@+CT@)SPO<V5L96-T/B<["GT*"B1T:71L92`](%\H(DQO9R!I;B(I
M.PHD;F]T:69I8V%T:6]N+3YP=7-H*"=S971&;V-U<R@I)RP@)VIA=F%S8W)I
M<'0G*3L*:68@*"1L;V=O=71?<F5A<V]N("8F("1C;VYF6R=M96YU)UU;)V%L
M=V%Y<R==*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"=I9B`H=VEN9&]W
M+G!A<F5N="YF<F%M97,N:&]R9&5?;65N=2D@=VEN9&]W+G!A<F5N="YF<F%M
M97,N:&]R9&5?;65N=2YL;V-A=&EO;BYH<F5F(#T@7"<G("X@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`G*2`N
M("=<)SLG+"`G:F%V87-C<FEP="<I.PI]"@HD<F5A<V]N(#T@)&%U=&@M/F=E
M=$QO9V]U=%)E87-O;E-T<FEN9R@I.PH*+RH@061D('-O;64@:F%V87-C<FEP
M="X@*B\*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V5N=&5R7VME>5]T<F%P+FIS
M)RP@)VAO<F1E)RP@=')U92D["@HO*B!$;R!W92!N965D('1O(&1O($E%('9E
M<G-I;VX@9&5T96-T:6]N/R`J+PII9B`H*"1B<F]W<V5R+3YG971"<F]W<V5R
M*"D@/3T@)VUS:64G*2`F)B`H)&)R;W=S97(M/F=E=$UA:F]R*"D@/CT@-2DI
M('L*("`@("1I95]C;&EE;G1C87!S(#T@=')U93L*?0H*<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+VQO9VEN+VQO9VEN+FEN8R<["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]I;F1E
M>"YP:'``````````````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`W,3<U`#$P-3$U-#,Q,#4W`#`Q-C(T-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!H;W)D92]I;F1E>"YP:'`L=B`R+C$P-2XT+C@@,C`P-B\P-R\R
M.2`Q-CHT.3HQ.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T
M<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M*3L*)&AO<F1E7V-O;F9I9W5R960@/2`H0&9I;&5?97AI<W1S*$A/4D1%7T)!
M4T4@+B`G+V-O;F9I9R]C;VYF+G!H<"<I("8F"B`@("`@("`@("`@("`@("`@
M("`@($!F:6QE7V5X:7-T<RA(3U)$15]"05-%("X@)R]C;VYF:6<O;6EM95]D
M<FEV97)S+G!H<"<I("8F"B`@("`@("`@("`@("`@("`@("`@($!F:6QE7V5X
M:7-T<RA(3U)$15]"05-%("X@)R]C;VYF:6<O;FQS+G!H<"<I("8F"B`@("`@
M("`@("`@("`@("`@("`@($!F:6QE7V5X:7-T<RA(3U)$15]"05-%("X@)R]C
M;VYF:6<O<')E9G,N<&AP)RD@)B8*("`@("`@("`@("`@("`@("`@("`@0&9I
M;&5?97AI<W1S*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP:'`G
M*2D["@II9B`H(21H;W)D95]C;VYF:6=U<F5D*2!["B`@("!R97%U:7)E($A/
M4D1%7T)!4T4@+B`G+VQI8B]497-T+G!H<"<["B`@("!(;W)D95]497-T.CIC
M;VYF:6=&:6QE<TUI<W-I;F<H)TAO<F1E)RP@2$]21$5?0D%312P@)W!R969S
M+G!H<"<L"B`@("`@("`@87)R87DH)V-O;F8N<&AP)R`]/B`G5&AI<R!I<R!T
M:&4@;6%I;B!(;W)D92!C;VYF:6=U<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS
M('!A=&AS(&%N9"!B87-I8R!I=&5M<R!T:&%T(&%P<&QY('1O('1H92!C;W)E
M(&9R86UE=V]R:R!A;F0@86QL($AO<F1E(&%P<&QI8V%T:6]N<RXG+`H@("`@
M("`@("`@("`@("=M:6UE7V1R:79E<G,N<&AP)R`]/B`G5&AI<R!F:6QE(&-O
M;G1R;VQS('1H92!G;&]B86P@<V5T(&]F($U)344@9')I=F5R<R!F;W(@=&AE
M($AO<F1E(&9R86UE=V]R:RP@86QL;W=I;F<@87!P;&EC871I;VYS('1O(&UA
M:V4@=7-E(&]F('!R;V=R86US('-U8V@@87,@96YS8W)I<'0@;W(@;7-W;W)D
M=FEE=R!T;R!R96YD97(@8V]N=&5N="!I;G1O($A434P@9F]R('9I97=I;F<@
M:6X@82!B<F]W<V5R+B<L"B`@("`@("`@("`@("`@)VYL<RYP:'`G(#T^("=4
M:&ES(&9I;&4@<')O=FED97,@;&]C86QI<V%T:6]N('-U<'!O<G0@9F]R('1H
M92!(;W)D92!F<F%M97=O<FLN)RP*("`@("`@("`@("`@("`G<F5G:7-T<GDN
M<&AP)R`]/B`G5&AE(')E9VES=')Y(&ES(&AO=R!(;W)D92!A<'!L:6-A=&EO
M;G,@9FEN9"!O=70@:&]W('1O('1A;&L@=&\@96%C:"!O=&AE<BX@66]U('-H
M;W5L9"!L:7-T(&%N>2!I;G-T86QL960@2&]R9&4@87!P;&EC871I;VYS('1H
M870@>6]U(&AA=F4@:&5R92XG*2D["GT*"G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8F%S92YP:'`G.PH*:68@*"1B<F]W<V5R+3YI<TUO8FEL
M92@I*2!["B`@("!R97%U:7)E($A/4D1%7T)!4T4@+B`G+W-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP)SL*("`@(&5X:70["GT*"B1M86EN7W!A9V4@/2!5
M=&EL.CIG971&;W)M1&%T82@G=7)L)RD["@HO+R!"<F5A:R!U<"!T:&4@<F5Q
M=65S=&5D(%523"!I;B`D;6%I;E]P86=E(&%N9"!R=6X@<V]M92!S86YI='D@
M8VAE8VMS"B\O(&]N(&ET('1O('!R979E;G0@<&AI<VAI;F<@86YD(%A34R!A
M='1A8VMS+B!)9B!A;GD@;V8@=&AE(&-H96-K<PHO+R!F86EL+"`D;6%I;E]P
M86=E('=I;&P@8F4@<V5T('1O(&YU;&PN"FEF("@A96UP='DH)&UA:6Y?<&%G
M92DI('L*("`@("\O($UU=&4@97)R;W)S(&EN(&-A<V4@;V8@=6YP87)S96%B
M;&4@55),<PH@("`@)')E<2`]($!P87)S95]U<FPH)&UA:6Y?<&%G92D["@H@
M("`@+R\@5V4@87-S=6UE('1H870@86YY('9A;&ED(')E9&ER96-T(%523"!W
M:6QL(&)E(&EN('1H92!S86UE"B`@("`O+R!C;V]K:64@9&]M86EN+B!4:&ES
M(&AE;'!S('!R979E;G0@<F]G=64@;V9F+7-I=&4@2&]R9&4@:6YS=&%L;',*
M("`@("\O(&9R;VT@;6EM:6-K:6YG('1H92!R96%L('-E<G9E<BX*("`@(&EF
M("AI<W-E="@D<F5Q6R=H;W-T)UTI*2!["B`@("`@("`@)'%C;V]K:65D;VT@
M/2!P<F5G7W%U;W1E*"1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTI.PH@("`@
M("`@(&EF("@A<')E9U]M871C:"@G+R<@+B`D<6-O;VMI961O;2`N("<D+R<L
M("1R97%;)VAO<W0G72DI('L*("`@("`@("`@("`@)&UA:6Y?<&%G92`](&YU
M;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O(%!R;W1O8V]L('=H:71E;&ES
M=#H@268@=&AE(%523"!I<R!F=6QL>2!Q=6%L:69I960L(&UA:V4@<W5R92!I
M=`H@("`@+R\@:7,@96ET:&5R(&AT='`@;W(@:'1T<',N"B`@("`D86QL;W=E
M9%]P<F]T;V-O;',@/2!A<G)A>2@G:'1T<"<L("=H='1P<R<I.PH@("`@:68@
M*&5M<'1Y*"1R97%;)W-C:&5M92==*2!\?`H@("`@("`@("%I;E]A<G)A>2@D
M<F5Q6R=S8VAE;64G72P@)&%L;&]W961?<')O=&]C;VQS*2D@>PH@("`@("`@
M("1M86EN7W!A9V4@/2!N=6QL.PH@("`@?0I]"@II9B`H(21M86EN7W!A9V4I
M('L*("`@("1I;FET:6%L7V%P<"`]("1P<F5F<RT^9V5T5F%L=64H)VEN:71I
M86Q?87!P;&EC871I;VXG*3L*("`@(&EF("@A96UP='DH)&EN:71I86Q?87!P
M*2`F)B`D<F5G:7-T<GDM/FAA<U!E<FUI<W-I;VXH)&EN:71I86Q?87!P*2D@
M>PH@("`@("`@("1M86EN7W!A9V4@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^
M9V5T26YI=&EA;%!A9V4H)&EN:71I86Q?87!P*2P@=')U92D["B`@("!](&5L
M<V5I9B`H:7-S970H)')E9VES=')Y+3YA<'!L:6-A=&EO;G-;)VAO<F1E)UU;
M)VEN:71I86Q?<&%G92==*2D@>PH@("`@("`@("1M86EN7W!A9V4@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)')E9VES=')Y+3YA<'!L:6-A=&EO;G-;)VAO
M<F1E)UU;)VEN:71I86Q?<&%G92==+"!T<G5E*3L*("`@('T@96QS96EF("A!
M=71H.CIG971!=71H*"DI('L*("`@("`@("`D;6%I;E]P86=E(#T@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T86PO)RP@=')U92D["B`@
M("!](&5L<V4@>PH@("`@("`@("1M86EN7W!A9V4@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)VQO9VEN+G!H<"<L('1R=64I.PH@("`@?0I]"@II9B`H(55T
M:6PZ.F=E=$9O<FU$871A*"=F<F%M97-E=%]L;V%D960G*2`F)@H@("`@*"1C
M;VYF6R=M96YU)UU;)V%L=V%Y<R==('Q\"B`@("`@*$%U=&@Z.F=E=$%U=&@H
M*2`F)B`D<')E9G,M/F=E=%9A;'5E*"=S:&]W7W-I9&5B87(G*2DI*2!["B`@
M("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=S8W)O;&QB87)?:6Y?=V%Y)RDI
M('L*("`@("`@("`D<V-R;VQL8F%R(#T@)WEE<R<["B`@("!](&5L<V4@>PH@
M("`@("`@("1S8W)O;&QB87(@/2`G875T;R<["B`@("!]"B`@("!R97%U:7)E
M($A/4D1%7U1%35!,051%4R`N("<O:6YD97@O9G)A;65S7VEN9&5X+FEN8R<[
M"GT@96QS92!["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)&UA:6Y?<&%G
M92D["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]A9&UI;B\`````````````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P
M`#`Q-30W-P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92\`
M````````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S$P-C``,#$V-S,V`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O861M:6XO;&]C86QE+V5N7U53+P``````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,3<W-#<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]L;V-A;&4O96Y?55,O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C$V`#$P-3$U
M-#,Q,#8P`#`R,30R,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2<Q+C`G/SX*/"$M+2`D2&]R9&4Z
M(&AO<F1E+V%D;6EN+VQO8V%L92]E;E]54R]H96QP+GAM;"QV(#$N,R`R,#`S
M+S`V+S$T(#`T.C(X.C(Q(&-H=6-K($5X<"`D("TM/@H\:&5L<#X*"CQE;G1R
M>2!I9#TB861M:6XM<&AP<VAE;&PB/@H@("`@/'1I=&QE/D%D;6EN(%1O;VQS
M.B!02%`@4VAE;&P\+W1I=&QE/@H@("`@/&AE861I;F<^2&]W('1O('5S92!T
M:&4@4$A0(%-H96QL/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE(%!(4"!C;VUM
M86YD('-H96QL(&QE=',@>6]U(&5X96-U=&4@87)B:71R87)Y(%!(4`H@("`@
M("`@("`@<W1A=&5M96YT<R!O;B!T:&4@<V5R=F5R+B!4:&5S92!C;VUM86YD
M<R!A<F4@97AE8W5T960@=7-I;F<*("`@("`@("`@('1H92`\8V]D93YE=F%L
M*"D\+V-O9&4^(&9U;F-T:6]N+"!A;F0@97AE8W5T92!I;B!T:&4@8V]N=&5X
M=`H@("`@("`@("`@;V8@=&AE(&-U<G)E;G0@<V5S<VEO;BX@5&AI<R!S:&5L
M;"!I<R!I;G1E;F1E9"!T;R!T<GD@;W5T"B`@("`@("`@("!S>6YT87@@86YD
M(&5X96-U=&4@<V]M92!S:6UP;&4@87)B:71R87)Y(&-O9&4N($YO=&4@=&AA
M="!T;PH@("`@("`@("`@9V5T(&%N>2!O=71P=70L('EO=2!M=7-T(&5C:&\@
M;W(@<')I;G0@<V]M971H:6YG(&EN('EO=7(*("`@("`@("`@(&-O9&4@9G)A
M9VUE;G0N/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)A9&UI;BUS<6QS
M:&5L;"(^"B`@("`\=&ET;&4^061M:6X@5&]O;',Z(%-13"!3:&5L;#PO=&ET
M;&4^"B`@("`\:&5A9&EN9SY(;W<@=&\@=7-E('1H92!344P@4VAE;&P\+VAE
M861I;F<^"B`@("`\<&%R83Y4:&4@4U%,('%U97)Y('-H96QL(&QE=',@>6]U
M(&5X96-U=&4@87)B:71R87)Y(%-13`H@("`@("`@("`@<W1A=&5M96YT<R!O
M;B!Y;W5R(&1A=&%B87-E+B!4:&5S92!C;VUM86YD<R!A<F4@97AE8W5T960*
M("`@("`@("`@(&%G86EN<W0@=&AE(&1A=&%B87-E(&1E9FEN960@:6X@)&-O
M;F9;)W-Q;"==('5S:6YG('1H90H@("`@("`@("`@4$5!4CHZ1$(@8VQA<W-E
M<RX@66]U(&-A;B!U<V4@=&AI<R!T;V]L('1O(&1O('%U97)I97,@:6YT;PH@
M("`@("`@("`@=&AE(&1A=&%B87-E+"!T;R!D;R!C;VUP;&EC871E9"!344P@
M=7!D871E<RP@9&5L971E<RP@971C+BP*("`@("`@("`@(&]R('1O(&1O('-I
M;7!L92!D871A(&-O;&QE8W1I;VXN($ET('-E;F1S(%-13"!Q=65R:65S('1O
M('1H90H@("`@("`@("`@9&%T86)A<V4@9&ER96-T;'DL(&%N9"!W:6QL(')E
M<&]R="!R971U<FX@8V]D97,@86YD(&-O;7!L971E"B`@("`@("`@("!R97-U
M;'0@<V5T<RX\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](F%D;6EN+6-M
M9'-H96QL(CX*("`@(#QT:71L93Y!9&UI;B!4;V]L<SH@0V]M;6%N9"!3:&5L
M;#PO=&ET;&4^"B`@("`\:&5A9&EN9SY(;W<@=&\@=7-E('1H92!#;VUM86YD
M(%-H96QL/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE(&-O;6UA;F0@<VAE;&P@
M;&5T<R!Y;W4@97AE8W5T92!A<F)I=')A<GD@<VAE;&P*("`@("`@("`@(&-O
M;6UA;F1S(&]N('EO=7(@<V5R=F5R+B!9;W4@8V%N('5S92!T:&ES('1O(&1O
M('%U:6-K"B`@("`@("`@("!S:&5L;"!O<&5R871I;VYS(&]R('=H96X@82!S
M:&5L;"!I<R!N;W0@;W1H97)W:7-E(&%V86EL86)L92X*("`@("`@("`@(#PO
M<&%R83X*/"]E;G1R>3X*"CPO:&5L<#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O861M:6XO;&]C86QE+V9I7T9)+P``````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V
M,``P,3<W,3(`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]L;V-A;&4O
M9FE?1DDO:&5L<"YX;6P`````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`T,C8Q`#$P-3$U-#,Q,#8P`#`R,3,V-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*
M/"$M+2`D2&]R9&4Z(&AO<F1E+V%D;6EN+VQO8V%L92]F:5]&22]H96QP+GAM
M;"QV(#$N,2XQ,BXR(#(P,#8O,#(O,C@@,30Z,#(Z,S4@:F%N($5X<"`D("TM
M/@H\:&5L<#X*("`\96YT<GD@:60](F%D;6EN+7!H<'-H96QL(B!M9#4](F0U
M,#$W-3DQ968T83-F,SED.3<X-V(U.#%A,&%B8F$U(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/EEL;"8C>$4T.W!I9&]N('1Y)B-X1C8[:V%L=70Z
M(%!(4"UK;VUE;G1O='5L:VMI/"]T:71L93X*("`@(#QH96%D:6YG/DUI=&5N
M(%!(4"UK;VUE;G1O='5L:VMI82!K)B-X130[>71E="8C>$4T.R8C>$4T.VX\
M+VAE861I;F<^"B`@("`\<&%R83X*("`@(%!(4"UK;VUE;G1O='5L:VMI<W-A
M('9O:2!S=6]R:71T86$@<&%L=F5L:6UE;&QA(&UI="8C>$4T.R!T86AA;G-A
M"B`@("!02%`M:V]M96YT;VIA+B!.)B-X130[;28C>$4T.R!K;VUE;FYO="!S
M=6]R:71E=&%A;B`\8V]D93YE=F%L*"D\+V-O9&4^"B`@("!F=6YK=&EO;B!S
M:7,F(WA%-#ML;"8C>$4T.R!J82!N>6MY:7-E;B!I<W1U;FYO;B!K;VYT96MS
M=&ES<V$N(%0F(WA%-#MM)B-X130["B`@("!K;VUE;G1O='5L:VMI(&]N(&5N
M<VES:6IA:7-E<W1I('1A<FMO:71E='1U('-Y;G1A:W-I;@H@("`@=&%R:VES
M='5K<V5E;B!J82!Y:W-I;FME<G1A:7-E;B!K;V]D:6X@<W5O<FET=6MS965N
M+B!(=6]M86$L"B`@("!E='0F(WA%-#L@='5L;W-T86%K<V5S:2!J;W1A:VEN
M+"!N:6EN('-I;G5N('!I="8C>$4T.R8C>$4T.R!K)B-X130[>71T)B-X130[
M)B-X130[(&5C:&\@:F$*("`@('!R:6YT(&MO;65N=&]J82X*("`@(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](F%D;6EN+7-Q;'-H96QL(B!M9#4]
M(C5B9#)F8V(Y8SDV-SAE-C)C83$T,34V-F%B.&8T8S1F(B!S=&%T93TB=7!T
M;V1A=&4B/@H@("`@/'1I=&QE/EEL;"8C>$4T.W!I9&]N('1Y)B-X1C8[:V%L
M=70Z(%-13"UK;VUE;G1O='5L:VMI/"]T:71L93X*("`@(#QH96%D:6YG/DUI
M=&5N(%-13"UK;VUE;G1O='5L:VMI82!K)B-X130[>71E="8C>$4T.R8C>$4T
M.VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@(%-13"UK;VUE;G1O='5L:VES
M<V$@=F]I('-U;W)I='1A82!M:70F(WA%-#L@=&%H86YS82!344PM;&%U<V5K
M:V5I=&$L(&IO=&MA"B`@("!S=6]R:71E=&%A;B!T:65T;VMA;FYA<W-A+B!+
M)B-X130[>71E='0F(WA%-#MV)B-X130[('1I971O:V%N=&$@;VX*("`@(&TF
M(WA%-#LF(WA%-#MR:71E;'1Y("1C;VYF6R=S<6PG72!J82!S:70F(WA%-#L@
M:R8C>$4T.WET970F(WA%-#LF(WA%-#MN(%!%05(Z1$(M;'5O:V%N"B`@("!A
M=G5L;&$N("!6;VET(&LF(WA%-#MY='0F(WA%-#LF(WA%-#L@="8C>$4T.W0F
M(WA%-#L@='DF(WA&-CMK86QU:F$@=&5H9"8C>$4T.VMS97-I(&MY<V5L>6HF
M(WA%-#L*("`@('1I971O:V%N=&%A;BP@<"8C>$4T.VEV:71T)B-X130[)B-X
M130[:W-E<VD@=&EE=&]J82!T:65T;VMA;FYA<W-A+`H@("`@<&]I<W1A86MS
M97-I('1I971O:F$@=&EE=&]K86YN87-T82!J;F4N('1A:2!H86ME82!T:65T
M;VIA"B`@("!T:65T;VMA;FYA<W1A+B!344PM:V]M96YN;W0@;"8C>$4T.VAE
M=&5T)B-X130[)B-X130[;B!S=6]R86%N('1I971O:V%N;F%L;&4*("`@(&IA
M('!A;'5U87)V;VYA('1U;&5E('-T871U<VMO;V1I(&IA(&MY<V5L>6X@<&%L
M875T=&%M80H@("`@87)V;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](F%D;6EN+6-M9'-H96QL(B!M9#4](CED8F)E-3DS-S,U965B8F(S
M-&1E.3DQ834W8CDX8CEF(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/EEL;"8C>$4T.W!I9&]N('1Y)B-X1C8[:V%L=70Z($MO;65N=&]T=6QK:VD\
M+W1I=&QE/@H@("`@/&AE861I;F<^36ET96X@:V]M96YT;W1U;&MK:6$@:R8C
M>$4T.WET970F(WA%-#LF(WA%-#MN/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@
M("!+;VUE;G1O='5L:VEN(&%V=6QL82!V;VET('-U;W)I='1A82!K;VUE;G1O
M:F$@=W=W+7!A;'9E;&EM96QL82X@5F]I="!K)B-X130[>71T)B-X130[)B-X
M130[('0F(WA%-#MT)B-X130[('1O:6UI;G1O82!K=6X@:&%L=6%T(&YO<&5A
M<W1I('-U;W)I='1A82!J;VYK=6X@:V]M96YN;VX@<&%L=F5L:6UE;&QA(&IA
M(&MO;65N=&]T=6QK:VD@96D@;VQE(&UU=71E;B!K)B-X130[>71E='0F(WA%
M-#MV:7-S)B-X130[+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A
M9&UI;B]L;V-A;&4O:'5?2%4O````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q-S<T-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]H=5](52]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,W-C,`,3`U,34T,S$P
M-C``,#(Q-#(V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y
M+3(B/SX*/"$M+2!(;W)D92`S+C$@061M:6X@:&5L<#H@:'5?2%4@)$AO<F1E
M.B!H;W)D92]A9&UI;B]L;V-A;&4O:'5?2%4O:&5L<"YX;6PL=B`Q+C$N,BXQ
M(#(P,#8O,#,O,#,@,3,Z-#0Z,3$@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\
M96YT<GD@:60](F%D;6EN+7!H<'-H96QL(B!S=&%T93TB=7!T;V1A=&4B(&UD
M-3TB9#4P,3<U.3%E9C1A,V8S.60Y-S@W8C4X,6$P86)B834B/@H@("`@/'1I
M=&QE/D%D;6EN:7-Z='+A8VGS<R!E<WIK]GKV:SH@82!02%`@4VAE;&P\+W1I
M=&QE/@H@("`@/&AE861I;F<^02!02%`@4VAE;&P@:&%S>F[A;&%T83PO:&5A
M9&EN9SX*("`@(#QP87)A/D$@4$A0('!A<F%N8W/I<G1E;&UE>O4@<V5G[71S
MZ6?I=F5L('1E='-Z]6QE9V5S(%!(4"!P87)A;F-S;VMA=`H@("`@("`@("`@
M:&%J=&AA="!VZ6=R92!A('-Z97)V97)E;BX@17IE:V5T(&$@<&%R86YC<V]K
M870@82!GZ7`@87H@"B`@("`@("`@("`\8V]D93YE=F%L*"D\+V-O9&4^(&;\
M9V=VZ6YY('-E9^UT<^EGZ79E;"P@87H@86MT=>%L:7-A;B#I<G;I;GEE<PH@
M("`@("`@("`@<V5S<VEO;B!K97)E=.EB96X@:&%J=&IA(';I9W)E+B!%('!A
M<F%N8W/I<G1E;&UE>O4@8^EL:F$L(&AO9WD*("`@("`@("`@(&MI('1U9&IU
M;FL@<'+S8N%L;FD@=&5T<WKU;&5G97,L(&5G>7-Z97+[8F(@:_-D<NES>FQE
M=&5K970N(`H@("`@("`@("`@06AH;WH@87IO;F)A;BP@:&]G>2!BX7)M:6QY
M96X@;W5T<'5T;W0@;.%S<W5N:RP@82!K\V1N86L@96-H;PH@("`@("`@("`@
M=F%G>2!P<FEN="!P87)A;F-S;VMA="!K96QL('1A<G1A;&UA>FYI82X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F%D;6EN+7-Q;'-H96QL
M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-6)D,F9C8CEC.38W.&4V,F-A,30Q
M-38V86(X9C1C-&8B/@H@("`@/'1I=&QE/D%D;6EN:7-Z='+A8VGS<R!E<WIK
M]GKV:SH@87H@4U%,(%-H96QL/"]T:71L93X*("`@(#QH96%D:6YG/D%Z(%-1
M3"!3:&5L;"!H87-Z;N%L871A/"]H96%D:6YG/@H@("`@/'!A<F$^07H@4U%,
M('!A<F%N8W/I<G1E;&UE>O4@<V5G[71SZ6?I=F5L('1E='-Z]6QE9V5S(%-1
M3"!P87)A;F-S;W0*("`@("`@("`@(&AA:G1H870@=NEG<F4@87H@861A=&+A
M>FES;VXN($5Z96ME="!A('!A<F%N8W-O:V%T(&$@9^EP(&$@4$5!4CHZ1$(*
M("`@("`@("`@('+I=NEN(&AA:G1J82!VZ6=R92!A("1C;VYF6R=S<6PG72UB
M96X@;65G861O='0@861A=&)A>FES;VXN"B`@("`@("`@("!%>GIE;"!A>B!E
M<WIK]GIZ96P@;&5KZ7)D97KI<V5K970L(&)O;GEO;'5L="!344P@;?-D;W/M
M=.%S;VMA="P*("`@("`@("`@('3V<FSI<V5K970@:&%J=&AA="!VZ6=R92P@
M=F%G>2!A9&%T;VMA="!G>?MJ=&AE="X@07H@4U%,('!A<F%N8W-O:V%T"B`@
M("`@("`@("!K]GIV971L96[\;"!A>B!A9&%T8N%Z:7-N86L@:_QL9&DL(&UA
M:F0@=FES<WIA861J82!A>B!E<F5D;>EN>6OS9&]K870*("`@("`@("`@(&EL
M;"X@82!K87!O='0@861A=&]K870N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)A9&UI;BUC;61S:&5L;"(@<W1A=&4](G5P=&]D871E(B!M
M9#4](CED8F)E-3DS-S,U965B8F(S-&1E.3DQ834W8CDX8CEF(CX*("`@(#QT
M:71L93Y!9&UI;FES>G1RX6-I\W,@97-Z:_9Z]FLZ(&$@<&%R86YC<W-O<CPO
M=&ET;&4^"B`@("`\:&5A9&EN9SY!('!A<F%N8W-S;W(@:&%S>F[A;&%T83PO
M:&5A9&EN9SX*("`@(#QP87)A/D$@<&%R86YC<W-O<B!S96?M='/I9^EV96P@
M<&%R86YC<V]K870@:&%J=&AA="!VZ6=R92!A('-Z97)V97)E;BX*("`@("`@
M("`@($5Z(&5G>2UE9WD@<&%R86YC<R!G>6]R<R!VZ6=R96AA:G3A<^%R82!J
M\RP@=F%G>2!A<G)A(&%Z(&5S971R92P@:&$*("`@("`@("`@(&WA<R!M\V1O
M;B!N96T@:^EP97,@82!S>F5R=F5R('!A<F%N8W/I<G1E;&UE>O5JZ6AE>B`H
M0V]M;6%N9"!3:&5L;"D*("`@("`@("`@(&IU=&YI82X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*/"]H96QP/@H`````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]A9&UI;B]P97)M<R\`````````````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q
M-C8R-0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W!E<FUS+V5D:70N
M<&AP````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`V
M-38`,3`U,34T,S$P-C``,#(P,C<P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+V%D;6EN+W!E<FUS+V5D:70N<&AP+'8@,2XS."XR+C4@,C`P-B\P,2\P,2`R
M,3HR.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT
M(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N
M<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T
M:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+RH@4V5T('5P('1H
M92!F;W)M('9A<FEA8FQE<RX@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]687)I
M86)L97,N<&AP)SL*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R
M:6%B;&5S*"D["B1P97)M7VED(#T@)'9A<G,M/F=E="@G<&5R;5]I9"<I.PHD
M8V%T96=O<GD@/2`D=F%R<RT^9V5T*"=C871E9V]R>2<I.PH*+RH@4V5E(&EF
M('=E(&YE960@=&\@*&%N9"!A<F4@<W5P<&]S960@=&\I(&%U=&]C<F5A=&4@
M=&AE('!E<FUI<W-I;VXN("HO"FEF("@D8V%T96=O<GD@(3T](&YU;&PI('L*
M("`@("1P97)M:7-S:6]N(#T@)B1P97)M<RT^9V5T4&5R;6ES<VEO;B@D8V%T
M96=O<GDI.PH@("`@:68@*&ES7V$H)'!E<FUI<W-I;VXL("=014%27T5R<F]R
M)RD@)B8@571I;#HZ9V5T1F]R;41A=&$H)V%U=&]C<F5A=&4G*2D@>PH*("`@
M("`@("`O*B!#:&5C:R!T;R!S964@:68@=&AE('!E<FUI<W-I;VX@=V4@87)E
M(&-O<'EI;F<@9G)O;2!E>&ES=',@8F5F;W)E('=E"B`@("`@("`@("H@875T
M;V-R96%T92X@*B\*("`@("`@("`D8V]P>49R;VT@/2!5=&EL.CIG971&;W)M
M1&%T82@G875T;V-R96%T95]C;W!Y)RD["B`@("`@("`@:68@*"1C;W!Y1G)O
M;2`F)B`A)'!E<FUS+3YE>&ES=',H)&-O<'E&<F]M*2D@>PH@("`@("`@("`@
M("`D8V]P>49R;VT@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)'!A<F5N
M="`]("1V87)S+3YG970H)W!A<F5N="<I.PH@("`@("`@("1P97)M:7-S:6]N
M(#T@)B1P97)M<RT^;F5W4&5R;6ES<VEO;B@D8V%T96=O<GDI.PH@("`@("`@
M("1R97-U;'0@/2`D<&5R;7,M/F%D9%!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL
M("1P87)E;G0I.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1F;W)M(#T@)V5D:70N:6YC)SL*("`@
M("`@("`@("`@)'!E<FU?:60@/2`D<&5R;7,M/F=E=%!E<FUI<W-I;VY)9"@D
M<&5R;6ES<VEO;BD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&-O<'E&<F]M
M*2!["B`@("`@("`@("`@("\J(%=E(&AA=F4@875T;V-R96%T960@=&AE('!E
M<FUI<W-I;VX@86YD('=E(&AA=F4@8F5E;B!T;VQD('1O"B`@("`@("`@("`@
M("`J(&-O<'D@86X@97AI<W1I;F<@<&5R;6ES<VEO;B!F;W(@=&AE(&1E9F%U
M;'1S+B`J+PH@("`@("`@("`@("`D8V]P>49R;VU/8FH@/2`F)'!E<FUS+3YG
M971097)M:7-S:6]N*"1C;W!Y1G)O;2D["B`@("`@("`@("`@("1P97)M:7-S
M:6]N+3YA9&1'=65S=%!E<FUI<W-I;VXH)&-O<'E&<F]M3V)J+3YG971'=65S
M=%!E<FUI<W-I;VYS*"DL(&9A;'-E*3L*("`@("`@("`@("`@)'!E<FUI<W-I
M;VXM/F%D9$1E9F%U;'1097)M:7-S:6]N*"1C;W!Y1G)O;4]B:BT^9V5T1&5F
M875L=%!E<FUI<W-I;VYS*"DL(&9A;'-E*3L*("`@("`@("`@("`@)'!E<FUI
M<W-I;VXM/F%D9$-R96%T;W)097)M:7-S:6]N*"1C;W!Y1G)O;4]B:BT^9V5T
M0W)E871O<E!E<FUI<W-I;VYS*"DL(&9A;'-E*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)&-O<'E&<F]M3V)J+3YG9715<V5R4&5R;6ES<VEO;G,H*2!A<R`D
M=7-E<B`]/B`D=7!E<FTI('L*("`@("`@("`@("`@("`@("1P97)M:7-S:6]N
M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@)'5P97)M+"!F86QS92D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&-O<'E&<F]M3V)J
M+3YG971'<F]U<%!E<FUI<W-I;VYS*"D@87,@)&=R;W5P(#T^("1G<&5R;2D@
M>PH@("`@("`@("`@("`@("`@)'!E<FUI<W-I;VXM/F%D9$=R;W5P4&5R;6ES
M<VEO;B@D9W)O=7`L("1G<&5R;2P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@5V4@:&%V92!A=71O8W)E
M871E9"!T:&4@<&5R;6ES<VEO;B!A;F0@=V4@9&]N)W0@:&%V92!A;@H@("`@
M("`@("`@("`@*B!E>&ES=&EN9R!P97)M:7-S:6]N('1O(&-O<'DN("!3964@
M:68@<V]M92!D969A=6QT<R!W97)E"B`@("`@("`@("`@("`J('-U<'!L:65D
M+B`J+PH@("`@("`@("`@("`D861D4&5R;7,@/2!5=&EL.CIG971&;W)M1&%T
M82@G875T;V-R96%T95]G=65S="<I.PH@("`@("`@("`@("!I9B`H)&%D9%!E
M<FUS*2!["B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO;BT^861D1W5E<W10
M97)M:7-S:6]N*"1A9&1097)M<RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1A9&1097)M<R`](%5T:6PZ.F=E=$9O<FU$871A*"=A=71O
M8W)E871E7V1E9F%U;'0G*3L*("`@("`@("`@("`@:68@*"1A9&1097)M<RD@
M>PH@("`@("`@("`@("`@("`@)'!E<FUI<W-I;VXM/F%D9$1E9F%U;'1097)M
M:7-S:6]N*"1A9&1097)M<RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1A9&1097)M<R`](%5T:6PZ.F=E=$9O<FU$871A*"=A=71O8W)E
M871E7V-R96%T;W(G*3L*("`@("`@("`@("`@:68@*"1A9&1097)M<RD@>PH@
M("`@("`@("`@("`@("`@)'!E<FUI<W-I;VXM/F%D9$-R96%T;W)097)M:7-S
M:6]N*"1A9&1097)M<RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@("1P97)M:7-S:6]N+3YS879E*"D["B`@("!](&5L<V4@>PH@
M("`@("`@("1P97)M7VED(#T@)'!E<FUS+3YG971097)M:7-S:6]N260H)'!E
M<FUI<W-I;VXI.PH@("`@?0H@("`@)'9A<G,M/G-E="@G<&5R;5]I9"<L("1P
M97)M7VED*3L*?2!E;'-E('L*("`@("1P97)M:7-S:6]N(#T@)B1P97)M<RT^
M9V5T4&5R;6ES<VEO;D)Y260H)'!E<FU?:60I.PI]"@HO*B!)9B!T:&4@<&5R
M;6ES<VEO;B!F971C:&5D(&ES(&%N(&5R<F]R(')E='5R;B!T;R!T:&4@<&5R
M;6ES<VEO;G,@;&ES="X@*B\*:68@*&ES7V$H)'!E<FUI<W-I;VXL("=014%2
M7T5R<F]R)RDI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M861M:6XO<&5R;7,O:6YD97@N<&AP)RP@=')U92D["B`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@IR97%U:7)E7V]N8V4@
M)TAO<F1E+U!E<FUS+U5)+G!H<"<["B1U:2`]("9N97<@4&5R;7-?54DH)'!E
M<FUS*3L*)'5I+3YS971687)S*"1V87)S*3L*)'5I+3YS971U<$5D:71&;W)M
M*"1P97)M:7-S:6]N*3L*"FEF("@D=6DM/G9A;&ED871E161I=$9O<FTH)&EN
M9F\I*2!["B`@("`O*B!5<&1A=&4@86YD('-A=F4@=&AE('!E<FUI<W-I;VYS
M+B`J+PH@("`@)'!E<FUI<W-I;VXM/G5P9&%T95!E<FUI<W-I;VYS*"1I;F9O
M*3L*("`@("1P97)M:7-S:6]N+3YS879E*"D["B`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B57!D871E9"!<(B5S7"(N(BDL("1P97)M<RT^
M9V5T5&ET;&4H)'!E<FUI<W-I;VXM/F=E=$YA;64H*2DI+"`G:&]R9&4N<W5C
M8V5S<R<I.PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@G861M:6XO
M<&5R;7,O961I="YP:'`G+"`G<&5R;5]I9"<L("1P97)M:7-S:6]N+3YG971)
M9"@I*3L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)'5R;"P@
M=')U92D["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E
M>&ET.PI]"@HD=&ET;&4@/2!?*")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E
M<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH
M)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*"B\J(%)E;F1E<B!T:&4@9F]R
M;2!A;F0@=')E92X@*B\*)'5I+3YR96YD97)&;W)M*"=E9&ET+G!H<"<I.PIE
M8VAO("<\8G(@+SXG.PHD=6DM/G)E;F1E<E1R964H)'!E<FU?:60I.PH*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R;7,O861D8VAI;&0N<&AP````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8S,P`Q,#4Q-30S
M,3`V,``P,C$P-S4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP+'8@,2XR-RXR+C0@,C`P-B\P,2\P,2`R,3HR.#HP
M-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#4M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*
M"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC
M871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+RH@4V5T('5P('1H92!F;W)M
M('9A<FEA8FQE<RX@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L97,N
M<&AP)SL*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B;&5S
M*"D["B1P97)M7VED(#T@)'9A<G,M/F=E="@G<&5R;5]I9"<I.PH*)'!E<FUI
M<W-I;VX@/2`F)'!E<FUS+3YG971097)M:7-S:6]N0GE)9"@D<&5R;5]I9"D[
M"FEF("AI<U]A*"1P97)M:7-S:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*%\H(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O:6YD97@N<&AP)RP@=')U92D["B`@
M("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HO
M*B!3970@=7`@9F]R;2X@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]097)M<R]5
M22YP:'`G.PHD=6D@/2`F;F5W(%!E<FUS7U5)*"1P97)M<RD["B1U:2T^<V5T
M5F%R<R@D=F%R<RD["B1U:2T^<V5T=7!!9&1&;W)M*"1P97)M:7-S:6]N*3L*
M"FEF("@D=6DM/G9A;&ED871E061D1F]R;2@D:6YF;RDI('L*("`@(&EF("@D
M:6YF;ULG<&5R;5]I9"==(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`D
M8VAI;&0@/2`F)'!E<FUS+3YN97=097)M:7-S:6]N*"1I;F9O6R=C:&EL9"==
M*3L*("`@("`@("`D<F5S=6QT(#T@)'!E<FUS+3YA9&1097)M:7-S:6]N*"1C
M:&EL9"D["B`@("!](&5L<V4@>PH@("`@("`@("1P3V(@/2`F)'!E<FUS+3YG
M971097)M:7-S:6]N0GE)9"@D:6YF;ULG<&5R;5]I9"==*3L*("`@("`@("`D
M;F%M92`]("1P3V(M/F=E=$YA;64H*2`N("<Z)R`N($1A=&%4<F5E.CIE;F-O
M9&5.86UE*"1I;F9O6R=C:&EL9"==*3L*("`@("`@("`D8VAI;&0@/2`F)'!E
M<FUS+3YN97=097)M:7-S:6]N*"1N86UE*3L*("`@("`@("`D<F5S=6QT(#T@
M)'!E<FUS+3YA9&1097)M:7-S:6]N*"1C:&EL9"D["B`@("!]"B`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(EPB)7-<(B!W87,@;F]T(&-R96%T
M960Z("5S+B(I+"`D<&5R;7,M/F=E=%1I=&QE*"1C:&EL9"T^9V5T3F%M92@I
M*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN(BDL("1P97)M<RT^9V5T5&ET;&4H)&-H:6QD+3YG971.86UE*"DI*2P@
M)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=A9&UI;B]P97)M<R]E9&ET+G!H<"<L('1R=64I.PH@("`@
M("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W!E<FU?:60G
M+"`D8VAI;&0M/F=E=$ED*"DL(&9A;'-E*3L*("`@("`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@97AI=#L*("`@('T*?0H*)'1I
M=&QE(#T@7R@B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB*3L*<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH96%D97(N
M:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G
M(#T^("=S=&%T=7,G*2D["@HO*B!296YD97(@=&AE(&9O<FT@86YD('1R964N
M("HO"B1U:2T^<F5N9&5R1F]R;2@G861D8VAI;&0N<&AP)RD["F5C:&\@)SQB
M<B`O/B<["B1U:2T^<F5N9&5R5')E92@D<&5R;5]I9"D["@IR97%U:7)E($A/
M4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R;7,O:6YD
M97@N<&AP````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,38U,@`Q,#4Q-30S,3`V,``P,C`T-#8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O861M:6XO<&5R;7,O:6YD97@N<&AP+'8@,2XQ,"XQ,"XS(#(P,#8O,#$O
M,#$@,C$Z,C@Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-
M96YU+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z
M.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B1P97)M7VED
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W!E<FU?:60G*3L*"B1T:71L92`](%\H
M(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(BD["G)E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<["B1N
M;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A
M='5S)RDI.PH*<F5Q=6ER95]O;F-E("=(;W)D92]097)M<R]522YP:'`G.PHD
M=6D@/2`F;F5W(%!E<FUS7U5)*"1P97)M<RD["B1U:2T^<F5N9&5R5')E92@D
M<&5R;5]I9"D["@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N
M+69O;W1E<BYI;F,G.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R
M;7,O9&5L971E+G!H<```````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#8Q-@`Q,#4Q-30S,3`V,``P,C`V,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O861M:6XO<&5R;7,O9&5L971E+G!H<"QV(#$N,3DN."XT(#(P
M,#8O,#$O,#$@,C$Z,C@Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@
M2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]-96YU+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@
M2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\J
M(%-E="!U<"!T:&4@9F]R;2!V87)I86)L97,N("HO"G)E<75I<F5?;VYC92`G
M2&]R9&4O5F%R:6%B;&5S+G!H<"<["B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T
M1&5F875L=%9A<FEA8FQE<R@I.PHD<&5R;5]I9"`]("1V87)S+3YG970H)W!E
M<FU?:60G*3L*)&-A=&5G;W)Y(#T@)'9A<G,M/F=E="@G8V%T96=O<GDG*3L*
M)'!E<FUI<W-I;VX@/2`F)'!E<FUS+3YG971097)M:7-S:6]N0GE)9"@D<&5R
M;5]I9"D["@HO*B!)9B!T:&4@<&5R;6ES<VEO;B!F971C:&5D(&ES(&%N(&5R
M<F]R(')E='5R;B!T;R!P97)M:7-S:6]N<R!L:7-T+B`J+PII9B`H:7-?82@D
M<&5R;6ES<VEO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"A?*")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("1U<FP@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W!E<FUS+VEN9&5X+G!H<"<L('1R
M=64I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI
M=#L*?0H*+RH@4V5T('5P(&9O<FTN("HO"G)E<75I<F5?;VYC92`G2&]R9&4O
M4&5R;7,O54DN<&AP)SL*)'5I(#T@)FYE=R!097)M<U]522@D<&5R;7,I.PHD
M=6DM/G-E=%9A<G,H)'9A<G,I.PHD=6DM/G-E='5P1&5L971E1F]R;2@D<&5R
M;6ES<VEO;BD["@II9B`H)&-O;F9I<FUE9"`]("1U:2T^=F%L:61A=&5$96QE
M=&5&;W)M*"1I;F9O*2D@>PH@("`@)')E<W5L="`]("1P97)M<RT^<F5M;W9E
M4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BP@=')U92D["B`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"AS<')I;G1F*%\H(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB*2P@)'!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M92@I
M*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(BDL("1P97)M<RT^
M9V5T5&ET;&4H)'!E<FUI<W-I;VXM/F=E=$YA;64H*2DI+"`G:&]R9&4N<W5C
M8V5S<R<I.PH@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)V%D;6EN+W!E<FUS+VEN9&5X+G!H<"<L('1R=64I.PH@("`@("`@(&AE861E
M<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@("`@("!E>&ET.PH@("`@?0I]
M(&5L<V5I9B`H)&-O;F9I<FUE9"`]/3T@9F%L<V4I('L*("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")097)M:7-S:6]N(%PB)7-<(B!N;W0@
M9&5L971E9"XB*2P@)'!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T
M3F%M92@I*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`D=7)L(#T@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E
M*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70[
M"GT*"B1T:71L92`](%\H(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(BD[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN
M8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES
M=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*+RH@4F5N9&5R('1H92!F;W)M(&%N
M9"!T<F5E+B`J+PHD=6DM/G)E;F1E<D9O<FTH)V1E;&5T92YP:'`G*3L*96-H
M;R`G/&)R("\^)SL*)'5I+3YR96YD97)4<F5E*"1P97)M7VED*3L*"G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O861M:6XO<V5T=7`O````````````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,38V,S<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]S971U<"]D:69F+G!H<```````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-3`W`#$P-3$U
M-#,Q,#8P`#`R,#(V-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@4V-R:7!T('1O('-H;W<@=&AE(&1I
M9F9E<F5N8V5S(&)E='=E96X@=&AE(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE
M(&YE=VQY"B`J(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@*@H@*B`D2&]R
M9&4Z(&AO<F1E+V%D;6EN+W-E='5P+V1I9F8N<&AP+'8@,2XT+C$P+C4@,C`P
M-B\P-2\R,R`P,CHQ,SHT,B!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!4:&4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D
M92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*9&5F:6YE*"=(3U)$15]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC
M92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+T9O<FTN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#;VYF:6<N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]496UP;&%T92YP:'`G.PII;F-L
M=61E7V]N8V4@)U1E>'0O1&EF9BYP:'`G.PII;F-L=61E7V]N8V4@)U1E>'0O
M1&EF9B]296YD97)E<BYP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*
M("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["GT*"B\J(%-E="!U<"!T:&4@9&EF9B!R96YD97)E<BX@*B\*)')E
M;F1E<E]T>7!E(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E;F1E<B<L("=I;FQI
M;F4G*3L*:6YC;'5D95]O;F-E("=497AT+T1I9F8O4F5N9&5R97(O)R`N("1R
M96YD97)?='EP92`N("<N<&AP)SL*)&-L87-S(#T@)U1E>'1?1&EF9E]296YD
M97)E<E\G("X@)')E;F1E<E]T>7!E.PHD<F5N9&5R97(@/2`F;F5W("1C;&%S
M<R@I.PH*+RHJ"B`J(%!R:79A=&4@9G5N8W1I;VX@=&\@<F5N9&5R('1H92!D
M:69F97)E;F-E<R!F;W(@82!S<&5C:69I8R!A<'`N"B`J+PIF=6YC=&EO;B!?
M9V5T1&EF9B@D87!P*0I["B`@("!G;&]B86P@)')E;F1E<F5R+"`D<F5G:7-T
M<GD["@H@("`@+RH@4F5A9"!T:&4@97AI<W1I;F<@8V]N9FEG=7)A=&EO;BX@
M*B\*("`@("1C=7)R96YT7V-O;F9I9R`]("<G.PH@("`@)'!A=&@@/2`D<F5G
M:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*("`@
M("1C=7)R96YT7V-O;F9I9R`]($!F:6QE7V=E=%]C;VYT96YT<R@D<&%T:"`N
M("<O8V]N9BYP:'`G*3L*"B`@("`O*B!#86QC=6QA=&4@=&AE(&1I9F9E<F5N
M8V5S+B`J+PH@("`@)&1I9F8@/2`F;F5W(%1E>'1?1&EF9BAE>'!L;V1E*")<
M;B(L("1C=7)R96YT7V-O;F9I9RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5X<&QO9&4H(EQN(BP@)%]315-324].6R=?8V]N9FEG)UU;)&%P<%TI
M*3L*("`@("1D:69F(#T@)')E;F1E<F5R+3YR96YD97(H)&1I9F8I.PH@("`@
M:68@*"%E;7!T>2@D9&EF9BDI('L*("`@("`@("!R971U<FX@)&1I9F8["B`@
M("!](&5L<V4@>PH@("`@("`@(')E='5R;B!?*").;R!C:&%N9V4N(BD["B`@
M("!]"GT*"B1D:69F<R`](&%R<F%Y*"D["B\J($]N;'D@8F]T:&5R('1O(&1O
M(&%N>71H:6YG(&EF('1H97)E(&ES(&%N>2!C;VYF:6<N("HO"FEF("@A96UP
M='DH)%]315-324].6R=?8V]N9FEG)UTI*2!["B`@("`O*B!3970@=7`@=&AE
M('1O9V=L92!B=71T;VX@9F]R(&EN;&EN92]U;FEF:65D+B`J+PH@("`@)'5R
M;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O9&EF9BYP
M:'`G*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W)E
M;F1E<B<L("@D<F5N9&5R7W1Y<&4@/3T@)VEN;&EN92<I(#\@)W5N:69I960G
M(#H@)VEN;&EN92<I.PH*("`@(&EF("@D87!P(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V%P<"<I*2!["B`@("`@("`@+RH@2&%N9&QE(&$@<VEN9VQE(&%P<"!R
M97%U97-T+B`J+PH@("`@("`@("1T;V=G;&5?<F5N9&5R97(@/2!(;W)D93HZ
M;&EN:R@D=7)L("X@)R,G("X@)&%P<"D@+B`H*"1R96YD97)?='EP92`]/2`G
M:6YL:6YE)RD@/R!?*")U;FEF:65D(BD@.B!?*")I;FQI;F4B*2D@+B`G/"]A
M/B<["B`@("`@("`@)&1I9F8@/2!?9V5T1&EF9B@D87!P*3L*("`@("`@("!I
M9B`H)')E;F1E<E]T>7!E("$]("=I;FQI;F4G*2!["B`@("`@("`@("`@("1D
M:69F(#T@:'1M;'-P96-I86QC:&%R<R@D9&EF9BD["B`@("`@("`@?0H@("`@
M("`@("1D:69F<UM=(#T@87)R87DH)V%P<"<@(#T^("1A<'`L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&EF9B<@/3X@)&1I9F8L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G=&]G9VQE7W)E;F1E<F5R)R`]/B`D=&]G9VQE7W)E
M;F1E<F5R*3L*("`@('T@96QS92!["B`@("`@("`@+RH@3&ES="!A;&P@=&AE
M(&%P<',@=VET:"!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX@*B\*("`@("`@
M("!K<V]R="@D7U-%4U-)3TY;)U]C;VYF:6<G72D["B`@("`@("`@9F]R96%C
M:"`H)%]315-324].6R=?8V]N9FEG)UT@87,@)&%P<"`]/B`D8V]N9FEG*2![
M"B`@("`@("`@("`@("1T;V=G;&5?<F5N9&5R97(@/2!(;W)D93HZ;&EN:R@D
M=7)L("X@)R,G("X@)&%P<"D@+B`H*"1R96YD97)?='EP92`]/2`G:6YL:6YE
M)RD@/R!?*")U;FEF:65D(BD@.B!?*")I;FQI;F4B*2D@+B`G/"]A/B<["B`@
M("`@("`@("`@("1D:69F(#T@7V=E=$1I9F8H)&%P<"D["B`@("`@("`@("`@
M(&EF("@D<F5N9&5R7W1Y<&4@(3T@)VEN;&EN92<I('L*("`@("`@("`@("`@
M("`@("1D:69F(#T@:'1M;'-P96-I86QC:&%R<R@D9&EF9BD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&1I9F9S6UT@/2!A<G)A>2@G87!P)R`@/3X@
M)&%P<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&EF9B<@/3X@
M)&1I9F8L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O9V=L95]R
M96YD97)E<B<@/3X@)'1O9V=L95]R96YD97)E<BD["B`@("`@("`@?0H@("`@
M?0I]"@HO*B!3970@=7`@=&AE('1E;7!L871E+B`J+PHD=&5M<&QA=&4@/2`F
M;F5W($AO<F1E7U1E;7!L871E*"D["B1T96UP;&%T92T^<V5T3W!T:6]N*"=G
M971T97AT)RP@=')U92D["B1T96UP;&%T92T^<V5T*"=D:69F<R<L("1D:69F
M<RP@=')U92D["@HD=&ET;&4@/2!?*")#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["F5C:&\@)'1E;7!L871E+3YF971C:"A(3U)$15]414U03$%4
M15,@+B`G+V%D;6EN+W-E='5P+V1I9F8N:'1M;"<I.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<V5T=7`O8V]N9FEG+G!H<```
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,38W,0`Q,#4Q
M-30S,3`V,``P,C`V,C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO
M<V5T=7`O8V]N9FEG+G!H<"QV(#$N,C0N-"XQ,"`R,#`V+S`S+S,P(#$P.C$U
M.C,P('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R
M;2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTO06-T:6]N+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+T-O;F9I9RYP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U9A<FEA8FQE<RYP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*
M("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["GT*"FEF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=D;VUX;6PG
M*2`F)B`A571I;#HZ97AT96YS:6]N17AI<W1S*"=D;VTG*2D@>PH@("`@2&]R
M9&4Z.F9A=&%L*"=9;W4@;F5E9"!T:&4@9&]M>&UL(&]R(&1O;2!02%`@97AT
M96YS:6]N('1O('5S92!T:&4@8V]N9FEG=7)A=&EO;B!T;V]L+B<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["GT*"B1A<'`@/2!5=&EL.CIG971&;W)M1&%T82@G
M87!P)RD["B1A<'!N86UE(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P
M*3L*)'1I=&QE(#T@<W!R:6YT9BA?*"(E<R!3971U<"(I+"`D87!P;F%M92D[
M"@II9B`H)&%P<"`]/3T@;G5L;"`F)@H@("`@:6Y?87)R87DH)&%P<"P@)')E
M9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G:6YA8W1I=F4G+"`G:&ED9&5N)RP@
M)VYO=&]O;&)A<B<L("=A8W1I=F4G+"`G861M:6XG*2DI*2!["B`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(DEN=F%L:60@87!P;&EC871I;VXN(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G861M:6XO<V5T=7`O:6YD97@N<&AP)RP@=')U92D["B`@("!H96%D97(H
M)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HD=F%R<R`](%9A
M<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PHD9F]R;2`]("9N97<@
M0V]N9FEG1F]R;2@D=F%R<RP@)&%P<"D["B1F;W)M+3YS971"=71T;VYS*'-P
M<FEN=&8H7R@B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(I+"`D87!P;F%M
M92DI.PII9B`H9FEL95]E>&ES=',H)')E9VES=')Y+3YG970H)V9I;&5R;V]T
M)RP@)&%P<"D@+B`G+V-O;F9I9R]C;VYF+G!H<"YB86LG*2D@>PH@("`@)&9O
M<FTM/F%P<&5N9$)U='1O;G,H7R@B4F5V97)T($-O;F9I9W5R871I;VXB*2D[
M"GT*"B1P:'`@/2`G)SL*:68@*%5T:6PZ.F=E=$9O<FU$871A*"=S=6)M:71B
M=71T;VXG*2`]/2!?*")2979E<G0@0V]N9FEG=7)A=&EO;B(I*2!["B`@("`D
M<&%T:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C
M;VYF:6<G.PH@("`@:68@*$!C;W!Y*"1P871H("X@)R]C;VYF+G!H<"YB86LG
M+"`D<&%T:"`N("<O8V]N9BYP:'`G*2D@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB*2P@)VAO<F1E+G-U8V-E<W,G
M*3L*("`@("`@("!`=6YL:6YK*"1P871H("X@)R]C;VYF+G!H<"YB86LG*3L*
M("`@('T@96QS92!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(BDL("=H;W)D92YE<G)O
M<B<I.PH@("`@?0I](&5L<V5I9B`H)&9O<FTM/G9A;&ED871E*"1V87)S*2D@
M>PH@("`@)&-O;F9I9R`]("9N97<@2&]R9&5?0V]N9FEG*"1A<'`I.PH@("`@
M)'!H<"`]("1C;VYF:6<M/F=E;F5R871E4$A00V]N9FEG*"1V87)S*3L*("`@
M("1P871H(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+V-O;F9I9R<["B`@("!I9B`H9FEL95]E>&ES=',H)'!A=&@@+B`G+V-O;F8N
M<&AP)RDI('L*("`@("`@("!I9B`H0&-O<'DH)'!A=&@@+B`G+V-O;F8N<&AP
M)RP@)'!A=&@@+B`G+V-O;F8N<&AP+F)A:R<I*2!["B`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(BDL(%5T:6PZ
M.G)E86Q0871H*"1P871H("X@)R]C;VYF+G!H<"YB86LG*2DL("=H;W)D92YS
M=6-C97-S)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(I+"!5=&EL.CIR96%L4&%T
M:"@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RDI+"`G:&]R9&4N=V%R;FEN9R<I
M.PH@("`@("`@('T*("`@('T*("`@(&EF("@D9G`@/2!`9F]P96XH)'!A=&@@
M+B`G+V-O;F8N<&AP)RP@)W<G*2D@>PH@("`@("`@("\J($-A;B!W<FET92P@
M<V\@;W5T<'5T('1O(&9I;&4N("HO"B`@("`@("`@9G=R:71E*"1F<"P@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D<&AP+"!.3%,Z.F=E=$-H87)S970H*2P@
M)VES;RTX.#4Y+3$G*2D["B`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!W
M<F]T92`E<R(I+"!5=&EL.CIR96%L4&%T:"@D<&%T:"`N("<O8V]N9BYP:'`G
M*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@)')E9VES=')Y+3YC;&5A
M<D-A8VAE*"D["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O:6YD97@N<&AP)RP@=')U
M92DI.PH@("`@("`@(&5X:70["B`@("!](&5L<V4@>PH@("`@("`@("\J($-A
M;FYO="!W<FET92X@*B\*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P
M<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RXB*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@@
M+B`G+V-O;F8N<&AP)RDL($AO<F1E.CIL:6YK*$AO<F1E.CIU<FPH)VEN9&5X
M+G!H<"<I("X@)R-U<&1A=&4G+"!?*")3971U<"(I*2`N(%\H(E-E='5P(BD@
M+B`G/"]A/B<L(%5T:6PZ.G)E86Q0871H*"1P871H("X@)R]C;VYF+G!H<"<I
M*2P@)VAO<F1E+G=A<FYI;F<G+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@
M("`@("`@+RH@4V%V92!T;R!S97-S:6]N+B`J+PH@("`@("`@("1?4T534TE/
M3ELG7V-O;F9I9R==6R1A<'!=(#T@)'!H<#L*("`@('T*?2!E;'-E:68@*"1F
M;W)M+3YI<U-U8FUI='1E9"@I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F
M;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+B(I
M+"`G:&]R9&4N97)R;W(G*3L*?0H*+RH@4F5N9&5R('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN("HO"G)E<75I<F5?;VYC92`G2&]R9&4O54DO5F%R4F5N9&5R
M97(N<&AP)SL*)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R
M*"D["B1R96YD97)E<BT^<V5T071T<D-O;'5M;E=I9'1H*"<U,"4G*3L*)&9O
M<FT@/2!5=&EL.CIB=69F97)/=71P=70H87)R87DH)&9O<FTL("=R96YD97)!
M8W1I=F4G*2P@)')E;F1E<F5R+"`D=F%R<RP@)V-O;F9I9RYP:'`G+"`G<&]S
M="<I.PH*"B\J(%-E="!U<"!T:&4@=&5M<&QA=&4N("HO"G)E<75I<F5?;VYC
M92`G2&]R9&4O5&5M<&QA=&4N<&AP)SL*)'1E;7!L871E(#T@)FYE=R!(;W)D
M95]496UP;&%T92@I.PHD=&5M<&QA=&4M/G-E="@G<&AP)RP@:'1M;'-P96-I
M86QC:&%R<R@D<&AP*2P@=')U92D["B\J($-R96%T92!T:&4@;&EN:R!F;W(@
M=&AE(&1I9F8@<&]P=7`@;VYL>2!I9B!S=&]R960@:6X@<V5S<VEO;BX@*B\*
M:68@*"%E;7!T>2@D7U-%4U-)3TY;)U]C;VYF:6<G75LD87!P72DI('L*("`@
M($AO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D92<L('1R
M=64I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO
M<V5T=7`O9&EF9BYP:'`G*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T
M97(H)'5R;"P@)V%P<"<L("1A<'`I.PH@("`@)&QI;FL@/2!(;W)D93HZ;&EN
M:R@G(R<L("<G+"`G)RP@)R<L("=P;W!U<"A<)R<@+B`D=7)L("X@)UPG+"`V
M-#`L(#0X,"D[(')E='5R;B!F86QS93LG*2`N(%\H(G-H;W<@9&EF9F5R96YC
M97,B*2`N("<\+V$^)SL*("`@("1T96UP;&%T92T^<V5T*"=D:69F7W!O<'5P
M)RP@)&QI;FLI.PI]"B1T96UP;&%T92T^<V5T*"=F;W)M)RP@)&9O<FTI.PHD
M=&5M<&QA=&4M/G-E="@G;F]T:69Y)RP@571I;#HZ8G5F9F5R3W5T<'5T*&%R
M<F%Y*"1N;W1I9FEC871I;VXL("=N;W1I9GDG*2DI.PHD=&5M<&QA=&4M/G-E
M=$]P=&EO;B@G9V5T=&5X="<L('1R=64I.PH*<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*96-H;R`D
M=&5M<&QA=&4M/F9E=&-H*$A/4D1%7U1%35!,051%4R`N("<O861M:6XO<V5T
M=7`O8V]N9FEG+FAT;6PG*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W-E='5P+VEN9&5X
M+G!H<```````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(R
M-3$`,3`U,34T,S$P-C``,#(P-#4V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+V%D;6EN+W-E='5P+VEN9&5X+G!H<"QV(#$N,C@N-"XQ,B`R,#`V+S`S+S(X
M(#$R.C,Q.C`X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M5&5M<&QA=&4N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(
M;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PI]"@HO*BH*("H@4F5T=7)N<R!T:&4@0U93('9E<G-I;VX@9F]R(&$@9VEV
M96X@9FEL92X*("HO"F9U;F-T:6]N(%]G971697)S:6]N*"1F:6QE*0I["B`@
M("`D<VEZ92`]($!F:6QE<VEZ92@D9FEL92D["B`@("!I9B`H(21S:7IE('Q\
M("%I<U]R97-O=7)C92@D9G`@/2!`9F]P96XH)&9I;&4L("=R)RDI*2!["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@)&1A=&$@/2!`9G)E860H
M)&9P+"`D<VEZ92D["B`@("!I9B`H<')E9U]M871C:"@G+UPD+BH_8V]N9EPN
M>&UL+'8@*"XJ/RD@+BI<)"\G+"`D9&%T82P@)&UA=&-H*2D@>PH@("`@("`@
M(')E='5R;B`D;6%T8VA;,5T["B`@("!](&5L<V4@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*?0H*+RHJ"B`J($1O97,@86X@1E10('5P;&]A9"!T
M;R!S879E('1H92!C;VYF:6=U<F%T:6]N+@H@*B\*9G5N8W1I;VX@7W5P;&]A
M9$944"@D<&%R86US*0I["B`@("!G;&]B86P@)')E9VES=')Y+"`D;F]T:69I
M8V%T:6]N.PH*("`@(')E<75I<F5?;VYC92`G5D93+G!H<"<["B`@("`D<&%R
M86US6R=H;W-T<W!E8R==(#T@)VQO8V%L:&]S="<["B`@("`D=F9S(#T@)E9&
M4SHZ<VEN9VQE=&]N*"=F='`G+"`D<&%R86US*3L*("`@(&EF("AI<U]A*"1V
M9G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(BDL("1P87)A;7-;)VAO<W1S<&5C)UTL("1V
M9G,M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*B!,;V]P('1H<F]U9V@@=&AE(&-O
M;F9I9R!A;F0@=W)I=&4@=&\@1E10+B`J+PH@("`@)&YO7V5R<F]R<R`]('1R
M=64["B`@("!F;W)E86-H("@D7U-%4U-)3TY;)U]C;VYF:6<G72!A<R`D87!P
M(#T^("1C;VYF:6<I('L*("`@("`@("`D<&%T:"`]("1R96=I<W1R>2T^9V5T
M*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G.PH@("`@("`@("\J(%1R
M>2!T;R!B86-K('5P('1H92!C=7)R96YT(&-O;F8N<&AP+B`J+PH@("`@("`@
M(&EF("@D=F9S+3YE>&ES=',H)'!A=&@L("=C;VYF+G!H<"<I*2!["B`@("`@
M("`@("`@(&EF("@H)')E<W5L="`]("1V9G,M/G)E;F%M92@D<&%T:"P@)V-O
M;F8N<&AP)RP@)'!A=&@L("<O8V]N9BYP:'`N8F%K)RDI(#T]/2!T<G5E*2![
M"B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB*2P@)VAO<F1E
M+G-U8V-E<W,G*3L*("`@("`@("`@("`@?2!E;'-E:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"AS<')I;G1F*%\H(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,B*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1W<FET92`]("1V9G,M
M/G=R:71E1&%T82@D<&%T:"P@)V-O;F8N<&AP)RP@)&-O;F9I9RD["B`@("`@
M("`@:68@*&ES7V$H)'=R:71E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("1N;U]E<G)O<G,@/2!F86QS93L*("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"AS<')I;G1F*%\H(D-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B!<(B5S7"(Z("5S(BDL("1A<'`L("1W<FET92T^9V5T365S
M<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(I+"!5=&EL.CIR96%L4&%T:"@D<&%T:"`N("<O
M8V]N9BYP:'`G*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@('5N
M<V5T*"1?4T534TE/3ELG7V-O;F9I9R==6R1A<'!=*3L*("`@("`@("!]"B`@
M("!]"B`@("`D<F5G:7-T<GDM/F-L96%R0V%C:&4H*3L*("`@(')E='5R;B`D
M;F]?97)R;W)S.PI]"@HO*B!3970@=7`@<V]M92!I8V]N<RX@*B\*)'-U8V-E
M<W,@/2!(;W)D93HZ:6UG*"=A;&5R=',O<W5C8V5S<RYP;F<G+"`G)RP@)R<L
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI.PHD=V%R;FEN9R`]
M($AO<F1E.CII;6<H)V%L97)T<R]W87)N:6YG+G!N9R<L("<G+"`G)RP@)')E
M9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D["B1E<G)O<B`]($AO<F1E
M.CII;6<H)V%L97)T<R]E<G)O<BYP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI.PH*)&-O;F9?=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=A9&UI;B]S971U<"]C;VYF:6<N<&AP)RD["B1A(#T@
M)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G:6YA8W1I=F4G+"`G:&ED9&5N
M)RP@)VYO=&]O;&)A<B<L("=A8W1I=F4G+"`G861M:6XG*2D["B1A<'!S(#T@
M87)R87DH*3L*)&D@/2`M,3L*9F]R96%C:"`H)&$@87,@)&%P<"D@>PH@("`@
M+RH@4VMI<"!A<'`@:68@;F\@8V]N9BYX;6P@9FEL92X@*B\*("`@("1P871H
M(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I
M9R<["B`@("!I9B`H(69I;&5?97AI<W1S*"1P871H("X@)R]C;VYF+GAM;"<I
M*2!["B`@("`@("`@8V]N=&EN=64["B`@("!]"@H@("`@)&DK*SL*("`@("1P
M871H(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O
M;F9I9R<["@H@("`@)&-O;F9?;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M8V]N9E]U<FPL("=A<'`G+"`D87!P*3L*("`@("1C;VYF7VQI;FL@/2!(;W)D
M93HZ;&EN:R@D8V]N9E]L:6YK+"!S<')I;G1F*%\H(D-O;F9I9W5R92`E<R(I
M+"`D87!P*2D["B`@("`D87!P<ULD:5U;)W-O<G0G72`]("1R96=I<W1R>2T^
M9V5T*"=N86UE)RP@)&%P<"D@+B`G("@G("X@)&%P<"`N("<I)SL*("`@("1A
M<'!S6R1I75LG;F%M92==(#T@)&-O;F9?;&EN:R`N("1A<'!S6R1I75LG<V]R
M="==("X@)SPO83XG.PH@("`@)&%P<'-;)&E=6R=V97)S:6]N)UT@/2`G)SL*
M("`@(&EF("AI<U]R96%D86)L92@D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`D87!P*2`N("<O;&EB+W9E<G-I;VXN<&AP)RDI('L*("`@("`@("!R97%U
M:7)E("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O
M=F5R<VEO;BYP:'`G.PH@("`@("`@("1V97)S:6]N7V-O;G-T86YT(#T@4W1R
M:6YG.CIU<'!E<B@D87!P*2`N("=?5D524TE/3B<["B`@("`@("`@:68@*&1E
M9FEN960H)'9E<G-I;VY?8V]N<W1A;G0I*2!["B`@("`@("`@("`@("1A<'!S
M6R1I75LG=F5R<VEO;B==(#T@8V]N<W1A;G0H)'9E<G-I;VY?8V]N<W1A;G0I
M.PH@("`@("`@('T*("`@('T*("`@(&EF("@A9FEL95]E>&ES=',H)'!A=&@@
M+B`G+V-O;F8N<&AP)RDI('L*("`@("`@("`O*B!.;R!C;VYF+G!H<"!E>&ES
M=',N("HO"B`@("`@("`@)&%P<'-;)&E=6R=C;VYF)UT@/2`D8V]N9E]L:6YK
M("X@)&5R<F]R("X@)SPO83XG.PH@("`@("`@("1A<'!S6R1I75LG<W1A='5S
M)UT@/2!?*")-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BXB*3L*("`@('T@96QS92!["B`@("`@("`@+RH@02!C;VYF+G!H<"!E
M>&ES=',L(&=E="!T:&4@>&UL('9E<G-I;VXN("HO"B`@("`@("`@:68@*"@D
M>&UL7W9E<B`](%]G971697)S:6]N*"1P871H("X@)R]C;VYF+GAM;"<I*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&%P<'-;)&E=6R=C;VYF)UT@/2`D
M8V]N9E]L:6YK("X@)'=A<FYI;F<@+B`G/"]A/B<["B`@("`@("`@("`@("1A
M<'!S6R1I75LG<W1A='5S)UT@/2!?*").;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BXB*3L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@
M("\J($=E="!T:&4@9V5N97)A=&5D('!H<"!V97)S:6]N+B`J+PH@("`@("`@
M(&EF("@H)'!H<%]V97(@/2!?9V5T5F5R<VEO;B@D<&%T:"`N("<O8V]N9BYP
M:'`G*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("\J($YO('9E<G-I;VX@
M9F]U;F0@:6X@9V5N97)A=&5D('!H<"P@<W5G9V5S="!R96=E;F%R871I;F<*
M("`@("`@("`@("`@("H@:G5S="!I;B!C87-E+B`J+PH@("`@("`@("`@("`D
M87!P<ULD:5U;)V-O;F8G72`]("1C;VYF7VQI;FL@+B`D=V%R;FEN9R`N("<\
M+V$^)SL*("`@("`@("`@("`@)&%P<'-;)&E=6R=S=&%T=7,G72`](%\H(DYO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(BD["B`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1X;6Q?=F5R("$]("1P:'!?=F5R*2![
M"B`@("`@("`@("`@("\J(%9E<G-I;VYS(&%R92!N;W0@=&AE('-A;64L(&-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N("HO"B`@("`@("`@("`@("1A
M<'!S6R1I75LG8V]N9B==(#T@)&-O;F9?;&EN:R`N("1E<G)O<B`N("<\+V$^
M)SL*("`@("`@("`@("`@)&%P<'-;)&E=6R=S=&%T=7,G72`](%\H(D-O;F9I
M9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(BD["B`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($-O;F9I9W5R
M871I;VX@:7,@;VLN("HO"B`@("`@("`@("`@("1A<'!S6R1I75LG8V]N9B==
M(#T@)&-O;F9?;&EN:R`N("1S=6-C97-S("X@)SPO83XG.PH@("`@("`@("`@
M("`D87!P<ULD:5U;)W-T871U<R==(#T@7R@B07!P;&EC871I;VX@:7,@<F5A
M9'DN(BD["B`@("`@("`@?0H@("`@?0I]"@HO*B!3;W)T('1H92!A<'!S(&)Y
M(&YA;64N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*2&]R
M9&5?07)R87DZ.F%R<F%Y4V]R="@D87!P<RP@)W-O<G0G*3L*"B\J(%-E="!U
M<"!A;GD@86-T:6]N<R!T:&%T(&UA>2!B92!O9F9E<F5D+B`J+PHD86-T:6]N
M<R`](&%R<F%Y*"D["B1F='!F;W)M(#T@)R<["FEF("@A96UP='DH)%]315-3
M24].6R=?8V]N9FEG)UTI*2!["B`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G
M<&]P=7`N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("1U<FP@/2!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+V1I9F8N<&AP)RD["B`@("`D
M86-T:6]N(#T@7R@B4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M+B(I.PH@("`@)&%C=&EO;G-;72`](&%R<F%Y*"=I8V]N)R`]/B!(;W)D93HZ
M:6UG*"=S96%R8V@N<&YG)RP@)R<L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI+`H@("`@("`@("`@("`@("`@
M("`@("`@("=L:6YK)R`]/B!(;W)D93HZ;&EN:R@G(R<L("<G+"`G)RP@)R<L
M("=P;W!U<"A<)R<@+B`D=7)L("X@)UPG+#8T,"P@-#@P*3L@<F5T=7)N(&9A
M;'-E.R<I("X@)&%C=&EO;B`N("<\+V$^)RD["@H@("`@)'5R;"`]($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O<V-R:7!T<RYP:'`G*3L*
M("`@("\J($%C=&EO;B!T;R!D;W=N;&]A9"!T:&4@8V]N9FEG=7)A=&EO;B!U
M<&=R861E(%!(4"!S8W)I<'0N("HO"B`@("`D=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL(&%R<F%Y*"=S971U<"<@/3X@)V-O;F8G+"`G='EP92<@
M/3X@)W!H<"<I*3L*("`@("1A8W1I;VX@/2!?*")$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(I.PH@("`@)&%C=&EO
M;G-;72`](&%R<F%Y*"=I8V]N)R`]/B!(;W)D93HZ:6UG*"=D;W=N;&]A9"YP
M;F<G+"`G)RP@)V%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG971);6%G
M941I<B@G:&]R9&4G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG
M(#T^($AO<F1E.CIL:6YK*"1U<FPI("X@)&%C=&EO;B`N("<\+V$^)RD["B`@
M("`O*B!!8W1I;VX@=&\@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!U<&=R861E
M(%!(4"!S8W)I<'0N("HO"B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=S879E)RP@)W1M<"<I.PH@("`@)&%C=&EO;B`](%\H(E-A=F4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO
M=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB*3L*("`@("1A8W1I
M;VYS6UT@/2!A<G)A>2@G:6-O;B<@/3X@2&]R9&4Z.FEM9R@G<V%V92YP;F<G
M+"`G)RP@)V%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG971);6%G941I
M<B@G:&]R9&4G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^
M($AO<F1E.CIL:6YK*"1U<FPI("X@)&%C=&EO;B`N("<\+V$^)RD["@H@("`@
M+RH@4V5T('5P('1H92!F;W)M(&9O<B!&5%`@=7!L;V%D(&]F('-C<FEP=',N
M("HO"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<["@H@("`@)'9A<G,@
M/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B;&5S*"D["B`@("`D9G1P
M9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)R<L("1V87)S*3L*("`@
M("1F='!F;W)M+3YS9714:71L92A?*")&5%`@=7!L;V%D(&]F('-E='5P(BDI
M.PH@("`@)&9T<&9O<FTM/G-E=$)U='1O;G,H7R@B57!L;V%D(BDL('1R=64I
M.PH@("`@)&9T<&9O<FTM/F%D9%9A<FEA8FQE*%\H(E5S97)N86UE(BDL("=U
M<V5R;F%M92<L("=T97AT)RP@=')U92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"<G
M+"`R,"DI.PH@("`@)&9T<&9O<FTM/F%D9%9A<FEA8FQE*%\H(E!A<W-W;W)D
M(BDL("=P87-S=V]R9"<L("=P87-S=V]R9"<L(&9A;'-E*3L*"B`@("!I9B`H
M)&9T<&9O<FTM/G9A;&ED871E*"1V87)S*2D@>PH@("`@("`@("1F='!F;W)M
M+3YG971);F9O*"1V87)S+"`D:6YF;RD["B`@("`@("`@)'5P;&]A9"`](%]U
M<&QO861&5%`H)&EN9F\I.PH@("`@("`@(&EF("@D=7!L;V%D*2!["B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B57!L;V%D960@86QL(&%P
M<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(BDL("=H;W)D
M92YS=6-C97-S)RD["B`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@("`@
M("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@
M("`@(&5X:70["B`@("`@("`@?0H@("`@?0H@("`@+RH@4F5N9&5R('1H92!F
M;W)M+B`J+PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+U)E;F1E<F5R
M+G!H<"<["B`@("`D<F5N9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R
M97(H*3L*("`@("1F='!F;W)M(#T@571I;#HZ8G5F9F5R3W5T<'5T*&%R<F%Y
M*"1F='!F;W)M+"`G<F5N9&5R06-T:79E)RDL("1R96YD97)E<BP@)'9A<G,L
M("=I;F1E>"YP:'`G+"`G<&]S="<I.PI]"@II9B`H9FEL95]E>&ES=',H2&]R
M9&4Z.F=E=%1E;7!$:7(H*2`N("<O:&]R9&5?<V5T=7!?=7!G<F%D92YP:'`G
M*2D@>PH@("`@+RH@06-T:6]N('1O(')E;6]V92!T:&4@8V]N9FEG=7)A=&EO
M;B!U<&=R861E(%!(4"!S8W)I<'0N("HO"B`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=A9&UI;B]S971U<"]S8W)I<'1S+G!H<"<I.PH@("`@
M)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G8VQE86XG+"`G=&UP
M)RD["B`@("`D86-T:6]N(#T@7R@B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(BD["B`@("`D86-T:6]N
M<UM=(#T@87)R87DH)VEC;VXG(#T^($AO<F1E.CII;6<H)V1E;&5T92YP;F<G
M+"`G)RP@)V%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG971);6%G941I
M<B@G:&]R9&4G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^
M($AO<F1E.CIL:6YK*"1U<FPI("X@)&%C=&EO;B`N("<\+V$^)RD["GT*"B\J
M(%-E="!U<"!T:&4@=&5M<&QA=&4N("HO"B1T96UP;&%T92`]("9N97<@2&]R
M9&5?5&5M<&QA=&4H*3L*)'1E;7!L871E+3YS970H)V%P<',G+"`D87!P<RD[
M"B1T96UP;&%T92T^<V5T*"=A8W1I;VYS)RP@)&%C=&EO;G,L('1R=64I.PHD
M=&5M<&QA=&4M/G-E="@G9G1P9F]R;2<L("1F='!F;W)M+"!T<G5E*3L*)'1E
M;7!L871E+3YS970H)VYO=&EF>2<L(%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A
M>2@D;F]T:69I8V%T:6]N+"`G;F]T:69Y)RDI*3L*)'1E;7!L871E+3YS971/
M<'1I;VXH)V=E='1E>'0G+"!T<G5E*3L*"B1T:71L92`]('-P<FEN=&8H7R@B
M)7,@4V5T=7`B*2P@)')E9VES=')Y+3YG970H)VYA;64G+"`G:&]R9&4G*2D[
M"DAO<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G+"`G:&]R9&4G+"!T
M<G5E*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC)SL*96-H;R`D=&5M<&QA=&4M/F9E=&-H*$A/4D1%
M7U1%35!,051%4R`N("<O861M:6XO<V5T=7`O:6YD97@N:'1M;"<I.PIR97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]A9&UI;B]S971U<"]S8W)I<'1S+G!H<```````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-3$R`#$P-3$U-#,Q,#8P`#`R,3`S
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@1V5N97)A=&5S('5P9W)A9&4@<V-R:7!T<R!F;W(@2&]R
M9&4G<R!S971U<"X@0W5R<F5N=&QY(&%L;&]W<R!T:&4@9V5N97)A=&EO;@H@
M*B!O9B!02%`@=7!G<F%D92!S8W)I<'1S(&9O<B!C;VYF+G!H<"!F:6QE<R!E
M:71H97(@87,@9&]W;FQO860@;W(@<V%V960@=&\@=&AE"B`J('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN"B`J"B`J("1(;W)D93H@:&]R9&4O861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`L=B`Q+CDN,3`N-B`R,#`V+S`V+S$V(#`X
M.C(T.C(W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*B\*"F1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2![
M"B`@("!(;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PI]"@HO*B!'970@9F]R;2!D871A+B`J+PHD<V5T=7`@/2!5=&EL
M.CIG971&;W)M1&%T82@G<V5T=7`G*3L*)'1Y<&4@/2!5=&EL.CIG971&;W)M
M1&%T82@G='EP92<I.PHD<V%V92`](%5T:6PZ.F=E=$9O<FU$871A*"=S879E
M)RD["B1C;&5A;B`](%5T:6PZ.F=E=$9O<FU$871A*"=C;&5A;B<I.PH*)&9I
M;&5N86UE(#T@)VAO<F1E7W-E='5P7W5P9W)A9&4N<&AP)SL*"B\J($-H96-K
M(&EF('1H:7,@:7,@;VYL>2!A(')E<75E<W0@=&\@8VQE86X@=7`N("HO"FEF
M("@D8VQE86X@/3T@)W1M<"<I('L*("`@("1T;7!?9&ER(#T@2&]R9&4Z.F=E
M=%1E;7!$:7(H*3L*("`@("1P871H(#T@571I;#HZ<F5A;%!A=&@H)'1M<%]D
M:7(@+B`G+R<@+B`D9FEL96YA;64I.PH@("`@:68@*'5N;&EN:R@D=&UP7V1I
M<B`N("<O)R`N("1F:6QE;F%M92DI('L*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="!<(B5S7"(N(BDL("1P871H*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T@
M96QS92!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(I+"!5=&EL.CIR96%L4&%T:"@D<&%T:"DI+"`G:&]R9&4N97)R;W(G*3L*
M("`@('T*("`@("1R96=I<W1R>2T^8VQE87)#86-H92@I.PH@("`@)'5R;"`]
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O:6YD97@N<&AP
M)RP@=')U92D["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@
M("!E>&ET.PI]"@HD9&%T82`]("<G.PII9B`H)'-E='5P(#T]("=C;VYF)R`F
M)B`D='EP92`]/2`G<&AP)RD@>PH@("`@+RH@02!B:70@=6=L>2!H97)E+"!S
M879E(%!(4"!C;V1E(&EN=&\@82!S=')I;F<@9F]R(&-R96%T:6YG('1H92!S
M8W)I<'0*("`@("`J('1O(&)E(')U;B!A="!T:&4@8V]M;6%N9"!P<F]M<'0N
M("HO"B`@("`D9&%T82`]("<C(2]U<W(O8FEN+W!H<"<@+B`B7&XB.PH@("`@
M)&1A=&$@+CT@)SP_<&AP)R`N(")<;B(["B`@("!F;W)E86-H("@D7U-%4U-)
M3TY;)U]C;VYF:6<G72!A<R`D87!P(#T^("1P:'`I('L*("`@("`@("`D<&%T
M:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF
M:6<G.PH@("`@("`@("\J($%D9"!C;V1E('1O('-A=F4@8F%C:W5P+B`J+PH@
M("`@("`@("1D871A("X]("=I9B`H9FEL95]E>&ES=',H7"<G("X@)'!A=&@@
M+B`G+V-O;F8N<&AP7"<I*2![)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@
M)R`@("!I9B`H0&-O<'DH7"<G("X@)'!A=&@@+B`G+V-O;F8N<&AP7"<L(%PG
M)R`N("1P871H("X@)R]C;VYF+G!H<"YB86M<)RDI('LG("X@(EQN(CL*("`@
M("`@("`D9&%T82`N/2`G("`@("`@("!E8VAO(%PG)R`N(%\H(E-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB*2`N("=<)R`N(")<
M;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!](&5L<V4@>R<@
M+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@("`@(&5C:&\@7"<G("X@
M7R@B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(I("X@
M)UPG("X@(EQN(CLG("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@('TG
M("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G?2<@+B`B7&XB.PH*("`@("`@
M("`D9&%T82`N/2`G:68@*"1F<"`]($!F;W!E;BA<)R<@+B`D<&%T:"`N("<O
M8V]N9BYP:'!<)RP@7"=W7"<I*2![)R`N(")<;B(["B`@("`@("`@)&1A=&$@
M+CT@)R`@("!F=W)I=&4H)&9P+"!<)R<["B`@("`@("`@)&1A=&$@+CT@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="AS=')?<F5P;&%C92AA<G)A>2@G7%PG+"`G
M7"<G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=<7%Q<)RP@)UQ<7"<G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M:'`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M3DQ3.CIG971#:&%R<V5T*"DL("=I<V\M.#@U.2TQ)RD["B`@("`@("`@)&1A
M=&$@+CT@)UPG*3LG("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@(&9C
M;&]S92@D9G`I.R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@96-H
M;R!<)R<@+B!S<')I;G1F*%\H(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(BDL
M("1A<'`I("X@)UPG("X@(EQN(CLG("X@(EQN(CL*("`@("`@("`D9&%T82`N
M/2`G?2!E;'-E('LG("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@(&5C
M:&\@7"<G("X@<W!R:6YT9BA?*")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+B(I+"`D87!P*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@("`@
M("`@)&1A=&$@+CT@)WTG("X@(EQN7&XB.PH@("`@?0I]"@II9B`H)'-A=F4@
M/3T@)W1M<"<I('L*("`@("1T;7!?9&ER(#T@2&]R9&4Z.F=E=%1E;7!$:7(H
M*3L*("`@("\J($%D9"!S96QF+61E<W1R=6-T(&-O9&4N("HO"B`@("`D9&%T
M82`N/2`G96-H;R!<)U-E;&8M9&5S=')U8W1I;F<N+BY<)R`N(")<;B([)R`N
M(")<;B(["B`@("`D9&%T82`N/2`G:68@*'5N;&EN:RA?7T9)3$5?7RDI('LG
M("X@(EQN(CL*("`@("1D871A("X]("<@("`@96-H;R!<)R<@+B!?*")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(I("X@)UPG("X@(EQN(CLG("X@(EQN(CL*
M("`@("1D871A("X]("=](&5L<V4@>R<@+B`B7&XB.PH@("`@)&1A=&$@+CT@
M)R`@("!E8VAO(%PG)R`N('-P<FEN=&8H7R@B5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N(BDL("1T;7!?9&ER*2`N("=<)R`N
M(")<;B([)R`N(")<;B(["B`@("`D9&%T82`N/2`G?2<@+B`B7&XB.PH@("`@
M+RH@5&AE('-C<FEP="!S:&]U;&0@8F4@<V%V960@=&\@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X@*B\*("`@("1P871H(#T@571I;#HZ<F5A;%!A
M=&@H)'1M<%]D:7(@+B`G+R<@+B`D9FEL96YA;64I.PH@("`@:68@*"1F<"`]
M($!F;W!E;B@D=&UP7V1I<B`N("<O)R`N("1F:6QE;F%M92P@)W<G*2D@>SL*
M("`@("`@("!F=W)I=&4H)&9P+"`D9&%T82D["B`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@8VAM;V0H)'1M<%]D:7(@+B`G+R<@+B`D9FEL96YA;64L
M(#`W-S<I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(I+"`D
M<&%T:"DL("=H;W)D92YS=6-C97-S)RD["B`@("!](&5L<V4@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(I+"`D<&%T:"DL
M("=H;W)D92YE<G)O<B<I.PH@("`@?0H@("`@)'5R;"`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O:6YD97@N<&AP)RP@=')U92D["B`@
M("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI](&5L
M<V4@>PH@("`@+RH@3W5T<'5T('-C<FEP="!T;R!B<F]W<V5R(&9O<B!D;W=N
M;&]A9"X@*B\*("`@("1B<F]W<V5R+3YD;W=N;&]A9$AE861E<G,H)&9I;&5N
M86UE+"`G=&5X="]P;&%I;B<L(&9A;'-E+"!S=')L96XH)&1A=&$I*3L*("`@
M(&5C:&\@)&1A=&$["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D
M;6EN+W!H<'-H96QL+G!H<```````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#4U-#,`,3`U,34T,S$P-C``,#(P,#,S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W!H<'-H96QL+G!H<"QV(#$N,C0N,3`N
M."`R,#`V+S`R+S(T(#(R.C0X.C(Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M365N=2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TAE;'`N<&AP)SL*"FEF
M("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I
M;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)'1I=&QE(#T@7R@B4$A0(%-H96QL
M(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8R<["@HD87!P<U]T;7`@/2`D<F5G:7-T<GDM/FQI<W1!
M<'!S*"D["B1A<'!S(#T@87)R87DH*3L*9F]R96%C:"`H)&%P<'-?=&UP(&%S
M("1A<'`I('L*("`@("1A<'!S6R1A<'!=(#T@)')E9VES=')Y+3YG970H)VYA
M;64G+"`D87!P*3L*?0IA<V]R="@D87!P<RD["B1A<'!L:6-A=&EO;B`](%5T
M:6PZ.F=E=$9O<FU$871A*"=A<'`G+"`G:&]R9&4G*3L*/SX*/&1I=B!S='EL
M93TB<&%D9&EN9SHQ,'!X(CX*/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO("1?
M4T525D526R=02%!?4T5,1B==(#\^(B!M971H;V0](G!O<W0B/@H\/W!H<"!5
M=&EL.CIP9F]R;4EN<'5T*"D@/SX*"CQH,2!C;&%S<STB:&5A9&5R(CX\/W!H
M<"!E8VAO(%\H(D%P<&QI8V%T:6]N(BD@/SX\+V@Q/CQB<B`O/@H\<V5L96-T
M(&YA;64](F%P<"(^"CP_<&AP(&9O<F5A8V@@*"1A<'!S(&%S("1A<'`@/3X@
M)&YA;64I.B`_/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@)&%P<"`_
M/B(\/W!H<"!I9B`H)&%P<&QI8V%T:6]N(#T]("1A<'`I(&5C:&\@)R!S96QE
M8W1E9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO("1N86UE(#\^/"]O<'1I
M;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CPO<V5L96-T/CQB<B`O/CQB<B`O
M/@H\/W!H<`H*:68@*"1C;VUM86YD(#T@=')I;2A5=&EL.CIG971&;W)M1&%T
M82@G<&AP)RDI*2!["B`@("!I9B`H0&9I;&5?97AI<W1S*"1R96=I<W1R>2T^
M9V5T*"=F:6QE<F]O="<L("1A<'!L:6-A=&EO;BD@+B`G+VQI8B]B87-E+G!H
M<"<I*2!["B`@("`@("`@:6YC;'5D92`D<F5G:7-T<GDM/F=E="@G9FEL97)O
M;W0G+"`D87!P;&EC871I;VXI("X@)R]L:6(O8F%S92YP:'`G.PH@("`@?2!E
M;'-E('L*("`@("`@("`D<F5G:7-T<GDM/G!U<VA!<'`H)&%P<&QI8V%T:6]N
M*3L*("`@('T*"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O5FEE=V5R
M+G!H<"<["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O5FEE=V5R+W-O
M=7)C92YP:'`G.PH@("`@)'!R971T>2`](&AI9VAL:6=H=%]S=')I;F<H)SP_
M<&AP("<@+B`D8V]M;6%N9"P@=')U92D["B`@("`D<')E='1Y(#T@<W1R7W)E
M<&QA8V4H87)R87DH)R9L=#L_<&AP("<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)SQF;VYT(&-O;&]R/2(C,#`P,#`P(CX\9F]N="!C;VQO
M<CTB(S`P-S<P,"(^)FQT.S\\+V9O;G0^/&9O;G0@8V]L;W(](B,P,#`P0D(B
M/G!H<"`\+V9O;G0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`B7')<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(EQR
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B7&XB+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\8G(@+SXG*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B7&XB*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')E='1Y*3L*("`@("1P<F5T='D@/2!-24U%7U9I
M97=E<E]3;W5R8V4Z.FQI;F5.=6UB97(H=')I;2@D<')E='1Y*2D["@H@("`@
M96-H;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")02%`@0V]D92(I("X@
M)SPO:#$^/&)R("\^)SL*("`@(&5C:&\@)'!R971T>3L*"B`@("!E8VAO("<\
M8G(@+SX\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(E)E<W5L=',B*2`N("<\
M+V@Q/CQB<B`O/B<["B`@("!E8VAO("<\<')E(&-L87-S/2)T97AT(CXG.PH@
M("`@979A;"@D8V]M;6%N9"D["B`@("!E8VAO("<\+W!R93X\8G(@+SXG.PI]
M"C\^"@H\=&5X=&%R96$@8VQA<W,](F9I>&5D(B!N86UE/2)P:'`B(')O=W,]
M(C$P(B!C;VQS/2(V,"(^"CP_<&AP(&EF("@A96UP='DH)&-O;6UA;F0I*2!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O;6UA;F0I(#\^/"]T97AT87)E83X*
M/&)R("\^"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A
M;'5E/2(\/W!H<"!E8VAO(%\H(D5X96-U=&4B*2`_/B(@+SX*/#]P:'`@96-H
M;R!(96QP.CIL:6YK*"=A9&UI;B<L("=A9&UI;BUP:'!S:&5L;"<I(#\^"@H\
M+V9O<FT^"CPO9&EV/@H\/W!H<`H*<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO:6YD97@N<&AP````
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(U
M-P`Q,#4Q-30S,3`V,``P,3<S,C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M861M:6XO:6YD97@N<&AP+'8@,2XQ-2XX+C,@,C`P-B\P,2\P,2`R,3HR.#HP
M-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S
M($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["@II9B`H
M(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=&;W)B:61D
M96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0H*)'1I=&QE(#T@7R@B061M
M:6YI<W1R871I;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O
M;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO=7-E<BYP
M:'``````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R,S<W-P`Q,#4Q-30S,3`V,``P,3<R,#,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@
M:&]R9&4O861M:6XO=7-E<BYP:'`L=B`Q+C0W+C$P+C<@,C`P-B\P,2\P,2`R
M,3HR.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B
M87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]687)I86)L97,N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+U)E
M;F1E<F5R+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H
M<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L
M*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0HD875T:"`]
M("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*
M:68@*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72`F)B`D8V]N9ELG<VEG;G5P
M)UU;)V%P<')O=F4G72D@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!=71H
M+U-I9VYU<"YP:'`G.PH@("`@)'-I9VYU<"`]("9!=71H7U-I9VYU<#HZ<VEN
M9VQE=&]N*"D["GT*"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A
M<FEA8FQE<R@I.PHD861D1F]R;2`]("9N97<@2&]R9&5?1F]R;2@D=F%R<RP@
M7R@B061D(&$@;F5W('5S97(Z(BDL("=A9&1U<V5R)RD["B1A9&1&;W)M+3YS
M971"=71T;VYS*%\H(D%D9"!U<V5R(BDL(%\H(E)E<V5T(BDI.PH*)'9A<G,M
M/G-E="@G9F]R;2<L("=A9&0G*3L*)&%D9$9O<FTM/F%D9$AI9&1E;B@G)RP@
M)V9O<FTG+"`G=&5X="<L('1R=64L('1R=64I.PHD861D1F]R;2T^861D5F%R
M:6%B;&4H7R@B57-E<FYA;64B*2P@)W5S97)?;F%M92<L("=T97AT)RP@=')U
M92D["B1A9&1&;W)M+3YA9&1687)I86)L92A?*")087-S=V]R9"(I+"`G<&%S
M<W=O<F0G+"`G<&%S<W=O<F1C;VYF:7)M)RP@9F%L<V4L(&9A;'-E+"!?*")T
M>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(BDI.PH*+RH@57-E
M(&AO;VMS(&=E="!A;GD@97AT<F$@9FEE;&1S(&9O<B!N97<@86-C;W5N=',N
M("HO"B1E>'1R82`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VEG
M;G5P7V=E=&5X=')A)RD["FEF("@A:7-?82@D97AT<F$L("=014%27T5R<F]R
M)RD@)B8@(65M<'1Y*"1E>'1R82DI('L*("`@(&9O<F5A8V@@*"1E>'1R82!A
M<R`D9FEE;&1?;F%M92`]/B`D9FEE;&0I('L*("`@("`@("`D<F5A9&]N;'D@
M/2!I<W-E="@D9FEE;&1;)W)E861O;FQY)UTI(#\@)&9I96QD6R=R96%D;VYL
M>2==(#H@;G5L;#L*("`@("`@("`D9&5S8R`](&ES<V5T*"1F:65L9%LG9&5S
M8R==*2`_("1F:65L9%LG9&5S8R==(#H@;G5L;#L*("`@("`@("`D9FEE;&1?
M<&%R86US(#T@:7-S970H)&9I96QD6R=P87)A;7,G72D@/R`D9FEE;&1;)W!A
M<F%M<R==(#H@87)R87DH*3L*"B`@("`@("`@)&%D9$9O<FTM/F%D9%9A<FEA
M8FQE*"1F:65L9%LG;&%B96PG72P@)V5X=')A6R<@+B`D9FEE;&1?;F%M92`N
M("==)RP@)&9I96QD6R=T>7!E)UTL("1F:65L9%LG<F5Q=6ER960G72P@)')E
M861O;FQY+"`D9&5S8RP@)&9I96QD7W!A<F%M<RD["B`@("!]"GT*"@HO+R!0
M<F]C97-S(&9O<FUS+B!5<V4@571I;#HZ9V5T4&]S="@I(&EN<W1E860@;V8@
M571I;#HZ9V5T1F]R;41A=&$H*0HO+R!F;W(@82!L;W0@;V8@=&AE(&1A=&$@
M8F5C875S92!W92!W86YT('1O(&%C=&EV96QY(&EG;F]R92!'150@9&%T80HO
M+R!I;B!S;VUE(&-A<V5S("T@861D:6YG+VUO9&EF>6EN9R!U<V5R<R`M(&%S
M(&$@<V5C=7)I='D@<')E8V%U=&EO;BX*<W=I=&-H("A5=&EL.CIG971&;W)M
M1&%T82@G9F]R;2<I*2!["F-A<V4@)V%D9"<Z"B`@("`D861D1F]R;2T^=F%L
M:61A=&4H)'9A<G,I.PH*("`@(&EF("@D861D1F]R;2T^:7-686QI9"@I("8F
M("1V87)S+3YG970H)V9O<FUN86UE)RD@/3T@)V%D9'5S97(G*2!["B`@("`@
M("`@)&%D9$9O<FTM/F=E=$EN9F\H)'9A<G,L("1I;F9O*3L*"B`@("`@("`@
M:68@*&5M<'1Y*"1I;F9O6R=U<V5R7VYA;64G72DI('L*("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N(BDL("=H;W)D92YE<G)O<B<I.PH*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D8W)E9&5N=&EA;',@/2!A<G)A>2@G<&%S
M<W=O<F0G(#T^("1I;F9O6R=P87-S=V]R9"==*3L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1I;F9O6R=E>'1R82==*2D@>PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&EN9F];)V5X=')A)UT@87,@)&9I96QD(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@("`@("1C<F5D96YT:6%L<ULD9FEE;&1=(#T@)'9A
M;'5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H:7-?82@D<F5T(#T@)&%U=&@M/F%D9%5S97(H)&EN9F];)W5S
M97)?;F%M92==+"`D8W)E9&5N=&EA;',I+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T
M96TZ("5S(BDL("1I;F9O6R=U<V5R7VYA;64G72P@)')E="T^9V5T365S<V%G
M92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)V5X=')A)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)')E<W5L="`]($AO<F1E.CIC86QL2&]O:R@G
M7VAO<F1E7VAO;VM?<VEG;G5P7V%D9&5X=')A)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1I;F9O6R=U
M<V5R7VYA;64G72P@)&EN9F];)V5X=')A)UTI*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+B(I+"`D
M:6YF;ULG=7-E<E]N86UE)UTL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H
M;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=R96UO=F51=65U9613:6=N=7`G*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1S:6=N=7`M/G)E;6]V95%U975E9%-I9VYU<"@D:6YF;ULG=7-E<E]N
M86UE)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!A9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB*2P@)&EN9F];)W5S97)?;F%M92==
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@("1A9&1&;W)M
M+3YU;G-E=%9A<G,H)'9A<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@8G)E86L["@IC87-E("=R96UO=F5?9B<Z"B`@("`D9E]U<V5R
M7VYA;64@/2!5=&EL.CIG971&;W)M1&%T82@G=7-E<E]N86UE)RD["B`@("`D
M<F5M;W9E7V9O<FT@/2!T<G5E.PH@("`@8G)E86L["@IC87-E("=R96UO=F4G
M.@H@("`@)&9?=7-E<E]N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S97)?
M;F%M92<I.PH@("`@:68@*&5M<'1Y*"1F7W5S97)?;F%M92DI('L*("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N(BDL("=H;W)D92YM97-S86=E)RD["B`@("!]
M(&5L<V5I9B`H571I;#HZ9V5T1F]R;41A=&$H)W-U8FUI="<I("$]/2!?*")#
M86YC96PB*2D@>PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D875T:"T^
M<F5M;W9E57-E<B@D9E]U<V5R7VYA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(I("X@)')E<W5L="T^9V5T365S<V%G92@I+"`D9E]U<V5R7VYA;64I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB*2P@)&9?=7-E<E]N
M86UE*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!]"B`@("!]"B`@("`D
M=F%R<RT^<F5M;W9E*"=U<V5R7VYA;64G*3L*("`@(&)R96%K.PH*8V%S92`G
M8VQE87)?9B<Z"B`@("`D9E]U<V5R7VYA;64@/2!5=&EL.CIG971&;W)M1&%T
M82@G=7-E<E]N86UE)RD["B`@("`D8VQE87)?9F]R;2`]('1R=64["B`@("!B
M<F5A:SL*"F-A<V4@)V-L96%R)SH*("`@("1F7W5S97)?;F%M92`](%5T:6PZ
M.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*3L*("`@(&EF("AE;7!T>2@D9E]U
M<V5R7VYA;64I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(I+"`G
M:&]R9&4N;65S<V%G92<I.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=S=6)M:70G*2`A/3T@7R@B0V%N8V5L(BDI('L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)&%U=&@M/G)E;6]V955S97)$871A*"1F7W5S97)?
M;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@8VQE
M87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B
M*2`N("1R97-U;'0M/F=E=$UE<W-A9V4H*2P@)&9?=7-E<E]N86UE*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB*2P@
M)&9?=7-E<E]N86UE*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!]"B`@
M("!]"B`@("`D=F%R<RT^<F5M;W9E*"=U<V5R7VYA;64G*3L*("`@(&)R96%K
M.PH*8V%S92`G=7!D871E7V8G.@H@("`@)&9?=7-E<E]N86UE(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W5S97)?;F%M92<I.PH@("`@)'5P9&%T95]F;W)M(#T@
M=')U93L*("`@(&)R96%K.PH*8V%S92`G=7!D871E)SH*("`@("1U<V5R7VYA
M;65?,2`](%5T:6PZ.F=E=%!O<W0H)W5S97)?;F%M92<I.PH@("`@)'5S97)?
M;F%M95\R(#T@571I;#HZ9V5T4&]S="@G=7-E<E]N86UE,B<L("1U<V5R7VYA
M;65?,2D["B`@("`D9G5L;&YA;64@/2!5=&EL.CIG9710;W-T*"=U<V5R7V9U
M;&QN86UE)RD["B`@("`D96UA:6P@/2!5=&EL.CIG9710;W-T*"=U<V5R7V5M
M86EL)RD["@H@("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G
M*2D@>PH@("`@("`@("1U<V5R7W!A<W-?,2`](%5T:6PZ.F=E=%!O<W0H)W5S
M97)?<&%S<U\Q)RD["B`@("`@("`@)'5S97)?<&%S<U\R(#T@571I;#HZ9V5T
M4&]S="@G=7-E<E]P87-S7S(G*3L*"B`@("`@("`@:68@*&5M<'1Y*"1U<V5R
M7VYA;65?,2DI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?
M*")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(BDL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D=7-E
M<E]P87-S7S$I('Q\(&5M<'1Y*"1U<V5R7W!A<W-?,BDI('L*("`@("`@("`@
M("`@+R\@1&]N)W0@=7!D871E+"!B=70@9&]N)W0@8V]M<&QA:6XN"B`@("`@
M("`@?2!E;'-E:68@*"1U<V5R7W!A<W-?,2`A/2`D=7-E<E]P87-S7S(I('L*
M("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")087-S=V]R9',@
M;75S="!M871C:"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)')E<W5L="`]("1A=71H+3YU<&1A=&55<V5R*"1U
M<V5R7VYA;65?,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1U<V5R7VYA;65?,BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=P87-S=V]R9"<@/3X@)'5S97)?<&%S
M<U\Q*2D["B`@("`@("`@?0H@("`@?0H*("`@(&EF("AI<W-E="@D<F5S=6QT
M*2`F)B!I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&$@<')O
M8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1U<V5R7VYA;65?,2P@)')E<W5L="T^9V5T
M365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@
M("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L("1U
M<V5R7VYA;65?,2D["B`@("`@("`@)&ED96YT:71Y+3YS971686QU92@G9G5L
M;&YA;64G+"`D9G5L;&YA;64I.PH@("`@("`@("1I9&5N=&ET>2T^<V5T5F%L
M=64H)V9R;VU?861D<B<L("1E;6%I;"D["B`@("`@("`@)&ED96YT:71Y+3YS
M879E*"D["@H@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?;F%M95\R*2P@)VAO<F1E
M+G-U8V-E<W,G*3L*("`@('T*("`@("1V87)S+3YR96UO=F4H)W5S97)?;F%M
M92<I.PH@("`@8G)E86L["@IC87-E("=A<'!R;W9E7V8G.@H@("`@)'1H:7-3
M:6=N=7`@/2`D<VEG;G5P+3YG9711=65U9613:6=N=7`H571I;#HZ9V5T1F]R
M;41A=&$H)W5S97)?;F%M92<I*3L*("`@("1I;F9O(#T@)'1H:7-3:6=N=7`M
M/F=E=$1A=&$H*3L*"B`@("`D=F%R<RT^<V5T*"=P87-S=V]R9"<L"B`@("`@
M("`@("`@("`@(&%R<F%Y*"=O<FEG:6YA;"<@/3X@)&EN9F];)W!A<W-W;W)D
M)UTL"B`@("`@("`@("`@("`@("`@("`@("=C;VYF:7)M)R`]/B`D:6YF;ULG
M<&%S<W=O<F0G72DI.PH@("`@=6YS970H)&EN9F];)W!A<W-W;W)D)UTI.PH@
M("`@)'9A<G,M/G-E="@G97AT<F$G+"`D:6YF;RD["@H@("`@)'9A<G,M/G-E
M="@G<F5M;W9E475E=65D4VEG;G5P)RP@=')U92D["B`@("`D861D1F]R;2T^
M861D2&ED9&5N*"<G+"`G<F5M;W9E475E=65D4VEG;G5P)RP@)V)O;VQE86XG
M+"!T<G5E*3L*("`@(&)R96%K.PH*8V%S92`G<F5M;W9E<75E=65D7V8G.@H@
M("`@)&9?=7-E<E]N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M
M92<I.PH@("`@)')E;6]V97%U975E9%]F;W)M(#T@=')U93L*("`@(&)R96%K
M.PH*8V%S92`G<F5M;W9E<75E=65D)SH*("`@("1R97-U;'0@/2`D<VEG;G5P
M+3YR96UO=F51=65U9613:6=N=7`H571I;#HZ9V5T1F]R;41A=&$H)W5S97)?
M;F%M92<I*3L*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R97-U;'0I.PH@("`@
M?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D
M+B(I+"!5=&EL.CIG971&;W)M1&%T82@G=7-E<E]N86UE)RDI*3L*("`@('T*
M("`@(&)R96%K.PI]"@HD=&ET;&4@/2!?*")5<V5R($%D;6EN:7-T<F%T:6]N
M(BD["DAO<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G+"`G:&]R9&4G
M+"!T<G5E*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH
M96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN
M+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R
M<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["@II9B`H:7-S970H)'5P
M9&%T95]F;W)M*2`F)B`D875T:"T^:&%S0V%P86)I;&ET>2@G;&ES="<I*2![
M"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`D
M:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L("1F7W5S
M97)?;F%M92D["B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M
M:6XO=7-E<B]U<&1A=&4N:6YC)SL*?2!E;'-E:68@*&ES<V5T*"1R96UO=F5?
M9F]R;2D@)B8@)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2`F)B`D875T
M:"T^:&%S0V%P86)I;&ET>2@G<F5M;W9E)RDI('L*("`@(')E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+W)E;6]V92YI;F,G.PI](&5L
M<V5I9B`H:7-S970H)&-L96%R7V9O<FTI*2!["B`@("!R97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O861M:6XO=7-E<B]C;&5A<BYI;F,G.PI](&5L<V5I
M9B`H:7-S970H)')E;6]V97%U975E9%]F;W)M*2D@>PH@("`@<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8R<["GT@96QS96EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G861D)RDI('L*
M("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+V%D
M9"YI;F,G.PH@("`@:68@*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72`F)B`D
M8V]N9ELG<VEG;G5P)UU;)V%P<')O=F4G72D@>PH@("`@("`@(')E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC)SL*
M("`@('T*?2!E;'-E('L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]A9&UI;B]U<V5R+VYO861D+FEN8R<["GT*"FEF("@D875T:"T^:&%S0V%P
M86)I;&ET>2@G;&ES="<I*2!["@H@("`@+RH@268@=V4@87)E;B=T('-U<'!L
M:65D('=I=&@@82!P86=E(&YU;6)E<BP@9&5F875L="!T;R!P86=E(#`N("HO
M"B`@("`D<&%G92`](%5T:6PZ.F=E=$9O<FU$871A*"=P86=E)RP@,"D["B`@
M("`D<V5A<F-H7W!A='1E<FX@/2!5=&EL.CIG971&;W)M1&%T82@G<V5A<F-H
M7W!A='1E<FXG+"`G)RD["@H@("`@)'5S97)S(#T@)&%U=&@M/FQI<W15<V5R
M<R@I.PH@("`@:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@2&]R9&4Z.F9A=&%L*"1U<V5R<RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@('T*"B`@("`O*B!2971U<FYS(&]N;'D@=7-E<G,@=&AA="!M871C
M:"!T:&4@<W!E8VEF:65D('!A='1E<FXN("HO"B`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`D=7-E<G,@/2!P<F5G7V=R97`H)R\G
M("X@)'-E87)C:%]P871T97)N("X@)R\G+"`D=7-E<G,I.PH@("`@<V]R="@D
M=7-E<G,I.PH*("`@(')E<75I<F5?;VYC92`G2&]R9&4O54DO4&%G97(N<&AP
M)SL*("`@("1V:65W=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=A9&UI;B]U
M<V5R+G!H<"<L("=S96%R8VA?<&%T=&5R;B<L("1S96%R8VA?<&%T=&5R;BD[
M"@H@("`@)&YU;6ET96T@/2!C;W5N="@D=7-E<G,I.PH@("`@)'!E<G!A9V4@
M/2`R,#L*"B`@("`D;6EN(#T@)'!A9V4@*B`D<&5R<&%G93L*("`@('=H:6QE
M("@D;6EN(#X@)&YU;6ET96TI('L*("`@("`@("`D<&%G92TM.PH@("`@("`@
M("1M:6X@/2`D<&%G92`J("1P97)P86=E.PH@("`@?0H@("`@)&UA>"`]("1M
M:6X@*R`D<&5R<&%G93L*"B`@("`D<W1A<G0@/2`H)'!A9V4@*B`D<&5R<&%G
M92D@*R`Q.PH@("`@)&5N9"`](&UI;B@D;G5M:71E;2P@)'-T87)T("L@)'!E
M<G!A9V4@+2`Q*3L*"B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M861M:6XO=7-E<B]L:7-T+FEN8R<["GT@96QS92!["B`@("!R97%U:7)E($A/
M4D1%7U1%35!,051%4R`N("<O861M:6XO=7-E<B]N;VQI<W0N:6YC)SL*?0H*
M<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC
M)SL*`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO8VUD<VAE;&PN
M<&AP````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S(U,P`Q,#4Q-30S,3`V,``P,C`P,#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O861M:6XO8VUD<VAE;&PN<&AP+'8@,2XY+C$P+C8@,C`P-B\P,B\R-"`R
M,CHT.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O
M8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<["@II9B`H(4%U=&@Z.FES061M
M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*?0H*)'1I=&QE(#T@7R@B0V]M;6%N9"!3:&5L;"(I
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI
M;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N
M+6AE861E<BYI;F,G.PH*96-H;R`G/&1I=B!S='EL93TB<&%D9&EN9SHQ,'!X
M(CXG.PII9B`H)&-O;6UA;F0@/2!T<FEM*%5T:6PZ.F=E=$9O<FU$871A*"=C
M;60G*2DI('L*("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B
M0V]M;6%N9"(I("X@)SH\+V@Q/CQB<B`O/B<["B`@("!E8VAO("<\<"!C;&%S
M<STB=&5X="(^/&-O9&4^)R`N(&YL,F)R*&AT;6QS<&5C:6%L8VAA<G,H)&-O
M;6UA;F0I*2`N("<\+V-O9&4^/"]P/B<["@H@("`@96-H;R`G/&)R("\^/&@Q
M(&-L87-S/2)H96%D97(B/B<@+B!?*")297-U;'1S(BD@+B`G.CPO:#$^/&)R
M("\^)SL*("`@(&5C:&\@)SQP<F4@8VQA<W,](G1E>'0B/B<["@H@("`@)&-M
M9',@/2!E>'!L;V1E*")<;B(L("1C;VUM86YD*3L*("`@(&9O<F5A8V@@*"1C
M;61S(&%S("1C;60I('L*("`@("`@("`D8VUD(#T@=')I;2@D8VUD*3L*("`@
M("`@("!I9B`H<W1R;&5N*"1C;60I*2!["B`@("`@("`@("`@('5N<V5T*"1R
M97-U;'1S*3L*("`@("`@("`@("`@9FQU<V@H*3L*("`@("`@("`@("`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*'-H96QL7V5X96,H)&-M9"DI.PH@("`@("`@
M('T*("`@('T*"B`@("!E8VAO("<\+W!R93X\8G(@+SXG.PI]"C\^"@H\9F]R
M;2!A8W1I;VX](CP_<&AP(&5C:&\@)%]315)615);)U!(4%]314Q&)UT@/SXB
M(&UE=&AO9#TB<&]S="(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\
M=&5X=&%R96$@8VQA<W,](F9I>&5D(B!N86UE/2)C;60B(')O=W,](C$P(B!C
M;VQS/2(V,"(^"CP_<&AP(&EF("@A96UP='DH)&-O;6UA;F0I*2!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&-O;6UA;F0I(#\^/"]T97AT87)E83X*/&)R("\^
M"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(D5X96-U=&4B*2`_/B(@+SX*/#]P:'`@96-H;R!(96QP
M.CIL:6YK*"=A9&UI;B<L("=A9&UI;BUC;61S:&5L;"<I(#\^"@H\+V9O<FT^
M"CPO9&EV/@H\/W!H<`H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O
M;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+V1A=&%T<F5E+G!H<```
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0W,C,`
M,3`U,34T,S$P-C``,#(P,#`T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D
M;6EN+V1A=&%T<F5E+G!H<"QV(#$N-RXR+C0@,C`P-B\P,B\P,2`P.3HS,#HT
M-B!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF
M=6YC=&EO;B!A9&14<F5E*"1P87)E;G0L("1P87)E;G1?:60L("1I;F1E;G0@
M/2`Q*0I["B`@("!G;&]B86P@)&1A=&%T<F5E+"`D=')E93L*"B`@("`D;F]D
M97,@/2`D9&%T871R964M/F=E=$)Y260H1$%40512145?1D]234%47T9,050L
M("1P87)E;G1?:60L('1R=64L("1P87)E;G0L(#$I.PH@("`@)&5X<&%N9&5D
M(#T@)'1R964M/FES17AP86YD960H)'!A<F5N="D["B`@("`D=7)L(#T@2&]R
M9&4Z.G5R;"@G9&%T871R964N<&AP)RD["B`@("!F;W)E86-H("@D;F]D97,@
M87,@)&ED(#T^("1N;V1E*2!["B`@("`@("`@:68@*"1I9"`]/2`D<&%R96YT
M7VED*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@
M("`D=')E92T^861D3F]D92@D<&%R96YT("X@)SHG("X@)&ED+"`D<&%R96YT
M+"`D9&%T871R964M/F=E=%-H;W)T3F%M92@D;F]D92DL("1I;F1E;G0L(&9A
M;'-E+"!A<G)A>2@G=7)L)R`]/B!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@
M)W-H;W<G+"`D9&%T871R964M/F=E=%!A<F%M*"=G<F]U<"<I("X@)SHG("X@
M)&ED*2`N("<C<VAO=R<I*3L*("`@("`@("!I9B`H)&5X<&%N9&5D*2!["B`@
M("`@("`@("`@(&%D9%1R964H)'!A<F5N="`N("<Z)R`N("1I9"P@)&ED+"`D
M:6YD96YT("L@,2D["B`@("`@("`@?0H@("`@?0I]"@I`9&5F:6YE*"=(3U)$
M15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](96QP
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5')E92YP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<["@II9B`H(4%U=&@Z.FES061M
M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER
M96-T*"D["GT*"B1T<F5E(#T@)DAO<F1E7U1R964Z.F9A8W1O<GDH)V1A=&%T
M<F5E)RP@)VAT;6PG*3L*)'1R964M/G-E=$]P=&EO;B@G86QT97)N871E)RP@
M=')U92D["@HD9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==
M.PHD8V]N9FEG(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G9&%T871R964G
M+"`D8V]N9ELG9&%T871R964G75LG9')I=F5R)UTI.PHD9&%T871R964@/2`F
M1&%T851R964Z.G-I;F=L971O;B@D8V]N9ELG9&%T871R964G75LG9')I=F5R
M)UTI.PHD<F]O=',@/2`D9&%T871R964M/F=E=$=R;W5P<R@I.PH*:68@*&ES
M7V$H)')O;W1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*"1R;V]T<RD["GT@96QS92!["B`@("!F;W)E86-H("@D<F]O=',@
M87,@)')O;W0I('L*("`@("`@("`D=')E92T^861D3F]D92@D<F]O="P@;G5L
M;"P@)')O;W0L(#`L(&9A;'-E*3L*("`@("`@("`D9&%T871R964@/2`F1&%T
M851R964Z.G-I;F=L971O;B@D9')I=F5R+"!A<G)A>5]M97)G92@D8V]N9FEG
M+"!A<G)A>2@G9W)O=7`G(#T^("1R;V]T*2DI.PH@("`@("`@(&%D9%1R964H
M)')O;W0L($1!5$%44D5%7U)/3U0I.PH@("`@?0I]"@II9B`H)'-H;W<@/2!5
M=&EL.CIG971&;W)M1&%T82@G<VAO=R<I*2!["B`@("!L:7-T*"1R;V]T+"`D
M:60I(#T@97AP;&]D92@G.B<L("1S:&]W*3L*("`@("1D871A=')E92`]("9$
M871A5')E93HZ<VEN9VQE=&]N*"1D<FEV97(L(&%R<F%Y7VUE<F=E*"1C;VYF
M:6<L(&%R<F%Y*"=G<F]U<"<@/3X@)')O;W0I*2D["B`@("`D9&%T82`]("1D
M871A=')E92T^9V5T1&%T82@D:60I.PH@("`@)&%T=')I8G5T97,@/2`D9&%T
M871R964M/F=E=$%T=')I8G5T97,H)&ED*3L*?0H*)'1I=&QE(#T@7R@B1&%T
M851R964@0G)O=W-E<B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN
M;W1I9GDH*3L*)'1R964M/G)E;F1E<E1R964H*3L*:68@*"1S:&]W*2!["B`@
M("!E8VAO("<\8G(@+SX\9&EV(&-L87-S/2)T97AT(B!S='EL93TB=VAI=&4M
M<W!A8V4Z<')E(CX\82!I9#TB<VAO=R(^/"]A/B<["B`@("!P<FEN=%]R*"1D
M871A*3L*("`@('!R:6YT7W(H)&%T=')I8G5T97,I.PH@("`@96-H;R`G/"]D
M:78^)SL*?0IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O
M;W1E<BYI;F,G.PH`````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W-E
M<W-I;VYS+G!H<```````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0P,C0`,3`U,34T,S$P-C``,#(P,#4S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+V%D;6EN+W-E<W-I;VYS+G!H<"QV(#$N,BXR+C,@,C`P-B\P
M,2\P,2`R,3HR.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#4M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP)SL*"FEF
M("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I
M;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)'1Y<&4@/2`A96UP='DH)&-O;F9;
M)W-E<W-I;VYH86YD;&5R)UU;)W1Y<&4G72D@/R`D8V]N9ELG<V5S<VEO;FAA
M;F1L97(G75LG='EP92==(#H@)VYO;F4G.PII9B`H)'1Y<&4@/3T@)V5X=&5R
M;F%L)RD@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#86XG="!A9&UI
M;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(BDL("=H;W)D92YE
M<G)O<B<I.PI](&5L<V4@>PH@("`@)'-H(#T@)E-E<W-I;VY(86YD;&5R.CIS
M:6YG;&5T;VXH)'1Y<&4I.PI]"@HD=&ET;&4@/2!?*")397-S:6]N($%D;6EN
M(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G
M;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*:68@*"%E;7!T>2@D<V@I*2![
M"B`@("`D=7-E<G,@/2`D<V@M/FQI<W1!=71H96YT:6-A=&5D57-E<G,H*3L*
M("`@("1C;W5N="`]("1S:"T^8V]U;G1!=71H96YT:6-A=&5D57-E<G,H*3L*
M("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B0W5R<F5N="!5
M<V5R<R(I.PH@("`@:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@96-H;R`G/"]H,3X\<"!C;&%S<STB:&5A9&5R8F]X(CX\96T^
M)R`N('-P<FEN=&8H7R@B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(BDL("1U
M<V5R<RT^9V5T365S<V%G92@I*2`N("<\+V5M/CPO<#XG.PH@("`@?2!E;'-E
M('L*("`@("`@("!E8VAO("<@*"<@+B`D8V]U;G0@+B`G*3PO:#$^)SL*("`@
M("`@("!E8VAO("<\=6P@8VQA<W,](FAE861E<F)O>"!L:6YE9%)O=R(^)SL*
M("`@("`@("!F;W)E86-H("@D=7-E<G,@87,@)'5S97(I('L*("`@("`@("`@
M("`@96-H;R`G/&QI/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`N("<\
M+VQI/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO=6P^)SL*("`@('T*
M"B`@("!E8VAO("<\8G(@+SXG.PH*("`@("1I9',@/2`D<V@M/F=E=%-E<W-I
M;VY)1',H*3L*("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B
M0W5R<F5N="!397-S:6]N<R(I("X@)SPO:#$^)SL*("`@(&EF("AI<U]A*"1I
M9',L("=014%27T5R<F]R)RDI('L*("`@("`@("!E8VAO("<\<"!C;&%S<STB
M:&5A9&5R8F]X(CX\96T^)R`N('-P<FEN=&8H7R@B3&ES=&EN9R!S97-S:6]N
M<R!F86EL960Z("5S(BDL("1I9',M/F=E=$UE<W-A9V4H*2D@+B`G/"]E;3X\
M+W`^)SL*("`@('T@96QS92!["B`@("`@("`@96-H;R`G/'5L(&-L87-S/2)H
M96%D97)B;W@@;&EN9612;W<B/B<["B`@("`@("`@9F]R96%C:"`H)&ED<R!A
M<R`D=7-E<BD@>PH@("`@("`@("`@("!E8VAO("<\;&D^)R`N(&AT;6QS<&5C
M:6%L8VAA<G,H)'5S97(I("X@)SPO;&D^)SL*("`@("`@("!]"B`@("`@("`@
M96-H;R`G/"]U;#XG.PH@("`@?0I]"@IR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V%D;6EN+W-Q;'-H96QL+G!H<```````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3,S,3(`,3`U,34T,S$P-C``,#(P,#,T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-Q;'-H96QL+G!H<"QV(#$N
M,3@N,3`N.2`R,#`V+S`R+S(T(#(R.C0X.C(Y(&-H=6-K($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E
M($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O365N=2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TAE;'`N<&AP
M)SL*<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN
M*"DI('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["GT*"B1T:71L92`](%\H(E-13"!3:&5L;"(I.PI(;W)D
M93HZ861D4V-R:7!T1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U92D[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN
M8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8R<["@H_/@H\9&EV('-T>6QE/2)P861D:6YG.C$P<'@B/@H\
M9F]R;2!N86UE/2)S<6QS:&5L;"(@86-T:6]N/2(\/W!H<"!E8VAO("1?4T52
M5D526R=02%!?4T5,1B==(#\^(B!M971H;V0](G!O<W0B/@H\/W!H<"!5=&EL
M.CIP9F]R;4EN<'5T*"D@/SX*"CP_<&AP"@HD9&)H(#T@)D1".CIC;VYN96-T
M*"1C;VYF6R=S<6PG72D["FEF("AI<U]A*"1D8F@L("=014%27T5R<F]R)RDI
M('L*("`@($AO<F1E.CIF871A;"@D9&)H+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PI]"B1D8F@M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))
M3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH*:68@
M*%5T:6PZ.F=E=$9O<FU$871A*"=L:7-T+71A8FQE<R<I*2!["B`@("`D9&5S
M8W)I<'1I;VX@/2`G3$E35"!404),15,G.PH@("`@)')E<W5L="`]("1D8F@M
M/F=E=$QI<W1/9B@G=&%B;&5S)RD["GT@96QS96EF("A5=&EL.CIG971&;W)M
M1&%T82@G;&ES="UD8G,G*2D@>PH@("`@)&1E<V-R:7!T:6]N(#T@)TQ)4U0@
M1$%404)!4T53)SL*("`@("1R97-U;'0@/2`D9&)H+3YG971,:7-T3V8H)V1A
M=&%B87-E<R<I.PI](&5L<V5I9B`H)&-O;6UA;F0@/2!T<FEM*%5T:6PZ.F=E
M=$9O<FU$871A*"=S<6PG*2DI('L*("`@("\O($ME97`@82!C86-H92!O9B!P
M<FEO<B!Q=65R:65S(&9O<B!C;VYV96YI96YC92X*("`@(&EF("@A:7-S970H
M)%]315-324].6R=?<W%L7W%U97)Y7V-A8VAE)UTI*2!["B`@("`@("`@)%]3
M15-324].6R=?<W%L7W%U97)Y7V-A8VAE)UT@/2!A<G)A>2@I.PH@("`@?0H@
M("`@:68@*"@D:V5Y(#T@87)R87E?<V5A<F-H*"1C;VUM86YD+"`D7U-%4U-)
M3TY;)U]S<6Q?<75E<GE?8V%C:&4G72DI("$]/2!F86QS92D@>PH@("`@("`@
M('5N<V5T*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==6R1K97E=*3L*
M("`@('T*("`@(&%R<F%Y7W5N<VAI9G0H)%]315-324].6R=?<W%L7W%U97)Y
M7V-A8VAE)UTL("1C;VUM86YD*3L*("`@('=H:6QE("AC;W5N="@D7U-%4U-)
M3TY;)U]S<6Q?<75E<GE?8V%C:&4G72D@/B`R,"D@>PH@("`@("`@(&%R<F%Y
M7W!O<"@D7U-%4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G72D["B`@("!]"@H@
M("`@+R\@4&%R<V4@;W5T('1H92!Q=65R>2!R97-U;'1S+@H@("`@)')E<W5L
M="`]("1D8F@M/G%U97)Y*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&-O;6UA
M;F0L($Y,4SHZ9V5T0VAA<G-E="@I+"`D8V]N9ELG<W%L)UU;)V-H87)S970G
M72DI.PI]"@II9B`H:7-S970H)')E<W5L="DI('L*("`@(&EF("AI<W-E="@D
M8V]M;6%N9"DI('L*("`@("`@("!E8VAO("<\:#$@8VQA<W,](FAE861E<B(^
M)R`N(%\H(E%U97)Y(BD@+B`G/"]H,3X\8G(@+SX\<')E(&-L87-S/2)T97AT
M(CXG("X@:'1M;'-P96-I86QC:&%R<R@D8V]M;6%N9"D@+B`G/"]P<F4^)SL*
M("`@('T*"B`@("!E8VAO("<\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(E)E
M<W5L=',B*2`N("<\+V@Q/CQB<B`O/B<["@H@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(&5C:&\@)SQP<F4@8VQA<W,]
M(G1E>'0B/B<[('9A<E]D=6UP*"1R97-U;'0I.R!E8VAO("<\+W!R93XG.PH@
M("`@?2!E;'-E('L*("`@("`@("!I9B`H:7-?;V)J96-T*"1R97-U;'0I*2![
M"B`@("`@("`@("`@(&5C:&\@)SQT86)L92!C96QL<W!A8VEN9STB,2(@8VQA
M<W,](FET96T@<W1R:7!E9"(^)SL*("`@("`@("`@("`@)&9I<G-T(#T@=')U
M93L*("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!W:&EL92`H)')O
M=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI('L*
M("`@("`@("`@("`@("`@(&EF("@D9FER<W0I('L*("`@("`@("`@("`@("`@
M("`@("!E8VAO("<\='(^)SL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D<F]W(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!E8VAO("<\=&@@86QI9VX](FQE9G0B/B<@+B`H96UP='DH)&ME>2D@
M/R`G)FYB<W`[)R`Z(&AT;6QS<&5C:6%L8VAA<G,H4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D:V5Y+"`D8V]N9ELG<W%L)UU;)V-H87)S970G72DI*2`N("<\
M+W1H/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&5C:&\@)SPO='(^)SL*("`@("`@("`@("`@("`@("`@("`D9FER<W0@
M/2!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5C
M:&\@)SQT<CXG.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O=R!A<R`D
M=F%L*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1D(&-L87-S/2)F
M:7AE9"(^)R`N("AE;7!T>2@D=F%L*2`_("<F;F)S<#LG(#H@:'1M;'-P96-I
M86QC:&%R<RA3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86PL("1C;VYF6R=S
M<6PG75LG8VAA<G-E="==*2DI("X@)SPO=&0^)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5C:&\@)SPO='(^)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E8VAO("<\+W1A8FQE/B<["B`@("`@("`@?2!E;'-E
M:68@*&ES7V%R<F%Y*"1R97-U;'0I*2!["B`@("`@("`@("`@(&5C:&\@)SQT
M86)L92!C96QL<W!A8VEN9STB,2(@8VQA<W,](FET96T@<W1R:7!E9"(^)SL*
M("`@("`@("`@("`@)&9I<G-T(#T@=')U93L*("`@("`@("`@("`@)&D@/2`P
M.PH@("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1V86PI('L*("`@
M("`@("`@("`@("`@(&EF("@D9FER<W0I('L*("`@("`@("`@("`@("`@("`@
M("!E8VAO("<\='(^/'1H(&%L:6=N/2)L969T(CXG("X@*&ES<V5T*"1D97-C
M<FEP=&EO;BD@/R!H=&UL<W!E8VEA;&-H87)S*"1D97-C<FEP=&EO;BD@.B`G
M)FYB<W`[)RD@+B`G/"]T:#X\+W1R/B<["B`@("`@("`@("`@("`@("`@("`@
M)&9I<G-T(#T@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!E8VAO("<\='(^/'1D(&-L87-S/2)F:7AE9"(^)R`N("AE;7!T>2@D
M=F%L*2`_("<F;F)S<#LG(#H@:'1M;'-P96-I86QC:&%R<RA3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1V86PL("1C;VYF6R=S<6PG75LG8VAA<G-E="==*2DI
M("X@)SPO=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C
M:&\@)SPO=&%B;&4^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E
M8VAO("<\<W1R;VYG/B<@+B!?*")3=6-C97-S(BD@+B`G/"]S=')O;F<^)SL*
M("`@("`@("!]"B`@("!]"@H@("`@96-H;R`G/&)R("\^)SL*?0H_/@H*/#]P
M:'`@:68@*&ES<V5T*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==*2`F
M)@H@("`@("`@("`@8V]U;G0H)%]315-324].6R=?<W%L7W%U97)Y7V-A8VAE
M)UTI*3H@/SX*("`\<V5L96-T(&YA;64](G%U97)Y7V-A8VAE(B!O;F-H86YG
M93TB9&]C=6UE;G0N<W%L<VAE;&PN<W%L+G9A;'5E(#T@9&]C=6UE;G0N<W%L
M<VAE;&PN<75E<GE?8V%C:&5;9&]C=6UE;G0N<W%L<VAE;&PN<75E<GE?8V%C
M:&4N<V5L96-T961);F1E>%TN=F%L=64[(CX*("`\/W!H<"!F;W)E86-H("@D
M7U-%4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G72!A<R`D<75E<GDI.B`_/@H@
M("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1Q=65R>2D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<75E
M<GDI(#\^/"]O<'1I;VX^"B`@/#]P:'`@96YD9F]R96%C:#L@/SX*("`\+W-E
M;&5C=#X*("`\:6YP=70@='EP93TB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H
M;R!?*")087-T92(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U
M;65N="YS<6QS:&5L;"YS<6PN=F%L=64@/2!D;V-U;65N="YS<6QS:&5L;"YQ
M=65R>5]C86-H95MD;V-U;65N="YS<6QS:&5L;"YQ=65R>5]C86-H92YS96QE
M8W1E9$EN9&5X72YV86QU93LB("\^"B`@/&EN<'5T('1Y<&4](F)U='1O;B(@
M=F%L=64](CP_<&AP(&5C:&\@7R@B4G5N(BD@/SXB(&-L87-S/2)B=71T;VXB
M(&]N8VQI8VL](F1O8W5M96YT+G-Q;'-H96QL+G-Q;"YV86QU92`](&1O8W5M
M96YT+G-Q;'-H96QL+G%U97)Y7V-A8VAE6V1O8W5M96YT+G-Q;'-H96QL+G%U
M97)Y7V-A8VAE+G-E;&5C=&5D26YD97A=+G9A;'5E.R!D;V-U;65N="YS<6QS
M:&5L;"YS=6)M:70H*3LB("\^"B`@/&)R("\^"CP_<&AP(&5N9&EF.R`_/@H*
M/'1E>'1A<F5A(&-L87-S/2)F:7AE9"(@;F%M93TB<W%L(B!R;W=S/2(Q,"(@
M8V]L<STB-C`B/@H\/W!H<"!I9B`H(65M<'1Y*"1C;VUM86YD*2D@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1C;VUM86YD*2`_/CPO=&5X=&%R96$^"CQB<B`O
M/@H\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB
M/#]P:'`@96-H;R!?*")%>&5C=71E(BD@/SXB("\^"CQI;G!U="!T>7!E/2)B
M=71T;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-L
M96%R(%%U97)Y(BD@/SXB(&]N8VQI8VL](F1O8W5M96YT+G-Q;'-H96QL+G-Q
M;"YV86QU93TG)R(@+SX*/#]P:'`@:68@*"%E;7!T>2@D8V]M;6%N9"DI.B`_
M/@H\:6YP=70@='EP93TB<F5S970B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(E)E<W1O<F4@3&%S="!1=65R>2(I(#\^(B`O/@H\/W!H
M<"!E;F1I9CL@/SX*/#]P:'`@:68@*"1D8F@M/F=E=%-P96-I86Q1=65R>2@G
M=&%B;&5S)RD@(3T](&YU;&PI.B`_/CQI;G!U="!T>7!E/2)S=6)M:70B(&-L
M87-S/2)B=71T;VXB(&YA;64](FQI<W0M=&%B;&5S(B!V86QU93TB/#]P:'`@
M96-H;R!?*"),:7-T(%1A8FQE<R(I(#\^(B`O/B`\/W!H<"!E;F1I9CL@/SX*
M/#]P:'`@:68@*"1D8F@M/F=E=%-P96-I86Q1=65R>2@G9&%T86)A<V5S)RD@
M(3T](&YU;&PI.B`_/CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T
M;VXB(&YA;64](FQI<W0M9&)S(B!V86QU93TB/#]P:'`@96-H;R!?*"),:7-T
M($1A=&%B87-E<R(I(#\^(B`O/B`\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96-H
M;R!(96QP.CIL:6YK*"=A9&UI;B<L("=A9&UI;BUS<6QS:&5L;"<I(#\^"@H\
M+V9O<FT^"CPO9&EV/@H\/W!H<`H*<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M861M:6XO=&5M<&QA=&5S+G!H<```````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-3$S-@`Q,#4Q-30S,3`V,``P,C`R,3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J($AO<F1E(%1E;7!L871E($%D;6EN"B`J"B`J("1(;W)D93H@:&]R9&4O
M861M:6XO=&5M<&QA=&5S+G!H<"QV(#$N,34N,3`N,R`R,#`V+S`Q+S`Q(#(Q
M.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!&:7)S="!S=&%B(&%T(&$@=&5M<&QA
M=&4@;&]A9&5R(&9O<B!H;W)D92P@=&\@8F4@=7-E9"!B>2!T:&4@:&]R9&4*
M("H@861M:6X@=&\@;&]A9"!A;'1E<FYA=&4@:6YD:79I9'5A;"!T96UP;&%T
M97,@;W(@96YT:7)E('1H96UE<R!F;W(@=&AE"B`J($AO<F1E7U1E;7!L871E
M('-Y<W1E;2X*("H@+2!G:79E<R!A(&QI<W0@;V8@86-T:79E(&AO<F1E(&%P
M<',@86YD('1H96ER("]T96UP;&%T97,@9&ER96-T;W)Y"B`J("`@8V]N=&5N
M=',@=&\@8VAO;W-E(&9R;VT*("H@+2!U<V5R(&-A;B!D<FEL;"!D;W=N('1O
M(&$@<W!E8VEF:6,@9FEL92!A;F0@;&]A9"!A<R!M86YY(&%L=&5R;F%T90H@
M*B`@('1E;7!L871E<R!A<R!R97%U:7)E9`H@*B`M(&ET(&%L;&]W<R!S879I
M;F<@;V8@=&5M<&QA=&5S(&]N;'D@;VX@86-T=6%L(&9I;&5S("AA;F0@;F]T
M"B`J("`@9&ER96-T;W)I97,I(&%N9"!D;V5S(&YO="!S:&]W(&AI9&1E;B!F
M:6QE<RX*("H@+2!T:&4@86QT97)N871E('1E;7!L871E<R!A<F4@<W1O<F5D
M(&EN('1H92!61E,@=6YD97(@=&AE(&1I<F5C=&]R>0H@*B`@('!A=&@Z"B`J
M("`@("`@+FAO<F1E7W1E;7!L871E<R\D87!P+W-O;65T96UP;&%T961I<B]T
M96UP;&%T969I;&4*("H@("!S;R!T:&%T(&1I<F5C=&]R>2!W;W5L9"!C;VYT
M86EN(&%L;"!T:&4@86QT97)N871I=F5S(&9O<B!T:&%T"B`J("`@=&5M<&QA
M=&4N"B`J("T@5$]$3SH@9&]N)W0@<VAO=R!C97)T86EN(&]T:&5R(&9I;&5S
M+"!L:6ME($-64R!D:7)E8W1O<FEE<SL@8V]M;65N=',["B`J("`@=&AE;64@
M<V5L96-T:6]N(&%N9"!S=&]R:6YG(&EN('1H92!61E,@=6YD97(Z"B`J("`@
M("`@+FAO<F1E7W1E;7!L871E<R\D87!P+U]T:&5M97,O)'1H96UE+W-O;65T
M96UP;&%T961I<B]T96UP;&%T969I;&4*("H@("!T;R!B92!A8FQE('1O(&-A
M;&P@=7`@86X@96YT:7)E('1H96UE(&=R;W5P(&]F('1E;7!L871E<S\@8F5T
M=&5R(&5R<F]R"B`J("`@8VAE8VMI;F<[(&1O=VYL;V%D:6YG(&]F(&]R:6=I
M;F%L('1E;7!L871E<SL@=&AE(&%P<&QI8V%T:6]N('-I9&4@;V8*("H@("!A
M;&QO=VEN9R!A(&1I9F9E<F5N="!T96UP;&%T92!T;R!B92!C:&]S96XO<')E
M9G,O971C+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E
M<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]687)I86)L97,N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@
M("!(;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PI]"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==
M6R=D<FEV97(G72D["@IF=6YC=&EO;B!?<V5T5F%L=65S5&]+97ES*"1I;BD@
M>PH@("`@)&]U="`](&%R<F%Y*"D["B`@("!F;W)E86-H("@D:6X@87,@)'9A
M;'5E*2!["B`@("`@("`@)&]U=%LD=F%L=65=(#T@)'9A;'5E.PH@("`@?0H@
M("`@87-O<G0H)&]U="D["B`@("!R971U<FX@)&]U=#L*?0H*+RH@4V5T('5P
M(%9&4RX@*B\*<F5Q=6ER95]O;F-E("=61E,N<&AP)SL*)'9F<U]T>7!E(#T@
M)&-O;F9;)W9F<R==6R=T>7!E)UT["B1V9G-?87)G<R`]($AO<F1E.CIG971$
M<FEV97)#;VYF:6<H)W9F<R<L("1V9G-?='EP92D["B1V9G-?87)G<ULG=7-E
M<B==(#T@075T:#HZ9V5T075T:"@I.PHD=F9S(#T@)E9&4SHZ<VEN9VQE=&]N
M*"1V9G-?='EP92P@)'9F<U]A<F=S*3L*"D!D969I;F4H)U1%35!,051%4U]6
M1E-?4$%42"<L("<N:&]R9&5?=&5M<&QA=&5S)RD["@HO*B!297%U:7)E($AO
M<F1E7T9O<FT@;&EB<RX@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTO06-T:6]N+G!H<"<["@HO*B!3970@
M=7`@2&]R9&5?1F]R;2X@*B\*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A
M=6QT5F%R:6%B;&5S*"D["B1F;W)M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O
M;B@G5&5M<&QA=&5S1F]R;2<L("1V87)S*3L*)&%C=&EO;B`]("9(;W)D95]&
M;W)M7T%C=&EO;CHZ9F%C=&]R>2@G<W5B;6ET)RD["@HO*B!3970@=7`@9F]R
M;2!F:65L9',N("HO"B1A<'!S(#T@7W-E=%9A;'5E<U1O2V5Y<R@D<F5G:7-T
M<GDM/FQI<W1!<'!S*"DI.PHD<V5L96-T7V%P<"`]("8D9F]R;2T^861D5F%R
M:6%B;&4H7R@B07!P;&EC871I;VXB*2P@)V%P<"<L("=E;G5M)RP@=')U92P@
M9F%L<V4L(&YU;&PL(&%R<F%Y*"1A<'!S*2D["B1S96QE8W1?87!P+3YS971!
M8W1I;VXH)&%C=&EO;BD["B1F;W)M+3YA9&1(:61D96XH)R<L("=O;&1?87!P
M)RP@)W1E>'0G+"!F86QS92P@9F%L<V4I.PH*+RH@4V5T('5P('-O;64@=F%R
M:6%B;&5S+B`J+PHD9F]R;6YA;64@/2`D=F%R<RT^9V5T*"=F;W)M;F%M92<I
M.PHD87!P(#T@)'9A<G,M/F=E="@G87!P)RD["B1O;&1?87!P(#T@)'9A<G,M
M/F=E="@G;VQD7V%P<"<I.PHD=&5M<&QA=&5?<&%T:"`]("1V87)S+3YG970H
M)W1E;7!L871E7W!A=&@G*3L*)'1E;7!L871E7V]R:6<@/2`D=F%R<RT^9V5T
M*"=T96UP;&%T95]O<FEG)RD["B1O;&1?=&5M<&QA=&5?;W)I9R`]("1V87)S
M+3YG970H)V]L9%]T96UP;&%T95]O<FEG)RD["B1H87-?8VAA;F=E9"`](&9A
M;'-E.PH*:68@*"1A<'`@(3T@)&]L9%]A<'`I('L*("`@("1H87-?8VAA;F=E
M9"`]('1R=64["B`@("`D=&5M<&QA=&5?<&%T:"`]("<G.PH@("`@)'1E;7!L
M871E7V]R:6<@/2`G)SL*("`@("1O;&1?=&5M<&QA=&5?;W)I9R`]("<G.PI]
M"B1V87)S+3YS970H)V]L9%]A<'`G+"`D87!P*3L*:68@*"1T96UP;&%T95]O
M<FEG("$]("1O;&1?=&5M<&QA=&5?;W)I9RD@>PH@("`@)&AA<U]C:&%N9V5D
M(#T@=')U93L*?0HD=F%R<RT^<V5T*"=O;&1?=&5M<&QA=&5?;W)I9R<L("1T
M96UP;&%T95]O<FEG*3L*"FEF("@A:7-?;G5L;"@D87!P*2D@>PH@("`@:68@
M*"1T96UP;&%T95]O<FEG(#T]("<N+B<I('L*("`@("`@("`D<&%T:%]P87)T
M<R`](&5X<&QO9&4H)R\G+"`D=&5M<&QA=&5?<&%T:"D["B`@("`@("`@87)R
M87E?<&]P*"1P871H7W!A<G1S*3L*("`@("`@("`D=&5M<&QA=&5?<&%T:"`]
M(&EM<&QO9&4H)R\G+"`D<&%T:%]P87)T<RD["B`@("`@("`@)'1E;7!L871E
M7V]R:6<@/2`G)SL*("`@('T*"B`@("`O*B!'970@=&AE(&9U;&P@=&5M<&QA
M=&4@<&%T:"!O;B!T:&4@9FEL92!S>7-T96TN("HO"B`@("`D=&5M<&QA=&5?
M<&%T:%]F=6QL(#T@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("1A<'`I
M("X@)R\G("X@)'1E;7!L871E7W!A=&@["@H@("`@+RH@268@<V5L96-T960@
M=&5M<&QA=&4@:7,@9&ER96-T;W)Y(&%D9"!T;R!T96UP;&%T92!P871H+B`J
M+PH@("`@:68@*"%E;7!T>2@D=&5M<&QA=&5?;W)I9RD@)B8*("`@("`@("!I
M<U]D:7(H)'1E;7!L871E7W!A=&A?9G5L;"`N("<O)R`N("1T96UP;&%T95]O
M<FEG*2D@>PH@("`@("`@("1T96UP;&%T95]P871H("X]("<O)R`N("1T96UP
M;&%T95]O<FEG.PH@("`@("`@("1T96UP;&%T95]P871H7V9U;&P@+CT@)R\G
M("X@)'1E;7!L871E7V]R:6<["B`@("!]"@H@("`@)&9O<FTM/F%D9%9A<FEA
M8FQE*'-P<FEN=&8H7R@B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(I+"`D
M=&5M<&QA=&5?<&%T:"DL("=O<FEG7W1E;7!L871E<U]H96%D97(G+"`G:&5A
M9&5R)RP@9F%L<V4L(&9A;'-E*3L*"B`@("`O*B!!9&0@=&AE('!A=&@@=&\@
M=&AE(&AI9&1E;B!V87(@:6X@=&AE(&9O<FTN("HO"B`@("`D9F]R;2T^861D
M2&ED9&5N*"<G+"`G=&5M<&QA=&5?<&%T:"<L("=T97AT)RP@9F%L<V4L(&9A
M;'-E*3L*("`@("1V87)S+3YS970H)W1E;7!L871E7W!A=&@G+"`D=&5M<&QA
M=&5?<&%T:"D["@H@("`@+RH@1V5T(&1I<F5C=&]R>2!L:7-T(&9O<B!C:&]S
M96X@9&ER96-T;W)Y(&EN('1E;7!L871E<RX@*B\*("`@(&EF("@D=&5M<&QA
M=&5S7V1I<B`](&]P96YD:7(H)'1E;7!L871E7W!A=&A?9G5L;"DI('L*("`@
M("`@("!W:&EL92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H)'1E;7!L
M871E<U]D:7(I*2D@>PH@("`@("`@("`@("`O*B!$;VXG="!S:&]W(&-U<G)E
M;G0@9&ER+"!H:61D96X@9FEL97,@86YD(&]N;'D@<VAO=R`G+BXG"B`@("`@
M("`@("`@("`J(&EF(&YO="!I;B!R;V]T(&1I<B!O9B!A;B!A<'`G<R!T96UP
M;&%T97,N("HO"B`@("`@("`@("`@(&EF("@D9FEL92`A/2`B+B(@)B8@(2@D
M9FEL92`]/2`G+BXG("8F(&5M<'1Y*"1T96UP;&%T95]P871H*2D@)B8*("`@
M("`@("`@("`@("`@("$H)&9I;&4@(3T@)RXN)R`F)B!S=6)S='(H)&9I;&4L
M(#`L(#$I(#T]("<N)RDI('L*("`@("`@("`@("`@("`@("1T96UP;&%T97-;
M72`]("1F:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&-L
M;W-E9&ER*"1T96UP;&%T97-?9&ER*3L*("`@("`@("`D=&5M<&QA=&5S(#T@
M7W-E=%9A;'5E<U1O2V5Y<R@D=&5M<&QA=&5S*3L*("`@("`@("`D=B`]("8D
M9F]R;2T^861D5F%R:6%B;&4H7R@B3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4B*2P@)W1E;7!L871E7V]R:6<G+"`G96YU;2<L('1R=64L(&9A;'-E
M+"!N=6QL+"!A<G)A>2@D=&5M<&QA=&5S*2D["B`@("`@("`@)'8M/G-E=$%C
M=&EO;B@D86-T:6]N*3L*("`@("`@("`D9F]R;2T^861D2&ED9&5N*"<G+"`G
M;VQD7W1E;7!L871E7V]R:6<G+"`G=&5X="<L(&9A;'-E+"!F86QS92D["B`@
M("!]"@H@("`@+RH@3VYL>2!S970@=7`@=&AE<V4@=F%R<R!I9B!T:&4@8VAO
M<V5N('1E;7!L871E(&ES(&$@9FEL92X@*B\*("`@(&EF("AI<U]F:6QE*"1T
M96UP;&%T95]P871H7V9U;&P@+B`G+R<@+B`D=&5M<&QA=&5?;W)I9RDI('L*
M("`@("`@("`D9F]R;2T^861D5F%R:6%B;&4H7R@B06QT97)N871E('1E;7!L
M871E<R(I+"`G86QT7W1E;7!L871E<U]H96%D97(G+"`G:&5A9&5R)RP@9F%L
M<V4L(&9A;'-E*3L*"B`@("`@("`@+RH@1V5T('1H92!A;')E861Y('-A=F5D
M(&%L=&5R;F%T92!T96UP;&%T97,N("HO"B`@("`@("`@)'9F<U]P871H(#T@
M5$5-4$Q!5$537U9&4U]0051(("X@)R\G("X@)&%P<"`N("1T96UP;&%T95]P
M871H("X@)R\G("X@)'1E;7!L871E7V]R:6<["B`@("`@("`@)'1E;7!L871E
M<U]A;'0@/2!A<G)A>5]K97ES*"1V9G,M/FQI<W1&;VQD97(H)'9F<U]P871H
M+"!N=6QL+"!F86QS92DI.PH@("`@("`@("1T96UP;&%T97-?86QT(#T@87)R
M87DH)R<@/3X@)R<I("L@7W-E=%9A;'5E<U1O2V5Y<R@D=&5M<&QA=&5S7V%L
M="D["B`@("`@("`@)&9O<FTM/F%D9%9A<FEA8FQE*%\H(D1E;&5T92!E>&ES
M=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B*2P@)V1E;&5T95]T96UP;&%T95]A
M;'0G+"`G96YU;2<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)'1E;7!L
M871E<U]A;'0I*3L*"B`@("`@("`@)&9O<FTM/F%D9%9A<FEA8FQE*%\H(DEN
M<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B*2P@)W1E;7!L871E7V%L="<L("=F
M:6QE)RP@9F%L<V4L(&9A;'-E*3L*("`@('T*?0H*:68@*"1F;W)M;F%M92`F
M)B`A)&AA<U]C:&%N9V5D*2!["B`@("`O*B!);G-E<G1I;F<@82!N97<@86QT
M97)N871E('1E;7!L871E+B`J+PH@("`@)&9O<FTM/G9A;&ED871E*"1V87)S
M*3L*"B`@("!I9B`H)&9O<FTM/FES5F%L:60H*2D@>PH@("`@("`@("1F;W)M
M+3YG971);F9O*"1V87)S+"`D:6YF;RD["B`@("`@("`@:68@*"%E;7!T>2@D
M:6YF;ULG9&5L971E7W1E;7!L871E7V%L="==*2D@>PH@("`@("`@("`@("`D
M=F9S+3YD96QE=&5&:6QE*"1V9G-?<&%T:"P@)&EN9F];)V1E;&5T95]T96UP
M;&%T95]A;'0G72D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&EN
M9F];)W1E;7!L871E7V%L="==6R=S:7IE)UTI*2!["B`@("`@("`@("`@("1V
M9G,M/G=R:71E*"1V9G-?<&%T:"P@)&EN9F];)W1E;7!L871E7V%L="==6R=N
M86UE)UTL("1I;F9O6R=T96UP;&%T95]A;'0G75LG=&UP7VYA;64G72P@=')U
M92D["B`@("`@("`@?0H@("`@?0I]"@HD=&ET;&4@/2!?*")496UP;&%T92!!
M9&UI;FES=')A=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN
M;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*"B\J(%)E
M;F1E<B!T:&4@9F]R;2X@*B\*)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M
M7U)E;F1E<F5R*"D["B1F;W)M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D
M=F%R<RP@)W1E;7!L871E<RYP:'`G+"`G<&]S="<I.PH*<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO9W)O=7!S+G!H
M<```````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R
M,#$T,@`Q,#4Q-30S,3`V,``P,3<U,C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O861M:6XO9W)O=7!S+G!H<"QV(#$N-3`N,BXV(#(P,#8O,#<O,3,@,#DZ
M,#$Z-3,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S
M92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+U1R964N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D
M93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)&=R;W5P
M<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["B1A=71H(#T@)D%U=&@Z.G-I;F=L
M971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D["@HD9F]R;2`](&YU;&P[
M"B1R96QO860@/2!F86QS93L*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V%C=&EO;DE$)RD["B1C:60@/2!5=&EL.CIG971&;W)M1&%T82@G8VED
M)RD["@IS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=A9&1C:&EL9"<Z"B`@
M("!I9B`H)&-I9"`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@)&9O<FT@
M/2`G861D8VAI;&0N:6YC)SL*("`@("`@("`D9VYA;64@/2!?*")!;&P@1W)O
M=7!S(BD["B`@("!](&5L<V4@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S
M+3YG971'<F]U<$)Y260H)&-I9"D["B`@("`@("`@:68@*"%I<U]A*"1G<F]U
M<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9VYA;64@/2`D9W)O
M=7`M/F=E=%-H;W)T3F%M92@I.PH@("`@("`@("`@("`D9F]R;2`]("=A9&1C
M:&EL9"YI;F,G.PH@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G
M861D8VAI;&1F;W)M)SH*("`@("1P87)E;G0@/2`D8VED.PH@("`@:68@*"1P
M87)E;G0@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("1C:&EL9"`]("8D
M9W)O=7!S+3YN97='<F]U<"A5=&EL.CIG971&;W)M1&%T82@G8VAI;&0G*2D[
M"B`@("`@("`@)')E<W5L="`]("1G<F]U<',M/F%D9$=R;W5P*"1C:&EL9"D[
M"B`@("!](&5L<V4@>PH@("`@("`@("1C:&EL9"`]("8D9W)O=7!S+3YN97='
M<F]U<"A5=&EL.CIG971&;W)M1&%T82@G8VAI;&0G*2P@)'!A<F5N="D["B`@
M("`@("`@)')E<W5L="`]("1G<F]U<',M/F%D9$=R;W5P*"1C:&EL9"D["B`@
M("!]"B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB
M*2P@)&-H:6QD+3YG9713:&]R=$YA;64H*2P@)')E<W5L="T^9V5T365S<V%G
M92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+B(I+"`D8VAI;&0M/F=E=%-H;W)T3F%M
M92@I*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D9W)O=7`@/2`D8VAI
M;&0["B`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@("`@("1R96QO
M860@/2!T<G5E.PH@("`@?0H@("`@8G)E86L["@IC87-E("=D96QE=&4G.@H@
M("`@)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D8VED*3L*("`@
M(&EF("@A:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI('L*("`@("`@("`D
M9F]R;2`]("=D96QE=&4N:6YC)SL*("`@('T*("`@(&)R96%K.PH*8V%S92`G
M9&5L971E9F]R;2<Z"B`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V-O;F9I
M<FTG*2`]/2!?*")$96QE=&4B*2D@>PH@("`@("`@("1G<F]U<"`]("8D9W)O
M=7!S+3YG971'<F]U<$)Y260H)&-I9"D["B`@("`@("`@:68@*&ES7V$H)&=R
M;W5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1R97-U;'0@/2`D9W)O=7!S+3YR96UO=F5'<F]U<"@D9W)O
M=7`L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(I
M+"`D9W)O=7`M/F=E=%-H;W)T3F%M92@I+"`D<F5S=6QT+3YG971-97-S86=E
M*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(I+"`D9W)O=7`M/F=E=%-H
M;W)T3F%M92@I*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@
M("1C:60@/2!N=6QL.PH@("`@("`@("`@("`@("`@)')E;&]A9"`]('1R=64[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*"F-A
M<V4@)V5D:70G.@H@("`@)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)
M9"@D8VED*3L*("`@(&EF("@A:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("!](&5L<V5I9B`H
M*"1C871E9V]R>2`](%5T:6PZ.F=E=$9O<FU$871A*"=C871E9V]R>2<I*2`A
M/3T@;G5L;"D@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U
M<"@D8V%T96=O<GDI.PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@
M("`@("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G875T;V-R96%T
M92<I*2!["B`@("`@("`@("`@("1P87)E;G0@/2!5=&EL.CIG971&;W)M1&%T
M82@G<&%R96YT)RD["B`@("`@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YN
M97='<F]U<"@D8V%T96=O<GDI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)&=R
M;W5P<RT^861D1W)O=7`H)&=R;W5P+"`D<&%R96YT*3L*("`@("`@("`@("`@
M:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("1F;W)M(#T@)V5D:70N:6YC)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G961I=&9O<FTG.@H@("`@
M)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D8VED*3L*"B`@("`O
M+R!M86ME(&$@8V]P>2!O9B!T:&4@9W)O=7`@<V\@=V4@8V%N(')E<W1O<F4@
M:70@:68@=&AE<F4@:7,@86X@97)R;W(N"B`@("`D<F5S=&]R92`]("1G<F]U
M<#L*"B`@("`O+R!!9&0@86YY(&YE=R!U<V5R<RX*("`@("1N97=U<V5R(#T@
M571I;#HZ9V5T1F]R;41A=&$H)VYE=U]U<V5R)RD["B`@("!I9B`H(65M<'1Y
M*"1N97=U<V5R*2D@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D;F5W=7-E<BDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&YE=W5S97(@87,@)&YE=RD@>PH@
M("`@("`@("`@("`@("`@)&=R;W5P+3YA9&15<V5R*"1N97<L(&9A;'-E*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1G
M<F]U<"T^861D57-E<B@D;F5W=7-E<BP@9F%L<V4I.PH@("`@("`@('T*("`@
M('T*"B`@("`O+R!296UO=F4@86YY('5S97)S(&UA<FME9"!F;W(@<'5R9VEN
M9RX*("`@("1R96UO=F5S(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E;6]V92<I
M.PH@("`@:68@*"%E;7!T>2@D<F5M;W9E<RD@)B8@:7-?87)R87DH)')E;6]V
M97,I*2!["B`@("`@("`@9F]R96%C:"`H)')E;6]V97,@87,@)'5S97(@/3X@
M)&IU;FLI('L*("`@("`@("`@("`@)&=R;W5P+3YR96UO=F55<V5R*"1U<V5R
M+"!F86QS92D["B`@("`@("`@?0H@("`@?0H*("`@("\O(%-E="!T:&4@96UA
M:6P@861D<F5S<R!O9B!T:&4@9W)O=7`N"B`@("`D9W)O=7`M/G-E="@G96UA
M:6PG+"!5=&EL.CIG971&;W)M1&%T82@G96UA:6PG*2D["@H@("`@+R\@4V%V
M92!T:&4@9W)O=7`@=&\@=&AE(&)A8VME;F0N"B`@("`D<F5S=6QT(#T@)&=R
M;W5P+3YS879E*"D["@H@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="T^
M9V5T365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`O+R!R97-T
M;W)E(&)A8VMU<"!C;W!Y"B`@("`@("`@)&=R;W5P(#T@)')E<W1O<F4["B`@
M("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")5<&1A=&5D(%PB)7-<(BXB*2P@)&=R;W5P+3YG9713:&]R=$YA;64H
M*2DL("=H;W)D92YS=6-C97-S)RD["B`@("!]"@H@("`@)&9O<FT@/2`G961I
M="YI;F,G.PH@("`@)')E;&]A9"`]('1R=64["B`@("!B<F5A:SL*?0H*<W=I
M=&-H("@D9F]R;2D@>PIC87-E("=A9&1C:&EL9"YI;F,G.@H@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@G9&]C=6UE;G0N861D7V-H:6QD+F-H:6QD+F9O8W5S
M*"DG+"`G:F%V87-C<FEP="<I.PH@("`@8G)E86L["@IC87-E("=E9&ET+FEN
M8R<Z"B`@("`O*B!3970@=7`@=&AE(&QI<W1S+B`J+PH@("`@)'5S97)S(#T@
M)&=R;W5P+3YL:7-T57-E<G,H*3L*("`@(&EF("AI<U]A*"1U<V5R<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'5S
M97)S+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`D=7-E<G,@/2!A<G)A>2@I
M.PH@("`@?0H@("`@)&%L;%]U<V5R<R`]("1G<F]U<"T^;&ES=$%L;%5S97)S
M*"D["B`@("!I9B`H:7-?82@D86QL7W5S97)S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D86QL7W5S97)S+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("`D86QL7W5S97)S(#T@87)R87DH*3L*("`@
M('T*("`@("1I;FAE<FET961?=7-E<G,@/2!A<G)A>5]D:69F*"1A;&Q?=7-E
M<G,L("1U<V5R<RD["@H@("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L
M:7-T)RDI('L*("`@("`@("`D=7-E<E]L:7-T(#T@)&%U=&@M/FQI<W15<V5R
M<R@I.PH@("`@("`@(&EF("AI<U]A*"1U<V5R7VQI<W0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D=7-E<E]L
M:7-T+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@)'5S97)?;&ES="`]
M(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@('-O<G0H)'5S97)?;&ES="D[
M"B`@("!](&5L<V4@>PH@("`@("`@("1U<V5R7VQI<W0@/2!A<G)A>2@I.PH@
M("`@?0H@("`@8G)E86L["@I]"@HD=&ET;&4@/2!?*")'<F]U<"!!9&UI;FES
M=')A=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N
M+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M
M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH
M87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*:68@*"%E;7!T>2@D
M9F]R;2DI('L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI
M;B]G<F]U<',O)R`N("1F;W)M.PI]"@HO*B!'970@=&AE('!E<FUS('1R964N
M("HO"B1N;V1E<R`]("1G<F]U<',M/FQI<W1'<F]U<',H=')U92D["B1N;V1E
M<UM$051!5%)%15]23T]472`]($1!5$%44D5%7U)/3U0["@HO*B!3970@=7`@
M<V]M92!N;V1E('!A<F%M<RX@*B\*)'-P86-E<B`]("<F;F)S<#LF;F)S<#LF
M;F)S<#LF;F)S<#LG.PHD:6-O;F1I<B`](&%R<F%Y*"=I8V]N9&ER)R`]/B`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"DI.PHD9W)O=7!?;F]D92`]("1I8V]N
M9&ER("L@87)R87DH)VEC;VXG(#T^("=G<F]U<"YP;F<G*3L*)&%D9"`]($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO9W)O=7!S+G!H<#]A8W1I;VY)
M1#UA9&1C:&EL9"<I.PHD961I="`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M861M:6XO9W)O=7!S+G!H<#]A8W1I;VY)1#UE9&ET)RD["B1D96QE=&4@/2!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+V=R;W5P<RYP:'`_86-T:6]N
M240]9&5L971E)RD["B1E9&ET7VEM9R`]($AO<F1E.CII;6<H)V5D:70N<&YG
M)RP@7R@B161I="!'<F]U<"(I*3L*)&1E;&5T95]I;6<@/2!(;W)D93HZ:6UG
M*"=D96QE=&4N<&YG)RP@7R@B1&5L971E($=R;W5P(BDI.PH*+RH@4V5T('5P
M('1H92!T<F5E+B`J+PHD=')E92`]($AO<F1E7U1R964Z.F9A8W1O<GDH)V%D
M;6EN7V=R;W5P<R<L("=J879A<V-R:7!T)RD["B1T<F5E+3YS971/<'1I;VXH
M87)R87DH)V%L=&5R;F%T92<@/3X@=')U92P@)VAI9&5(96%D97)S)R`]/B!T
M<G5E*2D["B1T<F5E+3YS971(96%D97(H87)R87DH87)R87DH)W=I9'1H)R`]
M/B`G-3`E)RDI*3L*"B\J($5X<&QI8VET;'D@8VAE8VL@9F]R(#X@,"!S:6YC
M92!W92!C86X@8F4@8V%L;&5D('=I=&@@8W5R<F5N="`]("TQ"B`J(&9O<B!T
M:&4@<F]O="!N;V1E+B`J+PII9B`H)&-I9"`^(#`I('L*("`@("1C:61?<&%R
M96YT<R`]("1G<F]U<',M/F=E=$=R;W5P4&%R96YT3&ES="@D8VED*3L*("`@
M(&EF("AI<U]A*"1C:61?<&%R96YT<RP@)U!%05)?15)R;W(G*2D@>PH@("`@
M("`@($AO<F1E.CIF871A;"@D8VED7W!A<F5N=',L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("!]"GT*"F9O<F5A8V@@*"1N;V1E<R!A<R`D:60@/3X@)&YO
M9&4I('L*("`@("1N;V1E7W!A<F%M<R`]("@D8VED(#T]("1I9"D@/R!A<G)A
M>2@G8VQA<W,G(#T^("=S96QE8W1E9"<I(#H@87)R87DH*3L*("`@(&EF("@D
M:60@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("1A9&1?:6UG(#T@2&]R
M9&4Z.FEM9R@G9W)O=7`N<&YG)RP@7R@B061D($YE=R!'<F]U<"(I*3L*("`@
M("`@("`D861D7VQI;FL@/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T
M97(H)&%D9"P@)V-I9"<L("1I9"DL(%\H(D%D9"!.97<@1W)O=7`B*2D@+B`D
M861D7VEM9R`N("<\+V$^)SL*"B`@("`@("`@)&)A<V5?;F]D95]P87)A;7,@
M/2`D:6-O;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G861M:6YI<W1R871I;VXN
M<&YG)RD["B`@("`@("`@)'1R964M/F%D9$YO9&4H)&ED+"!N=6QL+"!?*")!
M;&P@1W)O=7!S(BDL(#`L('1R=64L("1B87-E7VYO9&5?<&%R86US("L@)&YO
M9&5?<&%R86US+"!A<G)A>2@D<W!A8V5R+"`D861D7VQI;FLI*3L*("`@('T@
M96QS92!["B`@("`@("`@)&YO9&5?<&%R86US6R=U<FPG72`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D961I="P@)V-I9"<L("1I9"D["B`@("`@("`@)&%D9%]I
M;6<@/2!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G+"!?*")!9&0@0VAI;&0@1W)O
M=7`B*2D["B`@("`@("`@)&%D9%]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ
M861D4&%R86UE=&5R*"1A9&0L("=C:60G+"`D:60I+"!?*")!9&0@0VAI;&0@
M1W)O=7`B*2D@+B`D861D7VEM9R`N("<\+V$^)SL*("`@("`@("`D9&5L971E
M7VQI;FL@/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)&1E;&5T
M92P@)V-I9"<L("1I9"DL(%\H(D1E;&5T92!'<F]U<"(I*2`N("1D96QE=&5?
M:6UG("X@)SPO83XG.PH*("`@("`@("`D<&%R96YT7VED(#T@)&=R;W5P<RT^
M9V5T1W)O=7!087)E;G0H)&ED*3L*("`@("`@("`D9W)O=7!?97AT<F$@/2!A
M<G)A>2@D<W!A8V5R+"`D861D7VQI;FLL("1D96QE=&5?;&EN:RD["B`@("`@
M("`@)'1R964M/F%D9$YO9&4H)&ED+"`D<&%R96YT7VED+"`D9W)O=7!S+3YG
M971'<F]U<%-H;W)T3F%M92@D;F]D92DL("1G<F]U<',M/F=E=$QE=F5L*"1I
M9"D@*R`Q+"`H:7-S970H)&-I9%]P87)E;G1S6R1I9%TI*2`_('1R=64@.B!F
M86QS92P@)&=R;W5P7VYO9&4@*R`D;F]D95]P87)A;7,L("1G<F]U<%]E>'1R
M82D["B`@("!]"GT*"F5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@2&]R
M9&4Z.FEM9R@G9W)O=7`N<&YG)RD@+B`G("<@+B!?*")'<F]U<',B*2`N("<\
M+V@Q/B<["B1T<F5E+3YR96YD97)4<F5E*"D["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O````````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`V,``P,34P,C,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]T86)L
M97,N:G,`````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#(R-C(W`#$P-3$U-#,Q,#8P`#`Q-C8T,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*BH*("H@2F%V87-C<FEP
M="!C;V1E(&9O<B!F:6YD:6YG(&%L;"!T86)L97,@=VET:"!C;&%S<VYA;64@
M(G-T<FEP960B(&%N9`H@*B!D>6YA;6EC86QL>2!S=')I<&EN9R!T:&5I<B!R
M;W<@8V]L;W)S+"!A;F0@9FEN9&EN9R!A;&P@=&%B;&5S('=I=&@*("H@8VQA
M<W-N86UE(")S;W)T86)L92(@86YD(&UA:VEN9R!T:&5M(&1Y;F%M:6-A;&QY
M('-O<G1A8FQE+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+W1A8FQE<RYJ<RQV
M(#$N-"XR+C,@,C`P-2\Q,B\P,2`R,CHU.#HR-B!C:'5C:R!%>'`@)`H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@HO*B!792!D;R!E=F5R>71H:6YG(&]N;&]A9"!S;R!T
M:&%T('1H92!E;G1I<F4@9&]C=6UE;G0@:7,@<')E<V5N=`H@*B!B969O<F4@
M=V4@<W1A<G0@<V5A<F-H:6YG(&ET(&9O<B!T86)L97,N("HO"FEF("AW:6YD
M;W<N861D179E;G1,:7-T96YE<BD@>PH@("`@=VEN9&]W+F%D9$5V96YT3&ES
M=&5N97(H)VQO860G+"!T86)L95]I;FET+"!F86QS92D["GT@96QS92!I9B`H
M=VEN9&]W+F%T=&%C:$5V96YT*2!["B`@("!W:6YD;W<N871T86-H179E;G0H
M)V]N;&]A9"<L('1A8FQE7VEN:70I.PI](&5L<V4@:68@*'=I;F1O=RYO;FQO
M860@(3T@;G5L;"D@>PH@("`@=F%R(&]L9%]O;FQO860@/2!W:6YD;W<N;VYL
M;V%D.PH@("`@=VEN9&]W+F]N;&]A9"`](&9U;F-T:6]N*&4I"B`@("!["B`@
M("`@("`@;VQD7V]N;&]A9"AE*3L*("`@("`@("!T86)L95]I;FET*"D["B`@
M("!].PI](&5L<V4@>PH@("`@=VEN9&]W+F]N;&]A9"`]('1A8FQE7VEN:70[
M"GT*"G9A<B!33U)47T-/3%5-3E])3D1%6#L*"F9U;F-T:6]N('1A8FQE7VEN
M:70H*0I["B`@("!I9B`H(61O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE
M*2!["B`@("`@("`@<F5T=7)N.PH@("`@?0H@("`@=&%B;&5S(#T@9&]C=6UE
M;G0N9V5T16QE;65N='-">51A9TYA;64H)W1A8FQE)RD["B`@("!F;W(@*&D@
M/2`P.R!I(#P@=&%B;&5S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&AA
M<T-L87-S*'1A8FQE<UMI72P@)W-T<FEP960G*2D@>PH@("`@("`@("`@("!T
M86)L95]S=')I<&4H=&%B;&5S6VE=*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&AA<T-L87-S*'1A8FQE<UMI72P@)W-O<G1A8FQE)RD@)B8@=&%B;&5S6VE=
M+FED*2!["B`@("`@("`@("`@('1A8FQE7VUA:V53;W)T86)L92AT86)L97-;
M:5TI.PH@("`@("`@('T*("`@('T*?0H*9G5N8W1I;VX@=&%B;&5?<W1R:7!E
M*'1A8FQE*0I["B`@("`O+R!4:&4@9FQA9R!W92=L;"!U<V4@=&\@:V5E<"!T
M<F%C:R!O9B!W:&5T:&5R('1H92!C=7)R96YT(')O=R!I<PH@("`@+R\@;V1D
M(&]R(&5V96XN"B`@("!V87(@979E;B`](&9A;'-E.PH*("`@("\O(%1A8FQE
M<R!C86X@:&%V92!M;W)E('1H86X@;VYE('1B;V1Y(&5L96UE;G0[(&=E="!A
M;&P@8VAI;&0*("`@("\O('1B;V1Y('1A9W,@86YD(&EN=&5R871E('1H<F]U
M9V@@=&AE;2X*("`@('9A<B!T8F]D:65S(#T@=&%B;&4N8VAI;&1.;V1E<SL*
M("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@=&)O9&EE<RYL96YG=&@[(&,K*RD@
M>PH@("`@("`@(&EF("AT8F]D:65S6V-=+G1A9TYA;64@(3T@)U1"3T19)RD@
M>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@('9A
M<B!T<G,@/2!T8F]D:65S6V-=+F-H:6QD3F]D97,["B`@("`@("`@9F]R("AV
M87(@:2`](#`[(&D@/"!T<G,N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@
M:68@*'1R<UMI72YT86=.86UE(#T]("=44B<I('L*("`@("`@("`@("`@("`@
M(')E;6]V94-L87-S*'1R<UMI72P@)W)O=T5V96XG*3L*("`@("`@("`@("`@
M("`@(')E;6]V94-L87-S*'1R<UMI72P@)W)O=T]D9"<I.PH@("`@("`@("`@
M("`@("`@861D0VQA<W,H=')S6VE=+"!E=F5N(#\@)W)O=T5V96XG(#H@)W)O
M=T]D9"<I.PH*("`@("`@("`@("`@("`@("\O($9L:7`@9G)O;2!O9&0@=&\@
M979E;BP@;W(@=FEC92UV97)S82X*("`@("`@("`@("`@("`@(&5V96X@/2`A
M979E;CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*?0H*9G5N8W1I
M;VX@=&%B;&5?;6%K95-O<G1A8FQE*'1A8FQE*0I["B`@("!I9B`H=&%B;&4N
M<F]W<R`F)B!T86)L92YR;W=S+FQE;F=T:"`^(#`I('L*("`@("`@("!V87(@
M9FER<W12;W<@/2!T86)L92YR;W=S6S!=.PH@("`@?0H@("`@:68@*"%F:7)S
M=%)O=RD@>PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("`O+R!792!H879E
M(&$@9FER<W0@<F]W.B!A<W-U;64@:70G<R!T:&4@:&5A9&5R+"!A;F0@;6%K
M92!I=',*("`@("\O(&-O;G1E;G1S(&-L:6-K86)L92!L:6YK<RX*("`@(&9O
M<B`H=F%R(&D@/2`P.R!I(#P@9FER<W12;W<N8V5L;',N;&5N9W1H.R!I*RLI
M('L*("`@("`@("!V87(@8V5L;"`](&9I<G-T4F]W+F-E;&QS6VE=.PH@("`@
M("`@(&EF("AH87-#;&%S<RAC96QL+"`G;F]S;W)T)RDI('L*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("!C96QL+F-O;'5M;DEN
M9&5X(#T@:3L*("`@("`@("!C96QL+G-T>6QE+F-U<G-O<B`]("=P;VEN=&5R
M)SL*("`@("`@("!C96QL+F]N8VQI8VL@/2!F=6YC=&EO;BAE*0H@("`@("`@
M('L*("`@("`@("`@("`@=F%R(&4@/2!E('Q\('=I;F1O=RYE=F5N=#L*"B`@
M("`@("`@("`@(&EF("AE+G1A<F=E="D@>PH@("`@("`@("`@("`@("`@:68@
M*&4N=&%R9V5T+FYO9&54>7!E(#T](#,I('L*("`@("`@("`@("`@("`@("`@
M("!E+G1A<F=E="`](&4N=&%R9V5T+G!A<F5N=$YO9&4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!I9B`H92YS<F-%;&5M96YT*2![
M"B`@("`@("`@("`@("`@("!E+G1A<F=E="`](&4N<W)C16QE;65N=#L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@96P@/2!H87-087)E;G0H92YT87)G
M970L("=!)RP@)U1()RD["B`@("`@("`@("`@(&EF("AE;"`F)B`A:&%S0VQA
M<W,H96PL("=S;W)T;&EN:R<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@=&%B;&5?<F5S;W)T
M5&%B;&4H9V5T4&%R96YT*&4N=&%R9V5T+"`G5$@G*2D["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N('1A
M8FQE7V=E=$EN;F5R5&5X="AE;"D*>PH@("`@:68@*'1Y<&5O9B!E;"`]/2`G
M<W1R:6YG)RD@>PH@("`@("`@(')E='5R;B!E;#L*("`@('T*("`@(&EF("AT
M>7!E;V8@96P@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!R971U<FX@96P[
M"B`@("!]"B`@("!I9B`H96PN:6YN97)497AT*2!["B`@("`@("`@+R\@3F]T
M(&YE961E9"!B=70@:70@:7,@9F%S=&5R+@H@("`@("`@(')E='5R;B!E;"YI
M;FYE<E1E>'0["B`@("!]"@H@("`@=F%R('-T<B`]("(B.PH@("`@=F%R(&-S
M(#T@96PN8VAI;&1.;V1E<SL*("`@('9A<B!L(#T@8W,N;&5N9W1H.PH@("`@
M9F]R("AV87(@:2`](#`[(&D@/"!L.R!I*RLI('L*("`@("`@("!S=VET8V@@
M*&-S6VE=+FYO9&54>7!E*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@
M("`O+R!%3$5-14Y47TY/1$4*("`@("`@("`@("`@<W1R("L]('1A8FQE7V=E
M=$EN;F5R5&5X="AC<UMI72D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#,Z"B`@("`@("`@("`@("\O(%1%6%1?3D]$10H@("`@("`@("`@
M("!S='(@*ST@8W-;:5TN;F]D959A;'5E.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N('-T<CL*?0H*9G5N8W1I;VX@
M=&%B;&5?<F5S;W)T5&%B;&4H=&@I"GL*("`@('1A8FQE(#T@9V5T4&%R96YT
M*'1H+"`G5$%"3$4G*3L*("`@('-O<G1#;VQU;6X@/2!T:"YC;VQU;6Y);F1E
M>#L*("`@('-O<G1$;W=N(#T@,#L*"B`@("`O+R!,;V]P('1H<F]U9V@@/'1H
M96%D/B!T;R!F:6YD('1H92!C=7)R96YT('-O<G0@8V]L=6UN(&%N9`H@("`@
M+R\@9&ER96-T:6]N+@H@("`@=&AE861S(#T@=&%B;&4N=$AE860N9V5T16QE
M;65N='-">51A9TYA;64H)W1H)RD["B`@("!F;W(@*&D@/2`P.R!I(#P@=&AE
M861S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*'1H(#T]('1H96%D<UMI
M72D@>PH@("`@("`@("`@("!I9B`H:&%S0VQA<W,H=&AE861S6VE=+"`G<V]R
M='5P)RDI('L*("`@("`@("`@("`@("`@(')E;6]V94-L87-S*'1H96%D<UMI
M72P@)W-O<G1U<"<I.PH@("`@("`@("`@("`@("`@861D0VQA<W,H=&AE861S
M6VE=+"`G<V]R=&1O=VXG*3L*("`@("`@("`@("`@?2!E;'-E(&EF("AH87-#
M;&%S<RAT:&5A9'-;:5TL("=S;W)T9&]W;B<I*2!["B`@("`@("`@("`@("`@
M("!R96UO=F5#;&%S<RAT:&5A9'-;:5TL("=S;W)T9&]W;B<I.PH@("`@("`@
M("`@("`@("`@861D0VQA<W,H=&AE861S6VE=+"`G<V]R='5P)RD["B`@("`@
M("`@("`@("`@("!S;W)T1&]W;B`](#$["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!A9&1#;&%S<RAT:&5A9'-;:5TL("=S;W)T9&]W
M;B<I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5M;W9E0VQA<W,H=&AE861S6VE=+"`G<V]R='5P)RD["B`@("`@("`@
M("`@(')E;6]V94-L87-S*'1H96%D<UMI72P@)W-O<G1D;W=N)RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\O(%=O<FL@;W5T(&$@='EP92!F;W(@=&AE(&-O
M;'5M;@H@("`@:68@*'1A8FQE+G)O=W,N;&5N9W1H(#P](#$I('L*("`@("`@
M("!R971U<FX["B`@("!]"@H@("`@=F%R(&ET;2`]('1A8FQE7V=E=$EN;F5R
M5&5X="AT86)L92YR;W=S6S%=+F-E;&QS6W-O<G1#;VQU;6Y=*3L*("`@('-O
M<G1F;B`]('1A8FQE7W-O<G1?8V%S96EN<V5N<VET:79E.PH@("`@:68@*&ET
M;2YM871C:"@O7EQD7&1;7"\M75QD7&1;7"\M75QD7&1<9%QD)"\I*2!["B`@
M("`@("`@<V]R=&9N(#T@=&%B;&5?<V]R=%]D871E.PH@("`@?0H@("`@:68@
M*&ET;2YM871C:"@O7EQD7&1;7"\M75QD7&1;7"\M75QD7&0D+RDI('L*("`@
M("`@("!S;W)T9FX@/2!T86)L95]S;W)T7V1A=&4["B`@("!]"B`@("!I9B`H
M:71M+FUA=&-H*"]>6Z,D72\I*2!["B`@("`@("`@<V]R=&9N(#T@=&%B;&5?
M<V]R=%]C=7)R96YC>3L*("`@('T*("`@(&EF("AI=&TN;6%T8V@H+UY;7&1<
M+ETK)"\I*2!["B`@("`@("`@<V]R=&9N(#T@=&%B;&5?<V]R=%]N=6UE<FEC
M.PH@("`@?0H*("`@(%-/4E1?0T],54U.7TE.1$58(#T@<V]R=$-O;'5M;CL*
M"B`@("`O+R!$;VXG="!M:7@@=7`@<V5P97)A=&4@=&)O9&EE<SL@<V]R="!E
M86-H(&EN('1U<FXN"B`@("!F;W(@*&D@/2`P.R!I(#P@=&%B;&4N=$)O9&EE
M<RYL96YG=&@[(&DK*RD@>PH@("`@("`@('1R<R`]('1A8FQE+G1";V1I97-;
M:5TN9V5T16QE;65N='-">51A9TYA;64H)W1R)RD["B`@("`@("`@;F5W4F]W
M<R`](&YE=R!!<G)A>2@I.PH@("`@("`@(&9O<B`H:B`](#`[(&H@/"!T<G,N
M;&5N9W1H.R!J*RLI('L*("`@("`@("`@("`@;F5W4F]W<UMJ72`]('1R<UMJ
M73L*("`@("`@("!]"@H@("`@("`@(&YE=U)O=W,N<V]R="AS;W)T9FXI.PH@
M("`@("`@(&EF("AS;W)T1&]W;BD@>PH@("`@("`@("`@("!N97=2;W=S+G)E
M=F5R<V4H*3L*("`@("`@("!]"@H@("`@("`@("\O(%=E(&%P<&5N9$-H:6QD
M(')O=W,@=&AA="!A;')E861Y(&5X:7-T('1O('1H92!T8F]D>2P@<V\@:70*
M("`@("`@("`O+R!M;W9E<R!T:&5M(')A=&AE<B!T:&%N(&-R96%T:6YG(&YE
M=R!O;F5S+B!$;VXG="!D;PH@("`@("`@("\O('-O<G1B;W1T;VT@<F]W<RX*
M("`@("`@("!F;W(@*&H@/2`P.R!J(#P@;F5W4F]W<RYL96YG=&@[(&HK*RD@
M>PH@("`@("`@("`@("!I9B`H(6AA<T-L87-S*&YE=U)O=W-;:ETL("=S;W)T
M8F]T=&]M)RDI('L*("`@("`@("`@("`@("`@('1A8FQE+G1";V1I97-;:5TN
M87!P96YD0VAI;&0H;F5W4F]W<UMJ72D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O($1O('-O<G1B;W1T;VT@<F]W<R!O;FQY+@H@("`@
M("`@(&9O<B`H:B`](#`[(&H@/"!N97=2;W=S+FQE;F=T:#L@:BLK*2!["B`@
M("`@("`@("`@(&EF("AH87-#;&%S<RAN97=2;W=S6VI=+"`G<V]R=&)O='1O
M;2<I*2!["B`@("`@("`@("`@("`@("!T86)L92YT0F]D:65S6VE=+F%P<&5N
M9$-H:6QD*&YE=U)O=W-;:ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\O($EF('=E(&IU<W0@<F5S;W)T960@82!S=')I<&5D('1A
M8FQE+"!R92US=')I<&4@:70N"B`@("!I9B`H:&%S0VQA<W,H=&%B;&4L("=S
M=')I<&5D)RDI('L*("`@("`@("!T86)L95]S=')I<&4H=&%B;&4I.PH@("`@
M?0H*("`@("\O($9I;F%L;'DL('-E92!I9B!W92!H879E(&$@8V%L;&)A8VL@
M9G5N8W1I;VX@=&\@=')I9V=E<BX*("`@(&EF("AT>7!E;V8H=&%B;&5?<V]R
M=$-A;&QB86-K*2`]/2`G9G5N8W1I;VXG*2!["B`@("`@("`@=&%B;&5?<V]R
M=$-A;&QB86-K*'1A8FQE+FED+"!T:"YI9"P@<V]R=$1O=VXI.PH@("`@?0I]
M"@IF=6YC=&EO;B!G971087)E;G0H96PL('!486=.86UE*0I["B`@("!I9B`H
M96P@/3T@;G5L;"D@>PH@("`@("`@(')E='5R;B!N=6QL.PH@("`@?2!E;'-E
M(&EF("AP5&%G3F%M92`]/2!N=6QL*2!["B`@("`@("`@<F5T=7)N(&5L+G!A
M<F5N=$YO9&4["B`@("!](&5L<V4@:68@*&5L+FYO9&54>7!E(#T](#$@)B8@
M96PN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T]('!486=.86UE+G1O3&]W97)#
M87-E*"DI('L*("`@("`@("`O+R!'96-K;R!B=6<L('-U<'!O<V5D('1O(&)E
M('5P<&5R8V%S92X*("`@("`@("!R971U<FX@96P["B`@("!](&5L<V4@>PH@
M("`@("`@(')E='5R;B!G971087)E;G0H96PN<&%R96YT3F]D92P@<%1A9TYA
M;64I.PH@("`@?0I]"@IF=6YC=&EO;B!T86)L95]S;W)T7V1A=&4H82P@8BD*
M>PH@("`@+R\@5'=O(&1I9VET('EE87)S(&QE<W,@=&AA;B`U,"!A<F4@=')E
M871E9"!A<R`R,%A8+"!G<F5A=&5R('1H86X*("`@("\O(#4P(&%R92!T<F5A
M=&5D(&%S(#$Y6%@N"B`@("!A82`]('1A8FQE7V=E=$EN;F5R5&5X="AA+F-E
M;&QS6U-/4E1?0T],54U.7TE.1$5872D["B`@("!B8B`]('1A8FQE7V=E=$EN
M;F5R5&5X="AB+F-E;&QS6U-/4E1?0T],54U.7TE.1$5872D["B`@("!I9B`H
M86$N;&5N9W1H(#T](#$P*2!["B`@("`@("`@9'0Q(#T@86$N<W5B<W1R*#8L
M(#0I("L@86$N<W5B<W1R*#,L(#(I("L@86$N<W5B<W1R*#`L(#(I.PH@("`@
M?2!E;'-E('L*("`@("`@("!Y<B`](&%A+G-U8G-T<B@V+"`R*3L*("`@("`@
M("!I9B`H<&%R<V5);G0H>7(I(#P@-3`I('L*("`@("`@("`@("`@>7(@/2`G
M,C`G("L@>7(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@>7(@/2`G
M,3DG("L@>7(["B`@("`@("`@?0H@("`@("`@(&1T,2`]('ER*V%A+G-U8G-T
M<B@S+"`R*2`K(&%A+G-U8G-T<B@P+"`R*3L*("`@('T*("`@(&EF("AB8BYL
M96YG=&@@/3T@,3`I('L*("`@("`@("!D=#(@/2!B8BYS=6)S='(H-BP@-"D@
M*R!B8BYS=6)S='(H,RP@,BD@*R!B8BYS=6)S='(H,"P@,BD["B`@("!](&5L
M<V4@>PH@("`@("`@('ER(#T@8F(N<W5B<W1R*#8L(#(I.PH@("`@("`@(&EF
M("AP87)S94EN="AY<BD@/"`U,"D@>PH@("`@("`@("`@("!Y<B`]("<R,"<@
M*R!Y<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!Y<B`]("<Q.2<@
M*R!Y<CL*("`@("`@("!]"B`@("`@("`@9'0R(#T@>7(@*R!B8BYS=6)S='(H
M,RP@,BD@*R!B8BYS=6)S='(H,"P@,BD["B`@("!]"B`@("!I9B`H9'0Q(#T]
M(&1T,BD@>PH@("`@("`@(')E='5R;B`P.PH@("`@?2!E;'-E(&EF("AD=#$@
M/"!D=#(I('L*("`@("`@("!R971U<FX@+3$["B`@("!]"B`@("!R971U<FX@
M,3L*?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]C=7)R96YC>2AA+"!B*0I["B`@
M("!A82`]('1A8FQE7V=E=$EN;F5R5&5X="AA+F-E;&QS6U-/4E1?0T],54U.
M7TE.1$5872DN<F5P;&%C92@O6UXP+3DN72]G+"`G)RD["B`@("!B8B`]('1A
M8FQE7V=E=$EN;F5R5&5X="AB+F-E;&QS6U-/4E1?0T],54U.7TE.1$5872DN
M<F5P;&%C92@O6UXP+3DN72]G+"`G)RD["B`@("!R971U<FX@<&%R<V5&;&]A
M="AA82D@+2!P87)S949L;V%T*&)B*3L*?0H*9G5N8W1I;VX@=&%B;&5?<V]R
M=%]N=6UE<FEC*&$L(&(I"GL*("`@(&%A(#T@<&%R<V5&;&]A="AT86)L95]G
M971);FYE<E1E>'0H82YC96QL<UM33U)47T-/3%5-3E])3D1%6%TI*3L*("`@
M(&EF("AI<TYA3BAA82DI('L*("`@("`@("!A82`](#`["B`@("!]"B`@("!B
M8B`]('!A<G-E1FQO870H=&%B;&5?9V5T26YN97)497AT*&(N8V5L;'-;4T]2
M5%]#3TQ534Y?24Y$15A=*2D["B`@("!I9B`H:7-.84XH8F(I*2!["B`@("`@
M("`@8F(@/2`P.PH@("`@?0H@("`@<F5T=7)N(&%A("T@8F(["GT*"F9U;F-T
M:6]N('1A8FQE7W-O<G1?8V%S96EN<V5N<VET:79E*&$L(&(I"GL*("`@(&%A
M(#T@=&%B;&5?9V5T26YN97)497AT*&$N8V5L;'-;4T]25%]#3TQ534Y?24Y$
M15A=*2YT;TQO=V5R0V%S92@I.PH@("`@8F(@/2!T86)L95]G971);FYE<E1E
M>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%6%TI+G1O3&]W97)#87-E*"D[
M"B`@("!I9B`H86$@/3T@8F(I('L*("`@("`@("!R971U<FX@,#L*("`@('T@
M96QS92!I9B`H86$@/"!B8BD@>PH@("`@("`@(')E='5R;B`M,3L*("`@('T*
M("`@(')E='5R;B`Q.PI]"@IF=6YC=&EO;B!T86)L95]S;W)T7V1E9F%U;'0H
M82QB*0I["B`@("!A82`]('1A8FQE7V=E=$EN;F5R5&5X="AA+F-E;&QS6U-/
M4E1?0T],54U.7TE.1$5872D["B`@("!B8B`]('1A8FQE7V=E=$EN;F5R5&5X
M="AB+F-E;&QS6U-/4E1?0T],54U.7TE.1$5872D["B`@("!I9B`H86$@/3T@
M8F(I('L*("`@("`@("!R971U<FX@,#L*("`@('T@96QS92!I9B`H86$@/"!B
M8BD@>PH@("`@("`@(')E='5R;B`M,3L*("`@('T*("`@(')E='5R;B`Q.PI]
M"@HO*BH*("H@1$]-('5T:6QI='D@9G5N8W1I;VYS+@H@*B\*9G5N8W1I;VX@
M:&%S4&%R96YT*&5L+"!T86=.86UE+"!T86=3=&]P*0I["B`@("!I9B`H96PN
M=&%G3F%M92`]/2!T86=.86UE*2!["B`@("`@("`@<F5T=7)N(&5L.PH@("`@
M?2!E;'-E(&EF("AT86=3=&]P("$](&YU;&P@)B8@96PN=&%G3F%M92`]/2!T
M86=3=&]P*2!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E('L*
M("`@("`@("!R971U<FX@:&%S4&%R96YT*&=E=%!A<F5N="AE;"DL('1A9TYA
M;64L('1A9U-T;W`I.PH@("`@?0I]"@IF=6YC=&EO;B!A9&1#;&%S<RAE;"P@
M8VQA<W-.86UE*0I["B`@("!E;"YC;&%S<TYA;64@*ST@96PN8VQA<W-.86UE
M(#\@)R`G("L@8VQA<W-.86UE(#H@8VQA<W-.86UE.PI]"@IF=6YC=&EO;B!R
M96UO=F5#;&%S<RAE;"P@8VQA<W-.86UE*0I["B`@("!E;"YC;&%S<TYA;64@
M/2!E;"YC;&%S<TYA;64N<F5P;&%C92AN97<@4F5G17AP*"<@/R<@*R!C;&%S
M<TYA;64@*R`G(#\G*2P@)R<I.PI]"@IF=6YC=&EO;B!H87-#;&%S<RAE;"P@
M8VQA<W-.86UE*0I["B`@("!R971U<FX@*&5L+F-L87-S3F%M92YI;F1E>$]F
M*&-L87-S3F%M92D@(3T@+3$I.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:G,O<W1R:7!E+FIS````````````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#$P,0`Q,#4Q-30S
M,3`V,``P,38V-C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J($IA=F%S8W)I<'0@8V]D92!F;W(@9FEN9&EN9R!A
M;&P@=&%B;&5S('=I=&@@8VQA<W-N86UE(")S=')I<&5D(B!A;F0*("H@9'EN
M86UI8V%L;'D@<W1R:7!I;F<@=&AE:7(@<F]W(&-O;&]R<RX*("H*("H@)$AO
M<F1E.B!H;W)D92]J<R]S=')I<&4N:G,L=B`Q+C,N,BXR(#(P,#4O,3`O,3@@
M,3$Z,S,Z,S@@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J(%=E(&1O
M(&5V97)Y=&AI;F<@;VYL;V%D('-O('1H870@=&AE(&5N=&ER92!D;V-U;65N
M="!I<R!P<F5S96YT"B`J(&)E9F]R92!W92!S=&%R="!S96%R8VAI;F<@:70@
M9F]R('1A8FQE<RX@*B\*:68@*'=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R*2![
M"B`@("!W:6YD;W<N861D179E;G1,:7-T96YE<B@G;&]A9"<L(&9I;F13=')I
M<&5D5&%B;&5S+"!F86QS92D["GT@96QS92!I9B`H=VEN9&]W+F%T=&%C:$5V
M96YT*2!["B`@("!W:6YD;W<N871T86-H179E;G0H)V]N;&]A9"<L(&9I;F13
M=')I<&5D5&%B;&5S*3L*?2!E;'-E(&EF("AW:6YD;W<N;VYL;V%D("$](&YU
M;&PI('L*("`@('9A<B!O;&1/;DQO860@/2!W:6YD;W<N;VYL;V%D.PH@("`@
M=VEN9&]W+F]N;&]A9"`](&9U;F-T:6]N*&4I"B`@("!["B`@("`@("`@;VQD
M3VY,;V%D*&4I.PH@("`@("`@(&9I;F13=')I<&5D5&%B;&5S*"D["B`@("!]
M.PI](&5L<V4@>PH@("`@=VEN9&]W+F]N;&]A9"`](&9I;F13=')I<&5D5&%B
M;&5S.PI]"@IF=6YC=&EO;B!F:6YD4W1R:7!E9%1A8FQE<R@I"GL*("`@(&EF
M("@A9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64I('L*("`@("`@("!R
M971U<FX["B`@("!]"B`@("!T86)L97,@/2!D;V-U;65N="YG971%;&5M96YT
M<T)Y5&%G3F%M92@G=&%B;&4G*3L*("`@(&9O<B`H:2`](#`[(&D@/"!T86)L
M97,N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H=&%B;&5S6VE=+F-L87-S
M3F%M92YI;F1E>$]F*"=S=')I<&5D)RD@(3T@+3$I('L*("`@("`@("`@("`@
M<W1R:7!E*'1A8FQE<UMI72D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO
M;B!S=')I<&4H=&%B;&4I"GL*("`@("\O(%1H92!F;&%G('=E)VQL('5S92!T
M;R!K965P('1R86-K(&]F('=H971H97(@=&AE(&-U<G)E;G0@<F]W(&ES"B`@
M("`O+R!O9&0@;W(@979E;BX*("`@('9A<B!E=F5N(#T@9F%L<V4["@H@("`@
M+R\@5&%B;&5S(&-A;B!H879E(&UO<F4@=&AA;B!O;F4@=&)O9'D@96QE;65N
M=#L@9V5T(&%L;"!C:&EL9`H@("`@+R\@=&)O9'D@=&%G<R!A;F0@:6YT97)A
M=&4@=&AR;W5G:"!T:&5M+@H@("`@=F%R('1B;V1I97,@/2!T86)L92YC:&EL
M9$YO9&5S.PH@("`@9F]R("AV87(@8R`](#`[(&,@/"!T8F]D:65S+FQE;F=T
M:#L@8RLK*2!["B`@("`@("`@:68@*'1B;V1I97-;8UTN=&%G3F%M92`]/2`G
M5$)/1%DG*2!["B`@("`@("`@("`@('9A<B!T<G,@/2!T8F]D:65S6V-=+F-H
M:6QD3F]D97,["B`@("`@("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@=')S
M+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H=')S6VE=+G1A
M9TYA;64@/3T@)U12)RD@>PH@("`@("`@("`@("`@("`@("`@('1R<UMI72YC
M;&%S<TYA;64@/2!T<G-;:5TN8VQA<W-.86UE+G)E<&QA8V4H+R`_<F]W179E
M;B`_+RP@)R<I+G)E<&QA8V4H+R`_<F]W3V1D(#\O+"`G)RD["B`@("`@("`@
M("`@("`@("`@("`@:68@*'1R<UMI72YC;&%S<TYA;64I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@=')S6VE=+F-L87-S3F%M92`K/2`G("<["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('1R<UMI72YC
M;&%S<TYA;64@*ST@979E;B`_("=R;W=%=F5N)R`Z("=R;W=/9&0G.PH*("`@
M("`@("`@("`@("`@("`@("`O+R!&;&EP(&9R;VT@;V1D('1O(&5V96XL(&]R
M('9I8V4M=F5R<V$N"B`@("`@("`@("`@("`@("`@("`@979E;B`]("%E=F5N
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O:&]R9&4N:64N:G,`
M````````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3(Q,``Q,#4Q-30S,3`V,``P,3<P-#4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+RHJ"B`J($=E;F5R86P@2&]R9&4@54D@
M969F96-T<R!J879A<V-R:7!T("T@9FEX97,@9F]R($E%('1H870@8V%N)W0*
M("H@96%S:6QY(&)E(&1O;F4@=VET:&]U="!B<F]W<V5R(&1E=&5C=&EO;BX*
M("H*("H@)$AO<F1E.B!H;W)D92]J<R]H;W)D92YI92YJ<RQV(#$N,2XR+C(@
M,C`P-B\P,2\R.2`Q,#HQ.#HR,"!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@I4;V]L5&EP<U]/<'1I;VY?5VEN9&]W961?0V]N=')O;',@/2`Q.PH*
M:68@*'1Y<&5O9B!!<G)A>2YP<F]T;W1Y<&4N<'5S:"`]/2`G=6YD969I;F5D
M)RD@>PH@("`@($%R<F%Y+G!R;W1O='EP92YP=7-H(#T@9G5N8W1I;VXH*2![
M"B`@("`@("`@('9A<B!L(#T@=&AI<RYL96YG=&@["B`@("`@("`@(&9O<B`H
M=F%R(&D@/2`P.R!I(#P@87)G=6UE;G1S+FQE;F=T:#L@:2LK*2!["B`@("`@
M("`@("`@("!T:&ES6VP@*R!I72`](&%R9W5M96YT<UMI73L*("`@("`@("`@
M?0H@("`@("`@("!R971U<FX@=&AI<RYL96YG=&@*("`@("!]"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O<V]R=&5R
M+FIS````````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-C4S-@`Q,#4Q-30S,3`V,``P,38W,#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J($AO<F1E($9O<FT@
M4V]R=&5R($9I96QD($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O=FED97,@
M=&AE(&IA=F%S8W)I<'0@8VQA<W,@=&\@86-C;VUP86YY('1H92!(;W)D95]&
M;W)M('-O<G1E<@H@*B!F:65L9"X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]S
M;W)T97(N:G,L=B`Q+C(N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\
M;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!(
M;W)D95]&;W)M7U-O<G1E<BAI;G-T86YC94YA;64L('9A<DYA;64L(&AE861E
M<BD*>PH@("`@+RH@4V5T('5P('1H:7,@8VQA<W,@:6YS=&%N8V4@9F]R(&9U
M;F-T:6]N(&-A;&QS(&9R;VT@=&AE('!A9V4N("HO"B`@("!T:&ES+E]I;G-T
M86YC94YA;64@/2!I;G-T86YC94YA;64["@H@("`@=&AI<RY?=F%R3F%M92`]
M('9A<DYA;64["@H@("`@+RH@4V]R=&5R('9A<FEA8FQE<RX@*B\*("`@('1H
M:7,N7VAE861E<B`]("<G.PH@("`@=&AI<RYM:6Y,96YG=&@@/2`P.PH@("`@
M:68@*&AE861E<B`A/2`G)RD@>PH@("`@("`@('1H:7,N7VAE861E<B`](&AE
M861E<CL*("`@("`@("!T:&ES+FUI;DQE;F=T:"`](#$["B`@("!]"B`@("!T
M:&ES+G-O<G1E<DQI<W0@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AT:&ES
M+E]V87).86UE("L@)UML:7-T72<I.PH@("`@=&AI<RYS;W)T97)!<G)A>2`]
M(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1H:7,N7W9A<DYA;64@*R`G6V%R
M<F%Y72<I.PH*("`@('1H:7,N9&5S96QE8W1(96%D97(@/2!F=6YC=&EO;B@I
M"B`@("!["B`@("`@("`@:68@*'1H:7,N7VAE861E<B`A/2`G)RD@>PH@("`@
M("`@("`@("!T:&ES+G-O<G1E<DQI<W1;,%TN<V5L96-T960@/2!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@=&AI<RYS971(:61D96X@/2!F=6YC=&EO
M;B@I"B`@("!["B`@("`@("`@=F%R('1M<$%R<F%Y(#T@;F5W($%R<F%Y*"D[
M"@H@("`@("`@(&9O<B`H=F%R(&D@/2!T:&ES+FUI;DQE;F=T:#L@:2`\('1H
M:7,N<V]R=&5R3&ES="YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!I9B`H
M=&AI<RYS;W)T97),:7-T6VE=+G9A;'5E*2!["B`@("`@("`@("`@("`@("!T
M;7!!<G)A>5MI("T@=&AI<RYM:6Y,96YG=&A=(#T@=&AI<RYS;W)T97),:7-T
M6VE=+G9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!T
M:&ES+G-O<G1E<D%R<F%Y+G9A;'5E(#T@=&UP07)R87DN:F]I;B@B7'0B*3L*
M("`@('T*"B`@("!T:&ES+FUO=F5#;VQU;6Y5<"`](&9U;F-T:6]N*"D*("`@
M('L*("`@("`@("!V87(@<V5L(#T@=&AI<RYS;W)T97),:7-T+G-E;&5C=&5D
M26YD97@["@H@("`@("`@(&EF("AS96P@/#T@=&AI<RYM:6Y,96YG=&@@?'P@
M=&AI<RYS;W)T97),:7-T+FQE;F=T:"`\/2!T:&ES+FUI;DQE;F=T:"`K(#$I
M(')E='5R;CL*"B`@("`@("`@+RH@1&5S96QE8W0@979E<GET:&EN9R!B=70@
M=&AE(&9I<G-T('-E;&5C=&5D(&ET96TN("HO"B`@("`@("`@=&AI<RYS;W)T
M97),:7-T+G-E;&5C=&5D26YD97@@/2!S96P["B`@("`@("`@=F%R('5P(#T@
M=&AI<RYS;W)T97),:7-T6W-E;%TN=F%L=64["@H@("`@("`@('1M<"`](&YE
M=R!!<G)A>2@I.PH@("`@("`@(&9O<B`H:2`]('1H:7,N;6EN3&5N9W1H.R!I
M(#P@=&AI<RYS;W)T97),:7-T+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@
M('1M<%MI("T@=&AI<RYM:6Y,96YG=&A=(#T@;F5W($]P=&EO;BAT:&ES+G-O
M<G1E<DQI<W1;:5TN=&5X="P@=&AI<RYS;W)T97),:7-T6VE=+G9A;'5E*0H@
M("`@("`@('T*"B`@("`@("`@9F]R("AI(#T@,#L@:2`\('1M<"YL96YG=&@[
M(&DK*RD@>PH@("`@("`@("`@("!I9B`H:2`K('1H:7,N;6EN3&5N9W1H(#T]
M('-E;"`M(#$I('L*("`@("`@("`@("`@("`@('1H:7,N<V]R=&5R3&ES=%MI
M("L@=&AI<RYM:6Y,96YG=&A=(#T@=&UP6VD@*R`Q73L*("`@("`@("`@("`@
M?2!E;'-E(&EF("AI("L@=&AI<RYM:6Y,96YG=&@@/3T@<V5L*2!["B`@("`@
M("`@("`@("`@("!T:&ES+G-O<G1E<DQI<W1;:2`K('1H:7,N;6EN3&5N9W1H
M72`]('1M<%MI("T@,5T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!T:&ES+G-O<G1E<DQI<W1;:2`K('1H:7,N;6EN3&5N9W1H72`]
M('1M<%MI73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=&AI
M<RYS;W)T97),:7-T+G-E;&5C=&5D26YD97@@/2!S96P@+2`Q.PH*("`@("`@
M("!T:&ES+G-E=$AI9&1E;B@I.PH@("`@?0H*("`@('1H:7,N;6]V94-O;'5M
M;D1O=VX@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@=F%R('-E;"`]('1H
M:7,N<V]R=&5R3&ES="YS96QE8W1E9$EN9&5X.PH*("`@("`@("!I9B`H<V5L
M(#T]("TQ('Q\('-E;"`]/2!T:&ES+G-O<G1E<DQI<W0N;&5N9W1H("T@,2D@
M<F5T=7)N.PH*("`@("`@("`O*B!$97-E;&5C="!E=F5R>71H:6YG(&)U="!T
M:&4@9FER<W0@<V5L96-T960@:71E;2X@*B\*("`@("`@("!T:&ES+G-O<G1E
M<DQI<W0N<V5L96-T961);F1E>"`]('-E;#L*("`@("`@("!V87(@9&]W;B`]
M('1H:7,N<V]R=&5R3&ES=%MS96Q=+G9A;'5E.PH*("`@("`@("!T;7`@/2!N
M97<@07)R87DH*3L*("`@("`@("!F;W(@*&D@/2!T:&ES+FUI;DQE;F=T:#L@
M:2`\('1H:7,N<V]R=&5R3&ES="YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@
M("!T;7!;:2`M('1H:7,N;6EN3&5N9W1H72`](&YE=R!/<'1I;VXH=&AI<RYS
M;W)T97),:7-T6VE=+G1E>'0L('1H:7,N<V]R=&5R3&ES=%MI72YV86QU92D*
M("`@("`@("!]"@H@("`@("`@(&9O<B`H:2`](#`[(&D@/"!T;7`N;&5N9W1H
M.R!I*RLI('L*("`@("`@("`@("`@:68@*&D@*R!T:&ES+FUI;DQE;F=T:"`]
M/2!S96PI('L*("`@("`@("`@("`@("`@('1H:7,N<V]R=&5R3&ES=%MI("L@
M=&AI<RYM:6Y,96YG=&A=(#T@=&UP6VD@*R`Q73L*("`@("`@("`@("`@?2!E
M;'-E(&EF("AI("L@=&AI<RYM:6Y,96YG=&@@/3T@<V5L("L@,2D@>PH@("`@
M("`@("`@("`@("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T
M:%T@/2!T;7!;:2`M(#%=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T:%T@
M/2!T;7!;:5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('1H
M:7,N<V]R=&5R3&ES="YS96QE8W1E9$EN9&5X(#T@<V5L("L@,3L*"B`@("`@
M("`@=&AI<RYS971(:61D96XH*3L*("`@('T*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+V9O<FU?
M:&5L<&5R<RYJ<P``````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3$U-30`,3`U,34T,S$P-C``,#(P,#4Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B!*879A<V-R:7!T
M('1O(&%D9"!E=F5N=',@=&\@9F]R;2!E;&5M96YT<PH@*@H@*B`D2&]R9&4Z
M(&AO<F1E+VIS+V9O<FU?:&5L<&5R<RYJ<RQV(#$N,RXT+C8@,C`P-B\P,R\R
M-"`P-3HQ-SHU.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($UA='0@2WEN87-T;VX@/&UA='1`:WEN>"YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"B\J*@H@*B!!9&1S('1H92!G:79E;B!E=F5N="!T;R!A;B!E;&5M
M96YT+B!)9B!T:&4@96QE;65N="!A;')E861Y(&AA<PH@*B!S8W)I<'0@9F]R
M('1H92!E=F5N="P@=&AE(&YE=R!E=F5N="!I<R!A<'!E;F1E9"X*("H*("H@
M0'!A<F%M(&]B:F5C="!E;&5M96YT("`@5&AE(&5L96UE;G0@=&\@861D('1H
M92!E=F5N="!T;RX*("H@0'!A<F%M('-T<FEN9R!E=F5N="`@("`@5&AE(&YA
M;64@;V8@=&AE(&5V96YT+@H@*B!`<&%R86T@<W1R:6YG?&9U;F-T:6]N(&9U
M;F-T:6]N("!4:&4@:F%V87-C<FEP="!T;R!E>&5C=71E+@H@*B\*9G5N8W1I
M;VX@861D179E;G0H96QE;65N="P@979E;G0L(&-O9&4I"GL*("`@(&EF("@A
M96QE;65N="D@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M+R!!<W-I9VX@;F5W(&%N;VYY;6]U<R!F=6YC=&EO;B!I9B!W92=R92!P87-S
M960@82!J<R!S=')I;F<*("`@("\O(&EN<W1E860@;V8@82!F=6YC=&EO;B!R
M969E<F5N8V4N"B`@("!I9B`H='EP96]F(&-O9&4@/3T@)W-T<FEN9R<I('L*
M("`@("`@("!C;V1E(#T@;F5W($9U;F-T:6]N*&-O9&4I.PH@("`@?0H*("`@
M(&EF("AE;&5M96YT+F%D9$5V96YT3&ES=&5N97(I('L*("`@("`@("!E;&5M
M96YT+F%D9$5V96YT3&ES=&5N97(H979E;G0N<F5P;&%C92@O;VXO+"`G)RDL
M(&-O9&4L(&9A;'-E*3L*("`@('T@96QS92!I9B`H96QE;65N="YA='1A8VA%
M=F5N="D@>PH@("`@("`@(&5L96UE;G0N871T86-H179E;G0H979E;G0L(&-O
M9&4I.PH@("`@?2!E;'-E(&EF("AE;&5M96YT+F]N;&]A9"`A/2!N=6QL*2![
M"B`@("`@("`@=F%R($]L9$5V96YT(#T@96QE;65N=%ME=F5N=%T["B`@("`@
M("`@;F5W0V]D92`]($9U;F-T:6]N*&4I"B`@("`@("`@>PH@("`@("`@("`@
M("!O;&1%=F5N="AE*3L*("`@("`@("`@("`@8V]D92@I.PH@("`@("`@('T[
M"B`@("`@("`@96QE;65N=%ME=F5N=%T@/2!N97=#;V1E.PH@("`@?2!E;'-E
M('L*("`@("`@("!E;&5M96YT6V5V96YT72`](&-O9&4["B`@("!]"@H@("`@
M<F5T=7)N('1R=64["GT*"B\J*@H@*B!2971U<FYS(&=I=F5N('9A;'5E(&%S
M(&$@;G5M8F5R+"!O<B!Z97)O(&EF($YA3BX*("H*("H@0'!A<F%M(&UI>&5D
M("!V86P*("H*("H@0')E='5R;B!N=6UB97(*("HO"F9U;F-T:6]N('1O3G5M
M8F5R*'9A;"D*>PH@("`@:68@*&ES3F%.*'9A;"DI('L*("`@("`@("!R971U
M<FX@,#L*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N($YU;6)E<BAV86PI
M.PH@("`@?0I]"@HO*BH*("H@4V5T<R!T:&4@96YA8FQE9"!S=&%T92!O9B!O
M;F4@96QE;65N="!B87-E9"!O;B!T:&4@=F%L=65S(&]F(&%N;W1H97(N"B`J
M"B`J(%1A:V5S(&9O=7(@;W(@;6]R92!A<F=U;65N=',L(&EN('1H92!F;W)M
M.@H@*B`@(&-H96-K16YA8FQE9"AS;W5R8V4L('1A<F=E="P@=')U92P@=F%L
M=64Q+"!V86QU93(L('9A;'5E,RXN+BD*("H*("H@0'!A<F%M(&]B:F5C="`@
M(%1H92!E;&5M96YT('1O(&-H96-K"B`J($!P87)A;2!S=')I;F<@("!4:&4@
M96QE;65N="!T;R!E;F%B;&4O9&ES86)L90H@*B!`<&%R86T@8F]O;&5A;B`@
M5VAE=&AE<B!T;R!E;F%B;&4@;W(@9&ES86)L92!T:&4@=&%R9V5T"B`J($!P
M87)A;2!M:7AE9"`@("!4:&4@=F%L=64@=&\@8VAE8VL@86=A:6YS=`H@*B\*
M9G5N8W1I;VX@8VAE8VM%;F%B;&5D*"D*>PH@("`@:68@*&%R9W5M96YT<RYL
M96YG=&@@/B`R*2!["B`@("`@("`@;V)J4W)C(#T@87)G=6UE;G1S6S!=.PH@
M("`@("`@(&]B:E1A<F=E="`](&]B:E-R8RYF;W)M+F5L96UE;G1S6V%R9W5M
M96YT<ULQ75T["B`@("`@("`@96YA8FQE9"`](&%R9W5M96YT<ULR73L*("`@
M("`@("!T;V=G;&4@/2!F86QS93L*("`@("`@("!I9B`H;V)J5&%R9V5T*2![
M"B`@("`@("`@("`@('-W:71C:"`H;V)J4W)C+G1Y<&4N=&],;W=E<D-A<V4H
M*2D@>PH@("`@("`@("`@("!C87-E("=S96QE8W0M;VYE)R`Z"B`@("`@("`@
M("`@("`@("!V86P@/2!O8FI3<F,N;W!T:6]N<UMO8FI3<F,N<V5L96-T961)
M;F1E>%TN=F%L=64["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)W-E;&5C="UM=6QT:7!L92<@.@H@("`@("`@("`@("`@("`@
M=F%L(#T@;F5W($%R<F%Y*"D["B`@("`@("`@("`@("`@("!C;W5N="`](#`[
M"B`@("`@("`@("`@("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&]B:E-R8RYL
M96YG=&@[("LK:2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AO8FI3<F,N
M;W!T:6]N<UMI72YS96QE8W1E9"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!V86Q;8V]U;G1=(#T@;V)J4W)C+F]P=&EO;G-;:5TN=F%L=64["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=C:&5C:V)O>"<@.@H@
M("`@("`@("`@("`@("`@:68@*&]B:E-R8RYC:&5C:V5D*2!["B`@("`@("`@
M("`@("`@("`@("`@=F%L(#T@;V)J4W)C+G9A;'5E.PH@("`@("`@("`@("`@
M("`@("`@('1O9V=L92`]('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0@.@H@("`@
M("`@("`@("`@("`@=F%L(#T@;V)J4W)C+G9A;'5E.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!F;W(@*'9A<B!I(#T@,SL@:2`\(&%R9W5M96YT<RYL
M96YG=&@[("LK:2D@>PH@("`@("`@("`@("`@("`@:68@*'1Y<&5O9BAV86PI
M(#T]("=O8FIE8W0G("8F("AA<F=U;65N='-;:5T@:6X@=F%L*2D@>PH@("`@
M("`@("`@("`@("`@("`@('1O9V=L92`]('1R=64["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!](&5L<V4@:68@*&%R9W5M
M96YT<UMI72`]/2!V86PI('L*("`@("`@("`@("`@("`@("`@("!T;V=G;&4@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!O8FI487)G970N
M9&ES86)L960@/2!T;V=G;&4@/R`A96YA8FQE9"`Z(&5N86)L960["B`@("`@
M("`@("`@(&EF("@A;V)J5&%R9V5T+F1I<V%B;&5D*2!["B`@("`@("`@("`@
M("`@("!O8FI487)G970N9F]C=7,H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*?0H*+RHJ"B`J(%-E=',@=&AE('1A<F=E="!F:65L9"!T;R!T
M:&4@<W5M(&]F(&$@<F%N9V4@;V8@9FEE;&1S+@H@*@H@*B!486ME<R!T:')E
M92!O<B!M;W)E(&%R9W5M96YT<RP@:6X@=&AE(&9O<FTZ"B`J("`@('-U;49I
M96QD<RAF;W)M+"!T87)G970L(&9I96QD,2P@9FEE;&0R+"!F:65L9#,N+BXI
M"B`J"B`J($!P87)A;2!O8FIE8W0@(%1H92!F;W)M('1O(&-H96-K"B`J($!P
M87)A;2!S=')I;F<@(%1H92!N86UE(&]F('1H92!T87)G970@96QE;65N=`H@
M*B!`<&%R86T@<W1R:6YG("!/;F4@;W(@;6]R92!F:65L9"!N86UE<R!T;R!S
M=6T*("HO"F9U;F-T:6]N('-U;49I96QD<R@I"GL*("`@(&EF("AA<F=U;65N
M=',N;&5N9W1H(#X@,BD@>PH@("`@("`@(&]B:D9R;2`](&%R9W5M96YT<ULP
M73L*("`@("`@("!O8FI487)G970@/2!O8FI&<FTN96QE;65N='-;87)G=6UE
M;G1S6S%=73L*("`@("`@("!S=6T@/2`P.PH@("`@("`@(&EF("AO8FI487)G
M970I('L*("`@("`@("`@("`@9F]R("AV87(@:2`](#([(&D@/"!A<F=U;65N
M=',N;&5N9W1H.R`K*VDI('L*("`@("`@("`@("`@("`@(&]B:E-R8R`](&]B
M:D9R;2YE;&5M96YT<UMA<F=U;65N='-;:5U=.PH@("`@("`@("`@("`@("`@
M:68@*&]B:E-R8RD@>PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H;V)J
M4W)C+G1Y<&4N=&],;W=E<D-A<V4H*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W-E;&5C="UO;F4G.@H@("`@("`@("`@("`@("`@("`@("`@("!S
M=6T@*ST@=&].=6UB97(H;V)J4W)C+F]P=&EO;G-;;V)J4W)C+G-E;&5C=&5D
M26YD97A=+G9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W-E;&5C="UM=6QT:7!L92<@
M.@H@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*'9A<B!J(#T@,#L@:B`\
M(&]B:E-R8RYL96YG=&@[("LK:BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W5M("L]('1O3G5M8F5R*&]B:E-R8RYO<'1I;VYS6VI=+G9A;'5E
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G8VAE
M8VMB;W@G(#H*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&]B:E-R8RYC
M:&5C:V5D*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=6T@*ST@
M=&].=6UB97(H;V)J4W)C+G9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("`@("`@9&5F875L="`Z"B`@("`@("`@("`@("`@("`@("`@("`@
M('-U;2`K/2!T;TYU;6)E<BAO8FI3<F,N=F%L=64I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@;V)J5&%R9V5T+G9A;'5E(#T@<W5M.PH@("`@("`@('T*("`@
M('T*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J
M<R]H='1P8VQI96YT+FIS````````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$Q,#<V`#$P-3$U-#,Q,#8P`#`Q-S4T,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@2F%V
M87-C<FEP="!L:6)R87)Y(&9O<B!W;W)K:6YG('=I=&@@6&UL2'1T<%)E<75E
M<W0@;V)J96-T<R!A;F0*("H@2&]R9&4N"B`J"B`J("1(;W)D93H@:&]R9&4O
M:G,O:'1T<&-L:65N="YJ<RQV(#$N,BXQ,"XS(#(P,#4O,3`O,3@@,3$Z,S,Z
M,S@@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I
M9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\O($-O;G-T<G5C=&]R
M(&9O<B!G96YE<FEC($A45%`@8VQI96YT+@IF=6YC=&EO;B!(5%100VQI96YT
M*"D@>WT["@HO+R!!9&0@;65T:&]D<R!A;F0@<')O<&5R=&EE<R!A<R!A<G)A
M>2X*2%144$-L:65N="YP<F]T;W1Y<&4@/2!["B`@("!U<FPZ(&YU;&PL"@H@
M("`@+R\@26YS=&%N8V4@;V8@6$U,2'1T<%)E<75E<W0N"B`@("!R97%U97-T
M.B!N=6QL+`H*("`@("\O(%5S960@=&\@;6%K92!S=7)E(&UU;'1I<&QE(&-A
M;&QS(&%R92!N;W0@<&QA8V5D('=I=&@@=&AE('-A;64*("`@("\O(&-L:65N
M="!O8FIE8W0@=VAI;&4@86YO=&AE<B!I;B!P<F]G<F5S<RX*("`@(&-A;&Q)
M;E!R;V=R97-S.B!F86QS92P*"B`@("`O+R!4:&4@=7-E<B!D969I;F5D(&AA
M;F1L97(@+2!S964@37E(86YD;&5R(&)E;&]W+@H@("`@=7-E<FAA;F1L97(Z
M(&YU;&PL"@H@("`@:6YI=#H@9G5N8W1I;VXH=7)L*0H@("`@>PH@("`@("`@
M('1H:7,N=7)L(#T@=7)L.PH*("`@("`@("!T<GD@>PH@("`@("`@("`@("`O
M+R!-;WII;&QA+"!3869A<FDN"B`@("`@("`@("`@('1H:7,N<F5Q=65S="`]
M(&YE=R!834Q(='1P4F5Q=65S="@I.PH@("`@("`@('T@8V%T8V@@*&4I('L*
M("`@("`@("`@("`@+R\@244N"B`@("`@("`@("`@('9A<B!-4UA-3%]834Q(
M5%107U!23T=)1%,@/2!N97<@07)R87DH"B`@("`@("`@("`@("`@("`B35-8
M34PR+EA-3$A45%`N-"XP(BP*("`@("`@("`@("`@("`@(")-4UA-3#(N6$U,
M2%144"XS+C`B+`H@("`@("`@("`@("`@("`@(DU36$U,,BY834Q(5%10(BP*
M("`@("`@("`@("`@("`@(")-:6-R;W-O9G0N6$U,2%144"(*("`@("`@("`@
M("`@("`@("D["B`@("`@("`@("`@('9A<B!S=6-C97-S(#T@9F%L<V4["B`@
M("`@("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@35-834Q?6$U,2%144%]0
M4D]'2413+FQE;F=T:"`F)B`A<W5C8V5S<SL@:2LK*2!["B`@("`@("`@("`@
M("`@("!T<GD@>PH@("`@("`@("`@("`@("`@("`@('1H:7,N<F5Q=65S="`]
M(&YE=R!!8W1I=F583V)J96-T*$U36$U,7UA-3$A45%!?4%)/1TE$4UMI72D[
M"B`@("`@("`@("`@("`@("`@("`@<W5C8V5S<R`]('1R=64["B`@("`@("`@
M("`@("`@("!](&-A=&-H("AE*2![?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A<W5C8V5S<RD@>PH@("`@("`@("`@("`@("`@=&AR;W<@(E5N
M86)L92!T;R!C<F5A=&4@6$U,2'1T<%)E<75E<W0N(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('TL"@H@("`@+R\@2&%N9&QE<B!A<F=U;65N="!I
M<R!A('5S97(@9&5F:6YE9"!O8FIE8W0@=&\@8F4@8V%L;&5D+@H@("`@87-Y
M;F-'150Z(&9U;F-T:6]N*&AA;F1L97(I"B`@("!["B`@("`@("`@+R\@1&5G
M<F%D92!O<B!S;VUE('-U8V@N"B`@("`@("`@:68@*"%T:&ES+G)E<75E<W0I
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T["@H@("`@
M("`@("\O(%!R979E;G0@;75L=&EP;&4@8V%L;',*("`@("`@("!I9B`H=&AI
M<RYC86QL26Y0<F]G<F5S<RD@>PH@("`@("`@("`@("!T:')O=R`B0V%L;"!I
M;B!P<F]G<F5S<R(["B`@("`@("`@?3L*"B`@("`@("`@=&AI<RYC86QL26Y0
M<F]G<F5S<R`]('1R=64["@H@("`@("`@('1H:7,N=7-E<FAA;F1L97(@/2!H
M86YD;&5R.PH*("`@("`@("`O+R!/<&5N(&%N(&%S>6YC(')E<75E<W0@+2!T
M:&ER9"!A<F=U;65N="!M86ME<R!I=`H@("`@("`@("\O(&%S>6YC:')O;F]U
M<RX*("`@("`@("!T:&ES+G)E<75E<W0N;W!E;B@G1T54)RP@=&AI<RYU<FPL
M('1R=64I.PH*("`@("`@("`O+R!(879E('1O(&%S<VEG;B`B=&AI<R(@=&\@
M82!V87)I86)L92X*("`@("`@("!V87(@<V5L9B`]('1H:7,["@H@("`@("`@
M("\O($%S<VEG;B!A(&-L;W-U<F4@=&\@=&AE(&]N<F5A9'ES=&%T96-H86YG
M92!C86QL8F%C:RX*("`@("`@("!T:&ES+G)E<75E<W0N;VYR96%D>7-T871E
M8VAA;F=E(#T@9G5N8W1I;VXH*0H@("`@("`@('L*("`@("`@("`@("`@<V5L
M9BYS=&%T94-H86YG94-A;&QB86-K*'-E;&8I.PH@("`@("`@('T*"B`@("`@
M("`@=&AI<RYR97%U97-T+G-E;F0H;G5L;"D["B`@("!]+`H*("`@('-T871E
M0VAA;F=E0V%L;&)A8VLZ(&9U;F-T:6]N*&-L:65N="D*("`@('L*("`@("`@
M("!S=VET8V@@*&-L:65N="YR97%U97-T+G)E861Y4W1A=&4I('L*("`@("`@
M("`@("`@+R\@4F5Q=65S="!N;W0@>65T(&UA9&4N"B`@("`@("`@("`@(&-A
M<V4@,3H*("`@("`@("`@("`@=')Y('L*("`@("`@("`@("`@("`@(&-L:65N
M="YU<V5R:&%N9&QE<BYO;DEN:70H*3L*("`@("`@("`@("`@?2!C871C:"`H
M92D@>R`O*B!(86YD;&5R(&UE=&AO9"!N;W0@9&5F:6YE9"X@*B\@?0H@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O($-O;G1A8W0@97-T86)L
M:7-H960@=VET:"!S97)V97(@8G5T(&YO=&AI;F<@9&]W;FQO861E9`H@("`@
M("`@("`@("`O+R!Y970N"B`@("`@("`@("`@(&-A<V4@,CH*("`@("`@("`@
M("`@=')Y('L*("`@("`@("`@("`@("`@('-T871U<R`](&-L:65N="YR97%U
M97-T+G-T871U<SL*("`@("`@("`@("`@("`@("\O($-H96-K(&9O<B!(5%10
M('-T871U<R`R,#`N"B`@("`@("`@("`@("`@("!I9B`H<W1A='5S("$](#(P
M,"D@>PH@("`@("`@("`@("`@("`@("`@(&-L:65N="YU<V5R:&%N9&QE<BYO
M;D5R<F]R*`H@("`@("`@("`@("`@("`@("`@("`@("!S=&%T=7,L"B`@("`@
M("`@("`@("`@("`@("`@("`@(&-L:65N="YR97%U97-T+G-T871U<U1E>'0*
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@("`@("`@
M("`@+R\@06)O<G0@=&AE(')E<75E<W0N"B`@("`@("`@("`@("`@("`@("`@
M8VQI96YT+G)E<75E<W0N86)O<G0H*3L*"B`@("`@("`@("`@("`@("`@("`@
M+R\@0V%L;"!N;R!L;VYG97(@:6X@<')O9W)E<W,N"B`@("`@("`@("`@("`@
M("`@("`@8VQI96YT+F-A;&Q);E!R;V=R97-S(#T@9F%L<V4["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@8V%T8V@@*&4I('L*("`@("`@("`@
M("`@("`@("\J($U36$U,2%144"`S+G@K(&1O97-N)W0@<&]P=6QA=&4@<W1A
M='5S('5N=&EL"B`@("`@("`@("`@("`@("`@*B!R96%D>5-T871E(#0N("HO
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`O+R!#86QL960@;75L=&EP;&4@=&EM97,@=VAI;&4@9&]W;FQO860@:7,@
M:6X@<')O9W)E<W,N"B`@("`@("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@
M+R\@3F]T:69Y('5S97(@:&%N9&QE<B!O9B!D;W=N;&]A9"!P<F]G<F5S<RX*
M("`@("`@("`@("`@=')Y('L*("`@("`@("`@("`@("`@("\O($=E="!T:&4@
M=&]T86P@8V]N=&5N="!L96YG=&@@*'5S969U;"!T;R!W;W)K"B`@("`@("`@
M("`@("`@("`O+R!O=70@:&]W(&UU8V@@:&%S(&)E96X@9&]W;FQO861E9"DN
M"B`@("`@("`@("`@("`@("!T<GD@>PH@("`@("`@("`@("`@("`@("`@('9A
M<B!C;VYT96YT3&5N9W1H(#T*("`@("`@("`@("`@("`@("`@("`@("`@8VQI
M96YT+G)E<75E<W0N9V5T4F5S<&]N<V5(96%D97(H(D-O;G1E;G0M3&5N9W1H
M(BD["B`@("`@("`@("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@("`@
M("`@("`@("`@=F%R(&-O;G1E;G1,96YG=&@@/2!.84X["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@+R\@0V%L;"!T:&4@<')O9W)E<W,@
M:&%N9&QE<B!W:71H('=H870@=V4G=F4@9V]T+@H@("`@("`@("`@("`@("`@
M8VQI96YT+G5S97)H86YD;&5R+F]N4')O9W)E<W,H"B`@("`@("`@("`@("`@
M("`@("`@8VQI96YT+G)E<75E<W0N<F5S<&]N<V5497AT+`H@("`@("`@("`@
M("`@("`@("`@(&-O;G1E;G1,96YG=&@*("`@("`@("`@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@?2!C871C:"`H92D@>R`O*B!(86YD;&5R(&UE=&AO
M9"!N;W0@9&5F:6YE9"X@*B\@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("\O($1O=VYL;V%D(&-O;7!L971E+@H@("`@("`@("`@("!C87-E
M(#0Z"B`@("`@("`@("`@('1R>2!["B`@("`@("`@("`@("`@("!C;&EE;G0N
M=7-E<FAA;F1L97(N;VY,;V%D*&-L:65N="YR97%U97-T+G)E<W!O;G-E5&5X
M="D["B`@("`@("`@("`@('T@8V%T8V@@*&4I('L*("`@("`@("`@("`@("`@
M("\J($AA;F1L97(@;65T:&]D(&YO="!D969I;F5D+B`J+PH@("`@("`@("`@
M("!](&9I;F%L;'D@>PH@("`@("`@("`@("`@("`@+R\@0V%L;"!N;R!L;VYG
M97(@:6X@<')O9W)E<W,N"B`@("`@("`@("`@("`@("!C;&EE;G0N8V%L;$EN
M4')O9W)E<W,@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:G,O:65%<V-'=6%R9"YJ<P``````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0T,0`Q,#4Q-30S,3`V,``P,3<S-S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+RHJ
M"B`J($IA=F%S8W)I<'0@8V]D92!F;W(@871T86-H:6YG(&%N(&]N:V5Y9&]W
M;B!L:7-T96YE<B!T;R!T97AT87)E82!A;F0*("H@=&5X="!I;G!U="!E;&5M
M96YT<R!T;R!P<F5V96YT(&QO<W,@;V8@9&%T82!W:&5N('1H92!U<V5R(&AI
M=',@=&AE"B`J($530R!K97DN"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O:65%
M<V-'=6%R9"YJ<RQV(#$N,2XR+C,@,C`P-2\Q,"\Q."`Q,3HS,SHS."!J86X@
M17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@
M*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*+RH@5&AI<R!C;V1E(&ES(&]N;'D@
M<F5L979A;G0@9F]R($E%+B!4:&5R969O<F4@=')Y(&YO="!T;R!D;R!A;GET
M:&EN9PH@*B!I9B!T:&4@=7-E<B!I<VXG="!U<VEN9R!)12P@979E;B!I9B!T
M:&ES('-C<FEP="!I<R!I;F-L=61E9"X@5&AI<PH@*B!C:&5C:R!W:6QL(&-A
M=&-H('-O;64@8G)O=W-E<G,@=&AA="!A<F4@;F]T($E%(&)U="!I9&5N=&EF
M>0H@*B!T:&5M<V5L=F5S(&%S($E%+B!(;W!E9G5L;'D@:68@=&AE>2!P87-S
M('1H<F]U9V@@=&AE>2!S=7!P;W)T('=H870*("H@244@<W5P<&]R=',N("HO
M"FEF("AN879I9V%T;W(N87!P5F5R<VEO;BYI;F1E>$]F*"=-4TE%)RD@(3T@
M+3$@)B8@9&]C=6UE;G0N86QL*2!["B`@("`O*B!792!D;R!E=F5R>71H:6YG
M(&]N;&]A9"!S;R!T:&%T('1H92!E;G1I<F4@9&]C=6UE;G0@:7,@<')E<V5N
M=`H@("`@("H@8F5F;W)E('=E('-T87)T('-E87)C:&EN9R!I="X@*B\*("`@
M('=I;F1O=RYA='1A8VA%=F5N="@G;VYL;V%D)RP@9W5A<F0I.PI]"@HO*BH*
M("H@1FEN9',@86QL('1E>'0@:6YP=71S("AI;G!U="!T>7!E/2)T97AT(BD@
M86YD('1E>'1A<F5A('1A9W,L(&%N9`H@*B!A='1A8VAE<R!T:&4@;VYK97ED
M;W=N(&QI<W1E;F5R('1O('1H96T@=&\@879O:60@15-#(&-L96%R:6YG('1H
M90H@*B!T97AT+@H@*B\*9G5N8W1I;VX@9W5A<F0H*0I["B`@("`O*B!&:6YD
M<R!A;&P@=&5X=&%R96%S+B`J+PH@("`@=F%R('1E>'1A<F5A<R`](&1O8W5M
M96YT+F%L;"YT86=S*"=415A405)%02<I.PH@("`@9F]R("AV87(@:2`](#`[
M(&D@/"!T97AT87)E87,N;&5N9W1H.R!I*RLI('L*("`@("`@("!T97AT87)E
M87-;:5TN871T86-H179E;G0H)V]N:V5Y9&]W;B<L(&1I<V%B;&5%<V-A<&4I
M.PH@("`@?0H*("`@("\J($9I;F1S(%]A;&Q?(#QI;G!U=#X@=&%G<RX@*B\*
M("`@('9A<B!I;G!U=',@/2!D;V-U;65N="YA;&PN=&%G<R@G24Y0550G*3L*
M("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@:6YP=71S+FQE;F=T:#L@:2LK*2![
M"B`@("`@("`@+RH@3VYL>2!A='1A8V@@=&\@/&EN<'5T('1Y<&4](G1E>'0B
M/B!T86=S+B`J+PH@("`@("`@(&EF("AI;G!U='-;:5TN='EP92`]/2`G=&5X
M="<I('L*("`@("`@("`@("`@:6YP=71S6VE=+F%T=&%C:$5V96YT*"=O;FME
M>61O=VXG+"!D:7-A8FQE17-C87!E*3L*("`@("`@("!]"B`@("!]"GT*"B\J
M*@H@*B!2971U<FYS(&9A;'-E(&EF('1H92!U<V5R(&AI="!T:&4@15-#(&ME
M>2P@<')E=F5N=&EN9R!)12!F<F]M"B`J(&)L86YK:6YG('1H92!F:65L9"X@
M3W1H97)W:7-E(')E='5R;G,@=')U92X*("H*("H@<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1O(&%L;&]W('1H92!K97D@979E;G0N"B`J+PIF
M=6YC=&EO;B!D:7-A8FQE17-C87!E*"D*>PH@("`@<F5T=7)N('=I;F1O=RYE
M=F5N="YK97E#;V1E("$](#(W.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VIS+V9O<FU?<V5C=&EO;G,N:G,`````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,U,C0`,3`U,34T,S$P-C``,#(P,C,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J*@H@*B!(
M;W)D92!&;W)M(%-E8W1I;VYS($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O
M=FED97,@=&AE(&IA=F%S8W)I<'0@8VQA<W,@9F]R(&AA;F1L:6YG('1A8F)E
M9"!S96-T:6]N<R!I;B!(;W)D92!&;W)M<RX*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]F;W)M7W-E8W1I;VYS+FIS
M+'8@,2XQ+C(N,B`R,#`V+S`T+S$U(#(R.C(S.C,V(&-H=6-K($5X<"`D"B`J
M"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M($!P86-K86=E($AO<F1E7T9O<FT*("HO"F9U;F-T:6]N($AO<F1E7T9O<FU?
M4V5C=&EO;G,H:6YS=&%N8V5.86UE+"!O<&5N4V5C=&EO;BD*>PH@("`@+RH@
M4V5T('5P('1H:7,@8VQA<W,@:6YS=&%N8V4@9F]R(&9U;F-T:6]N(&-A;&QS
M(&9R;VT@=&AE('!A9V4N("HO"B`@("!T:&ES+E]I;G-T86YC94YA;64@/2!I
M;G-T86YC94YA;64["@H@("`@+RH@5&AE(&-U<G)E;G1L>2!S:&]W960@<V5C
M=&EO;BX@*B\*("`@('9A<B!?;W!E;E-E8W1I;VX["@H@("`@=&AI<RYT;V=G
M;&4@/2!F=6YC=&EO;BAS96-T:6]N260I"B`@("!["B`@("`@("`@+RH@1V5T
M('1H92!C=7)R96YT;'D@;W!E;B!S96-T:6]N(&]B:F5C="X@*B\*("`@("`@
M("!O<&5N4V5C=&EO;DED(#T@=&AI<RY?9V5T*"D["B`@("`@("`@:68@*&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"=?<V5C=&EO;E\G("L@;W!E;E-E8W1I
M;VY)9"DI('L*("`@("`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)U]S96-T:6]N7R<@*R!O<&5N4V5C=&EO;DED*2YS='EL92YD:7-P;&%Y(#T@
M)VYO;F4G.PH@("`@("`@('T*("`@("`@("!D;V-U;65N="YG971%;&5M96YT
M0GE)9"@G7W1A8E\G("L@;W!E;E-E8W1I;VY)9"DN8VQA<W-.86UE(#T@;G5L
M;#L*"B`@("`@("`@+RH@1V5T('1H92!N97=L>2!O<&5N960@<V5C=&EO;B!O
M8FIE8W0N("HO"B`@("`@("`@:68@*&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*"=?<V5C=&EO;E\G("L@<V5C=&EO;DED*2D@>PH@("`@("`@("`@("!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@G7W-E8W1I;VY?)R`K('-E8W1I;VY)9"DN
M<W1Y;&4N9&ES<&QA>2`]("=B;&]C:R<["B`@("`@("`@?0H@("`@("`@(&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"=?=&%B7R<@*R!S96-T:6]N260I+F-L
M87-S3F%M92`]("=A8W1I=F5486(G.PH*("`@("`@("`O*B!3=&]R92!T:&4@
M;F5W;'D@;W!E;F5D('-E8W1I;VXN("HO"B`@("`@("`@=&AI<RY?<V5T*'-E
M8W1I;VY)9"D["B`@("!]"@H@("`@=&AI<RY?9V5T(#T@9G5N8W1I;VXH*0H@
M("`@>PH@("`@("`@(')E='5R;B!T:&ES+E]O<&5N4V5C=&EO;CL*("`@('T*
M"B`@("!T:&ES+E]S970@/2!F=6YC=&EO;BAS96-T:6]N260I"B`@("!["B`@
M("`@("`@=F%R(&9O<FT@/2!E=F%L*"=D;V-U;65N="XG("L@=&AI<RY?:6YS
M=&%N8V5.86UE*3L*("`@("`@("!I9B`H9F]R;2`A/2!N=6QL("8F"B`@("`@
M("`@("`@('1Y<&5O9B!F;W)M+E]?9F]R;4]P96Y396-T:6]N("$]("=U;F1E
M9FEN960G*2!["B`@("`@("`@("`@(&9O<FTN7U]F;W)M3W!E;E-E8W1I;VXN
M=F%L=64@/2!E<V-A<&4H<V5C=&EO;DED*3L*("`@("`@("!]"B`@("`@("`@
M=&AI<RY?;W!E;E-E8W1I;VX@/2!S96-T:6]N260["B`@("!]"@H@("`@=&AI
M<RY?<V5T*&]P96Y396-T:6]N*3L*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]E
M;G1E<E]K97E?=')A<"YJ<P``````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,#`W`#$P-3$U-#,Q,#8P`#`R,#,V-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@2F%V87-C
M<FEP="!T;R!T<F%P(&9O<B!T:&4@96YT97(@:V5Y+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+VIS+V5N=&5R7VME>5]T<F%P+FIS+'8@,2XR+C$P+C,@,C`P-B\P
M-2\P-2`Q-3HS,SHS-"!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"F9U
M;F-T:6]N(&5N=&5R7VME>5]T<F%P*&5V96YT*0I["B`@("!V87(@:V5Y.PH@
M("`@:68@*&5V96YT+FME>4-O9&4I('L*("`@("`@("!K97D@/2!E=F5N="YK
M97E#;V1E.PH@("`@?2!E;'-E(&EF("AE=F5N="YW:&EC:"D@>PH@("`@("`@
M(&ME>2`](&5V96YT+G=H:6-H.PH@("`@?2!E;'-E('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@<F5T=7)N("AK97D@/3T@,3`@?'P@:V5Y
M(#T](#$S*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]J<R]H:61E86)L92YJ<P``````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-C(W`#$P-3$U-#,Q,#8P`#`Q-S$R,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O*BH*("H@
M2F%V87-C<FEP="!O8FIE8W0@9F]R(&AI9&EN9R`F('-H;W=I;F<@1$]-(&5L
M96UE;G1S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VAI9&5A8FQE+FIS+'8@
M,2XR(#(P,#0O,3`O,3D@,3DZ,#@Z-3,@8VAU8VL@17AP("0*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*+RHJ"B`J($-O;G-T<G5C=&]R(&9O<B!(;W)D92!(:61E86)L
M92!$3TT@96QE;65N=',N"B`J"B`J($!P87)A;2!I9"`@("`@("`@("`@(%1H
M92!$3TT@:60@;V8@=&AE(&5L96UE;G0@=V4@=V%N="!T;R!W;W)K('=I=&@N
M"B`J($!P87)A;2!D:7-P;&%Y4W1Y;&4@(%=H870@9&ES<&QA>2!S='EL92!S
M:&]W<R!T:&ES(&5L96UE;G0_($1E9F%U;'1S"B`J("`@("`@("`@("`@("`@
M("`@("`@('1O("=B;&]C:R<N"B`J+PIF=6YC=&EO;B!(;W)D95](:61E86)L
M92@I"GL*("`@('1H:7,N:60@/2!A<F=U;65N='-;,%T["B`@("!T:&ES+F5L
M96UE;G0@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AT:&ES+FED*3L*"B`@
M("!I9B`H87)G=6UE;G1S+FQE;F=T:"`]/2`R*2!["B`@("`@("`@=&AI<RYD
M:7-P;&%Y4W1Y;&4@/2!A<F=U;65N='-;,5T["B`@("!]"GT["@I(;W)D95](
M:61E86)L92YP<F]T;W1Y<&4@/2!["@H@("`@+RHJ"B`@("`@*B!)9"!O9B!T
M:&4@1$]-(&5L96UE;G0N"B`@("`@*B!`=F%R(&ED"B`@("`@*B\*("`@(&ED
M.B!N=6QL+`H*("`@("\J*@H@("`@("H@1$]-(&5L96UE;G0@<F5F97)E;F-E
M+@H@("`@("H@0'9A<B!E;&5M96YT"B`@("`@*B\*("`@(&5L96UE;G0Z(&YU
M;&PL"@H@("`@+RHJ"B`@("`@*B!4:&4@9&ES<&QA>2!S='EL92!T;R!U<V4N
M($1E9F%U;'0@:7,@)V)L;V-K)RX*("`@("`J($!V87(@9&ES<&QA>5-T>6QE
M"B`@("`@*B\*("`@(&1I<W!L87E3='EL93H@)V)L;V-K)RP*"B`@("!S:&]W
M;CH@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B!T:&ES+F5L96UE
M;G0N<W1Y;&4N9&ES<&QA>2`A/2`G;F]N92<["B`@("!]+`H*("`@(&AI9&4Z
M(&9U;F-T:6]N*"D*("`@('L*("`@("`@("!T:&ES+F5L96UE;G0N<W1Y;&4N
M9&ES<&QA>2`]("=N;VYE)SL*("`@("`@("!R971U<FX@=&AI<SL*("`@('TL
M"@H@("`@<VAO=SH@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('1H:7,N96QE
M;65N="YS='EL92YD:7-P;&%Y(#T@=&AI<RYD:7-P;&%Y4W1Y;&4["B`@("`@
M("`@<F5T=7)N('1H:7,["B`@("!]+`H*("`@('1O9V=L93H@9G5N8W1I;VXH
M*0H@("`@>PH@("`@("`@(')E='5R;B!T:&ES+G-H;W=N*"D@/R!T:&ES+FAI
M9&4H*2`Z('1H:7,N<VAO=R@I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+W1O;VQT:7`N:G,`````````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R-S0`
M,3`U,34T,S$P-C``,#$W,#4W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B!(;W)D92!4;V]L=&EP($IA=F%S8W)I
M<'0*("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I<'0@=&\@9&ES<&QA>2!T
M;V]L=&EP<RX*("H*("H@)$AO<F1E.B!H;W)D92]J<R]T;V]L=&EP+FIS+'8@
M,2XR+C$P+C(@,C`P-2\P-2\P,2`Q-CHU,SHS,"!C:'5C:R!%>'`@)`H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J+PH*=F%R(&%C=&EV951I;65O=70["@II9B`H='EP96]F
M(&1O8W5M96YT+F-A<'1U<F5%=F5N=',@(3T@)W5N9&5F:6YE9"<I('L*("`@
M(&1O8W5M96YT+F-A<'1U<F5%=F5N=',H179E;G0N34]54T5-3U9%*3L*("`@
M(&1O8W5M96YT+F]N;6]U<V5M;W9E(#T@;6]U<V50;W,["B`@("!V87(@;F5T
M6"P@;F5T63L*?0H*9G5N8W1I;VX@<&]S6"@I"GL*("`@('1E;7!8(#T@9&]C
M=6UE;G0N8F]D>2YS8W)O;&Q,969T("L@979E;G0N8VQI96YT6#L*("`@(&EF
M("AT96UP6"`\(#`I('L*("`@("`@("!T96UP6"`](#`["B`@("!]"B`@("!R
M971U<FX@=&5M<%@["GT*"F9U;F-T:6]N('!O<UDH*0I["B`@("!T96UP62`]
M(&1O8W5M96YT+F)O9'DN<V-R;VQL5&]P("L@979E;G0N8VQI96YT63L*("`@
M(&EF("AT96UP62`\(#`I('L*("`@("`@("!T96UP62`](#`["B`@("!]"B`@
M("!R971U<FX@=&5M<%D["GT*"F9U;F-T:6]N(&UO=7-E4&]S*&4I"GL*("`@
M(&YE=%@@/2!E+G!A9V58.PH@("`@;F5T62`](&4N<&%G95D["GT*"F9U;F-T
M:6]N('1O;VQT:7!3:&]W*'!8+"!P62P@<W)C*0I["B`@("!I9B`H<%@@/"`Q
M*2!["B`@("`@("`@<%@@/2`Q.PH@("`@?0H@("`@:68@*'!9(#P@,2D@>PH@
M("`@("`@('!9(#T@,3L*("`@('T*("`@(&EF("AD;V-U;65N="YG971%;&5M
M96YT0GE)9"D@>PH@("`@("`@('1T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)W1O;VQT:7`G*3L*("`@("`@("!T="YS='EL92YL969T(#T@<%@@*R`G
M<'@G.PH@("`@("`@('1T+G-T>6QE+G1O<"`]('!9("L@)W!X)SL*("`@("`@
M("!T="YS='EL92YV:7-I8FEL:71Y(#T@)W9I<VEB;&4G.PH@("`@("`@('1T
M+FEN;F5R2%1-3"`]('-R8SL*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE
M;G0N86QL+G1O;VQT:7`N<W1Y;&4N;&5F="`]('!8("L@)W!X)SL*("`@("`@
M("!D;V-U;65N="YA;&PN=&]O;'1I<"YS='EL92YT;W`@/2!P62`K("=P>"<[
M"B`@("`@("`@9&]C=6UE;G0N86QL+G1O;VQT:7`N<W1Y;&4N=FES:6)I;&ET
M>2`]("=V:7-I8FQE)SL*("`@("`@("!D;V-U;65N="YA;&PN=&]O;'1I<"YI
M;FYE<DA434P@/2!S<F,["B`@("!]"GT*"F9U;F-T:6]N('1O;VQT:7!#;&]S
M92@I"GL*("`@(&EF("AD;V-U;65N="YG971%;&5M96YT0GE)9"D@>PH@("`@
M("`@('1T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)W1O;VQT:7`G*3L*
M("`@("`@("!T="YS='EL92YV:7-I8FEL:71Y(#T@)VAI9&1E;B<["B`@("`@
M("`@='0N:6YN97)(5$U,(#T@)R<["B`@("!](&5L<V4@>PH@("`@("`@(&1O
M8W5M96YT+F%L;"YT;V]L=&EP+G-T>6QE+G9I<VEB:6QI='D@/2`G:&ED9&5N
M)SL*("`@("`@("!D;V-U;65N="YA;&PN=&]O;'1I<"YI;FYE<DA434P@/2`G
M)SL*("`@('T*("`@(&-L96%R5&EM96]U="AA8W1I=F54:6UE;W5T*3L*("`@
M('=I;F1O=RYS=&%T=7,@/2`G)SL*?0H*9G5N8W1I;VX@=&]O;'1I<$QI;FLH
M=&]O;'1E>'0L('-T871U<VQI;F4I"GL*("`@('1E>'0@/2`G/&1I=B!C;&%S
M<STB=&]O;'1I<"(^)R`K('1O;VQT97AT("L@)SPO9&EV/B<["B`@("!I9B`H
M='EP96]F(&1O8W5M96YT+F-A<'1U<F5%=F5N=',@(3T@)W5N9&5F:6YE9"<I
M('L*("`@("`@("!X<&]S(#T@;F5T6#L*("`@("`@("!Y<&]S(#T@;F5T63L*
M("`@('T@96QS92!["B`@("`@("`@>'!O<R`]('!O<U@H*3L*("`@("`@("!Y
M<&]S(#T@<&]S62@I.PH@("`@?0H@("`@86-T:79E5&EM96]U="`]('-E=%1I
M;65O=70H)W1O;VQT:7!3:&]W*'AP;W,@+2`Q,3`L('EP;W,@*R`Q-2P@=&5X
M="D[)RP@,S`P*3L*("`@('=I;F1O=RYS=&%T=7,@/2!S=&%T=7-L:6YE.PI]
M"@ID;V-U;65N="YW<FET92@G/&1I=B!I9#TB=&]O;'1I<"(@<W1Y;&4](G!O
M<VET:6]N.F%B<V]L=71E.R!V:7-I8FEL:71Y.FAI9&1E;CLB/CPO9&EV/B<I
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+W!O<'5P
M+FIS````````````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$W-3(`,3`U,34T,S$P-C``,#$V-3(V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B!(;W)D92!0;W!U
M<"!*879A4V-R:7!T+@H@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!T
M;R!O<&5N('!O<'5P('=I;F1O=W,N"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O
M<&]P=7`N:G,L=B`Q+C(N,3`N-"`R,#`V+S`R+S$P(#$X.C$T.C4T(&-H=6-K
M($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*9G5N8W1I;VX@<&]P=7`H=7)L+"!W
M:61T:"P@:&5I9VAT*0I["B`@("!I9B`H(7=I9'1H*2!["B`@("`@("`@=VED
M=&@@/2`V,#`["B`@("!]"B`@("!I9B`H(6AE:6=H="D@>PH@("`@("`@(&AE
M:6=H="`](#4P,#L*("`@('T*"B`@("!V87(@;F%M92`]("AN97<@1&%T92@I
M*2YG9714:6UE*"D["B`@("!V87(@<&%R86T@/2`B=&]O;&)A<CUN;RQL;V-A
M=&EO;CUN;RQS=&%T=7,]>65S+'-C<F]L;&)A<G,]>65S+')E<VEZ86)L93UY
M97,L=VED=&@](B`K('=I9'1H("L@(BQH96EG:'0](B`K(&AE:6=H="`K("(L
M;&5F=#TP+'1O<#TP(CL*("`@('9A<B!W:6X@/2!W:6YD;W<N;W!E;BAU<FPL
M(&YA;64L('!A<F%M*3L*("`@(&EF("@A=VEN*2!["B`@("`@("`@86QE<G0H
M(D$@<&]P=7`@=VEN9&]W(&-O=6QD(&YO="!B92!O<&5N960N(%EO=7(@8G)O
M=W-E<B!M87D@8F4@8FQO8VMI;F<@<&]P=7!S(&9O<B!T:&ES(&%P<&QI8V%T
M:6]N+B(I.PH@("`@?2!E;'-E('L*("`@("`@("!I9B`H='EP96]F('=I;BYN
M86UE(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@("`@('=I;BYN86UE(#T@
M;F%M93L*("`@("`@("!]"B`@("`@("`@:68@*'1Y<&5O9B!W:6XN;W!E;F5R
M(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@("`@('=I;BYO<&5N97(@/2!S
M96QF.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@=VEN.PI]"@``````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS
M+V9O<FU?87-S:6=N+FIS````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#0Q,S``,3`U,34T,S$P-C``,#$W-C8S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"\J*@H@*B!(;W)D
M92!&;W)M($%S<VEG;B!&:65L9"!*879A<V-R:7!T($-L87-S"B`J"B`J(%!R
M;W9I9&5S('1H92!J879A<V-R:7!T(&-L87-S('1O(&%C8V]M<&%N>2!T:&4@
M2&]R9&5?1F]R;2!A<W-I9VX@9FEE;&0N"B`J"B`J("1(;W)D93H@:&]R9&4O
M:G,O9F]R;5]A<W-I9VXN:G,L=B`Q+C(N,3`N-"`R,#`V+S`S+S(T(#`U.C$W
M.C4Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*
M"DAO<F1E7T9O<FU?07-S:6=N(#T@;F5W($]B:F5C="@I.PH*2&]R9&5?1F]R
M;5]!<W-I9VXN9&5S96QE8W1(96%D97)S(#T@9G5N8W1I;VXH;F%M92P@<VED
M92D*>PH@("`@:68@*'-I9&4I('L*("`@("`@("!D;V-U;65N=%MN86UE("L@
M)U]?<FEG:'0G75LP72YS96QE8W1E9"`](&9A;'-E.PH@("`@?2!E;'-E('L*
M("`@("`@("!D;V-U;65N=%MN86UE("L@)U]?;&5F="==6S!=+G-E;&5C=&5D
M(#T@9F%L<V4["B`@("!]"GT*"DAO<F1E7T9O<FU?07-S:6=N+FUO=F4@/2!F
M=6YC=&EO;BAN86UE+"!D:7)E8W1I;VXI"GL*("`@('9A<B!L969T(#T@9&]C
M=6UE;G1;;F%M92`K("=?7VQE9G0G73L*("`@('9A<B!R:6=H="`](&1O8W5M
M96YT6VYA;64@*R`G7U]R:6=H="==.PH*("`@(&EF("AD:7)E8W1I;VXI('L*
M("`@("`@("!V87(@9G)O;2`](')I9VAT.PH@("`@("`@('9A<B!T;R`](&QE
M9G0["B`@("!](&5L<V4@>PH@("`@("`@('9A<B!F<F]M(#T@;&5F=#L*("`@
M("`@("!V87(@=&\@/2!R:6=H=#L*("`@('T*"B`@("!F;W(@*'9A<B!I(#T@
M,#L@:2`\(&9R;VTN;&5N9W1H.R`K*VDI('L*("`@("`@("!I9B`H9G)O;5MI
M72YS96QE8W1E9"D@>PH@("`@("`@("`@("!T;UMT;RYL96YG=&A=(#T@;F5W
M($]P=&EO;BAF<F]M6VE=+G1E>'0L(&9R;VU;:5TN=F%L=64I.PH@("`@("`@
M("`@("!T;UMT;RYL96YG=&@@+2`Q72YO;F1B;&-L:6-K(#T@9G5N8W1I;VXH
M*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!(;W)D95]&;W)M7T%S
M<VEG;BYM;W9E*&YA;64L(#$@+2!D:7)E8W1I;VXI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&9R;VU;:5T@/2!N=6QL.PH@("`@("`@("`@("`M+6D[
M"B`@("`@("`@?0H@("`@?0H*("`@('1H:7,N<V5T1FEE;&0H;F%M92D["GT*
M"DAO<F1E7T9O<FU?07-S:6=N+G-E=$9I96QD(#T@9G5N8W1I;VXH;F%M92D*
M>PH@("`@=F%R(&QE9G0@/2!D;V-U;65N=%MN86UE("L@)U]?;&5F="==.PH@
M("`@=F%R(')I9VAT(#T@9&]C=6UE;G1;;F%M92`K("=?7W)I9VAT)UT["@H@
M("`@=F%R('9A;'5E<R`]("<G.PH@("`@=F%R(&AI="`](&9A;'-E.PH@("`@
M9F]R("AV87(@:2`](#`[(&D@/"!L969T+F]P=&EO;G,N;&5N9W1H.R`K*VDI
M('L*("`@("`@("!I9B`H:2`]/2`P("8F("%L969T6VE=+G9A;'5E*2!["B`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("!V86QU97,@
M*ST@;&5F="YO<'1I;VYS6VE=+G9A;'5E("L@)UQT)SL*("`@("`@("!H:70@
M/2!T<G5E.PH@("`@?0H@("`@:68@*&AI="D@>PH@("`@("`@('9A;'5E<R`]
M('9A;'5E<RYS=6)S=')I;F<H,"P@=F%L=65S+FQE;F=T:"`M(#$I.PH@("`@
M?0H@("`@=F%L=65S("L]("=<=%QT)SL*("`@(&AI="`](&9A;'-E.PH@("`@
M9F]R("AV87(@:2`](#`[(&D@/"!R:6=H="YO<'1I;VYS+FQE;F=T:#L@*RMI
M*2!["B`@("`@("`@:68@*&D@/3T@,"`F)B`A<FEG:'1;:5TN=F%L=64I('L*
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@('9A;'5E
M<R`K/2!R:6=H="YO<'1I;VYS6VE=+G9A;'5E("L@)UQT)SL*("`@("`@("!H
M:70@/2!T<G5E.PH@("`@?0H@("`@:68@*&AI="D@>PH@("`@("`@('9A;'5E
M<R`]('9A;'5E<RYS=6)S=')I;F<H,"P@=F%L=65S+FQE;F=T:"`M(#$I.PH@
M("`@?0H@("`@9&]C=6UE;G1;;F%M92`K("=?7W9A;'5E<R==+G9A;'5E(#T@
M=F%L=65S.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VIS+V%L<&AA26UA9V5,;V%D97(N<&AP````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W-S<`,3`U,34T,S$P-C``,#(P
M-S(U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+V%L<&AA26UA9V5,;V%D
M97(N<&AP+'8@,2XR+C@N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-H87)L97,@2BX@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I
M;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["@HD
M<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;BA(3U)$15]315-324].
M7TY/3D4I.PH*+RH@5&AI<R!S:&]U;&0@8F4@8V%C:&5D+B`J+PHD;6]D7V=M
M="`](&=M9&%T92@G1"P@9"!-(%D@2#II.G,G+"!F:6QE;71I;64H7U]&24Q%
M7U\I*2`N("<@1TU4)SL*:&5A9&5R*"=,87-T+4UO9&EF:65D.B`G("X@)&UO
M9%]G;70I.PIH96%D97(H)T-A8VAE+4-O;G1R;VPZ('!U8FQI8RP@;6%X+6%G
M93TX-C0P,"<I.PIH96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]X+6-O;7!O
M;F5N="<I.PH*/SX*/'!U8FQI8SIC;VUP;VYE;G0^"CQP=6)L:6,Z871T86-H
M(&5V96YT/2)O;G!R;W!E<G1Y8VAA;F=E(B!F;W(](F5L96UE;G0B(&]N179E
M;G0](G!R;W!E<G1Y0VAA;F=E9"@I(B`O/@H\<V-R:7!T/@H*=F%R('1R86YS
M<&%R96YT26UA9V4@/2`B/#]P:'`@96-H;R`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"=H;W)D92<I(#\^+V)L86YK+F=I9B(["@IP;F=(86-K*"D["@IF=6YC
M=&EO;B!P<F]P97)T>4-H86YG960H*0I["B`@("!I9B`H979E;G0N<')O<&5R
M='E.86UE(#T](")S<F,B*2!["B`@("`@("`@<&YG2&%C:R@I.PH@("`@?0I]
M"@IF=6YC=&EO;B!P;F=(86-K*"D*>PH@("`@=F%R('<@/2!E;&5M96YT+G=I
M9'1H.PH@("`@=F%R(&@@/2!E;&5M96YT+FAE:6=H=#L*("`@('9A<B!S<F,@
M/2!E;&5M96YT+G-R8SL*("`@(&EF("AS<F,N:6YD97A/9BAT<F%N<W!A<F5N
M=$EM86=E*2`A/2`M,2D@>PH@("`@("`@("\O($%L<F5A9'D@9FEX960N"B`@
M("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF("AS<F,N:6YD97A/9B@B<&YG
M(BD@/3T@+3$I('L*("`@("`@("!E;&5M96YT+G)U;G1I;653='EL92YF:6QT
M97(@/2`B(CL*("`@("`@("!R971U<FX["B`@("!]"@H@("`@96QE;65N="YS
M<F,@/2!T<F%N<W!A<F5N=$EM86=E.PH@("`@96QE;65N="YW:61T:"`]('<[
M"B`@("!E;&5M96YT+FAE:6=H="`](&@["B`@("!E;&5M96YT+G)U;G1I;653
M='EL92YF:6QT97(@/2`B<')O9VED.D1826UA9V54<F%N<V9O<FTN36EC<F]S
M;V9T+D%L<&AA26UA9V5,;V%D97(H<W)C/2<B("L@<W)C("L@(B<L<VEZ:6YG
M365T:&]D/2=S8V%L92<I(CL*?0H*/"]S8W)I<'0^"CPO<'5B;&EC.F-O;7!O
M;F5N=#X*`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O:&]R9&4N:G,`
M````````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q-38S-@`Q,#4Q-30S,3`V,``P,38T-S(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J($=E;F5R86P@2&]R9&4@
M54D@969F96-T<R!J879A<V-R:7!T+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS
M+VAO<F1E+FIS+'8@,2XQ-"XR+C4@,C`P-B\P-2\R-2`Q.#HP-SHR-B!S;'5S
M87)Z($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N
M;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"G9A<B!4;V]L5&EP<R`]('L*
M("`@($-54E)%3E0Z(&YU;&PL"B`@("!424U%3U54.B!N=6QL+`H@("`@3$E.
M2SH@;G5L;"P*"B`@("!A='1A8VA"96AA=FEO<CH@9G5N8W1I;VXH*0H@("`@
M>PH@("`@("`@(&QI;FMS(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA
M;64H)V$G*3L*("`@("`@("!F;W(@*&D@/2`P.R!I(#P@;&EN:W,N;&5N9W1H
M.R!I*RLI('L*("`@("`@("`@("`@:68@*&QI;FMS6VE=+G1I=&QE*2!["B`@
M("`@("`@("`@("`@("!L:6YK<UMI72YS971!='1R:6)U=&4H)VYI8V5T:71L
M92<L(&QI;FMS6VE=+G1I=&QE*3L*("`@("`@("`@("`@("`@(&QI;FMS6VE=
M+G)E;6]V94%T=')I8G5T92@G=&ET;&4G*3L*"B`@("`@("`@("`@("`@("!A
M9&1%=F5N="AL:6YK<UMI72P@)VUO=7-E;W9E<B<L(%1O;VQ4:7!S+F]V97(I
M.PH@("`@("`@("`@("`@("`@861D179E;G0H;&EN:W-;:5TL("=M;W5S96]U
M="<L(%1O;VQ4:7!S+F]U="D["B`@("`@("`@("`@("`@("!A9&1%=F5N="AL
M:6YK<UMI72P@)V9O8W5S)RP@5&]O;%1I<',N;W9E<BD["B`@("`@("`@("`@
M("`@("!A9&1%=F5N="AL:6YK<UMI72P@)V)L=7(G+"!4;V]L5&EP<RYO=70I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2P*"B`@("!O=F5R.B!F
M=6YC=&EO;BAE*0H@("`@>PH@("`@("`@(&EF("AT>7!E;V8@5&]O;%1I<',@
M/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@:68@*%1O;VQ4:7!S+E1)345/550I('L*("`@("`@("`@
M("`@=VEN9&]W+F-L96%R5&EM96]U="A4;V]L5&EP<RY424U%3U54*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("AW:6YD;W<N979E;G0@)B8@=VEN9&]W+F5V
M96YT+G-R8T5L96UE;G0I('L*("`@("`@("`@("`@5&]O;%1I<',N3$E.2R`]
M('=I;F1O=RYE=F5N="YS<F-%;&5M96YT.PH@("`@("`@('T@96QS92!I9B`H
M92`F)B!E+G1A<F=E="D@>PH@("`@("`@("`@("!4;V]L5&EP<RY,24Y+(#T@
M92YT87)G970["B`@("`@("`@?0H*("`@("`@("!4;V]L5&EP<RY424U%3U54
M(#T@=VEN9&]W+G-E=%1I;65O=70H)U1O;VQ4:7!S+G-H;W<H*2<L(#,P,"D*
M("`@('TL"@H@("`@;W5T.B!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@:68@
M*'1Y<&5O9B!4;V]L5&EP<R`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H5&]O;%1I<',N5$E-
M14]55"D@>PH@("`@("`@("`@("!W:6YD;W<N8VQE87)4:6UE;W5T*%1O;VQ4
M:7!S+E1)345/550I.PH@("`@("`@('T*"B`@("`@("`@:68@*%1O;VQ4:7!S
M+D-54E)%3E0I('L*("`@("`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N='-"
M>51A9TYA;64H)V)O9'DG*5LP72YR96UO=F5#:&EL9"A4;V]L5&EP<RY#55)2
M14Y4*3L*("`@("`@("`@("`@5&]O;%1I<',N0U524D5.5"`](&YU;&P["@H@
M("`@("`@("`@("!V87(@:69R86UE(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)VEF<F%M95]T="<I.PH@("`@("`@("`@("!I9B`H:69R86UE("$](&YU
M;&PI('L*("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YD:7-P;&%Y(#T@
M)VYO;F4G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2P*"B`@("!S
M:&]W.B!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@:68@*'1Y<&5O9B!4;V]L
M5&EP<R`]/2`G=6YD969I;F5D)R!\?"`A5&]O;%1I<',N3$E.2RD@>PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H5&]O;%1I
M<',N0U524D5.5"D@>PH@("`@("`@("`@("!4;V]L5&EP<RYO=70H*3L*("`@
M("`@("!]"@H@("`@("`@(&QI;FL@/2!4;V]L5&EP<RY,24Y+.PH@("`@("`@
M('=H:6QE("@A;&EN:RYG971!='1R:6)U=&4H)VYI8V5T:71L92<I("8F(&QI
M;FLN;F]D94YA;64N=&],;W=E<D-A<V4H*2`A/2`G8F]D>2<I('L*("`@("`@
M("`@("`@;&EN:R`](&QI;FLN<&%R96YT3F]D93L*("`@("`@("!]"B`@("`@
M("`@;FEC971I=&QE(#T@;&EN:RYG971!='1R:6)U=&4H)VYI8V5T:71L92<I
M.PH@("`@("`@(&EF("@A;FEC971I=&QE*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@(&0@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=D:78G*3L*("`@("`@("!D+F-L87-S3F%M92`]("=N:6-E=&ET;&4G
M.PH@("`@("`@(&0N:6YN97)(5$U,(#T@;FEC971I=&QE.PH*("`@("`@("!3
M5$1?5TE$5$@@/2`Q,#`["B`@("`@("`@34%87U=)1%1((#T@-C`P.PH@("`@
M("`@(&EF("AW:6YD;W<N:6YN97)7:61T:"D@>PH@("`@("`@("`@("!-05A?
M5TE$5$@@/2!-871H+FUI;BA-05A?5TE$5$@L('=I;F1O=RYI;FYE<E=I9'1H
M("T@,C`I.PH@("`@("`@('T*("`@("`@("!I9B`H9&]C=6UE;G0N8F]D>2`F
M)B!D;V-U;65N="YB;V1Y+G-C<F]L;%=I9'1H*2!["B`@("`@("`@("`@($U!
M6%]724142"`]($UA=&@N;6EN*$U!6%]724142"P@9&]C=6UE;G0N8F]D>2YS
M8W)O;&Q7:61T:"`M(#(P*3L*("`@("`@("!]"@H@("`@("`@(&YI8V5T:71L
M95]L96YG=&@@/2`P.PH@("`@("`@(&QI;F5S(#T@;FEC971I=&QE+G)E<&QA
M8V4H+SQB<B`_7"\^+V<L(")<;B(I+G-P;&ET*")<;B(I.PH@("`@("`@(&9O
M<B`H:2`](#`[(&D@/"!L:6YE<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("`@
M("!N:6-E=&ET;&5?;&5N9W1H(#T@36%T:"YM87@H;FEC971I=&QE7VQE;F=T
M:"P@;&EN97-;:5TN;&5N9W1H*3L*("`@("`@("!]"@H@("`@("`@(&A?<&EX
M96QS(#T@;FEC971I=&QE7VQE;F=T:"`J(#<["B`@("`@("`@=%]P:7AE;',@
M/2!N:6-E=&ET;&5?;&5N9W1H("H@,3`["@H@("`@("`@(&EF("AH7W!I>&5L
M<R`^(%-41%]724142"D@>PH@("`@("`@("`@("!W(#T@:%]P:7AE;',["B`@
M("`@("`@?2!E;'-E(&EF("A35$1?5TE$5$@@/B!T7W!I>&5L<RD@>PH@("`@
M("`@("`@("!W(#T@=%]P:7AE;',["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@=R`](%-41%]724142#L*("`@("`@("!]"@H@("`@("`@(&UP;W,@
M/2!F:6YD4&]S*&QI;FLI.PH@("`@("`@(&UX(#T@;7!O<ULP73L*("`@("`@
M("!M>2`](&UP;W-;,5T["@H@("`@("`@(&QE9G0@/2!M>"`K(#(P.PH@("`@
M("`@(&EF("AW:6YD;W<N:6YN97)7:61T:"`F)B`H*&QE9G0@*R!W*2`^('=I
M;F1O=RYI;FYE<E=I9'1H*2D@>PH@("`@("`@("`@("!L969T(#T@=VEN9&]W
M+FEN;F5R5VED=&@@+2!W("T@-#`["B`@("`@("`@?0H@("`@("`@(&EF("AD
M;V-U;65N="YB;V1Y("8F(&1O8W5M96YT+F)O9'DN<V-R;VQL5VED=&@@)B8@
M*"AL969T("L@=RD@/B!D;V-U;65N="YB;V1Y+G-C<F]L;%=I9'1H*2D@>PH@
M("`@("`@("`@("!L969T(#T@9&]C=6UE;G0N8F]D>2YS8W)O;&Q7:61T:"`M
M('<@+2`R-3L*("`@("`@("!]"@H@("`@("`@(&0N:60@/2`G=&]O;%1I<"<[
M"B`@("`@("`@9"YS='EL92YL969T(#T@36%T:"YM87@H;&5F="P@-2D@*R`G
M<'@G.PH@("`@("`@(&0N<W1Y;&4N=VED=&@@/2!-871H+FUI;BAW+"!-05A?
M5TE$5$@I("L@)W!X)SL*("`@("`@("!D+G-T>6QE+G1O<"`]("AM>2`K(#(P
M*2`K("=P>"<["B`@("`@("`@9"YS='EL92YD:7-P;&%Y(#T@(F)L;V-K(CL*
M"B`@("`@("`@=')Y('L*("`@("`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N
M='-">51A9TYA;64H)V)O9'DG*5LP72YA<'!E;F1#:&EL9"AD*3L*("`@("`@
M("`@("`@5&]O;%1I<',N0U524D5.5"`](&0["@H@("`@("`@("`@("!I9B`H
M='EP96]F(%1O;VQ4:7!S7T]P=&EO;E]7:6YD;W=E9%]#;VYT<F]L<R`A/2`G
M=6YD969I;F5D)RD@>PH@("`@("`@("`@("`@("`@=F%R(&EF<F%M92`](&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"=I9G)A;65?='0G*3L*("`@("`@("`@
M("`@("`@(&EF("AI9G)A;64@/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF<F%M92`](&1O8W5M96YT+F-R96%T945L96UE;G0H(CQI9G)A;64@
M<W)C/2=J879A<V-R:7!T.F9A;'-E.R<@;F%M93TG:69R86UE7W1T)R!I9#TG
M:69R86UE7W1T)R!S8W)O;&QI;F<])VYO)R!F<F%M96)O<F1E<CTG,"<@<W1Y
M;&4])W!O<VET:6]N.F%B<V]L=71E.R!T;W`Z,'!X.R!L969T.C!P>#L@9&ES
M<&QA>3IN;VYE.R<^/"]I9G)A;64^(BD["B`@("`@("`@("`@("`@("`@("`@
M9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64H)V)O9'DG*5LP72YA<'!E
M;F1#:&EL9"AI9G)A;64I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:69R86UE+G-T>6QE+G=I9'1H(#T@9"YO9F9S9717:61T:#L*("`@
M("`@("`@("`@("`@(&EF<F%M92YS='EL92YH96EG:'0@/2!D+F]F9G-E=$AE
M:6=H=#L*("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YT;W`@/2!D+G-T
M>6QE+G1O<#L*("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YL969T(#T@
M9"YS='EL92YL969T.PH@("`@("`@("`@("`@("`@:69R86UE+G-T>6QE+G!O
M<VET:6]N(#T@(F%B<V]L=71E(CL*("`@("`@("`@("`@("`@(&EF<F%M92YS
M='EL92YD:7-P;&%Y(#T@(F)L;V-K(CL*("`@("`@("`@("`@("`@(&0N<W1Y
M;&4N>DEN9&5X(#T@,3`P.PH@("`@("`@("`@("`@("`@:69R86UE+G-T>6QE
M+GI);F1E>"`](#DY.PH@("`@("`@("`@("!]"B`@("`@("`@?2!C871C:"`H
M92D@>PH@("`@("`@('T*("`@('T*"GT["@HO*BH*("H@4F5T=7)N('1H92!;
M>"QY72!P;W-I=&EO;B!O9B!A;B!O8FIE8W0N"B`J+PIF=6YC=&EO;B!F:6YD
M4&]S*&]B:BD*>PH@("`@:68@*&]B:BYO9F9S971087)E;G0I('L*("`@("`@
M("!F;W(@*'!O<U@@/2`P+"!P;W-9(#T@,#L@;V)J+F]F9G-E=%!A<F5N=#L@
M;V)J(#T@;V)J+F]F9G-E=%!A<F5N="D@>PH@("`@("`@("`@("!P;W-8("L]
M(&]B:BYO9F9S971,969T.PH@("`@("`@("`@("!P;W-9("L](&]B:BYO9F9S
M9714;W`["B`@("`@("`@?0H@("`@("`@(')E='5R;B!;<&]S6"P@<&]S65T[
M"B`@("!](&5L<V4@>PH@("`@("`@(')E='5R;B!;;V)J+G@L(&]B:BYY73L*
M("`@('T*?0H*+RHJ"B`J($%D9"!A;B!E=F5N="!L:7-T96YE<B!A<R!L;VYG
M(&%S('1H92!B<F]W<V5R('-U<'!O<G1S(&ET+B!$:69F97)E;G0*("H@8G)O
M=W-E<G,@<W1I;&P@:&%N9&QE('1H97-E(&5V96YT<R!S;&EG:'1L>2!D:69F
M97)E;G1L>3L@:6X*("H@<&%R=&EC=6QA<B!A=F]I9"!U<VEN9R`B=&AI<R(@
M:6X@979E;G0@9G5N8W1I;VYS+@H@*@H@*B!`875T:&]R(%-C;W1T($%N9')E
M=PH@*B!`875T:&]R($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B\*9G5N8W1I;VX@861D179E;G0H;V)J+"!E=E1Y<&4L(&9N*0I["B`@
M("!I9B`H;V)J+F%D9$5V96YT3&ES=&5N97(I('L*("`@("`@("!O8FHN861D
M179E;G1,:7-T96YE<BAE=E1Y<&4L(&9N+"!T<G5E*3L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T@96QS92!I9B`H;V)J+F%T=&%C:$5V96YT*2!["B`@
M("`@("`@=F%R('(@/2!O8FHN871T86-H179E;G0H)V]N)R`K(&5V5'EP92P@
M9FXI.PH@("`@("`@($5V96YT0V%C:&4N861D*&]B:BP@9794>7!E+"!F;BD[
M"B`@("`@("`@<F5T=7)N('(["B`@("!](&5L<V4@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*?0H*=F%R($5V96YT0V%C:&4@/2!F=6YC=&EO;B@I
M"GL*("`@('9A<B!L:7-T179E;G1S(#T@6UT["@H@("`@<F5T=7)N('L*("`@
M("`@("!L:7-T179E;G1S.B!L:7-T179E;G1S+`H*("`@("`@("!A9&0Z(&9U
M;F-T:6]N*&YO9&4L('-%=F5N=$YA;64L(&9(86YD;&5R+"!B0V%P='5R92D*
M("`@("`@("!["B`@("`@("`@("`@(&QI<W1%=F5N=',N<'5S:"AA<F=U;65N
M=',I.PH@("`@("`@('TL"@H@("`@("`@(&9L=7-H.B!F=6YC=&EO;B@I"B`@
M("`@("`@>PH@("`@("`@("`@("!V87(@:2P@:71E;3L*("`@("`@("`@("`@
M9F]R("AI(#T@;&ES=$5V96YT<RYL96YG=&@@+2`Q.R!I(#X](#`[(&D@/2!I
M("T@,2D@>PH@("`@("`@("`@("`@("`@:71E;2`](&QI<W1%=F5N='-;:5T[
M"@H@("`@("`@("`@("`@("`@:68@*&ET96U;,%TN<F5M;W9E179E;G1,:7-T
M96YE<BD@>PH@("`@("`@("`@("`@("`@("`@(&ET96U;,%TN<F5M;W9E179E
M;G1,:7-T96YE<BAI=&5M6S%=+"!I=&5M6S)=+"!I=&5M6S-=*3L*("`@("`@
M("`@("`@("`@('T["@H@("`@("`@("`@("`@("`@+RH@1G)O;2!T:&ES('!O
M:6YT(&]N('=E(&YE960@=&AE(&5V96YT(&YA;65S('1O(&)E"B`@("`@("`@
M("`@("`@("`@*B!P<F5F:7AE9"!W:71H("=O;B<N("HO"B`@("`@("`@("`@
M("`@("!I9B`H:71E;5LQ72YS=6)S=')I;F<H,"P@,BD@(3T@)V]N)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&ET96U;,5T@/2`G;VXG("L@:71E;5LQ73L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H:71E;5LP
M72YD971A8VA%=F5N="D@>PH@("`@("`@("`@("`@("`@("`@(&ET96U;,%TN
M9&5T86-H179E;G0H:71E;5LQ72P@:71E;5LR72D["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@:71E;5LP75MI=&5M6S%=72`](&YU;&P[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!].PI]*"D["@II9B`H9&]C
M=6UE;G0N8W)E871E16QE;65N="`F)B!D;V-U;65N="YG971%;&5M96YT<T)Y
M5&%G3F%M92D@>PH@("`@861D179E;G0H=VEN9&]W+"`G;&]A9"<L(%1O;VQ4
M:7!S+F%T=&%C:$)E:&%V:6]R*3L*("`@(&%D9$5V96YT*'=I;F1O=RP@)W5N
M;&]A9"<L(%1O;VQ4:7!S+F]U="D["B`@("!A9&1%=F5N="AW:6YD;W<L("=U
M;FQO860G+"!%=F5N=$-A8VAE+F9L=7-H*3L*?0H`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:G,O;W!E;E]C;VQO<G!I8VME<BYJ<P``````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-34U,``Q,#4Q-30S
M,3`V,``P,C`W,C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J($AO<F1E($-O;&]R<&EC:V5R($IA=F%38W)I<'0N
M"B`J"B`J(%!R;W9I9&5S('1H92!J879A<V-R:7!T('1O(&-R96%T92!A(&-O
M;&]R<&EC:V5R+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+V]P96Y?8V]L;W)P
M:6-K97(N:G,L=B`Q+C(@,C`P-"\Q,"\Q.2`Q.3HP.#HU,R!C:'5C:R!%>'`@
M)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!O<&5N0V]L;W)0:6-K97(H
M=&%R9V5T*0I["B`@("!V87(@;&%Y(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)V-O;&]R<&EC:V5R7R<@*R!T87)G970I.PH@("`@:68@*&QA>2YS='EL
M92YD:7-P;&%Y(#T]("=B;&]C:R<I('L*("`@("`@("!L87DN<W1Y;&4N9&ES
M<&QA>2`]("=N;VYE)SL*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@:68@*&QA>2YF:7)S=$-H:6QD*2!["B`@("`@("`@:68@*&QA>2YF:7)S
M=$-H:6QD+FYO9&54>7!E(#T](#$I('L*("`@("`@("`@("`@;&%Y+G-T>6QE
M+F1I<W!L87D@/2`G8FQO8VLG.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!L87DN<F5M
M;W9E0VAI;&0H;&%Y+F9I<G-T0VAI;&0I.PH@("`@("`@('T*("`@('T*"B`@
M("!V87(@=&%B;&4@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=T86)L92<I
M.PH@("`@=F%R('1B;V1Y(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G=&)O
M9'DG*3L*("`@('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@('1A8FQE
M+F-E;&Q3<&%C:6YG(#T@,#L*("`@('1A8FQE+F)O<F1E<B`](#`["B`@("!T
M86)L92YS='EL92YC=7)S;W(@/2`G8W)O<W-H86ER)SL*("`@('1A8FQE+F]N
M;6]U<V5O=70@/2!F=6YC=&EO;B@I('L*("`@("`@("!D;V-U;65N="YG971%
M;&5M96YT0GE)9"@G8V]L;W)D96UO7R<@*R!T87)G970I+G-T>6QE+F)A8VMG
M<F]U;F1#;VQO<B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E="DN
M=F%L=64["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O(%1H
M92!P86QE='1E"B`@("!R(#T@,#L@9R`](#`[(&(@/2`P.PH@("`@9F]R("AB
M(#T@,#L@8B`\(#8[(&(K*RD@>PH@("`@("`@(')O=R`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H)W1R)RD["B`@("`@("`@8V]L;W(@/2!M86ME0V]L;W(H
M8B`J(#4Q+"!B("H@-3$L(&(@*B`U,2D["B`@("`@("`@8V5L;"`](&UA:V5#
M96QL*'1A<F=E="P@8V]L;W(I.PH@("`@("`@(')O=RYA<'!E;F1#:&EL9"AC
M96QL*3L*("`@("`@("!F;W(@*&<@/2`P.R!G(#P@-CL@9RLK*2!["B`@("`@
M("`@("`@(&9O<B`H<B`](#`[('(@/"`V.R!R*RLI('L*("`@("`@("`@("`@
M("`@(&EF("AR("$](&(@)B8@8B`A/2!G*2!["B`@("`@("`@("`@("`@("`@
M("`@8V]L;W(@/2!M86ME0V]L;W(H<B`J(#4Q+"!G("H@-3$L(&(@*B`U,2D[
M"B`@("`@("`@("`@("`@("`@("`@8V5L;"`](&UA:V5#96QL*'1A<F=E="P@
M8V]L;W(I.PH@("`@("`@("`@("`@("`@("`@(')O=RYA<'!E;F1#:&EL9"AC
M96QL*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH@("`@?0H*("`@
M('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@(&QA>2YA<'!E;F1#:&EL
M9"AT86)L92D["B`@("!L87DN<W1Y;&4N9&ES<&QA>2`]("=B;&]C:R<["GT*
M"F9U;F-T:6]N(&UA:V5#96QL*'1A<F=E="P@8V]L;W(I"GL*("`@(&-E;&P@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=T9"<I.PH@("`@8V5L;"YH96EG
M:'0@/2`S.PH@("`@8V5L;"YW:61T:"`](#8["B`@("!C96QL+FED(#T@8V]L
M;W(["B`@("!C96QL+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`](&-O;&]R.PH@
M("`@8V5L;"YO;FUO=7-E;W9E<B`](&9U;F-T:6]N*"D@>PH@("`@("`@(&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"=C;VQO<F1E;6]?)R`K('1A<F=E="DN
M<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@=&AI<RYS='EL92YB86-K9W)O=6YD
M0V]L;W(["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@8V5L;"YO
M;F-L:6-K(#T@9G5N8W1I;VXH*2!["B`@("`@("`@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)V-O;&]R9&5M;U\G("L@=&%R9V5T*2YS='EL92YB86-K9W)O
M=6YD0V]L;W(@/2!T:&ES+G-T>6QE+F)A8VMG<F]U;F1#;VQO<CL*("`@("`@
M("!D;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G970I+G9A;'5E(#T@=&AI
M<RYI9#L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@<F5T=7)N
M(&-E;&P["GT*"F9U;F-T:6]N(&UA:V5#;VQO<BAR+"!G+"!B*0I["B`@("!C
M;VQO<B`]("(C(CL*("`@(&-O;&]R("L](&AE>"A-871H+F9L;V]R*'(@+R`Q
M-BDI.PH@("`@8V]L;W(@*ST@:&5X*'(@)2`Q-BD["B`@("!C;VQO<B`K/2!H
M97@H36%T:"YF;&]O<BAG("\@,38I*3L*("`@(&-O;&]R("L](&AE>"AG("4@
M,38I.PH@("`@8V]L;W(@*ST@:&5X*$UA=&@N9FQO;W(H8B`O(#$V*2D["B`@
M("!C;VQO<B`K/2!H97@H8B`E(#$V*3L*("`@(')E='5R;B!C;VQO<CL*?0H*
M9G5N8W1I;VX@:&5X*$1E8RD*>PH@("`@:68@*$1E8R`]/2`Q,"D@<F5T=7)N
M(")A(CL*("`@(&EF("A$96,@/3T@,3$I(')E='5R;B`B8B(["B`@("!I9B`H
M1&5C(#T](#$R*2!R971U<FX@(F,B.PH@("`@:68@*$1E8R`]/2`Q,RD@<F5T
M=7)N(")D(CL*("`@(&EF("A$96,@/3T@,30I(')E='5R;B`B92(["B`@("!I
M9B`H1&5C(#T](#$U*2!R971U<FX@(F8B.PH@("`@<F5T=7)N("(B("L@1&5C
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]J<R]I;6%G92YJ<P``````````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S-#0R`#$P-3$U-#,Q,#8P`#`Q-C0T,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O*BH*("H@
M2&]R9&4@26UA9V4@2F%V87-C<FEP=`H@*@H@*B!0<F]V:61E<R!T:&4@:F%V
M87-C<FEP="!T;R!H96QP(&1U<FEN9R!T:&4@=7!L;V%D:6YG(&]F(&EM86=E
M<R!I;B!(;W)D95]&;W)M+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VEM86=E
M+FIS+'8@,2XS+C0N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`
M;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N
M;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J*@H@*B!#:&%N9V5S('1H
M92!S<F,@;V8@86X@:6UA9V4@=&%R9V5T+"!O<'1I;VYA;&QY(&%T=&%C:&EN
M9R!A('1I;64@=F%L=64@=&\@=&AE"B`J(%523"!T;R!M86ME('-U<F4@=&AA
M="!T:&4@:6UA9V4@9&]E<R!U<&1A=&4@86YD(&YO="!U<V4@=&AE(&)R;W=S
M97(@8V%C:&4N"B`J"B`J($!P87)A;2!S=')I;F<@<W)C("`@("`@("`@("`@
M("!4:&4@<W)O=6-E('1O(&EN<V5R=&5D(&EN=&\@=&AE(&EM86=E(&5L96UE
M;G0N"B`J($!P87)A;2!S=')I;F<@=&%R9V5T("`@("`@("`@("!4:&4@=&%R
M9V5T(&5L96UE;G0N"B`J($!P87)A;2!O<'1I;VYA;"!B;V]L(&YO7V-A8VAE
M("!)9B!S970@=&\@=')U92!W:6QL(&%P<&5N9"!T:&4@=&EM92X*("H*("H@
M0')E='5R;B!B;V]L("!&86QS92!T;R!S=&]P('1H92!B<F]W<V5R(&QO861I
M;F<@86YY=&AI;F<N"B`J+PIF=6YC=&EO;B!S:&]W26UA9V4H<W)C+"!T87)G
M970L(&YO7V-A8VAE*0I["B`@("!V87(@:6UG(#T@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H=&%R9V5T*3L*("`@(&EF("AT>7!E;V8@;F]?8V%C:&4@/3T@
M)W5N9&5F:6YE9"<I('L*("`@("`@("!V87(@;F]?8V%C:&4@/2!F86QS93L*
M("`@('T*"B`@("!I9B`H;F]?8V%C:&4I('L*("`@("`@("!V87(@;F]W(#T@
M;F5W($1A=&4H*3L*("`@("`@("!S<F,@/2!S<F,@*R`G)B<@*R!N;W<N9V5T
M5&EM92@I.PH@("`@?0H*("`@(&EM9RYS<F,@/2!S<F,["@H@("`@<F5T=7)N
M(&9A;'-E.PI]"@HO*BH*("H@061D<R!T;R!T:&4@9VEV96X@<V]U<F-E('1H
M92!H96EG:'0O=VED=&@@9FEE;&0@=F%L=65S(&9O<B!T:&4@9VEV96X@=&%R
M9V5T+@H@*@H@*B!`<&%R86T@<W1R:6YG('-R8R`@("`@("`@("`@5&AE('-R
M;W5C92!T;R!A<'!E;F0@=&\@=&AE(')E<VEZ92!P87)A;7,N"B`J($!P87)A
M;2!S=')I;F<@=&%R9V5T("`@("`@("!4:&4@=&%R9V5T(&5L96UE;G0N"B`J
M($!P87)A;2!O<'1I;VYA;"!B;V]L(')A=&EO("!)9B!S970@=&\@=')U92!W
M:6QL(&%P<&5N9"!F:7@@=&AE(')A=&EO+@H@*@H@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&UO9&EF:65D('-O=7)C92!T;R!I;F-L=61E('1H92!R97-I>F4@
M9&%T82X*("HO"F9U;F-T:6]N(&=E=%)E<VEZ95-R8RAS<F,L('1A<F=E="P@
M<F%T:6\I"GL*("`@('9A<B!W:61T:"`](&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*"=?=U\G("L@=&%R9V5T*2YV86QU93L*("`@('9A<B!H96EG:'0@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@G7VA?)R`K('1A<F=E="DN=F%L=64[
M"B`@("!I9B`H='EP96]F(')A=&EO(#T]("=U;F1E9FEN960G*2!["B`@("`@
M("`@=F%R(')A=&EO(#T@,#L*("`@('T*"B`@("!S<F,@/2!S<F,@*R`G)B<@
M*R`G=CTG("L@=VED=&@@*R`G+B<@*R!H96EG:'0@*R`G+B<@*R!R871I;SL*
M"B`@("!R971U<FX@<W)C.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O
M861D179E;G0N<&AP````````````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C8T,@`Q,#4Q-30S,3`V,``P,3<R-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($=E;F5R
M:6,@9G5N8W1I;VX@=&\@861D(&%N(&5V96YT(&AA;F1L97(@=&\@86YY($1/
M32!E;&5M96YT+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+V%D9$5V96YT+G!H
M<"QV(#$N,2XR+C(@,C`P-B\P,2\P,2`R,3HR.3HP,B!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*+RHJ"B`J($%D9',@=&AE
M(&=I=F5N(&5V96YT('1O(&%N(&5L96UE;G0N($EF('1H92!E;&5M96YT(&%L
M<F5A9'D@:&%S"B`J(&AA;F1L97)S(&9O<B!T:&4@979E;G0L('1H92!N97<@
M979E;G0@:7,@87!P96YD960N"B`J"B`J($!P87)A;2!O8FIE8W0@96QE;65N
M="`@(%1H92!E;&5M96YT('1O(&%D9"!T:&4@979E;G0@=&\N"B`J($!P87)A
M;2!S=')I;F<@979E;G0@("`@(%1H92!N86UE(&]F('1H92!E=F5N="X*("H@
M0'!A<F%M('-T<FEN9WQF=6YC=&EO;B!F=6YC=&EO;B`@5&AE(&IA=F%S8W)I
M<'0@=&\@97AE8W5T92X*("HO"F9U;F-T:6]N(&%D9$5V96YT*&5L96UE;G0L
M(&5V96YT+"!C;V1E*0I["B`@("!I9B`H(65L96UE;G0I('L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@07-S:6=N(&YE=R!A;F]N>6UO
M=7,@9G5N8W1I;VX@:68@=V4G<F4@<&%S<V5D(&$@:G,@<W1R:6YG"B`@("`O
M+R!I;G-T96%D(&]F(&$@9G5N8W1I;VX@<F5F97)E;F-E+@H@("`@:68@*'1Y
M<&5O9B!C;V1E(#T]("=S=')I;F<G*2!["B`@("`@("`@8V]D92`](&YE=R!&
M=6YC=&EO;BAC;V1E*3L*("`@('T*"B`@("!I9B`H96QE;65N="YA9&1%=F5N
M=$QI<W1E;F5R*2!["B`@("`@("`@96QE;65N="YA9&1%=F5N=$QI<W1E;F5R
M*&5V96YT+G)E<&QA8V4H+V]N+RP@)R<I+"!C;V1E+"!F86QS92D["B`@("!]
M(&5L<V4@:68@*&5L96UE;G0N871T86-H179E;G0I('L*("`@("`@("!E;&5M
M96YT+F%T=&%C:$5V96YT*&5V96YT+"!C;V1E*3L*("`@('T@96QS92!I9B`H
M96QE;65N="YO;FQO860@(3T@;G5L;"D@>PH@("`@("`@(&5V86PH)W9A<B!/
M;&1%=F5N="`](&5L96UE;G0N)R`K(&5V96YT*3L*("`@("`@("!N97=#;V1E
M(#T@1G5N8W1I;VXH92D*("`@("`@("!["B`@("`@("`@("`@(&]L9$5V96YT
M*&4I.PH@("`@("`@("`@("!C;V1E*"D["B`@("`@("`@?3L*("`@("`@("!E
M=F%L*"=E;&5M96YT+B<@*R!E=F5N="`K("<@/2!N97=#;V1E)RD["B`@("!]
M(&5L<V4@>PH@("`@("`@(&5V86PH)V5L96UE;G0N)R`K(&5V96YT("L@)R`]
M(&-O9&4G*3L*("`@('T*"B`@("!R971U<FX@=')U93L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O````````````````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8Q`#`Q-3$U-@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC
M34PO````````````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-C``,#$V,S(R`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4O````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,3<U
M,C$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T1E=FEC92]3
M>6YC-&HN<&AP````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4T-38S
M`#$P-3$U-#,Q,#8P`#`R,30Q-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]I
M0V%L96YD87(N<&AP)SL*"B\J*@H@*B!3>6YC-&H@*'=W=RYS>6YC-&HN;W)G
M*0H@*@H@*B!4:&4@4WEN8S1*(&]U=&QO;VL@8V]N=F5R=&5R('5S97,@:71S
M(&YA=&EV92!3248@9F]R;6%T(&9O<B!D871A"B`J(&5X8VAA;F=E+B!#;VYV
M97)S:6]N('1O('1E>'0O=F-A;&5N9&%R(&5T8RX@:7,@9&]N92!B>0H@*B!3
M:69#;VYV97)T97(N<&AP(%1H92!C;VYN96-T;W(@<V5E;7,@;F]T('-U<'!O
M<G0@1&5V26YF"B`J(&EN9F]R;6%T:6]N+"!S;R!3>6YC34Q?1&5V:6-E(&-A
M;B!O;FQY(&1E=&5C="!I="!B>2!T:&4@9&5C:6-E($E$.@H@*B!S;R!I;B!T
M:&4@8V]N;F5C=&]R(&-O;F9I9W5R871I;VX@=&AE(&1E=FEC92!)1"!M=7-T
M(&)E('-E="!T;PH@*B`G<V,M<&EM+3QT>7!E/B<@=VAI8V@@<VAO=6QD(&)E
M('1H92!D969A=6QT(&%N>6AO=RX*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P
M-B!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO
M1&5V:6-E+U-Y;F,T:BYP:'`L=B`Q+C@N,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z
M,S<@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L
M87-S(%-Y;F--3%]$979I8V5?<WEN8S1J(&5X=&5N9',@4WEN8TU,7T1E=FEC
M92!["@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1H92!C;VYT96YT+@H@("`@
M("H*("`@("`J($-U<G)E;G1L>2!S=')I<',@=6ED("AP<FEM87)Y(&ME>2D@
M:6YF;W)M871I;VX@87,@8VQI96YT(&%N9`H@("`@("H@<V5R=F5R(&UI9VAT
M('5S92!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!#:&%R<V5T(&-O
M;G9E<G-I;VYS(&UI9VAT(&)E(&%D9&5D(&AE<F4@=&]O+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VYV97)T0VQI96YT,E-E<G9E<B@D8V]N=&5N="P@)&-O
M;G1E;G14>7!E*0H@("`@>PH@("`@("`@(&QI<W0H)&-O;G1E;G0L("1C;VYT
M96YT5'EP92D@/0H@("`@("`@("`@("!P87)E;G0Z.F-O;G9E<G1#;&EE;G0R
M4V5R=F5R*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH*("`@("`@("!S=VET
M8V@@*"1C;VYT96YT5'EP92D@>PH@("`@("`@(&-A<V4@)W-I9B]N;W1E)R`Z
M"B`@("`@("`@8V%S92`G=&5X="]X+7,T:BUS:69N)R`Z"B`@("`@("`@("`@
M("1C;VYT96YT(#T@)'1H:7,M/G-I9C)V;F]T92AB87-E-C1?9&5C;V1E*"1C
M;VYT96YT*2D["B`@("`@("`@("`@("1C;VYT96YT5'EP92`]("=T97AT+W@M
M=FYO=&4G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<VEF
M+V-O;G1A8W0G(#H*("`@("`@("!C87-E("=T97AT+W@M<S1J+7-I9F,G(#H*
M("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI<RT^<VEF,G9C87)D*&)A<V4V
M-%]D96-O9&4H)&-O;G1E;G0I*3L*("`@("`@("`@("`@)&-O;G1E;G14>7!E
M(#T@)W1E>'0O>"UV8V%R9"<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=S:68O8V%L96YD87(G(#H*("`@("`@("!C87-E("=T97AT+W@M
M<S1J+7-I9F4G(#H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI<RT^<VEF
M,G9E=F5N="AB87-E-C1?9&5C;V1E*"1C;VYT96YT*2D["B`@("`@("`@("`@
M("1C;VYT96YT5'EP92`]("=T97AT+W@M=F5V96YT)SL*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@)W-I9B]T87-K)R`Z"B`@("`@("`@8V%S
M92`G=&5X="]X+7,T:BUS:69T)R`Z"B`@("`@("`@("`@("1C;VYT96YT(#T@
M)'1H:7,M/G-I9C)V=&]D;RAB87-E-C1?9&5C;V1E*"1C;VYT96YT*2D["B`@
M("`@("`@("`@("1C;VYT96YT5'EP92`]("=T97AT+W@M=G1O9&\G.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(&EF("A$14)51TQ/
M1U])0T%,14Y$05)$051!*2!["B`@("`@("`@("`@("1F<"`]($!F;W!E;B@G
M+W1M<"]S>6YC+VQO9RYT>'0G+"`G82<I.PH@("`@("`@("`@("!I9B`H)&9P
M*2!["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN:6YP=70@8V]N
M=F5R=&5D(&9O<B!S97)V97(Z("1C;VYT96YT5'EP95QN(BD["B`@("`@("`@
M("`@("`@("!`9G=R:71E*"1F<"PD8V]N=&5N="`N(")<;B(I.PH@("`@("`@
M("`@("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@87)R87DH)&-O;G1E;G0L("1C;VYT96YT5'EP
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T:&4@8V]N=&5N
M="!F<F]M('1H92!B86-K96YD('1O(&$@9F]R;6%T('-U:71A8FQE(&9O<B!T
M:&4*("`@("`J(&-L:65N="!D979I8V4N"B`@("`@*@H@("`@("H@4W1R:7!S
M('1H92!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@
M86YD('-E<G9E<B!M:6=H="!U<V4*("`@("`J(&1I9F9E<F5N="!O;F5S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@("`@5&AE
M(&-O;G1E;G0@=&\@8V]N=F5R=`H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N
M=&5N=%1Y<&4@("!4:&4@8V]N=&5N=%1Y<&4@;V8@8V]N=&5N="!A<R!R971U
M<FYE9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!B86-K96YD"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@
M("`@(&%R<F%Y*"1N97=C;VYT96YT+"`D;F5W8V]N=&5N=%1Y<&4I.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8V]N=F5R=&5D
M(&-O;G1E;G0@86YD('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`H<&]S<VEB;'D@8VAA;F=E9"D@;F5W($-O;G1E;G14>7!E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T4V5R=F5R,D-L:65N="@D8V]N
M=&5N="P@)&-O;G1E;G14>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C
M:V5N9#L*"B`@("`@("`@;&ES="@D8V]N=&5N="P@)&-O;G1E;G14>7!E*2`]
M"B`@("`@("`@("`@('!A<F5N=#HZ8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O
M;G1E;G0L("1C;VYT96YT5'EP92D["@H@("`@("`@('-W:71C:"`H)&-O;G1E
M;G14>7!E*2!["B`@("`@("`@8V%S92`G=&5X="]C86QE;F1A<B<@.@H@("`@
M("`@(&-A<V4@)W1E>'0O>"UI8V%L96YD87(G(#H*("`@("`@("!C87-E("=T
M97AT+W@M=F-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+79E=F5N
M="<@.@H@("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES+3YV979E;G0R<VEF
M*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O;G1E;G0@/2!B87-E-C1?96YC
M;V1E*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@)W-I
M9B]C86QE;F1A<B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=T97AT+W@M=G1O9&\G(#H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI
M<RT^=G1O9&\R<VEF*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O;G1E;G0@
M/2!B87-E-C1?96YC;V1E*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O;G1E
M;G14>7!E(#T@)W-I9B]T87-K)SL*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@)W1E>'0O>"UV8V%R9"<@.@H@("`@("`@("`@("`D8V]N=&5N
M="`]("1T:&ES+3YV8V%R9#)S:68H)&-O;G1E;G0I.PH@("`@("`@("`@("`D
M8V]N=&5N="`](&)A<V4V-%]E;F-O9&4H)&-O;G1E;G0I.PH@("`@("`@("`@
M("`D8V]N=&5N=%1Y<&4@/2`G<VEF+V-O;G1A8W0G.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G=&5X="]X+79N;W1E)SH*("`@("`@("`@
M("`@)&-O;G1E;G0@/2`D=&AI<RT^=FYO=&4R<VEF*"1C;VYT96YT*3L*("`@
M("`@("`@("`@)&-O;G1E;G0@/2!B87-E-C1?96YC;V1E*"1C;VYT96YT*3L*
M("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@)W-I9B]N;W1E)SL*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!I9B`H1$5"54=,3T=?
M24-!3$5.1$%21$%402D@>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T
M;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@("`@("`@("`@:68@*"1F<"D@
M>PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L('-E<FEA;&EZ92@D8V]N
M=&5N=%1Y<&4I*3L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B7&YC
M;VYV97)T960@9F]R('-Y;F,T:B!C;&EE;G0Z("1C;VYT96YT5'EP95QN(BD[
M"B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@8F%S938T7V1E8V]D92@D
M8V]N=&5N="D@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&9P
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5C;V1E<R!A('-I9B!X;6P@<W1R:6YG('1O(&%N(&%S<V]C:6%T
M:79E(&%R<F%Y+@H@("`@("H*("`@("`J(%%U:6-K(&AA8VL@=&\@8V]N=F5R
M="!F<F]M('1E>'0O=F-A<F0@86YD('1E>'0O=F-A;&5N9&%R('1O"B`@("`@
M*B!3>6YC-$HG<R!P<F]P<FEE=&5R>2!S:68@9&%T871Y<&5S(&%N9"!V:6-E
M('9E<G-A+B`@1F]R(&1E=&%I;',*("`@("`J(&%B;W5T('1H92!S:68@9F]R
M;6%T('-E92!T:&4@87!P96YD:7@@;V8@=&AE(&1E=F5L;W!E<B!G=6ED92!O
M;@H@("`@("H@=W=W+G-Y;F,T:BYO<F<N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<VEF("!!
M('-I9B!S=')I;F<@;&EK92`\:S$^=C$F9W0[/"]K,3X\:S(^=C(\+VLR/@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%S<V]C(&%R<F%Y(&EN('5T
M9C@@;&EK92!A<G)A>2`H)VLQ)R`]/B`G=C$^)RP@)VLR)R`]/B`G=C(G*3L*
M("`@("`J+PH@("`@9G5N8W1I;VX@<VEF,F%R<F%Y*"1S:68I"B`@("!["B`@
M("`@("`@)'(@/2!A<G)A>2@I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L
M;"@G+SPH6UX^72HI/BA;7CQ=*BD\7"]<,3XO<VDG+"`D<VEF+"`D;6%T8VAE
M<RP@4%)%1U]3151?3U)$15(I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M
M871C:&5S(&%S("1M871C:"D@>PH@("`@("`@("`@("`@("`@)');)&UA=&-H
M6S%=72`](&AT;6Q?96YT:71Y7V1E8V]D92@D;6%T8VA;,ETI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<CL*("`@('T*"B`@
M("`O*BH*("`@("`J($5N8V]D97,@86X@87-S;V,N(&%R<F%Y('1O('-I9B!X
M;6P*("`@("`J"B`@("`@*B!1=6EC:R!H86-K('1O(&-O;G9E<G0@9G)O;2!T
M97AT+W9C87)D(&%N9"!T97AT+W9C86QE;F1A<B!T;PH@("`@("H@4WEN8S1*
M)W,@<')O<')I971E<GD@<VEF(&1A=&%T>7!E<R!A;F0@=FEC92!V97)S82X@
M($9O<B!D971A:6QS"B`@("`@*B!A8F]U="!T:&4@<VEF(&9O<FUA="!S964@
M=&AE(&%P<&5N9&EX(&]F('1H92!D979E;&]P97(@9W5I9&4@;VX*("`@("`J
M('=W=RYS>6YC-&HN;W)G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D87)R87D@($%N(&%S<V]C
M(&%R<F%Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5S
M=6QT:6YG(%A-3"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%R<F%Y
M,G-I9B@D87)R87DL("1P<F4])R<L("1P;W-T/2<G*0H@("`@>PH@("`@("`@
M("1S96%R8V@@/2!A<G)A>2@G/"<L("<^)RD["B`@("`@("`@)')E<&QA8V4@
M/2!A<G)A>2@G)FQT.R<L("<F9W0[)RD["@H@("`@("`@("1R(#T@)'!R93L*
M("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@)'(@+CT@)SPG("X@)&ME>2`N("<^)R`N"B`@("`@("`@
M("`@("`@("!S=')?<F5P;&%C92@D<V5A<F-H+"`D<F5P;&%C92P@)'9A;'5E
M*2`N"B`@("`@("`@("`@("`@("`G/"\G("X@)&ME>2`N("<^)SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<B`N("1P;W-T.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-I9C)V;F]T92@D<VEF*0H@("`@>PH@("`@("`@("1A(#T@)'1H
M:7,M/G-I9C)A<G)A>2@D<VEF*3L*"B`@("`@("`@)&E#86P@/2`F;F5W($AO
M<F1E7VE#86QE;F1A<B@I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H
M)U9%4E-)3TXG+"`G,2XQ)RD["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T
M92@G4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T+R]-;F5M;R`O+T5.
M)RD["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G34542$]$)RP@)U!5
M0DQ)4T@G*3L*"B`@("`@("`@)'9N;W1E(#T@)DAO<F1E7VE#86QE;F1A<CHZ
M;F5W0V]M<&]N96YT*"=V;F]T92<L("1I0V%L*3L*("`@("`@("`D=FYO=&4M
M/G-E=$%T=')I8G5T92@G0D]$62<L(&ES<V5T*"1A6R=";V1Y)UTI(#\@)&%;
M)T)O9'DG72`Z("<G*3L*"B`@("`@("`@<F5T=7)N("1V;F]T92T^97AP;W)T
M=D-A;&5N9&%R*"D["B`@("!]"@H@("`@9G5N8W1I;VX@<VEF,G9C87)D*"1S
M:68I"B`@("!["B`@("`@("`@)&$@/2`D=&AI<RT^<VEF,F%R<F%Y*"1S:68I
M.PH*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@
M("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G5D524TE/3B<L("<R+C$G*3L*
M("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=04D]$240G+"`G+2\O5&AE
M($AO<F1E(%!R;VIE8W0O+TUN96UO("\O14XG*3L*("`@("`@("`D:4-A;"T^
M<V5T071T<FEB=71E*"=-151(3T0G+"`G4%5"3$E32"<I.PH*("`@("`@("`D
M=F-A<F0@/2`F2&]R9&5?:4-A;&5N9&%R.CIN97=#;VUP;VYE;G0H)W9C87)D
M)RP@)&E#86PI.PH*("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G1DXG
M+"`D85LG1FEL94%S)UTI.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E
M*"=.24-+3D%-12<L("1A6R=.:6-K3F%M92==*3L*("`@("`@("`D=F-A<F0M
M/G-E=$%T=')I8G5T92@G5$5,)RP@)&%;)TAO;65496QE<&AO;F5.=6UB97(G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G5%E012<]
M/B=(3TU%)RDI.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=414PG
M+"`D85LG0G5S:6YE<W-496QE<&AO;F5.=6UB97(G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G5%E012<]/B=73U)+)RDI.PH@("`@
M("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=414PG+"`D85LG36]B:6QE5&5L
M97!H;VYE3G5M8F5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)U194$4G/3XG0T5,3"<I*3L*("`@("`@("`D=F-A<F0M/G-E=$%T
M=')I8G5T92@G5$5,)RP@)&%;)T)U<VEN97-S1F%X3G5M8F5R)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)U194$4G/3XG1D%8)RDI
M.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=%34%)3"<L("1A6R=%
M;6%I;#%!9&1R97-S)UTI.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E
M*"=4251,12<L("1A6R=*;V)4:71L92==*3L*("`@("`@("`D=F-A<F0M/G-E
M=$%T=')I8G5T92@G3U)')RP@)&%;)T-O;7!A;GE.86UE)UTI.PH@("`@("`@
M("1V8V%R9"T^<V5T071T<FEB=71E*"=.3U1%)RP@)&%;)T)O9'DG72D["B`@
M("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)U523"<L("1A6R=796)086=E
M)UTI.PH*("`@("`@("`D=B`](&%R<F%Y*`H@("`@("`@("`@("!60T%21%].
M7T9!34E,62`@("`@(#T^("1A6R=,87-T3F%M92==+`H@("`@("`@("`@("!6
M0T%21%].7T=)5D5.("`@("`@(#T^("1A6R=&:7)S=$YA;64G72P*("`@("`@
M("`@("`@5D-!4D1?3E]!1$1,("`@("`@("`]/B`D85LG36ED9&QE3F%M92==
M+`H@("`@("`@("`@("!60T%21%].7U!2149)6"`@("`@(#T^("1A6R=4:71L
M92==+`H@("`@("`@("`@("!60T%21%].7U-51D9)6"`@("`@(#T^("1A6R=3
M=69F:7@G70H@("`@("`@("D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U
M=&4H)TXG+"!I;7!L;V1E*"<[)RP@)'8I+"!A<G)A>2@I+"!F86QS92P@)'8I
M.PH*("`@("`@("`D=B`](&%R<F%Y*`H@("`@("`@("`@("!60T%21%]!1%)?
M4$]"("`@("`@("`@("`]/B`D85LG2&]M94%D9')E<W-0;W-T3V9F:6-E0F]X
M)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]%6%1%3D0@("`@("`@(#T^("<G
M+`H@("`@("`@("`@("!60T%21%]!1%)?4U121454("`@("`@("`]/B`D85LG
M2&]M94%D9')E<W-3=')E970G72P*("`@("`@("`@("`@5D-!4D1?04127TQ/
M0T%,2519("`@("`@/3X@)&%;)TAO;65!9&1R97-S0VET>2==+`H@("`@("`@
M("`@("!60T%21%]!1%)?4D5'24].("`@("`@("`]/B`D85LG2&]M94%D9')E
M<W-3=&%T92==+`H@("`@("`@("`@("!60T%21%]!1%)?4$]35$-/1$4@("`@
M("`]/B`D85LG2&]M94%D9')E<W-0;W-T86Q#;V1E)UTL"B`@("`@("`@("`@
M(%9#05)$7T%$4E]#3U5.5%)9("`@("`@(#T^("1A6R=(;VUE061D<F5S<T-O
M=6YT<GDG72P*("`@("`@("`I.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB
M=71E*"=!1%(G+"!I;7!L;V1E*"<[)RP@)'8I+"!A<G)A>2@G5%E012<@/3X@
M)TA/344G("DL('1R=64L("1V*3L*"B`@("`@("`@)'8@/2!A<G)A>2@*("`@
M("`@("`@("`@5D-!4D1?04127U!/0B`@("`@("`@("`@/3X@)&%;)T)U<VEN
M97-S061D<F5S<U!O<W1/9F9I8V5";W@G72P*("`@("`@("`@("`@5D-!4D1?
M04127T585$5.1"`@("`@("`@/3X@)R<L"B`@("`@("`@("`@(%9#05)$7T%$
M4E]35%)%150@("`@("`@(#T^("1A6R="=7-I;F5S<T%D9')E<W-3=')E970G
M72P*("`@("`@("`@("`@5D-!4D1?04127TQ/0T%,2519("`@("`@/3X@)&%;
M)T)U<VEN97-S061D<F5S<T-I='DG72P*("`@("`@("`@("`@5D-!4D1?0412
M7U)%1TE/3B`@("`@("`@/3X@)&%;)T)U<VEN97-S061D<F5S<U-T871E)UTL
M"B`@("`@("`@("`@(%9#05)$7T%$4E]03U-40T]$12`@("`@(#T^("1A6R="
M=7-I;F5S<T%D9')E<W-0;W-T86Q#;V1E)UTL"B`@("`@("`@("`@(%9#05)$
M7T%$4E]#3U5.5%)9("`@("`@(#T^("1A6R="=7-I;F5S<T%D9')E<W-#;W5N
M=')Y)UTL"B`@("`@("`@*3L*"B`@("`@("`@)'9C87)D+3YS971!='1R:6)U
M=&4H)T%$4B<L(&EM<&QO9&4H)SLG+"`D=BDL(&%R<F%Y*"=465!%)R`]/B`G
M5T]22R<@*2P@=')U92P@)'8I.PH*("`@("`@("!R971U<FX@)'9C87)D+3YE
M>'!O<G1V0V%L96YD87(H*3L*("`@('T*"B`@("!F=6YC=&EO;B!S:68R=F5V
M96YT*"1S:68I"B`@("!["B`@("`@("`@)&$@/2`D=&AI<RT^<VEF,F%R<F%Y
M*"1S:68I.PH*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R
M*"D["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G5D524TE/3B<L("<Q
M+C`G*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=04D]$240G+"`G
M+2\O5&AE($AO<F1E(%!R;VIE8W0O+TUN96UO("\O14XG*3L*("`@("`@("`D
M:4-A;"T^<V5T071T<FEB=71E*"=-151(3T0G+"`G4%5"3$E32"<I.PH*("`@
M("`@("`D=D5V96YT(#T@)DAO<F1E7VE#86QE;F1A<CHZ;F5W0V]M<&]N96YT
M*"=V979E;G0G+"`D:4-A;"D["@H@("`@("`@(&EF("@D85LG06QL1&%Y179E
M;G0G72`]/2`G5')U92<I('L*("`@("`@("`@("`@)'0@/2`D:4-A;"T^7W!A
M<G-E1&%T951I;64H)&%;)U-T87)T)UTI.PH@("`@("`@("`@("`D=D5V96YT
M+3YS971!='1R:6)U=&4H)T144U1!4E0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)WEE87(G(#T^(&1A=&4H)UDG+"`D="DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6]N
M=&@G(#T^(&1A=&4H)VTG+"`D="DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;61A>2<@/3X@9&%T92@G9"<L)'0I*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=604Q512<@
M/3X@)T1!5$4G*2D["B`@("`@("`@("`@("1T(#T@)&E#86PM/E]P87)S941A
M=&54:6UE*"1A6R=%;F0G72D["B`@("`@("`@("`@("1V179E;G0M/G-E=$%T
M=')I8G5T92@G1%1%3D0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)WEE87(G(#T^(&1A=&4H)UDG+"`D="DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6]N=&@G(#T^(&1A
M=&4H)VTG+"`D="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;61A>2<@/3X@9&%T92@G9"<L)'0I*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=604Q512<@/3X@)T1!5$4G
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9%=F5N="T^<V5T
M071T<FEB=71E*"=$5%-405)4)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I0V%L+3Y?<&%R<V5$871E5&EM92@D85LG4W1A<G0G72DI
M.PH@("`@("`@("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)T1414Y$)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I0V%L+3Y?<&%R
M<V5$871E5&EM92@D85LG16YD)UTI*3L*("`@("`@("!]"@H@("`@("`@("1V
M179E;G0M/G-E=$%T=')I8G5T92@G1%135$%-4"<L('1I;64H*2D["B`@("`@
M("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=354U-05)9)RP@)&%;)U-U8FIE
M8W0G72D["B`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=$15-#4DE0
M5$E/3B<L("1A6R=";V1Y)UTI.PH@("`@("`@("\O("1V179E;G0M/G-E=$%T
M=')I8G5T92@G0T%414=/4DE%4R<L("1A6R<G72D["B`@("`@("`@)'9%=F5N
M="T^<V5T071T<FEB=71E*"=,3T-!5$E/3B<L("1A6R=,;V-A=&EO;B==*3L*
M"B`@("`@("`@<F5T=7)N("1V179E;G0M/F5X<&]R='9#86QE;F1A<B@I.PH@
M("`@?0H*("`@(&9U;F-T:6]N('-I9C)V=&]D;R@D<VEF*0H@("`@>PH@("`@
M("`@("1A(#T@)'1H:7,M/G-I9C)A<G)A>2@D<VEF*3L*"B`@("`@("`@)&E#
M86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@("1I0V%L+3YS
M971!='1R:6)U=&4H)U9%4E-)3TXG+"`G,2XP)RD["B`@("`@("`@)&E#86PM
M/G-E=$%T=')I8G5T92@G4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T
M+R]-;F5M;R`O+T5.)RD["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G
M34542$]$)RP@)U!50DQ)4T@G*3L*"B`@("`@("`@)'9T;V1O(#T@)DAO<F1E
M7VE#86QE;F1A<CHZ;F5W0V]M<&]N96YT*"=V=&]D;R<L("1I0V%L*3L*"B`@
M("`@("`@)'9T;V1O+3YS971!='1R:6)U=&4H)U-534U!4EDG+"`D85LG4W5B
M:F5C="==*3L*("`@("`@("`D=G1O9&\M/G-E=$%T=')I8G5T92@G1$530U))
M4%1)3TXG+"`D85LG0F]D>2==*3L*("`@("`@("!I9B`H)&%;)TEM<&]R=&%N
M8V4G72`]/2`P*2!["B`@("`@("`@("`@("1V=&]D;RT^<V5T071T<FEB=71E
M*"=04DE/4DE462<L(#4I.PH@("`@("`@('T@96QS96EF("@D85LG26UP;W)T
M86YC92==(#T](#(I('L*("`@("`@("`@("`@)'9T;V1O+3YS971!='1R:6)U
M=&4H)U!224]22519)RP@,2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'9T;V1O+3YS971!='1R:6)U=&4H)U!224]22519)RP@,RD["B`@("`@
M("`@?0H@("`@("`@(&EF("@D85LG1'5E1&%T92==("$]("<T-3`P,3(S,50R
M,S`P,#!:)RD@>PH@("`@("`@("`@("`D=G1O9&\M/G-E=$%T=')I8G5T92@G
M1%5%)RP@)&E#86PM/E]P87)S941A=&54:6UE*"1A6R=$=65$871E)UTI*3L*
M("`@("`@("!]"B`@("`@("`@)'9T;V1O+3YS971!='1R:6)U=&4H)T-/35!,
M151%1"<L("1A6R=#;VUP;&5T92==(#T]("=4<G5E)R`_(#$@.B`P*3L*"B`@
M("`@("`@<F5T=7)N("1V=&]D;RT^97AP;W)T=D-A;&5N9&%R*"D["B`@("!]
M"@H@("`@9G5N8W1I;VX@=FYO=&4R<VEF*"1V;F]T92D*("`@('L*("`@("`@
M("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@("`@("`@:68@
M*"$D:4-A;"T^<&%R<V5V0V%L96YD87(H)'9N;W1E*2D@>PH@("`@("`@("`@
M("!D:64H(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$N
M(BD["B`@("`@("`@?0H*("`@("`@("`D8V]M<&]N96YT<R`]("1I0V%L+3YG
M971#;VUP;VYE;G1S*"D["@H@("`@("`@('-W:71C:"`H8V]U;G0H)&-O;7!O
M;F5N=',I*2!["B`@("`@("`@8V%S92`P.@H@("`@("`@("`@("!D:64H(DYO
M(&1A=&$@=V%S(&9O=6YD+B(I.PH*("`@("`@("!C87-E(#$Z"B`@("`@("`@
M("`@("1C;VYT96YT(#T@)&-O;7!O;F5N='-;,%T["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!D:64H(DUU;'1I
M<&QE(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE(&ES('-U<'!O<G1E9"XB
M*3L*("`@("`@("!]"@H@("`@("`@("1A(#T@87)R87DH)T)O9'DG(#T^("1C
M;VYT96YT+3YG971!='1R:6)U=&4H)T)/1%DG*2D["@H@("`@("`@(')E='5R
M;B`D=&AI<RT^87)R87DR<VEF*`H@("`@("`@("`@("`D82P*("`@("`@("`@
M("`@)SP_>&UL('9E<G-I;VX](C$N,"(_/CQN;W1E/B<L"B`@("`@("`@("`@
M("<\0V%T96=O<FEE<SX\+T-A=&5G;W)I97,^)PH@("`@("`@("`@("`N("<\
M4W5B:F5C=#X\+U-U8FIE8W0^/$-O;&]R/CPO0V]L;W(^/$AE:6=H=#X\+TAE
M:6=H=#X\5VED=&@^/"]7:61T:#X\3&5F=#X\+TQE9G0^/%1O<#X\+U1O<#XG
M"B`@("`@("`@("`@("X@)SPO;F]T93XG*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!V8V%R9#)S:68H)'9C87)D*0H@("`@>PH@("`@("`@("1I0V%L(#T@)FYE
M=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21I0V%L+3YP87)S
M979#86QE;F1A<B@D=F-A<F0I*2!["B`@("`@("`@("`@(&1I92@B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T82XB*3L*("`@("`@("!]
M"@H@("`@("`@("1C;VUP;VYE;G1S(#T@)&E#86PM/F=E=$-O;7!O;F5N=',H
M*3L*"B`@("`@("`@<W=I=&-H("AC;W5N="@D8V]M<&]N96YT<RDI('L*("`@
M("`@("!C87-E(#`Z"B`@("`@("`@("`@(&1I92@B3F\@9&%T82!W87,@9F]U
M;F0N(BD["@H@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@)&-O;G1E;G0@
M/2`D8V]M<&]N96YT<ULP73L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(&1I92@B375L=&EP;&4@8V]M<&]N96YT
M<R!F;W5N9#L@;VYL>2!O;F4@:7,@<W5P<&]R=&5D+B(I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@9G)O;2!H97)E(&]N+"!T:&4@8V]D92!I<R!T86ME;B!F
M<F]M"B`@("`@("`@+R\@5'5R8F%?1')I=F5R.CIT;TAA<V@L('8@,2XV-2`R
M,#`U+S`S+S$R"B`@("`@("`@+R\@86YD(&UO9&EF:65D(&9O<B!T:&4@4WEN
M8S1*(&%T=')I8G5T92!N86UE<RX*("`@("`@("`D871T<B`]("1C;VYT96YT
M+3YG971!;&Q!='1R:6)U=&5S*"D["B`@("`@("`@9F]R96%C:"`H)&%T='(@
M87,@)&ET96TI('L*("`@("`@("`@("`@<W=I=&-H("@D:71E;5LG;F%M92==
M*2!["B`@("`@("`@("`@(&-A<V4@)T9.)SH*("`@("`@("`@("`@("`@("1H
M87-H6R=&:6QE07,G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=.)SH*("`@("`@("`@("`@
M("`@("1N86UE(#T@)&ET96U;)W9A;'5E<R==.PH@("`@("`@("`@("`@("`@
M)&AA<VA;)TQA<W1.86UE)UT@/2`D;F%M95M60T%21%].7T9!34E,65T["B`@
M("`@("`@("`@("`@("`D:&%S:%LG1FER<W1.86UE)UT@/2`D;F%M95M60T%2
M1%].7T=)5D5.73L*("`@("`@("`@("`@("`@("1H87-H6R=-:61D;&5.86UE
M)UT@/2`D;F%M95M60T%21%].7T%$1$Q=.PH@("`@("`@("`@("`@("`@)&AA
M<VA;)U1I=&QE)UT@/2`D;F%M95M60T%21%].7U!2149)6%T["B`@("`@("`@
M("`@("`@("`D:&%S:%LG4W5F9FEX)UT@/2`D;F%M95M60T%21%].7U-51D9)
M6%T["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)TY)0TM.04U%)SH*("`@("`@("`@("`@("`@("1H87-H6R=.:6-K3F%M92==
M(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("\O($9O<B!V0V%R9"`S+C`N"B`@("`@("`@("`@(&-A<V4@
M)T%$4B<Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M
M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D:71E;5LG<&%R86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UT@/2!A<G)A>2@D
M:71E;5LG<&%R86US)UU;)U194$4G72D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D:71E;5LG<&%R86US)UU;)U194$4G72`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG5T]22R==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;
M)U194$4G75M=(#T@)U=/4DLG.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=(
M3TU%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M6R=P87)A
M;7,G75LG5%E012==6UT@/2`G2$]-12<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1A9&1R97-S
M(#T@)&ET96U;)W9A;'5E<R==.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&ET96U;)W!A<F%M<R==6R=465!%)UT@87,@)&%D<BD@>PH@("`@("`@("`@
M("`@("`@("`@('-W:71C:"`H4W1R:6YG.CIU<'!E<B@D861R*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)TA/344G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`D<')E9FEX(#T@)TAO;65!9&1R97-S)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)U=/4DLG.@H@("`@("`@("`@("`@("`@("`@("`@("`D<')E9FEX(#T@)U=O
M<FM!9&1R97-S)SL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5F:7@@/2`G2&]M94%D9')E<W,G.PH@("`@("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@:68@*"1P<F5F:7@I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N("=3=')E
M970G72`](&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]35%)%151=*2`_("1A
M9&1R97-S6U9#05)$7T%$4E]35%)%151=(#H@;G5L;#L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N("=#:71Y)UT@/2!I<W-E="@D
M861D<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=*2`_("1A9&1R97-S6U9#05)$
M7T%$4E],3T-!3$E465T@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D:&%S:%LD<')E9FEX("X@)U-T871E)UT@/2!I<W-E="@D861D<F5S<UM6
M0T%21%]!1%)?4D5'24].72D@/R`D861D<F5S<UM60T%21%]!1%)?4D5'24].
M72`Z(&YU;&P["B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F
M:7@@+B`G4&]S=&%L0V]D92==(#T@:7-S970H)&%D9')E<W-;5D-!4D1?0412
M7U!/4U1#3T1%72D@/R`D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=(#H@
M;G5L;#L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N
M("=#;W5N=')Y)UT@/2!I<W-E="@D861D<F5S<UM60T%21%]!1%)?0T]53E12
M65TI(#\@)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=(#H@;G5L;#L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N("=0;W-T3V9F
M:6-E0F]X)UT@/2!I<W-E="@D861D<F5S<UM60T%21%]!1%)?4$]"72D@/R`D
M861D<F5S<UM60T%21%]!1%)?4$]"72`Z(&YU;&P["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=414PG.@H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG1D%8)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&AA<VA;)T)U<VEN97-S1F%X3G5M8F5R)UT@/2`D:71E
M;5LG=F%L=64G73L*("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D
M:71E;5LG<&%R86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1I=&5M6R=P87)A;7,G75LG5%E012==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;)U194$4G
M72`](&%R<F%Y*"1I=&5M6R=P87)A;7,G75LG5%E012==*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@1F]R('9#87)D
M(#,N,"X*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:71E;5LG<&%R
M86US)UU;)U194$4G72!A<R`D=&5L*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("A3=')I;F<Z.G5P<&5R*"1T96PI(#T]("=73U)+)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)T)U<VEN97-S5&5L97!H
M;VYE3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*%-T<FEN9SHZ=7!P97(H)'1E;"D@/3T@)TA/
M344G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LG2&]M
M951E;&5P:&]N94YU;6)E<B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("A3=')I;F<Z.G5P<&5R*"1T96PI
M(#T]("=#14Q,)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AA
M<VA;)TUO8FEL951E;&5P:&]N94YU;6)E<B==(#T@)&ET96U;)W9A;'5E)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("A3=')I;F<Z.G5P
M<&5R*"1T96PI(#T]("=&05@G*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:&%S:%LG0G5S:6YE<W-&87A.=6UB97(G72`]("1I=&5M6R=V86QU
M92==.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=(3TU%)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R=(;VUE5&5L97!H;VYE
M3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=73U)+)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R="=7-I;F5S<U1E;&5P
M:&]N94YU;6)E<B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG0T5,3"==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LG36]B:6QE5&5L
M97!H;VYE3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S
M:%LG2&]M951E;&5P:&]N94YU;6)E<B==(#T@)&ET96U;)W9A;'5E)UT["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=%34%)3"<Z"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=04D5&
M)UTI('Q\("%I<W-E="@D:&%S:%LG96UA:6PG72DI('L*("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG16UA:6PQ061D<F5S<R==(#T@2&]R9&5?:4-A;&5N
M9&%R7W9C87)D.CIG971"87)E16UA:6PH)&ET96U;)W9A;'5E)UTI.PH@("`@
M("`@("`@("`@("`@("`@("1H87-H6R=%;6%I;#%!9&1R97-S5'EP92==(#T@
M)U--5%`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=4251,12<Z"B`@("`@("`@("`@("`@
M("`D:&%S:%LG2F]B5&ET;&4G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=/4D<G.@H@("`@
M("`@("`@("`@("`@)&AA<VA;)T-O;7!A;GE.86UE)UT@/2`D:71E;5LG=F%L
M=64G73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G3D]412<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG0F]D>2==(#T@)&ET
M96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)U523"<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG5V5B4&%G
M92==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YA<G)A>3)S:68H"B`@("`@("`@("`@("1H87-H+`H@("`@("`@("`@("`G
M/#]X;6P@=F5R<VEO;CTB,2XP(C\^/&-O;G1A8W0^)RP*("`@("`@("`@("`@
M)SPO8V]N=&%C=#XG*3L*("`@('T*"B`@("!F=6YC=&EO;B!V979E;G0R<VEF
M*"1V8V%R9"D*("`@('L*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A
M;&5N9&%R*"D["B`@("`@("`@:68@*"$D:4-A;"T^<&%R<V5V0V%L96YD87(H
M)'9C87)D*2D@>PH@("`@("`@("`@("!D:64H(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&1A=&$N(BD["B`@("`@("`@?0H*("`@("`@("`D
M8V]M<&]N96YT<R`]("1I0V%L+3YG971#;VUP;VYE;G1S*"D["@H@("`@("`@
M('-W:71C:"`H8V]U;G0H)&-O;7!O;F5N=',I*2!["B`@("`@("`@8V%S92`P
M.@H@("`@("`@("`@("!D:64H(DYO(&1A=&$@=V%S(&9O=6YD+B(I.PH*("`@
M("`@("!C87-E(#$Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)&-O;7!O;F5N
M='-;,%T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("!D:64H(DUU;'1I<&QE(&-O;7!O;F5N=',@9F]U;F0[(&]N
M;'D@;VYE(&ES('-U<'!O<G1E9"XB*3L*("`@("`@("!]"@H@("`@("`@("\O
M($ES('1H97)E(&$@<F5A;"!N965D('1O('!R;W9I9&4@=&AE(&-O<G)E8W0@
M=F%L=64_"B`@("`@("`@)&1U<F%T:6]N(#T@,#L*"B`@("`@("`@)&%T='(@
M/2`D8V]N=&5N="T^9V5T06QL071T<FEB=71E<R@I.PH@("`@("`@(&9O<F5A
M8V@@*"1A='1R(&%S("1I=&5M*2!["B`@("`@("`@("`@('-W:71C:"`H)&ET
M96U;)VYA;64G72D@>PH@("`@("`@("`@("!C87-E("=$5%-405)4)SH*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&ET96U;)W!A<F%M<R==6R=604Q5
M12==*2`F)B`D:71E;5LG<&%R86US)UU;)U9!3%5%)UT@/3T@(D1!5$4B*2![
M"B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)T%L;$1A>45V96YT)UT@/2`B
M5')U92(["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)U-T87)T)UT@/2!(
M;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG=F%L=64G
M72D["B`@("`@("`@("`@("`@("`@("`@)&1U<F%T:6]N(#T@,30T,#L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AA
M<VA;)T%L;$1A>45V96YT)UT@/2`B1F%L<V4B.PH@("`@("`@("`@("`@("`@
M("`@("1H87-H6R=3=&%R="==(#T@2&]R9&5?:4-A;&5N9&%R.CI?97AP;W)T
M1&%T951I;64H)&ET96U;)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=$5$5.
M1"<Z"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I=&5M6R=P87)A;7,G
M75LG5D%,544G72D@)B8@)&ET96U;)W!A<F%M<R==6R=604Q512==(#T](")$
M051%(BD@>PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=!;&Q$87E%=F5N
M="==(#T@(E1R=64B.PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=%;F0G
M72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A=&54:6UE*"1I=&5M6R=V
M86QU92==*3L*("`@("`@("`@("`@("`@("`@("`D9'5R871I;VX@/2`Q-#0P
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D:&%S:%LG06QL1&%Y179E;G0G72`](")&86QS92(["B`@("`@("`@("`@
M("`@("`@("`@)&AA<VA;)T5N9"==(#T@2&]R9&5?:4-A;&5N9&%R.CI?97AP
M;W)T1&%T951I;64H)&ET96U;)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=3
M54U-05)9)SH*("`@("`@("`@("`@("`@("1H87-H6R=3=6)J96-T)UT@/2`D
M:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G1$530U))4%1)3TXG.@H@("`@("`@("`@("`@("`@)&AA
M<VA;)T)O9'DG72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=,3T-!5$E/3B<Z"B`@("`@("`@
M("`@("`@("`D:&%S:%LG3&]C871I;VXG72`]("1I=&5M6R=V86QU92==.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^87)R87DR<VEF*`H@("`@("`@("`@
M("`D:&%S:"P*("`@("`@("`@("`@)SP_>&UL('9E<G-I;VX](C$N,"(_/CQA
M<'!O:6YT;65N=#X\1'5R871I;VX^)PH@("`@("`@("`@("`N("1D=7)A=&EO
M;B`N("<\+T1U<F%T:6]N/B<L"B`@("`@("`@("`@("<\27-296-U<G)I;F<^
M1F%L<V4\+TES4F5C=7)R:6YG/CQ-965T:6YG4W1A='5S/C`\+TUE971I;F=3
M=&%T=7,^/$)U<WE3=&%T=7,^,CPO0G5S>5-T871U<SX\+V%P<&]I;G1M96YT
M/B<I.PH@("`@?0H*("`@(&9U;F-T:6]N('9T;V1O,G-I9B@D=F-A<F0I"B`@
M("!["B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@
M("`@("`@(&EF("@A)&E#86PM/G!A<G-E=D-A;&5N9&%R*"1V8V%R9"DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$N)RD["B`@("`@("`@?0H*
M("`@("`@("`D8V]M<&]N96YT<R`]("1I0V%L+3YG971#;VUP;VYE;G1S*"D[
M"@H@("`@("`@('-W:71C:"`H8V]U;G0H)&-O;7!O;F5N=',I*2!["B`@("`@
M("`@8V%S92`P.@H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G3F\@9&%T82!W87,@9F]U;F0G*3L*"B`@("`@("`@8V%S92`Q.@H@("`@
M("`@("`@("`D8V]N=&5N="`]("1C;VUP;VYE;G1S6S!=.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)TUU;'1I<&QE(&-O;7!O;F5N=',@9F]U;F0[
M(&]N;'D@;VYE(&ES('-U<'!O<G1E9"XG*3L*("`@("`@("!]"@H@("`@("`@
M("1H87-H6R=#;VUP;&5T92==(#T@)T9A;'-E)SL*("`@("`@("`O+R!/=71L
M;V]K)W,@9&5F875L="!F;W(@;F\@9'5E(&1A=&4*("`@("`@("`D:&%S:%LG
M1'5E1&%T92==(#T@)S0U,#`Q,C,Q5#(S,#`P,%HG.PH*("`@("`@("`D871T
M<B`]("1C;VYT96YT+3YG971!;&Q!='1R:6)U=&5S*"D["B`@("`@("`@9F]R
M96%C:"`H)&%T='(@87,@)&ET96TI('L*("`@("`@("`@("`@<W=I=&-H("@D
M:71E;5LG;F%M92==*2!["B`@("`@("`@("`@(&-A<V4@)T1512<Z"B`@("`@
M("`@("`@("`@("`D:&%S:%LG1'5E1&%T92==(#T@2&]R9&5?:4-A;&5N9&%R
M.CI?97AP;W)T1&%T951I;64H)&ET96U;)W9A;'5E)UTI.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=354U-05)9)SH*("`@
M("`@("`@("`@("`@("1H87-H6R=3=6)J96-T)UT@/2`D:71E;5LG=F%L=64G
M73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M1$530U))4%1)3TXG.@H@("`@("`@("`@("`@("`@)&AA<VA;)T)O9'DG72`]
M("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=04DE/4DE462<Z"B`@("`@("`@("`@("`@("!I9B`H
M)&ET96U;)W9A;'5E)UT@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("1H
M87-H6R=);7!O<G1A;F-E)UT@/2`R.PH@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1I=&5M6R=V86QU92==(#T](#4I('L*("`@("`@("`@("`@("`@("`@
M("`D:&%S:%LG26UP;W)T86YC92==(#T@,#L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TEM<&]R=&%N8V4G
M72`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)T-/35!,151%1"<Z"B`@("`@("`@("`@
M("`@("`D:&%S:%LG0V]M<&QE=&4G72`]("1I=&5M6R=V86QU92==(#\@)U1R
M=64G(#H@)T9A;'-E)SL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/F%R<F%Y
M,G-I9B@*("`@("`@("`@("`@)&AA<V@L"B`@("`@("`@("`@("<\/WAM;"!V
M97)S:6]N/2(Q+C`B/SX\=&%S:SXG+`H@("`@("`@("`@("`G/"]T87-K/B<I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]3>6YC34PO1&5V:6-E+U`X,#`N<&AP````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3,T-3(`,3`U,34T,S$P-C``,#(P-C8S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!0.#`P+U`Y,#`O4#DQ,#H*("H@+2TM+2TM+2TM+2TM+2TM"B`J($-H87)S
M970Z"B`J(%1H:7,@9&5V:6-E(&ES(&%B;&4@=&\@:&%N9&QE(%541BTX(&%N
M9"!S96YD<R!I=',@6$U,('!A8VMA9V5S(&EN(%541C@N"B`J($AO=V5V97(@
M979E;B!T:&]U9V@@=&AE(%A-3"!I='-E;&8@:7,@551&+3@L(&ET(&5X<&5C
M=',@=&AE(&5N8VQO<V5D"B`J('9C87)D+61A=&$@=&\@8F4@25-/+3@X-3DM
M,2!U;FQE<W,@97AP;&EC:71L>2!S=&%T960@;W1H97)W:7-E("AU<VEN9R!T
M:&4*("H@0TA!4E-%5"!O<'1I;VXL('=H:6-H(&ES(&1E<')E8V%T960@9F]R
M(%9#05)$(#,N,"D*("H*("H@16YC;V1I;F<Z"B`J(%-T<FEN9R!V86QU97,@
M87)E(&5N8V]D960@(E%53U1%1"U04DE.5$%"3$4B"B`J"B`J($]T:&5R.@H@
M*B!4:&ES(&1E=FEC97,@:&%N9&QE<R!T87-K<R!A;F0@979E;G1S(&EN(&]N
M92!D871A8F%S92X*("H*("H@07,@=&AE(%`X,#`@=V%S('1H92!F:7)S="!D
M979I8V4@=&\@=V]R:R!W:71H('!A8VMA9V4L(&UO<W0@;V8@=&AE"B`J(')E
M<75I<F5D(&-O;G9E<G-I;VYS(&%R92!I;B!$979I8V4N<&AP)W,@9&5F875L
M="!H86YD;&EN9RX*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!+87)S=&5N
M($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO1&5V:6-E+U`X
M,#`N<&AP+'8@,2XW+C(N-2`R,#`V+S`U+S`Q(#$R.C`U.C$T(&IA;B!%>'`@
M)`H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO
M<F1E+F]R9SX*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?
M1&5V:6-E7U`X,#`@97AT96YD<R!3>6YC34Q?1&5V:6-E('L*"B`@("`O*BH*
M("`@("`J($-O;G9E<G0@=&AE(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0W5R
M<F5N=&QY('-T<FEP<R!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A
M<R!C;&EE;G0@86YD"B`@("`@*B!S97)V97(@;6EG:'0@=7-E(&1I9F9E<F5N
M="!O;F5S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@
M("`@("`@5&AE(&-O;G1E;G0@=&\@8V]N=F5R="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O;G1E;G14>7!E(&]F('1H92!C
M;VYT96YT+@H@("`@("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A
M<G)A>2@D;F5W8V]N=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT
M96YT(&%N9"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*'!O<W-I8FQY(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]N=F5R=$-L:65N=#)397)V97(H)&-O;G1E;G0L
M("1C;VYT96YT5'EP92D*("`@('L*("`@("`@("!L:7-T*"1C;VYT96YT+"`D
M8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@<&%R96YT.CIC;VYV97)T0VQI
M96YT,E-E<G9E<B@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*"B`@("`@("`@
M+RH@4#@P,"!S96YD<R!C871E9V]R:65S(&%S(")8+4-A=&5G;W)Y(BX@4F5M
M;W9E('1H92`B6"TB.B`J+PH@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L
M86-E*"<O*%QR7&Y\7')\7&XI0T%414=/4DE%4SI8+2\G+"`G7#%#051%1T]2
M2453.B<L("1C;VYT96YT+"`Q*3L*"B`@("`@("`@+RH@4#@P,"!S96YD<R!A
M;&P@9&%Y(&5V96YT<R!A<R!S+G1H+B!L:6ME"B`@("`@("`@("H@1%135$%2
M5#HR,#`U,#4P-50P,#`P,#!:7DT*("`@("`@("`@*B!$5$5.1#HR,#`U,#4P
M-50R-#`P,#!:7DT*("`@("`@("`@*B!4:&ES(&ES(&YO(&QO;F=E<B!A;B!A
M;&P@9&%Y(&5V96YT('=H96X@8V]N=F5R=&5D('1O(&QO8V%L('1I;65Z;VYE
M+@H@("`@("`@("`J(%-O(&UA;G5A;&QY(&AA;F1L92!T:&ES+@H@("`@("`@
M("`J("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE$
M5%-405)4.BXJ5#`P,#`P,%HH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N="D*("`@("`@("`@("`@)B8@<')E9U]M871C
M:"@G+RA<<EQN?%QR?%QN*41414Y$.BA<9%QD7&1<9"DH7&1<9"DH7&1<9"E4
M,C0P,#`P6BA<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@("`@)&-O;G1E;G0@/2!P
M<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE$5%-405)4.B@N*BE4,#`P,#`P
M6BA<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B)#%$5%-405)4.U9!3%5%/41!5$4Z)#(D,R(L("1C;VYT96YT
M*3L*("`@("`@("`@("`@+RH@16YD('1I;65S=&%M<"!M=7-T(&)E(&-O;G9E
M<G1E9"!T;R!N97AT(&1A>2=S(&1A=&4N("HO"B`@("`@("`@("`@("1S(#T@
M9&%T92@G66UD)RP@;6MT:6UE*#`L(#`L(#`L("1M6S-=+"`D;5LT72P@)&U;
M,ETI("L@,C0J,S8P,"D["B`@("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R
M97!L86-E*"<O*%QR7&Y\7')\7&XI1%1%3D0Z*"XJ*50R-#`P,#!:*%QR7&Y\
M7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("(D,41414Y$.U9!3%5%/41!5$4Z)',D,R(L("1C;VYT96YT*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("A$14)51TQ/1U])0T%,14Y$05)$051!*2!["B`@
M("`@("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S>6YC+VQO9RYT>'0G+"`G
M82<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("!`
M9G=R:71E*"1F<"P@(EQN:6YP=70@8V]N=F5R=&5D(&9O<B!S97)V97(Z("1C
M;VYT96YT5'EP95QN(BD["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"PD
M8V]N=&5N="`N(")<;B(I.PH@("`@("`@("`@("`@("`@0&9C;&]S92@D9G`I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R
M87DH)&-O;G1E;G0L("1C;VYT96YT5'EP92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!T:&4@8V]N=&5N="!F<F]M('1H92!B86-K96YD('1O
M(&$@9F]R;6%T('-U:71A8FQE(&9O<B!T:&4*("`@("`J(&-L:65N="!D979I
M8V4N"B`@("`@*@H@("`@("H@4W1R:7!S('1H92!U:60@*'!R:6UA<GD@:V5Y
M*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@86YD('-E<G9E<B!M:6=H="!U<V4*
M("`@("`J(&1I9F9E<F5N="!O;F5S+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;G1E;G0@("`@("`@5&AE(&-O;G1E;G0@=&\@8V]N=F5R="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O;G1E
M;G14>7!E(&]F(&-O;G1E;G0@87,@<F5T=7)N960@9G)O;0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8F%C:V5N9"X*("`@("`J
M($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH)&YE=V-O;G1E
M;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A;F0@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP;W-S:6)L>2!C
M:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I
M"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("!L:7-T
M*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@<&%R96YT
M.CIC;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E;G14>7!E
M*3L*"B`@("`@("`@+RH@0V]N=F5R="!A;&P@9&%Y(&5V96YT<RX@*B\*("`@
M("`@("!I9B`H<')E9U]M871C:"@G+RA<<EQN?%QR?%QN*4144U1!4E0[5D%,
M544]1$%413HH7&1[.'TI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;G1E;G0I"B`@("`@("`@("`@("8F('!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<
M;BE$5$5.1#M604Q513U$051%.BA<9%QD7&1<9"DH7&1<9"DH7&1<9"DO)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&TI*2!["B`@
M("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\
M7&XI1%135$%25#M604Q513U$051%.BA<9'LX?2DO)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(B0Q1%135$%25#HD,E0P,#`P,#!:
M(BP@)&-O;G1E;G0I.PH@("`@("`@("`@("`O*B!%;F0@9&%T92!M=7-T(&)E
M(&-O;G9E<G1E9"!T;R!T:6UE<W1A;7`N("HO"B`@("`@("`@("`@("1S(#T@
M9&%T92@G66UD)RP@;6MT:6UE*#`L(#`L(#`L("1M6S-=+"`D;5LT72P@)&U;
M,ETI("T@,C0J,S8P,"D["B`@("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R
M97!L86-E*"<O*%QR7&Y\7')\7&XI1%1%3D0[5D%,544]1$%413HH7&1[.'TI
M+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(D,414
M14Y$.SHD>W-]5#(T,#`P,%HB+"`D8V]N=&5N="D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@
M("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET92@D
M9G`L(")<;F]U='!U="!C;VYV97)T960@9F]R(&-L:65N="`H)&-O;G1E;G14
M>7!E*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L("1C;VYT
M96YT("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D
M8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-O;64@9&5V:6-E<R!L:6ME('1H92!3;VYY($5R:6-S<V]N(%`X,#`O4#DP
M,"]0.3$P(&AA;F1L92!V=&]D;W,@*'1A<VMS*0H@("`@("H@86YD('9E=F5N
M=',@:6X@=&AE('-A;64@(F-A;&5N9&%R(B!S>6YC+@H@("`@("H@5&AI<R!R
M97%U:7)E<R!S<&5C:6%L(&%C=&EO;G,@;VX@;W5R('-I9&4@87,@=V4@<W1O
M<F4@=&AI<R!I;B!D:69F97)E;G0*("`@("`J(&1A=&%B87-E<R`H;F%G(&%N
M9"!K<F]N;VQI=&@I+@H@("`@("H@5&AI<R!F=6YC=&EO;B!C;W5L9"!D:7)E
M8W1L>2!R971U<FX@=')U92!B=70@=')I97,@=&\@8F4@82!B:70@;6]R90H@
M("`@("H@9V5N97)I8R!S;R!I="!M:6=H="!W;W)K(&9O<B!O=&AE<B!P:&]N
M97,@87,@=V5L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE5&%S:W-)
M;D-A;&5N9&%R*"D*("`@('L*("`@("`@("`D9&D@/2`D=&AI<RT^9&5V:6-E
M26YF;R@I.PH*("`@("`@("!I9B`H(65M<'1Y*"1D:2T^7T-40V%P6R=T97AT
M+W@M=F-A;&5N9&%R)UU;)T)%1TE.)UTM/E]686Q%;G5M6R=6159%3E0G72D@
M)B8*("`@("`@("`@("`@(65M<'1Y*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A
M;&5N9&%R)UU;)T)%1TE.)UTM/E]686Q%;G5M6R=65$]$3R==*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!P87)E;G0Z.FAA;F1L951A<VMS26Y#86QE;F1A<B@I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&YE961S0V%T96=O<GE-87!P:6YG*"D*("`@('L*("`@("`@
M("`O+R!0.#`P('5S97,@;G5M97)I8R!C871E9V]R>2!C;V1E<RX*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y
M;F--3"]$979I8V4O4WEN=&AE<VES+G!H<```````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,#8T-P`Q,#4Q-30S,3`V,``P,C(R,S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!3>6YC34Q?1&5V:6-E7U-Y;G1H97-I<SHZ(&-L87-S('!R;W9I9&5S(&9U
M;F-T:6]N86QI='D@=&AA="!I<PH@*B!S<&5C:69I8R!T;R!T:&4@4WEN=&AE
M<VES+F-H(%-Y;F--3"!C;&EE;G1S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--
M3"]$979I8V4O4WEN=&AE<VES+G!H<"QV(#$N,BXR+C4@,C`P-B\P-2\P,2`Q
M,CHP-3HQ-"!J86X@17AP("0*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R
M;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P86-K86=E(%-Y;F--3`H@
M*B\*8VQA<W,@4WEN8TU,7T1E=FEC95]3>6YT:&5S:7,@97AT96YD<R!3>6YC
M34Q?1&5V:6-E('L*"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1H92!C;VYT
M96YT(&9R;VT@=&AE(&)A8VME;F0@=&\@82!F;W)M870@<W5I=&%B;&4@9F]R
M('1H90H@("`@("H@8VQI96YT(&1E=FEC92X*("`@("`J"B`@("`@*B!3=')I
M<',@=&AE('5I9"`H<')I;6%R>2!K97DI(&EN9F]R;6%T:6]N(&%S(&-L:65N
M="!A;F0@<V5R=F5R(&UI9VAT('5S90H@("`@("H@9&EF9F5R96YT(&]N97,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@("!4
M:&4@8V]N=&5N="!T;R!C;VYV97)T"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;VYT96YT5'EP92`@(%1H92!C;VYT96YT5'EP92!O9B!C;VYT96YT(&%S(')E
M='5R;F5D(&9R;VT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AE(&)A8VME;F0*("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@
M("`@("`@87)R87DH)&YE=V-O;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!C;VYV97)T
M960@8V]N=&5N="!A;F0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("AP;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1397)V97(R0VQI96YT*"1C
M;VYT96YT+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@("`@9VQO8F%L("1B
M86-K96YD.PH*("`@("`@("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I
M(#T*("`@("`@("`@("`@<&%R96YT.CIC;VYV97)T4V5R=F5R,D-L:65N="@D
M8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*"@H@("`@("`@("\O(%-O;64@<W!E
M8VEA;"!P<FEO<FET>2!H86YD;&EN9R!I<R!R97%U:7)E9"X@4WEN=&AE<VES
M('5S97,*("`@("`@("`O+R`Q("AH:6=H*2P@,B`H;65D:75M*2P@,RAL;W<I
M+"!A="!L96%S="!F;W(@;7D@=VEN9&]W<R!M;V)I;&4@9&5V:6-E+@H@("`@
M("`@("\O(&-O;G9E<G0@=&AE<V4@=&\@=F%L:60@<')I;W)I='D@<V5T=&EN
M9W,Z"B`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<
M<GQ<;BE04DE/4DE463I;,2TR72A<<EQN?%QR?%QN*2\G+"`G7#%04DE/4DE4
M63HQ7#(G+"`D8V]N=&5N="P@,2D["B`@("`@("`@)&-O;G1E;G0@/2!P<F5G
M7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE04DE/4DE463I;,UTH7')<;GQ<<GQ<
M;BDO)RP@)UPQ4%))3U))5%DZ,EPR)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@
M("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI4%))3U))
M5%DZ6S0M.5TH7')<;GQ<<GQ<;BDO)RP@)UPQ4%))3U))5%DZ,UPR)RP@)&-O
M;G1E;G0L(#$I.PH@("`@("`*"B`@("`@("`@+R\@5VEN9&]W<R!-;V)I;&4@
M86QS;R!E>'!E8W1S($1512!$051%4R!L:6ME($1513HR,#`V,#0Q.50P,#`P
M,#`*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA<<EQN?%QR?%QN*41513HH
M+BXN+BXN+BY4+BXN+BXN6BDH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@
M("`@("1C;VYT96YT+"1M*2D@>PH@("`@("`@("`@("`D;5LR72`]("1T:&ES
M+3Y55$,R3&]C86Q$871E*"1M6S)=*3L*("`@("`@("`@("`@)&-O;G1E;G0@
M/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE$544Z*"XN+BXN+BXN5"XN
M+BXN+EHI*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`G7#%$544Z
M)R`N("1M6S)=("X@)UPS)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@('T*"B`@
M("`@("`@"B`@("`@("`@:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*
M("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L
M("=A)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@
M($!F=W)I=&4H)&9P+"`B7&YO=71P=70@8V]N=F5R=&5D(&9O<B!C;&EE;G0@
M*"1C;VYT96YT5'EP92DZ7&XB*3L*("`@("`@("`@("`@("`@($!F=W)I=&4H
M)&9P+"`D8V]N=&5N="`N(")<;B(I.PH@("`@("`@("`@("`@("`@0&9C;&]S
M92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@87)R87DH)&-O;G1E;G0L("1C;VYT96YT5'EP92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T('1H92!C;VYT96YT+@H@("`@("H*("`@("`J
M($-U<G)E;G1L>2!S=')I<',@=6ED("AP<FEM87)Y(&ME>2D@:6YF;W)M871I
M;VX@87,@8VQI96YT(&%N9`H@("`@("H@<V5R=F5R(&UI9VAT('5S92!D:69F
M97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT
M96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E<G0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C;VYT96YT5'EP92!O9B!T
M:&4@8V]N=&5N="X*("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@
M("`@87)R87DH)&YE=V-O;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@
M8V]N=&5N="!A;F0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("AP;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1#;&EE;G0R4V5R=F5R*"1C;VYT
M96YT+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@("`@;&ES="@D8V]N=&5N
M="P@)&-O;G1E;G14>7!E*2`]"B`@("`@("`@("`@('!A<F5N=#HZ8V]N=F5R
M=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C;VYT96YT5'EP92D["@H@("`@
M("`@("\O(%-O;64@<W!E8VEA;"!P<FEO<FET>2!H86YD;&EN9R!I<R!R97%U
M:7)E9"X@4WEN=&AE<VES('5S97,*("`@("`@("`O+R`Q("AH:6=H*2P@,B`H
M;65D:75M*2P@,RAL;W<I+"!A="!L96%S="!F;W(@;7D@=VEN9&]W<R!M;V)I
M;&4@9&5V:6-E+@H@("`@("`@("\O(&-O;G9E<G0@=&AE<V4@=&\@=F%L:60@
M<')I;W)I='D@<V5T=&EN9W,Z"B`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E
M<&QA8V4H)R\H7')<;GQ<<GQ<;BE04DE/4DE463HS*%QR7&Y\7')\7&XI+R<L
M("=<,5!224]22519.C5<,B<L("1C;VYT96YT+"`Q*3L*("`@("`@("`D8V]N
M=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*5!224]22519.C(H
M7')<;GQ<<GQ<;BDO)RP@)UPQ4%))3U))5%DZ,UPR)RP@)&-O;G1E;G0L(#$I
M.PH*("`@("`@(&EF("A$14)51TQ/1U])0T%,14Y$05)$051!*2!["B`@("`@
M("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S>6YC+VQO9RYT>'0G+"`G82<I
M.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("!`9G=R
M:71E*"1F<"P@(EQN:6YP=70@8V]N=F5R=&5D(&9O<B!S97)V97(Z("1C;VYT
M96YT5'EP95QN(BD["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"PD8V]N
M=&5N="`N(")<;B(I.PH@("`@("`@("`@("`@("`@0&9C;&]S92@D9G`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH
M)&-O;G1E;G0L("1C;VYT96YT5'EP92D["B`@"B`@("!]"B`@("`*("`@(`H@
M("`@+RH@4W1A=&EC(&AE;'!E<B!F=6YC=&EO;CH@8V]N=F5R=',@82!55$,@
M5&EM97-T86UP(&QI:V4@,C`P-C`T,3A4,C(P,#`P6@H@("`@("H@:6YT;R!A
M(&QO8V%L(&1A=&4@;&EK92`R,#`V,#0Q.50P,#`P,#`N(%1H:7,@:7,@86-T
M=6%L;'D@;6]R92!T:&%N"B`@("`@*B!S=')I<'!I;F<@=&AE('1I;64@<&%R
M=#H@=V4@;F5E9"!T;R!C;VYV97)T('1O(&QO8V%L('1I;64@9FER<W0@=&\@
M96YS=7)E"B`@("`@*B!W92!G970@=&AE(')I9VAT(&1A=&4A"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%540S),;V-A;$1A=&4H)',I"B`@("!["B`@("`@("`@
M)'0@/2!(;W)D95]I0V%L96YD87(Z.E]P87)S941A=&54:6UE*"1S*3L*("`@
M("`@("!R971U<FX@9&%T92@G66UD)RP@)'0I("X@)U0P,#`P,#`G.PH@("`@
M?0I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T1E=FEC
M92].;VMI82YP:'``````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T
M-34U`#$P-3$U-#,Q,#8P`#`R,3,P,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE(%-Y;F--3%]$
M979I8V5?3F]K:6$Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y('1H
M870@:7,*("H@<W!E8VEF:6,@=&\@=&AE($YO:VEA(%-Y;F--3"!C;&EE;G1S
M+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]$979I8V4O3F]K:6$N<&AP+'8@
M,2XR+C(N,R`R,#`V+S`U+S`Q(#$R.C`U.C$T(&IA;B!%>'`@)`H@*@H@*B!`
M875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*
M("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?1&5V:6-E7TYO
M:VEA(&5X=&5N9',@4WEN8TU,7T1E=FEC92!["@H@("`@+RHJ"B`@("`@*B!#
M;VYV97)T<R!T:&4@8V]N=&5N="!F<F]M('1H92!B86-K96YD('1O(&$@9F]R
M;6%T('-U:71A8FQE(&9O<B!T:&4*("`@("`J(&-L:65N="!D979I8V4N"B`@
M("`@*@H@("`@("H@4W1R:7!S('1H92!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O
M<FUA=&EO;B!A<R!C;&EE;G0@86YD('-E<G9E<B!M:6=H="!U<V4*("`@("`J
M(&1I9F9E<F5N="!O;F5S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;G1E;G0@("`@("`@5&AE(&-O;G1E;G0@=&\@8V]N=F5R=`H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y<&4@("!4:&4@8V]N=&5N=%1Y<&4@
M;V8@8V]N=&5N="!A<R!R971U<FYE9"!F<F]M"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!B86-K96YD"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("`@("`@("`@("`@("`@(&%R<F%Y*"1N97=C;VYT96YT+"`D;F5W
M8V]N=&5N=%1Y<&4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@8V]N=F5R=&5D(&-O;G1E;G0@86YD('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H<&]S<VEB;'D@8VAA;F=E9"D@
M;F5W($-O;G1E;G14>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T
M4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E;G14>7!E*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@;&ES="@D8V]N=&5N
M="P@)&-O;G1E;G14>7!E*2`]"B`@("`@("`@("`@('!A<F5N=#HZ8V]N=F5R
M=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D["@H@("`@
M("`@("\O($9)6$U%.B!J=7-T('-W87!P:6YG(&]U="!T:&4@=F5R<VEO;B!N
M=6UB97(@:6X@=&AE(&AE861E<@H@("`@("`@("\O('-O('1H870@=&AE(&-L
M:65N="!D;V5S;B=T(&EM;65D:6%T96QY(&1E;GD@=VET:"!A(")&;W)M870*
M("`@("`@("`O+R!N;W0@<W5P<&]R=&5D(BX@4V5E(&AT='`Z+R]B=6=S+FAO
M<F1E+F]R9R]T:6-K970O/VED/3$X.#$N"B`@("`@("`@)&-O;G1E;G0@/2!P
M<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE615)324]..C(N,"\G+"`G7#%6
M15)324]..C$N,"<L("1C;VYT96YT+"`Q*3L*"B`@("`@("`@:68@*$1%0E5'
M3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P(#T@0&9O<&5N
M*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@("`@(&EF("@D
M9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B7&YO=71P=70@
M8V]N=F5R=&5D(&9O<B!C;&EE;G0@*"1C;VYT96YT5'EP92DZ7&XB*3L*("`@
M("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`D8V]N=&5N="`N(")<;B(I.PH@
M("`@("`@("`@("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&-O;G1E;G0L("1C;VYT
M96YT5'EP92D["B`@("!]"@H@("`@+RH@3F]K:6$@8W5R<F5N=&QY(&5X<&5C
M=',@;F]T97,@87,@=&5X="]P;&%I;BX@36%Y8F4@=V4@8V%N(&5X=')A8W0*
M("`@("`J('1H:7,@9G)O;2!$979);F8@<F%T:&5R('1H86X@:&%R9&-O9&4@
M:70N"B`@("`@*B\*"B`@(&9U;F-T:6]N(&=E=%!R969E<G)E9$-O;G1E;G14
M>7!E*"1T>7!E*0H@("`@>PH@("`@("`@("!I9B`H)'1Y<&4@/3T@)VYO=&5S
M)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O<&QA:6XG.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@<&%R96YT.CIG9710<F5F97)R961#;VYT96YT
M5'EP92@D='EP92D["B`@("!]"@H@("!F=6YC=&EO;B!H86YD;&5487-K<TEN
M0V%L96YD87(H*0H@("!["B`@("`@(')E='5R;B!T<G5E.R`@("`@(`H@("!]
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M4WEN8TU,+T-O;6UA;F0O````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q-S<P,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]&:6YA;"YP:'``````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<U,3$`,3`U,34T,S$P-C``
M,#(Q-#0S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<[
M"@HO*BH*("H@5&AE(%-Y;F--3%]#;VUM86YD7T9I;F%L(&-L87-S+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O1FEN
M86PN<&AP+'8@,2XQ,"XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\
M86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S
M(%-Y;F--3%]#;VUM86YD7T9I;F%L(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@
M>PH*("`@("\J*@H@("`@("H@0W)E871E('1H92!R97-P;VYS92!F;W(@82!F
M:6YA;"!T86<*("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT
M0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%
M4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("1A='1R<R`](&%R<F%Y
M*"D["@H@("`@("`@("\O($EF('1H92!C;&EE;G0@:&%S;B=T('-E;G0@=7,@
M9&5V:6-E(&EN9F\L(')E<75E<W0@:70@;F]W+@H@("`@("`@("1D:2`](%-Y
M;F--3%]$979I8V4Z.F1E=FEC94EN9F\H*3L*("`@("`@("!I9B`H96UP='DH
M)&1I+3Y?36%N*2D@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)T=E="<L("1A='1R<RD["@H@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T-M9$E$)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)&-U<G)E
M;G1#;61)1#L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA
M<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=#;61)1"<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-971A)RP@)&%T=')S*3L*
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))365T82@I+"`G5'EP92<L("1A='1R<RD["B`@("`@("`@("`@("1A='1R
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1O=71P=70L("=8
M34Q?5T)834Q?16YC;V1E<B<I*2!["B`@("`@("`@("`@("`@("`D8VAA<G,@
M/2!-24U%7U-93D--3%]$159)0T5?24Y&3U]70EA-3#L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1C:&%R<R`]($U)345?4UE.0TU,
M7T1%5DE#15])3D9/7UA-3#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U1Y<&4G*3L*("`@
M("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G365T82<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*("`@("`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=4
M87)G970G+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD["B`@
M("`@("`@("`@("1C:&%R<R`]("@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]/2`P
M*2`_("<N+V1E=FEN9C$P)R`Z("<N+V1E=FEN9C$Q)SL*("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG*3L*
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G5&%R9V5T)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)TET96TG*3L*"B`@("`@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T=E="<I.PH*
M("`@("`@("`@("`@+R\@36%R:R!T:&ES(&ED(&1O=VX@87,@;F5E9&EN9R!A
M(')E<W5L=',@<&%C:V5T(')O=71E9"!T;PH@("`@("`@("`@("`O+R!T:&4@
M4'5T(&-O;6UA;F0N"B`@("`@("`@("`@("1S=&%T92T^<V5T17AP96-T9612
M97-U;'14>7!E*"1C=7)R96YT0VUD240L("=0=70G*3L*"B`@("`@("`@("`@
M("1C=7)R96YT0VUD240K*SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C
M=7)R96YT0VUD240["B`@("!]"B`@("`O*BH*("`@("`J($-R96%T92!A("9L
M=#M&:6YA;"9G=#L@;W5T<'5T+@H@("`@("H@0F5F;W)E('1H870@8V]N=&EN
M=64@82!S>6YC(&EF('1H97)E(&%R92!P96YD:6YG(&5N=')I97,N"B`@("`@
M*B!3=&%T:6,@;65T:&]D"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U=$9I
M;F%L*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S
M=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("1A
M='1R<R`](&%R<F%Y*"D["@H@("`@("`@(&=L;V)A;"`D;65S<V%G949U;&P[
M"B`@("`@("`@+RH@268@=&AE<F4G<R!P96YD:6YG('-Y;F,@9&%T82!A;F0@
M<W!A8V4@;&5F="!I;B!T:&4@;65S<V%G93H*("`@("`@("`@*B!S96YD(&1A
M=&$@;F]W+B`J+PH@("`@("`@(&EF("@A)&UE<W-A9V5&=6QL("8F"B`@("`@
M("`@("`@("`@("!C;W5N="@D<"`]("1S=&%T92T^9V5T4&5N9&EN9U-Y;F-S
M*"DI(#X@,"D@>PH@("`@("`@("`@("!F;W)E86-H("@D<"!A<R`D<&5N9&EN
M9U-Y;F,I('L*("`@("`@("`@("`@("`@(&EF("@A)&UE<W-A9V5&=6QL*2![
M"B`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-
M97-S86=E*"=C;VYT:6YU92!S>6YC(&9O<B!S>6YC5'EP93TG("X@)'!E;F1I
M;F=3>6YC+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M("`@("`@("`@("`@)'-Y;F,@/2`F("1S=&%T92T^9V5T4WEN8R@D<&5N9&EN
M9U-Y;F,I.PH@("`@("`@("`@("`@("`@("`@("1C=7)R96YT0VUD240@/2`D
M<WEN8RT^8W)E871E4WEN8T]U='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@
M("`@("`@+RH*("`@("`@("`@*B!$;VXG="!S96YD('1H92!F:6YA;"!T86<@
M:68@=V4@:&%V96XG="!S96YT(&%L;"!S>6YC(&1A=&$@>65T+@H@("`@("`@
M("`J+PH@("`@("`@(&EF("@A)'-T871E+3YH87-096YD:6YG16QE;65N=',H
M*2D@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)T9I;F%L)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1FEN86PG*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N
M9"==+3YL;V=-97-S86=E*"=P96YD:6YG(&5L96UE;G1S+"!N;W0@<V5N9&EN
M9R!F:6YA;"!T86<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M
M;6%N9"]0=70N<&AP````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,C$P,#$`,3`U,34T,S$P-C``,#(Q,34P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y
M;F--3"]#;VUM86YD+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO
M4WEN8TU,+U-Y;F--3"]#;VUM86YD+U!U="YP:'`L=B`Q+C$R+C$P+C<@,C`P
M-B\P-2\S,2`Q-SHP-CHS-B!S96QS:WD@17AP("0*("H*("H@5&AE(%-Y;F--
M3%]#;VUM86YD7U!U=#HZ(&-L87-S(&AA;F1L97,@1&5V26YF(&1E=FEC92!I
M;F9O<FUA=&EO;@H@*B!S96YT(&)Y('1H92!C;&EE;G0N(%1H92!D871A(&ES
M('-T;W)E9"!I;B!A(%-Y;F--3%]$979I8V5);F9O"B`J(&]B:F5C="!W:&EC
M:"!I<R!D969I;F5D(&EN($1E=FEC92YP:'`@86YD('1H96X@<W1O<F5D(&EN
M"B`J(%-Y;F--3%]$979I8V4@87,@86X@871T<FEB=71E+@H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-2TR,#`V($-U8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M
M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?
M4'5T(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*("`@('9A<B`D7V1E=FEN
M9CL*"B`@("`O*BH*("`@("`J($QO8V%L('9A<G,@=&\@<F5M96UB97(@<W1A
M=&4N"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1$4SL*("`@('9A<B`D7T-4
M5'EP93L*("`@('9A<B`D7U9E<D-4.PH*("`@('9A<B`D7V-U<G)E;G10<F]P
M3F%M93L*("`@('9A<B`D7V-U<G)E;G1087)A;4YA;64["B`@("!V87(@)%]C
M=7)R96YT0U14>7!E.PH*("`@('9A<B`D7V-U<G)E;G183F%M.PH*("`@(&9U
M;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M
M96YT+"`D871T<G,I.PH@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3
M=&%C:RDI('L*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1T:&ES+3Y?
M9&5V:6YF(#T@)FYE=R!3>6YC34Q?1&5V:6-E26YF;R@I.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`U.@H@("`@("`@("`@("!I9B`H)&5L
M96UE;G0@/3T@)T1A=&%3=&]R92<I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=$13(#T@)FYE=R!3>6YC34Q?1&%T85-T;W)E*"D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("![
M"B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("`D9&D@/2`F)'1H
M:7,M/E]D979I;F8["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T
M86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@)%]315-324].
M6R=3>6YC34PN<W1A=&4G72T^<V5T1&5V:6-E26YF;R@D9&DI.PH@("`@("`@
M("`@("!I9B`H1$5"54=,3T=?1$5624Y&*2!["B`@("`@("`@("`@("`@("`D
M9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]D979I;F8N='AT)RP@)V$G*3L*("`@
M("`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@("`@("!`
M9G=R:71E*"1F<"P@=F%R7V5X<&]R="@D9&DL('1R=64I*3L*("`@("`@("`@
M("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@8V%S92`U.@H@("`@("`@("`@("!S=VET
M8V@@*"1E;&5M96YT*2!["B`@("`@("`@("`@(&-A<V4@)U9E<D141"<Z"B`@
M("`@("`@("`@("`@("`D9&DM/E]697)$5$0@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=-86XG.@H@("`@("`@("`@("`@("`@)&1I+3Y?36%N(#T@=')I;2@D=&AI
M<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G36]D)SH*("`@("`@("`@("`@("`@("1D:2T^7TUO9"`]('1R
M:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)T]%32<Z"B`@("`@("`@("`@("`@("`D9&DM/E]/
M14T@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=&=U8G.@H@("`@("`@("`@("`@("`@
M)&1I+3Y?1G=6(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4W=6)SH*("`@("`@("`@
M("`@("`@("1D:2T^7U-W5B`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)TAW5B<Z"B`@
M("`@("`@("`@("`@("`D9&DM/E](=U8@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=$
M979)1"<Z"B`@("`@("`@("`@("`@("`D9&DM/E]$979)1"`]('1R:6TH)'1H
M:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)T1E=E1Y<"<Z"B`@("`@("`@("`@("`@("`D9&DM/E]$9794
M>7`@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=55$,G.@H@("`@("`@("`@("`@("`@
M)&1I+3Y?551#(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G4W5P<&]R=$QA<F=E3V)J<R<Z"B`@("`@("`@("`@
M("`@("`D9&DM/E]3=7!P;W)T3&%R9V5/8FIS(#T@=')U93L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4W5P<&]R=$YU;6)E
M<D]F0VAA;F=E<R<Z"B`@("`@("`@("`@("`@("`D9&DM/E]3=7!P;W)T3G5M
M8F5R3V9#:&%N9V5S(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G1&%T85-T;W)E)SH*("`@("`@("`@("`@("`@
M("1D:2T^7T1A=&%3=&]R95M=(#T@)'1H:7,M/E]C=7)R96YT1%,["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T-40V%P)SH*
M("`@("`@("`@("`@8V%S92`G17AT)SH*("`@("`@("`@("`@("`@("\O($%U
M=&]M871I8V%L;'D@:&%N9&QE9"!B>2!S=6)E;&5M96YT<RX*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(#8Z"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T
M86-K6S1=(#T]("=$871A4W1O<F4G*2!["B`@("`@("`@("`@("`@("!S=VET
M8V@@*"1E;&5M96YT*2!["B`@("`@("`@("`@("`@("!C87-E("=3;W5R8V52
M968G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?
M4V]U<F-E4F5F(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=$:7-P;&%Y
M3F%M92<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT1%,M
M/E]$:7-P;&%Y3F%M92`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G36%X
M1U5)1%-I>F4G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=$13+3Y?36%X1U5)1%-I>F4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)T13365M)SH*("`@("`@("`@("`@("`@("`@("`O+R!#=7)R96YT;'D@:6=N
M;W)E9"P@=&\@8F4@9&]N92X*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=3>6YC0V%P)SH*("`@("`@("`@("`@
M("`@("`@("`O+R!!=71O;6%T:6-A;&QY(&AA;F1L960@8GD@4WEN8U1Y<&4@
M<W5B96QE;65N="X*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!C87-E("=2>"U0<F5F)SH*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-U<G)E;G1$4RT^7U)X7U!R969;)'1H:7,M/E]#5%1Y<&5=
M(#T@)'1H:7,M/E]697)#5#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=2>"<Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C=7)R96YT1%,M/E]2>%LD=&AI<RT^7T-45'EP95T@/2`D
M=&AI<RT^7U9E<D-4.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@)U1X+5!R968G.@H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?5'A?4')E9ELD=&AI<RT^7T-45'EP
M95T@/2`D=&AI<RT^7U9E<D-4.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@(&-A<V4@)U1X)SH*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-U<G)E;G1$4RT^7U1X6R1T:&ES+3Y?0U14>7!E72`]
M("1T:&ES+3Y?5F5R0U0["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7U-T86-K6S1=(#T]("=#5$-A<"<I('L*("`@("`@("`@("`@
M("`@('-W:71C:"`H)&5L96UE;G0I('L*("`@("`@("`@("`@("`@(&-A<V4@
M)T-45'EP92<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT
M0U14>7!E(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=0<F]P3F%M92<Z
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT4')O<$YA;64@
M/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@("\O
M(%)E<V5T('!A<F%M('-T871E+@H@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M92D["B`@("`@("`@("`@("`@("`@
M("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C=7)R96YT0U14>7!E75LD=&AI<RT^
M7V-U<G)E;G10<F]P3F%M95T@/2`F;F5W(%-Y;F--3%]0<F]P97)T>2@I.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A
M<V4@)U!A<F%M3F%M92<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M=7)R96YT4&%R86U.86UE(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@
M("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#5%1Y
M<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M<ULD=&AI<RT^
M7V-U<G)E;G1087)A;4YA;65=(#T@)FYE=R!3>6YC34Q?4')O<&5R='E087)A
M;65T97(H*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=686Q%;G5M)SH*("`@("`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@5V4G<F4@:6X@<&%R86UE=&5R(&UO9&4N
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T:&ES+3Y?
M8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?<&%R
M86US6R1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M95TM/E]686Q%;G5M6W1R:6TH
M)'1H:7,M/E]C:&%R<RE=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD
M=&AI<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE
M72T^7U9A;$5N=6U;=')I;2@D=&AI<RT^7V-H87)S*5T@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=$871A5'EP92<Z"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M
M971E<B!M;V1E+@H@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A
M<%LD=&AI<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.
M86UE72T^7W!A<F%M<ULD=&AI<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?1&%T
M851Y<&4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-4
M0V%P6R1T:&ES+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O
M<$YA;65=+3Y?1&%T851Y<&4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=3:7IE)SH*("`@("`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M92DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4G<F4@:6X@<&%R86UE=&5R
M(&UO9&4N"B`@("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T
M:&ES+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=
M+3Y?<&%R86US6R1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M95TM/E]3:7IE(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI
M<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^
M7U-I>F4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("`@("!C87-E("=$:7-P;&%Y3F%M92<Z"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E
M+@H@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^
M7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A
M<F%M<ULD=&AI<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?1&ES<&QA>4YA;64@
M/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T
M:&ES+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=
M+3Y?1&ES<&QA>4YA;64@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?4W1A8VM;-%T@/3T@)T5X="<@)B8@)&5L96UE;G0@/3T@)UA.
M86TG*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G183F%M(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]3=&%C:ULT72`]/2`G17AT)R`F)B`D96QE;65N="`]
M/2`G6%9A;"<I('L*("`@("`@("`@("`@("`@("1D:2T^7T5X=%LD=&AI<RT^
M7V-U<G)E;G183F%M75M=(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`W.@H@
M("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)U9E<D-4)RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]697)#5"`]('1R:6TH)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N="`]/2`G0U14>7!E)RD@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]#5%1Y<&4@/2!T<FEM*"1T:&ES
M+3Y?8VAA<G,I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@
M)U-Y;F-4>7!E)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT
M1%,M/E]3>6YC0V%P6W1R:6TH)'1H:7,M/E]C:&%R<RE=(#T@=')U93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@
M("`@('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("!]
M"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T
M*0H@("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS
M=&%T92==.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N
M9%]3=&%T=7,H*"@D<W1A=&4M/FES075T:&]R:7IE9"@I*2`_(%)%4U!/3E-%
M7T]+(#H@4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4RDL("=0=70G*3L*
M("`@("`@("`D<W1A='5S+3YS971#;612968H)'1H:7,M/E]C;61)1"D["@H@
M("`@("`@("1R968@/2`H)'-T871E+3YG971697)S:6]N*"D@/3T@,"D@/R`G
M+B]D979I;F8Q,"<@.B`G+B]D979I;F8Q,2<["@H@("`@("`@("1S=&%T=7,M
M/G-E=%-O=7)C95)E9B@D<F5F*3L*"B`@("`@("`@<F5T=7)N("1S=&%T=7,M
M/F]U='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y
M;F--3"]#;VUM86YD+U)E<W5L=',N<&AP````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C<P-0`Q,#4Q-30S,3`V,``P,C(P-3<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"FEN8VQU9&5?
M;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O4F5S=6QT<RYP:'`L=B`Q
M+C$Q+C$P+C8@,C`P-B\P-R\P,B`Q,#HT.#HR,"!K87)S=&5N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS
M0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($YA
M=&AA;B!0(%-H87)P"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U)E<W5L=',@97AT
M96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@=F%R("1?<W5B0V]M;6%N9#L*
M("`@('9A<B`D7W-A=F5D57)I.PH@("`@=F%R("1?<V%V961%;&5M96YT.PH@
M("`@=F%R("1?<V%V961!='1R<SL*("`@('9A<B`D7W-A=F5D0VUD240["B`@
M("!V87(@)%]C:&%R<SL*"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*("`@("`@("!P87)E;G0Z.G-T
M87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*3L*"B`@("`@("`@
M<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@
M,3H*("`@("`@("`@("`@+R\@4V%V92!T:&4@:6YF;RP@=V4@;6%Y(&AA=F4@
M=&\@<F4M<V5N9"!T:&ES('-T87)T16QE;65N=`H@("`@("`@("`@("`O+R!T
M;R!T:&4@<W5B+6-O;6UA;F0@;&%T97(N"B`@("`@("`@("`@("1T:&ES+3Y?
M<V%V9615<FD@/2`D=7)I.PH@("`@("`@("`@("`D=&AI<RT^7W-A=F5D16QE
M;65N="`]("1E;&5M96YT.PH@("`@("`@("`@("`D=&AI<RT^7W-A=F5D071T
M<G,@/2`D871T<G,["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<W5B0V]M;6%N9"DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S=6)#;VUM86YD+3YS=&%R=$5L96UE;G0H)'5R:2P@
M)&5L96UE;G0L("1A='1R<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@
M<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@
M,CH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=#;61)1"<@)B8@(6ES
M<V5T*"1T:&ES+3Y?<W5B0V]M;6%N9"DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V%V961#;61)1"`](&EN='9A;"AT<FEM*"1T:&ES+3Y?8VAA<G,I
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]
M("=#;612968G*2!["B`@("`@("`@("`@("`@("`D8VUD4F5F(#T@:6YT=F%L
M*'1R:6TH)'1H:7,M/E]C:&%R<RDI.PH@("`@("`@("`@("`@("`@)'-T871E
M(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("`@("`@
M("`@+R\@268@=&AI<R!R97-U;'0@<&%C:V5T(&ES(')E;&%T960@=&\@<V]M
M971H:6YG(&%N9`H@("`@("`@("`@("`@("`@+R\@;F5E9',@=&\@8F4@<F]U
M=&5D('1O(&$@<&%R=&EC=6QA<B!C;VUM86YD(&]B:F5C="P*("`@("`@("`@
M("`@("`@("\O(&1O(&ET(&YO=RX*("`@("`@("`@("`@("`@("1C;614>7!E
M(#T@)'-T871E+3YG971%>'!E8W1E9%)E<W5L=%1Y<&4H)&-M9%)E9BD["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;614>7!E*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<W5B0V]M;6%N9"`]("93>6YC34Q?0V]M
M;6%N9#HZ9F%C=&]R>2@D8VUD5'EP92D["B`@("`@("`@("`@("`@("`@("`@
M+R\@5&AI<R!I<VXG="!T;W1A;&QY('1E8VAN:6-A;&QY(&-O<G)E8W0@8F5C
M875S90H@("`@("`@("`@("`@("`@("`@("\O('1H92!834P@8V]U;&0@:&%V
M92!B965N(&]U="!O9B!O<F1E<B!A;F0@=V4*("`@("`@("`@("`@("`@("`@
M("`O+R!M:6=H="!H879E(&UI<W-E9"!S;VUE('-T=69F+"!B=70@:6X@<F5A
M;&ET>2P*("`@("`@("`@("`@("`@("`@("`O+R!I="!P<F]B86)L>2!W;VXG
M="!H87!P96XN"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=6)#;VUM
M86YD+3YS=&%R=$5L96UE;G0H"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V%V9615<FDL"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V%V961%;&5M96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-A=F5D071T<G,I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W-A=F5D0VUD240I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("\O($9)6$U%.B!3:&]U;&1N)W0@8F4@86-C97-S:6YG('1H:7,@<')I
M=F%T90H@("`@("`@("`@("`@("`@("`@("`@("`O+R!M96UB97(N"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B0V]M;6%N9"T^7V-M9$E$
M(#T@)'1H:7,M/E]S879E9$-M9$E$.PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@1F%L;"!T:')O=6=H
M('1O('1H92!D969A=6QT(&-A<V4N"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-U8D-O;6UA;F0M/F5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT.CIE;F1%;&5M96YT*"1U<FDL
M("1E;&5M96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S*"1S
M='(I"B`@("!["B`@("`@("`@<&%R96YT.CIC:&%R86-T97)S*"1S='(I.PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<W5B0V]M;6%N9"T^8VAA<F%C=&5R<R@D<W1R*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT
M0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%
M4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D<W1A='5S(#T@)FYE
M=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H4D534$].4T5?3TLL("=297-U;'1S
M)RD["B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I
M.PH*("`@("`@("`D<F5F(#T@*"1S=&%T92T^9V5T5F5R<VEO;B@I(#T](#`I
M(#\@)RXO9&5V:6YF,3`G(#H@)RXO9&5V:6YF,3$G.PH@("`@("`@("1S=&%T
M=7,M/G-E=%-O=7)C95)E9B@D<F5F*3L*"B`@("`@("`@<F5T=7)N("1S=&%T
M=7,M/F]U='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3
M>6YC34PO0V]M;6%N9"]-87`N<&AP````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3`U,C(`,3`U,34T,S$P-C``,#(Q,3(S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@II;F-L=61E
M7V]N8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--
M3%]-87`@8VQA<W,@<')O=FED97,@82!3>6YC34P@:6UP;&5M96YT871I;VX@
M;V8*("H@=&AE($UA<"!C;VUM86YD(&%S(&1E9FEN960@:6X@4WEN8TU,(%)E
M<')E<V5N=&%T:6]N(%!R;W1O8V]L+`H@*B!V97)S:6]N(#$N,"XQ(#4N-2XX
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA
M;F0O36%P+G!H<"QV(#$N,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2V%R<W1E;B!&;W5R
M;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y;F--3`H@*B\*
M8VQA<W,@4WEN8TU,7T-O;6UA;F1?36%P(&5X=&5N9',@4WEN8TU,7T-O;6UA
M;F0@>PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?<V]U<F-E3&]C55)).PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T3&]C55)).PH*("`@('9A<B`D
M7VUA<%1A<F=E=#L*("`@('9A<B`D7VUA<%-O=7)C93L*"B`@("!F=6YC=&EO
M;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@("!["B`@("`@
M("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@)'-T871E(#T@)B1?4T53
M4TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("1S=&%T=7,@/2`F;F5W
M(%-Y;F--3%]#;VUM86YD7U-T871U<R@D<W1A=&4M/FES075T:&]R:7IE9"@I
M(#\@4D534$].4T5?3TL@.B!215-03TY315])3E9!3$E$7T-2141%3E1)04Q3
M+"`G36%P)RD["B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?
M8VUD240I.PH@("`@("`@(&EF("@D=&AI<RT^7W-O=7)C94QO8U5222`A/2!N
M=6QL*2!["B`@("`@("`@("`@("1S=&%T=7,M/G-E=%-O=7)C95)E9B@D=&AI
M<RT^7W-O=7)C94QO8U5222D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI
M<RT^7W1A<F=E=$QO8U5222`A/2!N=6QL*2!["B`@("`@("`@("`@("1S=&%T
M=7,M/G-E=%1A<F=E=%)E9B@D=&AI<RT^7W1A<F=E=$QO8U5222D["B`@("`@
M("`@?0H*("`@("`@("`D8W5R<F5N=$-M9$E$(#T@)'-T871U<RT^;W5T<'5T
M*"1C=7)R96YT0VUD240L("1O=71P=70I.PH*("`@("`@("!R971U<FX@)&-U
M<G)E;G1#;61)1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@
M<')O<&5R='D@<V]U<F-E55))+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'-O=7)C955222`@3F5W('9A;'5E(&]F('!R;W!E<G1Y('-O=7)C9552
M22X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4V]U<F-E3&]C55))*"1S;W5R
M8V554DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]S;W5R8V554DD@/2`D<V]U
M<F-E55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1A<F=E=$QO8U5222@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&%R9V5T55)).PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!T87)G9715
M4DDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T55))("!.
M97<@=F%L=64@;V8@<')O<&5R='D@=&%R9V5T55))+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971487)G97154DDH)'1A<F=E=%5222D*("`@('L*("`@("`@
M("`D=&AI<RT^7W1A<F=E=%5222`]("1T87)G97154DD["B`@("!]"@H@("`@
M9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I
M"B`@("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L
M96UE;G0L("1A='1R<RD["@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M
M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D
M96QE;65N="`]/2`G36%P271E;2<I('L*("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?;6%P5&%R9V5T*3L*("`@("`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?;6%P4V]U<F-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N
M="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME
M;F0["@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*
M("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1S=&%T92`]("8D7U-%4U-)
M3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("`@("`D<WEN8R`]("8@)'-T
M871E+3YG9713>6YC*"1T:&ES+3Y?=&%R9V5T3&]C55))*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E
M;&5M96YT(#T]("=-87!)=&5M)RD@>PH@("`@("`@("`@("`@("`@)'-T871E
M(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["B`@("`@("`@("`@("`@
M("`D<WEN8R`]("8@)'-T871E+3YG9713>6YC*"1T:&ES+3Y?=&%R9V5T3&]C
M55))*3L*("`@("`@("`@("`@("`@(&EF("@A)'-T871E+3YI<T%U=&AO<FEZ
M960H*2D@>PH@("`@("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S
M86=E*"=.;W0@075T:&]R:7IE9"!I;B!-87!)=&5M(2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`O+R!/=F5R=W)I=&4@97AI<W1I;F<@9&%T
M82!B>2!R96UO=FEN9R!I="!F:7)S="X*("`@("`@("`@("`@("`@("`@("`D
M8F%C:V5N9"T^8W)E871E56ED36%P*"1S=&%T92T^9V5T4WEN8TED96YT:69I
M97(H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=&%R9V5T3&]C55))+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M87!3;W5R8V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7VUA<%1A<F=E="D["@H@("`@("`@("`@("`@("`@("`@("1B86-K96YD
M+3YL;V=-97-S86=E*"=C<F5A=&5D($UA<"!F;W(@<V]U<F-E/2<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?
M;6%P4V]U<F-E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G(&%N9"!T87)G970])R`N("1T:&ES+3Y?;6%P5&%R9V5T"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&EN
M(&1B("<@+B`D=&AI<RT^7W1A<F=E=$QO8U5222P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,SH*("`@
M("`@("`@("`@:68@*"1E;&5M96YT(#T]("=,;V-54DDG*2!["B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G4V]U<F-E)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E3&]C55))(#T@=')I
M;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M=&AI<RT^7U-T86-K6S%=(#T]("=487)G970G*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]T87)G971,;V-54DD@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@(&EF("@D
M96QE;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?4W1A8VM;,ET@/3T@)U-O=7)C92<I('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VUA<%-O=7)C92`]('1R:6TH)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]3=&%C:ULR72`]
M/2`G5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%P
M5&%R9V5T(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE;65N="D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM
M86YD+U-Y;F-%;&5M96YT+G!H<```````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,38S-``Q,#4Q-30S,3`V,``P,C(V-#$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN
M8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B!4:&4@8VQA<W,@4WEN8TU,7T-O
M;6UA;F1?4WEN8T5L96UE;G0@<W1O<F5S(&EN9F]R;6%T:6]N(&9R;VT@=&AE
M($%D9"P*("H@1&5L971E(&%N9"!297!L86-E(&5L96UE;G1S(&9O=6YD(&EN
M<VED92!A('-Y;F,@8V]M;6%N9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M4WEN8TU,+U-Y;F--3"]#;VUM86YD+U-Y;F-%;&5M96YT+G!H<"QV(#$N,RXR
M+C,@,C`P-B\P,2\P,2`R,3HR.#HS-B!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!4:&4@:&]R9&4@<')O:F5C="`H=W=W+FAO<F1E+F]R
M9RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO
M;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]3
M>6YC16QE;65N="!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("`O*BH*
M("`@("`J($%D9"P@1&5L971E(&]R(%)E<&QA8V4N"B`@("`@*B\*("`@('9A
M<B`D7V5L96UE;G14>7!E.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@4WEN
M8TU,7U-Y;F-)=&5M(&5N=')I97,N"B`@("`@*B\*("`@('9A<B`D7VET96US
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($UI;65T>7!E(&9O<B!A;&P@
M:71E;7,N"B`@("`@*B\*("`@('9A<B`D7V-O;G1E;G14>7!E.PH*("`@("\J
M*@H@("`@("H@5&5M<"!D871A(&9O<B!C<F5A=&EO;B!O9B!I;F1I=FED=6%L
M(&ET96US+@H@("`@("HO"B`@("!V87(@)%]C;VYT96YT.PH*("`@('9A<B`D
M7V-U:60["@H@("`@+RHJ"B`@("`@*B!-:6UE='EP92!F;W(@:6YD:79I9'5A
M;"!I=&5M+@H@("`@("HO"B`@("!V87(@)%]I=&5M0V]N96YT5'EP93L*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!3>6YC($5L96UE;G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R!E;&5M96YT5'EP92!E:71H97(@061D+"!$
M96QE=&4@;W(@4F5P;&%C90H@("`@("HO"B`@("!F=6YC=&EO;B!3>6YC34Q?
M0V]M;6%N9%]3>6YC16QE;65N="@D96QE;65N=%1Y<&4I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]E;&5M96YT5'EP92`]("1E;&5M96YT5'EP93L*("`@('T*
M"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I
M"B`@("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V5L96UE;G14>7!E*2![
M"B`@("`@("`@8V%S92`G061D)SH*("`@("`@("`@("`@)')E<W!O;G-E(#T@
M4D534$].4T5?251%35]!1$1%1#L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@)T1E;&5T92<Z"B`@("`@("`@("`@("1R97-P;VYS92`](%)%
M4U!/3E-%7T]+.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M4F5P;&%C92<Z"B`@("`@("`@("`@("1R97-P;VYS92`](%)%4U!/3E-%7T]+
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("1S=&%T
M=7,@/2`F;F5W(%-Y;F--3%]#;VUM86YD7U-T871U<R@D<F5S<&]N<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?96QE;65N=%1Y<&4I.PH@("`@("`@("1S=&%T=7,M/G-E=$-M9%)E
M9B@D=&AI<RT^7V-M9$E$*3L*"B`@("`@("`@<F5T=7)N("1S=&%T=7,M/F]U
M='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@
M('L*("`@("`@("!P87)E;G0Z.G-T87)T16QE;65N="@D=7)I+"`D96QE;65N
M="P@)&%T=')S*3L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A
M8VLI*2!["B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`D=&AI<RT^7V-U
M:60@/2!N=6QL.PH@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G0@/2!N=6QL
M.PH@("`@("`@("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP92`](&YU;&P[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@
M('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E
M(#$Z"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@
M("`@("`@(&EF("@D96QE;65N="`]/2`G271E;2<I('L*("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7VET96U#;VYT96YT5'EP92D*("`@("`@
M("`@("`@("`@("`@("`F)B`A96UP='DH)'1H:7,M/E]C;VYT96YT5'EP92DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP
M92`]("1T:&ES+3Y?8V]N=&5N=%1Y<&4["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I=&5M<UM=(#T@)FYE=R!3>6YC34Q?
M4WEN8TET96TH)'1H:7,M/E]E;&5M96YT5'EP92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8V]N=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:71E;4-O;G1E;G14>7!E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C=6ED*3L*("`@("`@("`@("`@?0H*("`@
M("`@("!C87-E(#,Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G5'EP
M92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=%1Y<&4@/2!T
M<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5L
M96UE;G0@/3T@)T1A=&$G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;G1E;G0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@
M(&EF("@D96QE;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?4W1A8VM;,ET@/3T@)U-O=7)C92<I('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-U:60@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?4W1A8VM;,ET@
M/3T@)U1A<F=E="<I('L*("`@("`@("`@("`@("`@("`@("`O+R!.;W0@=7-E
M9#H@=V4@:6=N;W)E(")S=6ED('!R;W!O<V%L<R(@9G)O;0H@("`@("`@("`@
M("`@("`@("`@("\O(&-L:65N="X*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`U.@H@
M("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)U1Y<&4G*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP92`]('1R:6TH)'1H:7,M
M/E]C:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L96UE;G0H)'5R:2P@)&5L
M96UE;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$ET96US*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]I=&5M<SL*("`@('T*"B`@("!F=6YC
M=&EO;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8V]N=&5N=%1Y<&4["B`@("!]"@I]"@HO*BH*("H@5&AE(&-L87-S
M(%-Y;F--3%]#;VUM86YD7U-Y;F-%;&5M96YT('-T;W)E<R!I;F9O<FUA=&EO
M;B!A8F]U=`H@*B!T:&4@:71E;7,@:6YS:61E(&$@<WEN8R!E;&5M96YT("A!
M9&1\1&5L971E?%)E<&QA8V4I+@H@*@H@*B!!('-I;F=L92!3>6YC16QE;65N
M="!C86X@8V]N=&%I;B!M=6QT:7!L92!I=&5M<RX*("H*("H@26YS=&%N8V5S
M(&]F('1H:7,@8VQA<W,@87)E(&-R96%T960@9'5R:6YG('1H92!834P@<&%R
M<VEN9R!B>0H@*B!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="X*("H*("H@
M0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?4WEN8TET96T@>PH*
M("`@("\J*@H@("`@("H@061D+"!$96QE=&4@;W(@4F5P;&%C92P@:6YH97)I
M=&5D(&9R;VT*("`@("`J(%-Y;F--3%]#;VUM86YD7U-Y;F-%;&5M96YT+@H@
M("`@("HO"B`@("!V87(@)%]E;&5M96YT5'EP93L*"B`@("!V87(@)%]C=6ED
M.PH*("`@("\J*@H@("`@("H@3W!T:6]N86PL(&UA>2!B92!P<F]V:61E9"!B
M>2!P87)E;G0@96QE;65N="!O<B!E=F5N(&YO="!A="!A;&PN"B`@("`@*B\*
M("`@('9A<B`D7V-O;G1E;G14>7!E.PH*("`@('9A<B`D7V-O;G1E;G0["@H@
M("`@9G5N8W1I;VX@4WEN8TU,7U-Y;F-)=&5M*"1E;&5M96YT5'EP92P@)&-O
M;G1E;G0@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M;VYT96YT5'EP92`](&YU;&PL("1C=6ED(#T@;G5L;"D*("`@('L*("`@("`@
M("`D=&AI<RT^7V5L96UE;G14>7!E(#T@)&5L96UE;G14>7!E.PH@("`@("`@
M("1T:&ES+3Y?8W5I9"`]("1C=6ED.PH@("`@("`@("1T:&ES+3Y?8V]N=&5N
M=%1Y<&4@/2`D8V]N=&5N=%1Y<&4["B`@("`@("`@)'1H:7,M/E]C;VYT96YT
M(#T@)&-O;G1E;G0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0W5I9"@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8W5I9#L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971#;VYT96YT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]C;VYT96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14
M>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT5'EP
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971%;&5M96YT5'EP92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?96QE;65N=%1Y<&4["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC
M34PO0V]M;6%N9"]3=&%T=7,N<&AP````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,38Q,3``,3`U,34T,S$P-C``,#(Q-C<P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<["G)E<75I<F5?;VYC92`G4WEN8TU,
M+T-O;G-T86YT<RYP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y
M;F--3"]3>6YC34PO0V]M;6%N9"]3=&%T=7,N<&AP+'8@,2XQ-2XQ,"XV(#(P
M,#8O,#$O,S$@,3<Z-34Z,3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M
M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U-T871U
M<R!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("!V87(@)%]R97-P;VYS
M93L*"B`@("!V87(@)%]C;612968["@H@("`@+RHJ"B`@("`@*B!-=7-T(&)E
M('!R97-E;G0N"B`@("`@*B\*("`@('9A<B`D7V-M9#L*"B`@("!V87(@)%]S
M;W5R8V52968["@H@("`@=F%R("1?=&%R9V5T4F5F.PH*("`@('9A<B`D7V-H
M86Q-971A1F]R;6%T.PH*("`@('9A<B`D7V-H86Q-971A5'EP93L*"B`@("!V
M87(@)%]C:&%L365T84YE>'1.;VYC93L*"B`@("!V87(@)%]I=&5M1&%T84%N
M8VAO<DYE>'0["@H@("`@=F%R("1?:71E;41A=&%!;F-H;W),87-T.PH*("`@
M(&9U;F-T:6]N(%-Y;F--3%]#;VUM86YD7U-T871U<R@D<F5S<&]N<V4@/2!N
M=6QL+"`D8VUD(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)')E<W!O;G-E
M("$](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/E]R97-P;VYS92`]("1R
M97-P;VYS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D8VUD("$](&YU;&PI
M('L*("`@("`@("`@("`@)'1H:7,M/E]C;60@/2`D8VUD.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O
M=71P=70I"B`@("!["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@
M("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@
M("`@(&EF("@D=&AI<RT^7V-M9"`A/2!N=6QL*2!["B`@("`@("`@("`@("1A
M='1R<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G4W1A='5S)RP@)&%T=')S*3L*"B`@
M("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G0VUD240G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D
M8W5R<F5N=$-M9$E$.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)T-M9$E$)RD["@H@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<L("1A
M='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1S=&%T92T^9V5T37-G240H
M*3L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@
M("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=-<V=2968G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD4F5F)RP@)&%T=')S*3L*("`@
M("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]C;612968["B`@("`@("`@("`@
M("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD4F5F)RD[
M"@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)T-M9"<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]
M("1T:&ES+3Y?8VUD.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)T-M9"<I.PH*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?=&%R9V5T4F5F*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G9712968G
M+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]T
M87)G9712968["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1C:&%R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=487)G9712968G*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<V]U<F-E4F5F*2D@
M>PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=3;W5R8V52968G+"`D871T<G,I.PH@("`@("`@("`@
M("`@("`@)&-H87)S(#T@)'1H:7,M/E]S;W5R8V52968["B`@("`@("`@("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3
M;W5R8V52968G*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@268@
M=V4@87)E(')E<W!O;F1I;F<@=&\@=&AE(%-Y;F-(9'(@86YD('=E(&%R92!N
M;W0*("`@("`@("`@("`@+R\@875T:&]R:7IE9"!T:&5N(')E<75E<W0@8F%S
M:6,@875T:&]R:7IA=&EO;BX*("`@("`@("`@("`@+R\*("`@("`@("`@("`@
M+R\@1DE8344Z(%)I9VAT(&YO=R!W92!A;'=A>7,@<V5N9"!T:&ES+"!I9VYO
M<FEN9R!T:&4*("`@("`@("`@("`@+R\@:7-!=71H;W)I>F5D*"D@=&5S="X@
M27,@=&AA="!C;W)R96-T/PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;60@
M/3T@)U-Y;F-(9'(G("8F("$D<W1A=&4M/FES075T:&]R:7IE9"@I*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-H86Q-971A1F]R;6%T(#T@)V(V-"<[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86Q-971A5'EP92`]("=S>6YC
M;6PZ875T:"UB87-I8R<["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E<W!O
M;G-E(#T@4D534$].4T5?0U)%1$5.5$E!3%-?34E34TE.1SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;$UE=&%&
M;W)M870I("8F(&ES<V5T*"1T:&ES+3Y?8VAA;$UE=&%4>7!E*2D@>PH@("`@
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=#:&%L)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<L("1A
M='1R<RD["@H@("`@("`@("`@("`@("`@)&UE=&%I;F9U<FD@/2`D<W1A=&4M
M/F=E=%5224UE=&$H*3L*"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)&UE=&%I;F9U<FDL("=4>7!E)RP@)&%T=')S*3L*("`@("`@
M("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?8VAA;$UE=&%4>7!E.PH@("`@
M("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D;65T86EN9G5R:2P@
M)U1Y<&4G*3L*"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)&UE=&%I;F9U<FDL("=&;W)M870G+"`D871T<G,I.PH@("`@("`@("`@
M("`@("`@)&-H87)S(#T@)'1H:7,M/E]C:&%L365T849O<FUA=#L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)&UE=&%I;F9U<FDL("=&
M;W)M870G*3L*"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=-971A)RD["B`@("`@("`@("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#:&%L)RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<L("1A='1R<RD["B`@("`@
M("`@("`@("1C:&%R<R`]("1T:&ES+3Y?<F5S<&]N<V4["B`@("`@("`@("`@
M("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<I.PH*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:71E;41A=&%!;F-H;W).
M97AT*2!\?"!I<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R3&%S="DI('L*
M("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G271E;2<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D
M;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G
M+"`D871T<G,I.PH*("`@("`@("`@("`@("`@("1M971A:6YF=7)I(#T@)'-T
M871E+3YG97154DE-971A*"D["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)&UE=&%I;F9U<FDL("=!;F-H;W(G+"`D871T<G,I.PH*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VET96U$871A06YC
M:&]R3&%S="DI('L*"B`@("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D;65T86EN9G5R:2P@)TQA<W0G+"`D871T<G,I.PH@("`@("`@
M("`@("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7VET96U$871A06YC:&]R3&%S
M=#L*("`@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA
M<G,I.PH@("`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1M
M971A:6YF=7)I+"`G3&%S="<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R3F5X
M="DI('L*"B`@("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D;65T86EN9G5R:2P@)TYE>'0G+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@("`D8VAA<G,@/2`D=&AI<RT^7VET96U$871A06YC:&]R3F5X=#L*("`@
M("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@
M("`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1M971A:6YF
M=7)I+"`G3F5X="<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)&UE=&%I;F9U<FDL("=!;F-H;W(G
M*3L*"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=$871A)RD["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RD["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)U-T871U<R<I.PH*("`@("`@("`@("`@)&-U<G)E
M;G1#;61)1"LK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C=7)R96YT
M0VUD240["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E
M<G1Y(')E<W!O;G-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E
M<W!O;G-E("!.97<@=F%L=64@;V8@<')O<&5R='D@<F5S<&]N<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=%)E<W!O;G-E*"1R97-P;VYS92D*("`@('L*
M("`@("`@("`D=&AI<RT^7W)E<W!O;G-E(#T@)')E<W!O;G-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!C;60N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VUD("!.97<@=F%L=64@;V8@<')O
M<&5R='D@8VUD+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#;60H)&-M9"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V-M9"`]("1C;60["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(&-M9%)E9BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;612968@($YE=R!V86QU92!O9B!P
M<F]P97)T>2!C;612968N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-M9%)E
M9B@D8VUD4F5F*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VUD4F5F(#T@)&-M
M9%)E9CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R
M='D@<V]U<F-E4F5F+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-O
M=7)C95)E9B`@3F5W('9A;'5E(&]F('!R;W!E<G1Y('-O=7)C95)E9BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T4V]U<F-E4F5F*"1S;W5R8V52968I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S;W5R8V52968@/2`D<V]U<F-E4F5F.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!T87)G
M9712968N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T4F5F
M("!.97<@=F%L=64@;V8@<')O<&5R='D@=&%R9V5T4F5F+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971487)G9712968H)'1A<F=E=%)E9BD*("`@('L*("`@
M("`@("`D=&AI<RT^7W1A<F=E=%)E9B`]("1T87)G9712968["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(&ET96U$871A06YC
M:&]R3F5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I=&5M1&%T
M84%N8VAO<DYE>'0@($YE=R!V86QU92!O9B!P<F]P97)T>2!I=&5M1&%T84%N
M8VAO<DYE>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ET96U$871A06YC
M:&]R3F5X="@D:71E;41A=&%!;F-H;W).97AT*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:71E;41A=&%!;F-H;W).97AT(#T@)&ET96U$871A06YC:&]R3F5X
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@
M:71E;41A=&%!;F-H;W),87-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ET96U$871A06YC:&]R3&%S="`@3F5W('9A;'5E(&]F('!R;W!E<G1Y
M(&ET96U$871A06YC:&]R3&%S="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M271E;41A=&%!;F-H;W),87-T*"1I=&5M1&%T84%N8VAO<DQA<W0I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]I=&5M1&%T84%N8VAO<DQA<W0@/2`D:71E;41A
M=&%!;F-H;W),87-T.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y
M;F--3"]#;VUM86YD+T%L97)T+G!H<```````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R-3`R-0`Q,#4Q-30S,3`V,``P,C$T-C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"FEN8VQU9&5?
M;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B!4:&4@4WEN8TU,
M7T%L97)T(&-L87-S('!R;W9I9&5S(&$@4WEN8TU,(&EM<&QE;65N=&%T:6]N
M(&]F"B`J('1H92!!;&5R="!C;VUM86YD(&%S(&1E9FEN960@:6X@4WEN8TU,
M(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+`H@*B!V97)S:6]N(#$N,2`U+C4N
M,BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM
M86YD+T%L97)T+G!H<"QV(#$N,3@N,3`N.2`R,#`V+S`Q+S,Q(#$W.C4U.C,Q
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@
M36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,"B`J
M+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]!;&5R="!E>'1E;F1S(%-Y;F--3%]#
M;VUM86YD('L*"B`@("`O*BH*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)%]A;&5R=#L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7W-O=7)C94QO8U5223L*"B`@("`O*BH*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=$QO8U52
M23L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7VUE=&%!;F-H;W).97AT.PH*("`@("\J*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D7VUE=&%!;F-H;W),87-T.PH*("`@("\J
M*@H@("`@("H@0W)E871E<R!A(&YE=R!I;G-T86YC92!O9B!!;&5R="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@4WEN8TU,7T-O;6UA;F1?06QE<G0H)&%L97)T
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&%L97)T("$](&YU;&PI('L*
M("`@("`@("`@("`@)'1H:7,M/E]A;&5R="`]("1A;&5R=#L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D
M;W5T<'5T*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@
M("`@)&%T=')S(#T@87)R87DH*3L*("`@("`@("`D<W1A=&4@/2`F)%]315-3
M24].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@+R\@2&%N9&QE('5N875T
M:&]R:7IE9"!F:7)S="X*("`@("`@("!I9B`H(21S=&%T92T^:7-!=71H;W)I
M>F5D*"DI('L*("`@("`@("`@("`@)'-T871U<R`]("9N97<@4WEN8TU,7T-O
M;6UA;F1?4W1A='5S*%)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,L("=!
M;&5R="<I.PH@("`@("`@("`@("`D<W1A='5S+3YS971#;612968H)'1H:7,M
M/E]C;61)1"D["B`@("`@("`@("`@("1C=7)R96YT0VUD240@/2`D<W1A='5S
M+3YO=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("`@("`@("`@
M(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@("`@('T*"B`@("`@("`@)&1A
M=&%B87-E(#T@)'1H:7,M/E]T87)G971,;V-54DD["@H@("`@("`@("\O(%-T
M;W)E(&-L:65N="=S($YE>'0@06YC:&]R(&EN(%-T871E+B`@069T97(@<W5C
M8V5S<V9U;"!S>6YC"B`@("`@("`@+R\@=&AI<R!I<R!T:&5N('=R:71T96X@
M=&\@<&5R<VES=&5N8V4@9F]R(&YE9V]T:6%T:6]N(&]F"B`@("`@("`@+R\@
M9G5R=&AE<B!S>6YC<RX*("`@("`@("`D<W1A=&4M/G-E=$-L:65N=$%N8VAO
M<DYE>'0H)&1A=&%B87-E+"`D=&AI<RT^7VUE=&%!;F-H;W).97AT*3L*"B`@
M("`@("`@)&EN9F\@/2`D8F%C:V5N9"T^9V5T4WEN8U-U;6UA<GDH)'-T871E
M+3YG9713>6YC261E;G1I9FEE<B@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C55))*3L*"B`@
M("`@("`@:68@*&ES7V$H)&EN9F\L("=$871A5')E94]B:F5C="<I*2!["B`@
M("`@("`@("`@("1X(#T@)&EN9F\M/F=E="@G0VQI96YT06YC:&]R)RD["B`@
M("`@("`@("`@("1C;&EE;G1L87-T(#T@)'A;)&1A=&%B87-E73L*("`@("`@
M("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H<W!R:6YT9B@G<')E=FEO=7,@
M<WEN8R!F;W5N9"!F;W(@9&%T86)A<V4Z("5S.R!C;&EE;G0M=',Z("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-L:65N=&QA<W0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`@("`@)'@@/2`D:6YF;RT^9V5T*"=397)V97)!;F-H;W(G*3L*("`@
M("`@("`@("`@)'-T871E+3YS971397)V97)!;F-H;W),87-T*"1D871A8F%S
M92P@)'A;)&1A=&%B87-E72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H<W!R:6YT9B@G4WEN8TU,.B!.;R!I
M;F9O(&%B;W5T('!R979I;W5S('-Y;F-S(&9O=6YD(&9O<B!I9"`E<R!A;F0@
M9&%T86)A<V4@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S=&%T92T^9V5T4WEN8TED96YT:69I97(H*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T86)A<V4I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)&-L:65N
M=&QA<W0@/2`P.PH@("`@("`@("`@("`D<W1A=&4M/G-E=%-E<G9E<D%N8VAO
M<DQA<W0H)&1A=&%B87-E+"`P*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E
M="!397)V97(@06YC:&]R(&9O<B!T:&ES('-Y;F,@=&\@8W5R<F5N="!T:6UE
M+@H@("`@("`@("1S=&%T92T^<V5T4V5R=F5R06YC:&]R3F5X="@D9&%T86)A
M<V4L('1I;64H*2D["B`@("`@("`@:68@*"@D8VQI96YT;&%S="!\?"`D8VQI
M96YT;&%S="`]/3T@)S`G*0H@("`@("`@("`@("`@("`@("8F("1C;&EE;G1L
M87-T(#T]("1T:&ES+3Y?;65T84%N8VAO<DQA<W0I('L*("`@("`@("`@("`@
M+R\@3&%S="!3>6YC($%N8VAO<B!M871C:&5S+"!4=V]787E3>6YC('=I;&P@
M9&\N"B`@("`@("`@("`@("1C;V1E(#T@4D534$].4T5?3TL["B`@("`@("`@
M("`@("1B86-K96YD+3YL;V=-97-S86=E*")3>6YC34PZ($%N8VAO<B!M871C
M:"P@5'=O5V%Y4WEN8R!S:6YC92`B"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`D8VQI96YT;&%S="P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D8VQI96YT;&%S
M="D@>PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)V-L
M:65N="!R97%U97-T960@<WEN8R!W:71H(&%N8VAO<B!T<R`G("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;65T84%N
M8VAO<DQA<W0@+B`G(&)U="!S97)V97(@)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:&%S('1I;65S=&%M<"<@+B`D8VQI96YT
M;&%S="`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M(&]N(&9I;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@B4WEN
M8TU,.B!!;F-H;W(@;6ES;6%T8V@L(&5N9F]R8VEN9R!3;&]W4WEN8R(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D8VQI96YT;&%S
M="`](#`["B`@("`@("`@("`@("1S=&%T92T^<V5T4V5R=F5R06YC:&]R3&%S
M="@D9&%T86)A<V4L(#`I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]A;&5R
M="`]/2`R,#$I('L*("`@("`@("`@("`@("`@("\J(%-L;W=S>6YC(')E<75E
M<W1E9"!F<F]M(&-L:65N="!A;GEW87DZ(&IU<W0@86-K;F]W;&5D9V4N("HO
M"B`@("`@("`@("`@("`@("`D8V]D92`](%)%4U!/3E-%7T]+.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@36ES;6%T8V@L(&5N
M9F]R8V4@<VQO=R!S>6YC+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M;&5R="`](#(P,3L*("`@("`@("`@("`@("`@("1C;V1E(#T@-3`X.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@)FYE=R!3
M>6YC34Q?0V]M;6%N9%]3=&%T=7,H)&-O9&4L("=!;&5R="<I.PH@("`@("`@
M("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$*3L*("`@("`@("!I
M9B`H)'1H:7,M/E]S;W5R8V5,;V-54DD@(3T@;G5L;"D@>PH@("`@("`@("`@
M("`D<W1A='5S+3YS9713;W5R8V52968H)'1H:7,M/E]S;W5R8V5,;V-54DDI
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]T87)G971,;V-54DD@
M(3T@;G5L;"D@>PH@("`@("`@("`@("`D<W1A='5S+3YS971487)G9712968H
M)'1H:7,M/E]T87)G971,;V-54DDI.PH@("`@("`@('T*"B`@("`@("`@+R\@
M36ER<F]R($YE>'0@06YC:&]R(&9R;VT@8VQI96YT(&)A8VL@=&\@8VQI96YT
M+@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VUE=&%!;F-H;W).97AT*2D@
M>PH@("`@("`@("`@("`D<W1A='5S+3YS971)=&5M1&%T84%N8VAO<DYE>'0H
M)'1H:7,M/E]M971A06YC:&]R3F5X="D["B`@("`@("`@?0H*("`@("`@("`O
M+R!-:7)R;W(@3&%S="!!;F-H;W(@9G)O;2!C;&EE;G0@8F%C:R!T;R!C;&EE
M;G0N"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;65T84%N8VAO<DQA<W0I
M*2!["B`@("`@("`@("`@("1S=&%T=7,M/G-E=$ET96U$871A06YC:&]R3&%S
M="@D=&AI<RT^7VUE=&%!;F-H;W),87-T*3L*("`@("`@("!]"@H@("`@("`@
M("1C=7)R96YT0VUD240@/2`D<W1A='5S+3YO=71P=70H)&-U<G)E;G1#;61)
M1"P@)&]U='!U="D["@H@("`@("`@(&EF("@D<W1A=&4M/FES075T:&]R:7IE
M9"@I*2!["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G06QE<G0G+"`D871T<G,I.PH*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)
M1"<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1C=7)R96YT0VUD
M240["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G0VUD240G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<L("1A='1R<RD["B`@("`@
M("`@("`@("1C:&%R<R`]("1T:&ES+3Y?86QE<G0["B`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<I.PH*("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=)=&5M)RP@)&%T=')S*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7W-O=7)C94QO8U5222`A/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U1A<F=E="<L
M("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@
M("`@("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7W-O=7)C94QO8U5223L*("`@
M("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@
M("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)TQO8U5222<I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T)RD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W1A<F=E=$QO8U5222`A
M/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)U-O=7)C92<L("1A='1R<RD["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D8VAA
M<G,@/2`D=&AI<RT^7W1A<F=E=$QO8U5223L*("`@("`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<I
M.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G4V]U<F-E)RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G
M365T82<L("1A='1R<RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=!;F-H;W(G+"`D871T<G,I
M.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^
M9V5T55))365T82@I+"`G3&%S="<L("1A='1R<RD["B`@("`@("`@("`@("1C
M:&%R<R`]("1S=&%T92T^9V5T4V5R=F5R06YC:&]R3&%S="@D9&%T86)A<V4I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE-
M971A*"DL("=,87-T)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=.97AT)RP@)&%T=')S*3L*
M("`@("`@("`@("`@)&-H87)S(#T@)'-T871E+3YG971397)V97)!;F-H;W).
M97AT*"1D871A8F%S92D["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E
M<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D
M<W1A=&4M/F=E=%5224UE=&$H*2P@)TYE>'0G*3L*"B`@("`@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=!;F-H
M;W(G*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G365T82<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RD["B`@("`@("`@("`@
M("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T%L97)T
M)RD["@H@("`@("`@("`@("`D8W5R<F5N=$-M9$E$*RL["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@<V]U<F-E55))+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'-O=7)C955222`@3F5W('9A;'5E(&]F
M('!R;W!E<G1Y('-O=7)C955222X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M4V]U<F-E3&]C55))*"1S;W5R8V554DDI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]S;W5R8V554DD@/2`D<V]U<F-E55)).PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%1A<F=E=$QO8U5222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=&%R9V5T55)).PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O
M<B!P<F]P97)T>2!T87)G97154DDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&%R9V5T55))("!.97<@=F%L=64@;V8@<')O<&5R='D@=&%R9V5T
M55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971487)G97154DDH)'1A<F=E
M=%5222D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E=%5222`]("1T87)G
M97154DD["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL
M("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@("`@<&%R96YT.CIS=&%R
M=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@?0H*("`@
M(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@
M("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("!S=VET8V@@*&-O=6YT
M*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@
M("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?=&%R9V5T3&]C55))("$]("=T87-K<R<*("`@
M("`@("`@("`@("`@("8F("1T:&ES+3Y?=&%R9V5T3&]C55))("$]("=C86QE
M;F1A<B<*("`@("`@("`@("`@("`@("8F("1T:&ES+3Y?=&%R9V5T3&]C55))
M("$]("=N;W1E<R<*("`@("`@("`@("`@("`@("8F("1T:&ES+3Y?=&%R9V5T
M3&]C55))("$]("=C;VYT86-T<R<I('L*("`@("`@("`@("`@("`@("1B86-K
M96YD+3YL;V=-97-S86=E*"=%<G)O<B$@26YV86QI9"!D871A8F%S93H@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^
M7W1A<F=E=$QO8U5220H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G+B!/;FQY('1A<VMS+"!C86QE;F1A<BP@;F]T97,L)PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&%N9"!C;VYT
M86-T<R!A;&QO=V5D(2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@
M("`@("`@("`@("`@("!D:64H(F5R<F]R.B!I;G9A;&ED(&1A=&%B87-E(2(I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S
M<V%G92@G;&]O:VEN9R!F;W(@<WEN8R!F;W(@)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C55))+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)'-Y;F,@/2`F("1S
M=&%T92T^9V5T4WEN8R@D=&AI<RT^7W1A<F=E=$QO8U5222D["@H@("`@("`@
M("`@("!I9B`H(21S>6YC*2!["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^
M;&]G365S<V%G92@G0W)E871E(&YE=R!S>6YC(&9O<B`G("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C
M55))+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@
M("`@("`@)'-Y;F,@/2`F;F5W(%-Y;F--3%]3>6YC*"1T:&ES+3Y?86QE<G0L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]T87)G971,;V-54DDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V5,;V-54DDI.PH@("`@("`@
M("`@("`@("`@)'-T871E+3YS9713>6YC*"1T:&ES+3Y?=&%R9V5T3&]C55))
M+"`D<WEN8RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=$
M871A)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A;&5R="`](&EN='9A
M;"AT<FEM*"1T:&ES+3Y?8VAA<G,I*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`T.@H@("`@("`@("`@("!I9B`H
M)&5L96UE;G0@/3T@)TQO8U5222<I('L*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7U-T86-K6S)=(#T]("=3;W5R8V4G*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S;W5R8V5,;V-54DD@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?4W1A8VM;
M,ET@/3T@)U1A<F=E="<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W1A<F=E=$QO8U5222`](&)A<V5N86UE*'!R96=?<F5P;&%C92@G+UP_+BHD
M+R<L("<G+"!T<FEM*"1T:&ES+3Y?8VAA<G,I*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@-3H*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=.97AT)RD@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M971A06YC:&]R3F5X="`]('1R
M:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T@96QS96EF("@D96QE
M;65N="`]/2`G3&%S="<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;65T
M84%N8VAO<DQA<W0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<&%R
M96YT.CIE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971!;&5R="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?86QE<G0["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T06QE="@D86QE<G0I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]A;&5R="`]("1A;&5R=#L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]'
M970N<&AP````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$V,38`
M,3`U,34T,S$P-C``,#(Q,3,S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U-Y;F--3"]#
M;VUM86YD+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]#;VUM86YD7T=E="!C
M;&%S<RX*("H*("H@5&AI<R!C;&%S<R!R97-P;VYD<R!T;R!A(&-L:65N="!G
M970@<F5Q=65S="!A;F0@<F5T=7)N<R!T:&4@1&5V26YF"B`J(&EN9F]R;6%T
M:6]N(&9O<B!T:&4@4WEN8TU,('-E<G9E<BX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+T=E="YP:'`L=B`Q+C$T+C$P
M+C$P(#(P,#8O,#4O,CD@,38Z-#`Z,S<@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U
M<FUO;G0@/&9O=7)M;VYT0&=M>"YD93X*("H@0&%U=&AO<B`@06YT:&]N>2!-
M:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA
M;F1?1V5T(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*("`@(&9U;F-T:6]N
M(&]U='!U="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U="D*("`@('L*("`@("`@
M("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@
M("`@)')E9B`]("@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]/2`P*2`_("<N+V1E
M=FEN9C$P)R`Z("<N+V1E=FEN9C$Q)SL*"B`@("`@("`@)'-T871U<R`]("9N
M97<@4WEN8TU,7T-O;6UA;F1?4W1A='5S*"@D<W1A=&4M/FES075T:&]R:7IE
M9"@I(#\@4D534$].4T5?3TL@.B!215-03TY315])3E9!3$E$7T-2141%3E1)
M04Q3*2P@)T=E="<I.PH@("`@("`@("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI
M<RT^7V-M9$E$*3L*("`@("`@("`D<W1A='5S+3YS971487)G9712968H)')E
M9BD["B`@("`@("`@)&-U<G)E;G1#;61)1"`]("1S=&%T=7,M/F]U='!U="@D
M8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*"B`@("`@("`@:68@*"1S=&%T92T^
M:7-!=71H;W)I>F5D*"DI('L*("`@("`@("`@("`@)&%T=')S(#T@87)R87DH
M*3L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=297-U;'1S)RP@)&%T=')S*3L*"B`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G
M+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$
M.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)T-M9$E$)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<L("1A='1R<RD["B`@("`@
M("`@("`@("1C:&%R<R`]("1S=&%T92T^9V5T37-G240H*3L*("`@("`@("`@
M("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-<V=2968G
M*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G0VUD4F5F)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H
M87)S(#T@)'1H:7,M/E]C;61)1#L*("`@("`@("`@("`@)&]U='!U="T^8VAA
M<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=#;612968G*3L*"B`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T
M82<L("1A='1R<RD["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5224UE=&$H*2P@)U1Y<&4G+"`D871T<G,I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D;W5T<'5T+"`G6$U,7U="6$U,7T5N8V]D97(G
M*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<RA-24U%
M7U-93D--3%]$159)0T5?24Y&3U]70EA-3"D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*$U)345?
M4UE.0TU,7T1%5DE#15])3D9/7UA-3"D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE-971A
M*"DL("=4>7!E)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TUE=&$G*3L*"B`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E;2<L("1A
M='1R<RD["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G4V]U<F-E)RP@)&%T=')S*3L*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-5
M4DDG+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1R968I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@("`@("`@("`@)&]U='!U="T^
M96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E)RD["@H@("`@
M("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)T1A=&$G+"`D871T<G,I.PH*("`@("`@("`@("`@+RH@1&5V26YF(&1A
M=&$@:7,@<W1O<F5D(&EN('=B>&UL(&YO="!A<R!A('-E<&5R871E(&-O9&5P
M86=E(&)U=`H@("`@("`@("`@("`@*B!R871H97(@87,@82!C;VUP;&5T92!W
M8GAM;"!S=')E86T@87,@;W!A<75E(&1A=&$N("!3;R!W92!N965D(&$*("`@
M("`@("`@("`@("H@;F5W($AA;F1L97(N("HO"B`@("`@("`@("`@("1D979I
M;F9O=71P=70@/2`D;W5T<'5T+3YC<F5A=&53=6)(86YD;&5R*"D["B`@("`@
M("`@("`@(`H@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=$979);F8G+"`D871T<G,I
M.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T
M871E+3YG97154DE$979);F8H*2`L("=697)$5$0G+"`D871T<G,I.PH@("`@
M("`@("`@("`D9&5V:6YF;W5T<'5T+3YC:&%R86-T97)S*"@D<W1A=&4M/F=E
M=%9E<G-I;VXH*2`]/2`P*2`_("<Q+C`G(#H@)S$N,2<I.PH@("`@("`@("`@
M("`D9&5V:6YF;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V
M26YF*"D@+"`G5F5R1%1$)RP@)&%T=')S*3L*("`@("`@("`@("`@)&1E=FEN
M9F]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@
M+"`G36%N)RP@)&%T=')S*3L*("`@("`@("`@("`@)&1E=FEN9F]U='!U="T^
M8VAA<F%C=&5R<R@G5&AE($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R
M9&4N;W)G*2<I.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G36%N)RP@)&%T=')S*3L*
M("`@("`@("`@("`@)&1E=FEN9F]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T
M92T^9V5T55))1&5V26YF*"D@+"`G1&5V240G+"`D871T<G,I.PH@("`@("`@
M("`@("`D9&5V:6YF;W5T<'5T+3YC:&%R86-T97)S*"1?4T525D526R=(5%10
M7TA/4U0G72D["B`@("`@("`@("`@("1D979I;F9O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=$979)1"<L("1A='1R<RD[
M"B`@("`@("`@("`@("1D979I;F9O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%52241E=DEN9B@I("P@)T1E=E1Y<"<L("1A='1R<RD["B`@("`@
M("`@("`@("1D979I;F9O=71P=70M/F-H87)A8W1E<G,H)W-E<G9E<B<I.PH@
M("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))1&5V26YF*"D@+"`G1&5V5'EP)RP@)&%T=')S*3L*("`@("`@("`@
M("`@)'1H:7,M/E]W<FET941A=&%3=&]R92@G;F]T97,G+"`G=&5X="]X+79N
M;W1E)RP@)S$N,2<L("1D979I;F9O=71P=70L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)W1E>'0O<&QA:6XG(#T^("<Q+C`G
M*2D["B`@("`@("`@("`@("1T:&ES+3Y?=W)I=&5$871A4W1O<F4H)V-O;G1A
M8W1S)RP@)W1E>'0O>"UV8V%R9"<L("<S+C`G+"`D9&5V:6YF;W5T<'5T+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T97AT
M+W@M=F-A<F0G(#T^("<R+C$G*2D["B`@("`@("`@("`@("1T:&ES+3Y?=W)I
M=&5$871A4W1O<F4H)W1A<VMS)RP@)W1E>'0O8V%L96YD87(G+"`G,BXP)RP@
M)&1E=FEN9F]U='!U="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G=&5X="]X+79C86QE;F1A<B<@/3X@)S$N,"<I*3L*("`@
M("`@("`@("`@)'1H:7,M/E]W<FET941A=&%3=&]R92@G8V%L96YD87(G+"`G
M=&5X="]C86QE;F1A<B<L("<R+C`G+"`D9&5V:6YF;W5T<'5T+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T97AT+W@M=F-A
M;&5N9&%R)R`]/B`G,2XP)RDI.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G1&5V26YF
M)RP@)&%T=')S*3L*"B`@("`@("`@("`@("1O=71P=70M/F]P87%U92@D9&5V
M:6YF;W5T<'5T+3YG971/=71P=70H*2D["B`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G*3L*("`@("`@
M("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G
M271E;2<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=297-U;'1S)RD["@H@("`@("`@("`@("`D8W5R<F5N
M=$-M9$E$*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-U<G)E;G1#
M;61)1#L*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E<R!$979);F8@9&%T
M82!F;W(@;VYE($1A=&%3=&]R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S;W5R8V5R968Z(&1A=&$@9F]R(%-O=7)C95)E9B!E;&5M96YT+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;6EM971Y<&4Z(&1A=&$@9F]R("9L=#LH
M4GQ4*7@M4')E9B9G=#LF;'0[0U14>7!E)F=T.PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D=F5R<VEO;CH@9&%T82!F;W(@)FQT.RA2?%0I>"U0<F5F)F=T.R9L
M=#M697)#5"9G=#L*("`@("`J($!P87)A;2!S=')I;F<@)B1O=71P=70@8V]N
M=&5N=&AA;F1L97(@=&AA="!W:6QL(')E8V5I=F5D('1H92!O=71P=70N"B`@
M("`@*B!`<&%R86T@87)R87D@)&%D9&ET:6]N86QT>7!E<SH@87)R87D@;V8@
M861D:71I;VYA;"!T>7!E<R!F;W(@5'@@86YD(%)X.PH@("`@("H@("`@("`@
M("`@("`@(&9O<FUA="!A<G)A>2@G=&5X="]V8V%R9"<@/3X@)S(N,"<I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]W<FET941A=&%3=&]R92@D<V]U<F-E<F5F
M+"`D;6EM971Y<&4L("1V97)S:6]N+"`F)&]U='!U="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D861D:71I;VYA;'1Y<&5S(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@)'-T871E
M(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T1A
M=&%3=&]R92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4V]U<F-E4F5F)RP@)&%T
M=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1S;W5R8V5R968I
M.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$
M979);F8H*2`L("=3;W5R8V52968G+"`D871T<G,I.PH*("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=2
M>"U0<F5F)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I
M.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&UI;65T>7!E*3L*("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF
M*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#5"<L("1A
M='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D=F5R<VEO;BD[
M"B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E
M=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4G@M4')E9B<L
M("1A='1R<RD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D861D:71I;VYA;'1Y
M<&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D861D:71I;VYA;'1Y<&5S
M(&%S("1C="`]/B`D8W1V97(I>PH@("`@("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4G@G+"`D
M871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*
M("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-T*3L*("`@
M("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF
M*"D@+"`G5F5R0U0G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U
M="T^8VAA<F%C=&5R<R@D8W1V97(I.PH@("`@("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4
M)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=2>"<L("1A='1R<RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U1X+5!R968G+"`D
M871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)T-45'EP92<L("1A='1R<RD["B`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D;6EM971Y<&4I.PH@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=#5%1Y
M<&4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1V97)S:6]N*3L*("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G
M5F5R0U0G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=4>"U0<F5F)RP@)&%T=')S*3L*
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A9&1I=&EO;F%L='EP97,I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1A9&1I=&EO;F%L='EP97,@87,@)&-T(#T^
M("1C='9E<BE["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=4>"<L("1A='1R<RD["B`@
M("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@("`@("`@("`@
M("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8W0I.PH@("`@("`@("`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I
M("P@)T-45'EP92<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#
M5"<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T
M97)S*"1C='9E<BD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5F5R0U0G+"`D871T<G,I
M.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)U1X)RP@)&%T=')S*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G4WEN8T-A<"<L("1A='1R<RD["B`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V
M26YF*"D@+"`G4WEN8U1Y<&4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M
M/F-H87)A8W1E<G,H)S$G*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4WEN8U1Y<&4G+"`D871T<G,I
M.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M241E=DEN9B@I("P@)U-Y;F-4>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T
M<'5T+3YC:&%R86-T97)S*"<R)RD["B`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U-Y;F-4>7!E)RP@)&%T
M=')S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))1&5V26YF*"D@+"`G4WEN8T-A<"<L("1A='1R<RD["B`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T1A
M=&%3=&]R92<L("1A='1R<RD["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#
M;VUM86YD+U-Y;F,N<&AP````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,3(R-@`Q,#4Q-30S,3`V,``P,C$S,C0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G
M4WEN8TU,+T-O;6UA;F0N<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M
M;6%N9"]3>6YC16QE;65N="YP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W
M;W)K+U-Y;F--3"]3>6YC34PO0V]M;6%N9"]3>6YC+G!H<"QV(#$N,3<N,3`N
M."`R,#`V+S`Q+S$Q(#$X.C,Y.C(X('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R
M9&4N;W)G/@H@*@H@*B!4:&4@8V]M;6%N9"!H86YD;&5R(&9O<B!T:&4@)F=T
M.U-Y;F,F;'0[(&-O;6UA;F0@:7,@=&AE(&-E;G1R86P*("H@8VQA<W,@=&\@
M9&ES<&%T8V@@<WEN8R!M97-S86=E<RX*("H*("H@1'5R:6YG('!A<G-I;F<@
M;V8@=&AE(')E8V5I=F5D(%A-3"P@=&AE(&%C='5A;"!S>6YC(&-O;6UA;F1S
M("A!9&0L"B`J(%)E<&QA8V4L($1E;&5T92D@9G)O;2!T:&4@8VQI96YT(&%R
M92!S=&]R960@:6X@=&AE(%]S>6YC16QE;65N=',*("H@871T<FEB=71E+B`@
M5VAE;B!T:&4@;W5T<'5T(&UE=&AO9"!O9B!3>6YC34Q?0V]M;6%N9%]3>6YC
M(&ES"B`J(&-A;&QE9"P@=&AE<V4@96QE;65N=',@87)E('!R;V-E<W-E9"!A
M;F0@=&AE(')E<W5L=&EN9R!S=&%T=7,*("H@;65S<V%G97,@8W)E871E9"X*
M("H*("H@5&AE;B!T:&4@<V5R=F5R(&UO9&EF:6-A=&EO;G,@87)E('-E;G0@
M8F%C:R!T;R!T:&4@8VQI96YT(&)Y('1H90H@*B!H86YD;&53>6YC(&UE=&AO
M9"!W:&EC:"!I<R!C86QL960@9G)O;2!W:71H:6X@=&AE(&]U='!U="!M971H
M;V0N"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M
M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?
M4WEN8R!E>'1E;F1S(%-Y;F-M;%]#;VUM86YD"GL*("`@("\J*@H@("`@("H@
M0'9A<B!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N=`H@("`@("HO"B`@("!V
M87(@)%]C=7)R96YT4WEN8T5L96UE;G0["@H@("`@+RHJ"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-Y;F-%;&5M96YT<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!C;VYT86-T<RP@8V%L96YD87(L('1A<VMS
M(&]R(&YO=&5S"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?=&%R9V5T55)).PH*("`@("\J*@H@("`@("H@0W)E871E<R!A
M(')E<W!O;G-E('1O(&$@<WEN8R!C;VUM86YD+@H@("`@("H@0W5R<F5N=&QY
M('1H870G<R!T:&4@<&QA8V4@=VAE<F4@=V4@86QS;R!C<F5A=&4*("`@("`J
M('1H92`F;'0[<WEN8R9G=#L@=VET:"!T:&4@<V5R=F5R(&-H86YG97,@=&AA
M=`H@("`@("H@;F5E9',@=&\@8F4@<V5N9"!T;R!T:&4@8VQI96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P
M=70I"B`@("!["B`@("`@("`@)'-T871E(#TF("1?4T534TE/3ELG4WEN8TU,
M+G-T871E)UT["B`@("`@("`@)'-Y;F,@/28@)'-T871E+3YG9713>6YC*"1T
M:&ES+3Y?=&%R9V5T55))*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D<WEN
M8RDI('L*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S
M<V%G92@G3F\@<WEN8R!O8FIE8W0@9F]U;F0@9F]R(%5222`]("<@+B`D=&AI
M<RT^7W1A<F=E=%5222P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@("\O($!43T1/.B!C<F5A=&4@;65A;FEN9V9U;"!S
M=&%T=7,@8V]D92!H97)E+@H@("`@("`@('T*"B`@("`@("`@+R\@2&5R92=S
M('=H97)E(&-L:65N="!M;V1I9FEC871I;VYS(&%R92!P<F]C97-S960Z"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]S>6YC16QE;65N=',@87,@)&5L96UE
M;G0I('L*("`@("`@("`@("`@9F]R96%C:"`H)&5L96UE;G0M/F=E=$ET96US
M*"D@87,@)&ET96TI('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D<WEN
M8RT^:&%N9&QE4WEN8TET96TH)&ET96TI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1C=7)R96YT0VUD240@/2`D96QE;65N="T^;W5T<'5T*"1C=7)R
M96YT0VUD240L("1O=71P=70I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]W
M('-E;F0@8VQI96YT(&-H86YG97,@=&\@<V5R=F5R.B!T:&ES('=I;&P@<')E
M8V5D92!T:&4*("`@("`@("`@*B`\<WEN8SX@<F5S<&]N<V4Z("HO"B`@("`@
M("`@)&-U<G)E;G1#;61)1"`]("1S>6YC+3YC<F5A=&53>6YC3W5T<'5T*"1C
M=7)R96YT0VUD240L("1O=71P=70I.PH*("`@("`@("`D<W1A='5S(#T@)FYE
M=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H4D534$].4T5?3TLL("=3>6YC)RD[
M"B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*
M("`@("`@("!I9B`H)'1H:7,M/E]T87)G97154DD@(3T@;G5L;"D@>PH@("`@
M("`@("`@("`D<W1A='5S+3YS971487)G9712968H)'1H:7,M/E]T87)G9715
M4DDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?<V]U<F-E55))
M("$](&YU;&PI('L*("`@("`@("`@("`@)'-T871U<RT^<V5T4V]U<F-E4F5F
M*"1T:&ES+3Y?<V]U<F-E55))*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<W1A='5S+3YO=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T5&%R9V5T55))*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]T87)G97154DD["B`@("!]"@H@("`@9G5N8W1I
M;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("![
M"B`@("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L
M("1A='1R<RD["@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C
M:RDI('L*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N
M="`]/2`G4F5P;&%C92<@?'P@)&5L96UE;G0@/3T@)T%D9"<@?'P@)&5L96UE
M;G0@/3T@)T1E;&5T92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R
M<F5N=%-Y;F-%;&5M96YT(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3>6YC16QE
M;65N="@D96QE;65N="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C=7)R
M96YT4WEN8T5L96UE;G0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=%-Y;F-%;&5M96YT+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A
M='1R<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V-U<G)E;G13>6YC16QE;65N="T^96YD16QE;65N="@D=7)I+"`D96QE
M;65N="D["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES
M+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H
M)&5L96UE;G0@/3T@)U)E<&QA8V4G('Q\("1E;&5M96YT(#T]("=!9&0G('Q\
M("1E;&5M96YT(#T]("=$96QE=&4G*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-Y;F-%;&5M96YT<UM=(#T@)'1H:7,M/E]C=7)R96YT4WEN8T5L96UE
M;G0["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-U<G)E;G13>6YC
M16QE;65N="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T@)TQO
M8U5222<@)B8@(6ES<V5T*"1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U-O
M=7)C92<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C9552
M22`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G5&%R9V5T)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T55))(#T@8F%S96YA;64H<')E
M9U]R97!L86-E*"<O7#\N*B0O)RP@)R<L('1R:6TH)'1H:7,M/E]C:&%R<RDI
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N
M="@D=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C
M=&5R<R@D<W1R*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-U
M<G)E;G13>6YC16QE;65N="DI('L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT4WEN8T5L96UE;G0M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA<G,I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H87)S(#T@)'1H:7,M/E]C:&%R
M<R`N("1S='(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H87)S(#T@)'-T<CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3
M>6YC34PO4W1A=&4N<&AP````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,C0Q,30`,3`U,34T,S$P-C``,#(P,3$R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)U-Y;F--3"]$979I8V5);F9O+G!H<"<["G)E<75I<F5?;VYC92`G
M4WEN8TU,+T1E=FEC92YP:'`G.PIR97%U:7)E7V]N8V4@)U-Y;F--3"]#;VYS
M=&%N=',N<&AP)SL*"B\J*@H@*B!4:&4@4WEN8TU,7U-T871E(&-L87-S('!R
M;W9I9&5S(&$@4WEN8TU,('-T871E(&]B:F5C="X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]3=&%T92YP:'`L=B`Q+C$W+C(N."`R
M,#`V+S`Q+S`Q(#(Q.C(X.C,V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA
M;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?4W1A=&4@>PH*("`@
M("\J*@H@("`@("H@4V5S<VEO;B!I9"!O9B!T:&ES('-E<W-I;VXN"B`@("`@
M*B\*("`@('9A<B`D7W-E<W-I;VY)1#L*"B`@("`O*BH*("`@("`J($ED(&]F
M(&-U<G)E;G0@;65S<V%G92X*("`@("`J+PH@("`@=F%R("1?;7-G240["@H@
M("`@+RHJ"B`@("`@*B!4:&4@=&%R9V5T(%5222!A<R!S96YT(&)Y('1H92!C
M;&EE;G0N(%1H:7,@:7,@;F]R;6%L;'D@=&AE(%523`H@("`@("H@;V8@=&AE
M($AO<F1E(')P8R!S97)V97(N($AO=V5V97(@=&AE(&-L:65N="!I<R!F<F5E
M('1O('-E;F0*("`@("`J(&%N>71H:6YG.B!S>6YC-&H@9F]R(&5X86UP;&4@
M9&]E<R!N;W0@<V5N9"!T:&4@<&%T:"!P87)T+@H@("`@("HO"B`@("!V87(@
M)%]T87)G97154DD["@H@("`@+RHJ"B`@("`@*B!4:&4@<V]U<F-E(%5222!A
M<R!S96YT(&)Y('1H92!C;&EE;G0N($-A;B!B92!U<V5D('1O(&ED96YT:69Y
M"B`@("`@*B!T:&4@8VQI96YT.R!T:&4@<V5S<VEO;B!I9"!I<R!C;VYS=')U
M8W1E9"!M86EN;'D@9G)O;2!T:&ES"B`@("`@*B!D871A+@H@("`@("HO"B`@
M("!V87(@)%]S;W5R8V554DD["@H@("`@+RHJ"B`@("`@*B`P(&9O<B!S>6YC
M;6P@,2XP+"`Q(&9O<B!S>6YC;6P@,2XQ+@H@("`@("HO"B`@("!V87(@)%]V
M97)S:6]N.PH*("`@("\J*@H@("`@("H@57-E<FYA;64@=7-E9"!T;R!A=71H
M('=I=&@@=&AE(&)A8VME;F0N"B`@("`@*B\*("`@('9A<B`D7VQO8TYA;64[
M"@H@("`@+RHJ"B`@("`@*B!087-S=V]R9"!U<V5D('1O(&%U=&@@=VET:"!T
M:&4@8F%C:V5N9"X*("`@("`J+PH@("`@=F%R("1?<&%S<W=O<F0["@H@("`@
M+RHJ"B`@("`@*B!4<G5E(&UE86YS('1H870@=&AI<R!S97-S:6]N(&AA<R!A
M=71H96YT:6-A=&5D('-U8V-E<W-F=6QL>2X*("`@("`J+PH@("`@=F%R("1?
M:7-!=71H;W)I>F5D.PH*("`@("\J*@H@("`@("H@3F%M97-P86-E(&EN9F]R
M;6%T:6]N+@H@("`@("HO"B`@("!V87(@)%]U<FD["@H@("`@+RHJ"B`@("`@
M*B!.86UE<W!A8V4@:6YF;W)M871I;VXN"B`@("`@*B\*("`@('9A<B`D7W5R
M:4UE=&$["@H@("`@+RHJ"B`@("`@*B!.86UE<W!A8V4@:6YF;W)M871I;VXN
M"B`@("`@*B\*("`@('9A<B`D7W5R:41E=DEN9CL*"B`@("!V87(@)%]W8GAM
M;#L@+R\@8F]O;&5A;@H*("`@('9A<B`D7VUA>$US9U-I>F4["@H@("`@=F%R
M("1?<WEN8W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5W)I='1E;B!T
M;R!D8B!A9G1E<B!S=6-C97-S9G5L('-Y;F,N"B`@("`@*B\*("`@('9A<B`D
M7V-L:65N=$%N8VAO<DYE>'0@/2!A<G)A>2@I.PH*("`@('9A<B`D7W-E<G9E
M<D%N8VAO<DQA<W0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5W)I='1E
M;B!T;R!D8B!A9G1E<B!S=6-C97-S9G5L('-Y;F,N"B`@("`@*B\*("`@('9A
M<B`D7W-E<G9E<D%N8VAO<DYE>'0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@4VUA;&P@:&%S:"!T;R!S=&]R92!T:&4@;G5M8F5R(&]F(&%D9',L(&1E
M;&5T97,L(&5T8RX@9'5R:6YG(&$*("`@("`J('-E<W-I;VX@9F]R(&-R96%T
M:6]N(&]F('-U;6UA<GD@9F]R(&QO9V9I;&4N"B`@("`@*B\*("`@('9A<B`D
M7VQO9R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@4WEN8TU,7T1E
M=FEC92!C;&%S<R!D969I;F5D(&EN($1E=FEC92YP:'`N(%1H:7,@8VQA<W,*
M("`@("`J(&AA;F1L97,@9&5C:6-E('-P96-I9FEC('-T=69F+@H@("`@("HO
M"B`@("!V87(@)%]D979I8V4["@H@("`@+RHJ"B`@("`@*B!$979I8V4@:6YF
M;R!P<F]V:61E9"!B>2!T:&4@4WEN8TU,($1E=DEN9B!D871A+B!-86EN;'D@
M=7-E9"!B>0H@("`@("H@=&AE(%-Y;F--3%]$979I8V4@8VQA<W,N"B`@("`@
M*B\*("`@('9A<B`D7V1E=FEC94EN9F\["@H@("`@+RHJ"B`@("`@*B!)9B!W
M92!A<F4@97AP96-T:6YG(&$@4F5S=6QT('!A8VME="P@=&AI<R!S=&]R97,@
M=VAE<F4@=&\*("`@("`J(')O=71E(&ET+@H@("`@("HO"B`@("!V87(@)%]E
M>'!E8W1E9%)E<W5L="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S(&$@;F5W(&EN<W1A;F-E(&]F(%-Y;F--3%]3=&%T92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@4WEN8TU,7U-T871E*"1S;W5R8V554DDL("1L;V-.86UE
M+"`D<V5S<VEO;DE$+"`D<&%S<W=O<F0@/2!F86QS92D*("`@('L*("`@("`@
M("`D=&AI<RT^<V5T4V]U<F-E55))*"1S;W5R8V554DDI.PH@("`@("`@("1T
M:&ES+3YS971,;V-.86UE*"1L;V-.86UE*3L*("`@("`@("`D=&AI<RT^<V5T
M4V5S<VEO;DE$*"1S97-S:6]N240I.PH@("`@("`@(&EF("@D<&%S<W=O<F0I
M('L*("`@("`@("`@("`@)'1H:7,M/G-E=%!A<W-W;W)D*"1P87-S=V]R9"D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^:7-!=71H;W)I>F5D(#T@9F%L
M<V4["@H@("`@("`@("\O($-R96%T92!E;7!T>2!D=6UM>2!D979I8V4@:6YF
M;RX@5VEL;"!B92!R97!L86-E9"!W:71H(')E86P*("`@("`@("`O+R!$979)
M;F8@:6YF;W)M871I;VX@:68@=&AE>2!A<F4@=')A;G-F97)R960N"B`@("`@
M("`@)'1H:7,M/E]D979I8V5);F9O(#T@)FYE=R!3>6YC34Q?1&5V:6-E26YF
M;R@I.PH*("`@("`@("`O*B!A;&QO=R!V97)Y(&)I9R!M97-S86=E<R!U;FQE
M<W,@=&]L9"!O=&AE<G=I<V4Z("HO"B`@("`@("`@)'1H:7,M/G-E=$UA>$US
M9U-I>F4H,3`P,#`P,#`P,"D["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T1&5V
M:6-E26YF;R@D9&DI"B`@("!["B`@("`@("`@)'1H:7,M/E]D979I8V5);F9O
M(#T@)&1I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$1E=FEC94EN9F\H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1E=FEC94EN9F\["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T3&]C3F%M92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?;&]C3F%M93L*("`@('T*"B`@("!F=6YC=&EO;B!G9713
M;W5R8V554DDH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-O=7)C
M955223L*("`@('T*"B`@("!F=6YC=&EO;B!G971487)G97154DDH*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1A<F=E=%5223L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971697)S:6]N*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]V97)S:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$US9TE$
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M<V=)1#L*("`@('T*
M"B`@("!F=6YC=&EO;B!S97170EA-3"@D=V)X;6PI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]W8GAM;"`]("1W8GAM;#L*("`@('T*"B`@("!F=6YC=&EO;B!I
M<U="6$U,*"D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3Y?
M=V)X;6PI.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$UA>$US9U-I>F4H)',I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]M87A-<V=3:7IE(#T@)',["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T36%X37-G4VEZ92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?;6%X37-G4VEZ93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E='1E<B!F;W(@<')O<&5R='D@;7-G240N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;7-G240@($YE=R!V86QU92!O9B!P<F]P97)T>2!M
M<V=)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T37-G240H)&US9TE$*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?;7-G240@/2`D;7-G240["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(&QO8TYA;64N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&]C3F%M92`@3F5W('9A;'5E
M(&]F('!R;W!E<G1Y(&QO8TYA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$QO8TYA;64H)&QO8TYA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]L;V-.
M86UE(#T@)&QO8TYA;64["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4&%S<W=O
M<F0H)'!A<W-W;W)D*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%S<W=O<F0@
M/2`D<&%S<W=O<F0["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4V]U<F-E55))
M*"1S;W5R8V554DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]S;W5R8V554DD@
M/2`D<V]U<F-E55)).PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%1A<F=E=%52
M22@D=&%R9V5T55))*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&%R9V5T55))
M(#T@)'1A<F=E=%5223L*("`@('T*"B`@("!F=6YC=&EO;B!S971697)S:6]N
M*"1V97)S:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F5R<VEO;B`]("1V
M97)S:6]N.PH*("`@("`@("!I9B`H)'9E<G-I;VX@/3T@,"D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W5R:2`]($Y!345?4U!!0T5?55))7U-93D--3#L*("`@
M("`@("`@("`@)'1H:7,M/E]U<FE-971A(#T@3D%-15]34$%#15]54DE?3454
M24Y&.PH@("`@("`@("`@("`D=&AI<RT^7W5R:41E=DEN9B`]($Y!345?4U!!
M0T5?55))7T1%5DE.1CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7W5R:2`]($Y!345?4U!!0T5?55))7U-93D--3%\Q7S$["B`@("`@
M("`@("`@("1T:&ES+3Y?=7)I365T82`]($Y!345?4U!!0T5?55))7TU%5$E.
M1E\Q7S$["B`@("`@("`@("`@("1T:&ES+3Y?=7)I1&5V26YF(#T@3D%-15]3
M4$%#15]54DE?1$5624Y&7S%?,3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T4V5S<VEO;DE$*"1S97-S:6]N240I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S97-S:6]N240@/2`D<V5S<VEO;DE$.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&ES075T:&]R:7IE9"@I"B`@("!["B`@("`@("`@:68@*"$D=&AI
M<RT^7VES075T:&]R:7IE9"`F)B`A96UP='DH)'1H:7,M/E]P87-S=V]R9"DI
M('L*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G
M92@G8VAE8VMI;F<@875T:"!F;W(@=7-E<CTG"B`@("`@("`@("`@("X@)'1H
M:7,M/E]L;V-.86UE+`H@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`D875T:"`]("9!=71H
M.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G
M72D["B`@("`@("`@("`@("1T:&ES+3Y?:7-!=71H;W)I>F5D(#T@)&%U=&@M
M/F%U=&AE;G1I8V%T92@D=&AI<RT^7VQO8TYA;64L(&%R<F%Y*"=P87-S=V]R
M9"<@/3X@)'1H:7,M/E]P87-S=V]R9"DI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:7-!=71H;W)I>F5D.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-E=%-Y;F,H)'1A<F=E="P@)B1S>6YC*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<WEN8W-;)'1A<F=E=%T@/2`F)'-Y;F,["B`@("!]"@H@("`@9G5N
M8W1I;VX@)F=E=%-Y;F,H)'1A<F=E="D*("`@('L*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]S>6YC<ULD=&%R9V5T72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<WEN8W-;)'1A<F=E=%T["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&9A;'-E(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R
M;B`D9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=%52
M22@I"B`@("!["B`@("`@("`@+RH*("`@("`@("`@*B!4:&4@;F]N(%="6$U,
M(&1E=FEC97,@*&YO=&%B;'D@4#DP,"!A;F0@4WEN8S1J('-E96T@=&\@9V5T
M(&-O;F9U<V5D"B`@("`@("`@("H@8GD@82`\4WEN8TU,('AM;&YS/2)S>6YC
M;6PZ4UE.0TU,,2XQ(CX@96QE;65N="X@5&AE>2!R97%U:7)E"B`@("`@("`@
M("H@:G5S="`\4WEN8TU,/BX@4V\@9&]N)W0@=7-E(&%N(&YS(&9O<B!N;VX@
M=V)X;6P@9&5V:6-E<RX*("`@("`@("`@*B\*("`@("`@("!I9B`H)'1H:7,M
M/FES5T)834PH*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]U<FD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@('T*("`@('T*("`@(&9U;F-T:6]N(&=E=%5224UE=&$H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W5R:4UE=&$["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T55))1&5V26YF*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]U<FE$979);F8["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T0VQI96YT
M06YC:&]R3F5X="@D='EP92P@)&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]C
M;&EE;G1!;F-H;W).97AT6R1T>7!E72`]("1A.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-E=%-E<G9E<D%N8VAO<DQA<W0H)'1Y<&4L("1A*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<V5R=F5R06YC:&]R3&%S=%LD='EP95T@/2`D83L*("`@
M('T*"B`@("!F=6YC=&EO;B!S971397)V97)!;F-H;W).97AT*"1T>7!E+"`D
M82D*("`@('L*("`@("`@("`D=&AI<RT^7W-E<G9E<D%N8VAO<DYE>'1;)'1Y
M<&5=(#T@)&$["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VQI96YT06YC:&]R
M3F5X="@D='EP92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;&EE
M;G1!;F-H;W).97AT6R1T>7!E73L*("`@('T*"B`@("!F=6YC=&EO;B!G9713
M97)V97)!;F-H;W).97AT*"1T>7!E*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W-E<G9E<D%N8VAO<DYE>'1;)'1Y<&5=.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=%-E<G9E<D%N8VAO<DQA<W0H)'1Y<&4I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<V5R=F5R06YC:&]R3&%S=%LD='EP95T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@;&]G('-I;7!L>2!C;W5N=',@=&AE
M(&5N=')I97,@9F]R(&5A8V@@=&]P:6,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QO9R@D=&]P:6,I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M;&]G6R1T;W!I8UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&]G6R1T;W!I
M8UT@*ST@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7VQO9ULD=&]P:6-=(#T@,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!4:&4@3&]G(&ES(&%N(&%R<F%Y('=H97)E('1H92!K97D@:7,@=&AE
M(&5V96YT(&YA;64@86YD('1H90H@("`@("H@=F%L=64@<V%Y<R!H;W<@;V9T
M96X@=&AI<R!E=F5N="!O8V-U<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971,;V<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VQO9SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@:61E;G1I9FEE<B!U<V5D
M('1O(&ED96YT:69Y('1H92!S>6YC(&1E=FEC92!I;B!T:&4*("`@("`J(&UA
M<"X@0W5R<F5N=&QY(")L;V-N86UE.G-O=7)C955222(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-Y;F-)9&5N=&EF:65R*"D*("`@('L*("`@("`@("!R
M971U<FX@<W1R7W)E<&QA8V4H)SHG+"`G7R<L("1T:&ES+3Y?;&]C3F%M92D*
M("`@("`@("`@("`@("`@("X@)SHG"B`@("`@("`@("`@("`@("`N('-T<E]R
M97!L86-E*"<Z)RP@)U\G+"`D=&AI<RT^7W-O=7)C955222D["B`@("!]"@H@
M("`@9G5N8W1I;VX@)F=E=$1E=FEC92@I"B`@("!["B`@("`@("`@<F5T=7)N
M(%-Y;F--3%]$979I8V4Z.G-I;F=L971O;B@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@97AP96-T960@<F5S=6QT('1Y<&4@9F]R(&$@
M4F5S=6QT<R!T86<L('5S960@=&\@<F5D:7)E8W0@=&AE"B`@("`@*B!I;F-O
M;6EN9R!C;VUM86YD('-O;65W:&5R92!S<&5C:6%L+B`@1F]R(&5X86UP;&4L
M(&EF('=E(&AA=F4@<F5Q=65S=&5D"B`@("`@*B!D979I8V4@:6YF;RP@=&AE
M(%)E<W5L=',@=&%G('-H;W5L9"!B92!S96YT('1O('1H92!0=70@8V]M;6%N
M9"!S;R!W92!C86X*("`@("`J(')E860@:70@:6XN"B`@("`@*@H@("`@("H@
M0VQE87)S('1H92!H87-H(&]F('1H:7,@0V]M;6%N9"!2969E<F5N8V4@8F5F
M;W)E(')E='5R;FEN9R!A('9A;'5E+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C;612968@(%1H92!#;612968@;V8@=&AE(&EN8V]M:6YG(&-O
M;6UA;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VUM
M86YD('1Y<&4@=&\@<F5D:7)E8W0@=&\L(&]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@=6YD969I;F5D(&EF(&YO(')E9&ER96-T(')E9VES=&5R960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$5X<&5C=&5D4F5S=6QT5'EP92@D8VUD
M4F5F*0H@("`@>PH@("`@("`@(&EF("@@:7-S970H)'1H:7,M/E]E>'!E8W1E
M9%)E<W5L=%LD8VUD4F5F72D@*2!["B`@("`@("`@("`@("1C;614>7!E(#T@
M)'1H:7,M/E]E>'!E8W1E9%)E<W5L=%LD8VUD4F5F73L*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]E>'!E8W1E9%)E<W5L=%LD8VUD4F5F72D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D8VUD5'EP93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E=',@=7`@82!C;VUM86YD(')E9&ER96-T:6]N(&9O<B!A(&9U
M='5R92!297-U;'0@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8VUD240@("`@5&AE($-M9$E$(&]F('1H92!C;VUM86YD('=E(&%R
M92!S96YD:6YG('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AE(&-L:65N="X*("`@("`J($!P87)A;2!S=')I;F<@("1C;614>7!E("!4
M:&4@='EP92!O9B!C;VUM86YD('1O(')E9&ER96-T('1O('=H96X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@4F5S=6QT<R!C;VUM86YD
M(&ES(')E8V5I=F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971%>'!E8W1E
M9%)E<W5L=%1Y<&4H)&-M9$E$+"`D8VUD5'EP92D*("`@('L*("`@("`@("`D
M=&AI<RT^7V5X<&5C=&5D4F5S=6QT6R1C;61)1%T@/2`D8VUD5'EP93L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H96-K(&EF('1H97)E(&%R92!A;GD@<&5N
M9&EN9R!E;&5M96YT<R!T:&%T(&AA=F4@;F]T(&)E96X@<V5N="!T;R!D=64*
M("`@("`J('1O(&UE<W-A9V4@<VET>F4@<F5S=')I8W1I;VYS+B!4:&5S92!W
M:6QL(&)E('-E;G0@:6YT('1H92!N97AT(&US9RX*("`@("`J"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&AA<U!E;F1I;F=%;&5M96YT<R@I"B`@("!["@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7W-Y;F-S*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7W-Y;F-S(&%S("1S>6YC*2!["B`@("`@("`@
M("`@("`@("!I9B`H)'-Y;F,M/FAA<U!E;F1I;F=%;&5M96YT<R@I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@<WEN8W,@
M=VAI8V@@:&%V92!P96YD:6YG(&5L96UE;G1S(&QE9G0N"B`@("`@*B!2971U
M<FYS(&%N(&%R<F%Y(&]F(%1A<F=E=$QO8U5227,@=VAI8V@@8V%N(&)E('5S
M960*("`@("`J(&%S(&$@:V5Y(&EN(&=E=%-Y;F,@8V%L;',N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!E;F1I;F=3>6YC<R@I"B`@("!["B`@("`@("`@
M)'(@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7W-Y
M;F-S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W-Y;F-S(&%S
M("1T87)G970@/3X@)'-Y;F,I('L*("`@("`@("`@("`@("`@(&EF("@D<WEN
M8RT^:&%S4&5N9&EN9T5L96UE;G1S*"DI('L*("`@("`@("`@("`@("`@("`@
M("`D<EM=(#T@)'1A<F=E=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'(["B`@("!]"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U-Y;F--3"]"86-K96YD+G!H<```````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-S0U-``Q,#4Q-30S,3`V,``P,C`S
M-S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%-Y;F--3"!"86-K96YD(&9O<B!T:&4@2&]R9&4@07!P
M;&EC871I;VX@9G)A;65W;W)K+@H@*@H@*B!4:&4@8F%C:V5N9"!P<F]V:61E
M<R!T:&4@9F]L;&]W:6YG(&9U;F-T:6]N86QI='DZ"B`J"B`J(#$I(&AA;F1L
M:6YG(&]F('1H92!A8W1U86P@9&%T82P@:2YE+@H@*B`@("!A*2!A9&0O<F5P
M;&%C92]D96QE=&4@96YT<FEE<R!T;R!A;F0@<F5T<FEE=F4@96YT<FEE<R!F
M<F]M('1H90H@*B`@("`@("!B86-K96YD"B`J("`@(&(I(')E=')I979E(&AI
M<W1O<GD@=&\@9FEN9"!O=70@=VAA="!E;G1R:65S(&AA=F4@8F5E;B!C:&%N
M9V5D"B`J(#(I(&UA;F%G:6YG(&]F('1H92!M87`@8F5T=V5E;B!C;&EE;F0@
M241S(&%N9"!S97)V97(@241S"B`J(#,I('-T;W)E(&EN9F]R;6%T:6]N(&%B
M;W5T('-Y;F,@86YC:&]R<R`H=&EM97-T86UP<RD@;V8@<')E=FEO=7,*("H@
M("`@<W5C8V5S<V9U;',@<WEN8R!S97-S:6]N<PH@*B`T*2!S97-S:6]N(&AA
M;F1L:6YG("AN;W0@>65T+"!S=&EL;"!T;R!B92!D;VYE*0H@*B`U*2!A=71H
M;W)I<V%T:6]N("AN;W0@>65T+"!S=&EL;"!T;R!B92!D;VYE*0H@*B`V*2!L
M;V=G:6YG"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R
M;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T)A8VME;F0N<&AP+'8@
M,2XX+C(N."`R,#`V+S`W+S$X(#$R.C`P.C4V(&IA;B!%>'`@)`H@*@H@*B!`
M875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*
M("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0F%C:V5N9%](
M;W)D92!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!A<R!V86QU92!I;F1I
M8V%T97,@=&AA="!F;W(@=&AI<R!C;&EE;G0@8V%T96=O<GD@;F\*("`@("`J
M('-E<G9E<B!C871E9V]R>2!I<R!D969I;F5D('EE="X@5&AE(&%R<F%Y(&-O
M;G1E;G0@:7,@=&AE"B`@("`@*B!S=6UM87)Y('1E>'0@;V8@=&AE(&QA<W0@
M96YC;W5N=&5R960@8VQI96YT(&5N=')Y('1H870@=7-E9`H@("`@("H@=&AI
M<R!C871E9V]R>2X*("`@("`J"B`@("`@*B`@(&ME>3H@("!C;&EE;G1#871E
M9V]R>0H@("`@("H@("!V86QU93H@<V5R=F5R0V%T96=O<GD*("`@("`J+PH@
M("`@=F%R("1?8V%T96=O<FEE<TUA<#L*"B`@("`O*BH*("`@("`J(%-E<G9E
M<B!C871E9V]R:65S(&UI<W-I;F<@;VX@=&AE(&-L:65N="X*("`@("`J"B`@
M("`@*B`@(&ME>3H@("!S97)V97)#871E9V]R>0H@("`@("H@("!V86QU93H@
M<W5M;6%R>2!O9B!L87-T(&5N=')Y('=I=&@@=&AI<R!C871E9V]R>0H@("`@
M("HO"B`@("!V87(@)%]M:7-S:6YG4V5R=F5R0V%T96=O<FEE<SL*"B`@("!V
M87(@)%]D871A=')E93L*"B`@("`O*BH*("`@("`J($-A8VAE(&9O<B!$871A
M=')E92!V86QU97,*("`@("`J+PH@("`@(`H@("`@=F%R("1?8V%C:&4["B`@
M("`*("`@(&9U;F-T:6]N(%-Y;F--3%]"86-K96YD7TAO<F1E*"D*("`@('L*
M("`@("`@("`D9')I=F5R(#T@)$=,3T)!3%-;)V-O;F8G75LG9&%T871R964G
M75LG9')I=F5R)UT["B`@("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BD["B`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y7VUE<F=E*"1P87)A;7,L(&%R<F%Y*"=G<F]U<"<@/3X@)W-Y
M;F-M;"<I*3L*"B`@("`@("`@)'1H:7,M/E]D871A=')E92`])B!$871A5')E
M93HZ<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@("1T:&ES
M+3Y?8V%C:&4@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F5S(&%N(&5N=')Y(&9R;VT@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T86)A<V4@("!$871A8F%S92!T;R!S8V%N
M+B!I+F4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A;&5N
M9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S=6ED("`@("`@(%-E<G9E<B!U;FEQ=64@:60@;V8@=&AE(&5N=')Y.B!F
M;W(@:&]R9&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AI
M<R!I<R!T:&4@9W5I9"X*("`@("`J($!P87)A;2!S=')I;F<@8V]N=&5N=%1Y
M<&4@0V]N=&5N="U4>7!E.B!T:&4@;6EM92!T>7!E(&EN('=H:6-H('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!F=6YC=&EO;B!S:&%L
M;"!R971U<FX@=&AE(&1A=&$*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("`@("`@("`@("`@($$@<W1R:6YG('=I=&@@=&AE(&1A=&$@96YT<GD@;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@82!014%27T5R
M<F]R(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5T<FEE=F5%;G1R
M>2@D9&%T86)A<V4L("1S=6ED+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@
M("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"1D871A8F%S
M92`N("<O97AP;W)T)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V=U:60G(#T^("1S=6ED+"`G8V]N=&5N=%1Y
M<&4G(#T^("1C;VYT96YT5'EP92DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&5N=')I97,@=&AA="!H879E(&)E96X@;6]D:69I960@:6X@=&AE('-E
M<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M>6YC261E;G1I9FEE<B`@261E;G1I9FEE<R!T:&4@8VQI96YT(&1E=FEC92!T
M;R!A;&QO=R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U<V5R('1O('-Y;F,@=VET:"!D:69F97)E;G0@9&5V:6-E<RX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.;W)M86QL>2!T
M:&4@4V]U<F-E55))(&9R;VT@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4WEN8TAE861E<@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%T86)A<V4@("`@("`@($1A=&%B87-E('1O('-C86XN(&DN92X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T
M87-K<R]C;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R
M;VU?=',@("`@("`@(%-T87)T('1I;65S=&%M<"X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1T;U]T<R`@("`@("`@("!%>&-L=7-I=F4@96YD('1I;65S=&%M
M<"X@3F]T('EE=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QE;65N=&5D+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%!%05)?17)R;W(@;W(@87-S;V,@87)R87D@;V8@8VAA;F=E<R!W:71H(&ME
M>3US=6ED+`H@("`@("H@("`@("`@("`@("`@("`@=F%L=64]8W5I9"X@268@
M;F\@8W5I9"!C86X@8F4@9F]U;F0@9F]R(&$@<W5I9"P@=F%L=64@:7,*("`@
M("`J("`@("`@("`@("`@("`@(&YU;&PN(%1H96X@82!3>6YC($%D9"!C;VUM
M86YD(&AA<R!T;R!B92!C<F5A=&5D('1O(&%D9`H@("`@("H@("`@("`@("`@
M("`@("`@=&AI<R!E;G1R>2!I;B!T:&4@8VQI96YT(&1A=&%B87-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971397)V97)-;V1I9FEC871I;VYS*"1S>6YC
M261E;G1I9FEE<BP@)&1A=&%B87-E+"`D9G)O;5]T<RP@)'1O7W1S*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@(&EF("@D9G)O
M;5]T<R`]/2`P*2!["B`@("`@("`@("`@("\O($-O;7!L971E('-Y;F,Z(&5V
M97)Y=&AI;F<@:7,@<V5N="!D=7)I;F<*("`@("`@("`@("`@+R\@9V5T4V5R
M=F5R061D:71I;VYS+B!.;R!N965D('1O('-E;F0@;6]D:69I8V%T:6]N<RX*
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@
M("`O+R!'970@8VAA;F=E<RX*("`@("`@("`D8VAA;F=E<R`]("1R96=I<W1R
M>2T^8V%L;"@D9&%T86)A<V4N("<O;&ES=$)Y)RP@87)R87DH)V%C=&EO;B<@
M/3X@)VUO9&EF>2<L("=T:6UE<W1A;7`G(#T^("1F<F]M7W1S*2D["B`@("`@
M("`@:68@*&ES7V$H)&-H86YG97,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(E-Y;F--3#H@)&1A=&%B87-E+VQI
M<W1">2!F86EL960@9F]R(&UO9&EF>3HB"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)&-H86YG97,M/F=E=$UE<W-A9V4H*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]705).24Y'*3L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@
M("`@("`@?0H*("`@("`@("`D<B`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A
M8V@@*"1C:&%N9V5S(&%S("1S=6ED*2!["B`@("`@("`@("`@("1S=6ED7W1S
M(#T@)')E9VES=')Y+3YC86QL*"1D871A8F%S92`N("<O9V5T06-T:6]N5&EM
M97-T86UP)RP@87)R87DH)'-U:60L("=M;V1I9GDG*2D["B`@("`@("`@("`@
M("1S>6YC7W1S(#T@)'1H:7,M/F=E=$-H86YG9513*"1S>6YC261E;G1I9FEE
M<BP@)&1A=&%B87-E+"`D<W5I9"D["B`@("`@("`@("`@(&EF("@D<WEN8U]T
M<R`F)B`D<WEN8U]T<R`^/2`D<W5I9%]T<RD@>PH@("`@("`@("`@("`@("`@
M+R\@0VAA;F=E('=A<R!D;VYE(&)Y('5S('5P;VX@<F5Q=65S="!O9B!C;&EE
M;G0N"B`@("`@("`@("`@("`@("`O+R!$;VXG="!M:7)R;W(@=&AA="!B86-K
M('1O('1H92!C;&EE;G0N"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S
M<V%G92@B8VAA;F=E.B`D<W5I9"!I9VYO<F5D+"!C86UE(&9R;VT@8VQI96YT
M(BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D8W5I9"`]("1T:&ES+3YG971#=6ED*"1S>6YC261E;G1I9FEE<BP@)&1A
M=&%B87-E+"`D<W5I9"D["B`@("`@("`@("`@(&EF("@A)&-U:60I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E*")5;F%B;&4@=&\@8W)E
M871E(&-H86YG92!F;W(@)'-U:60Z(&-L:65N="UI9"!N;W0@9F]U;F0@:6X@
M;6%P+B!4<GEI;F<@861D(&EN<W1E860N(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M5T%23DE.1RD["B`@("`@("`@("`@("`@("`D<ELD<W5I9%T@/2!N=6QL.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)');)'-U:61=
M(#T@)&-U:60["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<CL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!E;G1R:65S('1H
M870@:&%V92!B965N(&1E;&5T960@9G)O;2!T:&4@<V5R=F5R(&1A=&%B87-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&%B87-E("!$871A
M8F%S92!T;R!S8V%N+B!I+F4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V%L96YD87(O=&%S:W,O8V]N=&%C=',O;F]T97,*("`@("`J($!P
M87)A;2!I;G1E9V5R("1F<F]M7W1S"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M=&]?=',@("`@17AC;'5S:79E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@4$5!4E]%<G)O<B!O<B!A<W-O8R!A<G)A>2!O9B!D96QE=&EO;G,@=VET
M:"!K97D]<W5I9"P*("`@("`J("`@("`@("`@("`@("`@('9A;'5E/6-U:60N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<G9E<D1E;&5T:6]N<R@D<WEN
M8TED96YT:69I97(L("1D871A8F%S92P@)&9R;VU?=',L("1T;U]T<RD*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!I9B`H)&9R
M;VU?=',@/3T@,"D@>PH@("`@("`@("`@("`O+R!#;VUP;&5T92!S>6YC.B!E
M=F5R>71H:6YG(&ES('-E;G0@9'5R:6YG"B`@("`@("`@("`@("\O(&=E=%-E
M<G9E<D%D9&ET:6]N<RX@($YO(&YE960@=&\@<V5N9"!D96QE=&EO;G,N"B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@1V5T(&1E;&5T:6]N<RX*("`@("`@("`D9&5L971E<R`]("1R96=I<W1R
M>2T^8V%L;"@D9&%T86)A<V4N("<O;&ES=$)Y)RP@87)R87DH)V%C=&EO;B<@
M/3X@)V1E;&5T92<L("=T:6UE<W1A;7`G(#T^("1F<F]M7W1S*2D["@H@("`@
M("`@(&EF("AI<U]A*"1D96QE=&5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1T:&ES+3YL;V=-97-S86=E*")3>6YC34PZ("1D871A8F%S92]L
M:7-T0GD@9F%I;&5D(&9O<B!D96QE=&4Z(@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("1D96QE=&5S+3YG971-97-S86=E*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?5T%23DE.1RD["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@
M("`@("`@('T*"B`@("`@("`@)'(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E
M86-H("@D9&5L971E<R!A<R`D<W5I9"D@>PH@("`@("`@("`@("`D<W5I9%]T
M<R`]("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4N("<O9V5T06-T:6]N5&EM
M97-T86UP)RP@87)R87DH)'-U:60L("=D96QE=&4G*2D["B`@("`@("`@("`@
M("1S>6YC7W1S(#T@)'1H:7,M/F=E=$-H86YG9513*"1S>6YC261E;G1I9FEE
M<BP@)&1A=&%B87-E+"`D<W5I9"D["B`@("`@("`@("`@(&EF("@D<WEN8U]T
M<R`F)B`D<WEN8U]T<R`^/2`D<W5I9%]T<RD@>PH@("`@("`@("`@("`@("`@
M+R\@0VAA;F=E('=A<R!D;VYE(&)Y('5S('5P;VX@<F5Q=65S="!O9B!C;&EE
M;G0N"B`@("`@("`@("`@("`@("`O+R!$;VXG="!M:7)R;W(@=&AA="!B86-K
M('1O('1H92!C;&EE;G0N"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S
M<V%G92@B4WEN8TU,.B!D96QE=&4@)'-U:60@:6=N;W)E9"P@8V%M92!F<F]M
M(&-L:65N="(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&-U:60@/2`D=&AI<RT^9V5T0W5I9"@D<WEN8TED96YT:69I
M97(L("1D871A8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H(21C=6ED
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B56YA8FQE
M('1O(&-R96%T92!D96QE=&4@9F]R("1S=6ED.B!L;V-I9"!N;W0@9F]U;F0@
M:6X@;6%P(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?5T%23DE.1RD["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)');)'-U:61=(#T@)&-U:60["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@96YT<FEE<R!T:&%T(&AA
M=F4@8F5E;B!A9&1E9"!T;R!T:&4@<V5R=F5R(&1A=&%B87-E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&1A=&%B87-E("!$871A8F%S92!T;R!S
M8V%N+B!I+F4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@8V%L
M96YD87(O=&%S:W,O8V]N=&%C=',O;F]T97,*("`@("`J($!P87)A;2!I;G1E
M9V5R("1F<F]M7W1S"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=&]?=',@("`@
M17AC;'5S:79E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4$5!4E]%
M<G)O<B!O<B!A<W-O8R!A<G)A>2!O9B!D96QE=&EO;G,@=VET:"!K97D]<W5I
M9"P*("`@("`J("`@("`@("`@("`@("`@('9A;'5E/3`N("AA<G)A>2!S='EL
M92!I<R!C:&]S96X@=&\@;6%T8V@@8VAA;F=E("8@9&5L*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971397)V97)!9&1I=&EO;G,H)'-Y;F-)9&5N=&EF:65R
M+"`D9&%T86)A<V4L("1F<F]M7W1S+"`D=&]?=',I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@:68@*"1F<F]M7W1S(#T](#`I
M('L*("`@("`@("`@("`@+R\@4F5T=7)N(&%L;"!D8B!E;G1R:65S(&1I<F5C
M=&QY(')A=&AE<B!T:&%N(&)O=&AE<@H@("`@("`@("`@("`O+R!H:7-T;W)Y
M.@H@("`@("`@("`@("`D861D<R`]("1R96=I<W1R>2T^8V%L;"@D9&%T86)A
M<V4N("<O;&ES="<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A
M9&1S(#T@)')E9VES=')Y+3YC86QL*"1D871A8F%S92X@)R]L:7-T0GDG+"!A
M<G)A>2@G86-T:6]N)R`]/B`G861D)RP@)W1I;65S=&%M<"<@/3X@)&9R;VU?
M=',I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1A9&1S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E*")3
M>6YC34PZ("1D871A8F%S92]L:7-T0GD@9F%I;&5D(&9O<B!A9&0Z(@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("1A9&1S+3YG971-97-S86=E
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?5T%23DE.1RD["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FQO9TUE<W-A
M9V4H)V%D9"!M;V1I9FEC871I;VYS(')E=')I979E9"X@8V]U;G0])PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@8V]U;G0H)&%D9',I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH*("`@("`@("`D<B`](&%R<F%Y*"D["@H@("`@("`@(&9O
M<F5A8V@@*"1A9&1S(&%S("1S=6ED*2!["B`@("`@("`@("`@("1S=6ED7W1S
M(#T@)')E9VES=')Y+3YC86QL*"1D871A8F%S92`N("<O9V5T06-T:6]N5&EM
M97-T86UP)RP@87)R87DH)'-U:60L("=A9&0G*2D["B`@("`@("`@("`@("1S
M>6YC7W1S(#T@)'1H:7,M/F=E=$-H86YG9513*"1S>6YC261E;G1I9FEE<BP@
M)&1A=&%B87-E+"`D<W5I9"D["B`@("`@("`@("`@(&EF("@D<WEN8U]T<R`F
M)B`D<WEN8U]T<R`^/2`D<W5I9%]T<RD@>PH@("`@("`@("`@("`@("`@+R\@
M0VAA;F=E('=A<R!D;VYE(&)Y('5S('5P;VX@<F5Q=65S="!O9B!C;&EE;G0N
M"B`@("`@("`@("`@("`@("`O+R!$;VXG="!M:7)R;W(@=&AA="!B86-K('1O
M('1H92!C;&EE;G0N"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G
M92@B861D.B`D<W5I9"!I9VYO<F5D+"!C86UE(&9R;VT@8VQI96YT(BP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-U
M:60@/2`D=&AI<RT^9V5T0W5I9"@D<WEN8TED96YT:69I97(L("1D871A8F%S
M92P@)'-U:60I.PH*("`@("`@("`@("`@:68@*"1C=6ED("8F("1F<F]M7W1S
M(#T](#`I('L*("`@("`@("`@("`@("`@("\O($9O<B!S;&]W('-Y;F,@*'1S
M(#T@,"DL(&1O(&YO="!A9&0@9&%T82!F;W(@=VAI8V@*("`@("`@("`@("`@
M("`@("\O('=E(&AA=F4@82!L;V-I9"!A9V%I;BX@5&AI<R!I<R!A(&AE=7)I
M<W1I8R!T;PH@("`@("`@("`@("`@("`@+R\@879O:60@9'5P;&EC871I;VX@
M;V8@96YT<FEE<RX*("`@("`@("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E
M*")S:VEP<&EN9R!A9&0@;V8@9W5I9"`D<W5I9"!A<R!T:&5R92!A;')E861Y
M(&ES(&$@8W5I9"`D8W5I9"(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)');)'-U:61=(#T@,#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<CL*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M86X@96YT<GD@:6YT;R!T:&4@<V5R=F5R(&1A=&%B87-E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&%B87-E("`@("!$871A8F%S92!W:&5R
M92!T;R!A9&0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V%L96YD87(O=&%S:W,O8V]N=&%C=',O;F]T97,*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;G1E;G0@("`@("!4:&4@86-T=6%L(&1A=&$*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("!-:6UE='EP92!O9B`D8V]N=&5N
M=`H@("`@("H@0'!A<F%M('-T<FEN9R`D8W5I9"`@("`@("`@($-L:65N="!)
M1"!O9B!T:&ES(&5N=')Y("AF;W(@;6%P*0H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%!%05)?17)R;W(@;W(@<W5I9"`H2&]R9&4@9W5I9"D@;V8@
M;F5W(&5N=')Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM<&]R=$5N=')Y*"1S
M>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8V]N=&5N="P@)&-O;G1E;G14
M>7!E+"`D8W5I9"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*
M("`@("`@("`D=&%S:W-A;F1C86QE;F1A<F-O;6)I;F5D(#T@9F%L<V4["@H@
M("`@("`@("\O($-H96-K<R!I9B!T:&4@8VQI96YT('-E;F1S('5S(&$@=G1O
M9&\@:6X@82!C86QE;F1A<B!S>6YC.@H@("`@("`@(&EF("@D9&%T86)A<V4@
M/3T@)V-A;&5N9&%R)PH@("`@("`@("`@("`@)B8@<')E9U]M871C:"@G+RA<
M<EQN?%QR?%QN*4)%1TE.6UXZ72HZ5E1/1$\O)RP@(EQN(B`N("1C;VYT96YT
M*2D@>PH@("`@("`@("`@("`D<V5R=F5R9&%T86)A<V4@/2`G=&%S:W,G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S97)V97)D871A8F%S92`]
M("1D871A8F%S93L*("`@("`@("!]"@H@("`@("`@("1S=6ED(#T@)')E9VES
M=')Y+3YC86QL*"1S97)V97)D871A8F%S92`N("<O:6UP;W)T)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D8V]N=&5N="P@)&-O
M;G1E;G14>7!E*2D["@H@("`@("`@("1T:&ES+3YL;V=-97-S86=E*")A9&0@
M=&\@<V5R=F5R(&1B("1S97)V97)D871A8F%S92!C=6ED("1C=6ED("T^('-U
M:60@)'-U:60B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@:68@*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1T<R`]("1R96=I<W1R>2T^8V%L;"@D<V5R=F5R9&%T
M86)A<V4N("<O9V5T06-T:6]N5&EM97-T86UP)RP@87)R87DH)'-U:60L("=A
M9&0G*2D["B`@("`@("`@("`@(&EF("@A)'1S*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G365S<V%G92@G56YA8FQE('1O(&9I;F0@861D+71S(&9O
M<B`G("X@)'-U:60@+B`G(&%T("<@+B`D=',L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^8W)E871E56ED36%P*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E
M+"`D8W5I9"P@)'-U:60L("1T<RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'-U:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%N(&5N
M=')Y(&9R;VT@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A8F%S92`@1&%T86)A<V4@=VAE<F4@=&\@861D
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-A;&5N9&%R+W1A
M<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@<W1R:6YG("1C=6ED
M("`@("`@0VQI96YT($E$(&]F('1H92!E;G1R>0H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%!%05)?17)R;W(@;W(@<W5I9"`H2&]R9&4@9W5I9"D@
M;V8@9&5L971E9"!E;G1R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1C=6ED*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\O($9I;F0@
M<V5R=F5R($E$(&9O<B!T:&ES(&5N=')Y.@H@("`@("`@("1S=6ED(#T@)'1H
M:7,M/F=E=%-U:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1C=6ED
M*3L*("`@("`@("!I9B`H(6ES7V$H)'-U:60L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)')E9VES=')Y+3YC86QL*"1D871A8F%S92X@)R]D96QE
M=&4G+"!A<G)A>2@D<W5I9"DI.PH@("`@("`@("`@("`D=',@/2`D<F5G:7-T
M<GDM/F-A;&PH)&1A=&%B87-E("X@)R]G971!8W1I;VY4:6UE<W1A;7`G+"!A
M<G)A>2@D<W5I9"P@)V1E;&5T92<I*3L*("`@("`@("`@("`@+R\@5V4@8V%N
M)W0@<F5M;W9E('1H92!M87!P:6YG(&5N=')Y(&%S('=E(&YE960@=&\@:V5E
M<`H@("`@("`@("`@("`O+R!T:&4@=&EM97-T86UP(&EN9F]R;6%T:6]N+@H@
M("`@("`@("`@("`D=&AI<RT^8W)E871E56ED36%P*"1S>6YC261E;G1I9FEE
M<BP@)&1A=&%B87-E+"`D8W5I9"P@)'-U:60L("1T<RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'-U:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M97!L86-E<R!A;B!E;G1R>2!I;B!T:&4@<V5R=F5R(&1A=&%B87-E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&%B87-E("`@("!$871A8F%S
M92!W:&5R92!T;R!R97!L86-E+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-A;&5N9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@5&AE(&%C='5A;"!D871A
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@36EM971Y<&4@
M;V8@)&-O;G1E;G0*("`@("`J($!P87)A;2!S=')I;F<@)&-U:60@("`@("`@
M("!#;&EE;G0@240@;V8@=&AI<R!E;G1R>0H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%!%05)?17)R;W(@;W(@<W5I9"`H2&]R9&4@9W5I9"D@;V8@
M;6]D:69I960@96YT<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<&QA8V5%
M;G1R>2@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-O;G1E;G0L("1C
M;VYT96YT5'EP92P@)&-U:60I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("`@("`@+R\@0VAE8VMS(&EF('1H92!C;&EE;G0@<V5N9',@
M=7,@82!V=&]D;R!I;B!A(&-A;&5N9&%R('-Y;F,Z"B`@("`@("`@:68@*"1D
M871A8F%S92`]/2`G8V%L96YD87(G"B`@("`@("`@("`@("`F)B!P<F5G7VUA
M=&-H*"<O*%QR7&Y\7')\7&XI0D5'24Y;7CI=*CI65$]$3R\G+"`B7&XB("X@
M)&-O;G1E;G0I*2!["B`@("`@("`@("`@("1S97)V97)D871A8F%S92`]("=T
M87-K<R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-E<G9E<F1A
M=&%B87-E(#T@)&1A=&%B87-E.PH@("`@("`@('T*"B`@("`@("`@)'-U:60@
M/2`D=&AI<RT^9V5T4W5I9"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@
M)&-U:60I.PH*("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B<F5P;&%C92!I
M;B!D8B`D<V5R=F5R9&%T86)A<V4@8W5I9"`D8W5I9"!S=6ED("1S=6ED(BP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M(&EF("@D<W5I9"D@>PH@("`@("`@("`@("`O+R!%;G1R>2!E>&ES=',Z(')E
M<&QA8V4@8W5R<F5N="!O;F4N"B`@("`@("`@("`@("1O:R`]("1R96=I<W1R
M>2T^8V%L;"@D<V5R=F5R9&%T86)A<V4@+B`G+W)E<&QA8V4G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'-U:60L("1C;VYT
M96YT+"`D8V]N=&5N=%1Y<&4I*3L*("`@("`@("`@("`@:68@*&ES7V$H)&]K
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&]K
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T<R`]("1R96=I<W1R>2T^
M8V%L;"@D<V5R=F5R9&%T86)A<V4@+B`G+V=E=$%C=&EO;E1I;65S=&%M<"<L
M(&%R<F%Y*"1S=6ED+"`G;6]D:69Y)RDI.PH@("`@("`@("`@("`D=&AI<RT^
M8W)E871E56ED36%P*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I
M9"P@)'-U:60L("1T<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(&UA<"!E;G1R>2!F;W5N9"<I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S=6ED.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T<FEE=F5S(&EN9F]R;6%T:6]N(&%B;W5T('1H92!P
M<F5V:6]U<R!S>6YC(&EF(&%N>2X@4F5T=7)N<PH@("`@("H@9F%L<V4@:68@
M;F\@:6YF;R!F;W5N9"!O<B!A($1A=&54<F5E3V)J96-T('=I=&@@870@;&5A
M<W0@=&AE"B`@("`@*B!F;VQL;W=I;F<@871T<FEB=71E<SH*("`@("`J"B`@
M("`@*B!#;&EE;G1!;F-H;W(Z('1H92!C;&EE;G1S($YE>'0@06YC:&]R(&]F
M('1H92!P<F5V:6]U<R!S>6YC+@H@("`@("H@4V5R=F5R06YC:&]R.B!T:&4@
M4V5R=F5R($YE>'0@06YC:&]R(&]F('1H92!P<F5V:6]U<R!S>6YC+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9V5T4WEN8U-U;6UA<GDH)'-Y;F-)9&5N=&EF
M:65R+"`D='EP92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G971/
M8B@D<WEN8TED96YT:69I97(@+B`G.G-U;6UA<GDZ)R`N("1T>7!E*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($%F=&5R(&$@<W5C8V5S<V9U;"!S>6YC+"!T
M:&4@8VQI96YT(&%N9"!S97)V97(G<R!.97AT($%N8VAO<G,*("`@("`J(&%R
M92!W<FET=&5N('1O('1H92!D871A8F%S92!S;R!T:&5Y(&-A;B!B92!U<V5D
M('1O(&YE9V]T:6%T90H@("`@("H@=7!C;VUI;F<@<WEN8W,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('=R:71E4WEN8U-U;6UA<GDH)'-Y;F-)9&5N=&EF:65R
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQI96YT06YC:&]R
M3F5X="P@)'-E<G9E<D%N8VAO<DYE>'0I"B`@("!["B`@("`@("`@:68@*"%I
M<W-E="@D<V5R=F5R06YC:&]R3F5X="D@?'P@(6ES7V%R<F%Y*"1S97)V97)!
M;F-H;W).97AT*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@G
M4WEN8TU,(&EN=&5R;F%L(&5R<F]R.B!N;R!A;F-H;W(@<')O=FED960@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("=I;B!W<FET95-Y;F-3
M=6UM87)Y)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!D:64H
M)U-Y;F--3"!I;G1E<FYA;"!E<G)O<CH@;F\@86YC:&]R('!R;W9I9&5D(&EN
M('=R:71E4WEN8U-U;6UA<GDG*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*&%R<F%Y7VME>7,H)'-E<G9E<D%N8VAO<DYE>'0I(&%S("1T>7!E*2![
M"B`@("`@("`@("`@("1S(#T@)'-Y;F-)9&5N=&EF:65R("X@)SIS=6UM87)Y
M.B<@+B`D='EP93L*"B`@("`@("`@("`@("\O(%-E="`D;&]C:60N"B`@("`@
M("`@("`@("1I;F9O(#T@)FYE=R!$871A5')E94]B:F5C="@D<RD["B`@("`@
M("`@("`@("1I;F9O+3YS970H)T-L:65N=$%N8VAO<B<L("1C;&EE;G1!;F-H
M;W).97AT*3L*("`@("`@("`@("`@)&EN9F\M/G-E="@G4V5R=F5R06YC:&]R
M)RP@)'-E<G9E<D%N8VAO<DYE>'0I.PH@("`@("`@("`@("`D<B`]("1T:&ES
M+3Y?9&%T871R964M/F%D9"@D:6YF;RD["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`O+R!/8FIE
M8W0@86QR96%D>2!E>&ES=',Z('5P9&%T92!I;G-T96%D+@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T82@D:6YF;RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]C86-H95LD:6YF;RT^
M9V5T3F%M92@I72`]("1I;F9O.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T92!A(&UA<"!E;G1R:65S('1O(&UA<"!B971W965N('-E
M<G9E<B!A;F0@8VQI96YT($E$<RX*("`@("`J"B`@("`@*B!0=71S(&$@9VEV
M96X@8VQI96YT("1C=6ED(&%N9"!(;W)D92!S97)V97(@)'-U:60@<&%I<B!I
M;G1O('1H90H@("`@("H@;6%P('1A8FQE('1O(&%L;&]W(&UA<'!I;F<@8F5T
M=V5E;B!T:&4@8VQI96YT)W,@86YD('-E<G9E<B=S"B`@("`@*B!)1',N("!!
M8W1U86QL>2!T:&5R92!A<F4@='=O(&UA<',Z(&9R;VT@=&AE('-U:60@=&\@
M=&AE(&-U:60*("`@("`J(&%N9"!V:6-E('9E<G-A+@H@("`@("H@268@86X@
M96YT<GD@86QR96%D>2!E>&ES=',L(&ET(&ES(&]V97)W<FET=&5N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C<F5A=&55:61-87`H)'-Y;F-)9&5N=&EF:65R
M+"`D='EP92P@)&-U:60L("1S=6ED+"`D=',],"D*("`@('L*("`@("`@("`O
M+R!3970@)&-U:60N"B`@("`@("`@)&=I9"`]("9N97<@1&%T851R965/8FIE
M8W0H)'-Y;F-)9&5N=&EF:65R("X@)SHG("X@)'1Y<&4*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("<Z<W5I9#)C=6ED.B<@+B`D<W5I
M9"D["B`@("`@("`@)&=I9"T^<V5T*"=D871A<W1O<F4G+"`D='EP92D["B`@
M("`@("`@)&=I9"T^<V5T*"=C=6ED)RP@)&-U:60I.PH@("`@("`@("1G:60M
M/G-E="@G=',G+"`D=',I.PH*("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R
M964M/F%D9"@D9VED*3L*("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`O+R!/8FIE8W0@86QR96%D>2!E>&ES=',Z
M('5P9&%T92!I;G-T96%D+@H@("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&%T
M871R964M/G5P9&%T941A=&$H)&=I9"D["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?8V%C:&5;)&=I9"T^9V5T3F%M92@I72`]("1G:60["B`@("`@("`@
M)'1H:7,M/F1I94]N17)R;W(H)'(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@
M("`@("`@("\O(%-E="`D9VQO8F%L=6ED"B`@("`@("`@)&QI9"`]("9N97<@
M1&%T851R965/8FIE8W0H)'-Y;F-)9&5N=&EF:65R("X@)SHG("X@)'1Y<&4*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<Z8W5I9#)S
M=6ED.B<@+B`D8W5I9"D["B`@("`@("`@)&QI9"T^<V5T*"=S=6ED)RP@)'-U
M:60I.PH@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^861D*"1L:60I
M.PH@("`@("`@(&EF("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("\O($]B:F5C="!A;')E861Y(&5X:7-T<SH@=7!D871E(&EN<W1E
M860N"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^=7!D871E
M1&%T82@D;&ED*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]C86-H95LD
M;&ED+3YG971.86UE*"E=(#T@)&QI9#L*("`@("`@("`D=&AI<RT^9&EE3VY%
M<G)O<B@D<BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@+R\@268@
M=&%S:W,@86YD(&5V96YT<R!A<F4@:&%N9&QE9"!A="!O;F-E+"!W92!N965D
M('1O('-T;W)E"B`@("`@("`@+R\@=&AE(&UA<"!E;G1R>2!I;B!B;W1H(&1A
M=&%B87-E<SH*("`@("`@("`D<V5S<VEO;B`])B`D7U-%4U-)3TY;)U-Y;F--
M3"YS=&%T92==.PH@("`@("`@("1D979I8V4@/28@)'-E<W-I;VXM/F=E=$1E
M=FEC92@I.PH*("`@("`@("!I9B`H)&1E=FEC92T^:&%N9&QE5&%S:W-);D-A
M;&5N9&%R*"D*("`@("`@("`@("`@)B8@*"1T>7!E(#T]("=T87-K<R<@?'P@
M)'1Y<&4@/3T@)V-A;&5N9&%R)RD@*2!["B`@("`@("`@("`@("1T>7!E(#T@
M)'1Y<&4@/3T@)W1A<VMS)R`_("=C86QE;F1A<B<@.B`G=&%S:W,G(#L@+R\@
M=&AE(&]T:&5R(&]N90H*("`@("`@("`@("`@+R\@4V5T("1C=6ED+@H@("`@
M("`@("`@("`D9VED(#T@)FYE=R!$871A5')E94]B:F5C="@D<WEN8TED96YT
M:69I97(@+B`G.B<@+B`D='EP90H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N("<Z<W5I9#)C=6ED.B<@+B`D<W5I9"D["B`@("`@
M("`@("`@("1G:60M/G-E="@G9&%T87-T;W)E)RP@)'1Y<&4I.PH@("`@("`@
M("`@("`D9VED+3YS970H)V-U:60G+"`D8W5I9"D["B`@("`@("`@("`@("1G
M:60M/G-E="@G=',G+"`D=',I.PH*("`@("`@("`@("`@)'(@/2`D=&AI<RT^
M7V1A=&%T<F5E+3YA9&0H)&=I9"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`O+R!/8FIE8W0@
M86QR96%D>2!E>&ES=',Z('5P9&%T92!I;G-T96%D+@H@("`@("`@("`@("`@
M("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E+3YU<&1A=&5$871A*"1G:60I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;)&=I9"T^
M9V5T3F%M92@I72`]("1G:60["B`@("`@("`@("`@("1T:&ES+3YD:65/;D5R
M<F]R*"1R+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`@("`@+R\@
M4V5T("1G;&]B86QU:60*("`@("`@("`@("`@)&QI9"`]("9N97<@1&%T851R
M965/8FIE8W0H)'-Y;F-)9&5N=&EF:65R("X@)SHG("X@)'1Y<&4*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G.F-U:60R<W5I
M9#HG("X@)&-U:60I.PH@("`@("`@("`@("`D;&ED+3YS970H)W-U:60G+"`D
M<W5I9"D["B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^861D
M*"1L:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@97AI<W1S
M.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`@("`@("`@("1R(#T@)'1H:7,M
M/E]D871A=')E92T^=7!D871E1&%T82@D;&ED*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7V-A8VAE6R1L:60M/F=E=$YA;64H*5T@/2`D
M;&ED.PH@("`@("`@("`@("`D=&AI<RT^9&EE3VY%<G)O<B@D<BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!T:6UE<W1A;7`@*&EF('-E="D@;V8@=&AE(&QA<W0@
M8VAA;F=E('1O('1H90H@("`@("H@;V)J.F=U:60L('1H870@=V%S(&-A=7-E
M9"!B>2!T:&4@8VQI96YT+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J(%1H:7,@:7,@<W1O<F5D('1O"B`@("`@*B!A=F]I
M9"!M:7)R;W)I;F<@=&AE<V4@8VAA;F=E<R!B86-K('1O('1H92!C;&EE;G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-H86YG9513*"1S>6YC261E;G1I
M9FEE<BP@)&1A=&%B87-E+"`D<W5I9"D*("`@('L*("`@("`@("`D9VED(#TF
M("1T:&ES+3Y?9V5T3V(H)'-Y;F-)9&5N=&EF:65R("X@)SHG("X@)&1A=&%B
M87-E("X@)SIS=6ED,F-U:60Z)R`N("1S=6ED*3L*("`@("`@("!I9B`H:7-?
M82@D9VED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9VED+3YG970H)W1S
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE($AO<F1E
M('-E<G9E<B!G=6ED("AL:6ME"B`@("`@*B!K<F]N;VQI=&@Z,&0Q8C0Q-69C
M,3(T9#,T,C<W,C)E.35F,&4Y,C9B-S4I(&9O<B!A(&=I=F5N(&-L:65N=`H@
M("`@("H@8W5I9"X@4F5T=7)N<R!F86QS92!I9B!N;R!S=6-H(&ED(&ES('-T
M;W)E9"!Y970N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@3W!P;W-I=&4@;V8@9V5T3&]C260@=VAI8V@@<F5T=7)N<R!T
M:&4@;&]C:60@9F]R(&$@9VEV96X@9W5I9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4W5I9"@D<WEN8TED96YT:69I97(L("1T>7!E+"`D8W5I9"D*("`@
M('L*("`@("`@("`D;&ED(#TF("1T:&ES+3Y?9V5T3V(H)'-Y;F-)9&5N=&EF
M:65R("X@)SHG("X@)'1Y<&4@+B`G.F-U:60R<W5I9#HG("X@)&-U:60I.PH@
M("`@("`@(&EF("AI<U]A*"1L:60L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1L:60M/F=E="@G<W5I9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N
M=F5R=',@82!S=6ED('-E<G9E<B!I9"`H:2YE+B!(;W)D92!'54E$*2!T;R!A
M(&-U:60@8VQI96YT($E$"B`@("`@*B!A<R!U<V5D(&)Y('1H92!S>6YC(&-L
M:65N="`H;&EK92`Q,BD@<F5T=7)N<R!F86QS92!I9B!N;R!S=6-H"B`@("`@
M*B!I9"!I<R!S=&]R960@>65T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!G971#=6ED*"1S>6YC261E;G1I
M9FEE<BP@)&1A=&%B87-E+"`D<W5I9"D*("`@('L*("`@("`@("`D9VED(#TF
M("1T:&ES+3Y?9V5T3V(H)'-Y;F-)9&5N=&EF:65R("X@)SHG("X@)&1A=&%B
M87-E("`N("<Z<W5I9#)C=6ED.B<@+B`D<W5I9"D["B`@("`@("`@:68@*&ES
M7V$H)&=I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&=I9"T^9V5T*"=C
M=6ED)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V=S(&$@;65S<V%G92!I
M;B!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&UE
M<W-A9V4@("`@($5I=&AE<B!A('-T<FEN9R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@("`@("!7:&%T(&9I
M;&4@=V%S('1H92!L;V<@9G5N8W1I;VX@8V%L;&5D(&9R;VT*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*&4N9RX@7U]&24Q%7U\I/PH@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&QI;F4@("`@("!7:&%T(&QI;F4@=V%S('1H
M92!L;V<@9G5N8W1I;VX@8V%L;&5D(&9R;VT*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*&4N9RX@7U],24Y%7U\I/PH@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'!R:6]R:71Y("!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A
M9V4N($]N92!O9CH*("`@("`J(#QP<F4^"B`@("`@*B!014%27TQ/1U]%3452
M1PH@("`@("H@4$5!4E],3T=?04Q%4E0*("`@("`J(%!%05)?3$]'7T-2250*
M("`@("`J(%!%05)?3$]'7T524@H@("`@("H@4$5!4E],3T=?5T%23DE.1PH@
M("`@("H@4$5!4E],3T=?3D]424-%"B`@("`@*B!014%27TQ/1U])3D9/"B`@
M("`@*B!014%27TQ/1U]$14)51PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QO9TUE<W-A9V4H)&UE<W-A9V4L("1F:6QE(#T@7U]&24Q%
M7U\L("1L:6YE(#T@7U],24Y%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P<FEO<FET>2`](%!%05)?3$]'7TE.1D\I"B`@("!["B`@("`@("`@:68@
M*&ES7W-T<FEN9R@D;65S<V%G92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@
M/2`B4WEN8TU,.B`B("X@)&UE<W-A9V4["B`@("`@("`@?0H@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"1M97-S86=E+"`D9FEL92P@)&QI;F4L("1P<FEO
M<FET>2D["B`@("!]"@H@("`@9G5N8W1I;VX@;6%P0VQI96YT0V%T96=O<GDR
M4V5R=F5R*"1C;&EE;G1#871E9V]R>2P@)'-U;6UA<GD@(#T@)W5N:VYO=VXG
M*2!["@H@("`@("`@(&EF("AE;7!T>2@D8VQI96YT0V%T96=O<GDI*2!["B`@
M("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/E]L;V%D0V%T96=O<FEE<TUA<"@I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?8V%T96=O<FEE<TUA<%LD8VQI96YT0V%T96=O<GE=*2`F)@H@("`@
M("`@("`@("`A:7-?87)R87DH)'1H:7,M/E]C871E9V]R:65S36%P6R1C;&EE
M;G1#871E9V]R>5TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-A
M=&5G;W)I97--87!;)&-L:65N=$-A=&5G;W)Y73L*("`@("`@("!]"@H@("`@
M("`@("\J('-T;W)E('1H92!C;&EE;G1#871E9V]R>2!A<R!L86-K:6YG(&$@
M;6%P+B`J+PH@("`@("`@("1T:&ES+3Y?8V%T96=O<FEE<TUA<%LD8VQI96YT
M0V%T96=O<GE=(#T@87)R87DH)'-U;6UA<GDI.PH@("`@("`@("1T:&ES+3Y?
M<W1O<F5#871E9V]R:65S36%P*"D["B`@("`@("`@<F5T=7)N("1C;&EE;G1#
M871E9V]R>3L*("`@('T*"B`@("!F=6YC=&EO;B!M87!397)V97)#871E9V]R
M>3)#;&EE;G0H)'-E<G9E<D-A=&5G;W)Y+"`D<W5M;6%R>2`]("=U;FMN;W=N
M)RD@>PH*("`@("`@("!I9B`H96UP='DH)'-E<G9E<D-A=&5G;W)Y*2D@>PH@
M("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7VQO861#871E9V]R:65S36%P*"D["@H@("`@("`@("1C(#T@87)R87E?
M<V5A<F-H*"1S97)V97)#871E9V]R>2P@)'1H:7,M/E]C871E9V]R:65S36%P
M*3L*("`@("`@("!I9B`H(65M<'1Y*"1C*2`F)B`A:7-?87)R87DH)&,I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("!]"@H@("`@("`@("\J
M(%-T;W)E('1H92!S97)V97)#871E9V]R>2!A<R!L86-K:6YG(&$@;6%P+B`J
M+PH@("`@("`@("1T:&ES+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97-;)'-E
M<G9E<D-A=&5G;W)Y72`]("1S=6UM87)Y.PH@("`@("`@("1T:&ES+3Y?<W1O
M<F5#871E9V]R:65S36%P*"D["@H@("`@("`@(')E='5R;B`D<V5R=F5R0V%T
M96=O<GD["B`@("!]"@H@("`@9G5N8W1I;VX@7VQO861#871E9V]R:65S36%P
M*"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]C871E9V]R
M:65S36%P*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@
M("`@("`D;6%P(#TF("1T:&ES+3Y?9V5T3V(H)%]315-324].6R=3>6YC34PN
M<W1A=&4G72T^9V5T4WEN8TED96YT:69I97(H*2`N("<Z8V%T96=O<FEE<R<I
M.PH@("`@("`@(&EF("AI<U]A*"1M87`L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@)'1H:7,M/E]C871E9V]R:65S36%P(#T@87)R87DH*3L*("`@
M("`@("`@("`@)'1H:7,M/E]M:7-S:6YG4V5R=F5R0V%T96=O<FEE<R`](&%R
M<F%Y*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]C
M871E9V]R:65S36%P(#T@)&UA<"T^9V5T*"=M87`G*3L*("`@("`@("`@("`@
M)'1H:7,M/E]M:7-S:6YG4V5R=F5R0V%T96=O<FEE<R`]("1M87`M/F=E="@G
M;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7W-T;W)E0V%T96=O<FEE<TUA<"@I"B`@("!["B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^7V-A=&5G;W)I97--87`I*2!["B`@
M("`@("`@("`@(')E='5R;CL@+R\@;F]T:&EN9R!T;R!D;PH@("`@("`@('T*
M"B`@("`@("`@)&UA<"`]("9N97<@1&%T851R965/8FIE8W0H)%]315-324].
M6R=3>6YC34PN<W1A=&4G72T^9V5T4WEN8TED96YT:69I97(H*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)SIC871E9V]R:65S)RD[
M"B`@("`@("`@)&UA<"T^<V5T*"=M87`G+"`D=&AI<RT^7V-A=&5G;W)I97--
M87`I.PH@("`@("`@("1M87`M/G-E="@G;6ES<VEN9U-E<G9E<D-A=&5G;W)I
M97,G+"`D=&AI<RT^7VUI<W-I;F=397)V97)#871E9V]R:65S*3L*"B`@("`@
M("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)&UA<"D["B`@("`@("`@
M:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@+R\@
M3V)J96-T(&%L<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@
M("`@("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E+3YU<&1A=&5$871A*"1M87`I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V-A8VAE6R1M87`M/F=E=$YA
M;64H*5T@/2`D;6%P.PH@("`@("`@("1T:&ES+3YD:65/;D5R<F]R*"1R+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI
M<R!I<R!A('-M86QL(&AE;'!E<B!F=6YC=&EO;B!T:&%T(&-A;B!B92!I;F-L
M=61E9"!T;R!C:&5C:PH@("`@("H@=VAE=&AE<B!A(&=I=F5N("1O8FH@:7,@
M82!014%27T5R<F]R(&]R(&YO="X@268@<V\L(&ET(&QO9W,*("`@("`J('1O
M(&1E8G5G+"!V87)?9'5M<',@=&AE("1O8FH@86YD(&5X:71S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D:65/;D5R<F]R*"1O8FHL("1F:6QE(#T@7U]&24Q%
M7U\L("1L:6YE(#T@7U],24Y%7U\I"B`@("!["B`@("`@("`@:68@*"%I<U]A
M*"1O8FHL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H)U-Y;F--3#H@
M4$5!4B!%<G)O<CH@)R`N("1O8FHM/F=E=$UE<W-A9V4H*2P@)&9I;&4L("1L
M:6YE+"!014%27TQ/1U]%4E(I.PH@("`@("`@('!R:6YT(")014%2($524D]2
M7&Y<;B(["B`@("`@("`@=F%R7V1U;7`H)&]B:BD["B`@("!]"@H@("`@9G5N
M8W1I;VX@)E]G971/8B@D;F%M92D*("`@('L*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?8V%C:&5;)&YA;65=*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-A8VAE6R1N86UE72`])B`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H
M)&YA;64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]C86-H
M95LD;F%M95T["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T1E
M=FEC92YP:'``````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#,S,C`W`#$P-3$U-#,Q,#8P`#`R,#(S-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*"B\J*@H@*B!4:&4@4WEN
M8TU,7T1E=FEC93HZ(&-L87-S('!R;W9I9&5S(&9U;F-T:6]N86QI='D@=&AA
M="!I<PH@*B!P;W1E;G1I86QL>2`H8VQI96YT*2!D979I8V4@9&5P96YD86YT
M+@H@*@H@*B!3;R!I9B!A('-Y;F,@8VQI96YT(&YE961S(&%N>2!K:6YD(&]F
M('-P96-I86P@9&%T82!O9B!T:&4@9&%T82!S96YT"B`J('1O(&ET(&]R(')E
M8V5I=F5D(&9R;VT@:70L('1H:7,@:7,@9&]N92!H97)E+B!4:&5R92!A<F4@
M='=O('-O=7)C90H@*B!O9B!I;F9O<FUA=&EO;B!T;R!I9&5N=&EF>2!A;B!D
M979I8V4Z(%1H92!F:7)S="`H86YD(&)E='1E<BD@;VYE(&ES"B`J('1H92!$
M979);F8@9&5V:6-E(&EN9F\@<V5N="!B>2!T:&4@9&5V:6-E('5P;VX@82!G
M970@<F5Q=65S="X@268*("H@1&5V26YF(&ES(&YO="!S=7!P;W)T960@;W(@
M<V5N="!B>2!T:&4@8VQI96YT+"!T:&4@4V]U<F-E55))(&]F('1H90H@*B!D
M979I8V4@;6%Y(&)E('-U9F9I8V5N="!T;R!I9&5N=&EF>2!I="X*("H*("H@
M26YF;W)M871I;VX@86)O=70@82!F97<@9&5V:6-E<R!A;')E861Y('=O<FMI
M;F<@=VET:"!3>6YC34PZ.@H@*@H@*B!0.#`P+U`Y,#`O4#DQ,#H*("H@+2TM
M+2TM+2TM+2TM+2TM"B`J($-H87)S970Z"B`J(%1H:7,@9&5V:6-E(&ES(&%B
M;&4@=&\@:&%N9&QE(%541BTX(&%N9"!S96YD<R!I=',@6$U,('!A8VMA9V5S
M(&EN(%541C@N"B`J($AO=V5V97(@979E;B!T:&]U9V@@=&AE(%A-3"!I='-E
M;&8@:7,@551&+3@L(&ET(&5X<&5C=',@=&AE(&5N8VQO<V5D"B`J('9C87)D
M+61A=&$@=&\@8F4@25-/+3@X-3DM,2!U;FQE<W,@97AP;&EC:71L>2!S=&%T
M960@;W1H97)W:7-E("AU<VEN9R!T:&4*("H@0TA!4E-%5"!O<'1I;VXL('=H
M:6-H(&ES(&1E<')E8V%T960@9F]R(%9#05)$(#,N,"D*("H*("H@16YC;V1I
M;F<Z"B`J(%-T<FEN9R!V86QU97,@87)E(&5N8V]D960@(E%53U1%1"U04DE.
M5$%"3$4B"B`J"B`J($]T:&5R.@H@*B!4:&ES(&1E=FEC97,@:&%N9&QE<R!T
M87-K<R!A;F0@979E;G1S(&EN(&]N92!D871A8F%S92X*("H*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@
M*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y
M;F--3"]3>6YC34PO1&5V:6-E+G!H<"QV(#$N-RXR+C@@,C`P-B\P-2\P,R`R
M,3HT,CHU-"!J86X@17AP("0*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R
M;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P86-K86=E(%-Y;F--3`H@
M*B\*8VQA<W,@4WEN8TU,7T1E=FEC92!["@H@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH*0H@("`@>PH@("`@("`@("1S:2`](%-Y;F--3%]$979I8V4Z.G-O=7)C
M955222@I.PH@("`@("`@("1D:2`](%-Y;F--3%]$979I8V4Z.F1E=FEC94EN
M9F\H*3L*"B`@("`@("`@:68@*'-T<FES='(H)'-I+"`G<WEN8S1J)RD@(3T]
M(&9A;'-E('Q\('-T<FES='(H)'-I+"`G<V,M<&EM)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G4WEN8TU,+T1E=FEC92]3>6YC
M-&HN<&AP)SL*("`@("`@("`@("`@)&1E=FEC92`]("9N97<@4WEN8TU,7T1E
M=FEC95]S>6YC-&HH*3L*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1D:2T^
M7TUA;BD@)B8@<W1R:7-T<B@D9&DM/E]-86XL("=3;VYY($5R:6-S<V]N)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G4WEN8TU,
M+T1E=FEC92]0.#`P+G!H<"<["B`@("`@("`@("`@("1D979I8V4@/2`F;F5W
M(%-Y;F--3%]$979I8V5?4#@P,"@I.PH@("`@("`@('T@96QS96EF("@A96UP
M='DH)&1I+3Y?36%N*2`F)B!S=')I<W1R*"1D:2T^7TUA;BP@)W-Y;G1H97-I
M<R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)U-Y
M;F--3"]$979I8V4O4WEN=&AE<VES+G!H<"<["B`@("`@("`@("`@("1D979I
M8V4@/2`F;F5W(%-Y;F--3%]$979I8V5?4WEN=&AE<VES*"D["B`@("`@("`@
M?2!E;'-E:68@*"%E;7!T>2@D9&DM/E]-86XI("8F('-T<FES='(H)&1I+3Y?
M36%N+"`G;F]K:6$G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:6YC;'5D
M95]O;F-E("=3>6YC34PO1&5V:6-E+TYO:VEA+G!H<"<["B`@("`@("`@("`@
M("1D979I8V4@/2`F;F5W(%-Y;F--3%]$979I8V5?3F]K:6$H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D9&5V:6-E(#T@)FYE=R!3>6YC34Q?
M1&5V:6-E*"D["B`@("`@("`@?0H*("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N
M9"==+3YL;V=-97-S86=E*"=5<VEN9R!D979I8V4@8VQA<W,@)R`N(&=E=%]C
M;&%S<R@D9&5V:6-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH*("`@("`@("!R971U<FX@)&1E=FEC93L*("`@('T*"B`@("!F=6YC=&EO
M;B`F<VEN9VQE=&]N*"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC92DI('L*("`@("`@("`@
M("`@)&EN<W1A;F-E(#T@4WEN8TU,7T1E=FEC93HZ9F%C=&]R>2@I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(%-O=7)C955222!F<F]M('-T871E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S;W5R8V554DDH*0H@("`@>PH@("`@("`@
M(')E='5R;B`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==+3YG9713;W5R8V55
M4DDH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($1E=DEN
M9B!C;&%S<R!F<F]M('-T871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D979I
M8V5);F9O*"D*("`@('L*("`@("`@("!R971U<FX@)%]315-324].6R=3>6YC
M34PN<W1A=&4G72T^9V5T1&5V:6-E26YF;R@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5VAE;B!A(&-L:65N="!S96YD<R!D871A(&1U<FEN9R!A('-Y;F,@
M8G5T(&1O97,@;F]T('!R;W9I9&4*("`@("`J(&EN9F]R;6%T:6]N(&%B;W5T
M('1H92!C;VYT96YT='EP92!W:71H('1H:7,@:6YD:79I9'5A;"!I=&5M+`H@
M("`@("H@=&AI<R!F=6YC=&EO;B!R971U<FYS('1H92!C;VYT96YT='EP92!T
M:&4@:71E;2!I<R!S=7!P;W-E9"!T;R!B92!I;BX*("`@("`J"B`@("`@*B!!
M<R!T:&ES(&ES(&]N;'D@=7-E9"!T;R!P87)S92!T;R!T:&4@:&]R9&4G<R!I
M;7!O<G1D871A(&%P:2!F=6YC=&EO;G,L"B`@("`@*B!S;VUE('-I;7!L92!G
M=65S<V5S(&9O<B!T:&4@8V]N=&5N='1Y<&4@87)E(&-O;7!L971E;'D@<W5F
M9FEC:65N=#H*("`@("`J($AO<F1E(&1O97,@;F]T(&-A<F4@=VAE=&AE<B!D
M871A(&ES('1E>'0O>"UV8V%L96YD87(@;W(@=&5X="]C86QE;F1A<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&4H)'1Y
M<&4I"B`@("!["B`@("`@("`@:68@*"1T>7!E(#T]("=C;VYT86-T<R<I('L*
M("`@("`@("`@("`@<F5T=7)N("=T97AT+W@M=F-A<F0G.PH@("`@("`@('T@
M96QS96EF("@D='EP92`]/2`G;F]T97,G*2!["B`@("`@("`@("`@(')E='5R
M;B`G=&5X="]X+79N;W1E)SL*("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@
M)W1A<VMS)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O8V%L96YD87(G
M.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`G8V%L96YD87(G*2!["B`@
M("`@("`@("`@(')E='5R;B`G=&5X="]C86QE;F1A<B<["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<')E9F5R<G)E9"!C
M;VYT96YT='EP92!O9B!T:&4@8VQI96YT(&9O<B!T:&4@9VEV96X*("`@("`J
M('-Y;F,@9&%T82!T>7!E("AC;VYT86-T<R]T87-K<R]N;W1E<R]C86QE;F1A
M<BDN"B`@("`@*@H@("`@("H@5&AE(')E<W5L="!I<R!P87-S960@87,@86X@
M;W!T:6]N('1O('1H92!(;W)D92!!4$D@97AP;W)T(&9U;F-T:6]N<RX*("`@
M("`J(%!L96%S92!N;W1E('1H870@=&AI<R!I<R!N;W0@=&AE(&-O;G1E;G14
M>7!E('5L=&EM871E;'D@<&%S<V5D('1O('1H90H@("`@("H@8VQI96YT(&)U
M="!R871H97(@=&AE(&-O;G1E;G14>7!E('!R97-E;G1E9"!T;R!T:&4@2&]R
M9&4@05!)(&5X<&]R=`H@("`@("H@9G5N8W1I;VYS+B!&;W(@97AA;7!L92!T
M:&4@8V]N=&%C="!A<&D@<W5P<&]R=',@82!C;VYT96YT='EP92`*("`@("`J
M('1E>'0O>"UV8V%R9#MV97)S:6]N/3(N,2!T;R!C<F5A=&4@82!V8V%R9"!I
M;B!V8V%R9"`R+C$@9F]R;6%T+@H@("`@("H*("`@("`J($%F=&5R('1H92!D
M871A(&ES(')E=')I979E9"!F<F]M(&AO<F1E+"!C;VYV97)T4V5R=F5R,D-L
M:65N="!C86X@9&\*("`@("`J('-O;64@<&]S="UP<F]C97-S:6YG(&%N9"!S
M970@=&AE(&-O<G)E8W0@8V]N=&5N=%1Y<&4@86-C97!T86)L92!F;W(*("`@
M("`J('1H92!C;&EE;G0@:68@;F5C97-S87)Y+@H@("`@("H*("`@("`J(%1H
M92!D969A=6QT(&EM<&QE;65N=&%T:6]N('1R:65S('1O(&5X=')A8W0@=&AE
M(&-O;G1E;G1T>7!E(&9R;VT@=&AE"B`@("`@*B!P<F5S96YT960@9&5V:6-E
M(&EN9F\N($EF('1H:7,@9&]E<R!N;W0@=V]R:RP@<V]M92!D969A=6QT(&%R
M92!U<V5D+@H@("`@("H*("`@("`J($EF('1H92!C;&EE;G0@9&]E<R!N;W0@
M<')O=FEC92!P<F]P97(@1&5V26YF(&1A=&$L('1H:7,@9G5N8W1I;VX@;6%Y
M"B`@("`@*B!H879E('1O(&)E(&]V97)W<FET=&5N('1O(')E='5R;B!T:&4@
M8V]R<F5C="!V86QU97,N"B`@("`@*@H@("`@("H@4V5R=F5R4WEN8U5223H@
M5&AE('-E<G9E<B!D871A8F%S92!O9B!T:&4@<WEN8SH*("`@("`J("`@("`@
M("`@("`@("`@(&-O;G1A8W1S?&YO=&5S?&-A;&5N9&%R?'1A<VMS"B`@("`@
M*B!S;W5R8V53>6YC55)).B!4:&4@55))(&9O<B!T:&4@8VQI96YT(&1A=&%B
M87-E+B!4:&ES(&ES(&YE961E9"!A<PH@("`@("H@("`@("`@("`@("`@("`@
M=&AE($1E=DEN9B!I<R!A<G)A;F=E9"!B>2!S;W5R8V53>6YC55))<PH@("`@
M("HO"B`@("`@"B`@("!F=6YC=&EO;B!G9710<F5F97)R961#;VYT96YT5'EP
M94-L:65N="@D<V5R=F5R4WEN8U5222P@)'-O=7)C95-Y;F-54DDI"B`@("![
M"B`@("`@("`@)&1I(#T@)'1H:7,M/F1E=FEC94EN9F\H*3L*("`@("`@("`D
M9',@/2`D9&DM/F=E=$1A=&%3=&]R92@D<V]U<F-E4WEN8U5222D["B`@("`@
M("`@:68@*"%E;7!T>2@D9',I*2!["B`@("`@("`@("`@("1R(#T@)&1S+3YG
M9710<F5F97)R96126$-O;G1E;G14>7!E*"D["B`@("`@("`@("`@(&EF("@A
M96UP='DH)&1S*2D@>PH@("`@("`@("`@("`@("`@:68@*"1R(#T]("=T97AT
M+W@M=F-A<F0G("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1D<RT^9V5T
M4')E9F5R<F5D4EA#;VYT96YT5'EP959E<G-I;VXH*2`]/2`G,BXQ)RD@>PH@
M("`@("`@("`@("`@("`@("`@("\J(%-P96-I86P@8W5S=&]M(&UI;65T>7!E
M('=H:6-H(&UA:V5S('1H92!H;W)D92!T=7)B82!!4$D*("`@("`@("`@("`@
M("`@("`@("`@*B!R971U<FX@82!V97)S:6]N(#(N,2!R871H97(@=&AA;B`S
M+C`@=F-A<F0N"B`@("`@("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("=T97AT+W@M=F-A<F0[=F5R<VEO;CTR+C$G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1R.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!.;R!);F9O(&EN
M($1E=DEN9BX@57-E(&1E9F%U;'1S.B`J+PH@("`@("`@(&EF("@D<V5R=F5R
M4WEN8U5222`]/2`G8V]N=&%C=',G*2!["B`@("`@("`@("`@(')E='5R;B`G
M=&5X="]X+79C87)D)SL*("`@("`@("!](&5L<V5I9B`H)'-E<G9E<E-Y;F-5
M4DD@/3T@)VYO=&5S)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O>"UV
M;F]T92<["B`@("`@("`@?2!E;'-E:68@*"1S97)V97)3>6YC55))(#T]("=T
M87-K<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+W@M=G1O9&\G.PH@
M("`@("`@('T@96QS96EF("@D<V5R=F5R4WEN8U5222`]/2`G8V%L96YD87(G
M*2!["B`@("`@("`@("`@(')E='5R;B`G=&5X="]C86QE;F1A<B<["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T:&4@8V]N=&5N
M="!R96-E:79E9"!F<F]M('1H92!C;&EE;G0@9F]R('1H92!H;W)D92!B86-K
M96YD+@H@("`@("H*("`@("`J($-U<G)E;G1L>2!S=')I<',@=6ED("AP<FEM
M87)Y(&ME>2D@:6YF;W)M871I;VX@87,@8VQI96YT(&%N9`H@("`@("H@<V5R
M=F5R(&UI9VAT('5S92!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!#
M:&%R<V5T(&-O;G9E<G-I;VYS(&UI9VAT(&)E(&%D9&5D(&AE<F4@=&]O+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@("`@5&AE
M(&-O;G1E;G0@=&\@8V]N=F5R=`H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N
M=&5N=%1Y<&4@("!4:&4@8V]N=&5N=%1Y<&4@;V8@=&AE(&-O;G1E;G0*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@("`@(&%R<F%Y
M*"1N97=C;VYT96YT+"`D;F5W8V]N=&5N=%1Y<&4I.@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@8V]N=F5R=&5D(&-O;G1E;G0@
M86YD('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H
M<&]S<VEB;'D@8VAA;F=E9"D@;F5W($-O;G1E;G14>7!E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VYV97)T0VQI96YT,E-E<G9E<B@D8V]N=&5N="P@)&-O
M;G1E;G14>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*("`@
M("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@
M("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET92@D
M9G`L(")<;FEN<'5T(')E8V5I=F5D(&9R;VT@8VQI96YT("@D8V]N=&5N=%1Y
M<&4I7&XB*3L*("`@("`@("`@("`@("`@(&EF("AS=')S='(H)&-O;G1E;G14
M>7!E+"=S:68O)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@
M+R\@<WEN8S1F:B!S:68O*B!D871A(&ES(&)A<V4V-%]E;F-O9&5D+@H@("`@
M("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"!B87-E-C1?9&5C;V1E*"1C
M;VYT96YT*2`N(")<;B(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@)&-O;G1E;G0@+B`B7&XB
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@($!F8VQO<V4H
M)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@06QW
M87ES(')E;6]V92!C;&EE;G0@54E$+B!5240@=VEL;"!B92!S97!E<F%T96QY
M('!A<W-E9"!I;@H@("`@("`@("\O(%A-3"X*("`@("`@("`D8V]N=&5N="`]
M('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*55)1#HN*C\H7')<;GQ<<GQ<
M;BDO)RP@)UPQ)RP@)&-O;G1E;G0L(#$I.PH*("`@("`@("!I9B`H)'1H:7,M
M/FYE961S0V%T96=O<GE-87!P:6YG*"D@)B8*("`@("`@("`@("`@<')E9U]M
M871C:"@G+RA<<EQN?%QR?%QN*4-!5$5'3U))15-;7EPZ72HZ*"XJ/RDH7')<
M;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@
M)&TI*2!["B`@("`@("`@("`@("1C871S(#T@97AP;&]D92@G+"<L("1M6S)=
M*3L*("`@("`@("`@("`@:68H('!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE3
M54U-05)96UY<.ETJ.B@N*C\I*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@("`@("`@("`@("`@
M)'-U;6UA<GD@/2`D;5LR73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1S=6UM87)Y(#T@)W5N:VYO=VXG.PH@("`@("`@("`@("!]
M"@H*("`@("`@("`@("`@9F]R96%C:"`H)&-A=',@87,@)&-A="D@>PH@("`@
M("`@("`@("`@("`@)')E<W5L='-;72`]("1B86-K96YD+3YM87!#;&EE;G1#
M871E9V]R>3)397)V97(H)&-A="P@)'-U;6UA<GDI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\
M7')\7&Y#051%1T]224536UY<.ETJ.BDH+BH_*2A<<EQN?%QR?%QN*2\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)#$G("X@:6UP
M;&]D92@G+"<L)')E<W5L=',I("X@)R0S)RP@)&-O;G1E;G0I.PH*("`@("`@
M("!]"B`@("`@("`@+R\@16YS=7)E('9A;&ED(&YE=VQI;F4@=&5R;6EN871I
M;VXN"B`@("`@("`@:68@*'-U8G-T<B@D8V]N=&5N="P@+3$I("$](")<;B(@
M)B8@<W5B<W1R*"1C;VYT96YT+"`M,2D@(3T@(EQR(BD@>PH@("`@("`@("`@
M("`D8V]N=&5N="`N/2`B7')<;B(["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@87)R87DH)&-O;G1E;G0L("1C;VYT96YT5'EP92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T<R!T:&4@8V]N=&5N="!F<F]M('1H92!B86-K
M96YD('1O(&$@9F]R;6%T('-U:71A8FQE(&9O<B!T:&4*("`@("`J(&-L:65N
M="!D979I8V4N"B`@("`@*@H@("`@("H@4W1R:7!S('1H92!U:60@*'!R:6UA
M<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@86YD('-E<G9E<B!M:6=H
M="!U<V4*("`@("`J(&1I9F9E<F5N="!O;F5S+@H@("`@("H*("`@("`J($-H
M87)S970@8V]N=F5R<VEO;G,@;6EG:'0@8F4@861D960@:&5R92!T;V\N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@("!4:&4@
M8V]N=&5N="!T;R!C;VYV97)T"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT
M96YT5'EP92`@(%1H92!C;VYT96YT5'EP92!O9B!C;VYT96YT(&%S(')E='5R
M;F5D(&9R;VT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AE(&)A8VME;F0*("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@
M("`@87)R87DH)&YE=V-O;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@
M8V]N=&5N="!A;F0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("AP;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT
M96YT+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K
M96YD.PH@("`@("`@(&EF("AI<U]A<G)A>2@D8V]N=&5N=%1Y<&4I*2!["B`@
M("`@("`@("`@("1C;VYT96YT5'EP92`]("1C;VYT96YT5'EP95LG0V]N=&5N
M=%1Y<&4G73L*("`@("`@("!]"@H@("`@("`@(&EF("A$14)51TQ/1U])0T%,
M14Y$05)$051!*2!["B`@("`@("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S
M>6YC+VQO9RYT>'0G+"`G82<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@
M("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN;W5T<'5T(')E8V5I=F5D
M(&9R;VT@:&]R9&4@8F%C:V5N9"`B("X*("`@("`@("`@("`@("`@("`@("`@
M("`@(B@D8V]N=&5N=%1Y<&4I.EQN(BD["B`@("`@("`@("`@("`@("!`9G=R
M:71E*"1F<"PD8V]N=&5N="`N(")<;B(I.PH@("`@("`@("`@("`@("`@0&9C
M;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!296UO=F4@<W!E8VEA;"!V97)S:6]N/3(N,2!I;F1I8V%T;W(@=7-E9"!F
M;W(@:&]R9&4@87!I+B`J+PH@("`@("`@(&EF("@D8V]N=&5N=%1Y<&4@/3T@
M)W1E>'0O>"UV8V%R9#MV97)S:6]N/3(N,2<I('L*("`@("`@("`@("`@)&-O
M;G1E;G14>7!E(#T@)W1E>'0O>"UV8V%R9"<["B`@("`@("`@?0H*("`@("`@
M("`O*B!!;'=A>7,@<F5M;W9E('-E<G9E<B!5240N(%5)1"!W:6QL(&)E('-E
M<&5R871E;'D@<&%S<V5D(&EN(%A-3"X@*B\*("`@("`@("`D8V]N=&5N="`]
M('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*55)1#HN*C\H7')<;GQ<<GQ<
M;BDO)RP@)UPQ)RP@)&-O;G1E;G0L(#$I.PH*("`@("`@("`D9&D@/2`D=&AI
M<RT^9&5V:6-E26YF;R@I.PH*("`@("`@("!I9B`H)'1H:7,M/FYE961S0V%T
M96=O<GE-87!P:6YG*"D@)B8*("`@("`@("`@("`@<')E9U]M871C:"@G+RA<
M<EQN?%QR?%QN*4-!5$5'3U))15-;7EPZ72HZ*"XJ/RDH7')<;GQ<<GQ<;BDO
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&TI*2!["B`@
M("`@("`@("`@("1C871S(#T@97AP;&]D92@G+"<L("1M6S)=*3L*"B`@("`@
M("`@("`@(&EF*"!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI4U5-34%265M>
M7#I=*CHH+BH_*2A<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@("`@("`@("1S=6UM87)Y
M(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<W5M;6%R>2`]("=U;FMN;W=N)SL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@9F]R96%C:"`H)&-A=',@87,@)&-A="D@>PH@("`@("`@("`@("`@
M("`@)')E<W5L='-;72`]("1B86-K96YD+3YM87!397)V97)#871E9V]R>3)#
M;&EE;G0H)&-A="P@)'-U;6UA<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN0T%414=/4DE%4UM>7#I=
M*CHI*"XJ/RDH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("<D,2<@+B!I;7!L;V1E*"<L)RPD<F5S=6QT<RD@+B`G)#(G+"`D8V]N
M=&5N="D["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1C;VYT96YT5'EP
M92D@>PH@("`@("`@(&-A<V4@)W1E>'0O8V%L96YD87(G(#H*("`@("`@("!C
M87-E("=T97AT+W@M:6-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X
M+79C86QE;F1A<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV979E;G0G(#H*
M("`@("`@("!C87-E("=T97AT+W@M=G1O9&\G(#H*("`@("`@("!C87-E("=T
M97AT+W@M=FYO=&4G.@H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`G=&5X="]X+79C87)D)R`Z"B`@("`@("`@("`@("\O($EF('=E(&-A;B!E
M>'1R86-T(&9R;VT@=&AE($1E=FEC92!);F9O+"!T:&%T('1H92!C;&EE;G0*
M("`@("`@("`@("`@+R\@=7-E<R!414P[5T]22SH@,#@P,"`Q,C,@:6YS=&5A
M9"!O9B!414P[5%E013U73U)+.@H@("`@("`@("`@("`O+R`P.#`P,3(S+"!C
M;VYV97)T('1H92!D871A(&%C8V]R9&EN9VQY+@H@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG5$5,)UTI("8F
M"B`@("`@("`@("`@("`@("!E;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C
M87)D)UU;)U1%3"==+3Y?<&%R86US6R=465!%)UTI("8F"B`@("`@("`@("`@
M("`@("`A96UP='DH)&1I+3Y?0U1#87!;)W1E>'0O>"UV8V%R9"==6R=414PG
M72T^7W!A<F%M<ULG5D])0T4G72DI('L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI5$5,.U194$4]2$]-
M12\G+"`G7#%414P[2$]-13M63TE#12<L("1C;VYT96YT+"`Q*3L*("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\
M7&XI5$5,.U194$4]5T]22R\G+"`G7#%414P[5T]22SM63TE#12<L("1C;VYT
M96YT+"`Q*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L
M86-E*"<O*%QR7&Y\7')\7&XI5$5,.U194$4]0T5,3"\G+"`G7#%414P[5D])
M0T4[0T5,3"<L("1C;VYT96YT+"`Q*3L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI5$5,.U194$4]1D%8
M+R<L("=<,51%3#M73U)+.T9!6"<L("1C;VYT96YT+"`Q*3L*("`@("`@("`@
M("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI
M5$5,.U194$4]4$%'15(O)RP@)UPQ5$5,.U!!1T52.U=/4DLG+"`D8V]N=&5N
M="P@,2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($EF('=E(&-A
M;B!E>'1R86-T(&9R;VT@=&AE($1E=FEC92!);F9O+"!T:&%T('1H92!C;&EE
M;G0*("`@("`@("`@("`@+R\@=7-E<R!!1%([5T]22SH@+BXN(&EN<W1E860@
M;V8@0412.U194$4]5T]22SH@,#@P,#$R,RP*("`@("`@("`@("`@+R\@8V]N
M=F5R="!T:&4@9&%T82!A8V-O<F1I;F=L>2X*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C87)D)UU;)T%$4B==*2`F)@H@
M("`@("`@("`@("`@("`@96UP='DH)&1I+3Y?0U1#87!;)W1E>'0O>"UV8V%R
M9"==6R=!1%(G72T^7W!A<F%M<ULG5%E012==*2`F)@H@("`@("`@("`@("`@
M("`@(65M<'1Y*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG0412)UTM
M/E]P87)A;7-;)U=/4DLG72DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT
M(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI0412.U194$4]5T]22R\G
M+"`G7#%!1%([5T]22R<L("1C;VYT96YT+"`Q*3L*("`@("`@("`@("`@("`@
M("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI0412.U19
M4$4]2$]-12\G+"`G7#%!1%([2$]-12<L("1C;VYT96YT+"`Q*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@87)R87DH)&-O;G1E;G0L("1C;VYT96YT5'EP92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3;VUE(&1E=FEC97,@;&EK92!T:&4@4V]N>2!%
M<FEC<W-O;B!0.#`P+U`Y,#`O4#DQ,"!H86YD;&4*("`@("`J('9T;V1O<R`H
M=&%S:W,I(&%N9"!V979E;G1S(&EN('1H92!S86UE(")C86QE;F1A<B(@<WEN
M8RX@(%1H:7,*("`@("`J(')E<75I<F5S('-P96-I86P@86-T:6]N<R!O;B!O
M=7(@<VED92!A<R!W92!S=&]R92!T:&ES(&EN"B`@("`@*B!D:69F97)E;G0@
M9&%T86)A<V5S("AN86<@86YD(&MR;VYO;&ET:"DN("!4:&ES(&9U;F-T:6]N
M"B`@("`@*B!D971E<FUI;F5S('=H971H97(@=&AE(&-L:65N="!D;V5S(&ET
M(&QI:V4@=&AA="X@($-U<G)E;G1L>0H@("`@("H@=&AI<R!I<R!D;VYE(&)Y
M(&-H96-K:6YG('1H92!$979);F8@:6YF;W)M871I;VXN($9O<B!D:69F97)E
M;G0*("`@("`J(&-L:65N=',@=&AE<F4@;6%Y(&)E(&1I9F9E<F5N="!W87ES
M('1O(&9I;F0@;W5T(&AO=R!T:&4@8VQI96YT"B`@("`@*B!L:6ME<R!I=',@
M=&%S:W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L951A<VMS26Y#86QE
M;F1A<B@I"B`@("!["B`@("`@("`@+R\@1&5F875L=#H@=&%S:W,@86YD(&5V
M96YT<R!A<F4@<V5P97)A=&4@9&%T86)A<V5S+@H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-O;64@9&5V:6-E<R!N965D
M(&$@;6%P<&EN9R!O9B!C;&EE;G0@=G,N('-E<G9E<B!C871E9V]R:64@;F%M
M97,N"B`@("`@*B!4:&4@8F%C:V5N9"!P<F]V:61E<R!A(&UE8VAA;FES;2!F
M;W(@=&AI<R!M87!P:6YG+B!)="!I<R!U<V5D"B`@("`@*B!W:&5N('1H:7,@
M;F5E9'-#871E9V]R>4UA<'!I;F<@<F5T=7)N<R!T<G5E+@H@("`@("H@1F]R
M('-P96-I86P@8V%S97,@=&AE(&UA<'!I;F<@;6%Y(&%L<V\@8F4@:6UP;&5M
M96YT960@9&ER96-T;'D@:6X*("`@("`J(&-O;G9E<G1#;&EE;G0R4V5R=F5R
M(&%N9"!C;VYV97)T4V5R=F5R,D-L:65N="X@26X@=&AI<R!C87-E"B`@("`@
M*B!N965D<T-A=&5G;W)Y36%P<&EN9R!M87D@<F5T=7)N(&9A;'-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!N965D<T-A=&5G;W)Y36%P<&EN9R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]3>6YC
M+G!H<```````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T
M,#8T,P`Q,#4Q-30S,3`V,``P,3<W-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@9G)A
M;65W;W)K+U-Y;F--3"]3>6YC34PO4WEN8RYP:'`L=B`Q+C@N-"XY(#(P,#8O
M,#4O,#$@,3(Z,#4Z,30@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M:6QL
M<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]3>6YC('L*"B`@("`O*BH*
M("`@("`J(%1A<F=E=#H@8V]N=&%C=',L(&YO=&5S+"!C86QE;F1A<BP@=&%S
M:W,L"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=$QO8U5223L@+R\@=&%R9V5T
M(&UE86YS('-E<G9E<B!H97)E"@H@("`@=F%R("1?<V]U<F-E3&]C55)).R`O
M+R!S;W5R8V4@;65A;G,@8VQI96YT(&AE<F4*"B`@("!V87(@)%]A;&5R=#L*
M"B`@("`O*BH*("`@("`J(%1R=64@:6YD:6-A=&5S('1H870@=&AE<F4@87)E
M('-T:6QL('-Y;F,@96QE;65N=',@=&AA="!H879E(&YO="!B965N"B`@("`@
M*B!S96YT('EE="!D=64@=&\@;65S<V%G92!S:7IE(&QI;6ET871I;VYS(&%N
M9"!H879E('1O(&)E('-E;G0@:6X@=&AE(&YE>'0*("`@("`J(&UE<W-A9V4N
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7W!E;F1I;F=%;&5M96YT<SL*"B`@("`O*BH*("`@("`J(%)E;65M8F5R(&5N
M=')I97,@=V4@:&%V92!H86YD;&5D(&%L<F5A9'DZ(&]N8V4@=V4@<V5N9"!A
M(&1E;&5T92!F;W(@86X*("`@("`J(&5N=')Y+"!W92!D;VXG="!W86YT('1O
M('-E;F0@86X@861D(&%F=&5R=V%R9',N(%1H:7,@87)R87D@:7,@86QS;R!U
M<V5D"B`@("`@*B!I9B!A('-Y;F,@:7,@<V5N="!I;B!M=6QT:7!L92!M97-S
M86=E<R!D=64@=&\@;65S<V%G92!S:7IE(')E<W1R:6-T:6]N<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V1O;F4["@H@
M("`@9G5N8W1I;VX@4WEN8TU,7U-Y;F,H)&%L97)T+"`D<V5R=F5R55))+"`D
M8VQI96YT55))*0H@("`@>PH@("`@("`@("1T:&ES+3Y?86QE<G0@/2`D86QE
M<G0["B`@("`@("`@)'1H:7,M/E]P96YD:6YG16QE;65N=',@/2!F86QS93L*
M("`@("`@("`D=&AI<RT^7V1O;F4@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES
M+3Y?=&%R9V5T3&]C55))(#T@8F%S96YA;64H)'-E<G9E<E5222D["B`@("`@
M("`@)'1H:7,M/E]S;W5R8V5,;V-54DD@/2`D8VQI96YT55)).PH@("`@("`@
M(&=L;V)A;"`D8F%C:V5N9#L*("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G
M92@B8W)E871E(&9O<B!S>6YC5'EP93TD<V5R=F5R55))(BP@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!(97)E)W,@=VAE<F4@=&AE(&%C='5A;"!P<F]C97-S:6YG(&]F(&$@
M8VQI96YT+7-E;G0@4WEN8PH@("`@("H@271E;2!T86ME<R!P;&%C92X@16YT
M<FEE<R!A<F4@861D960L(&1E;&5T960@;W(@<F5P;&%C960*("`@("`J(&9R
M;VT@=&AE('-E<G9E<B!D871A8F%S92!B>2!U<VEN9R!(;W)D92!!4$D@*%)E
M9VES=')Y*2!C86QL<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE4WEN
M8TET96TH)&ET96TI"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*
M("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*
M("`@("`@("`D9&5V:6-E(#T@)B1S=&%T92T^9V5T1&5V:6-E*"D["B`@("`@
M("`@)'-Y;F-)9&5N=&EF:65R(#T@)'-T871E+3YG9713>6YC261E;G1I9FEE
M<B@I.PH*("`@("`@("`D:&]R9&54>7!E(#T@)'1Y<&4@/2`D=&AI<RT^7W1A
M<F=E=$QO8U5223L*"B`@("`@("`@+R\@57-E(&-O;G1E;G14>7!E(&5X<&QI
M8VET;'D@<W!E8VEF:65D(&EN('1H:7,@<WEN8R!C;VUM86YD+@H@("`@("`@
M("1C;VYT96YT5'EP92`]("1I=&5M+3YG971#;VYT96YT5'EP92@I.PH*("`@
M("`@("`O+R!)9B!N;W0@<')O=FED960L('5S92!D969A=6QT(&9R;VT@9&5V
M:6-E(&EN9F\N"B`@("`@("`@:68@*"$D8V]N=&5N=%1Y<&4I('L*("`@("`@
M("`@("`@)&-O;G1E;G14>7!E(#T@)&1E=FEC92T^9V5T4')E9F5R<F5D0V]N
M=&5N=%1Y<&4H)'1Y<&4I.PH@("`@("`@('T*"B`@("`@("`@;&ES="@D8V]N
M=&5N="P@)&-O;G1E;G14>7!E*2`]"B`@("`@("`@("`@("1D979I8V4M/F-O
M;G9E<G1#;&EE;G0R4V5R=F5R*"1I=&5M+3YG971#;VYT96YT*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M5'EP92D["B`@("`@("`@)&-U:60@/2`D:71E;2T^9V5T0W5I9"@I.PH@("`@
M("`@("1S=6ED(#T@9F%L<V4["@H@("`@("`@("\O($AA;F1L92!C;&EE;G0@
M861D(')E<75E<W1S+@H@("`@("`@(&EF("@D:71E;2T^9V5T16QE;65N=%1Y
M<&4H*2`]/2=!9&0G*2!["B`@("`@("`@("`@("1S=6ED(#T@)&)A8VME;F0M
M/FEM<&]R=$5N=')Y*"1S>6YC261E;G1I9FEE<BP@)&AO<F1E5'EP92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E
M;G0L("1C;VYT96YT5'EP92P@)&-U:60I.PH@("`@("`@("`@("!I9B`H(6ES
M7V$H)'-U:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1S
M=&%T92T^;&]G*")#;&EE;G0M061D(BD["B`@("`@("`@("`@("`@("`D8F%C
M:V5N9"T^;&]G365S<V%G92@G861D960@8VQI96YT(&5N=')Y(&%S("<@+B`D
M<W5I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-T871E+3YL;V<H(D-L:65N
M="U!9&1&86EL=7)E(BD["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G
M365S<V%G92@G17)R;W(@:6X@861D:6YG(&-L:65N="!E;G1R>3HG("X@)'-U
M:60M/FUE<W-A9V4L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`O+R!(86YD;&4@8VQI96YT(&1E
M;&5T92!R97%U97-T<RX*("`@("`@("!](&5L<V5I9B`H)&ET96TM/F=E=$5L
M96UE;G14>7!E*"D@/3TG1&5L971E)RD@>PH@("`@("`@("`@("`D<W5I9"`]
M("1B86-K96YD+3YD96QE=&5%;G1R>2@D<WEN8TED96YT:69I97(L("1T>7!E
M+"`D8W5I9"D["B`@("`@("`@("`@(&EF("@D='EP92`]/2`G8V%L96YD87(G
M"B`@("`@("`@("`@("`@("`F)B`D9&5V:6-E+3YH86YD;&5487-K<TEN0V%L
M96YD87(H*2D@>PH@("`@("`@("`@("`@("`@+R\@9&5L971E16YT<GD@9&]E
M<R!N;W0@;F5E9"!T;R!R971U<FX@86X@97)R;W(@;VX*("`@("`@("`@("`@
M("`@("\O(&1E;&5T:6]N(&]F(&YO;F5X:7-T96YT(&5N=')I97,N(%-O(&IU
M<W0@=&\@8F4@<W5R90H@("`@("`@("`@("`@("`@+R\@=V4@:&%V92!T;R!D
M96QE=&4@9G)O;2!T:&4@=&%S:W,@9&%T86)A<V4@87,@=V5L;#H*("`@("`@
M("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=S<&5C:6%L('1A<VMS
M(&1E;&5T92`G("X@)'-U:60@+B`G(&1U92!T;R!C;&EE;G0@<F5Q=65S="<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M("`@("`@("`@)'-U:60@/2`D8F%C:V5N9"T^9&5L971E16YT<GDH)'-Y;F-)
M9&5N=&EF:65R+"`G=&%S:W,G+"`D8W5I9"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D<W1A=&4M/FQO9R@B0VQI96YT+41E;&5T92(I.PH@
M("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)V1E;&5T960@
M96YT<GD@)R`N("1S=6ED("X@)R!D=64@=&\@8VQI96YT(')E<75E<W0G+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*")#;&EE
M;G0M1&5L971E1F%I;'5R92(I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9TUE<W-A9V4H)T9A:6QU<F4@9&5L971I;F<@8VQI96YT(&5N=')Y+"!M87EB
M92!G;VYE(&%L<F5A9'D@;VX@<V5R=F5R+B!M<V<Z)RX@)'-U:60M/FUE<W-A
M9V4L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`O+R!(86YD;&4@8VQI96YT(')E<&QA8V4@<F5Q
M=65S=',N"B`@("`@("`@?2!E;'-E:68@*"1I=&5M+3YG971%;&5M96YT5'EP
M92@I(#T]("=297!L86-E)RD@>PH@("`@("`@("`@("`D<W5I9"`]("1B86-K
M96YD+3YR97!L86-E16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D:&]R9&54>7!E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G0L("1C;VYT96YT5'EP92P@)&-U:60I.PH*("`@("`@("`@("`@
M:68@*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`D<W1A=&4M/FQO9R@B0VQI96YT+5)E<&QA8V4B*3L*("`@("`@("`@
M("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=R97!L86-E9"!E;G1R>2`G
M("X@)'-U:60@+B`G(&1U92!T;R!C;&EE;G0@<F5Q=65S="<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)'-U
M:60M/FUE<W-A9V4L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)'-U
M:60L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`@("`@("`@("\O($5N=')Y(&UA>2!H879E(&)E96X@9&5L971E9#L@
M=')Y(&%D9&EN9R!I="X*("`@("`@("`@("`@("`@("1S=6ED(#T@)&)A8VME
M;F0M/FEM<&]R=$5N=')Y*"1S>6YC261E;G1I9FEE<BP@)&AO<F1E5'EP92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C;VYT96YT+"`D8V]N=&5N=%1Y<&4L("1C=6ED*3L*("`@("`@("`@("`@
M("`@(&EF("@A:7-?82@D<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1S=&%T92T^;&]G*")#;&EE;G0M061D4F5P;&%C92(I
M.PH@("`@("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=A
M9&1E9"!C;&EE;G0@96YT<GD@9'5E('1O(')E<&QA8V4@<F5Q=65S="!A<R`G
M("X@)'-U:60L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D<W1A=&4M/FQO9R@B0VQI96YT+4%D9$9A:6QU<F4B*3L*("`@("`@("`@
M("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G17)R;W(@:6X@861D
M:6YG(&-L:65N="!E;G1R>2!D=64@=&\@<F5P;&%C92!R97%U97-T.B<@+B`D
M<W5I9"T^;65S<V%G92P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)U5N
M97AP96-T960@96QE;65N=%1Y<&4Z("<@+B`D:71E;2T^9V5T16QE;65N=%1Y
M<&4H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1S=6ED.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E
M<R!A("9L=#M3>6YC)F=T.R!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-R96%T95-Y;F-/=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@
M("!["B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E
M)UT["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3>6YC)RP@)&%T
M=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)T-M9$E$)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC
M:&%R86-T97)S*"1C=7)R96YT0VUD240I.PH@("`@("`@("1C=7)R96YT0VUD
M240K*SL*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=#;61)1"<I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)U1A<F=E="<L("1A='1R<RD["B`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,
M;V-54DDG+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H
M)'1H:7,M/E]S;W5R8V5,;V-54DDI.PH@("`@("`@("1O=71P=70M/F5N9$5L
M96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<I.PH@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U1A<F=E="<I
M.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)U-O=7)C92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG+"`D871T<G,I
M.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'1H:7,M/E]T87)G971,
M;V-54DDI.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)TQO8U5222<I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)U-O=7)C92<I.PH*("`@("`@("`D<WEN
M8U1Y<&4@/2`D=&AI<RT^7W1A<F=E=$QO8U5223L*"B`@("`@("`@9VQO8F%L
M("1B86-K96YD.PH@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*")H86YD
M;&53>6YC(&9O<B!S>6YC5'EP93TD<WEN8U1Y<&4B+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+R\@2&5R92=S('=H
M97)E('-E<G9E<B!M;V1I9FEC871I;VYS(&%R92!S96YT('1O('1H92!C;&EE
M;G0Z"B`@("`@("`@)')E9G1S(#T@)'-T871E+3YG971397)V97)!;F-H;W),
M87-T*"1S>6YC5'EP92D["B`@("`@("`@)&-U<G)E;G1#;61)1"`]("1T:&ES
M+3YH86YD;&53>6YC*"1C=7)R96YT0VUD240L("1S>6YC5'EP92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="P@
M)')E9G1S*3L*"B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G4WEN8R<I.PH*("`@("`@("!R971U<FX@)&-U<G)E;G1#
M;61)1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F1S('-E<G9E<B!C:&%N
M9V5S('1O('1H92!C;&EE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L
M95-Y;F,H)&-U<G)E;G1#;61)1"P@)'-Y;F-4>7!E+"`F)&]U='!U="P@)')E
M9G1S+"`D96YD7W1S(#T@,"D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME
M;F0["B`@("`@("`@9VQO8F%L("1M97-S86=E1G5L;#L*"B`@("`@("`@+RH@
M)&UE<W-A9V5&=6QL('=I;&P@8F4@<V5T('1O('1R=64@=&\@:6YD:6-A=&4@
M=&AA="!T:&5R92=S(&YO(')O;VT*("`@("`@("`@*B!F;W(@;W1H97(@9&%T
M82!I;B!T:&ES(&UE<W-A9V4N($EF(&ET)W,@9F%L<V4@*&5M<'1Y*2!A;F0@
M=&AE<F4*("`@("`@("`@*B!A<F4@<&5N9&EN9R!3>6YC(&1A=&$L('1H92!F
M:6YA;"!C;VUM86YD('=I;&P@<V5N="!T:&4@<&5N9&EN9R!D871A+@H@("`@
M("`@("`J(%1H:7,@9VQO8F%L(&1A=&$@<VAO=6QD(&)E(&UO=F5D('1O(&$@
M9VQO8F%L(&]B:F5C="P@=&]G971H97(*("`@("`@("`@*B!W:71H(&-U<G)E
M;G1#;61)1"!A;F0@)&]U='!U="X@*B\*("`@("`@("`D;65S<V%G949U;&P@
M/2!F86QS93L*"B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,
M+G-T871E)UT["B`@("`@("`@)&1E=FEC92`]("8D<W1A=&4M/F=E=$1E=FEC
M92@I.PH@("`@("`@("1S>6YC261E;G1I9FEE<B`]("1S=&%T92T^9V5T4WEN
M8TED96YT:69I97(H*3L*("`@("`@("`D8V]N=&5N=%1Y<&4@/2`D9&5V:6-E
M+3YG9710<F5F97)R961#;VYT96YT5'EP94-L:65N="@D<WEN8U1Y<&4L("1T
M:&ES+3Y?<V]U<F-E3&]C55))*3L*"B`@("`@("`@+RH@5V4@9F%I=&AF=6QL
M>2!E>'!E8W0@=&\@9&5A;"!W:71H(&%L;"!R96UA:6YI;F<@96QE;65N=',N
M(%=I;&P@8F4*("`@("`@("`@*B!S970@=&\@=')U92!I9B!W92!R=6X@;W5T
M(&]F('-P86-E(&9O<B!M97-S86=E(&-R96%T:6]N+B`J+PH@("`@("`@("1T
M:&ES+3YS971096YD:6YG16QE;65N=',H9F%L<V4I.PH*("`@("`@("`O+R!(
M86YD;&4@9&5L971I;VYS+@H@("`@("`@("1D96QE=&EO;G,@/2`D8F%C:V5N
M9"T^9V5T4V5R=F5R1&5L971I;VYS*"1S>6YC261E;G1I9FEE<BP@)'-Y;F-4
M>7!E+"`D<F5F=',L("1E;F1?=',I.PH*("`@("`@("!I9B`H)')E9G1S(#X@
M,"D@>PH@("`@("`@("`@("`O+R!$;VXG="!S96YD(&1E;&5T97,@;VX@4VQO
M=U-Y;F,N"B`@("`@("`@("`@(&9O<F5A8V@@*"1D96QE=&EO;G,@87,@)'-U
M:60@/3X@)&-U:60I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]N95LD
M<W5I9%T@/2!T<G5E.PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE
M<W-A9V4H(F1E;&5T93H@8W5I9#TD8W5I9"!S=6ED/21S=6ED(')E9G1S.B`D
M<F5F=',B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@("`@("`@("`@("`@("\O($-R96%T92!A($1E;&5T92!R97%U97-T(&9O
M<B!C;&EE;G0N"B`@("`@("`@("`@("`@("`D8W5R<F5N=$-M9$E$(#T@)'1H
M:7,M/F]U='!U=$-O;6UA;F0H)&-U<G)E;G1#;61)1"P@)&]U='!U="P@)T1E
M;&5T92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@)&-U:60L(&YU;&PI.PH@("`@
M("`@("`@("`@("`@)'-T871E+3YL;V<H)U-E<G9E<BU$96QE=&4G*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!(86YD;&4@861D:71I
M;VYS+@H@("`@("`@("1A9&1S(#T@)&)A8VME;F0M/F=E=%-E<G9E<D%D9&ET
M:6]N<R@D<WEN8TED96YT:69I97(L("1S>6YC5'EP92P@)')E9G1S+"`D96YD
M7W1S*3L*("`@("`@("!F;W)E86-H("@D861D<R!A<R`D<W5I9"`]/B`D8W5I
M9"D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?9&]N95LD<W5I
M9%TI*2!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y('-E;G0@9&5L971E
M+"!N;R!N965D('1O(&%D9"X*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E
M*")A9&0Z("1S=6ED(BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["@H@("`@("`@("`@("`D8R`]("1B86-K96YD+3YR971R:65V945N
M=')Y*"1S>6YC5'EP92P@)'-U:60L("1C;VYT96YT5'EP92D["B`@("`@("`@
M("`@(&EF("@A:7-?82@D8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@+R\@271E;2!I;B!H:7-T;W)Y(&)U="!N;W0@:6X@9&%T86)A<V4N
M(%-T<F%N9V4L(&)U="!C86X@:&%P<&5N+@H@("`@("`@("`@("`@("`@;&ES
M="@D8VQI96YT0V]N=&5N="P@)&-L:65N=$-O;G1E;G14>7!E*2`]"B`@("`@
M("`@("`@("`@("`@("`@)&1E=FEC92T^8V]N=F5R=%-E<G9E<C)#;&EE;G0H
M)&,L("1C;VYT96YT5'EP92D["B`@("`@("`@("`@("`@("`O+R!#:&5C:R!I
M9B!W92!H879E('-P86-E(&QE9G0@:6X@=&AE(&UE<W-A9V4N"B`@("`@("`@
M("`@("`@("!I9B`H*"1S=&%T92T^9V5T36%X37-G4VEZ92@I"B`@("`@("`@
M("`@("`@("`@("`@+2`D;W5T<'5T+3YG971/=71P=713:7IE*"D*("`@("`@
M("`@("`@("`@("`@("`M('-T<FQE;B@D8VQI96YT0V]N=&5N="DI(#P@-3`I
M('L*("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G
M;6%X(&UE<W-A9V4@<VEZ92!R96%C:&5D(&-U<G-I>F4])PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)&]U='!U="T^9V5T
M3W5T<'5T4VEZ92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`@("`@("`@("1M97-S86=E1G5L;"`]('1R=64["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%!E;F1I;F=%;&5M96YT<RAT
M<G5E*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)
M1#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&]N95LD<W5I9%T@/2!T<G5E.PH@("`@("`@("`@("`@("`@)&-U<G)E;G1#
M;61)1"`]("1T:&ES+3YO=71P=71#;VUM86YD*"1C=7)R96YT0VUD240L("1O
M=71P=70L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)T%D9"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L:65N=$-O;G1E;G0L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-L:65N=$-O;G1E;G14>7!E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-U:60I.PH@("`@("`@("`@("`@("`@)'-T871E+3YL;V<H)U-E
M<G9E<BU!9&0G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1B86-K96YD+3YL;V=-97-S86=E*"=A<&D@97AP;W)T(&-A;&P@9F]R
M("<@+B`D<W5I9"`N("<@9F%I;&5D.B`@)R`N("1C+3YG971-97-S86=E*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+R\@2&%N9&QE(&-H86YG97,N"B`@("`@("`@
M:68@*"1R969T<R`A/2`P*2!["B`@("`@("`@("`@("\O($1O;B=T('-E;F0@
M8VAA;F=E<R!F;W(@4VQO=U-Y;F,L(&-O;F9U<V5S('-O;64@8VQI96YT<RX*
M("`@("`@("`@("`@)&5N9%]T<R`]('1I;64H*3L*("`@("`@("`@("`@)&-H
M86YG97,@/2`D8F%C:V5N9"T^9V5T4V5R=F5R36]D:69I8V%T:6]N<R@D<WEN
M8TED96YT:69I97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-Y;F-4>7!E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R969T<RP@)&5N9%]T<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1C:&%N
M9V5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D8F%C:V5N
M9"T^;&]G365S<V%G92@D8VAA;F=E<RP@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1C:&%N9V5S
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D8VAA;F=E
M<R!A<R`D<W5I9"`]/B`D8W5I9"D@>PH@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7V1O;F5;)'-U:61=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("\O($%L<F5A9'D@<V5N="!D96QE=&4@;W(@861D+"!N;R!N965D('1O
M(&UO9&EF>2X*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H(21C=6ED*2!["B`@
M("`@("`@("`@("`@("`@("`@+R\@5$]$3SH@8W)E871E(&%N(")A9&0B(&AE
M<F4@:6YS=&5A9#\*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D8R`]("1B86-K96YD
M+3YR971R:65V945N=')Y*"1S>6YC5'EP92P@)'-U:60L("1C;VYT96YT5'EP
M92D["B`@("`@("`@("`@("`@("!I9B`H(6ES7V$H)&,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G
M92@B8VAA;F=E.B`D<W5I9"(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@("`@("`@("`@("`@;&ES="@D8VQI96YT0V]N=&5N
M="P@)&-L:65N=$-O;G1E;G14>7!E*2`]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1D979I8V4M/F-O;G9E<G1397)V97(R0VQI96YT*"1C+"`D8V]N=&5N
M=%1Y<&4I.PH@("`@("`@("`@("`@("`@("`@("\O($-H96-K(&EF('=E(&AA
M=F4@<W!A8V4@;&5F="!I;B!T:&4@;65S<V%G92X*("`@("`@("`@("`@("`@
M("`@("!I9B`H*"1S=&%T92T^9V5T36%X37-G4VEZ92@I"B`@("`@("`@("`@
M("`@("`@("`@("`@("`M("1O=71P=70M/F=E=$]U='!U=%-I>F4H*0H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!S=')L96XH)&-L:65N=$-O;G1E;G0I
M*2`\(#4P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1B86-K96YD+3YL
M;V=-97-S86=E*"=M87@@;65S<V%G92!S:7IE(')E86-H960@8W5R<VEZ93TG
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)&]U='!U="T^9V5T3W5T<'5T4VEZ92@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&UE<W-A9V5&=6QL(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=%!E;F1I;F=%;&5M96YT<RAT<G5E*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]N95LD
M<W5I9%T@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("1C=7)R96YT0VUD
M240@/2`D=&AI<RT^;W5T<'5T0V]M;6%N9"@D8W5R<F5N=$-M9$E$+"`D;W5T
M<'5T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G4F5P;&%C92<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&EE
M;G1#;VYT96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8VQI96YT0V]N=&5N=%1Y<&4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C=6ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL*3L*("`@("`@("`@
M("`@("`@("`@("`D<W1A=&4M/FQO9R@G4V5R=F5R+5)E<&QA8V4G*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@
M271E;2!I;B!H:7-T;W)Y(&)U="!N;W0@:6X@9&%T86)A<V4N(%-T<F%N9V4L
M(&)U=`H@("`@("`@("`@("`@("`@("`@("\O(&-A;B!H87!P96XN"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\O($EF('1A<VMS(&%R92!H86YD;&5D(&EN<VED92!C86QE;F1A<BP@9&\@
M=&AE('-A;64@86=A:6X@9F]R"B`@("`@("`@+R\@=&%S:W,N"B`@("`@("`@
M:68@*"1S>6YC5'EP92`]/2`G8V%L96YD87(G("8F("1D979I8V4M/FAA;F1L
M951A<VMS26Y#86QE;F1A<B@I*2!["B`@("`@("`@("`@("1B86-K96YD+3YL
M;V=-97-S86=E*")H86YD;&EN9R!T87-K<R!I;B!C86QE;F1A<B!S>6YC(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`D8W5R<F5N
M=$-M9$E$(#T@)'1H:7,M/FAA;F1L95-Y;F,H)&-U<G)E;G1#;61)1"P@)W1A
M<VMS)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1O=71P=70L("1R969T<RP@)&5N9%]T<RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@('T*"B`@("`O*BH*
M("`@("`J($]U='!U="!A('-I;F=L92!3>6YC(&-O;6UA;F0@*$%D9"P@1&5L
M971E+"!297!L86-E*2X*("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T0V]M
M;6%N9"@D8W5R<F5N=$-M9$E$+"`F)&]U='!U="P@)&-O;6UA;F0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT+"`D8V]N=&5N=%1Y<&4@
M/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W5I9"`](&YU
M;&PL("1S=6ED(#T@;G5L;"D*("`@('L*("`@("`@("`D<W1A=&4@/2`F)%]3
M15-324].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@)&%T=')S(#T@87)R
M87DH*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)&-O;6UA;F0L("1A='1R<RD["@H@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G+"`D871T
M<G,I.PH@("`@("`@("1C:&%R<R`]("1C=7)R96YT0VUD240["B`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$)RD["@H@("`@
M("`@(&EF("AI<W-E="@D8V]N=&5N=%1Y<&4I*2!["B`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<L
M("1A='1R<RD["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%5224UE=&$H*2P@)U1Y<&4G+"`D871T<G,I.PH@("`@("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C;VYT96YT5'EP92D["B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE-971A
M*"DL("=4>7!E)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TUE=&$G*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D8V]N=&5N="D*("`@("`@("`@("`@?'P@:7-S970H)&-U
M:60I('Q\(&ES<V5T*"1S=6ED*2D@>PH@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TET96TG+"`D871T<G,I
M.PH@("`@("`@("`@("!I9B`H)'-U:60@(3T@;G5L;"D@>PH@("`@("`@("`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=3;W5R8V4G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG+"`D871T
M<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D<W5I
M9"D["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@("`@("`@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U-O=7)C92<I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&-U:60@(3T@;G5L;"D@
M>PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=487)G970G+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,
M;V-54DDG+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA
M<F%C=&5R<R@D8W5I9"D["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@("`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)U1A<F=E="<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E
M="@D8V]N=&5N="DI('L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<L("1A='1R<RD["B`@
M("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C;VYT96YT*3L*
M("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)T1A=&$G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RD[
M"B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("1C;VUM86YD*3L*"B`@("`@("`@)&-U<G)E;G1#;61)
M1"LK.PH*("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@('T*"B`@
M("!F=6YC=&EO;B!S971096YD:6YG16QE;65N=',H)&4I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]P96YD:6YG16QE;65N=',@/2`D93L*("`@('T*"B`@("!F
M=6YC=&EO;B!H87-096YD:6YG16QE;65N=',H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!E;F1I;F=%;&5M96YT<SL*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;G-T86YT<RYP
M:'``````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,3$R`#$P
M-3$U-#,Q,#8P`#`R,3`P,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@0V]P>7)I9VAT(#(P,#4M,C`P
M-B!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VYS=&%N=',N<&AP
M+'8@,2XQ+C(N-"`R,#`V+S`U+S`Q(#$R.C`U.C$T(&IA;B!%>'`@)`H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R
M<W1E;D!H;W)D92YO<F<^"B`J($!P86-K86=E(%-Y;F--3`H@*B\*9&5F:6YE
M*"=!3$525%]$25-03$%9)RP@,3`P*3L*"B\O($YO="!I;7!L96UE;G1E9"X*
M9&5F:6YE*"=!3$525%]45T]?5T%9)RP@,C`P*3L*9&5F:6YE*"=!3$525%]3
M3$]77U-93D,G+"`R,#$I.PID969I;F4H)T%,15)47T].15]705E?1E)/35]#
M3$E%3E0G+"`R,#(I.PID969I;F4H)T%,15)47U)%1E)%4TA?1E)/35]#3$E%
M3E0G+"`R,#,I.PID969I;F4H)T%,15)47T].15]705E?1E)/35]315)615(G
M+"`R,#0I.PID969I;F4H)T%,15)47U)%1E)%4TA?1E)/35]315)615(G+"`R
M,#4I.PH*+R\@3F]T(&EM<&QE;65N=&5D+@ID969I;F4H)T%,15)47U173U]7
M05E?0EE?4T525D52)RP@,C`V*3L*9&5F:6YE*"=!3$525%]/3D5?5T%97T92
M3TU?0TQ)14Y47T)97U-%4E9%4B<L(#(P-RD["F1E9FEN92@G04Q%4E1?4D5&
M4D532%]&4D]-7T-,245.5%]"65]315)615(G+"`R,#@I.PID969I;F4H)T%,
M15)47T].15]705E?1E)/35]315)615)?0EE?4T525D52)RP@,C`Y*3L*9&5F
M:6YE*"=!3$525%]2149215-(7T923TU?4T525D527T)97U-%4E9%4B<L(#(Q
M,"D["@ID969I;F4H)T%,15)47U)%4U5,5%]!3$525"<L(#(R,2D["F1E9FEN
M92@G04Q%4E1?3D585%]-15-304=%)RP@,C(R*3L*9&5F:6YE*"=!3$525%].
M3U]%3D1?3T9?1$%402<L(#(R,RD["@ID969I;F4H)TU)345?4UE.0TU,7UA-
M3"<L("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL*WAM;"<I.PID969I;F4H)TU)
M345?4UE.0TU,7U="6$U,)RP@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PK=V)X
M;6PG*3L*"F1E9FEN92@G34E-15]364Y#34Q?1$5624-%7TE.1D]?6$U,)RP@
M)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PM9&5V:6YF*WAM;"<I.PID969I;F4H
M)TU)345?4UE.0TU,7T1%5DE#15])3D9/7U="6$U,)RP@)V%P<&QI8V%T:6]N
M+W9N9"YS>6YC;6PM9&5V:6YF*W=B>&UL)RD["@ID969I;F4H)TU)345?5$58
M5%]03$%)3B<L("=T97AT+W!L86EN)RD["F1E9FEN92@G34E-15]60T%21%]6
M,C$G+"`G=&5X="]X+79C87)D)RD["F1E9FEN92@G34E-15]60T%21%]6,S`G
M+"`G=&5X="]V8V%R9"<I.PH*9&5F:6YE*"=-24U%7U9#04Q%3D1!4B<L("=T
M97AT+W@M=F-A;&5N9&%R)RD["F1E9FEN92@G34E-15])0T%,14Y$05(G+"`G
M=&5X="]C86QE;F1A<B<I.PID969I;F4H)TU)345?6$U,7TE#04Q%3D1!4B<L
M("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL+7AC86PG*3L*"F1E9FEN92@G34E-
M15]-15-304=%)RP@)W1E>'0O;65S<V%G92<I.PH*9&5F:6YE*"=-24U%7U-9
M3D--3%]834Q?14U!24PG+"`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"UX;7-G
M)RD["F1E9FEN92@G34E-15]364Y#34Q?6$U,7T)/3TM-05)+)RP@)V%P<&QI
M8V%T:6]N+W9N9"YS>6YC;6PM>&)O;VMM87)K)RD["F1E9FEN92@G34E-15]3
M64Y#34Q?4D5,051)3TY!3%]/0DI%0U0G+"`G87!P;&EC871I;VXO=FYD+G-Y
M;F-M;"UX<F5L871I;VYA;"<I.PH*9&5F:6YE*"=215-03TY315])3E]04D]'
M4D534R<L(#$P,2D["@ID969I;F4H)U)%4U!/3E-%7T]+)RP@,C`P*3L*9&5F
M:6YE*"=215-03TY315])5$5-7T%$1$5$)RP@,C`Q*3L*9&5F:6YE*"=215-0
M3TY315]!0T-%4%1%1%]&3U)?4%)/0T534TE.1R<L(#(P,BD["F1E9FEN92@G
M4D534$].4T5?3D].05542$]224%4051)5D5?4D534$].4T4G+"`R,#,I.PID
M969I;F4H)U)%4U!/3E-%7TY/7T-/3E1%3E0G+"`R,#0I.PID969I;F4H)U)%
M4U!/3E-%7U)%4T547T-/3E1%3E0G+"`R,#4I.PID969I;F4H)U)%4U!/3E-%
M7U!!4E1)04Q?0T].5$5.5"<L(#(P-BD["F1E9FEN92@G4D534$].4T5?0T].
M1DQ)0U1?4D533TQ6141?5TE42%]-15)'12<L(#(P-RD["F1E9FEN92@G4D53
M4$].4T5?0T].1DQ)0U1?4D533TQ6141?5TE42%]#3$E%3E1?5TE.3DE.1R<L
M(#(P."D["F1E9FEN92@G4D534$].4T5?0T].1DE,0U1?4D533TQ6141?5TE4
M2%]$55!,24-!5$4G+"`R,#DI.PID969I;F4H)U)%4U!/3E-%7T1%3$5415]7
M251(3U547T%20TA)5D4G+"`R,3`I.PID969I;F4H)U)%4U!/3E-%7TE414U?
M3D]?1$5,151%1"<L(#(Q,2D["F1E9FEN92@G4D534$].4T5?05542$5.5$E#
M051)3TY?04-#15!4140G+"`R,3(I.PID969I;F4H)U)%4U!/3E-%7T-(54Y+
M141?251%35]!0T-%4%1%1%]!3D1?0E5&1D52140G+"`R,3,I.PID969I;F4H
M)U)%4U!/3E-%7T]015)!5$E/3E]#04Y#14Q,140G+"`R,30I.PID969I;F4H
M)U)%4U!/3E-%7TY/7T5814-55$5$)RP@,C$U*3L*9&5F:6YE*"=215-03TY3
M15]!5$]-24-?4D],3%]"04-+7T]+)RP@,C$V*3L*"F1E9FEN92@G4D534$].
M4T5?355,5$E03$5?0TA/24-%4R<L(#,P,"D["B\O($YE960@=&\@8VAA;F=E
M(&YA;65S+@HO+R!D969I;F4H)U)%4U!/3E-%7TU53%1)4$Q%7T-(3TE#15,G
M+"`S,#$I.PHO+R!D969I;F4H)U)%4U!/3E-%7TU53%1)4$Q%7T-(3TE#15,G
M+"`S,#(I.PHO+R!D969I;F4H)U)%4U!/3E-%7TU53%1)4$Q%7T-(3TE#15,G
M+"`S,#,I.PHO+R!D969I;F4H)U)%4U!/3E-%7TU53%1)4$Q%7T-(3TE#15,G
M+"`S,#0I.PID969I;F4H)U)%4U!/3E-%7U5315]04D]862<L(#,P-2D["@ID
M969I;F4H)U)%4U!/3E-%7T)!1%]215%515-4)RP@-#`P*3L*9&5F:6YE*"=2
M15-03TY315])3E9!3$E$7T-2141%3E1)04Q3)RP@-#`Q*3L*+R\@3F5E9"!T
M;R!C:&%N9V4@;F%M97,N"B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#
M4D5$14Y424%,4R<L(#0P,BD["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)
M1%]#4D5$14Y424%,4R<L(#0P,RD["F1E9FEN92@G4D534$].4T5?3D]47T9/
M54Y$)RP@-#`T*3L*+R\@3F5E9"!T;R!C:&%N9V4@;F%M97,N"B\O(&1E9FEN
M92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0P-2D["B\O(&1E
M9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0P-BD["F1E
M9FEN92@G4D534$].4T5?0U)%1$5.5$E!3%-?34E34TE.1R<L(#0P-RD["B\O
M(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0P."D[
M"B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0P
M.2D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L
M(#0Q,"D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,
M4R<L(#0Q,2D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y4
M24%,4R<L(#0Q,BD["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$
M14Y424%,4R<L(#0Q,RD["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#
M4D5$14Y424%,4R<L(#0Q-"D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)
M1%]#4D5$14Y424%,4R<L(#0Q-2D["F1E9FEN92@G4D534$].4T5?4D515453
M5%]325I%7U1/3U]"24<G+"`T,38I.PHO+R!.965D('1O(&-H86YG92!N86UE
M<RX*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)04Q3)RP@
M-#$W*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)04Q3
M)RP@-#$X*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%3E1)
M04Q3)RP@-#$Y*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2141%
M3E1)04Q3)RP@-#(P*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$7T-2
M141%3E1)04Q3)RP@-#(Q*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!3$E$
M7T-2141%3E1)04Q3)RP@-#(R*3L*+R\@9&5F:6YE*"=215-03TY315])3E9!
M3$E$7T-2141%3E1)04Q3)RP@-#(S*3L*9&5F:6YE*"=215-03TY315]325I%
M7TU)4TU!5$-()RP@-#(T*3L*"F1E9FEN92@G4D534$].4T5?0T]-34%.1%]&
M04E,140G+"`U,#`I.PHO+R!.965D('1O(&-H86YG92!N86UE<RX*+R\@9&5F
M:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4P,2D["B\O(&1E9FEN
M92@G4D534$].4T5?0T]-34%.1%]&04E,140G+"`U,#(I.PHO+R!D969I;F4H
M)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`S*3L*+R\@9&5F:6YE*"=2
M15-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4P-"D["B\O(&1E9FEN92@G4D53
M4$].4T5?0T]-34%.1%]&04E,140G+"`U,#4I.PHO+R!D969I;F4H)U)%4U!/
M3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`V*3L*+R\@9&5F:6YE*"=215-03TY3
M15]#3TU-04Y$7T9!24Q%1"<L(#4P-RD["B\O(&1E9FEN92@G4D534$].4T5?
M0T]-34%.1%]&04E,140G+"`U,#@I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/
M34U!3D1?1D%)3$5$)RP@-3`Y*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-
M04Y$7T9!24Q%1"<L(#4Q,"D["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.
M1%]&04E,140G+"`U,3$I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?
M1D%)3$5$)RP@-3$R*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!
M24Q%1"<L(#4Q,RD["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&04E,
M140G+"`U,30I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$
M)RP@-3$U*3L*+R\@9&5F:6YE*"=215-03TY315]!5$]-24-?4D],3%]"04-+
M7T9!24Q%1"<L(#4Q-BD["@ID969I;F4H)TY!345?4U!!0T5?55))7U-93D--
M3%\Q7S$G+"`G<WEN8VUL.G-Y;F-M;#$N,2<I.PID969I;F4H)TY!345?4U!!
M0T5?55))7U-93D--3"<L("=S>6YC;6PZ<WEN8VUL)RD["F1E9FEN92@G3D%-
M15]34$%#15]54DE?345424Y&)RP@)W-Y;F-M;#IM971I;F8G*3L*9&5F:6YE
M*"=.04U%7U-004-%7U5225]-151)3D9?,5\Q)RP@)W-Y;F-M;#IM971I;F8G
M*3L*9&5F:6YE*"=.04U%7U-004-%7U5225]$159)3D8G+"`G<WEN8VUL.F1E
M=FEN9B<I.PID969I;F4H)TY!345?4U!!0T5?55))7T1%5DE.1E\Q7S$G+"`G
M<WEN8VUL.F1E=FEN9B<I.PH*+RHJ"B`J($EF('-E="!T;R!T<G5E+"!L;V=S
M(&%L;"!I;F-O;6EN9R!A;F0@;W5T9V]U;F0@:6-A;&5N9&%R+W9C87)D(&1A
M=&$*("H@=&\@+W1M<"]S>6YC+VQO9RYT>'0N(%1H92!W96(@<V5R=F5R('5S
M97(@*&QI:V4@=W=W<G5N*2!M=7-T(&AA=F4*("H@=W)I=&4@86-C97-S('1O
M('1H:7,@9FEL92X*("HO"F1E9FEN92@G1$5"54=,3T=?24-!3$5.1$%21$%4
M02<L('1R=64I.PH*+RHJ"B`J($EF('-E="!T;R!T<G5E+"!A(&-O<'D@;V8@
M86YY($1E=DEN9B!R96-E:79E9"!F<F]M(&-L:65N=',*("H@:7,@<V%V960@
M=&\@+W1M<"]S>6YC+V1E=FEN9BYT>'0N"B`J(%1H92!W96(@<V5R=F5R('5S
M97(@*&QI:V4@=W=W<G5N*2!M=7-T(&AA=F4*("H@=W)I=&4@86-C97-S('1O
M('1H:7,@9FEL92X*("HO"@ID969I;F4H)T1%0E5'3$]'7T1%5DE.1B<L('1R
M=64I.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E26YF;RYP:'``
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$R-S8`,3`U,34T
M,S$P-C``,#(Q,#4R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!3>6YC34Q?1&5V:6-E26YF;R!R97!R
M97-E;G1S(&$@9&5V:6-E(&EN9F]R;6%T:6]N('-E="!A8V-O<F1I;F<@=&\@
M=&AE"B`J(%-Y;F--3"!S<&5C+@H@*@H@*B!3964@:'1T<#HO+W=W=RYS>6YC
M;6PN;W)G+V1O8W,O<WEN8VUL7V1E=FEN9E]V,3%?,C`P,C`R,34N<&1F"B`J
M"B`J($$@1&5V:6-E26YF;R!O8FIE8W0@:7,@8W)E871E9"!B>2!#;VUM86YD
M+U!U=#HZ4WEN8TU,7T-O;6UA;F1?4'5T(&9R;VT@86X*("H@87!P<F]P<FEA
M=&4@6$U,(&UE<W-A9V4N(%-Y;F--3%]#;VUM86YD7U!U="!D:7)E8W1L>2!P
M;W!U;&%T97,@=&AE(&UE;6)E<G,*("H@=F%R:6%B;&5S+@H@*@H@*B!4:&4@
M8W5R<F5N="!I;7!L96UE;G1A=&EO;B!S:&]U;&0@:&%N9&QE(&%L;"!$979)
M;F8@,2XQ($141"!E;&5M96YT<PH@*B!E>'!C97!T($13365M(&5N=')I97,N
M"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R;6]N="`\
M:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E=FEC94EN9F\N<&AP+'8@,2XR
M+C(N-B`R,#`V+S`U+S`U(#(Q.C$T.C0U(&MA<G-T96X@17AP("0*("H*("H@
M0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T1E=FEC94EN
M9F\@>PH*("`@('9A<B`D7U9E<D141#L*("`@('9A<B`D7TUA;CL*("`@('9A
M<B`D7TUO9#L*("`@('9A<B`D7T]%33L*("`@('9A<B`D7T9W5CL*("`@('9A
M<B`D7U-W5CL*("`@('9A<B`D7TAW5CL*("`@('9A<B`D7T1E=DE$.PH@("`@
M=F%R("1?1&5V5'EP.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@4WEN8TU,
M7T1A=&%3=&]R92!O8FIE8W1S+@H@("`@("HO"B`@("!V87(@)%]$871A4W1O
M<F4["@H@("`@+RHJ"B`@("`@*B!!<G)A>3H@0U14>7!E(#T^(&%R<F%Y.B!0
M<F]P97)T>4YA;64@/3X@4WEN8TU,7U!R;W!E<G1Y(&]B:F5C="X*("`@("`J
M+PH@("`@=F%R("1?0U1#87`["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!83F%M
M(#T^(&%R<F%Y(&]F(%AV86P@96YT<FEE<RX*("`@("`J+PH@("`@=F%R("1?
M17AT.PH*("`@("\J*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D7U540SL*"B`@("`O*BH*("`@("`J($!V87(@8F]O;&5A;@H@("`@
M("HO"B`@("!V87(@)%]3=7!P;W)T3&%R9V5/8FIS.PH*("`@("\J*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7U-U<'!O<G1.=6UB
M97)/9D-H86YG97,["@H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@1&5V
M26YF(&1A=&$@9F]R(&$@9&%T87-T;W)E(&ED96YT:69I960@8GD@)'-O=7)C
M955220H@("`@("H@*%]3;W5R8V52968@<&%R86UE=&5R*2X@(%)E='5R;G,@
M82!3>6YC34Q?1&%T85-T;W)E(&]B:F5C="!O<B!N=6QL(&EF"B`@("`@*B!N
M;R!S=6-H(&1A=&%S=&]R92!E>&ES=',N"B`@("`@*B\@"B`@("!F=6YC=&EO
M;B!G971$871A4W1O<F4H)'-O=7)C955222D*("`@('L*"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T:&ES+3Y?1&%T85-T;W)E*2D@>PH@("`@("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7T1A=&%3=&]R92!A<R`D=BD@>PH@("`@("`@("`@
M("`@("`@:68@*"1V+3Y?4V]U<F-E4F5F(#T]("1S;W5R8V554DDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'8["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("!]"GT*"B\J*@H@*B!4:&4@4WEN8TU,7T1A=&%3=&]R92!C;&%S<R!D
M97-C<FEB97,@;VYE(&]F('1H92!P;W-S:6)L92!D871A<W1O<F5S"B`J("AI
M+F4N(&1A=&%B87-E<RD@;V8@=&AE(&1E=FEC92X@($UO<W0@:6UP;W)T86YT
M(&%T=')I8G5T97,@87)E('1H90H@*B!P<F5F97)R960@36EM92!4>7!E<R!F
M;W(@<V5N9&EN9R!A;F0@<F5C96EV:6YG(&1A=&$@9F]R('1H:7,@9&%T87-T
M;W)E.@H@*B!?5'@M4')E9B!A;F0@7U)X+5!R968*("H*("H@0'!A8VMA9V4@
M4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?1&%T85-T;W)E('L*"B`@("`O*BH*
M("`@("`J(%1H92!L;V-A;"!54DD@;V8@=&AE(&1A=&%S=&]R92X*("`@("`J
M+PH@("`@=F%R("1?4V]U<F-E4F5F.PH*("`@("\J*@H@("`@("H@3W!T:6]N
M86PN"B`@("`@*B\*("`@('9A<B`D7T1I<W!L87E.86UE.PH*("`@("\J*@H@
M("`@("H@3W!T:6]N86PN"B`@("`@*B\*("`@('9A<B`D7TUA>$=52413:7IE
M.PH*("`@("\J*@H@("`@("H@3VYE(&5L96UE;G0@87)R87D@;V8@0U14>7!E
M(#T^(%9E<D-4"B`@("`@*B\*("`@('9A<B`D7U)X7U!R968["@H@("`@+RHJ
M"B`@("`@*B!!<G)A>2!O9B!#5%1Y<&4@/3X@5F5R0U0*("`@("`J+PH@("`@
M=F%R("1?4G@["@H@("`@+RHJ"B`@("`@*B!/;F4@96QE;65N="!A<G)A>2!O
M9B!#5%1Y<&4@/3X@5F5R0U0*("`@("`J+PH@("`@=F%R("1?5'A?4')E9CL*
M"B`@("`O*BH*("`@("`J($%R<F%Y(&]F($-45'EP92`]/B!697)#5`H@("`@
M("HO"B`@("!V87(@)%]4>#L*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@
M("`@("HO"B`@("!V87(@)%]$4TUE;3L*"B`@("`O*BH*("`@("`J($%R<F%Y
M(%-Y;F-4>7!E(#T^('1R=64*("`@("`J+PH@("`@=F%R("1?4WEN8T-A<#L*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!R969E<G)E9"!C;VYT96YT
M>7!E('1H92!C;&EE;G0@=V%N=',@=&\@<F5C96EV92`H4E@I+B!/<@H@("`@
M("H@3E5,3"!I9B!N;W0@<W!E8VEF:65D("AW:&EC:"!I<R!N;W0@86QL;W=E
M9"!B>2!P<F]T;V-O;"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R969E
M<G)E9%)80V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&AI<RT^7U)X7U!R968I*2!["B`@("`@("`@("`@("1R(#T@87)R87E?
M:V5Y<R@D=&AI<RT^7U)X7U!R968I.PH@("`@("`@("`@("!R971U<FX@)');
M,%T["B`@("`@("`@?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F5R<VEO;B!O9B!T:&4@<')E9F5R
M<F5D(&-O;G1E;G1Y<&4@=&AE(&-L:65N="!W86YT<R!T;PH@("`@("H@<F5C
M96EV92`H4E@I+B!/<B!.54Q,(&EF(&YO="!S<&5C:69I960@*'=H:6-H(&ES
M(&YO="!A;&QO=V5D(&)Y"B`@("`@*B!P<F]T;V-O;"DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!R969E<G)E9%)80V]N=&5N=%1Y<&5697)S:6]N*"D*
M("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]2>%]0<F5F*2D@
M>PH@("`@("`@("`@("`D<B`](&%R<F%Y7W9A;'5E<R@D=&AI<RT^7U)X7U!R
M968I.PH@("`@("`@("`@("!R971U<FX@)');,%T["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!.54Q,.PH@("`@?0I]"@HO*BH*("H@5&AE(&-L87-S(%-Y
M;F--3%]0<F]P97)T>2!I<R!U<V5D('1O(&1E9FEN92!A('-I;F=L92!P<F]P
M97)T>2!O9B!A('9C87)D"B`J(&5L96UE;G0N("!4:&4@8V]N=&5N=',@;V8@
M82!0<F]P97)T>2!C86X@8F4@9&5F:6YE9"!B>2!A;B!E;G5M97)A=&EO;B!O
M9@H@*B!V86QI9"!V86QU97,@*%]686Q%;G5M*2!O<B!B>2!A($1A=&%4>7!E
M+U-I>F4@8V]M8FEN871I;VXL(&]R(&YO="!A="!A;&PN"B`J"B`J($!P86-K
M86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7U!R;W!E<G1Y('L*"B`@("`O
M*BH*("`@("`J($%R<F%Y(&]F('9A;&ED('9A;'5E<R`]/B!T<G5E"B`@("`@
M*B\*("`@('9A<B`D7U9A;$5N=6T["@H@("`@+RHJ"B`@("`@*B!)9B!N;W0@
M5F%L16YU;2X*("`@("`J+PH@("`@=F%R("1?1&%T851Y<&4["@H@("`@+RHJ
M"B`@("`@*B!)9B!N;W0@5F%L16YU;2P@;W!T:6]N86PN"B`@("`@*B\*("`@
M('9A<B`D7U-I>F4["@H@("`@+RHJ"B`@("`@*B!/<'1I;VYA;"X*("`@("`J
M+PH@("`@=F%R("1?1&ES<&QA>4YA;64["@H@("`@+RHJ"B`@("`@*B!!<G)A
M>2!O9B!087)A;4YA;64@/3X@4WEN8TU,7U!R;W!E<G1Y4&%R86UE=&5R"B`@
M("`@*B\*("`@('9A<B`D7W!A<F%M<SL*"GT*"B\J*@H@*B!4:&4@8VQA<W,@
M4WEN8TU,7U!R;W!E<G1Y4&%R86UE=&5R(&ES('5S960@=&\@9&5F:6YE(&$@
M<VEN9VQE('!A<F%M971E<B!O9@H@*B!A('!R;W!E<G1Y(&]F(&$@=F-A<F0@
M96QE;65N="X@(%1H92!C;VYT96YT<R!O9B!A(%!R;W!E<G1Y4&%R86UE=&5R
M(&-A;B!B90H@*B!D969I;F5D(&)Y(&%N(&5N=6UE<F%T:6]N(&]F('9A;&ED
M('9A;'5E<R`H7U9A;$5N=6TI(&]R(&)Y(&$@1&%T851Y<&4O4VEZ90H@*B!C
M;VUB:6YA=&EO;BP@;W(@;F]T(&%T(&%L;"X*("H*("H@0'!A8VMA9V4@4WEN
M8TU,"B`J+PIC;&%S<R!3>6YC34Q?4')O<&5R='E087)A;65T97(@>PH*("`@
M("\J*@H@("`@("H@268@<')O=FED960Z(&%R<F%Y(&]F(%9A;$5N=6T@/3X@
M=')U90H@("`@("HO"B`@("!V87(@)%]686Q%;G5M.PH*("`@("\J*@H@("`@
M("H@268@;F]T(%9A;$5N=6TN"B`@("`@*B\*("`@('9A<B`D7T1A=&%4>7!E
M.PH*("`@("\J*@H@("`@("H@268@;F]T(%9A;$5N=6TL(&]P=&EO;F%L+@H@
M("`@("HO"B`@("!V87(@)%]3:7IE.PH*("`@("\J*@H@("`@("H@3W!T:6]N
M86PN"B`@("`@*B\*("`@('9A<B`D7T1I<W!L87E.86UE.PH*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0N
M<&AP````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-38U
M`#$P-3$U-#,Q,#8P`#`R,#0Q-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=3>6YC34PO
M4W1A=&4N<&AP)SL*"B\J*@H@*B!4:&4@4WEN8TU,7T-O;6UA;F0@8VQA<W,@
M<')O=FED97,@82!S=7!E<B!C;&%S<R!F;R!3>6YC0F]D>0H@*B!C;VUM86YD
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM
M86YD+G!H<"QV(#$N-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\
M86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S
M(%-Y;F--3%]#;VUM86YD('L*"B`@("`O*BH*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]C;61)1#L*"B`@("`O*BH*("`@("`J($EN
M=&5R;F%L('-T<G5C='5R92!U<V5D(&1U<FEN9R!834P@<&%R<VEN9RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7U-T86-K
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V-H87)S.PH*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1C
M;VUM86YD+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I;F-L=61E
M7V]N8V4@)U-Y;F--3"]#;VUM86YD+R<@+B`D8V]M;6%N9"`N("<N<&AP)SL*
M("`@("`@("`D8VQA<W,@/2`G4WEN8TU,7T-O;6UA;F1?)R`N("1C;VUM86YD
M.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@
M("`@("`D8VUD(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S
M<V%G92@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@
M9F]U;F0N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@
M("`@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@
M("`D8VUD(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O
M9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&-M9#L*("`@('T*"B`@("!F=6YC=&EO;B!O=71P=70H
M)&-U<G)E;G1#;61)1"P@)&]U='!U="D*("`@('L*("`@('T*"B`@("!F=6YC
M=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@)&QO8V%L3F%M92P@)&%T=')S*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?4W1A8VM;72`]("1L;V-A;$YA;64["B`@
M("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I+"`D96QE;65N="D*
M("`@('L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2![
M"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@
M)T-M9$E$)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;61)1"`](&EN
M='9A;"AT<FEM*"1T:&ES+3Y?8VAA<G,I*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8VAA
M<G,@/2`G)SL*("`@("`@("!A<G)A>5]P;W`H)'1H:7,M/E]3=&%C:RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D<W1R*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8VAA<G,@+CT@)'-T<CL*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O````````````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`V,``P,38P,S0`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL
M92]01$8O````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q-C0T-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R\`````````````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C``,#$W
M-3<V`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S
M+V-O=7)I97(N<&AP````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q
M-@`Q,#4Q-30S,3`V,``P,C$W-34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?
M4$1&"B`J+PIF;W(@*"1I(#T@,#L@)&D@/#T@,C4U.R`D:2LK*2!["B`@("`D
M9F]N=%]W:61T:'-;)V-O=7)I97(G75MC:'(H)&DI72`](#8P,#L*?0HD9F]N
M=%]W:61T:'-;)V-O=7)I97)")UT@/2`D9F]N=%]W:61T:'-;)V-O=7)I97(G
M73L*)&9O;G1?=VED=&AS6R=C;W5R:65R22==(#T@)&9O;G1?=VED=&AS6R=C
M;W5R:65R)UT["B1F;VYT7W=I9'1H<ULG8V]U<FEE<D)))UT@/2`D9G!D9E]W
M:61T:'-;)V-O=7)I97(G73L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV971I8V%B
M:2YP:'``````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,3``,3`U,34T,S$P
M-C``,#(R-38R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*)&9O
M;G1?=VED=&AS6R=H96QV971I8V%"22==(#T@87)R87DH"B`@("!C:'(H,"D]
M/C(W."QC:'(H,2D]/C(W."QC:'(H,BD]/C(W."QC:'(H,RD]/C(W."QC:'(H
M-"D]/C(W."QC:'(H-2D]/C(W."QC:'(H-BD]/C(W."QC:'(H-RD]/C(W."QC
M:'(H."D]/C(W."QC:'(H.2D]/C(W."QC:'(H,3`I/3XR-S@L8VAR*#$Q*3T^
M,C<X+&-H<B@Q,BD]/C(W."QC:'(H,3,I/3XR-S@L8VAR*#$T*3T^,C<X+&-H
M<B@Q-2D]/C(W."QC:'(H,38I/3XR-S@L8VAR*#$W*3T^,C<X+&-H<B@Q."D]
M/C(W."QC:'(H,3DI/3XR-S@L8VAR*#(P*3T^,C<X+&-H<B@R,2D]/C(W."P*
M("`@(&-H<B@R,BD]/C(W."QC:'(H,C,I/3XR-S@L8VAR*#(T*3T^,C<X+&-H
M<B@R-2D]/C(W."QC:'(H,C8I/3XR-S@L8VAR*#(W*3T^,C<X+&-H<B@R."D]
M/C(W."QC:'(H,CDI/3XR-S@L8VAR*#,P*3T^,C<X+&-H<B@S,2D]/C(W."PG
M("<]/C(W."PG(2<]/C,S,RPG(B<]/C0W-"PG(R<]/C4U-BPG)"<]/C4U-BPG
M)2<]/C@X.2PG)B<]/C<R,BPG7"<G/3XR,S@L)R@G/3XS,S,L)RDG/3XS,S,L
M)RHG/3XS.#DL)RLG/3XU.#0L"B`@("`G+"<]/C(W."PG+2<]/C,S,RPG+B<]
M/C(W."PG+R<]/C(W."PG,"<]/C4U-BPG,2<]/C4U-BPG,B<]/C4U-BPG,R<]
M/C4U-BPG-"<]/C4U-BPG-2<]/C4U-BPG-B<]/C4U-BPG-R<]/C4U-BPG."<]
M/C4U-BPG.2<]/C4U-BPG.B<]/C,S,RPG.R<]/C,S,RPG/"<]/C4X-"PG/2<]
M/C4X-"PG/B<]/C4X-"PG/R<]/C8Q,2PG0"<]/CDW-2PG02<]/C<R,BP*("`@
M("=")ST^-S(R+"=#)ST^-S(R+"=$)ST^-S(R+"=%)ST^-C8W+"=&)ST^-C$Q
M+"=')ST^-S<X+"=()ST^-S(R+"=))ST^,C<X+"=*)ST^-34V+"=+)ST^-S(R
M+"=,)ST^-C$Q+"=-)ST^.#,S+"=.)ST^-S(R+"=/)ST^-S<X+"=0)ST^-C8W
M+"=1)ST^-S<X+"=2)ST^-S(R+"=3)ST^-C8W+"=4)ST^-C$Q+"=5)ST^-S(R
M+"=6)ST^-C8W+"=7)ST^.30T+`H@("`@)U@G/3XV-C<L)UDG/3XV-C<L)UHG
M/3XV,3$L)ULG/3XS,S,L)UQ<)ST^,C<X+"==)ST^,S,S+"=>)ST^-3@T+"=?
M)ST^-34V+"=@)ST^,S,S+"=A)ST^-34V+"=B)ST^-C$Q+"=C)ST^-34V+"=D
M)ST^-C$Q+"=E)ST^-34V+"=F)ST^,S,S+"=G)ST^-C$Q+"=H)ST^-C$Q+"=I
M)ST^,C<X+"=J)ST^,C<X+"=K)ST^-34V+"=L)ST^,C<X+"=M)ST^.#@Y+`H@
M("`@)VXG/3XV,3$L)V\G/3XV,3$L)W`G/3XV,3$L)W$G/3XV,3$L)W(G/3XS
M.#DL)W,G/3XU-38L)W0G/3XS,S,L)W4G/3XV,3$L)W8G/3XU-38L)W<G/3XW
M-S@L)W@G/3XU-38L)WDG/3XU-38L)WHG/3XU,#`L)WLG/3XS.#DL)WPG/3XR
M.#`L)WTG/3XS.#DL)WXG/3XU.#0L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^
M-34V+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C(W."QC:'(H,3,Q*3T^-34V
M+`H@("`@8VAR*#$S,BD]/C4P,"QC:'(H,3,S*3T^,3`P,"QC:'(H,3,T*3T^
M-34V+&-H<B@Q,S4I/3XU-38L8VAR*#$S-BD]/C,S,RQC:'(H,3,W*3T^,3`P
M,"QC:'(H,3,X*3T^-C8W+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]/C$P,#`L
M8VAR*#$T,2D]/C,U,"QC:'(H,30R*3T^-C$Q+&-H<B@Q-#,I/3XS-3`L8VAR
M*#$T-"D]/C,U,"QC:'(H,30U*3T^,C<X+&-H<B@Q-#8I/3XR-S@L8VAR*#$T
M-RD]/C4P,"QC:'(H,30X*3T^-3`P+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]
M/C4U-BQC:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XQ
M,#`P+`H@("`@8VAR*#$U-"D]/C4U-BQC:'(H,34U*3T^,S,S+&-H<B@Q-38I
M/3XY-#0L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^-3`P+&-H<B@Q-3DI/3XV
M-C<L8VAR*#$V,"D]/C(W."QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I/3XU-38L
M8VAR*#$V,RD]/C4U-BQC:'(H,38T*3T^-34V+&-H<B@Q-C4I/3XU-38L8VAR
M*#$V-BD]/C(X,"QC:'(H,38W*3T^-34V+&-H<B@Q-C@I/3XS,S,L8VAR*#$V
M.2D]/C<S-RQC:'(H,3<P*3T^,S<P+&-H<B@Q-S$I/3XU-38L8VAR*#$W,BD]
M/C4X-"QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW,S<L8VAR*#$W-2D]/C,S
M,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4X-"QC:'(H,3<X*3T^
M,S,S+&-H<B@Q-SDI/3XS,S,L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-C$Q
M+&-H<B@Q.#(I/3XU-38L8VAR*#$X,RD]/C(W."QC:'(H,3@T*3T^,S,S+&-H
M<B@Q.#4I/3XS,S,L8VAR*#$X-BD]/C,V-2QC:'(H,3@W*3T^-34V+&-H<B@Q
M.#@I/3XX,S0L8VAR*#$X.2D]/C@S-"QC:'(H,3DP*3T^.#,T+&-H<B@Q.3$I
M/3XV,3$L8VAR*#$Y,BD]/C<R,BQC:'(H,3DS*3T^-S(R+&-H<B@Q.30I/3XW
M,C(L8VAR*#$Y-2D]/C<R,BQC:'(H,3DV*3T^-S(R+&-H<B@Q.3<I/3XW,C(L
M"B`@("!C:'(H,3DX*3T^,3`P,"QC:'(H,3DY*3T^-S(R+&-H<B@R,#`I/3XV
M-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W+&-H<B@R,#,I/3XV-C<L
M8VAR*#(P-"D]/C(W."QC:'(H,C`U*3T^,C<X+&-H<B@R,#8I/3XR-S@L8VAR
M*#(P-RD]/C(W."QC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L8VAR*#(Q
M,"D]/C<W."QC:'(H,C$Q*3T^-S<X+&-H<B@R,3(I/3XW-S@L8VAR*#(Q,RD]
M/C<W."QC:'(H,C$T*3T^-S<X+&-H<B@R,34I/3XU.#0L8VAR*#(Q-BD]/C<W
M."QC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*
M("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C8V-RQC:'(H,C(R*3T^-C8W
M+&-H<B@R,C,I/3XV,3$L8VAR*#(R-"D]/C4U-BQC:'(H,C(U*3T^-34V+&-H
M<B@R,C8I/3XU-38L8VAR*#(R-RD]/C4U-BQC:'(H,C(X*3T^-34V+&-H<B@R
M,CDI/3XU-38L8VAR*#(S,"D]/C@X.2QC:'(H,C,Q*3T^-34V+&-H<B@R,S(I
M/3XU-38L8VAR*#(S,RD]/C4U-BQC:'(H,C,T*3T^-34V+&-H<B@R,S4I/3XU
M-38L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L
M8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-C$Q+&-H<B@R-#$I/3XV,3$L"B`@
M("!C:'(H,C0R*3T^-C$Q+&-H<B@R-#,I/3XV,3$L8VAR*#(T-"D]/C8Q,2QC
M:'(H,C0U*3T^-C$Q+&-H<B@R-#8I/3XV,3$L8VAR*#(T-RD]/C4X-"QC:'(H
M,C0X*3T^-C$Q+&-H<B@R-#DI/3XV,3$L8VAR*#(U,"D]/C8Q,2QC:'(H,C4Q
M*3T^-C$Q+&-H<B@R-3(I/3XV,3$L8VAR*#(U,RD]/C4U-BQC:'(H,C4T*3T^
M-C$Q+&-H<B@R-34I/3XU-38I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM97,N<&AP
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,3<W`#$P-3$U-#,Q
M,#8P`#`R,30T,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F
M;VYT7W=I9'1H<ULG=&EM97,G72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR-3`L
M8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR*#,I/3XR-3`L8VAR*#0I/3XR
M-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L8VAR*#<I/3XR-3`L8VAR*#@I
M/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^,C4P+&-H<B@Q,2D]/C(U,"QC
M:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H<B@Q-"D]/C(U,"QC:'(H,34I
M/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]/C(U,"QC:'(H,3@I/3XR-3`L
M8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC:'(H,C$I/3XR-3`L"B`@("!C
M:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H<B@R-"D]/C(U,"QC:'(H,C4I
M/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]/C(U,"QC:'(H,C@I/3XR-3`L
M8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC:'(H,S$I/3XR-3`L)R`G/3XR
M-3`L)R$G/3XS,S,L)R(G/3XT,#@L)R,G/3XU,#`L)R0G/3XU,#`L)R4G/3XX
M,S,L)R8G/3XW-S@L)UPG)ST^,3@P+"<H)ST^,S,S+"<I)ST^,S,S+"<J)ST^
M-3`P+"<K)ST^-38T+`H@("`@)RPG/3XR-3`L)RTG/3XS,S,L)RXG/3XR-3`L
M)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L)S(G/3XU,#`L)S,G/3XU,#`L
M)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L)S<G/3XU,#`L)S@G/3XU,#`L
M)SDG/3XU,#`L)SHG/3XR-S@L)SLG/3XR-S@L)SPG/3XU-C0L)STG/3XU-C0L
M)SXG/3XU-C0L)S\G/3XT-#0L)T`G/3XY,C$L)T$G/3XW,C(L"B`@("`G0B<]
M/C8V-RPG0R<]/C8V-RPG1"<]/C<R,BPG12<]/C8Q,2PG1B<]/C4U-BPG1R<]
M/C<R,BPG2"<]/C<R,BPG22<]/C,S,RPG2B<]/C,X.2PG2R<]/C<R,BPG3"<]
M/C8Q,2PG32<]/C@X.2PG3B<]/C<R,BPG3R<]/C<R,BPG4"<]/C4U-BPG42<]
M/C<R,BPG4B<]/C8V-RPG4R<]/C4U-BPG5"<]/C8Q,2PG52<]/C<R,BPG5B<]
M/C<R,BPG5R<]/CDT-"P*("`@("=8)ST^-S(R+"=9)ST^-S(R+"=:)ST^-C$Q
M+"=;)ST^,S,S+"=<7"<]/C(W."PG72<]/C,S,RPG7B<]/C0V.2PG7R<]/C4P
M,"PG8"<]/C,S,RPG82<]/C0T-"PG8B<]/C4P,"PG8R<]/C0T-"PG9"<]/C4P
M,"PG92<]/C0T-"PG9B<]/C,S,RPG9R<]/C4P,"PG:"<]/C4P,"PG:2<]/C(W
M."PG:B<]/C(W."PG:R<]/C4P,"PG;"<]/C(W."PG;2<]/C<W."P*("`@("=N
M)ST^-3`P+"=O)ST^-3`P+"=P)ST^-3`P+"=Q)ST^-3`P+"=R)ST^,S,S+"=S
M)ST^,S@Y+"=T)ST^,C<X+"=U)ST^-3`P+"=V)ST^-3`P+"=W)ST^-S(R+"=X
M)ST^-3`P+"=Y)ST^-3`P+"=Z)ST^-#0T+"=[)ST^-#@P+"=\)ST^,C`P+"=]
M)ST^-#@P+"=^)ST^-30Q+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]/C4P,"QC
M:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XS,S,L8VAR*#$S,2D]/C4P,"P*("`@
M(&-H<B@Q,S(I/3XT-#0L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]/C4P,"QC
M:'(H,3,U*3T^-3`P+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L8VAR
M*#$S."D]/C4U-BQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XX.#DL8VAR*#$T
M,2D]/C,U,"QC:'(H,30R*3T^-C$Q+&-H<B@Q-#,I/3XS-3`L8VAR*#$T-"D]
M/C,U,"QC:'(H,30U*3T^,S,S+&-H<B@Q-#8I/3XS,S,L8VAR*#$T-RD]/C0T
M-"QC:'(H,30X*3T^-#0T+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]/C4P,"QC
M:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XY.#`L"B`@
M("!C:'(H,34T*3T^,S@Y+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]/C<R,BQC
M:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XT-#0L8VAR*#$U.2D]/C<R,BQC:'(H
M,38P*3T^,C4P+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4P,"QC:'(H,38S
M*3T^-3`P+&-H<B@Q-C0I/3XU,#`L8VAR*#$V-2D]/C4P,"QC:'(H,38V*3T^
M,C`P+&-H<B@Q-C<I/3XU,#`L8VAR*#$V."D]/C,S,RQC:'(H,38Y*3T^-S8P
M+&-H<B@Q-S`I/3XR-S8L8VAR*#$W,2D]/C4P,"QC:'(H,3<R*3T^-38T+&-H
M<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<V,"QC:'(H,3<U*3T^,S,S+`H@("`@
M8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-38T+&-H<B@Q-S@I/3XS,#`L8VAR
M*#$W.2D]/C,P,"QC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU,#`L8VAR*#$X
M,BD]/C0U,RQC:'(H,3@S*3T^,C4P+&-H<B@Q.#0I/3XS,S,L8VAR*#$X-2D]
M/C,P,"QC:'(H,3@V*3T^,S$P+&-H<B@Q.#<I/3XU,#`L8VAR*#$X."D]/C<U
M,"QC:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I/3XW-3`L8VAR*#$Y,2D]/C0T-"QC
M:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW,C(L8VAR*#$Y-"D]/C<R,BQC:'(H
M,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L8VAR*#$Y-RD]/C<R,BP*("`@(&-H
M<B@Q.3@I/3XX.#DL8VAR*#$Y.2D]/C8V-RQC:'(H,C`P*3T^-C$Q+&-H<B@R
M,#$I/3XV,3$L8VAR*#(P,BD]/C8Q,2QC:'(H,C`S*3T^-C$Q+&-H<B@R,#0I
M/3XS,S,L8VAR*#(P-2D]/C,S,RQC:'(H,C`V*3T^,S,S+&-H<B@R,#<I/3XS
M,S,L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R,3`I/3XW,C(L
M8VAR*#(Q,2D]/C<R,BQC:'(H,C$R*3T^-S(R+&-H<B@R,3,I/3XW,C(L8VAR
M*#(Q-"D]/C<R,BQC:'(H,C$U*3T^-38T+&-H<B@R,38I/3XW,C(L8VAR*#(Q
M-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@("!C:'(H
M,C(P*3T^-S(R+&-H<B@R,C$I/3XW,C(L8VAR*#(R,BD]/C4U-BQC:'(H,C(S
M*3T^-3`P+&-H<B@R,C0I/3XT-#0L8VAR*#(R-2D]/C0T-"QC:'(H,C(V*3T^
M-#0T+&-H<B@R,C<I/3XT-#0L8VAR*#(R."D]/C0T-"QC:'(H,C(Y*3T^-#0T
M+&-H<B@R,S`I/3XV-C<L8VAR*#(S,2D]/C0T-"QC:'(H,C,R*3T^-#0T+&-H
M<B@R,S,I/3XT-#0L8VAR*#(S-"D]/C0T-"QC:'(H,C,U*3T^-#0T+&-H<B@R
M,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H<B@R,SDI
M/3XR-S@L8VAR*#(T,"D]/C4P,"QC:'(H,C0Q*3T^-3`P+`H@("`@8VAR*#(T
M,BD]/C4P,"QC:'(H,C0S*3T^-3`P+&-H<B@R-#0I/3XU,#`L8VAR*#(T-2D]
M/C4P,"QC:'(H,C0V*3T^-3`P+&-H<B@R-#<I/3XU-C0L8VAR*#(T."D]/C4P
M,"QC:'(H,C0Y*3T^-3`P+&-H<B@R-3`I/3XU,#`L8VAR*#(U,2D]/C4P,"QC
M:'(H,C4R*3T^-3`P+&-H<B@R-3,I/3XU,#`L8VAR*#(U-"D]/C4P,"QC:'(H
M,C4U*3T^-3`P*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+WIA<&9D:6YG
M8F%T<RYP:'``````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C`S,``Q,#4Q-30S
M,3`V,``P,C(W-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD
M9F]N=%]W:61T:'-;)WIA<&9D:6YG8F%T<R==(#T@87)R87DH"B`@("!C:'(H
M,"D]/C`L8VAR*#$I/3XP+&-H<B@R*3T^,"QC:'(H,RD]/C`L8VAR*#0I/3XP
M+&-H<B@U*3T^,"QC:'(H-BD]/C`L8VAR*#<I/3XP+&-H<B@X*3T^,"QC:'(H
M.2D]/C`L8VAR*#$P*3T^,"QC:'(H,3$I/3XP+&-H<B@Q,BD]/C`L8VAR*#$S
M*3T^,"QC:'(H,30I/3XP+&-H<B@Q-2D]/C`L8VAR*#$V*3T^,"QC:'(H,3<I
M/3XP+&-H<B@Q."D]/C`L8VAR*#$Y*3T^,"QC:'(H,C`I/3XP+&-H<B@R,2D]
M/C`L"B`@("!C:'(H,C(I/3XP+&-H<B@R,RD]/C`L8VAR*#(T*3T^,"QC:'(H
M,C4I/3XP+&-H<B@R-BD]/C`L8VAR*#(W*3T^,"QC:'(H,C@I/3XP+&-H<B@R
M.2D]/C`L8VAR*#,P*3T^,"QC:'(H,S$I/3XP+"<@)ST^,C<X+"<A)ST^.3<T
M+"<B)ST^.38Q+"<C)ST^.3<T+"<D)ST^.3@P+"<E)ST^-S$Y+"<F)ST^-S@Y
M+"=<)R<]/C<Y,"PG*"<]/C<Y,2PG*2<]/C8Y,"PG*B<]/CDV,"PG*R<]/CDS
M.2P*("`@("<L)ST^-30Y+"<M)ST^.#4U+"<N)ST^.3$Q+"<O)ST^.3,S+"<P
M)ST^.3$Q+"<Q)ST^.30U+"<R)ST^.3<T+"<S)ST^-S4U+"<T)ST^.#0V+"<U
M)ST^-S8R+"<V)ST^-S8Q+"<W)ST^-3<Q+"<X)ST^-C<W+"<Y)ST^-S8S+"<Z
M)ST^-S8P+"<[)ST^-S4Y+"<\)ST^-S4T+"<])ST^-#DT+"<^)ST^-34R+"<_
M)ST^-3,W+"=`)ST^-3<W+"=!)ST^-CDR+`H@("`@)T(G/3XW.#8L)T,G/3XW
M.#@L)T0G/3XW.#@L)T4G/3XW.3`L)T8G/3XW.3,L)T<G/3XW.30L)T@G/3XX
M,38L)TDG/3XX,C,L)THG/3XW.#DL)TLG/3XX-#$L)TPG/3XX,C,L)TTG/3XX
M,S,L)TXG/3XX,38L)T\G/3XX,S$L)U`G/3XY,C,L)U$G/3XW-#0L)U(G/3XW
M,C,L)U,G/3XW-#DL)U0G/3XW.3`L)U4G/3XW.3(L)U8G/3XV.34L)U<G/3XW
M-S8L"B`@("`G6"<]/C<V."PG62<]/C<Y,BPG6B<]/C<U.2PG6R<]/C<P-RPG
M7%PG/3XW,#@L)UTG/3XV.#(L)UXG/3XW,#$L)U\G/3XX,C8L)V`G/3XX,34L
M)V$G/3XW.#DL)V(G/3XW.#DL)V,G/3XW,#<L)V0G/3XV.#<L)V4G/3XV.38L
M)V8G/3XV.#DL)V<G/3XW.#8L)V@G/3XW.#<L)VDG/3XW,3,L)VHG/3XW.3$L
M)VLG/3XW.#4L)VPG/3XW.3$L)VTG/3XX-S,L"B`@("`G;B<]/C<V,2PG;R<]
M/C<V,BPG<"<]/C<V,BPG<2<]/C<U.2PG<B<]/C<U.2PG<R<]/C@Y,BPG="<]
M/C@Y,BPG=2<]/C<X."PG=B<]/C<X-"PG=R<]/C0S."PG>"<]/C$S."PG>2<]
M/C(W-RPG>B<]/C0Q-2PG>R<]/C,Y,BPG?"<]/C,Y,BPG?2<]/C8V."PG?B<]
M/C8V."QC:'(H,3(W*3T^,"QC:'(H,3(X*3T^,SDP+&-H<B@Q,CDI/3XS.3`L
M8VAR*#$S,"D]/C,Q-RQC:'(H,3,Q*3T^,S$W+`H@("`@8VAR*#$S,BD]/C(W
M-BQC:'(H,3,S*3T^,C<V+&-H<B@Q,S0I/3XU,#DL8VAR*#$S-2D]/C4P.2QC
M:'(H,3,V*3T^-#$P+&-H<B@Q,S<I/3XT,3`L8VAR*#$S."D]/C(S-"QC:'(H
M,3,Y*3T^,C,T+&-H<B@Q-#`I/3XS,S0L8VAR*#$T,2D]/C,S-"QC:'(H,30R
M*3T^,"QC:'(H,30S*3T^,"QC:'(H,30T*3T^,"QC:'(H,30U*3T^,"QC:'(H
M,30V*3T^,"QC:'(H,30W*3T^,"QC:'(H,30X*3T^,"QC:'(H,30Y*3T^,"QC
M:'(H,34P*3T^,"QC:'(H,34Q*3T^,"QC:'(H,34R*3T^,"QC:'(H,34S*3T^
M,"P*("`@(&-H<B@Q-30I/3XP+&-H<B@Q-34I/3XP+&-H<B@Q-38I/3XP+&-H
M<B@Q-3<I/3XP+&-H<B@Q-3@I/3XP+&-H<B@Q-3DI/3XP+&-H<B@Q-C`I/3XP
M+&-H<B@Q-C$I/3XW,S(L8VAR*#$V,BD]/C4T-"QC:'(H,38S*3T^-30T+&-H
M<B@Q-C0I/3XY,3`L8VAR*#$V-2D]/C8V-RQC:'(H,38V*3T^-S8P+&-H<B@Q
M-C<I/3XW-C`L8VAR*#$V."D]/C<W-BQC:'(H,38Y*3T^-3DU+&-H<B@Q-S`I
M/3XV.30L8VAR*#$W,2D]/C8R-BQC:'(H,3<R*3T^-S@X+&-H<B@Q-S,I/3XW
M.#@L8VAR*#$W-"D]/C<X."QC:'(H,3<U*3T^-S@X+`H@("`@8VAR*#$W-BD]
M/C<X."QC:'(H,3<W*3T^-S@X+&-H<B@Q-S@I/3XW.#@L8VAR*#$W.2D]/C<X
M."QC:'(H,3@P*3T^-S@X+&-H<B@Q.#$I/3XW.#@L8VAR*#$X,BD]/C<X."QC
M:'(H,3@S*3T^-S@X+&-H<B@Q.#0I/3XW.#@L8VAR*#$X-2D]/C<X."QC:'(H
M,3@V*3T^-S@X+&-H<B@Q.#<I/3XW.#@L8VAR*#$X."D]/C<X."QC:'(H,3@Y
M*3T^-S@X+&-H<B@Q.3`I/3XW.#@L8VAR*#$Y,2D]/C<X."QC:'(H,3DR*3T^
M-S@X+&-H<B@Q.3,I/3XW.#@L8VAR*#$Y-"D]/C<X."QC:'(H,3DU*3T^-S@X
M+&-H<B@Q.38I/3XW.#@L8VAR*#$Y-RD]/C<X."P*("`@(&-H<B@Q.3@I/3XW
M.#@L8VAR*#$Y.2D]/C<X."QC:'(H,C`P*3T^-S@X+&-H<B@R,#$I/3XW.#@L
M8VAR*#(P,BD]/C<X."QC:'(H,C`S*3T^-S@X+&-H<B@R,#0I/3XW.#@L8VAR
M*#(P-2D]/C<X."QC:'(H,C`V*3T^-S@X+&-H<B@R,#<I/3XW.#@L8VAR*#(P
M."D]/C<X."QC:'(H,C`Y*3T^-S@X+&-H<B@R,3`I/3XW.#@L8VAR*#(Q,2D]
M/C<X."QC:'(H,C$R*3T^.#DT+&-H<B@R,3,I/3XX,S@L8VAR*#(Q-"D]/C$P
M,38L8VAR*#(Q-2D]/C0U."QC:'(H,C$V*3T^-S0X+&-H<B@R,3<I/3XY,C0L
M8VAR*#(Q."D]/C<T."QC:'(H,C$Y*3T^.3$X+`H@("`@8VAR*#(R,"D]/CDR
M-RQC:'(H,C(Q*3T^.3(X+&-H<B@R,C(I/3XY,C@L8VAR*#(R,RD]/C@S-"QC
M:'(H,C(T*3T^.#<S+&-H<B@R,C4I/3XX,C@L8VAR*#(R-BD]/CDR-"QC:'(H
M,C(W*3T^.3(T+&-H<B@R,C@I/3XY,3<L8VAR*#(R.2D]/CDS,"QC:'(H,C,P
M*3T^.3,Q+&-H<B@R,S$I/3XT-C,L8VAR*#(S,BD]/C@X,RQC:'(H,C,S*3T^
M.#,V+&-H<B@R,S0I/3XX,S8L8VAR*#(S-2D]/C@V-RQC:'(H,C,V*3T^.#8W
M+&-H<B@R,S<I/3XV.38L8VAR*#(S."D]/C8Y-BQC:'(H,C,Y*3T^.#<T+&-H
M<B@R-#`I/3XP+&-H<B@R-#$I/3XX-S0L"B`@("!C:'(H,C0R*3T^-S8P+&-H
M<B@R-#,I/3XY-#8L8VAR*#(T-"D]/C<W,2QC:'(H,C0U*3T^.#8U+&-H<B@R
M-#8I/3XW-S$L8VAR*#(T-RD]/C@X."QC:'(H,C0X*3T^.38W+&-H<B@R-#DI
M/3XX.#@L8VAR*#(U,"D]/C@S,2QC:'(H,C4Q*3T^.#<S+&-H<B@R-3(I/3XY
M,C<L8VAR*#(U,RD]/CDW,"QC:'(H,C4T*3T^.3$X+&-H<B@R-34I/3XP*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<V(N
M<&AP````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,#4`,3`U,34T
M,S$P-C``,#(Q-3<R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*
M)&9O;G1?=VED=&AS6R=T:6UE<T(G72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR
M-3`L8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR*#,I/3XR-3`L8VAR*#0I
M/3XR-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L8VAR*#<I/3XR-3`L8VAR
M*#@I/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^,C4P+&-H<B@Q,2D]/C(U
M,"QC:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H<B@Q-"D]/C(U,"QC:'(H
M,34I/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]/C(U,"QC:'(H,3@I/3XR
M-3`L8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC:'(H,C$I/3XR-3`L"B`@
M("!C:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H<B@R-"D]/C(U,"QC:'(H
M,C4I/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]/C(U,"QC:'(H,C@I/3XR
M-3`L8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC:'(H,S$I/3XR-3`L)R`G
M/3XR-3`L)R$G/3XS,S,L)R(G/3XU-34L)R,G/3XU,#`L)R0G/3XU,#`L)R4G
M/3XQ,#`P+"<F)ST^.#,S+"=<)R<]/C(W."PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C4P,"PG*R<]/C4W,"P*("`@("<L)ST^,C4P+"<M)ST^,S,S+"<N)ST^
M,C4P+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^
M-3`P+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^
M-3`P+"<Y)ST^-3`P+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-3<P+"<])ST^
M-3<P+"<^)ST^-3<P+"<_)ST^-3`P+"=`)ST^.3,P+"=!)ST^-S(R+`H@("`@
M)T(G/3XV-C<L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV,3$L
M)T<G/3XW-S@L)T@G/3XW-S@L)TDG/3XS.#DL)THG/3XU,#`L)TLG/3XW-S@L
M)TPG/3XV-C<L)TTG/3XY-#0L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV,3$L
M)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XU-38L)U0G/3XV-C<L)U4G/3XW,C(L
M)U8G/3XW,C(L)U<G/3XQ,#`P+`H@("`@)U@G/3XW,C(L)UDG/3XW,C(L)UHG
M/3XV-C<L)ULG/3XS,S,L)UQ<)ST^,C<X+"==)ST^,S,S+"=>)ST^-3@Q+"=?
M)ST^-3`P+"=@)ST^,S,S+"=A)ST^-3`P+"=B)ST^-34V+"=C)ST^-#0T+"=D
M)ST^-34V+"=E)ST^-#0T+"=F)ST^,S,S+"=G)ST^-3`P+"=H)ST^-34V+"=I
M)ST^,C<X+"=J)ST^,S,S+"=K)ST^-34V+"=L)ST^,C<X+"=M)ST^.#,S+`H@
M("`@)VXG/3XU-38L)V\G/3XU,#`L)W`G/3XU-38L)W$G/3XU-38L)W(G/3XT
M-#0L)W,G/3XS.#DL)W0G/3XS,S,L)W4G/3XU-38L)W8G/3XU,#`L)W<G/3XW
M,C(L)W@G/3XU,#`L)WDG/3XU,#`L)WHG/3XT-#0L)WLG/3XS.30L)WPG/3XR
M,C`L)WTG/3XS.30L)WXG/3XU,C`L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^
M-3`P+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C,S,RQC:'(H,3,Q*3T^-3`P
M+`H@("`@8VAR*#$S,BD]/C4P,"QC:'(H,3,S*3T^,3`P,"QC:'(H,3,T*3T^
M-3`P+&-H<B@Q,S4I/3XU,#`L8VAR*#$S-BD]/C,S,RQC:'(H,3,W*3T^,3`P
M,"QC:'(H,3,X*3T^-34V+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]/C$P,#`L
M8VAR*#$T,2D]/C,U,"QC:'(H,30R*3T^-C8W+&-H<B@Q-#,I/3XS-3`L8VAR
M*#$T-"D]/C,U,"QC:'(H,30U*3T^,S,S+&-H<B@Q-#8I/3XS,S,L8VAR*#$T
M-RD]/C4P,"QC:'(H,30X*3T^-3`P+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]
M/C4P,"QC:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XQ
M,#`P+`H@("`@8VAR*#$U-"D]/C,X.2QC:'(H,34U*3T^,S,S+&-H<B@Q-38I
M/3XW,C(L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^-#0T+&-H<B@Q-3DI/3XW
M,C(L8VAR*#$V,"D]/C(U,"QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I/3XU,#`L
M8VAR*#$V,RD]/C4P,"QC:'(H,38T*3T^-3`P+&-H<B@Q-C4I/3XU,#`L8VAR
M*#$V-BD]/C(R,"QC:'(H,38W*3T^-3`P+&-H<B@Q-C@I/3XS,S,L8VAR*#$V
M.2D]/C<T-RQC:'(H,3<P*3T^,S`P+&-H<B@Q-S$I/3XU,#`L8VAR*#$W,BD]
M/C4W,"QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW-#<L8VAR*#$W-2D]/C,S
M,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4W,"QC:'(H,3<X*3T^
M,S`P+&-H<B@Q-SDI/3XS,#`L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-34V
M+&-H<B@Q.#(I/3XU-#`L8VAR*#$X,RD]/C(U,"QC:'(H,3@T*3T^,S,S+&-H
M<B@Q.#4I/3XS,#`L8VAR*#$X-BD]/C,S,"QC:'(H,3@W*3T^-3`P+&-H<B@Q
M.#@I/3XW-3`L8VAR*#$X.2D]/C<U,"QC:'(H,3DP*3T^-S4P+&-H<B@Q.3$I
M/3XU,#`L8VAR*#$Y,BD]/C<R,BQC:'(H,3DS*3T^-S(R+&-H<B@Q.30I/3XW
M,C(L8VAR*#$Y-2D]/C<R,BQC:'(H,3DV*3T^-S(R+&-H<B@Q.3<I/3XW,C(L
M"B`@("!C:'(H,3DX*3T^,3`P,"QC:'(H,3DY*3T^-S(R+&-H<B@R,#`I/3XV
M-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W+&-H<B@R,#,I/3XV-C<L
M8VAR*#(P-"D]/C,X.2QC:'(H,C`U*3T^,S@Y+&-H<B@R,#8I/3XS.#DL8VAR
M*#(P-RD]/C,X.2QC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L8VAR*#(Q
M,"D]/C<W."QC:'(H,C$Q*3T^-S<X+&-H<B@R,3(I/3XW-S@L8VAR*#(Q,RD]
M/C<W."QC:'(H,C$T*3T^-S<X+&-H<B@R,34I/3XU-S`L8VAR*#(Q-BD]/C<W
M."QC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*
M("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C<R,BQC:'(H,C(R*3T^-C$Q
M+&-H<B@R,C,I/3XU-38L8VAR*#(R-"D]/C4P,"QC:'(H,C(U*3T^-3`P+&-H
M<B@R,C8I/3XU,#`L8VAR*#(R-RD]/C4P,"QC:'(H,C(X*3T^-3`P+&-H<B@R
M,CDI/3XU,#`L8VAR*#(S,"D]/C<R,BQC:'(H,C,Q*3T^-#0T+&-H<B@R,S(I
M/3XT-#0L8VAR*#(S,RD]/C0T-"QC:'(H,C,T*3T^-#0T+&-H<B@R,S4I/3XT
M-#0L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L
M8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-3`P+&-H<B@R-#$I/3XU-38L"B`@
M("!C:'(H,C0R*3T^-3`P+&-H<B@R-#,I/3XU,#`L8VAR*#(T-"D]/C4P,"QC
M:'(H,C0U*3T^-3`P+&-H<B@R-#8I/3XU,#`L8VAR*#(T-RD]/C4W,"QC:'(H
M,C0X*3T^-3`P+&-H<B@R-#DI/3XU-38L8VAR*#(U,"D]/C4U-BQC:'(H,C4Q
M*3T^-34V+&-H<B@R-3(I/3XU-38L8VAR*#(U,RD]/C4P,"QC:'(H,C4T*3T^
M-34V+&-H<B@R-34I/3XU,#`I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM97-I
M+G!H<```````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,3<V`#$P-3$U
M-#,Q,#8P`#`R,38Q,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO
M"B1F;VYT7W=I9'1H<ULG=&EM97-))UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^
M,C4P+&-H<B@Q*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T
M*3T^,C4P+&-H<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H
M<B@X*3T^,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR
M-3`L8VAR*#$R*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR
M*#$U*3T^,C4P+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^
M,C4P+&-H<B@Q.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@
M("`@8VAR*#(R*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR
M*#(U*3T^,C4P+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^
M,C4P+&-H<B@R.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@
M)ST^,C4P+"<A)ST^,S,S+"<B)ST^-#(P+"<C)ST^-3`P+"<D)ST^-3`P+"<E
M)ST^.#,S+"<F)ST^-S<X+"=<)R<]/C(Q-"PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C4P,"PG*R<]/C8W-2P*("`@("<L)ST^,C4P+"<M)ST^,S,S+"<N)ST^
M,C4P+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^
M-3`P+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^
M-3`P+"<Y)ST^-3`P+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-C<U+"<])ST^
M-C<U+"<^)ST^-C<U+"<_)ST^-3`P+"=`)ST^.3(P+"=!)ST^-C$Q+`H@("`@
M)T(G/3XV,3$L)T,G/3XV-C<L)T0G/3XW,C(L)T4G/3XV,3$L)T8G/3XV,3$L
M)T<G/3XW,C(L)T@G/3XW,C(L)TDG/3XS,S,L)THG/3XT-#0L)TLG/3XV-C<L
M)TPG/3XU-38L)TTG/3XX,S,L)TXG/3XV-C<L)T\G/3XW,C(L)U`G/3XV,3$L
M)U$G/3XW,C(L)U(G/3XV,3$L)U,G/3XU,#`L)U0G/3XU-38L)U4G/3XW,C(L
M)U8G/3XV,3$L)U<G/3XX,S,L"B`@("`G6"<]/C8Q,2PG62<]/C4U-BPG6B<]
M/C4U-BPG6R<]/C,X.2PG7%PG/3XR-S@L)UTG/3XS.#DL)UXG/3XT,C(L)U\G
M/3XU,#`L)V`G/3XS,S,L)V$G/3XU,#`L)V(G/3XU,#`L)V,G/3XT-#0L)V0G
M/3XU,#`L)V4G/3XT-#0L)V8G/3XR-S@L)V<G/3XU,#`L)V@G/3XU,#`L)VDG
M/3XR-S@L)VHG/3XR-S@L)VLG/3XT-#0L)VPG/3XR-S@L)VTG/3XW,C(L"B`@
M("`G;B<]/C4P,"PG;R<]/C4P,"PG<"<]/C4P,"PG<2<]/C4P,"PG<B<]/C,X
M.2PG<R<]/C,X.2PG="<]/C(W."PG=2<]/C4P,"PG=B<]/C0T-"PG=R<]/C8V
M-RPG>"<]/C0T-"PG>2<]/C0T-"PG>B<]/C,X.2PG>R<]/C0P,"PG?"<]/C(W
M-2PG?2<]/C0P,"PG?B<]/C4T,2QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU
M,#`L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,S,S+&-H<B@Q,S$I/3XU,#`L
M"B`@("!C:'(H,3,R*3T^-34V+&-H<B@Q,S,I/3XX.#DL8VAR*#$S-"D]/C4P
M,"QC:'(H,3,U*3T^-3`P+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L
M8VAR*#$S."D]/C4P,"QC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XY-#0L8VAR
M*#$T,2D]/C,U,"QC:'(H,30R*3T^-34V+&-H<B@Q-#,I/3XS-3`L8VAR*#$T
M-"D]/C,U,"QC:'(H,30U*3T^,S,S+&-H<B@Q-#8I/3XS,S,L8VAR*#$T-RD]
M/C4U-BQC:'(H,30X*3T^-34V+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]/C4P
M,"QC:'(H,34Q*3T^.#@Y+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/CDX,"P*
M("`@(&-H<B@Q-30I/3XS.#DL8VAR*#$U-2D]/C,S,RQC:'(H,34V*3T^-C8W
M+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C,X.2QC:'(H,34Y*3T^-34V+&-H
M<B@Q-C`I/3XR-3`L8VAR*#$V,2D]/C,X.2QC:'(H,38R*3T^-3`P+&-H<B@Q
M-C,I/3XU,#`L8VAR*#$V-"D]/C4P,"QC:'(H,38U*3T^-3`P+&-H<B@Q-C8I
M/3XR-S4L8VAR*#$V-RD]/C4P,"QC:'(H,38X*3T^,S,S+&-H<B@Q-CDI/3XW
M-C`L8VAR*#$W,"D]/C(W-BQC:'(H,3<Q*3T^-3`P+&-H<B@Q-S(I/3XV-S4L
M8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S8P+&-H<B@Q-S4I/3XS,S,L"B`@
M("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XV-S4L8VAR*#$W."D]/C,P,"QC
M:'(H,3<Y*3T^,S`P+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C4P,"QC:'(H
M,3@R*3T^-3(S+&-H<B@Q.#,I/3XR-3`L8VAR*#$X-"D]/C,S,RQC:'(H,3@U
M*3T^,S`P+&-H<B@Q.#8I/3XS,3`L8VAR*#$X-RD]/C4P,"QC:'(H,3@X*3T^
M-S4P+&-H<B@Q.#DI/3XW-3`L8VAR*#$Y,"D]/C<U,"QC:'(H,3DQ*3T^-3`P
M+&-H<B@Q.3(I/3XV,3$L8VAR*#$Y,RD]/C8Q,2QC:'(H,3DT*3T^-C$Q+&-H
M<B@Q.34I/3XV,3$L8VAR*#$Y-BD]/C8Q,2QC:'(H,3DW*3T^-C$Q+`H@("`@
M8VAR*#$Y."D]/C@X.2QC:'(H,3DY*3T^-C8W+&-H<B@R,#`I/3XV,3$L8VAR
M*#(P,2D]/C8Q,2QC:'(H,C`R*3T^-C$Q+&-H<B@R,#,I/3XV,3$L8VAR*#(P
M-"D]/C,S,RQC:'(H,C`U*3T^,S,S+&-H<B@R,#8I/3XS,S,L8VAR*#(P-RD]
M/C,S,RQC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XV-C<L8VAR*#(Q,"D]/C<R
M,BQC:'(H,C$Q*3T^-S(R+&-H<B@R,3(I/3XW,C(L8VAR*#(Q,RD]/C<R,BQC
M:'(H,C$T*3T^-S(R+&-H<B@R,34I/3XV-S4L8VAR*#(Q-BD]/C<R,BQC:'(H
M,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*("`@(&-H
M<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C4U-BQC:'(H,C(R*3T^-C$Q+&-H<B@R
M,C,I/3XU,#`L8VAR*#(R-"D]/C4P,"QC:'(H,C(U*3T^-3`P+&-H<B@R,C8I
M/3XU,#`L8VAR*#(R-RD]/C4P,"QC:'(H,C(X*3T^-3`P+&-H<B@R,CDI/3XU
M,#`L8VAR*#(S,"D]/C8V-RQC:'(H,C,Q*3T^-#0T+&-H<B@R,S(I/3XT-#0L
M8VAR*#(S,RD]/C0T-"QC:'(H,C,T*3T^-#0T+&-H<B@R,S4I/3XT-#0L8VAR
M*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L8VAR*#(S
M.2D]/C(W."QC:'(H,C0P*3T^-3`P+&-H<B@R-#$I/3XU,#`L"B`@("!C:'(H
M,C0R*3T^-3`P+&-H<B@R-#,I/3XU,#`L8VAR*#(T-"D]/C4P,"QC:'(H,C0U
M*3T^-3`P+&-H<B@R-#8I/3XU,#`L8VAR*#(T-RD]/C8W-2QC:'(H,C0X*3T^
M-3`P+&-H<B@R-#DI/3XU,#`L8VAR*#(U,"D]/C4P,"QC:'(H,C4Q*3T^-3`P
M+&-H<B@R-3(I/3XU,#`L8VAR*#(U,RD]/C0T-"QC:'(H,C4T*3T^-3`P+&-H
M<B@R-34I/3XT-#0I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E
M=&EC86(N<&AP````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(P-P`Q,#4Q
M-30S,3`V,``P,C(T,3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J
M+PHD9F]N=%]W:61T:'-;)VAE;'9E=&EC84(G72`](&%R<F%Y*`H@("`@8VAR
M*#`I/3XR-S@L8VAR*#$I/3XR-S@L8VAR*#(I/3XR-S@L8VAR*#,I/3XR-S@L
M8VAR*#0I/3XR-S@L8VAR*#4I/3XR-S@L8VAR*#8I/3XR-S@L8VAR*#<I/3XR
M-S@L8VAR*#@I/3XR-S@L8VAR*#DI/3XR-S@L8VAR*#$P*3T^,C<X+&-H<B@Q
M,2D]/C(W."QC:'(H,3(I/3XR-S@L8VAR*#$S*3T^,C<X+&-H<B@Q-"D]/C(W
M."QC:'(H,34I/3XR-S@L8VAR*#$V*3T^,C<X+&-H<B@Q-RD]/C(W."QC:'(H
M,3@I/3XR-S@L8VAR*#$Y*3T^,C<X+&-H<B@R,"D]/C(W."QC:'(H,C$I/3XR
M-S@L"B`@("!C:'(H,C(I/3XR-S@L8VAR*#(S*3T^,C<X+&-H<B@R-"D]/C(W
M."QC:'(H,C4I/3XR-S@L8VAR*#(V*3T^,C<X+&-H<B@R-RD]/C(W."QC:'(H
M,C@I/3XR-S@L8VAR*#(Y*3T^,C<X+&-H<B@S,"D]/C(W."QC:'(H,S$I/3XR
M-S@L)R`G/3XR-S@L)R$G/3XS,S,L)R(G/3XT-S0L)R,G/3XU-38L)R0G/3XU
M-38L)R4G/3XX.#DL)R8G/3XW,C(L)UPG)ST^,C,X+"<H)ST^,S,S+"<I)ST^
M,S,S+"<J)ST^,S@Y+"<K)ST^-3@T+`H@("`@)RPG/3XR-S@L)RTG/3XS,S,L
M)RXG/3XR-S@L)R\G/3XR-S@L)S`G/3XU-38L)S$G/3XU-38L)S(G/3XU-38L
M)S,G/3XU-38L)S0G/3XU-38L)S4G/3XU-38L)S8G/3XU-38L)S<G/3XU-38L
M)S@G/3XU-38L)SDG/3XU-38L)SHG/3XS,S,L)SLG/3XS,S,L)SPG/3XU.#0L
M)STG/3XU.#0L)SXG/3XU.#0L)S\G/3XV,3$L)T`G/3XY-S4L)T$G/3XW,C(L
M"B`@("`G0B<]/C<R,BPG0R<]/C<R,BPG1"<]/C<R,BPG12<]/C8V-RPG1B<]
M/C8Q,2PG1R<]/C<W."PG2"<]/C<R,BPG22<]/C(W."PG2B<]/C4U-BPG2R<]
M/C<R,BPG3"<]/C8Q,2PG32<]/C@S,RPG3B<]/C<R,BPG3R<]/C<W."PG4"<]
M/C8V-RPG42<]/C<W."PG4B<]/C<R,BPG4R<]/C8V-RPG5"<]/C8Q,2PG52<]
M/C<R,BPG5B<]/C8V-RPG5R<]/CDT-"P*("`@("=8)ST^-C8W+"=9)ST^-C8W
M+"=:)ST^-C$Q+"=;)ST^,S,S+"=<7"<]/C(W."PG72<]/C,S,RPG7B<]/C4X
M-"PG7R<]/C4U-BPG8"<]/C,S,RPG82<]/C4U-BPG8B<]/C8Q,2PG8R<]/C4U
M-BPG9"<]/C8Q,2PG92<]/C4U-BPG9B<]/C,S,RPG9R<]/C8Q,2PG:"<]/C8Q
M,2PG:2<]/C(W."PG:B<]/C(W."PG:R<]/C4U-BPG;"<]/C(W."PG;2<]/C@X
M.2P*("`@("=N)ST^-C$Q+"=O)ST^-C$Q+"=P)ST^-C$Q+"=Q)ST^-C$Q+"=R
M)ST^,S@Y+"=S)ST^-34V+"=T)ST^,S,S+"=U)ST^-C$Q+"=V)ST^-34V+"=W
M)ST^-S<X+"=X)ST^-34V+"=Y)ST^-34V+"=Z)ST^-3`P+"=[)ST^,S@Y+"=\
M)ST^,C@P+"=])ST^,S@Y+"=^)ST^-3@T+&-H<B@Q,C<I/3XS-3`L8VAR*#$R
M."D]/C4U-BQC:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XR-S@L8VAR*#$S,2D]
M/C4U-BP*("`@(&-H<B@Q,S(I/3XU,#`L8VAR*#$S,RD]/C$P,#`L8VAR*#$S
M-"D]/C4U-BQC:'(H,3,U*3T^-34V+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]
M/C$P,#`L8VAR*#$S."D]/C8V-RQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XQ
M,#`P+&-H<B@Q-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P
M+&-H<B@Q-#0I/3XS-3`L8VAR*#$T-2D]/C(W."QC:'(H,30V*3T^,C<X+&-H
M<B@Q-#<I/3XU,#`L8VAR*#$T."D]/C4P,"QC:'(H,30Y*3T^,S4P+&-H<B@Q
M-3`I/3XU-38L8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S
M*3T^,3`P,"P*("`@(&-H<B@Q-30I/3XU-38L8VAR*#$U-2D]/C,S,RQC:'(H
M,34V*3T^.30T+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C4P,"QC:'(H,34Y
M*3T^-C8W+&-H<B@Q-C`I/3XR-S@L8VAR*#$V,2D]/C,S,RQC:'(H,38R*3T^
M-34V+&-H<B@Q-C,I/3XU-38L8VAR*#$V-"D]/C4U-BQC:'(H,38U*3T^-34V
M+&-H<B@Q-C8I/3XR.#`L8VAR*#$V-RD]/C4U-BQC:'(H,38X*3T^,S,S+&-H
M<B@Q-CDI/3XW,S<L8VAR*#$W,"D]/C,W,"QC:'(H,3<Q*3T^-34V+&-H<B@Q
M-S(I/3XU.#0L8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S,W+&-H<B@Q-S4I
M/3XS,S,L"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU.#0L8VAR*#$W
M."D]/C,S,RQC:'(H,3<Y*3T^,S,S+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]
M/C8Q,2QC:'(H,3@R*3T^-34V+&-H<B@Q.#,I/3XR-S@L8VAR*#$X-"D]/C,S
M,RQC:'(H,3@U*3T^,S,S+&-H<B@Q.#8I/3XS-C4L8VAR*#$X-RD]/C4U-BQC
M:'(H,3@X*3T^.#,T+&-H<B@Q.#DI/3XX,S0L8VAR*#$Y,"D]/C@S-"QC:'(H
M,3DQ*3T^-C$Q+&-H<B@Q.3(I/3XW,C(L8VAR*#$Y,RD]/C<R,BQC:'(H,3DT
M*3T^-S(R+&-H<B@Q.34I/3XW,C(L8VAR*#$Y-BD]/C<R,BQC:'(H,3DW*3T^
M-S(R+`H@("`@8VAR*#$Y."D]/C$P,#`L8VAR*#$Y.2D]/C<R,BQC:'(H,C`P
M*3T^-C8W+&-H<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^
M-C8W+&-H<B@R,#0I/3XR-S@L8VAR*#(P-2D]/C(W."QC:'(H,C`V*3T^,C<X
M+&-H<B@R,#<I/3XR-S@L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H
M<B@R,3`I/3XW-S@L8VAR*#(Q,2D]/C<W."QC:'(H,C$R*3T^-S<X+&-H<B@R
M,3,I/3XW-S@L8VAR*#(Q-"D]/C<W."QC:'(H,C$U*3T^-3@T+&-H<B@R,38I
M/3XW-S@L8VAR*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW
M,C(L"B`@("!C:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV-C<L8VAR*#(R,BD]
M/C8V-RQC:'(H,C(S*3T^-C$Q+&-H<B@R,C0I/3XU-38L8VAR*#(R-2D]/C4U
M-BQC:'(H,C(V*3T^-34V+&-H<B@R,C<I/3XU-38L8VAR*#(R."D]/C4U-BQC
M:'(H,C(Y*3T^-34V+&-H<B@R,S`I/3XX.#DL8VAR*#(S,2D]/C4U-BQC:'(H
M,C,R*3T^-34V+&-H<B@R,S,I/3XU-38L8VAR*#(S-"D]/C4U-BQC:'(H,C,U
M*3T^-34V+&-H<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^
M,C<X+&-H<B@R,SDI/3XR-S@L8VAR*#(T,"D]/C8Q,2QC:'(H,C0Q*3T^-C$Q
M+`H@("`@8VAR*#(T,BD]/C8Q,2QC:'(H,C0S*3T^-C$Q+&-H<B@R-#0I/3XV
M,3$L8VAR*#(T-2D]/C8Q,2QC:'(H,C0V*3T^-C$Q+&-H<B@R-#<I/3XU.#0L
M8VAR*#(T."D]/C8Q,2QC:'(H,C0Y*3T^-C$Q+&-H<B@R-3`I/3XV,3$L8VAR
M*#(U,2D]/C8Q,2QC:'(H,C4R*3T^-C$Q+&-H<B@R-3,I/3XU-38L8VAR*#(U
M-"D]/C8Q,2QC:'(H,C4U*3T^-34V*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV
M971I8V%I+G!H<```````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,3``,3`U
M,34T,S$P-C``,#(R-#(P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@
M*B\*)&9O;G1?=VED=&AS6R=H96QV971I8V%))UT@/2!A<G)A>2@*("`@(&-H
M<B@P*3T^,C<X+&-H<B@Q*3T^,C<X+&-H<B@R*3T^,C<X+&-H<B@S*3T^,C<X
M+&-H<B@T*3T^,C<X+&-H<B@U*3T^,C<X+&-H<B@V*3T^,C<X+&-H<B@W*3T^
M,C<X+&-H<B@X*3T^,C<X+&-H<B@Y*3T^,C<X+&-H<B@Q,"D]/C(W."QC:'(H
M,3$I/3XR-S@L8VAR*#$R*3T^,C<X+&-H<B@Q,RD]/C(W."QC:'(H,30I/3XR
M-S@L8VAR*#$U*3T^,C<X+&-H<B@Q-BD]/C(W."QC:'(H,3<I/3XR-S@L8VAR
M*#$X*3T^,C<X+&-H<B@Q.2D]/C(W."QC:'(H,C`I/3XR-S@L8VAR*#(Q*3T^
M,C<X+`H@("`@8VAR*#(R*3T^,C<X+&-H<B@R,RD]/C(W."QC:'(H,C0I/3XR
M-S@L8VAR*#(U*3T^,C<X+&-H<B@R-BD]/C(W."QC:'(H,C<I/3XR-S@L8VAR
M*#(X*3T^,C<X+&-H<B@R.2D]/C(W."QC:'(H,S`I/3XR-S@L8VAR*#,Q*3T^
M,C<X+"<@)ST^,C<X+"<A)ST^,C<X+"<B)ST^,S4U+"<C)ST^-34V+"<D)ST^
M-34V+"<E)ST^.#@Y+"<F)ST^-C8W+"=<)R<]/C$Y,2PG*"<]/C,S,RPG*2<]
M/C,S,RPG*B<]/C,X.2PG*R<]/C4X-"P*("`@("<L)ST^,C<X+"<M)ST^,S,S
M+"<N)ST^,C<X+"<O)ST^,C<X+"<P)ST^-34V+"<Q)ST^-34V+"<R)ST^-34V
M+"<S)ST^-34V+"<T)ST^-34V+"<U)ST^-34V+"<V)ST^-34V+"<W)ST^-34V
M+"<X)ST^-34V+"<Y)ST^-34V+"<Z)ST^,C<X+"<[)ST^,C<X+"<\)ST^-3@T
M+"<])ST^-3@T+"<^)ST^-3@T+"<_)ST^-34V+"=`)ST^,3`Q-2PG02<]/C8V
M-RP*("`@("=")ST^-C8W+"=#)ST^-S(R+"=$)ST^-S(R+"=%)ST^-C8W+"=&
M)ST^-C$Q+"=')ST^-S<X+"=()ST^-S(R+"=))ST^,C<X+"=*)ST^-3`P+"=+
M)ST^-C8W+"=,)ST^-34V+"=-)ST^.#,S+"=.)ST^-S(R+"=/)ST^-S<X+"=0
M)ST^-C8W+"=1)ST^-S<X+"=2)ST^-S(R+"=3)ST^-C8W+"=4)ST^-C$Q+"=5
M)ST^-S(R+"=6)ST^-C8W+"=7)ST^.30T+`H@("`@)U@G/3XV-C<L)UDG/3XV
M-C<L)UHG/3XV,3$L)ULG/3XR-S@L)UQ<)ST^,C<X+"==)ST^,C<X+"=>)ST^
M-#8Y+"=?)ST^-34V+"=@)ST^,S,S+"=A)ST^-34V+"=B)ST^-34V+"=C)ST^
M-3`P+"=D)ST^-34V+"=E)ST^-34V+"=F)ST^,C<X+"=G)ST^-34V+"=H)ST^
M-34V+"=I)ST^,C(R+"=J)ST^,C(R+"=K)ST^-3`P+"=L)ST^,C(R+"=M)ST^
M.#,S+`H@("`@)VXG/3XU-38L)V\G/3XU-38L)W`G/3XU-38L)W$G/3XU-38L
M)W(G/3XS,S,L)W,G/3XU,#`L)W0G/3XR-S@L)W4G/3XU-38L)W8G/3XU,#`L
M)W<G/3XW,C(L)W@G/3XU,#`L)WDG/3XU,#`L)WHG/3XU,#`L)WLG/3XS,S0L
M)WPG/3XR-C`L)WTG/3XS,S0L)WXG/3XU.#0L8VAR*#$R-RD]/C,U,"QC:'(H
M,3(X*3T^-34V+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C(R,BQC:'(H,3,Q
M*3T^-34V+`H@("`@8VAR*#$S,BD]/C,S,RQC:'(H,3,S*3T^,3`P,"QC:'(H
M,3,T*3T^-34V+&-H<B@Q,S4I/3XU-38L8VAR*#$S-BD]/C,S,RQC:'(H,3,W
M*3T^,3`P,"QC:'(H,3,X*3T^-C8W+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]
M/C$P,#`L8VAR*#$T,2D]/C,U,"QC:'(H,30R*3T^-C$Q+&-H<B@Q-#,I/3XS
M-3`L8VAR*#$T-"D]/C,U,"QC:'(H,30U*3T^,C(R+&-H<B@Q-#8I/3XR,C(L
M8VAR*#$T-RD]/C,S,RQC:'(H,30X*3T^,S,S+&-H<B@Q-#DI/3XS-3`L8VAR
M*#$U,"D]/C4U-BQC:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q
M-3,I/3XQ,#`P+`H@("`@8VAR*#$U-"D]/C4P,"QC:'(H,34U*3T^,S,S+&-H
M<B@Q-38I/3XY-#0L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^-3`P+&-H<B@Q
M-3DI/3XV-C<L8VAR*#$V,"D]/C(W."QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I
M/3XU-38L8VAR*#$V,RD]/C4U-BQC:'(H,38T*3T^-34V+&-H<B@Q-C4I/3XU
M-38L8VAR*#$V-BD]/C(V,"QC:'(H,38W*3T^-34V+&-H<B@Q-C@I/3XS,S,L
M8VAR*#$V.2D]/C<S-RQC:'(H,3<P*3T^,S<P+&-H<B@Q-S$I/3XU-38L8VAR
M*#$W,BD]/C4X-"QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW,S<L8VAR*#$W
M-2D]/C,S,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4X-"QC:'(H
M,3<X*3T^,S,S+&-H<B@Q-SDI/3XS,S,L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q
M*3T^-34V+&-H<B@Q.#(I/3XU,S<L8VAR*#$X,RD]/C(W."QC:'(H,3@T*3T^
M,S,S+&-H<B@Q.#4I/3XS,S,L8VAR*#$X-BD]/C,V-2QC:'(H,3@W*3T^-34V
M+&-H<B@Q.#@I/3XX,S0L8VAR*#$X.2D]/C@S-"QC:'(H,3DP*3T^.#,T+&-H
M<B@Q.3$I/3XV,3$L8VAR*#$Y,BD]/C8V-RQC:'(H,3DS*3T^-C8W+&-H<B@Q
M.30I/3XV-C<L8VAR*#$Y-2D]/C8V-RQC:'(H,3DV*3T^-C8W+&-H<B@Q.3<I
M/3XV-C<L"B`@("!C:'(H,3DX*3T^,3`P,"QC:'(H,3DY*3T^-S(R+&-H<B@R
M,#`I/3XV-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W+&-H<B@R,#,I
M/3XV-C<L8VAR*#(P-"D]/C(W."QC:'(H,C`U*3T^,C<X+&-H<B@R,#8I/3XR
M-S@L8VAR*#(P-RD]/C(W."QC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L
M8VAR*#(Q,"D]/C<W."QC:'(H,C$Q*3T^-S<X+&-H<B@R,3(I/3XW-S@L8VAR
M*#(Q,RD]/C<W."QC:'(H,C$T*3T^-S<X+&-H<B@R,34I/3XU.#0L8VAR*#(Q
M-BD]/C<W."QC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]
M/C<R,BP*("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C8V-RQC:'(H,C(R
M*3T^-C8W+&-H<B@R,C,I/3XV,3$L8VAR*#(R-"D]/C4U-BQC:'(H,C(U*3T^
M-34V+&-H<B@R,C8I/3XU-38L8VAR*#(R-RD]/C4U-BQC:'(H,C(X*3T^-34V
M+&-H<B@R,CDI/3XU-38L8VAR*#(S,"D]/C@X.2QC:'(H,C,Q*3T^-3`P+&-H
M<B@R,S(I/3XU-38L8VAR*#(S,RD]/C4U-BQC:'(H,C,T*3T^-34V+&-H<B@R
M,S4I/3XU-38L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I
M/3XR-S@L8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-34V+&-H<B@R-#$I/3XU
M-38L"B`@("!C:'(H,C0R*3T^-34V+&-H<B@R-#,I/3XU-38L8VAR*#(T-"D]
M/C4U-BQC:'(H,C0U*3T^-34V+&-H<B@R-#8I/3XU-38L8VAR*#(T-RD]/C4X
M-"QC:'(H,C0X*3T^-C$Q+&-H<B@R-#DI/3XU-38L8VAR*#(U,"D]/C4U-BQC
M:'(H,C4Q*3T^-34V+&-H<B@R-3(I/3XU-38L8VAR*#(U,RD]/C4P,"QC:'(H
M,C4T*3T^-34V+&-H<B@R-34I/3XU,#`I.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM
M97-B:2YP:'``````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,C`R`#$P
M-3$U-#,Q,#8P`#`R,3<T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*
M("HO"B1F;VYT7W=I9'1H<ULG=&EM97-"22==(#T@87)R87DH"B`@("!C:'(H
M,"D]/C(U,"QC:'(H,2D]/C(U,"QC:'(H,BD]/C(U,"QC:'(H,RD]/C(U,"QC
M:'(H-"D]/C(U,"QC:'(H-2D]/C(U,"QC:'(H-BD]/C(U,"QC:'(H-RD]/C(U
M,"QC:'(H."D]/C(U,"QC:'(H.2D]/C(U,"QC:'(H,3`I/3XR-3`L8VAR*#$Q
M*3T^,C4P+&-H<B@Q,BD]/C(U,"QC:'(H,3,I/3XR-3`L8VAR*#$T*3T^,C4P
M+&-H<B@Q-2D]/C(U,"QC:'(H,38I/3XR-3`L8VAR*#$W*3T^,C4P+&-H<B@Q
M."D]/C(U,"QC:'(H,3DI/3XR-3`L8VAR*#(P*3T^,C4P+&-H<B@R,2D]/C(U
M,"P*("`@(&-H<B@R,BD]/C(U,"QC:'(H,C,I/3XR-3`L8VAR*#(T*3T^,C4P
M+&-H<B@R-2D]/C(U,"QC:'(H,C8I/3XR-3`L8VAR*#(W*3T^,C4P+&-H<B@R
M."D]/C(U,"QC:'(H,CDI/3XR-3`L8VAR*#,P*3T^,C4P+&-H<B@S,2D]/C(U
M,"PG("<]/C(U,"PG(2<]/C,X.2PG(B<]/C4U-2PG(R<]/C4P,"PG)"<]/C4P
M,"PG)2<]/C@S,RPG)B<]/C<W."PG7"<G/3XR-S@L)R@G/3XS,S,L)RDG/3XS
M,S,L)RHG/3XU,#`L)RLG/3XU-S`L"B`@("`G+"<]/C(U,"PG+2<]/C,S,RPG
M+B<]/C(U,"PG+R<]/C(W."PG,"<]/C4P,"PG,2<]/C4P,"PG,B<]/C4P,"PG
M,R<]/C4P,"PG-"<]/C4P,"PG-2<]/C4P,"PG-B<]/C4P,"PG-R<]/C4P,"PG
M."<]/C4P,"PG.2<]/C4P,"PG.B<]/C,S,RPG.R<]/C,S,RPG/"<]/C4W,"PG
M/2<]/C4W,"PG/B<]/C4W,"PG/R<]/C4P,"PG0"<]/C@S,BPG02<]/C8V-RP*
M("`@("=")ST^-C8W+"=#)ST^-C8W+"=$)ST^-S(R+"=%)ST^-C8W+"=&)ST^
M-C8W+"=')ST^-S(R+"=()ST^-S<X+"=))ST^,S@Y+"=*)ST^-3`P+"=+)ST^
M-C8W+"=,)ST^-C$Q+"=-)ST^.#@Y+"=.)ST^-S(R+"=/)ST^-S(R+"=0)ST^
M-C$Q+"=1)ST^-S(R+"=2)ST^-C8W+"=3)ST^-34V+"=4)ST^-C$Q+"=5)ST^
M-S(R+"=6)ST^-C8W+"=7)ST^.#@Y+`H@("`@)U@G/3XV-C<L)UDG/3XV,3$L
M)UHG/3XV,3$L)ULG/3XS,S,L)UQ<)ST^,C<X+"==)ST^,S,S+"=>)ST^-3<P
M+"=?)ST^-3`P+"=@)ST^,S,S+"=A)ST^-3`P+"=B)ST^-3`P+"=C)ST^-#0T
M+"=D)ST^-3`P+"=E)ST^-#0T+"=F)ST^,S,S+"=G)ST^-3`P+"=H)ST^-34V
M+"=I)ST^,C<X+"=J)ST^,C<X+"=K)ST^-3`P+"=L)ST^,C<X+"=M)ST^-S<X
M+`H@("`@)VXG/3XU-38L)V\G/3XU,#`L)W`G/3XU,#`L)W$G/3XU,#`L)W(G
M/3XS.#DL)W,G/3XS.#DL)W0G/3XR-S@L)W4G/3XU-38L)W8G/3XT-#0L)W<G
M/3XV-C<L)W@G/3XU,#`L)WDG/3XT-#0L)WHG/3XS.#DL)WLG/3XS-#@L)WPG
M/3XR,C`L)WTG/3XS-#@L)WXG/3XU-S`L8VAR*#$R-RD]/C,U,"QC:'(H,3(X
M*3T^-3`P+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C,S,RQC:'(H,3,Q*3T^
M-3`P+`H@("`@8VAR*#$S,BD]/C4P,"QC:'(H,3,S*3T^,3`P,"QC:'(H,3,T
M*3T^-3`P+&-H<B@Q,S4I/3XU,#`L8VAR*#$S-BD]/C,S,RQC:'(H,3,W*3T^
M,3`P,"QC:'(H,3,X*3T^-34V+&-H<B@Q,SDI/3XS,S,L8VAR*#$T,"D]/CDT
M-"QC:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC
M:'(H,30T*3T^,S4P+&-H<B@Q-#4I/3XS,S,L8VAR*#$T-BD]/C,S,RQC:'(H
M,30W*3T^-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]/C,U,"QC:'(H,34P
M*3T^-3`P+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]
M/C$P,#`L"B`@("!C:'(H,34T*3T^,S@Y+&-H<B@Q-34I/3XS,S,L8VAR*#$U
M-BD]/C<R,BQC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XS.#DL8VAR*#$U.2D]
M/C8Q,2QC:'(H,38P*3T^,C4P+&-H<B@Q-C$I/3XS.#DL8VAR*#$V,BD]/C4P
M,"QC:'(H,38S*3T^-3`P+&-H<B@Q-C0I/3XU,#`L8VAR*#$V-2D]/C4P,"QC
M:'(H,38V*3T^,C(P+&-H<B@Q-C<I/3XU,#`L8VAR*#$V."D]/C,S,RQC:'(H
M,38Y*3T^-S0W+&-H<B@Q-S`I/3XR-C8L8VAR*#$W,2D]/C4P,"QC:'(H,3<R
M*3T^-C`V+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<T-RQC:'(H,3<U*3T^
M,S,S+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3<P+&-H<B@Q-S@I
M/3XS,#`L8VAR*#$W.2D]/C,P,"QC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU
M-S8L8VAR*#$X,BD]/C4P,"QC:'(H,3@S*3T^,C4P+&-H<B@Q.#0I/3XS,S,L
M8VAR*#$X-2D]/C,P,"QC:'(H,3@V*3T^,S`P+&-H<B@Q.#<I/3XU,#`L8VAR
M*#$X."D]/C<U,"QC:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I/3XW-3`L8VAR*#$Y
M,2D]/C4P,"QC:'(H,3DR*3T^-C8W+&-H<B@Q.3,I/3XV-C<L8VAR*#$Y-"D]
M/C8V-RQC:'(H,3DU*3T^-C8W+&-H<B@Q.38I/3XV-C<L8VAR*#$Y-RD]/C8V
M-RP*("`@(&-H<B@Q.3@I/3XY-#0L8VAR*#$Y.2D]/C8V-RQC:'(H,C`P*3T^
M-C8W+&-H<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^-C8W
M+&-H<B@R,#0I/3XS.#DL8VAR*#(P-2D]/C,X.2QC:'(H,C`V*3T^,S@Y+&-H
M<B@R,#<I/3XS.#DL8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R
M,3`I/3XW,C(L8VAR*#(Q,2D]/C<R,BQC:'(H,C$R*3T^-S(R+&-H<B@R,3,I
M/3XW,C(L8VAR*#(Q-"D]/C<R,BQC:'(H,C$U*3T^-3<P+&-H<B@R,38I/3XW
M,C(L8VAR*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L
M"B`@("!C:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV,3$L8VAR*#(R,BD]/C8Q
M,2QC:'(H,C(S*3T^-3`P+&-H<B@R,C0I/3XU,#`L8VAR*#(R-2D]/C4P,"QC
M:'(H,C(V*3T^-3`P+&-H<B@R,C<I/3XU,#`L8VAR*#(R."D]/C4P,"QC:'(H
M,C(Y*3T^-3`P+&-H<B@R,S`I/3XW,C(L8VAR*#(S,2D]/C0T-"QC:'(H,C,R
M*3T^-#0T+&-H<B@R,S,I/3XT-#0L8VAR*#(S-"D]/C0T-"QC:'(H,C,U*3T^
M-#0T+&-H<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X
M+&-H<B@R,SDI/3XR-S@L8VAR*#(T,"D]/C4P,"QC:'(H,C0Q*3T^-34V+`H@
M("`@8VAR*#(T,BD]/C4P,"QC:'(H,C0S*3T^-3`P+&-H<B@R-#0I/3XU,#`L
M8VAR*#(T-2D]/C4P,"QC:'(H,C0V*3T^-3`P+&-H<B@R-#<I/3XU-S`L8VAR
M*#(T."D]/C4P,"QC:'(H,C0Y*3T^-34V+&-H<B@R-3`I/3XU-38L8VAR*#(U
M,2D]/C4U-BQC:'(H,C4R*3T^-34V+&-H<B@R-3,I/3XT-#0L8VAR*#(U-"D]
M/C4P,"QC:'(H,C4U*3T^-#0T*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE
M;'9E=&EC82YP:'``````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(P-P`Q
M,#4Q-30S,3`V,``P,C(R-34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&
M"B`J+PHD9F]N=%]W:61T:'-;)VAE;'9E=&EC82==(#T@87)R87DH"B`@("!C
M:'(H,"D]/C(W."QC:'(H,2D]/C(W."QC:'(H,BD]/C(W."QC:'(H,RD]/C(W
M."QC:'(H-"D]/C(W."QC:'(H-2D]/C(W."QC:'(H-BD]/C(W."QC:'(H-RD]
M/C(W."QC:'(H."D]/C(W."QC:'(H.2D]/C(W."QC:'(H,3`I/3XR-S@L8VAR
M*#$Q*3T^,C<X+&-H<B@Q,BD]/C(W."QC:'(H,3,I/3XR-S@L8VAR*#$T*3T^
M,C<X+&-H<B@Q-2D]/C(W."QC:'(H,38I/3XR-S@L8VAR*#$W*3T^,C<X+&-H
M<B@Q."D]/C(W."QC:'(H,3DI/3XR-S@L8VAR*#(P*3T^,C<X+&-H<B@R,2D]
M/C(W."P*("`@(&-H<B@R,BD]/C(W."QC:'(H,C,I/3XR-S@L8VAR*#(T*3T^
M,C<X+&-H<B@R-2D]/C(W."QC:'(H,C8I/3XR-S@L8VAR*#(W*3T^,C<X+&-H
M<B@R."D]/C(W."QC:'(H,CDI/3XR-S@L8VAR*#,P*3T^,C<X+&-H<B@S,2D]
M/C(W."PG("<]/C(W."PG(2<]/C(W."PG(B<]/C,U-2PG(R<]/C4U-BPG)"<]
M/C4U-BPG)2<]/C@X.2PG)B<]/C8V-RPG7"<G/3XQ.3$L)R@G/3XS,S,L)RDG
M/3XS,S,L)RHG/3XS.#DL)RLG/3XU.#0L"B`@("`G+"<]/C(W."PG+2<]/C,S
M,RPG+B<]/C(W."PG+R<]/C(W."PG,"<]/C4U-BPG,2<]/C4U-BPG,B<]/C4U
M-BPG,R<]/C4U-BPG-"<]/C4U-BPG-2<]/C4U-BPG-B<]/C4U-BPG-R<]/C4U
M-BPG."<]/C4U-BPG.2<]/C4U-BPG.B<]/C(W."PG.R<]/C(W."PG/"<]/C4X
M-"PG/2<]/C4X-"PG/B<]/C4X-"PG/R<]/C4U-BPG0"<]/C$P,34L)T$G/3XV
M-C<L"B`@("`G0B<]/C8V-RPG0R<]/C<R,BPG1"<]/C<R,BPG12<]/C8V-RPG
M1B<]/C8Q,2PG1R<]/C<W."PG2"<]/C<R,BPG22<]/C(W."PG2B<]/C4P,"PG
M2R<]/C8V-RPG3"<]/C4U-BPG32<]/C@S,RPG3B<]/C<R,BPG3R<]/C<W."PG
M4"<]/C8V-RPG42<]/C<W."PG4B<]/C<R,BPG4R<]/C8V-RPG5"<]/C8Q,2PG
M52<]/C<R,BPG5B<]/C8V-RPG5R<]/CDT-"P*("`@("=8)ST^-C8W+"=9)ST^
M-C8W+"=:)ST^-C$Q+"=;)ST^,C<X+"=<7"<]/C(W."PG72<]/C(W."PG7B<]
M/C0V.2PG7R<]/C4U-BPG8"<]/C,S,RPG82<]/C4U-BPG8B<]/C4U-BPG8R<]
M/C4P,"PG9"<]/C4U-BPG92<]/C4U-BPG9B<]/C(W."PG9R<]/C4U-BPG:"<]
M/C4U-BPG:2<]/C(R,BPG:B<]/C(R,BPG:R<]/C4P,"PG;"<]/C(R,BPG;2<]
M/C@S,RP*("`@("=N)ST^-34V+"=O)ST^-34V+"=P)ST^-34V+"=Q)ST^-34V
M+"=R)ST^,S,S+"=S)ST^-3`P+"=T)ST^,C<X+"=U)ST^-34V+"=V)ST^-3`P
M+"=W)ST^-S(R+"=X)ST^-3`P+"=Y)ST^-3`P+"=Z)ST^-3`P+"=[)ST^,S,T
M+"=\)ST^,C8P+"=])ST^,S,T+"=^)ST^-3@T+&-H<B@Q,C<I/3XS-3`L8VAR
M*#$R."D]/C4U-BQC:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XR,C(L8VAR*#$S
M,2D]/C4U-BP*("`@(&-H<B@Q,S(I/3XS,S,L8VAR*#$S,RD]/C$P,#`L8VAR
M*#$S-"D]/C4U-BQC:'(H,3,U*3T^-34V+&-H<B@Q,S8I/3XS,S,L8VAR*#$S
M-RD]/C$P,#`L8VAR*#$S."D]/C8V-RQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I
M/3XQ,#`P+&-H<B@Q-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^
M,S4P+&-H<B@Q-#0I/3XS-3`L8VAR*#$T-2D]/C(R,BQC:'(H,30V*3T^,C(R
M+&-H<B@Q-#<I/3XS,S,L8VAR*#$T."D]/C,S,RQC:'(H,30Y*3T^,S4P+&-H
M<B@Q-3`I/3XU-38L8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H
M,34S*3T^,3`P,"P*("`@(&-H<B@Q-30I/3XU,#`L8VAR*#$U-2D]/C,S,RQC
M:'(H,34V*3T^.30T+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C4P,"QC:'(H
M,34Y*3T^-C8W+&-H<B@Q-C`I/3XR-S@L8VAR*#$V,2D]/C,S,RQC:'(H,38R
M*3T^-34V+&-H<B@Q-C,I/3XU-38L8VAR*#$V-"D]/C4U-BQC:'(H,38U*3T^
M-34V+&-H<B@Q-C8I/3XR-C`L8VAR*#$V-RD]/C4U-BQC:'(H,38X*3T^,S,S
M+&-H<B@Q-CDI/3XW,S<L8VAR*#$W,"D]/C,W,"QC:'(H,3<Q*3T^-34V+&-H
M<B@Q-S(I/3XU.#0L8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S,W+&-H<B@Q
M-S4I/3XS,S,L"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU.#0L8VAR
M*#$W."D]/C,S,RQC:'(H,3<Y*3T^,S,S+&-H<B@Q.#`I/3XS,S,L8VAR*#$X
M,2D]/C4U-BQC:'(H,3@R*3T^-3,W+&-H<B@Q.#,I/3XR-S@L8VAR*#$X-"D]
M/C,S,RQC:'(H,3@U*3T^,S,S+&-H<B@Q.#8I/3XS-C4L8VAR*#$X-RD]/C4U
M-BQC:'(H,3@X*3T^.#,T+&-H<B@Q.#DI/3XX,S0L8VAR*#$Y,"D]/C@S-"QC
M:'(H,3DQ*3T^-C$Q+&-H<B@Q.3(I/3XV-C<L8VAR*#$Y,RD]/C8V-RQC:'(H
M,3DT*3T^-C8W+&-H<B@Q.34I/3XV-C<L8VAR*#$Y-BD]/C8V-RQC:'(H,3DW
M*3T^-C8W+`H@("`@8VAR*#$Y."D]/C$P,#`L8VAR*#$Y.2D]/C<R,BQC:'(H
M,C`P*3T^-C8W+&-H<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S
M*3T^-C8W+&-H<B@R,#0I/3XR-S@L8VAR*#(P-2D]/C(W."QC:'(H,C`V*3T^
M,C<X+&-H<B@R,#<I/3XR-S@L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R
M+&-H<B@R,3`I/3XW-S@L8VAR*#(Q,2D]/C<W."QC:'(H,C$R*3T^-S<X+&-H
M<B@R,3,I/3XW-S@L8VAR*#(Q-"D]/C<W."QC:'(H,C$U*3T^-3@T+&-H<B@R
M,38I/3XW-S@L8VAR*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI
M/3XW,C(L"B`@("!C:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV-C<L8VAR*#(R
M,BD]/C8V-RQC:'(H,C(S*3T^-C$Q+&-H<B@R,C0I/3XU-38L8VAR*#(R-2D]
M/C4U-BQC:'(H,C(V*3T^-34V+&-H<B@R,C<I/3XU-38L8VAR*#(R."D]/C4U
M-BQC:'(H,C(Y*3T^-34V+&-H<B@R,S`I/3XX.#DL8VAR*#(S,2D]/C4P,"QC
M:'(H,C,R*3T^-34V+&-H<B@R,S,I/3XU-38L8VAR*#(S-"D]/C4U-BQC:'(H
M,C,U*3T^-34V+&-H<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X
M*3T^,C<X+&-H<B@R,SDI/3XR-S@L8VAR*#(T,"D]/C4U-BQC:'(H,C0Q*3T^
M-34V+`H@("`@8VAR*#(T,BD]/C4U-BQC:'(H,C0S*3T^-34V+&-H<B@R-#0I
M/3XU-38L8VAR*#(T-2D]/C4U-BQC:'(H,C0V*3T^-34V+&-H<B@R-#<I/3XU
M.#0L8VAR*#(T."D]/C8Q,2QC:'(H,C0Y*3T^-34V+&-H<B@R-3`I/3XU-38L
M8VAR*#(U,2D]/C4U-BQC:'(H,C4R*3T^-34V+&-H<B@R-3,I/3XU,#`L8VAR
M*#(U-"D]/C4U-BQC:'(H,C4U*3T^-3`P*3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]S
M>6UB;VPN<&AP````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8P-S,`
M,3`U,34T,S$P-C``,#(Q-C$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$
M1@H@*B\*)&9O;G1?=VED=&AS6R=S>6UB;VPG72`](&%R<F%Y*`H@("`@8VAR
M*#`I/3XR-3`L8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR*#,I/3XR-3`L
M8VAR*#0I/3XR-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L8VAR*#<I/3XR
M-3`L8VAR*#@I/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^,C4P+&-H<B@Q
M,2D]/C(U,"QC:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H<B@Q-"D]/C(U
M,"QC:'(H,34I/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]/C(U,"QC:'(H
M,3@I/3XR-3`L8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC:'(H,C$I/3XR
M-3`L"B`@("!C:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H<B@R-"D]/C(U
M,"QC:'(H,C4I/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]/C(U,"QC:'(H
M,C@I/3XR-3`L8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC:'(H,S$I/3XR
M-3`L)R`G/3XR-3`L)R$G/3XS,S,L)R(G/3XW,3,L)R,G/3XU,#`L)R0G/3XU
M-#DL)R4G/3XX,S,L)R8G/3XW-S@L)UPG)ST^-#,Y+"<H)ST^,S,S+"<I)ST^
M,S,S+"<J)ST^-3`P+"<K)ST^-30Y+`H@("`@)RPG/3XR-3`L)RTG/3XU-#DL
M)RXG/3XR-3`L)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L)S(G/3XU,#`L
M)S,G/3XU,#`L)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L)S<G/3XU,#`L
M)S@G/3XU,#`L)SDG/3XU,#`L)SHG/3XR-S@L)SLG/3XR-S@L)SPG/3XU-#DL
M)STG/3XU-#DL)SXG/3XU-#DL)S\G/3XT-#0L)T`G/3XU-#DL)T$G/3XW,C(L
M"B`@("`G0B<]/C8V-RPG0R<]/C<R,BPG1"<]/C8Q,BPG12<]/C8Q,2PG1B<]
M/C<V,RPG1R<]/C8P,RPG2"<]/C<R,BPG22<]/C,S,RPG2B<]/C8S,2PG2R<]
M/C<R,BPG3"<]/C8X-BPG32<]/C@X.2PG3B<]/C<R,BPG3R<]/C<R,BPG4"<]
M/C<V."PG42<]/C<T,2PG4B<]/C4U-BPG4R<]/C4Y,BPG5"<]/C8Q,2PG52<]
M/C8Y,"PG5B<]/C0S.2PG5R<]/C<V."P*("`@("=8)ST^-C0U+"=9)ST^-SDU
M+"=:)ST^-C$Q+"=;)ST^,S,S+"=<7"<]/C@V,RPG72<]/C,S,RPG7B<]/C8U
M."PG7R<]/C4P,"PG8"<]/C4P,"PG82<]/C8S,2PG8B<]/C4T.2PG8R<]/C4T
M.2PG9"<]/C0Y-"PG92<]/C0S.2PG9B<]/C4R,2PG9R<]/C0Q,2PG:"<]/C8P
M,RPG:2<]/C,R.2PG:B<]/C8P,RPG:R<]/C4T.2PG;"<]/C4T.2PG;2<]/C4W
M-BP*("`@("=N)ST^-3(Q+"=O)ST^-30Y+"=P)ST^-30Y+"=Q)ST^-3(Q+"=R
M)ST^-30Y+"=S)ST^-C`S+"=T)ST^-#,Y+"=U)ST^-3<V+"=V)ST^-S$S+"=W
M)ST^-C@V+"=X)ST^-#DS+"=Y)ST^-C@V+"=Z)ST^-#DT+"=[)ST^-#@P+"=\
M)ST^,C`P+"=])ST^-#@P+"=^)ST^-30Y+&-H<B@Q,C<I/3XP+&-H<B@Q,C@I
M/3XP+&-H<B@Q,CDI/3XP+&-H<B@Q,S`I/3XP+&-H<B@Q,S$I/3XP+`H@("`@
M8VAR*#$S,BD]/C`L8VAR*#$S,RD]/C`L8VAR*#$S-"D]/C`L8VAR*#$S-2D]
M/C`L8VAR*#$S-BD]/C`L8VAR*#$S-RD]/C`L8VAR*#$S."D]/C`L8VAR*#$S
M.2D]/C`L8VAR*#$T,"D]/C`L8VAR*#$T,2D]/C`L8VAR*#$T,BD]/C`L8VAR
M*#$T,RD]/C`L8VAR*#$T-"D]/C`L8VAR*#$T-2D]/C`L8VAR*#$T-BD]/C`L
M8VAR*#$T-RD]/C`L8VAR*#$T."D]/C`L8VAR*#$T.2D]/C`L8VAR*#$U,"D]
M/C`L8VAR*#$U,2D]/C`L8VAR*#$U,BD]/C`L8VAR*#$U,RD]/C`L"B`@("!C
M:'(H,34T*3T^,"QC:'(H,34U*3T^,"QC:'(H,34V*3T^,"QC:'(H,34W*3T^
M,"QC:'(H,34X*3T^,"QC:'(H,34Y*3T^,"QC:'(H,38P*3T^-S4P+&-H<B@Q
M-C$I/3XV,C`L8VAR*#$V,BD]/C(T-RQC:'(H,38S*3T^-30Y+&-H<B@Q-C0I
M/3XQ-C<L8VAR*#$V-2D]/C<Q,RQC:'(H,38V*3T^-3`P+&-H<B@Q-C<I/3XW
M-3,L8VAR*#$V."D]/C<U,RQC:'(H,38Y*3T^-S4S+&-H<B@Q-S`I/3XW-3,L
M8VAR*#$W,2D]/C$P-#(L8VAR*#$W,BD]/CDX-RQC:'(H,3<S*3T^-C`S+&-H
M<B@Q-S0I/3XY.#<L8VAR*#$W-2D]/C8P,RP*("`@(&-H<B@Q-S8I/3XT,#`L
M8VAR*#$W-RD]/C4T.2QC:'(H,3<X*3T^-#$Q+&-H<B@Q-SDI/3XU-#DL8VAR
M*#$X,"D]/C4T.2QC:'(H,3@Q*3T^-S$S+&-H<B@Q.#(I/3XT.30L8VAR*#$X
M,RD]/C0V,"QC:'(H,3@T*3T^-30Y+&-H<B@Q.#4I/3XU-#DL8VAR*#$X-BD]
M/C4T.2QC:'(H,3@W*3T^-30Y+&-H<B@Q.#@I/3XQ,#`P+&-H<B@Q.#DI/3XV
M,#,L8VAR*#$Y,"D]/C$P,#`L8VAR*#$Y,2D]/C8U."QC:'(H,3DR*3T^.#(S
M+&-H<B@Q.3,I/3XV.#8L8VAR*#$Y-"D]/C<Y-2QC:'(H,3DU*3T^.3@W+&-H
M<B@Q.38I/3XW-C@L8VAR*#$Y-RD]/C<V."P*("`@(&-H<B@Q.3@I/3XX,C,L
M8VAR*#$Y.2D]/C<V."QC:'(H,C`P*3T^-S8X+&-H<B@R,#$I/3XW,3,L8VAR
M*#(P,BD]/C<Q,RQC:'(H,C`S*3T^-S$S+&-H<B@R,#0I/3XW,3,L8VAR*#(P
M-2D]/C<Q,RQC:'(H,C`V*3T^-S$S+&-H<B@R,#<I/3XW,3,L8VAR*#(P."D]
M/C<V."QC:'(H,C`Y*3T^-S$S+&-H<B@R,3`I/3XW.3`L8VAR*#(Q,2D]/C<Y
M,"QC:'(H,C$R*3T^.#DP+&-H<B@R,3,I/3XX,C,L8VAR*#(Q-"D]/C4T.2QC
M:'(H,C$U*3T^,C4P+&-H<B@R,38I/3XW,3,L8VAR*#(Q-RD]/C8P,RQC:'(H
M,C$X*3T^-C`S+&-H<B@R,3DI/3XQ,#0R+`H@("`@8VAR*#(R,"D]/CDX-RQC
M:'(H,C(Q*3T^-C`S+&-H<B@R,C(I/3XY.#<L8VAR*#(R,RD]/C8P,RQC:'(H
M,C(T*3T^-#DT+&-H<B@R,C4I/3XS,CDL8VAR*#(R-BD]/C<Y,"QC:'(H,C(W
M*3T^-SDP+&-H<B@R,C@I/3XW.#8L8VAR*#(R.2D]/C<Q,RQC:'(H,C,P*3T^
M,S@T+&-H<B@R,S$I/3XS.#0L8VAR*#(S,BD]/C,X-"QC:'(H,C,S*3T^,S@T
M+&-H<B@R,S0I/3XS.#0L8VAR*#(S-2D]/C,X-"QC:'(H,C,V*3T^-#DT+&-H
M<B@R,S<I/3XT.30L8VAR*#(S."D]/C0Y-"QC:'(H,C,Y*3T^-#DT+&-H<B@R
M-#`I/3XP+&-H<B@R-#$I/3XS,CDL"B`@("!C:'(H,C0R*3T^,C<T+&-H<B@R
M-#,I/3XV.#8L8VAR*#(T-"D]/C8X-BQC:'(H,C0U*3T^-C@V+&-H<B@R-#8I
M/3XS.#0L8VAR*#(T-RD]/C,X-"QC:'(H,C0X*3T^,S@T+&-H<B@R-#DI/3XS
M.#0L8VAR*#(U,"D]/C,X-"QC:'(H,C4Q*3T^,S@T+&-H<B@R-3(I/3XT.30L
M8VAR*#(U,RD]/C0Y-"QC:'(H,C4T*3T^-#DT+&-H<B@R-34I/3XP*3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8N<&AP````
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,C<R,#(W
M`#$P-3$U-#,Q,#8P`#`Q-S$V-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@1FEL95]01$8Z.@H@*@H@
M*B!4:&4@1FEL95]01$8Z.B!C;&%S<R!P<F]V:61E<R!A(%!(4"UO;FQY(&EM
M<&QE;65N=&%T:6]N(&]F(&$@4$1&(&QI8G)A<GDN"B`J($YO(&5X=&5R;F%L
M(&QI8G,@;W(@4$A0(&5X=&5N<VEO;G,@87)E(')E<75I<F5D+@H@*@H@*B!"
M87-E9"!O;B!T:&4@1E!$1B!C;&%S<R!B>2!/;&EV:65R(%!L871H97D@*&AT
M='`Z+R]W=W<N9G!D9BYO<F<I+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($]L:79I97(@4&QA=&AE>2`\;VQI=FEE<D!F<&1F+F]R9SX*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1FEL95]01$8O
M4$1&+G!H<"QV(#$N,3@N,3`N,3(@,C`P-B\P,2\P,2`R,3HR.#HQ-2!J86X@
M17AP("0*("H*("H@0&%U=&AO<B`@3VQI=FEE<B!0;&%T:&5Y(#QO;&EV:65R
M0&9P9&8N;W)G/@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*8VQA<W,@1FEL95]0
M1$8@>PH*("`@("\J*@H@("`@("H@0W5R<F5N="!P86=E(&YU;6)E<BX*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<&%G
M92`](#`["@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&]B:F5C="!N=6UB97(N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7VX@/2`R.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@;V)J96-T(&]F9G-E
M=',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]O9F9S971S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($)U9F9E<B!H
M;VQD:6YG(&EN+6UE;6]R>2!01$8N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?8G5F9F5R(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!!<G)A>2!C;VYT86EN:6YG('1H92!P86=E<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A9V5S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@9&]C=6UE;G0@<W1A=&4N"B`@
M("`@*B`@(#`@+2!I;FET:6%L('-T871E"B`@("`@*B`@(#$@+2!D;V-U;65N
M="!O<&5N960*("`@("`J("`@,B`M('!A9V4@;W!E;F5D"B`@("`@*B`@(#,@
M+2!D;V-U;65N="!C;&]S960*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1?<W1A=&4@/2`P.PH*("`@("\J*@H@("`@("H@
M1FQA9R!I;F1I8V%T:6YG(&EF(%!$1B!F:6QE(&ES('1O(&)E(&-O;7!R97-S
M960@;W(@;F]T+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]C;VUP<F5S<SL*"B`@("`O*BH*("`@("`J(%1H92!D969A
M=6QT('!A9V4@;W)I96YT871I;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?9&5F875L=%]O<FEE;G1A=&EO;CL*"B`@
M("`O*BH*("`@("`J(%1H92!C=7)R96YT('!A9V4@;W)I96YT871I;VXN"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W5R
M<F5N=%]O<FEE;G1A=&EO;CL*"B`@("`O*BH*("`@("`J($%R<F%Y(&EN9&EC
M871I;F<@;W)I96YT871I;VX@8VAA;F=E<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]R:65N=&%T:6]N7V-H86YG97,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!W:61T:"!O9B!P
M86=E(&9O<FUA="!I;B!P;VEN=',N"B`@("`@*@H@("`@("H@0'9A<B!F;&]A
M=`H@("`@("HO"B`@("!V87(@)&9W4'0["@H@("`@+RHJ"B`@("`@*B!#=7)R
M96YT(&AE:6=H="!O9B!P86=E(&9O<FUA="!I;B!P;VEN=',N"B`@("`@*@H@
M("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)&9H4'0["@H@("`@
M+RHJ"B`@("`@*B!#=7)R96YT('=I9'1H(&]F('!A9V4@9F]R;6%T(&EN('5S
M97(@=6YI=',N"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@
M("!V87(@)&9W.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!H96EG:'0@;V8@
M<&%G92!F;W)M870@:6X@=7-E<B!U;FET<RX*("`@("`J"B`@("`@*B!`=F%R
M(&9L;V%T"B`@("`@*B\*("`@('9A<B`D9F@["@H@("`@+RHJ"B`@("`@*B!#
M=7)R96YT('=I9'1H(&]F('!A9V4@:6X@<&]I;G1S+@H@("`@("H*("`@("`J
M($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1W4'0["@H@("`@+RHJ"B`@
M("`@*B!#=7)R96YT(&AE:6=H="!O9B!P86=E(&EN('!O:6YT<RX*("`@("`J
M"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D:%!T.PH*("`@
M("\J*@H@("`@("H@0W5R<F5N="!W:61T:"!O9B!P86=E(&EN('5S97(@=6YI
M=',*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D
M=SL*"B`@("`O*BH*("`@("`J($-U<G)E;G0@:&5I9VAT(&]F('!A9V4@:6X@
M=7-E<B!U;FET<PH@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@
M("`@=F%R("1H.PH*("`@("\J*@H@("`@("H@4V-A;&4@9F%C=&]R("AN=6UB
M97(@;V8@<&]I;G1S(&EN('5S97(@=6YI=',I+@H@("`@("H*("`@("`J($!V
M87(@9FQO870*("`@("`J+PH@("`@=F%R("1?<V-A;&4["@H@("`@+RHJ"B`@
M("`@*B!,969T('!A9V4@;6%R9VEN('-I>F4N"B`@("`@*@H@("`@("H@0'9A
M<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]L969T7VUA<F=I;CL*"B`@("`O
M*BH*("`@("`J(%1O<"!P86=E(&UA<F=I;B!S:7IE+@H@("`@("H*("`@("`J
M($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?=&]P7VUA<F=I;CL*"B`@
M("`O*BH*("`@("`J(%)I9VAT('!A9V4@;6%R9VEN('-I>F4N"B`@("`@*@H@
M("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]R:6=H=%]M87)G
M:6X["@H@("`@+RHJ"B`@("`@*B!"<F5A:R!P86=E(&UA<F=I;B!S:7IE+"!T
M:&4@8F]T=&]M(&UA<F=I;B!W:&EC:"!T<FEG9V5R<R!A('!A9V4@8G)E86LN
M"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]B
M<F5A:U]M87)G:6X["@H@("`@+RHJ"B`@("`@*B!#96QL(&UA<F=I;B!S:7IE
M+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?
M8V5L;%]M87)G:6X["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!H;W)I
M>F]N=&%L('!O<VET:6]N(&9O<B!C96QL('!O<VET:6]N:6YG+@H@("`@("H@
M5F%L=64@:7,@<V5T(&EN('5S97(@=6YI=',@86YD(&ES(&-A;&-U;&%T960@
M9G)O;2!T:&4@=&]P(&QE9G0@8V]R;F5R"B`@("`@*B!A<R!O<FEG:6XN"B`@
M("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)'@["@H@
M("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!V97)T:6-A;"!P;W-I=&EO;B!F
M;W(@8V5L;"!P;W-I=&EO;FEN9RX*("`@("`J(%9A;'5E(&ES('-E="!I;B!U
M<V5R('5N:71S(&%N9"!I<R!C86QC=6QA=&5D(&9R;VT@=&AE('1O<"!L969T
M(&-O<FYE<@H@("`@("H@87,@;W)I9VEN+@H@("`@("H*("`@("`J($!V87(@
M9FQO870*("`@("`J+PH@("`@=F%R("1Y.PH*("`@("\J*@H@("`@("H@5&AE
M(&AE:6=H="!O9B!T:&4@;&%S="!C96QL('!R:6YT960N"B`@("`@*@H@("`@
M("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]L87-T7VAE:6=H=#L*
M"B`@("`O*BH*("`@("`J($QI;F4@=VED=&@@:6X@=7-E<B!U;FET<RX*("`@
M("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7VQI;F5?
M=VED=&@["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!S=&%N9&%R9"!F
M;VYT(&YA;65S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?8V]R95]F;VYT<R`](&%R<F%Y*"=C;W5R:65R)R`@("`@(#T^
M("=#;W5R:65R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]U
M<FEE<D(G("`@("`]/B`G0V]U<FEE<BU";VQD)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8V]U<FEE<DDG("`@("`]/B`G0V]U<FEE<BU/8FQI
M<75E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]U<FEE<D))
M)R`@("`]/B`G0V]U<FEE<BU";VQD3V)L:7%U92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAE;'9E=&EC82<@("`@/3X@)TAE;'9E=&EC82<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE;'9E=&EC84(G("`@
M/3X@)TAE;'9E=&EC82U";VQD)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&5L=F5T:6-A22<@("`]/B`G2&5L=F5T:6-A+4]B;&EQ=64G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H96QV971I8V%"22<@(#T^
M("=(96QV971I8V$M0F]L9$]B;&EQ=64G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T:6UE<R<@("`@("`@(#T^("=4:6UE<RU2;VUA;B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1I;65S0B<@("`@("`@/3X@
M)U1I;65S+4)O;&0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M:6UE<TDG("`@("`@(#T^("=4:6UE<RU)=&%L:6,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=T:6UE<T)))R`@("`@(#T^("=4:6UE<RU";VQD
M271A;&EC)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<WEM8F]L
M)R`@("`@("`]/B`G4WEM8F]L)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G>F%P9F1I;F=B871S)R`]/B`G6F%P9D1I;F=B871S)RD["@H@("`@
M+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!U<V5D(&9O;G1S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9F]N=',@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@9F]N="!F:6QE<RX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V9O
M;G1?9FEL97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06X@87)R87D@
M;V8@96YC;V1I;F<@9&EF9F5R96YC97,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]D:69F<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!U<V5D(&EM86=E<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VEM86=E<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!L:6YK<R!I;B!P
M86=E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W!A9V5?;&EN:W,["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!I
M;G1E<FYA;"!L:6YK<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7VQI;FMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-U<G)E;G0@9F]N="!F86UI;'DN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?9F]N=%]F86UI;'D@/2`G)SL*"B`@("`O
M*BH*("`@("`J($-U<G)E;G0@9F]N="!S='EL92X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]F;VYT7W-T>6QE(#T@)R<[
M"@H@("`@+RHJ"B`@("`@*B!5;F1E<FQI;FEN9R!F;&%G+@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]U;F1E<FQI;F4@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&-O;G1A:6YI;F<@
M8W5R<F5N="!F;VYT(&EN9F\N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]C=7)R96YT7V9O;G0["@H@("`@+RHJ"B`@("`@
M*B!#=7)R96YT(&9O;G0@<VEZ92!I;B!P;VEN=',N"B`@("`@*@H@("`@("H@
M0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]F;VYT7W-I>F5?<'0@/2`Q
M,CL*"B`@("`O*BH*("`@("`J($-U<G)E;G0@9F]N="!S:7IE(&EN('5S97(@
M=6YI=',N"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V
M87(@)%]F;VYT7W-I>F4["@H@("`@+RHJ"B`@("`@*B!#;VUM86YD<R!F;W(@
M9FEL;&EN9R!C;VQO<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]F:6QL7V-O;&]R(#T@)S`@9R<["@H@("`@+RHJ"B`@
M("`@*B!#;VUM86YD<R!F;W(@9')A=VEN9R!C;VQO<BX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D<F%W7V-O;&]R(#T@
M)S`@1R<["@H@("`@+RHJ"B`@("`@*B!7;W)D('-P86-I;F<N"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W=O<F1?<W!A
M8VEN9R`](#`["@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6,@<&%G92!B<F5A
M:VEN9RX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?875T;U]P86=E7V)R96%K.PH*("`@("\J*@H@("`@("H@5&AR97-H
M;VQD('5S960@=&\@=')I9V=E<B!P86=E(&)R96%K<RX*("`@("`J"B`@("`@
M*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7W!A9V5?8G)E86M?=')I
M9V=E<CL*"B`@("`O*BH*("`@("`J($9L86<@<V5T('=H96X@<')O8V5S<VEN
M9R!F;V]T97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7VEN7V9O;W1E<B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M6F]O;2!D:7-P;&%Y(&UO9&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?>F]O;5]M;V1E.PH*("`@("\J*@H@("`@("H@
M3&%Y;W5T(&1I<W!L87D@;6]D92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]L87EO=71?;6]D93L*"B`@("`O*BH*("`@
M("`J($%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&1O8W5M96YT(&EN9F\L(&-O
M;G-I<W1I;F<@;V8Z"B`@("`@*B`@("T@=&ET;&4*("`@("`J("`@+2!S=6)J
M96-T"B`@("`@*B`@("T@875T:&]R"B`@("`@*B`@("T@:V5Y=V]R9',*("`@
M("`J("`@+2!C<F5A=&]R"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]I;F9O(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($%L:6%S(&9O<B!T;W1A;"!N=6UB97(@;V8@<&%G97,N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?86QI87-?;F)?<&%G
M97,@/2`G>VYB?2<["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U
M<FX@82!C;VYR971E(%!$1B!I;G-T86YC92X@270@86QL;W=S('1O('-E="!U
M<"!T:&4@<&%G90H@("`@("H@9F]R;6%T+"!T:&4@;W)I96YT871I;VX@86YD
M('1H92!U;FET<R!O9B!M96%S=7)E;65N="!U<V5D(&EN(&%L;"!T:&4*("`@
M("`J(&UE=&AO9',@*&5X8V5P="!F;W(@=&AE(&9O;G0@<VEZ97,I+@H@("`@
M("H*("`@("`J($5X86UP;&4Z/'!R93X*("`@("`J("1P9&8@/2`F1FEL95]0
M1$8Z.F9A8W1O<GDH87)R87DH)V]R:65N=&%T:6]N)R`]/B`G4"<L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U;FET)R`]/B`G
M;6TG+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9F]R;6%T)R`]/B`G030G*2D[/"]P<F4^"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!W:71H('!A<F%M971E<G,@9F]R('1H
M92!C<F5A=&5D(%!$1B!O8FIE8W0N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@4&]S<VEB;&4@<&%R86UE=&5R<R!A<F4Z"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@;W)I96YT871I;VX@+2!$969A=6QT('!A9V4@;W)I
M96YT871I;VXN(%!O<W-I8FQE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@=F%L=65S(&%R92`H8V%S92!I;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@/'!R93X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("T@4"!O<B!0;W)T<F%I="`H9&5F875L="D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@3"!O<B!,86YD<V-A<&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`\+W!R93X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!U;FET("T@57-E<B!M96%S=7)E('5N:71S+B!0;W-S
M:6)L92!V86QU97,@=F%L=65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@87)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(#QP<F4^"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M('!T.B!P;VEN=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!M;3H@;6EL;&EM971E<B`H
M9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@8VTZ
M(&-E;G1I;65T97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@
M:6XZ(&EN8V@*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`\+W!R93X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!!('!O:6YT(&5Q=6%L<R`Q
M+S<R(&]F(&EN8V@L('1H870@:7,@=&\@<V%Y(&%B;W5T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@,"XS-2!M;2`H86X@:6YC:"!B96EN9R`R+C4T
M(&-M*2X@5&AI<R!I<R!A('9E<GD*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!C;VUM;VX@=6YI="!I;B!T>7!O9W)A<&AY.R!F;VYT('-I>F5S(&%R
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5X<')E<W-E9"!I;B!T
M:&%T('5N:70N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9F]R;6%T
M("T@5&AE(&9O<FUA="!U<V5D(&9O<B!P86=E<RX@270@8V%N(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@96ET:&5R(&]N92!O9B!T:&4@9F]L
M;&]W:6YG('9A;'5E<R`H8V%S90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&EN<V5N<VET:79E*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`\<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!!,PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!!-"`H9&5F875L="D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@034*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@3&5T=&5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M($QE9V%L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@/"]P<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M;W(@82!C=7-T;VT@9F]R;6%T(&EN('1H92!F;W)M(&]F(&$@='=O+65L96UE
M;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2!C;VYT86EN
M:6YG('1H92!W:61T:"!A;F0@=&AE(&AE:6=H=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("AE>'!R97-S960@:6X@=&AE('5N:70@9VEV96X@8GD@
M=&AE('5N:70*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T
M97(I+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@(%1H92!C;VYC<F5T
M92!C;&%S<R!N86UE('1O(')E='5R;B!A;B!I;G-T86YC92!O9BX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!&:6QE7U!$1BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)'!A<F%M<R`](&%R<F%Y
M*"DL("1C;&%S<R`]("=&:6QE7U!$1B<I"B`@("!["B`@("`@("`@+RH@0VAE
M8VL@9F]R(%!(4"!L;V-A;&4M<F5L871E9"!B=6<N("HO"B`@("`@("`@:68@
M*#$N,2`]/2`Q*2!["B`@("`@("`@("`@(')E='5R;B!&:6QE7U!$1CHZ<F%I
M<V5%<G)O<B@G1&\@;F]T(&%L=&5R('1H92!L;V-A;&4@8F5F;W)E(&EN8VQU
M9&EN9R!T:&4@8VQA<W,@9FEL92XG*3L*("`@("`@("!]"@H@("`@("`@("\J
M($1E9F%U;'0@<&%R86UE=&5R<RX@*B\*("`@("`@("`D9&5F875L=',@/2!A
M<G)A>2@G;W)I96YT871I;VXG(#T^("=0)RP@)W5N:70G(#T^("=M;2<L("=F
M;W)M870G(#T^("=!-"<I.PH*("`@("`@("`O*B!"86-K=V%R9"!C;VUP871I
M8FEL:71Y('=I=&@@;VQD(&UE=&AO9"!S:6=N871U<F4N("HO"B`@("`@("`@
M+RH@4VAO=6QD(&)E(')E;6]V960@82!F97<@=F5R<VEO;G,@;&%T97(N("HO
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@
M("`D8VQA<W,@/2`G1FEL95]01$8G.PH@("`@("`@("`@("`D<&%R86US(#T@
M)&1E9F%U;'1S.PH@("`@("`@("`@("`D;F%M97,@/2!A<G)A>5]K97ES*"1D
M969A=6QT<RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&9U;F-?
M;G5M7V%R9W,H*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULD
M;F%M97-;)&E=72`](&9U;F-?9V5T7V%R9R@D:2D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R86US(#T@87)R87E?
M;65R9V4H)&1E9F%U;'1S+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@
M("\J($-R96%T92!T:&4@4$1&(&]B:F5C="X@*B\*("`@("`@("`D<&1F(#T@
M)FYE=R`D8VQA<W,H*3L*"B`@("`@("`@+RH@4V-A;&4@9F%C=&]R+B`J+PH@
M("`@("`@(&EF("@D<&%R86US6R=U;FET)UT@/3T@)W!T)RD@>PH@("`@("`@
M("`@("`D<&1F+3Y?<V-A;&4@/2`Q.PH@("`@("`@('T@96QS96EF("@D<&%R
M86US6R=U;FET)UT@/3T@)VUM)RD@>PH@("`@("`@("`@("`D<&1F+3Y?<V-A
M;&4@/2`W,B`O(#(U+C0["B`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)W5N
M:70G72`]/2`G8VTG*2!["B`@("`@("`@("`@("1P9&8M/E]S8V%L92`](#<R
M("\@,BXU-#L*("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG=6YI="==(#T]
M("=I;B<I('L*("`@("`@("`@("`@)'!D9BT^7W-C86QE(#T@-S(["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N($9I;&5?4$1&.CIR86ES
M945R<F]R*'-P<FEN=&8H)TEN8V]R<F5C="!U;FET<SH@)7,G+"`D<&%R86US
M6R=U;FET)UTI*3L*("`@("`@("!]"B`@("`@("`@+RH@4&%G92!F;W)M870N
M("HO"B`@("`@("`@:68@*&ES7W-T<FEN9R@D<&%R86US6R=F;W)M870G72DI
M('L*("`@("`@("`@("`@)'!A<F%M<ULG9F]R;6%T)UT@/2!S=')T;VQO=V5R
M*"1P87)A;7-;)V9O<FUA="==*3L*("`@("`@("`@("`@:68@*"1P87)A;7-;
M)V9O<FUA="==(#T]("=A,R<I('L*("`@("`@("`@("`@("`@("1P87)A;7-;
M)V9O<FUA="==(#T@87)R87DH.#0Q+C@Y+"`Q,3DP+C4U*3L*("`@("`@("`@
M("`@?2!E;'-E:68@*"1P87)A;7-;)V9O<FUA="==(#T]("=A-"<I('L*("`@
M("`@("`@("`@("`@("1P87)A;7-;)V9O<FUA="==(#T@87)R87DH-3DU+C(X
M+"`X-#$N.#DI.PH@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG9F]R
M;6%T)UT@/3T@)V$U)RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULG9F]R
M;6%T)UT@/2!A<G)A>2@T,C`N.30L(#4Y-2XR."D["B`@("`@("`@("`@('T@
M96QS96EF("@D<&%R86US6R=F;W)M870G72`]/2`G;&5T=&5R)RD@>PH@("`@
M("`@("`@("`@("`@)'!A<F%M<ULG9F]R;6%T)UT@/2!A<G)A>2@V,3(L(#<Y
M,BD["B`@("`@("`@("`@('T@96QS96EF("@D<&%R86US6R=F;W)M870G72`]
M/2`G;&5G86PG*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R=F;W)M870G
M72`](&%R<F%Y*#8Q,BP@,3`P."D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@1FEL95]01$8Z.G)A:7-E17)R;W(H<W!R
M:6YT9B@G56YK;F]W;B!P86=E(&9O<FUA=#H@)7,G+"`D<&%R86US6R=F;W)M
M870G72DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P9&8M/F9W4'0@
M/2`D<&%R86US6R=F;W)M870G75LP73L*("`@("`@("`@("`@)'!D9BT^9FA0
M="`]("1P87)A;7-;)V9O<FUA="==6S%=.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1P9&8M/F9W4'0@/2`D<&%R86US6R=F;W)M870G75LP72`J
M("1P9&8M/E]S8V%L93L*("`@("`@("`@("`@)'!D9BT^9FA0="`]("1P87)A
M;7-;)V9O<FUA="==6S%=("H@)'!D9BT^7W-C86QE.PH@("`@("`@('T*("`@
M("`@("`D<&1F+3YF=R`]("1P9&8M/F9W4'0@+R`D<&1F+3Y?<V-A;&4["B`@
M("`@("`@)'!D9BT^9F@@/2`D<&1F+3YF:%!T("\@)'!D9BT^7W-C86QE.PH*
M("`@("`@("`O*B!086=E(&]R:65N=&%T:6]N+B`J+PH@("`@("`@("1P87)A
M;7-;)V]R:65N=&%T:6]N)UT@/2!S=')T;VQO=V5R*"1P87)A;7-;)V]R:65N
M=&%T:6]N)UTI.PH@("`@("`@(&EF("@D<&%R86US6R=O<FEE;G1A=&EO;B==
M(#T]("=P)R!\?"`D<&%R86US6R=O<FEE;G1A=&EO;B==(#T]("=P;W)T<F%I
M="<I('L*("`@("`@("`@("`@)'!D9BT^7V1E9F%U;'1?;W)I96YT871I;VX@
M/2`G4"<["B`@("`@("`@("`@("1P9&8M/G=0="`]("1P9&8M/F9W4'0["B`@
M("`@("`@("`@("1P9&8M/FA0="`]("1P9&8M/F9H4'0["B`@("`@("`@?2!E
M;'-E:68@*"1P87)A;7-;)V]R:65N=&%T:6]N)UT@/3T@)VPG('Q\("1P87)A
M;7-;)V]R:65N=&%T:6]N)UT@/3T@)VQA;F1S8V%P92<I('L*("`@("`@("`@
M("`@)'!D9BT^7V1E9F%U;'1?;W)I96YT871I;VX@/2`G3"<["B`@("`@("`@
M("`@("1P9&8M/G=0="`]("1P9&8M/F9H4'0["B`@("`@("`@("`@("1P9&8M
M/FA0="`]("1P9&8M/F9W4'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N($9I;&5?4$1&.CIR86ES945R<F]R*'-P<FEN=&8H)TEN8V]R
M<F5C="!O<FEE;G1A=&EO;CH@)7,G+"`D<&%R86US6R=O<FEE;G1A=&EO;B==
M*2D["B`@("`@("`@?0H@("`@("`@("1P9&8M/E]C=7)R96YT7V]R:65N=&%T
M:6]N(#T@)'!D9BT^7V1E9F%U;'1?;W)I96YT871I;VX["B`@("`@("`@)'!D
M9BT^=R`]("1P9&8M/G=0="`O("1P9&8M/E]S8V%L93L*("`@("`@("`D<&1F
M+3YH(#T@)'!D9BT^:%!T("\@)'!D9BT^7W-C86QE.PH*("`@("`@("`O*B!0
M86=E(&UA<F=I;G,@*#$@8VTI("HO"B`@("`@("`@)&UA<F=I;B`](#(X+C,U
M("\@)'!D9BT^7W-C86QE.PH@("`@("`@("1P9&8M/G-E=$UA<F=I;G,H)&UA
M<F=I;BP@)&UA<F=I;BD["@H@("`@("`@("\J($EN=&5R:6]R(&-E;&P@;6%R
M9VEN("@Q(&UM*2`J+PH@("`@("`@("1P9&8M/E]C96QL7VUA<F=I;B`]("1M
M87)G:6X@+R`Q,#L*"B`@("`@("`@+RH@3&EN92!W:61T:"`H,"XR(&UM*2`J
M+PH@("`@("`@("1P9&8M/E]L:6YE7W=I9'1H(#T@+C4V-R`O("1P9&8M/E]S
M8V%L93L*"B`@("`@("`@+RH@075T;VUA=&EC('!A9V4@8G)E86L@*B\*("`@
M("`@("`D<&1F+3YS971!=71O4&%G94)R96%K*'1R=64L(#(@*B`D;6%R9VEN
M*3L*"B`@("`@("`@+RH@1G5L;"!W:61T:"!D:7-P;&%Y(&UO9&4@*B\*("`@
M("`@("`D<&1F+3YS971$:7-P;&%Y36]D92@G9G5L;'=I9'1H)RD["@H@("`@
M("`@("\J($-O;7!R97-S:6]N("HO"B`@("`@("`@)'!D9BT^<V5T0V]M<')E
M<W-I;VXH=')U92D["@H@("`@("`@(')E='5R;B`D<&1F.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(%!%05)?17)R;W(@;V)J96-T+B!7<F%P
M<R!A<F]U;F0@4$5!4CHZ<F%I<V5%<G)O<B@I('1O"B`@("`@*B!A=F]I9"!H
M879I;F<@=&\@:6YC;'5D92!014%2+G!H<"!U;FQE<W,@86X@97)R;W(@;V-C
M=7)S+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D97)R;W(@(%1H92!E
M<G)O<B!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T(%!%
M05)?17)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D97)R
M;W(I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(&QE9G0L('1O<"!A;F0@<FEG
M:'0@;6%R9VEN<RX@0GD@9&5F875L="P@=&AE>2!E<75A;`H@("`@("H@,2!C
M;2X@($-A;&P@=&AI<R!M971H;V0@=&\@8VAA;F=E('1H96TN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&9L;V%T("1L969T("`@3&5F="!M87)G:6XN"B`@("`@
M*B!`<&%R86T@9FQO870@)'1O<"`@("!4;W`@;6%R9VEN+@H@("`@("H@0'!A
M<F%M(&9L;V%T("1R:6=H="`@4FEG:'0@;6%R9VEN+B!)9B!N;W0@<W!E8VEF
M:65D(&1E9F%U;'0@=&\@=&AE('9A;'5E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!O9B!T:&4@;&5F="!O;F4N"B`@("`@*@H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ<V5T075T;U!A9V5"<F5A:PH@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T3&5F=$UA<F=I;@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T4FEG
M:'1-87)G:6X*("`@("`J($!S964@1FEL95]01$8Z.G-E=%1O<$UA<F=I;@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971-87)G:6YS*"1L969T+"`D=&]P+"`D
M<FEG:'0@/2!N=6QL*0H@("`@>PH@("`@("`@("\J(%-E="!L969T(&%N9"!T
M;W`@;6%R9VEN<RX@*B\*("`@("`@("`D=&AI<RT^7VQE9G1?;6%R9VEN("`]
M("1L969T.PH@("`@("`@("1T:&ES+3Y?=&]P7VUA<F=I;B`@(#T@)'1O<#L*
M("`@("`@("`O*B!)9B!N;R!R:6=H="!M87)G:6X@<V5T(&1E9F%U;'0@=&\@
M<V%M92!A<R!L969T+B`J+PH@("`@("`@("1T:&ES+3Y?<FEG:'1?;6%R9VEN
M(#T@*&ES7VYU;&PH)')I9VAT*2`_("1L969T(#H@)')I9VAT*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(&QE9G0@;6%R9VEN+B!4:&4@
M;65T:&]D(&-A;B!B92!C86QL960@8F5F;W)E(&-R96%T:6YG('1H90H@("`@
M("H@9FER<W0@<&%G92X*("`@("`J($EF('1H92!C=7)R96YT(&%B<V-I<W-A
M(&=E=',@;W5T(&]F('!A9V4L(&ET(&ES(&)R;W5G:'0@8F%C:R!T;R!T:&4*
M("`@("`J(&UA<F=I;BX*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)&UA
M<F=I;B`@(%1H92!M87)G:6XN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T075T;U!A9V5"<F5A:PH@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T
M36%R9VEN<PH@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T4FEG:'1-87)G:6X*
M("`@("`J($!S964@1FEL95]01$8Z.G-E=%1O<$UA<F=I;@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971,969T36%R9VEN*"1M87)G:6XI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]L969T7VUA<F=I;B`]("1M87)G:6X["B`@("`@("`@+RH@
M268@=&AE<F4@:7,@82!C=7)R96YT('!A9V4@86YD('1H92!C=7)R96YT(%@@
M<&]S:71I;VX@:7,@;&5S<R!T:&%N"B`@("`@("`@("H@;6%R9VEN('-E="!T
M:&4@6"!P;W-I=&EO;B!T;R!T:&4@;6%R9VEN('9A;'5E+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^7W!A9V4@/B`P("8F("1T:&ES+3YX(#P@)&UA<F=I;BD@
M>PH@("`@("`@("`@("`D=&AI<RT^>"`]("1M87)G:6X["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE<R!T:&4@=&]P(&UA<F=I;BX@
M5&AE(&UE=&AO9"!C86X@8F4@8V%L;&5D(&)E9F]R92!C<F5A=&EN9R!T:&4*
M("`@("`J(&9I<G-T('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T
M("1M87)G:6X@(%1H92!M87)G:6XN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=%1O<$UA<F=I;B@D;6%R9VEN*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&]P
M7VUA<F=I;B`]("1M87)G:6X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$969I
M;F5S('1H92!R:6=H="!M87)G:6XN(%1H92!M971H;V0@8V%N(&)E(&-A;&QE
M9"!B969O<F4@8W)E871I;F<@=&AE"B`@("`@*B!F:7)S="!P86=E+@H@("`@
M("H*("`@("`J($!P87)A;2!F;&]A="`D;6%R9VEN("!4:&4@;6%R9VEN+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S9712:6=H=$UA<F=I;B@D;6%R9VEN*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<FEG:'1?;6%R9VEN(#T@)&UA<F=I;CL*
M("`@('T*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES86)L97,@=&AE
M(&%U=&]M871I8R!P86=E(&)R96%K:6YG(&UO9&4N(%=H96X@96YA8FQI;F<L
M"B`@("`@*B!T:&4@<V5C;VYD('!A<F%M971E<B!I<R!T:&4@9&ES=&%N8V4@
M9G)O;2!T:&4@8F]T=&]M(&]F('1H92!P86=E('1H870*("`@("`J(&1E9FEN
M97,@=&AE('1R:6=G97)I;F<@;&EM:70N($)Y(&1E9F%U;'0L('1H92!M;V1E
M(&ES(&]N(&%N9"!T:&4@;6%R9VEN"B`@("`@*B!I<R`R(&-M+@H@("`@("H*
M("`@("`J($!P87)A;2!B;V]L96%N(&%U=&\@("!";V]L96%N(&EN9&EC871I
M;F<@:68@;6]D92!S:&]U;&0@8F4@;VX@;W(@;V9F+@H@("`@("H@0'!A<F%M
M(&9L;V%T("1M87)G:6X@($1I<W1A;F-E(&9R;VT@=&AE(&)O='1O;2!O9B!T
M:&4@<&%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T075T;U!A9V5"<F5A
M:R@D875T;RP@)&UA<F=I;B`](#`I"B`@("!["B`@("`@("`@)'1H:7,M/E]A
M=71O7W!A9V5?8G)E86L@("`@/2`D875T;SL*("`@("`@("`D=&AI<RT^7V)R
M96%K7VUA<F=I;B`@("`@("`]("1M87)G:6X["B`@("`@("`@)'1H:7,M/E]P
M86=E7V)R96%K7W1R:6=G97(@/2`D=&AI<RT^:"`M("1M87)G:6X["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!W87D@=&AE(&1O8W5M96YT
M(&ES('1O(&)E(&1I<W!L87EE9"!B>2!T:&4@=FEE=V5R+B!4:&4@>F]O;0H@
M("`@("H@;&5V96P@8V%N(&)E('-E=#H@<&%G97,@8V%N(&)E(&1I<W!L87EE
M9"!E;G1I<F5L>2!O;B!S8W)E96XL(&]C8W5P>2!T:&4*("`@("`J(&9U;&P@
M=VED=&@@;V8@=&AE('=I;F1O=RP@=7-E(')E86P@<VEZ92P@8F4@<V-A;&5D
M(&)Y(&$@<W!E8VEF:6,*("`@("`J('IO;VUI;F<@9F%C=&]R(&]R('5S92!V
M:65W97(@9&5F875L="`H8V]N9FEG=7)E9"!I;B!T:&4@4')E9F5R96YC97,*
M("`@("`J(&UE;G4@;V8@06-R;V)A="DN(%1H92!P86=E(&QA>6]U="!C86X@
M8F4@<W!E8VEF:65D('1O;SH@<VEN9VQE(&%T(&]N8V4L"B`@("`@*B!C;VYT
M:6YU;W5S(&1I<W!L87DL('1W;R!C;VQU;6YS(&]R('9I97=E<B!D969A=6QT
M+@H@("`@("H@0GD@9&5F875L="P@9&]C=6UE;G1S('5S92!T:&4@9G5L;"!W
M:61T:"!M;V1E('=I=&@@8V]N=&EN=6]U<R!D:7-P;&%Y+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D>F]O;2`@("`@("`@("`@("!4:&4@>F]O;2!T
M;R!U<V4N($ET(&-A;B!B92!O;F4@;V8@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9F]L;&]W:6YG('-T<FEN9R!V86QU97,Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`M(&9U
M;&QP86=E.B!E;G1I<F4@<&%G92!O;B!S8W)E96X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("T@9G5L;'=I9'1H.B!M87AI;75M
M('=I9'1H(&]F('=I;F1O=PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!R96%L.B!U<V5S(')E86P@<VEZ92`H,3`P)2!Z;V]M
M*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!D
M969A=6QT.B!U<V5S('9I97=E<B!D969A=6QT(&UO9&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!A(&YU;6)E<B!I;F1I8V%T
M:6YG('1H92!Z;V]M:6YG(&9A8W1O<BX*("`@("`J($!P87)A;2!S=')I;F<@
M;&%Y;W5T("!4:&4@<&%G92!L87EO=70N(%!O<W-I8FQE('9A;'5E<R!A<F4Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M('-I;F=L93H@;VYE
M('!A9V4@870@;VYC90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!C;VYT:6YU;W5S.B!P86=E<R!I;B!C;VYT:6YU;W5S;'D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@='=O.B!T=V\@<&%G97,@;VX@='=O
M(&-O;'5M;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@9&5F
M875L=#H@=7-E<R!V:65W97(@9&5F875L="!M;V1E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!$969A=6QT('9A;'5E(&ES(&-O;G1I;G5O=7,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1I<W!L87E-;V1E*"1Z;V]M+"`D
M;&%Y;W5T(#T@)V-O;G1I;G5O=7,G*0H@("`@>PH@("`@("`@("1Z;V]M(#T@
M<W1R=&]L;W=E<B@D>F]O;2D["B`@("`@("`@:68@*"1Z;V]M(#T]("=F=6QL
M<&%G92<@?'P@)'IO;VT@/3T@)V9U;&QW:61T:"<@?'P@)'IO;VT@/3T@)W)E
M86PG"B`@("`@("`@("`@('Q\("1Z;V]M(#T]("=D969A=6QT)R!\?"`A:7-?
M<W1R:6YG*"1Z;V]M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7WIO;VU?;6]D
M92`]("1Z;V]M.PH@("`@("`@('T@96QS96EF("@D>F]O;2`]/2`G>F]O;2<I
M('L*("`@("`@("`@("`@)'1H:7,M/E]Z;V]M7VUO9&4@/2`D;&%Y;W5T.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BAS<')I;G1F*"=);F-O<G)E8W0@>F]O;2!D:7-P;&%Y(&UO9&4Z
M("5S)RP@)'IO;VTI*3L*("`@("`@("!]"@H@("`@("`@("1L87EO=70@/2!S
M=')T;VQO=V5R*"1L87EO=70I.PH@("`@("`@(&EF("@D;&%Y;W5T(#T]("=S
M:6YG;&4G('Q\("1L87EO=70@/3T@)V-O;G1I;G5O=7,G('Q\("1L87EO=70@
M/3T@)W1W;R<*("`@("`@("`@("`@?'P@)&QA>6]U="`]/2`G9&5F875L="<I
M('L*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71?;6]D92`]("1L87EO=70[
M"B`@("`@("`@?2!E;'-E:68@*"1Z;V]M("$]("=Z;V]M)RD@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G26YC;W)R
M96-T(&QA>6]U="!D:7-P;&%Y(&UO9&4Z("5S)RP@)&QA>6]U="DI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%C=&EV871E<R!O<B!D96%C
M=&EV871E<R!P86=E(&-O;7!R97-S:6]N+B!7:&5N(&%C=&EV871E9"P@=&AE
M(&EN=&5R;F%L"B`@("`@*B!R97!R97-E;G1A=&EO;B!O9B!E86-H('!A9V4@
M:7,@8V]M<')E<W-E9"P@=VAI8V@@;&5A9',@=&\@82!C;VUP<F5S<VEO;@H@
M("`@("H@<F%T:6\@;V8@86)O=70@,B!F;W(@=&AE(')E<W5L=&EN9R!D;V-U
M;65N="X*("`@("`J($-O;7!R97-S:6]N(&ES(&]N(&)Y(&1E9F%U;'0N"B`@
M("`@*B!.;W1E.B!T:&4@6FQI8B!E>'1E;G-I;VX@:7,@<F5Q=6ER960@9F]R
M('1H:7,@9F5A='5R92X@268@;F]T('!R97-E;G0L"B`@("`@*B!C;VUP<F5S
M<VEO;B!W:6QL(&)E('1U<FYE9"!O9F8N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&-O;7!R97-S("!";V]L96%N(&EN9&EC871I;F<@:68@8V]M
M<')E<W-I;VX@;75S="!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!E;F%B;&5D(&]R(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M0V]M<')E<W-I;VXH)&-O;7!R97-S*0H@("`@>PH@("`@("`@("\J($EF(&YO
M(&=Z8V]M<')E<W,@9G5N8W1I;VX@:7,@879A:6QA8FQE('1H96X@9&5F875L
M="!T;R!F86QS92X@*B\*("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@*&9U
M;F-T:6]N7V5X:7-T<R@G9WIC;VUP<F5S<R<I(#\@)&-O;7!R97-S(#H@9F%L
M<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!I;F9O('1O(&$@
M9&]C=6UE;G0N(%!O<W-I8FQE(&EN9F\@<V5T=&EN9W,@87)E.@H@("`@("H@
M("`M('1I=&QE"B`@("`@*B`@("T@<W5B:F5C=`H@("`@("H@("`M(&%U=&AO
M<@H@("`@("H@("`M(&ME>7=O<F1S"B`@("`@*B`@("T@8W)E871O<@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D:6YF;R`@("!)9B!P87-S960@87,@
M86X@87)R87D@=&AE;B!T:&4@8V]M<&QE=&4@:&%S:`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1A:6YI;F<@=&AE(&EN9F\@=&\@8F4@:6YS
M97)T960@:6YT;R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!D
M;V-U;65N="X@3W1H97)W:7-E('1H92!N86UE(&]F('-E='1I;F<@=&\@8F4@
M<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!V86QU92!O
M9B!T:&4@<V5T=&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T26YF;R@D
M:6YF;RP@)'9A;'5E(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1I;F9O*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VEN9F\@/2`D:6YF;SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VEN9F];)&EN
M9F]=(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($1E9FEN97,@86X@86QI87,@9F]R('1H92!T;W1A;"!N=6UB97(@;V8@<&%G
M97,N($ET('=I;&P@8F4@<W5B<W1I='5T960*("`@("`J(&%S('1H92!D;V-U
M;65N="!I<R!C;&]S960N"B`@("`@*@H@("`@("H@17AA;7!L93H*("`@("`J
M(&-L87-S($UY7T9I;&5?4$1&(&5X=&5N9',@1FEL95]01$8@>PH@("`@("H@
M("`@(&9U;F-T:6]N(&9O;W1E<B@I"B`@("`@*B`@("`@>PH@("`@("H@("`@
M("`@("`O+R!';R!T;R`Q+C4@8VT@9G)O;2!B;W1T;VT*("`@("`J("`@("`@
M("`@)'1H:7,M/G-E=%DH+3$U*3L*("`@("`J("`@("`@("`@+R\@4V5L96-T
M($%R:6%L(&ET86QI8R`X"B`@("`@*B`@("`@("`@("1T:&ES+3YS971&;VYT
M*"=!<FEA;"<L("=))RP@."D["B`@("`@*B`@("`@("`@("\O(%!R:6YT(&-U
M<G)E;G0@86YD('1O=&%L('!A9V4@;G5M8F5R<PH@("`@("H@("`@("`@("`D
M=&AI<RT^8V5L;"@P+"`Q,"P@)U!A9V4@)R`N("1T:&ES+3YG971086=E3F\H
M*2`N("<O>VYB?2<L(#`L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(#`L
M("=#)RD["B`@("`@*B`@("`@?0H@("`@("H@?0H@("`@("H@)'!D9B`]("9-
M>5]&:6QE7U!$1CHZ9F%C=&]R>2@I.PH@("`@("H@)'!D9BT^86QI87-.8E!A
M9V5S*"D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86QI87,@(%1H
M92!A;&EA<RX@1&5F875L="!V86QU93H@>VYB?2X*("`@("`J"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIG971086=E3F\*("`@("`J($!S964@1FEL95]01$8Z
M.F9O;W1E<@H@("`@("HO"B`@("!F=6YC=&EO;B!A;&EA<TYB4&%G97,H)&%L
M:6%S(#T@)WMN8GTG*0H@("`@>PH@("`@("`@("1T:&ES+3Y?86QI87-?;F)?
M<&%G97,@/2`D86QI87,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE
M=&AO9"!B96=I;G,@=&AE(&=E;F5R871I;VX@;V8@=&AE(%!$1B!D;V-U;65N
M=#L@:70@;75S="!B90H@("`@("H@8V%L;&5D(&)E9F]R92!A;GD@;W5T<'5T
M(&-O;6UA;F1S+B!.;R!P86=E(&ES(&-R96%T960@8GD@=&AI<R!M971H;V0L
M"B`@("`@*B!T:&5R969O<F4@:70@:7,@;F5C97-S87)Y('1O(&-A;&P@1FEL
M95]01$8Z.F%D9%!A9V4N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M861D4&%G90H@("`@("H@0'-E92!&:6QE7U!$1CHZ8VQO<V4*("`@("`J+PH@
M("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]B96=I
M;D1O8R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&5R;6EN871E<R!T:&4@
M4$1&(&1O8W5M96YT+B!)="!I<R!N;W0@;F5C97-S87)Y('1O(&-A;&P@=&AI
M<R!M971H;V0*("`@("`J(&5X<&QI8VET;'D@8F5C875S92!&:6QE7U!$1CHZ
M;W5T<'5T(&1O97,@:70@875T;VUA=&EC86QL>2X*("`@("`J($EF('1H92!D
M;V-U;65N="!C;VYT86EN<R!N;R!P86=E+"!&:6QE7U!$1CHZ861D4&%G92!I
M<R!C86QL960@=&\@<')E=F5N=`H@("`@("H@9G)O;2!G971T:6YG(&%N(&EN
M=F%L:60@9&]C=6UE;G0N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M;W!E;@H@("`@("H@0'-E92!&:6QE7U!$1CHZ;W5T<'5T"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O*B!497)M:6YA=&4@
M9&]C=6UE;G0@*B\*("`@("`@("!I9B`H)'1H:7,M/E]P86=E(#T](#`I('L*
M("`@("`@("`@("`@)'1H:7,M/F%D9%!A9V4H*3L*("`@("`@("!]"B`@("`@
M("`@+RH@4&%G92!F;V]T97(@*B\*("`@("`@("`D=&AI<RT^7VEN7V9O;W1E
M<B`]('1R=64["B`@("`@("`@)'1H:7,M/F9O;W1E<B@I.PH@("`@("`@("1T
M:&ES+3Y?:6Y?9F]O=&5R(#T@9F%L<V4["B`@("`@("`@+RH@0VQO<V4@<&%G
M92`J+PH@("`@("`@("1T:&ES+3Y?96YD4&%G92@I.PH@("`@("`@("\J($-L
M;W-E(&1O8W5M96YT("HO"B`@("`@("`@)'1H:7,M/E]E;F1$;V,H*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@82!N97<@<&%G92!T;R!T:&4@9&]C
M=6UE;G0N($EF(&$@<&%G92!I<R!A;')E861Y('!R97-E;G0L('1H90H@("`@
M("H@1FEL95]01$8Z.F9O;W1E<B!M971H;V0@:7,@8V%L;&5D(&9I<G-T('1O
M(&]U='!U="!T:&4@9F]O=&5R+B!4:&5N('1H90H@("`@("H@<&%G92!I<R!A
M9&1E9"P@=&AE(&-U<G)E;G0@<&]S:71I;VX@<V5T('1O('1H92!T;W`M;&5F
M="!C;W)N97(@86-C;W)D:6YG"B`@("`@*B!T;R!T:&4@;&5F="!A;F0@=&]P
M(&UA<F=I;G,L(&%N9"!&:6QE7U!$1CHZ:&5A9&5R(&ES(&-A;&QE9"!T;R!D
M:7-P;&%Y"B`@("`@*B!T:&4@:&5A9&5R+@H@("`@("H@5&AE(&9O;G0@=VAI
M8V@@=V%S('-E="!B969O<F4@8V%L;&EN9R!I<R!A=71O;6%T:6-A;&QY(')E
M<W1O<F5D+B!4:&5R90H@("`@("H@:7,@;F\@;F5E9"!T;R!C86QL($9I;&5?
M4$1&.CIS971&;VYT(&%G86EN(&EF('EO=2!W86YT('1O(&-O;G1I;G5E('=I
M=&@*("`@("`J('1H92!S86UE(&9O;G0N(%1H92!S86UE(&ES('1R=64@9F]R
M(&-O;&]R<R!A;F0@;&EN92!W:61T:"X*("`@("`J(%1H92!O<FEG:6X@;V8@
M=&AE(&-O;W)D:6YA=&4@<WES=&5M(&ES(&%T('1H92!T;W`M;&5F="!C;W)N
M97(@86YD"B`@("`@*B!I;F-R96%S:6YG(&]R9&EN871E<R!G;R!D;W=N=V%R
M9',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W)I96YT871I;VX@
M(%!A9V4@;W)I96YT871I;VXN(%!O<W-I8FQE('9A;'5E<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R92`H8V%S92!I;G-E;G-I=&EV
M92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`M(%`@
M;W(@4&]R=')A:70*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("T@3"!O<B!,86YD<V-A<&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!4:&4@9&5F875L="!V86QU92!I<R!T:&4@;VYE('!A<W-E
M9"!T;R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CI01$8*
M("`@("`J($!S964@1FEL95]01$8Z.FAE861E<@H@("`@("H@0'-E92!&:6QE
M7U!$1CHZ9F]O=&5R"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971-87)G:6YS
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%!A9V4H)&]R:65N=&%T:6]N(#T@
M)R<I"B`@("!["B`@("`@("`@+RH@1F]R(&=O;V0@;65A<W5R92!M86ME('-U
M<F4@=&AI<R!I<R!C86QL960N("HO"B`@("`@("`@)'1H:7,M/E]B96=I;D1O
M8R@I.PH*("`@("`@("`O*B!3879E('-T>6QE('-E='1I;F=S('-O('1H870@
M=&AE>2!A<F4@;F]T(&]V97)R:61D96X@8GD*("`@("`@("`@*B!H96%D97(H
M*2X@*B\*("`@("`@("`D;'<@/2`D=&AI<RT^7VQI;F5?=VED=&@["B`@("`@
M("`@)&1C(#T@)'1H:7,M/E]D<F%W7V-O;&]R.PH@("`@("`@("1F8R`]("1T
M:&ES+3Y?9FEL;%]C;VQO<CL*("`@("`@("!I9B`H)'1H:7,M/E]P86=E(#X@
M,"D@>PH@("`@("`@("`@("`O*B!086=E(&9O;W1E<BX@*B\*("`@("`@("`@
M("`@)'1H:7,M/E]I;E]F;V]T97(@/2!T<G5E.PH@("`@("`@("`@("`D=&AI
M<RT^9F]O=&5R*"D["B`@("`@("`@("`@("1T:&ES+3Y?:6Y?9F]O=&5R(#T@
M9F%L<V4["B`@("`@("`@("`@("\J($-L;W-E('!A9V4N("HO"B`@("`@("`@
M("`@("1T:&ES+3Y?96YD4&%G92@I.PH@("`@("`@('T*("`@("`@("`O*B!3
M=&%R="!N97<@<&%G92X@*B\*("`@("`@("`D=&AI<RT^7V)E9VEN4&%G92@D
M;W)I96YT871I;VXI.PH@("`@("`@("\J(%-E="!L:6YE(&-A<"!S='EL92!T
M;R!S<75A<F4N("HO"B`@("`@("`@)'1H:7,M/E]O=70H)S(@2B<I.PH@("`@
M("`@("\J(%-E="!L:6YE('=I9'1H+B`J+PH@("`@("`@("1T:&ES+3Y?;&EN
M95]W:61T:"`]("1L=SL*("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F*"<E
M+C)F('<G+"`D;'<@*B`D=&AI<RT^7W-C86QE*2D["B`@("`@("`@+RH@4V5T
M(&9O;G0@9F]R('1H92!B96=I;FYI;F<@;V8@=&AE('!A9V4N("HO"B`@("`@
M("`@:68@*"1T:&ES+3Y?9F]N=%]F86UI;'DI('L*("`@("`@("`@("`@)'1H
M:7,M/G-E=$9O;G0H)'1H:7,M/E]F;VYT7V9A;6EL>2P@)'-T>6QE+"`D=&AI
M<RT^7V9O;G1?<VEZ95]P="D["B`@("`@("`@("`@("1F;VYT7V9A;6EL>2`]
M("1T:&ES+3Y?9F]N=%]F86UI;'D["B`@("`@("`@("`@("1F;VYT7W-T>6QE
M(#T@)'1H:7,M/E]F;VYT7W-T>6QE("X@*"1T:&ES+3Y?=6YD97)L:6YE(#\@
M)U4G(#H@)R<I.PH@("`@("`@("`@("`D9F]N=%]S:7IE("`]("1T:&ES+3Y?
M9F]N=%]S:7IE7W!T.PH@("`@("`@('T*("`@("`@("`O*B!3970@8V]L;W)S
M+B`J+PH@("`@("`@("1T:&ES+3Y?9FEL;%]C;VQO<B`]("1F8SL*("`@("`@
M("`O*B!#:&5C:R!I9B!F:6QL(&-O;&]R(&AA<R!B965N('-E="!B969O<F4@
M=&AI<R!P86=E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V9I;&Q?8V]L;W(@
M(3T@)S`@9R<I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)'1H:7,M/E]F
M:6QL7V-O;&]R*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]D<F%W7V-O
M;&]R(#T@)&1C.PH@("`@("`@("\J($-H96-K(&EF(&1R87<@8V]L;W(@:&%S
M(&)E96X@<V5T(&)E9F]R92!T:&ES('!A9V4N("HO"B`@("`@("`@:68@*"1T
M:&ES+3Y?9')A=U]C;VQO<B`A/2`G,"!')RD@>PH@("`@("`@("`@("`D=&AI
M<RT^7V]U="@D=&AI<RT^7V1R87=?8V]L;W(I.PH@("`@("`@('T*("`@("`@
M("`O*B!086=E(&AE861E<BX@*B\*("`@("`@("`D=&AI<RT^:&5A9&5R*"D[
M"B`@("`@("`@+RH@4F5S=&]R92!L:6YE('=I9'1H+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^7VQI;F5?=VED=&@@(3T@)&QW*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&EN95]W:61T:"`]("1L=SL*("`@("`@("`@("`@)'1H:7,M/E]O
M=70H<W!R:6YT9B@G)2XR9B!W)RP@)&QW("H@)'1H:7,M/E]S8V%L92DI.PH@
M("`@("`@('T*("`@("`@("`O*B!-86ME('-U<F4@=&AE(&9O;G0@:7,@<V5T
M(&9O<B!T:&ES('!A9V4@87,@:70@=V%S(&)E9F]R92!T:&4*("`@("`@("`@
M*B!H96%D97(N("HO"B`@("`@("`@:68@*"1F;VYT7V9A;6EL>2D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T1F]N="@D9F]N=%]F86UI;'DL("1F;VYT7W-T
M>6QE+"`D9F]N=%]S:7IE+"!T<G5E*3L*("`@("`@("!]"B`@("`@("`@+RH@
M4F5S=&]R92!C;VQO<G,N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?9')A=U]C
M;VQO<B`A/2`D9&,I('L*("`@("`@("`@("`@)'1H:7,M/E]D<F%W7V-O;&]R
M(#T@)&1C.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@D9&,I.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'1H:7,M/E]F:6QL7V-O;&]R("$]("1F8RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7V9I;&Q?8V]L;W(@/2`D9F,["B`@("`@("`@
M("`@("1T:&ES+3Y?;W5T*"1F8RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@5&AI<R!M971H;V0@:7,@=7-E9"!T;R!R96YD97(@=&AE('!A
M9V4@:&5A9&5R+B!)="!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B!C86QL960@
M8GD@1FEL95]01$8Z.F%D9%!A9V4@86YD('-H;W5L9"!N;W0@8F4@8V%L;&5D
M(&1I<F5C=&QY(&)Y('1H90H@("`@("H@87!P;&EC871I;VXN(%1H92!I;7!L
M96UE;G1A=&EO;B!I;B!&:6QE7U!$1CHZ(&ES(&5M<'1Y+"!S;R!Y;W4@:&%V
M92!T;PH@("`@("H@<W5B8VQA<W,@:70@86YD(&]V97)R:61E('1H92!M971H
M;V0@:68@>6]U('=A;G0@82!S<&5C:69I8R!P<F]C97-S:6YG+@H@("`@("H*
M("`@("`J($5X86UP;&4Z"B`@("`@*@H@("`@("H@8VQA<W,@37E?1FEL95]0
M1$8@97AT96YD<R!&:6QE7U!$1B!["B`@("`@*B`@("`@9G5N8W1I;VX@:&5A
M9&5R*"D*("`@("`J("`@("!["B`@("`@*B`@("`@("`@("\O(%-E;&5C="!!
M<FEA;"!B;VQD(#$U"B`@("`@*B`@("`@("`@("1T:&ES+3YS971&;VYT*"=!
M<FEA;"<L("=")RP@,34I.PH@("`@("H@("`@("`@("`O+R!-;W9E('1O('1H
M92!R:6=H=`H@("`@("H@("`@("`@("`D=&AI<RT^8V5L;"@X,"D["B`@("`@
M*B`@("`@("`@("\O($9R86UE9"!T:71L90H@("`@("H@("`@("`@("`D=&AI
M<RT^8V5L;"@S,"P@,3`L("=4:71L92<L(#$L(#`L("=#)RD["B`@("`@*B`@
M("`@("`@("\O($QI;F4@8G)E86L*("`@("`J("`@("`@("`@)'1H:7,M/FYE
M=TQI;F4H,C`I.PH@("`@("H@("`@('T*("`@("`J('T*("`@("`J"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIF;V]T97(*("`@("`J+PH@("`@9G5N8W1I;VX@
M:&5A9&5R*"D*("`@('L*("`@("`@("`O*B!4;R!B92!I;7!L96UE;G1E9"!I
M;B!Y;W5R(&]W;B!I;FAE<FET960@8VQA<W,N("HO"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!U<V5D('1O(')E;F1E<B!T:&4@<&%G
M92!F;V]T97(N($ET(&ES(&%U=&]M871I8V%L;'D*("`@("`J(&-A;&QE9"!B
M>2!&:6QE7U!$1CHZ861D4&%G92!A;F0@1FEL95]01$8Z.F-L;W-E(&%N9"!S
M:&]U;&0@;F]T(&)E(&-A;&QE9`H@("`@("H@9&ER96-T;'D@8GD@=&AE(&%P
M<&QI8V%T:6]N+B!4:&4@:6UP;&5M96YT871I;VX@:6X@1FEL95]01$8Z.B!I
M<R!E;7!T>2P*("`@("`J('-O('EO=2!H879E('1O('-U8F-L87-S(&ET(&%N
M9"!O=F5R<FED92!T:&4@;65T:&]D(&EF('EO=2!W86YT(&$@<W!E8VEF:6,*
M("`@("`J('!R;V-E<W-I;F<N"B`@("`@*@H@("`@("H@17AA;7!L93H*("`@
M("`J"B`@("`@*B!C;&%S<R!->5]&:6QE7U!$1B!E>'1E;F1S($9I;&5?4$1&
M('L*("`@("`J("`@(&9U;F-T:6]N(&9O;W1E<B@I"B`@("`@*B`@("!["B`@
M("`@*B`@("`@("`@+R\@1V\@=&\@,2XU(&-M(&9R;VT@8F]T=&]M"B`@("`@
M*B`@("`@("`@)'1H:7,M/G-E=%DH+3$U*3L*("`@("`J("`@("`@("`O+R!3
M96QE8W0@07)I86P@:71A;&EC(#@*("`@("`J("`@("`@("`D=&AI<RT^<V5T
M1F]N="@G07)I86PG+"`G22<L(#@I.PH@("`@("H@("`@("`@("\O(%!R:6YT
M(&-E;G1E<F5D('!A9V4@;G5M8F5R"B`@("`@*B`@("`@("`@)'1H:7,M/F-E
M;&PH,"P@,3`L("=086=E("<@+B`D=&AI<RT^9V5T4&%G94YO*"DL(#`L(#`L
M("=#)RD["B`@("`@*B`@("!]"B`@("`@*B!]"B`@("`@*@H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ:&5A9&5R"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O;W1E
M<B@I"B`@("!["B`@("`@("`@+RH@5&\@8F4@:6UP;&5M96YT960@:6X@>6]U
M<B!O=VX@:6YH97)I=&5D(&-L87-S+B`J+PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@8W5R<F5N="!P86=E(&YU;6)E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(*("`@("`J"B`@("`@*B!`<V5E($9I;&5?
M4$1&.CIA;&EA<TYB4&%G97,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%G
M94YO*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P86=E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@9FEL;"!C;VQO<BX@4W!E8VEF
M:65S('1H92!C;VQO<B!F;W(@8F]T:"!F:6QL960@87)E87,@86YD"B`@("`@
M*B!T97AT+B!$97!E;F1I;F<@;VX@=&AE(&-O;&]R<W!A8V4@8V%L;&5D+"!T
M:&4@;G5M8F5R(&]F(&-O;&]R(&-O;7!O;F5N=`H@("`@("H@<&%R86UE=&5R
M<R!R97%U:7)E9"!C86X@8F4@96ET:&5R(#$L(#,@;W(@-"X@5&AE(&UE=&AO
M9"!C86X@8F4@8V%L;&5D"B`@("`@*B!B969O<F4@=&AE(&9I<G-T('!A9V4@
M:7,@8W)E871E9"!A;F0@=&AE(&-O;&]R(&ES(')E=&%I;F5D(&9R;VT@<&%G
M92!T;PH@("`@("H@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C<R`@26YD:6-A=&5S('1H92!C;VQO<G-P86-E('=H:6-H(&-A;B!B92!E
M:71H97(@)W)G8B<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@)V-M>6LG
M(&]R("=G<F%Y)RX@1&5F875L=',@=&\@)W)G8B<N"B`@("`@*B!`<&%R86T@
M9FQO870@)&,Q("`@1FER<W0@8V]L;W(@8V]M<&]N96YT+"!F;&]A=&EN9R!P
M;VEN="!V86QU92!B971W965N(#`*("`@("`J("`@("`@("`@("`@("`@("`@
M("!A;F0@,2X@4F5Q=6ER960@9F]R(&=R87DL(')G8B!A;F0@8VUY:RX*("`@
M("`J($!P87)A;2!F;&]A="`D8S(@("!396-O;F0@8V]L;W(@8V]M<&]N96YT
M+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W965N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@,"!A;F0@,2X@4F5Q=6ER960@9F]R(')G8B!A;F0@8VUY
M:RX*("`@("`J($!P87)A;2!F;&]A="`D8S,@("!4:&ER9"!C;VQO<B!C;VUP
M;VYE;G0L(&9L;V%T:6YG('!O:6YT('9A;'5E(&)E='=E96X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`P(&%N9"`Q+B!297%U:7)E9"!F;W(@<F=B(&%N
M9"!C;7EK+@H@("`@("H@0'!A<F%M(&9L;V%T("1C-"`@($9O=7)T:"!C;VQO
M<B!C;VUP;VYE;G0L(&9L;V%T:6YG('!O:6YT('9A;'5E(&)E='=E96X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`P(&%N9"`Q+B!297%U:7)E9"!F;W(@
M8VUY:RX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971$<F%W0V]L
M;W(*("`@("`J($!S964@1FEL95]01$8Z.G)E8W0*("`@("`J($!S964@1FEL
M95]01$8Z.F-E;&P*("`@("`J($!S964@1FEL95]01$8Z.FUU;'1I0V5L;`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971&:6QL0V]L;W(H)&-S(#T@)W)G8B<L
M("1C,2P@)&,R(#T@,"P@)&,S(#T@,"P@)&,T(#T@,"D*("`@('L*("`@("`@
M("`D8W,@/2!S=')T;VQO=V5R*"1C<RD["B`@("`@("`@:68@*"1C<R`]/2`G
M<F=B)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V9I;&Q?8V]L;W(@/2!S<')I
M;G1F*"<E+C-F("4N,V8@)2XS9B!R9R<L("1C,2P@)&,R+"`D8S,I.PH@("`@
M("`@('T@96QS96EF("@D8W,@/3T@)V-M>6LG*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9FEL;%]C;VQO<B`]('-P<FEN=&8H)R4N,V8@)2XS9B`E+C-F("4N
M,V8@:R<L("1C,2P@)&,R+"`D8S,L("1C-"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]F:6QL7V-O;&]R(#T@<W!R:6YT9B@G)2XS
M9B!G)RP@)&,Q*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?<&%G
M92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)'1H:7,M/E]F:6QL
M7V-O;&]R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S
M('1H92!D<F%W(&-O;&]R+"!U<V5D('=H96X@9')A=VEN9R!L:6YE<RX@1&5P
M96YD:6YG(&]N('1H90H@("`@("H@8V]L;W)S<&%C92!C86QL960L('1H92!N
M=6UB97(@;V8@8V]L;W(@8V]M<&]N96YT('!A<F%M971E<G,@<F5Q=6ER960*
M("`@("`J(&-A;B!B92!E:71H97(@,2P@,R!O<B`T+B!4:&4@;65T:&]D(&-A
M;B!B92!C86QL960@8F5F;W)E('1H92!F:7)S="!P86=E"B`@("`@*B!I<R!C
M<F5A=&5D(&%N9"!T:&4@8V]L;W(@:7,@<F5T86EN960@9G)O;2!P86=E('1O
M('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W,@($EN9&EC
M871E<R!T:&4@8V]L;W)S<&%C92!W:&EC:"!C86X@8F4@96ET:&5R("=R9V(G
M+`H@("`@("H@("`@("`@("`@("`@("`@("`@("=C;7EK)R!O<B`G9W)A>2<N
M($1E9F%U;'1S('1O("=R9V(G+@H@("`@("H@0'!A<F%M(&9L;V%T("1C,2`@
M($9I<G-T(&-O;&]R(&-O;7!O;F5N="P@9FQO871I;F<@<&]I;G0@=F%L=64@
M8F5T=V5E;B`P"B`@("`@*B`@("`@("`@("`@("`@("`@("`@86YD(#$N(%)E
M<75I<F5D(&9O<B!G<F%Y+"!R9V(@86YD(&-M>6LN"B`@("`@*B!`<&%R86T@
M9FQO870@)&,R("`@4V5C;VYD(&-O;&]R(&-O;7!O;F5N="P@9FQO871I;F<@
M<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M(#`@86YD(#$N(%)E<75I<F5D(&9O<B!R9V(@86YD(&-M>6LN"B`@("`@*B!`
M<&%R86T@9FQO870@)&,S("`@5&AI<F0@8V]L;W(@8V]M<&]N96YT+"!F;&]A
M=&EN9R!P;VEN="!V86QU92!B971W965N(#`*("`@("`J("`@("`@("`@("`@
M("`@("`@("!A;F0@,2X@4F5Q=6ER960@9F]R(')G8B!A;F0@8VUY:RX*("`@
M("`J($!P87)A;2!F;&]A="`D8S0@("!&;W5R=&@@8V]L;W(@8V]M<&]N96YT
M+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W965N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@,"!A;F0@,2X@4F5Q=6ER960@9F]R(&-M>6LN"B`@("`@
M*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1FEL;$-O;&]R"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIL:6YE"B`@("`@*B!`<V5E($9I;&5?4$1&.CIR96-T
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC96QL"B`@("`@*B!`<V5E($9I;&5?
M4$1&.CIM=6QT:4-E;&P*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1')A=T-O
M;&]R*"1C<R`]("=R9V(G+"`D8S$L("1C,B`](#`L("1C,R`](#`L("1C-"`]
M(#`I"B`@("!["B`@("`@("`@)&-S(#T@<W1R=&]L;W=E<B@D8W,I.PH@("`@
M("`@(&EF("@D8W,@/3T@)W)G8B<I('L*("`@("`@("`@("`@)'1H:7,M/E]D
M<F%W7V-O;&]R(#T@<W!R:6YT9B@G)2XS9B`E+C-F("4N,V8@4D<G+"`D8S$L
M("1C,BP@)&,S*3L*("`@("`@("!](&5L<V5I9B`H)&-S(#T]("=C;7EK)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7V1R87=?8V]L;W(@/2!S<')I;G1F*"<E
M+C-F("4N,V8@)2XS9B`E+C-F($LG+"`D8S$L("1C,BP@)&,S+"`D8S0I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?9')A=U]C;VQO
M<B`]('-P<FEN=&8H)R4N,V8@1R<L("1C,2D["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<RT^7W!A9V4@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"1T:&ES+3Y?9')A=U]C;VQO<BD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&5N9W1H(&]F(&$@=&5X="!S=')I
M;F<N($$@9F]N="!M=7-T(&)E('-E;&5C=&5D+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('=H;W-E(&QE;F=T:"!I<R!T
M;R!B92!C;VUP=71E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1P="`@($)O
M;VQE86X@=&\@:6YD:6-A=&4@:68@=&AE('=I9'1H('-H;W5L9"!B92!R971U
M<FYE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@:6X@<&]I;G1S(&]R
M('5S97(@=6YI=',N($1E9F%U;'0@:7,@)V9A;'-E)RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&9L;V%T"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-T<FEN
M9U=I9'1H*"1T97AT+"`D<'0@/2!F86QS92D*("`@('L*("`@("`@("`D=&5X
M="`]("AS=')I;F<I)'1E>'0["B`@("`@("`@)'=I9'1H(#T@,#L*("`@("`@
M("`D;&5N9W1H(#T@<W1R;&5N*"1T97AT*3L*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D;&5N9W1H.R`D:2LK*2!["B`@("`@("`@("`@("1W:61T:"`K
M/2`D=&AI<RT^7V-U<G)E;G1?9F]N=%LG8W<G75LD=&5X='LD:7U=.PH@("`@
M("`@('T*"B`@("`@("`@+RH@061J=7-T(&9O<B!W;W)D('-P86-I;F<N("HO
M"B`@("`@("`@)'=I9'1H("L]("1T:&ES+3Y?=V]R9%]S<&%C:6YG("H@<W5B
M<W1R7V-O=6YT*"1T97AT+"`G("<I("H@)'1H:7,M/E]C=7)R96YT7V9O;G1;
M)V-W)UU;)R`G73L*"B`@("`@("`@:68@*"1P="D@>PH@("`@("`@("`@("!R
M971U<FX@)'=I9'1H("H@)'1H:7,M/E]F;VYT7W-I>F5?<'0@+R`Q,#`P.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=VED=&@@*B`D
M=&AI<RT^7V9O;G1?<VEZ92`O(#$P,#`["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1&5F:6YE<R!T:&4@;&EN92!W:61T:"X@0GD@9&5F875L
M="P@=&AE('9A;'5E(&5Q=6%L<R`P+C(@;6TN(%1H92!M971H;V0*("`@("`J
M(&-A;B!B92!C86QL960@8F5F;W)E('1H92!F:7)S="!P86=E(&ES(&-R96%T
M960@86YD('1H92!V86QU92!I<PH@("`@("H@<F5T86EN960@9G)O;2!P86=E
M('1O('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1W:61T:"`@
M5&AE('=I9'1H+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.FQI;F4*
M("`@("`J($!S964@1FEL95]01$8Z.G)E8W0*("`@("`J($!S964@1FEL95]0
M1$8Z.F-E;&P*("`@("`J($!S964@1FEL95]01$8Z.FUU;'1I0V5L;`H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971,:6YE5VED=&@H)'=I9'1H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;&EN95]W:61T:"`]("1W:61T:#L*("`@("`@("!I
M9B`H)'1H:7,M/E]P86=E(#X@,"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U
M="AS<')I;G1F*"<E+C)F('<G+"`D=VED=&@@*B`D=&AI<RT^7W-C86QE*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=W,@82!L:6YE
M(&)E='=E96X@='=O('!O:6YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@9FQO
M870@)'@Q("!!8G-C:7-S82!O9B!F:7)S="!P;VEN="X*("`@("`J($!P87)A
M;2!F;&]A="`D>3$@($]R9&EN871E(&]F(&9I<G-T('!O:6YT+@H@("`@("H@
M0'!A<F%M(&9L;V%T("1X,B`@06)S8VES<V$@;V8@<V5C;VYD('!O:6YT+@H@
M("`@("H@0'!A<F%M(&9L;V%T("1Y,B`@3W)D:6YA=&4@;V8@<V5C;VYD('!O
M:6YT+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$QI;F57:61T
M:`H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1')A=T-O;&]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@)'DQ+"`D>#(L("1Y,BD*("`@('L*
M("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F*"<E+C)F("4N,F8@;2`E+C)F
M("4N,F8@;"!3)RP@)'@Q("H@)'1H:7,M/E]S8V%L92P@*"1T:&ES+3YH("T@
M)'DQ*2`J("1T:&ES+3Y?<V-A;&4L("1X,B`J("1T:&ES+3Y?<V-A;&4L("@D
M=&AI<RT^:"`M("1Y,BD@*B`D=&AI<RT^7W-C86QE*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!/=71P=71S(&$@<F5C=&%N9VQE+B!)="!C86X@8F4@9')A
M=VX@*&)O<F1E<B!O;FQY*2P@9FEL;&5D("AW:71H(&YO"B`@("`@*B!B;W)D
M97(I(&]R(&)O=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@
M("`@($%B<V-I<W-A(&]F('5P<&5R+6QE9G0@8V]R;F5R+@H@("`@("H@0'!A
M<F%M(&9L;V%T("1Y("`@("`@($]R9&EN871E(&]F('5P<&5R+6QE9G0@8V]R
M;F5R+@H@("`@("H@0'!A<F%M(&9L;V%T("1W:61T:"`@(%=I9'1H+@H@("`@
M("H@0'!A<F%M(&9L;V%T("1H96EG:'0@($AE:6=H="X*("`@("`J($!P87)A
M;2!F;&]A="`D<W1Y;&4@("!3='EL92!O9B!R96YD97)I;F<N(%!O<W-I8FQE
M('9A;'5E<R!A<F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M
M($0@;W(@96UP='D@<W1R:6YG.B!D<F%W("AD969A=6QT*0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!&.B!F:6QL"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M($1&(&]R($9$.B!D<F%W(&%N9"!F:6QL"B`@
M("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T3&EN95=I9'1H"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS971$<F%W0V]L;W(*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=$9I;&Q#;VQO<@H@("`@("HO"B`@("!F=6YC=&EO;B!R96-T
M*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D<W1Y;&4@/2`G)RD*("`@('L*
M("`@("`@("`D<W1Y;&4@/2!S=')T;W5P<&5R*"1S='EL92D["B`@("`@("`@
M:68@*"1S='EL92`]/2`G1B<I('L*("`@("`@("`@("`@)&]P(#T@)V8G.PH@
M("`@("`@('T@96QS96EF("@D<W1Y;&4@/3T@)T9$)R!\?"`D<W1Y;&4@/3T@
M)T1&)RD@>PH@("`@("`@("`@("`D;W`@/2`G0B<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&]P(#T@)U,G.PH@("`@("`@('T*"B`@("`@("`@
M)'@@("`@("`]("1T:&ES+3Y?=&]0="@D>"D["B`@("`@("`@)'D@("`@("`]
M("1T:&ES+3Y?=&]0="@D>2D["B`@("`@("`@)'=I9'1H("`]("1T:&ES+3Y?
M=&]0="@D=VED=&@I.PH@("`@("`@("1H96EG:'0@/2`D=&AI<RT^7W1O4'0H
M)&AE:6=H="D["@H@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,F8@
M)2XR9B`E+C)F("4N,F8@<F4@)7,G+"`D>"P@)'1H:7,M/FA0="`M("1Y+"`D
M=VED=&@L("TD:&5I9VAT+"`D;W`I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($]U='!U=',@82!C:7)C;&4N($ET(&-A;B!B92!D<F%W;B`H8F]R9&5R(&]N
M;'DI+"!F:6QL960@*'=I=&@@;F\*("`@("`J(&)O<F1E<BD@;W(@8F]T:"X*
M("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@("`@("`@06)S8VES<V$@
M;V8@=&AE(&-E;G1E<B!O9B!T:&4@8VER8VQE+@H@("`@("H@0'!A<F%M(&9L
M;V%T("1Y("`@("`@($]R9&EN871E(&]F('1H92!C96YT97(@;V8@=&AE(&-I
M<F-L92X*("`@("`J($!P87)A;2!F;&]A="`D<B`@("`@("!#:7)C;&4@<F%D
M:75S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1Y;&4@(%-T>6QE(&]F(')E
M;F1E<FEN9RX@4&]S<VEB;&4@=F%L=65S(&%R93H*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("T@1"!O<B!E;7!T>2!S=')I;F<Z(&1R87<@*&1E
M9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($8Z(&9I
M;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@1$8@;W(@1D0Z
M(&1R87<@86YD(&9I;&P*("`@("`J+PH@("`@9G5N8W1I;VX@8VER8VQE*"1X
M+"`D>2P@)'(L("1S='EL92`]("<G*0H@("`@>PH@("`@("`@("1S='EL92`]
M('-T<G1O;&]W97(H)'-T>6QE*3L*("`@("`@("!I9B`H)'-T>6QE(#T]("=F
M)RD@>PH@("`@("`@("`@("`D;W`@/2`G9B<[("`@("`@+R\@4W1Y;&4@:7,@
M9FEL;"!O;FQY+@H@("`@("`@('T@96QS96EF("@D<W1Y;&4@/3T@)V9D)R!\
M?"`D<W1Y;&4@/3T@)V1F)RD@>PH@("`@("`@("`@("`D;W`@/2`G0B<[("`@
M("`@+R\@4W1Y;&4@:7,@9FEL;"!A;F0@<W1R;VME+@H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1O<"`]("=3)SL@("`@("`O+R!3='EL92!I<R!S
M=')O:V4@;VYL>2X*("`@("`@("!]"@H@("`@("`@("1X(#T@)'1H:7,M/E]T
M;U!T*"1X*3L*("`@("`@("`D>2`]("1T:&ES+3Y?=&]0="@D>2D["B`@("`@
M("`@)'(@/2`D=&AI<RT^7W1O4'0H)'(I.PH*("`@("`@("`O*B!);G9E<G0@
M=&AE('D@<V-A;&4N("HO"B`@("`@("`@)'D@/2`D=&AI<RT^:%!T("T@)'D[
M"B`@("`@("`@+RH@3&5N9W1H(&]F('1H92!"97II97(@8V]N=')O;"X@*B\*
M("`@("`@("`D8B`]("1R("H@,"XU-3(["@H@("`@("`@("\J($UO=F4@9G)O
M;2!T:&4@9VEV96X@;W)I9VEN(&%N9"!S970@=&AE(&-U<G)E;G0@<&]I;G0*
M("`@("`@("`@*B!T;R!T:&4@<W1A<G0@;V8@=&AE(&9I<G-T($)E>FEE<B!C
M=7)V92X@*B\*("`@("`@("`D8R`]('-P<FEN=&8H)R4N,F8@)2XR9B!M)RP@
M)'@@+2`D<BP@)'DI.PH@("`@("`@("1X(#T@)'@@+2`D<CL*("`@("`@("`O
M*B!&:7)S="!C:7)C;&4@<75A<G1E<BX@*B\*("`@("`@("`D8R`N/2!S<')I
M;G1F*"<@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@8R<L"B`@("`@
M("`@("`@("`@("`@("`@("`D>"P@)'D@*R`D8BP@("`@("`@("`@("\O($9I
M<G-T(&-O;G1R;VP@<&]I;G0N"B`@("`@("`@("`@("`@("`@("`@("`D>"`K
M("1R("T@)&(L("1Y("L@)'(L("\O(%-E8V]N9"!C;VYT<F]L('!O:6YT+@H@
M("`@("`@("`@("`@("`@("`@("`@)'@@*R`D<BP@)'D@*R`D<BD[("`@("`O
M+R!&:6YA;"!P;VEN="X*("`@("`@("`O*B!3970@>"]Y('1O('1H92!F:6YA
M;"!P;VEN="X@*B\*("`@("`@("`D>"`]("1X("L@)'(["B`@("`@("`@)'D@
M/2`D>2`K("1R.PH@("`@("`@("\J(%-E8V]N9"!C:7)C;&4@<75A<G1E<BX@
M*B\*("`@("`@("`D8R`N/2!S<')I;G1F*"<@)2XR9B`E+C)F("4N,F8@)2XR
M9B`E+C)F("4N,F8@8R<L"B`@("`@("`@("`@("`@("`@("`@("`D>"`K("1B
M+"`D>2P*("`@("`@("`@("`@("`@("`@("`@("1X("L@)'(L("1Y("T@)'(@
M*R`D8BP*("`@("`@("`@("`@("`@("`@("`@("1X("L@)'(L("1Y("T@)'(I
M.PH@("`@("`@("\J(%-E="!X+WD@=&\@=&AE(&9I;F%L('!O:6YT+B`J+PH@
M("`@("`@("1X(#T@)'@@*R`D<CL*("`@("`@("`D>2`]("1Y("T@)'(["B`@
M("`@("`@+RH@5&AI<F0@8VER8VQE('%U87)T97(N("HO"B`@("`@("`@)&,@
M+CT@<W!R:6YT9B@G("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F(&,G
M+`H@("`@("`@("`@("`@("`@("`@("`@)'@L("1Y("T@)&(L"B`@("`@("`@
M("`@("`@("`@("`@("`D>"`M("1R("L@)&(L("1Y("T@)'(L"B`@("`@("`@
M("`@("`@("`@("`@("`D>"`M("1R+"`D>2`M("1R*3L*("`@("`@("`O*B!3
M970@>"]Y('1O('1H92!F:6YA;"!P;VEN="X@*B\*("`@("`@("`D>"`]("1X
M("T@)'(["B`@("`@("`@)'D@/2`D>2`M("1R.PH@("`@("`@("\J($9O=7)T
M:"!C:7)C;&4@<75A<G1E<BX@*B\*("`@("`@("`D8R`N/2!S<')I;G1F*"<@
M)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@8R`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`D>"`M("1B+"`D>2P*("`@("`@("`@("`@("`@("`@
M("`@("1X("T@)'(L("1Y("L@)'(@+2`D8BP*("`@("`@("`@("`@("`@("`@
M("`@("1X("T@)'(L("1Y("L@)'(L"B`@("`@("`@("`@("`@("`@("`@("`D
M;W`I.PH@("`@("`@("\J($]U='!U="!T:&4@=VAO;&4@<W1R:6YG+B`J+PH@
M("`@("`@("1T:&ES+3Y?;W5T*"1C*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($EM<&]R=',@82!4<G5E5'EP92!O<B!4>7!E,2!F;VYT(&%N9"!M86ME<R!I
M="!A=F%I;&%B;&4N($ET(&ES"B`@("`@*B!N96-E<W-A<GD@=&\@9V5N97)A
M=&4@82!F;VYT(&1E9FEN:71I;VX@9FEL92!F:7)S="!W:71H('1H90H@("`@
M("H@;6%K969O;G0N<&AP('5T:6QI='DN"B`@("`@*B!4:&4@;&]C871I;VX@
M;V8@=&AE(&1E9FEN:71I;VX@9FEL92`H86YD('1H92!F;VYT(&9I;&4@:71S
M96QF('=H96X*("`@("`J(&5M8F5D9&EN9RD@;75S="!B92!F;W5N9"!A="!T
M:&4@9G5L;"!P871H(&YA;64@:6YC;'5D960N"B`@("`@*@H@("`@("H@17AA
M;7!L93H*("`@("`J("1P9&8M/F%D9$9O;G0H)T-O;6EC)RP@)TDG*3L*("`@
M("`J(&ES(&5Q=6EV86QE;G0@=&\Z"B`@("`@*B`D<&1F+3YA9&1&;VYT*"=#
M;VUI8R<L("=))RP@)V-O;6EC:2YP:'`G*3L*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F86UI;'D@($9O;G0@9F%M:6QY+B!4:&4@;F%M92!C86X@
M8F4@8VAO<V5N(&%R8FET<F%R:6QY+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!)9B!I="!I<R!A('-T86YD87)D(&9A;6EL>2!N86UE+"!I="!W
M:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&]V97)R:61E('1H
M92!C;W)R97-P;VYD:6YG(&9O;G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M='EL92`@($9O;G0@<W1Y;&4N(%!O<W-I8FQE('9A;'5E<R!A<F4@*&-A<V4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@:6YS96YS:71I=F4I.@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@96UP='D@<W1R:6YG
M.B!R96=U;&%R("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("T@0CH@8F]L9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("T@23H@:71A;&EC"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@+2!"22!O<B!)0CH@8F]L9"!I=&%L:6,*("`@("`J($!P87)A;2!S=')I
M;F<@)&9I;&4@("`@5&AE(&9O;G0@9&5F:6YI=&EO;B!F:6QE+B!">2!D969A
M=6QT+"!T:&4@;F%M92!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!B=6EL="!F<F]M('1H92!F86UI;'D@86YD('-T>6QE+"!I;B!L;W=E<B!C
M87-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('=I=&@@;F\@<W!A
M8V4N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1F]N=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1&;VYT*"1F86UI;'DL("1S='EL92`]("<G
M+"`D9FEL92`]("<G*0H@("`@>PH@("`@("`@("1F86UI;'D@/2!S=')T;VQO
M=V5R*"1F86UI;'DI.PH@("`@("`@(&EF("@D9F%M:6QY(#T]("=A<FEA;"<I
M('L*("`@("`@("`@("`@)&9A;6EL>2`]("=H96QV971I8V$G.PH@("`@("`@
M('T*"B`@("`@("`@)'-T>6QE(#T@<W1R=&]U<'!E<B@D<W1Y;&4I.PH@("`@
M("`@(&EF("@D<W1Y;&4@/3T@)TE")RD@>PH@("`@("`@("`@("`D<W1Y;&4@
M/2`G0DDG.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]F
M;VYT<ULD9F%M:6QY("X@)'-T>6QE72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)T9O;G0@86QR96%D>2!A9&1E
M9#H@)7,@)7,G+"`D9F%M:6QY+"`D<W1Y;&4I*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1F:6QE(#T]("<G*2!["B`@("`@("`@("`@("1F:6QE(#T@<W1R
M7W)E<&QA8V4H)R`G+"`G)RP@)&9A;6EL>2D@+B!S=')T;VQO=V5R*"1S='EL
M92D@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@(&EN8VQU9&4H)&9I;&4I
M.PH@("`@("`@(&EF("@A:7-S970H)&YA;64I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&EN8VQU9&4@9F]N
M="!D969I;FET:6]N(&9I;&4N)RD["B`@("`@("`@?0H@("`@("`@("1I(#T@
M8V]U;G0H)'1H:7,M/E]F;VYT<RD@*R`Q.PH@("`@("`@("1T:&ES+3Y?9F]N
M='-;)&9A;6EL>2`N("1S='EL95T@/2!A<G)A>2@G:2<@/3X@)&DL("=T>7!E
M)R`]/B`D='EP92P@)VYA;64G(#T^("1N86UE+"`G9&5S8R<@/3X@)&1E<V,L
M("=U<"<@/3X@)'5P+"`G=70G(#T^("1U="P@)V-W)R`]/B`D8W<L("=E;F,G
M(#T^("1E;F,L("=F:6QE)R`]/B`D9FEL92D["B`@("`@("`@:68@*"1D:69F
M*2!["B`@("`@("`@("`@("\J(%-E87)C:"!E>&ES=&EN9R!E;F-O9&EN9W,N
M("HO"B`@("`@("`@("`@("1D(#T@,#L*("`@("`@("`@("`@)&YB(#T@8V]U
M;G0H)'1H:7,M/E]D:69F<RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`Q.R`D
M:2`\/2`D;F([("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V1I9F9S6R1I72`]/2`D9&EF9BD@>PH@("`@("`@("`@("`@("`@("`@("1D
M(#T@)&D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D(#T](#`I
M('L*("`@("`@("`@("`@("`@("1D(#T@)&YB("L@,3L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&EF9G-;)&1=(#T@)&1I9F8["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]F;VYT<ULD9F%M:6QY+B1S='EL95U;)V1I
M9F8G72`]("1D.PH@("`@("`@('T*("`@("`@("!I9B`H)&9I;&4I('L*("`@
M("`@("`@("`@:68@*"1T>7!E(#T]("=4<G5E5'EP92<I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9F]N=%]F:6QE<ULD9FEL95T@/2!A<G)A>2@G;&5N
M9W1H,2<@/3X@)&]R:6=I;F%L<VEZ92D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O;G1?9FEL97-;)&9I;&5=(#T@
M87)R87DH)VQE;F=T:#$G(#T^("1S:7IE,2P@)VQE;F=T:#(G(#T^("1S:7IE
M,BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!F;VYT('5S960@=&\@<')I;G0@8VAA<F%C=&5R('-T
M<FEN9W,N($ET(&ES(&UA;F1A=&]R>2!T;R!C86QL"B`@("`@*B!T:&ES(&UE
M=&AO9"!A="!L96%S="!O;F-E(&)E9F]R92!P<FEN=&EN9R!T97AT(&]R('1H
M92!R97-U;'1I;F<*("`@("`J(&1O8W5M96YT('=O=6QD(&YO="!B92!V86QI
M9"X@5&AE(&9O;G0@8V%N(&)E(&5I=&AE<B!A('-T86YD87)D(&]N92!O<B!A
M"B`@("`@*B!F;VYT(&%D9&5D('9I82!T:&4@1FEL95]01$8Z.F%D9$9O;G0@
M;65T:&]D+B!3=&%N9&%R9"!F;VYT<R!U<V4@5VEN9&]W<PH@("`@("H@96YC
M;V1I;F<@8W`Q,C4R("A797-T97)N($5U<F]P92DN"B`@("`@*B!4:&4@;65T
M:&]D(&-A;B!B92!C86QL960@8F5F;W)E('1H92!F:7)S="!P86=E(&ES(&-R
M96%T960@86YD('1H92!F;VYT"B`@("`@*B!I<R!R971A:6YE9"!F<F]M('!A
M9V4@=&\@<&%G92X*("`@("`J($EF('EO=2!J=7-T('=I<V@@=&\@8VAA;F=E
M('1H92!C=7)R96YT(&9O;G0@<VEZ92P@:70@:7,@<VEM<&QE<B!T;R!C86QL
M"B`@("`@*B!&:6QE7U!$1CHZ<V5T1F]N=%-I>F4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F%M:6QY("!&86UI;'D@9F]N="X@270@8V%N(&)E
M(&5I=&AE<B!A(&YA;64@9&5F:6YE9"!B>0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!&:6QE7U!$1CHZ861D1F]N="!O<B!O;F4@;V8@=&AE('-T
M86YD87)D(&9A;6EL:65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("AC87-E(&EN<V5N<VET:79E*3H*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`M($-O=7)I97(@*&9I>&5D+7=I9'1H*0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("T@2&5L=F5T:6-A(&]R($%R:6%L("AS86YS
M('-E<FEF*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@5&EM
M97,@*'-E<FEF*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@
M4WEM8F]L("AS>6UB;VQI8RD*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`M(%IA<&9$:6YG8F%T<R`H<WEM8F]L:6,I"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@($ET(&ES(&%L<V\@<&]S<VEB;&4@=&\@<&%S<R!A
M;B!E;7!T>2!S=')I;F<N($EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@('1H870@8V%S92P@=&AE(&-U<G)E;G0@9F%M:6QY(&ES(')E=&%I;F5D
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1Y;&4@("!&;VYT('-T>6QE+B!0
M;W-S:6)L92!V86QU97,@87)E("AC87-E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(&EN<V5N<VET:79E*3H*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`M(&5M<'1Y('-T<FEN9SH@<F5G=6QA<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("T@0CH@8F]L9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("T@23H@:71A;&EC"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!5.B!U;F1E<FQI;F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@;W(@86YY(&-O;6)I;F%T:6]N+B!4:&4@9&5F
M875L="!V86QU92!I<R!R96=U;&%R+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!";VQD(&%N9"!I=&%L:6,@<W1Y;&5S(&1O(&YO="!A<'!L>2!T
M;R!3>6UB;VP@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%IA
M<&9$:6YG8F%T<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S:7IE("`@1F]N
M="!S:7IE(&EN('!O:6YT<RX@5&AE(&1E9F%U;'0@=F%L=64@:7,@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-U<G)E;G0@<VEZ92X@268@
M;F\@<VEZ92!H87,@8F5E;B!S<&5C:69I960@<VEN8V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9&]C=6UE
M;G0L('1H92!V86QU92!T86ME;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!I<R`Q,BX*("`@("`J($!P87)A;2!B;V]L96%N("1F;W)C92`@1F]R
M8V4@=&AE('-E='1I;F<@;V8@=&AE(&9O;G0N($5A8V@@;F5W('!A9V4@=VEL
M;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E(&$@;F5W
M(&-A;&P@=&\@1FEL95]01$8Z.G-E=$9O;G0@86YD"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@('-E='1I;F=S('1H:7,@=&\@=')U92!W:6QL(&UA
M:V4@<W5R92!T:&%T('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!C:&5C:W,@9F]R('-A;64@9F]N="!C86QL<R!W:6QL(&)E('-K:7!P960N
M"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D1F]N=`H@("`@("H@
M0'-E92!&:6QE7U!$1CHZ<V5T1F]N=%-I>F4*("`@("`J($!S964@1FEL95]0
M1$8Z.F-E;&P*("`@("`J($!S964@1FEL95]01$8Z.FUU;'1I0V5L;`H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ5W)I=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1F]N="@D9F%M:6QY+"`D<W1Y;&4@/2`G)RP@)'-I>F4@/2!N=6QL+"`D
M9F]R8V4@/2!F86QS92D*("`@('L*("`@("`@("`D9F%M:6QY(#T@<W1R=&]L
M;W=E<B@D9F%M:6QY*3L*("`@("`@("!I9B`H)&9A;6EL>2`]/2`G87)I86PG
M*2!["B`@("`@("`@("`@("\J(%5S92!H96QV971I8V$@:6YS=&5A9"!O9B!A
M<FEA;"X@*B\*("`@("`@("`@("`@)&9A;6EL>2`]("=H96QV971I8V$G.PH@
M("`@("`@('T@96QS96EF("@D9F%M:6QY(#T]("=S>6UB;VPG('Q\("1F86UI
M;'D@/3T@)WIA<&9D:6YG8F%T<R<I('L*("`@("`@("`@("`@+RH@5&AE<V4@
M='=O(&9O;G1S(&1O(&YO="!H879E('-T>6QE<R!A=F%I;&%B;&4N("HO"B`@
M("`@("`@("`@("1S='EL92`]("<G.PH@("`@("`@('T*"B`@("`@("`@)'-T
M>6QE(#T@<W1R=&]U<'!E<B@D<W1Y;&4I.PH*("`@("`@("`O*B!5;F1E<FQI
M;F4@:7,@:&%N9&QE9"!S97!A<F%T96QY+"!I9B!S<&5C:69I960@:6X@=&AE
M('-T>6QE('9A<@H@("`@("`@("`J(')E;6]V92!I="!F<F]M('1H92!S='EL
M92!A;F0@<V5T('1H92!U;F1E<FQI;F4@9FQA9RX@*B\*("`@("`@("!I9B`H
M<W1R<&]S*"1S='EL92P@)U4G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M)'1H:7,M/E]U;F1E<FQI;F4@/2!T<G5E.PH@("`@("`@("`@("`D<W1Y;&4@
M/2!S=')?<F5P;&%C92@G52<L("<G+"`D<W1Y;&4I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?=6YD97)L:6YE(#T@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'-T>6QE(#T]("=)0B<I('L*("`@("`@
M("`@("`@)'-T>6QE(#T@)T)))SL*("`@("`@("!]"@H@("`@("`@("\J($EF
M(&YO('-I>F4@<W!E8VEF:65D+"!U<V4@8W5R<F5N="!S:7IE+B`J+PH@("`@
M("`@(&EF("AI<U]N=6QL*"1S:7IE*2D@>PH@("`@("`@("`@("`D<VEZ92`]
M("1T:&ES+3Y?9F]N=%]S:7IE7W!T.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@9F]N="!R97%U97-T960@:7,@86QR96%D>2!T:&4@8W5R<F5N="!F;VYT
M(&%N9"!N;R!F;W)C92!S971T:6YG"B`@("`@("`@("H@;V8@=&AE(&9O;G0@
M:7,@<F5Q=65S=&5D("AE9RX@=VAE;B!A9&1I;F<@82!N97<@<&%G92D@9&]N
M)W0@8F]T:&5R"B`@("`@("`@("H@=VET:"!T:&4@<F5S="!O9B!T:&4@9G5N
M8W1I;VX@86YD('-I;7!L>2!R971U<FXN("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?9F]N=%]F86UI;'D@/3T@)&9A;6EL>2`F)B`D=&AI<RT^7V9O;G1?<W1Y
M;&4@/3T@)'-T>6QE("8F"B`@("`@("`@("`@("1T:&ES+3Y?9F]N=%]S:7IE
M7W!T(#T]("1S:7IE("8F("$D9F]R8V4I('L*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('1H92!F;VYT(&ME>2X@*B\*
M("`@("`@("`D9F]N=&ME>2`]("1F86UI;'D@+B`D<W1Y;&4["@H@("`@("`@
M("\J(%1E<W0@:68@86QR96%D>2!C86-H960N("HO"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V9O;G1S6R1F;VYT:V5Y72DI('L*("`@("`@("`@("`@
M+RH@1V5T('1H92!C:&%R86-T97(@=VED=&@@9&5F:6YI=&EO;B!F:6QE+B`J
M+PH@("`@("`@("`@("`D9F]N=%]W:61T:',@/2`F1FEL95]01$8Z.E]G971&
M;VYT1FEL92@D9F]N=&ME>2D["B`@("`@("`@("`@(&EF("AI<U]A*"1F;VYT
M7W=I9'1H<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1F;VYT7W=I9'1H<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&D@/2!C;W5N="@D=&AI<RT^7V9O;G1S*2`K(#$["B`@("`@("`@("`@("1T
M:&ES+3Y?9F]N='-;)&9O;G1K97E=(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`G:2<@("`@/3X@)&DL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)V-O
M<F4G+`H@("`@("`@("`@("`@("`@)VYA;64G(#T^("1T:&ES+3Y?8V]R95]F
M;VYT<ULD9F]N=&ME>5TL"B`@("`@("`@("`@("`@("`G=7`G("`@/3X@+3$P
M,"P*("`@("`@("`@("`@("`@("=U="<@("`]/B`U,"P*("`@("`@("`@("`@
M("`@("=C=R<@("`]/B`D9F]N=%]W:61T:'-;)&9O;G1K97E=*3L*("`@("`@
M("!]"@H@("`@("`@("\J(%-T;W)E(&9O;G0@:6YF;W)M871I;VX@87,@8W5R
M<F5N="!F;VYT+B`J+PH@("`@("`@("1T:&ES+3Y?9F]N=%]F86UI;'D@(#T@
M)&9A;6EL>3L*("`@("`@("`D=&AI<RT^7V9O;G1?<W1Y;&4@("`]("1S='EL
M93L*("`@("`@("`D=&AI<RT^7V9O;G1?<VEZ95]P="`]("1S:7IE.PH@("`@
M("`@("1T:&ES+3Y?9F]N=%]S:7IE("`@(#T@)'-I>F4@+R`D=&AI<RT^7W-C
M86QE.PH@("`@("`@("1T:&ES+3Y?8W5R<F5N=%]F;VYT(#T@)B1T:&ES+3Y?
M9F]N='-;)&9O;G1K97E=.PH*("`@("`@("`O*B!/=71P=70@9F]N="!I;F9O
M<FUA=&EO;B!I9B!A="!L96%S="!O;F4@<&%G92!H87,@8F5E;B!D969I;F5D
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A9V4@/B`P*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)T)4("]&)60@)2XR9B!49B!%5"<L
M("1T:&ES+3Y?8W5R<F5N=%]F;VYT6R=I)UTL("1T:&ES+3Y?9F]N=%]S:7IE
M7W!T*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE
M<R!T:&4@<VEZ92!O9B!T:&4@8W5R<F5N="!F;VYT+@H@("`@("H*("`@("`J
M($!P87)A;2!F;&]A="`D<VEZ92`@5&AE('-I>F4@*&EN('!O:6YT<RDN"B`@
M("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1F]N=`H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971&;VYT4VEZ92@D<VEZ92D*("`@('L*("`@("`@("`O
M*B!)9B!T:&4@9F]N="!S:7IE(&ES(&%L<F5A9'D@=&AE(&-U<G)E;G0@9F]N
M="!S:7IE+"!J=7-T(')E='5R;BX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]F
M;VYT7W-I>F5?<'0@/3T@)'-I>F4I('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*("`@("`@("`O*B!3970@=&AE(&-U<G)E;G0@9F]N="!S:7IE
M+"!B;W1H(&EN('!O:6YT<R!A;F0@<V-A;&5D('1O('5S97(*("`@("`@("`@
M*B!U;FET<RX@*B\*("`@("`@("`D=&AI<RT^7V9O;G1?<VEZ95]P="`]("1S
M:7IE.PH@("`@("`@("1T:&ES+3Y?9F]N=%]S:7IE(#T@)'-I>F4@+R`D=&AI
M<RT^7W-C86QE.PH*("`@("`@("`O*B!/=71P=70@9F]N="!I;F9O<FUA=&EO
M;B!I9B!A="!L96%S="!O;F4@<&%G92!H87,@8F5E;B!D969I;F5D+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7W!A9V4@/B`P*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;W5T*'-P<FEN=&8H)T)4("]&)60@)2XR9B!49B!%5"<L("1T:&ES
M+3Y?8W5R<F5N=%]F;VYT6R=I)UTL("1T:&ES+3Y?9F]N=%]S:7IE7W!T*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE
M=R!I;G1E<FYA;"!L:6YK(&%N9"!R971U<FYS(&ET<R!I9&5N=&EF:65R+B!!
M;B!I;G1E<FYA;`H@("`@("H@;&EN:R!I<R!A(&-L:6-K86)L92!A<F5A('=H
M:6-H(&1I<F5C=',@=&\@86YO=&AE<B!P;&%C92!W:71H:6X@=&AE"B`@("`@
M*B!D;V-U;65N="X*("`@("`J(%1H92!I9&5N=&EF:65R(&-A;B!T:&5N(&)E
M('!A<W-E9"!T;R!&:6QE7U!$1CHZ8V5L;"P@1FEL95]01$8Z.G=R:71E+`H@
M("`@("H@1FEL95]01$8Z.FEM86=E(&]R($9I;&5?4$1&.CIL:6YK+B!4:&4@
M9&5S=&EN871I;VX@:7,@9&5F:6YE9"!W:71H"B`@("`@*B!&:6QE7U!$1CHZ
M<V5T3&EN:RX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC96QL"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CI7<FET90H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ:6UA9V4*("`@("`J($!S964@1FEL95]01$8Z.DQI;FL*("`@("`J($!S
M964@1FEL95]01$8Z.E-E=$QI;FL*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M3&EN:R@I"B`@("!["B`@("`@("`@)&X@/2!C;W5N="@D=&AI<RT^7VQI;FMS
M*2`K(#$["B`@("`@("`@)'1H:7,M/E]L:6YK<ULD;ET@/2!A<G)A>2@P+"`P
M*3L*("`@("`@("!R971U<FX@)&X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M969I;F5S('1H92!P86=E(&%N9"!P;W-I=&EO;B!A(&QI;FL@<&]I;G1S('1O
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YK("!4:&4@;&EN
M:R!I9&5N=&EF:65R(')E='5R;F5D(&)Y($9I;&5?4$1&.CIA9&1,:6YK+@H@
M("`@("H@0'!A<F%M(&9L;V%T("1Y("`@("`@($]R9&EN871E(&]F('1A<F=E
M="!P;W-I=&EO;CL@+3$@:6YD:6-A=&5S('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&-U<G)E;G0@<&]S:71I;VXN(%1H92!D969A=6QT('9A
M;'5E(&ES(#`@*'1O<"!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('!A9V4I+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!A9V4@($YU;6)E<B!O
M9B!T87)G970@<&%G93L@+3$@:6YD:6-A=&5S('1H92!C=7)R96YT"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@<&%G92X@5&AI<R!I<R!T:&4@9&5F
M875L="!V86QU92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&1,
M:6YK"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$QI;FLH)&QI;FLL("1Y(#T@
M,"P@)'!A9V4@/2`M,2D*("`@('L*("`@("`@("!I9B`H)'D@/3T@+3$I('L*
M("`@("`@("`@("`@)'D@/2`D=&AI<RT^>3L*("`@("`@("!]"B`@("`@("`@
M:68@*"1P86=E(#T]("TQ*2!["B`@("`@("`@("`@("1P86=E(#T@)'1H:7,M
M/E]P86=E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VQI;FMS6R1L:6YK
M72`](&%R<F%Y*"1P86=E+"`D>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M=71S(&$@;&EN:R!O;B!A(')E8W1A;F=U;&%R(&%R96$@;V8@=&AE('!A9V4N
M(%1E>'0@;W(@:6UA9V4@;&EN:W,@87)E"B`@("`@*B!G96YE<F%L;'D@<'5T
M('9I82!&:6QE7U!$1CHZ8V5L;"P@1FEL95]01$8Z.E=R:71E(&]R($9I;&5?
M4$1&.CII;6%G92P*("`@("`J(&)U="!T:&ES(&UE=&AO9"!C86X@8F4@=7-E
M9G5L(&9O<B!I;G-T86YC92!T;R!D969I;F4@82!C;&EC:V%B;&4@87)E80H@
M("`@("H@:6YS:61E(&%N(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!F
M;&]A="`D>"`@("`@("!!8G-C:7-S82!O9B!T:&4@=7!P97(M;&5F="!C;W)N
M97(@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!F;&]A="`D>2`@
M("`@("!/<F1I;F%T92!O9B!T:&4@=7!P97(M;&5F="!C;W)N97(@;V8@=&AE
M(')E8W1A;F=L92X*("`@("`J($!P87)A;2!F;&]A="`D=VED=&@@("!7:61T
M:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&9L;V%T("1H96EG
M:'0@($AE:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1L:6YK("`@(%523"!O<B!I9&5N=&EF:65R(')E='5R;F5D(&)Y($9I
M;&5?4$1&.CIA9&1,:6YK+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z
M.F%D9$QI;FL*("`@("`J($!S964@1FEL95]01$8Z.F-E;&P*("`@("`J($!S
M964@1FEL95]01$8Z.E=R:71E"B`@("`@*B!`<V5E($9I;&5?4$1&.CII;6%G
M90H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YK*"1X+"`D>2P@)'=I9'1H+"`D
M:&5I9VAT+"`D;&EN:RD*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE(&-O
M;W)D:6YA=&5S('=I=&@@8V]R<F5C="!S8V%L:6YG(&EN('!T+B`J+PH@("`@
M("`@("1X("`@("`@/2`D=&AI<RT^7W1O4'0H)'@I.PH@("`@("`@("1Y("`@
M("`@/2`D=&AI<RT^:%!T("T@)'1H:7,M/E]T;U!T*"1Y*3L*("`@("`@("`D
M=VED=&@@(#T@)'1H:7,M/E]T;U!T*"1W:61T:"D["B`@("`@("`@)&AE:6=H
M="`]("1T:&ES+3Y?=&]0="@D:&5I9VAT*3L*"B`@("`@("`@+RH@4V%V92!L
M:6YK('1O('!A9V4@;&EN:W,@87)R87DN("HO"B`@("`@("`@)'1H:7,M/E]L
M:6YK*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D;&EN:RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!0<FEN=',@82!C:&%R86-T97(@<W1R:6YG+B!4:&4@
M;W)I9VEN(&ES(&]N('1H92!L969T(&]F('1H92!F:7)S=`H@("`@("H@8VAA
M<F%C=&5R+"!O;B!T:&4@8F%S96QI;F4N(%1H:7,@;65T:&]D(&%L;&]W<R!T
M;R!P;&%C92!A('-T<FEN9PH@("`@("H@<')E8VES96QY(&]N('1H92!P86=E
M+"!B=70@:70@:7,@=7-U86QL>2!E87-I97(@=&\@=7-E($9I;&5?4$1&.CIC
M96QL+`H@("`@("H@1FEL95]01$8Z.FUU;'1I0V5L;"!O<B!&:6QE7U!$1CHZ
M5W)I=&4@=VAI8V@@87)E('1H92!S=&%N9&%R9"!M971H;V1S('1O"B`@("`@
M*B!P<FEN="!T97AT+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D>"`@
M("`@($%B<V-I<W-A(&]F('1H92!O<FEG:6XN"B`@("`@*B!`<&%R86T@9FQO
M870@)'D@("`@("!/<F1I;F%T92!O9B!T:&4@;W)I9VEN+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@4W1R:6YG('1O('!R:6YT+@H@("`@("H*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J($!S964@1FEL95]0
M1$8Z.F-E;&P*("`@("`J($!S964@1FEL95]01$8Z.FUU;'1I0V5L;`H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ5W)I=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M=&5X="@D>"P@)'DL("1T97AT*0H@("`@>PH@("`@("`@("\J(%-C86QE(&-O
M;W)D:6YA=&5S(&EN=&\@<&]I;G1S(&%N9"!S970@8V]R<F5C="!9('!O<VET
M:6]N+B`J+PH@("`@("`@("1X(#T@)'1H:7,M/E]T;U!T*"1X*3L*("`@("`@
M("`D>2`]("1T:&ES+3YH4'0@+2`D=&AI<RT^7W1O4'0H)'DI.PH*("`@("`@
M("`O*B!%<V-A<&4@86YY('!O=&5N=&EA;&QY(&AA<FUF=6P@8VAA<F%C=&5R
M<RX@*B\*("`@("`@("`D=&5X="`]("1T:&ES+3Y?97-C87!E*"1T97AT*3L*
M"B`@("`@("`@)&]U="`]('-P<FEN=&8H)T)4("4N,F8@)2XR9B!49"`H)7,I
M(%1J($54)RP@)'@L("1Y+"`D=&5X="D["B`@("`@("`@:68@*"1T:&ES+3Y?
M=6YD97)L:6YE("8F("1T97AT("$]("<G*2!["B`@("`@("`@("`@("1O=70@
M+CT@)R`G("X@)'1H:7,M/E]D;U5N9&5R;&EN92@D>"P@)'DL("1T97AT*3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]O=70H)&]U="D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!7:&5N979E<B!A('!A9V4@8G)E86L@8V]N9&ET:6]N
M(&ES(&UE="P@=&AE(&UE=&AO9"!I<R!C86QL960L(&%N9"!T:&4*("`@("`J
M(&)R96%K(&ES(&ES<W5E9"!O<B!N;W0@9&5P96YD:6YG(&]N('1H92!R971U
M<FYE9"!V86QU92X@5&AE(&1E9F%U;'0*("`@("`J(&EM<&QE;65N=&%T:6]N
M(')E='5R;G,@82!V86QU92!A8V-O<F1I;F<@=&\@=&AE(&UO9&4@<V5L96-T
M960@8GD*("`@("`J($9I;&5?4$1&.G-E=$%U=&]086=E0G)E86LN"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!C86QL960@875T;VUA=&EC86QL>2!A;F0@<VAO
M=6QD(&YO="!B92!C86QL960@9&ER96-T;'D*("`@("`J(&)Y('1H92!A<'!L
M:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971!=71O4&%G94)R96%K+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A8V-E<'1086=E0G)E86LH*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V%U=&]?<&%G95]B<F5A:SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%!R:6YT<R!A(&-E;&P@*')E8W1A;F=U;&%R(&%R96$I
M('=I=&@@;W!T:6]N86P@8F]R9&5R<RP@8F%C:V=R;W5N9`H@("`@("H@8V]L
M;W(@86YD(&-H87)A8W1E<B!S=')I;F<N(%1H92!U<'!E<BUL969T(&-O<FYE
M<B!O9B!T:&4@8V5L;`H@("`@("H@8V]R<F5S<&]N9',@=&\@=&AE(&-U<G)E
M;G0@<&]S:71I;VXN(%1H92!T97AT(&-A;B!B92!A;&EG;F5D(&]R"B`@("`@
M*B!C96YT97)E9"X@069T97(@=&AE(&-A;&PL('1H92!C=7)R96YT('!O<VET
M:6]N(&UO=F5S('1O('1H92!R:6=H="!O<B!T;PH@("`@("H@=&AE(&YE>'0@
M;&EN92X@270@:7,@<&]S<VEB;&4@=&\@<'5T(&$@;&EN:R!O;B!T:&4@=&5X
M="X*("`@("`J($EF(&%U=&]M871I8R!P86=E(&)R96%K:6YG(&ES(&5N86)L
M960@86YD('1H92!C96QL(&=O97,@8F5Y;VYD('1H90H@("`@("H@;&EM:70L
M(&$@<&%G92!B<F5A:R!I<R!D;VYE(&)E9F]R92!O=71P=71T:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!F;&]A="`D=VED=&@@("!#96QL('=I9'1H+B!)
M9B`P+"!T:&4@8V5L;"!E>'1E;F1S('5P('1O('1H92!R:6=H=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&UA<F=I;BX*("`@("`J($!P87)A;2!F
M;&]A="`D:&5I9VAT("!#96QL(&AE:6=H="X@1&5F875L="!V86QU93H@,"X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!3=')I;F<@=&\@<')I;G0N
M($1E9F%U;'0@=F%L=64Z(&5M<'1Y+@H@("`@("H@0'!A<F%M(&UI>&5D("1B
M;W)D97(@($EN9&EC871E<R!I9B!B;W)D97)S(&UU<W0@8F4@9')A=VX@87)O
M=6YD('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-E;&PN(%1H
M92!V86QU92!C86X@8F4@96ET:&5R(&$@;G5M8F5R.@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2`P.B!N;R!B;W)D97(@*&1E9F%U;'0I"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#$Z(&9R86UE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@;W(@82!S=')I;F<@8V]N=&%I;FEN
M9R!S;VUE(&]R(&%L;"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!F;VQL;W=I;F<@8VAA<F%C=&5R<R`H:6X@86YY(&]R9&5R*3H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@3#H@;&5F=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@+2!4.B!T;W`*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("T@4CH@<FEG:'0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("T@0CH@8F]T=&]M"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D;&X@("`@26YD:6-A=&5S('=H97)E('1H92!C=7)R96YT('!O<VET
M:6]N('-H;W5L9"!G;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&%F
M=&5R('1H92!C86QL+B!0;W-S:6)L92!V86QU97,@87)E.@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2`P.B!T;R!T:&4@<FEG:'0@*&1E9F%U
M;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#$Z('1O('1H
M92!B96=I;FYI;F<@;V8@=&AE(&YE>'0@;&EN90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@+2`R.B!B96QO=PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(%!U='1I;F<@,2!I<R!E<75I=F%L96YT('1O('!U='1I;F<@
M,"!A;F0@8V%L;&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@($9I
M;&5?4$1&.CIN97=,:6YE(&IU<W0@869T97(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A;&EG;B`@06QL;W=S('1O(&-E;G1E<B!O<B!A;&EG;B!T:&4@=&5X
M="X@4&]S<VEB;&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!V86QU
M97,@87)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!,(&]R
M(&5M<'1Y('-T<FEN9SH@;&5F="`H9&5F875L="D*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("T@0SH@8V5N=&5R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`M(%(Z(')I9VAT"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9FEL;"`@26YD:6-A=&5S(&EF('1H92!C96QL(&9I;&P@='EP92X@4&]S
M<VEB;&4@=F%L=65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@87)E
M.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`P.B!T<F%N<W!A
M<F5N="`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("T@,3H@<&%I;G1E9`H@("`@("H@0'!A<F%M('-T<FEN9R`D;&EN:R`@(%52
M3"!O<B!I9&5N=&EF:65R(')E='5R;F5D(&)Y"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1FEL95]01$8Z861D3&EN:RX*("`@("`J
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIS971$<F%W0V]L;W(*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=$9I;&Q#;VQO<@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T3&EN95=I9'1H
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&1,:6YK"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIN97=,:6YE"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E
M;&P*("`@("`J($!S964@1FEL95]01$8Z.E=R:71E"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIS971!=71O4&%G94)R96%K"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-E;&PH)'=I9'1H+"`D:&5I9VAT(#T@,"P@)'1E>'0@/2`G)RP@)&)O<F1E
M<B`](#`L("1L;B`](#`L("1A;&EG;B`]("<G+"`D9FEL;"`](#`L("1L:6YK
M(#T@)R<I"B`@("!["B`@("`@("`@)&L@/2`D=&AI<RT^7W-C86QE.PH@("`@
M("`@(&EF("@D=&AI<RT^>2`K("1H96EG:'0@/B`D=&AI<RT^7W!A9V5?8G)E
M86M?=')I9V=E<B`F)B`A)'1H:7,M/E]I;E]F;V]T97(@)B8@)'1H:7,M/D%C
M8V5P=%!A9V5"<F5A:R@I*2!["B`@("`@("`@("`@("1X(#T@)'1H:7,M/G@[
M"B`@("`@("`@("`@("1W<R`]("1T:&ES+3Y?=V]R9%]S<&%C:6YG.PH@("`@
M("`@("`@("!I9B`H)'=S(#X@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]W;W)D7W-P86-I;F<@/2`P.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)S`@5'<G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M861D4&%G92@D=&AI<RT^7V-U<G)E;G1?;W)I96YT871I;VXI.PH@("`@("`@
M("`@("`D=&AI<RT^>"`]("1X.PH@("`@("`@("`@("!I9B`H)'=S(#X@,"D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]W;W)D7W-P86-I;F<@/2`D=W,[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F*"<E+C-F(%1W
M)RP@)'=S("H@)&LI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H)'=I9'1H(#T](#`I('L*("`@("`@("`@("`@)'=I9'1H(#T@)'1H
M:7,M/G<@+2`D=&AI<RT^7W)I9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@
M("`@('T*("`@("`@("`D<R`]("<G.PH@("`@("`@(&EF("@D9FEL;"`]/2`Q
M('Q\("1B;W)D97(@/3T@,2D@>PH@("`@("`@("`@("!I9B`H)&9I;&P@/3T@
M,2D@>PH@("`@("`@("`@("`@("`@)&]P(#T@*"1B;W)D97(@/3T@,2D@/R`G
M0B<@.B`G9B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;W`@/2`G4R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)',@/2!S
M<')I;G1F*"<E+C)F("4N,F8@)2XR9B`E+C)F(')E("5S("<L("1T:&ES+3YX
M("H@)&LL("@D=&AI<RT^:"`M("1T:&ES+3YY*2`J("1K+"`D=VED=&@@*B`D
M:RP@+21H96EG:'0@*B`D:RP@)&]P*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES7W-T<FEN9R@D8F]R9&5R*2D@>PH@("`@("`@("`@("!I9B`H<W1R<&]S
M*"1B;W)D97(L("=,)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M<R`N/2!S<')I;G1F*"<E+C)F("4N,F8@;2`E+C)F("4N,F8@;"!3("<L("1T
M:&ES+3YX("H@)&LL("@D=&AI<RT^:"`M("1T:&ES+3YY*2`J("1K+"`D=&AI
M<RT^>"`J("1K+"`H)'1H:7,M/F@@+2`H)'1H:7,M/GD@*R`D:&5I9VAT*2D@
M*B`D:RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*'-T<G!O<R@D
M8F]R9&5R+"`G5"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)',@
M+CT@<W!R:6YT9B@G)2XR9B`E+C)F(&T@)2XR9B`E+C)F(&P@4R`G+"`D=&AI
M<RT^>"`J("1K+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@*B`D:RP@*"1T:&ES
M+3YX("L@)'=I9'1H*2`J("1K+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@*B`D
M:RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*'-T<G!O<R@D8F]R
M9&5R+"`G4B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)',@+CT@
M<W!R:6YT9B@G)2XR9B`E+C)F(&T@)2XR9B`E+C)F(&P@4R`G+"`H)'1H:7,M
M/G@@*R`D=VED=&@I("H@)&LL("@D=&AI<RT^:"`M("1T:&ES+3YY*2`J("1K
M+"`H)'1H:7,M/G@@*R`D=VED=&@I("H@)&LL("@D=&AI<RT^:"`M("@D=&AI
M<RT^>2`K("1H96EG:'0I*2`J("1K*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1B;W)D97(L("=")RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`D<R`N/2!S<')I;G1F*"<E+C)F("4N,F8@;2`E+C)F
M("4N,F8@;"!3("<L("1T:&ES+3YX("H@)&LL("@D=&AI<RT^:"`M("@D=&AI
M<RT^>2`K("1H96EG:'0I*2`J("1K+"`H)'1H:7,M/G@@*R`D=VED=&@I("H@
M)&LL("@D=&AI<RT^:"`M("@D=&AI<RT^>2`K("1H96EG:'0I*2`J("1K*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1E>'0@(3T@
M)R<I('L*("`@("`@("`@("`@:68@*"1A;&EG;B`]/2`G4B<I('L*("`@("`@
M("`@("`@("`@("1D>"`]("1W:61T:"`M("1T:&ES+3Y?8V5L;%]M87)G:6X@
M+2`D=&AI<RT^9V5T4W1R:6YG5VED=&@H)'1E>'0I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)&%L:6=N(#T]("=#)RD@>PH@("`@("`@("`@("`@("`@)&1X
M(#T@*"1W:61T:"`M("1T:&ES+3YG9713=')I;F=7:61T:"@D=&5X="DI("\@
M,CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D>"`]
M("1T:&ES+3Y?8V5L;%]M87)G:6X["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1E>'0@/2!S=')?<F5P;&%C92@G*2<L("=<7"DG+"!S=')?<F5P;&%C
M92@G*"<L("=<7"@G+"!S=')?<F5P;&%C92@G7%PG+"`G7%Q<7"<L("1T97AT
M*2DI.PH@("`@("`@("`@("`D=&5S=#(@/2`H*"XU("H@)&AE:6=H="D@*R`H
M+C,@*B`D=&AI<RT^7V9O;G1?<VEZ92DI.PH@("`@("`@("`@("`D=&5S=#$@
M/2`D=&AI<RT^9FA0="`M("@H)'1H:7,M/GD@*R`D=&5S=#(I("H@)&LI.PH@
M("`@("`@("`@("`D<R`N/2!S<')I;G1F*"="5"`E+C)F("4N,F8@5&0@*"5S
M*2!4:B!%5"<L("@D=&AI<RT^>"`K("1D>"D@*B`D:RP@*"1T:&ES+3YH("T@
M*"1T:&ES+3YY("L@+C4@*B`D:&5I9VAT("L@+C,@*B`D=&AI<RT^7V9O;G1?
M<VEZ92DI("H@)&LL("1T97AT*3L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M=6YD97)L:6YE*2!["B`@("`@("`@("`@("`@("`D<R`N/2`G("<@+B`D=&AI
M<RT^7V1O56YD97)L:6YE*"1T:&ES+3YX("L@)&1X+"`D=&AI<RT^>2`K("XU
M("H@)&AE:6=H="`K("XS("H@)'1H:7,M/E]F;VYT7W-I>F4L("1T97AT*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&QI;FLI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YL:6YK*"1T:&ES+3YX("L@)&1X+"`D=&AI<RT^
M>2`K("XU("H@)&AE:6=H="TN-2`J("1T:&ES+3Y?9F]N=%]S:7IE+"`D=&AI
M<RT^9V5T4W1R:6YG5VED=&@H)'1E>'0I+"`D=&AI<RT^7V9O;G1?<VEZ92P@
M)&QI;FLI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D
M<RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@D<RD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?;&%S=%]H96EG:'0@/2`D:&5I9VAT.PH@("`@("`@
M(&EF("@D;&X@/B`P*2!["B`@("`@("`@("`@("\J($=O('1O(&YE>'0@;&EN
M92X@*B\*("`@("`@("`@("`@)'1H:7,M/GD@*ST@)&AE:6=H=#L*("`@("`@
M("`@("`@:68@*"1L;B`]/2`Q*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^>"`K/2`D=VED=&@["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@86QL
M;W=S('!R:6YT:6YG('1E>'0@=VET:"!L:6YE(&)R96%K<RX@5&AE>2!C86X@
M8F4*("`@("`J(&%U=&]M871I8R`H87,@<V]O;B!A<R!T:&4@=&5X="!R96%C
M:&5S('1H92!R:6=H="!B;W)D97(@;V8@=&AE(&-E;&PI(&]R"B`@("`@*B!E
M>'!L:6-I="`H=FEA('1H92!<;B!C:&%R86-T97(I+B!!<R!M86YY(&-E;&QS
M(&%S(&YE8V5S<V%R>2!A<F4@;W5T<'5T+`H@("`@("H@;VYE(&)E;&]W('1H
M92!O=&AE<BX*("`@("`J(%1E>'0@8V%N(&)E(&%L:6=N960L(&-E;G1E<F5D
M(&]R(&IU<W1I9FEE9"X@5&AE(&-E;&P@8FQO8VL@8V%N(&)E"B`@("`@*B!F
M<F%M960@86YD('1H92!B86-K9W)O=6YD('!A:6YT960N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&9L;V%T("1W:61T:"`@(%=I9'1H(&]F(&-E;&QS+B!)9B`P
M+"!T:&5Y(&5X=&5N9"!U<"!T;R!T:&4@<FEG:'0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!M87)G:6X@;V8@=&AE('!A9V4N"B`@("`@*B!`<&%R
M86T@9FQO870@)&AE:6=H="`@2&5I9VAT(&]F(&-E;&QS+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@(%-T<FEN9R!T;R!P<FEN="X*("`@("`J($!P
M87)A;2!M:7AE9"`D8F]R9&5R("!);F1I8V%T97,@:68@8F]R9&5R<R!M=7-T
M(&)E(&1R87=N(&%R;W5N9"!T:&4@8V5L;`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&)L;V-K+B!4:&4@=F%L=64@8V%N(&)E(&5I=&AE<B!A(&YU
M;6)E<CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@,#H@;F\@
M8F]R9&5R("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@+2`Q.B!F<F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]R
M(&$@<W1R:6YG(&-O;G1A:6YI;F<@<V]M92!O<B!A;&P@;V8@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9F]L;&]W:6YG(&-H87)A8W1E<G,@
M*&EN(&%N>2!O<F1E<BDZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@+2!,.B!L969T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!4.B!T;W`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M(%(Z
M(')I9VAT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!".B!B
M;W1T;VT*("`@("`J($!P87)A;2!S=')I;F<@)&%L:6=N("!3971S('1H92!T
M97AT(&%L:6=N;65N="X@4&]S<VEB;&4@=F%L=65S(&%R93H*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@3#H@;&5F="!A;&EG;FUE;G0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@0SH@8V5N=&5R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M(%(Z(')I9VAT(&%L:6=N;65N
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!*.B!J=7-T:69I
M8V%T:6]N("AD969A=6QT('9A;'5E*0H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&9I;&P@($EN9&EC871E<R!I9B!T:&4@8V5L;"!B86-K9W)O=6YD(&UU<W0Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#`Z('1R86YS<&%R
M96YT("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M+2`Q.B!P86EN=&5D"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T
M1F]N=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1')A=T-O;&]R"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS971&:6QL0V]L;W(*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=$QI;F57:61T:`H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L
M;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ=W)I=&4*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=$%U=&]086=E0G)E86L*("`@("`J+PH@("`@9G5N8W1I;VX@
M;75L=&E#96QL*"1W:61T:"P@)&AE:6=H="P@)'1E>'0L("1B;W)D97(@/2`P
M+"`D86QI9VX@/2`G2B<L("1F:6QL(#T@,"D*("`@('L*("`@("`@("`D8W<@
M/2`F)'1H:7,M/E]C=7)R96YT7V9O;G1;)V-W)UT["B`@("`@("`@:68@*"1W
M:61T:"`]/2`P*2!["B`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YW("T@
M)'1H:7,M/E]R:6=H=%]M87)G:6X@+2`D=&AI<RT^>#L*("`@("`@("!]"B`@
M("`@("`@)'=M87@@/2`H)'=I9'1H+3(@*B`D=&AI<RT^7V-E;&Q?;6%R9VEN
M*2`J(#$P,#`@+R`D=&AI<RT^7V9O;G1?<VEZ93L*("`@("`@("`D<R`]('-T
M<E]R97!L86-E*")<<B(L("<G+"`D=&5X="D["B`@("`@("`@)&YB(#T@<W1R
M;&5N*"1S*3L*("`@("`@("!I9B`H)&YB(#X@,"`F)B`D<ULD;F(M,5T@/3T@
M(EQN(BD@>PH@("`@("`@("`@("`D;F(M+3L*("`@("`@("!]"B`@("`@("`@
M)&(@/2`P.PH@("`@("`@(&EF("@D8F]R9&5R*2!["B`@("`@("`@("`@(&EF
M("@D8F]R9&5R(#T](#$I('L*("`@("`@("`@("`@("`@("1B;W)D97(@/2`G
M3%120B<["B`@("`@("`@("`@("`@("`D8B`]("=,4E0G.PH@("`@("`@("`@
M("`@("`@)&(R(#T@)TQ2)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1B,B`]("<G.PH@("`@("`@("`@("`@("`@:68@*'-T<G!O
M<R@D8F]R9&5R+"`G3"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M("`@("1B,B`N/2`G3"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1B;W)D97(L("=2)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`@("`@)&(R("X]("=2)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1B(#T@*'-T<G!O<R@D8F]R9&5R+"`G5"<I
M("$]/2!F86QS92D@/R`D8C(@+B`G5"<@.B`D8C(["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@)'-E<"`]("TQ.PH@("`@("`@("1I("`@/2`P
M.PH@("`@("`@("1J("`@/2`P.PH@("`@("`@("1L("`@/2`P.PH@("`@("`@
M("1N<R`@/2`P.PH@("`@("`@("1N;"`@/2`Q.PH@("`@("`@('=H:6QE("@D
M:2`\("1N8BD@>PH@("`@("`@("`@("`O*B!'970@;F5X="!C:&%R86-T97(N
M("HO"B`@("`@("`@("`@("1C(#T@)'-;)&E=.PH@("`@("`@("`@("!I9B`H
M)&,@/3T@(EQN(BD@>PH@("`@("`@("`@("`@("`@+RH@17AP;&EC:70@;&EN
M92!B<F5A:RX@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W=O<F1?
M<W!A8VEN9R`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W=O
M<F1?<W!A8VEN9R`](#`["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)S`@5'<G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@
M)&DM)&HI+"`D8BP@,BP@)&%L:6=N+"`D9FEL;"D["B`@("`@("`@("`@("`@
M("`D:2LK.PH@("`@("`@("`@("`@("`@)'-E<"`]("TQ.PH@("`@("`@("`@
M("`@("`@)&H@/2`D:3L*("`@("`@("`@("`@("`@("1L(#T@,#L*("`@("`@
M("`@("`@("`@("1N<R`](#`["B`@("`@("`@("`@("`@("`D;FPK*SL*("`@
M("`@("`@("`@("`@(&EF("@D8F]R9&5R("8F("1N;"`]/2`R*2!["B`@("`@
M("`@("`@("`@("`@("`@)&(@/2`D8C(["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H)&,@/3T@)R`G*2!["B`@("`@("`@("`@("`@("`D<V5P(#T@
M)&D["B`@("`@("`@("`@("`@("`D;',@/2`D;#L*("`@("`@("`@("`@("`@
M("1N<RLK.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L("L]("1C=ULD
M8UT["B`@("`@("`@("`@(&EF("@D;"`^("1W;6%X*2!["B`@("`@("`@("`@
M("`@("`O*B!!=71O;6%T:6,@;&EN92!B<F5A:RX@*B\*("`@("`@("`@("`@
M("`@(&EF("@D<V5P(#T]("TQ*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1I(#T]("1J*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W=O<F1?<W!A8VEN9R`^(#`I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]W;W)D7W-P86-I;F<@/2`P.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V]U="@G,"!4=R<I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V5L;"@D=VED
M=&@L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I("T@)&HI+"`D8BP@,BP@
M)&%L:6=N+"`D9FEL;"D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D86QI9VX@/3T@)THG*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=V]R9%]S<&%C:6YG(#T@*"1N<SXQ
M*2`_("@D=VUA>"`M("1L<RDO,3`P,"`J("1T:&ES+3Y?9F]N=%]S:7IE("\@
M*"1N<R`M(#$I(#H@,#L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]O=70H<W!R:6YT9B@G)2XS9B!4=R<L("1T:&ES+3Y?=V]R9%]S<&%C:6YG
M("H@)'1H:7,M/E]S8V%L92DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8V5L;"@D=VED=&@L("1H96EG:'0L
M('-U8G-T<B@D<RP@)&HL("1S97`@+2`D:BDL("1B+"`R+"`D86QI9VXL("1F
M:6QL*3L*("`@("`@("`@("`@("`@("`@("`D:2`]("1S97`@*R`Q.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-E<"`]("TQ.PH@("`@
M("`@("`@("`@("`@)&H@/2`D:3L*("`@("`@("`@("`@("`@("1L(#T@,#L*
M("`@("`@("`@("`@("`@("1N<R`](#`["B`@("`@("`@("`@("`@("`D;FPK
M*SL*("`@("`@("`@("`@("`@(&EF("@D8F]R9&5R("8F("1N;"`]/2`R*2![
M"B`@("`@("`@("`@("`@("`@("`@)&(@/2`D8C(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:2LK
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\J($QA<W0@8VAU
M;FLN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?=V]R9%]S<&%C:6YG(#X@,"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W=O<F1?<W!A8VEN9R`](#`["B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"<P(%1W)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("@D8F]R9&5R("8F('-T<G!O<R@D8F]R9&5R+"`G0B<I("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`D8B`N/2`G0B<["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@
M)&DI+"`D8BP@,BP@)&%L:6=N+"`D9FEL;"D["B`@("`@("`@)'1H:7,M/G@@
M/2`D=&AI<RT^7VQE9G1?;6%R9VEN.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5&AI<R!M971H;V0@<')I;G1S('1E>'0@9G)O;2!T:&4@8W5R<F5N="!P;W-I
M=&EO;BX@5VAE;B!T:&4@<FEG:'0*("`@("`J(&UA<F=I;B!I<R!R96%C:&5D
M("AO<B!T:&4@7&X@8VAA<F%C=&5R(&ES(&UE="D@82!L:6YE(&)R96%K(&]C
M8W5R<R!A;F0*("`@("`J('1E>'0@8V]N=&EN=65S(&9R;VT@=&AE(&QE9G0@
M;6%R9VEN+B!5<&]N(&UE=&AO9"!E>&ET+"!T:&4@8W5R<F5N=`H@("`@("H@
M<&]S:71I;VX@:7,@;&5F="!J=7-T(&%T('1H92!E;F0@;V8@=&AE('1E>'0N
M"B`@("`@*B!)="!I<R!P;W-S:6)L92!T;R!P=70@82!L:6YK(&]N('1H92!T
M97AT+@H@("`@("H*("`@("`J($5X86UP;&4Z"B`@("`@*B`O+T)E9VEN('=I
M=&@@<F5G=6QA<B!F;VYT"B`@("`@*B`D<&1F+3YS971&;VYT*"=!<FEA;"<L
M)R<L,30I.PH@("`@("H@)'!D9BT^=W)I=&4H-2PG5FES:70@)RD["B`@("`@
M*B`O+U1H96X@<'5T(&$@8FQU92!U;F1E<FQI;F5D(&QI;FL*("`@("`J("1P
M9&8M/G-E=%1E>'1#;VQO<B@P+#`L,C4U*3L*("`@("`J("1P9&8M/G-E=$9O
M;G0H)R<L)U4G*3L*("`@("`J("1P9&8M/G=R:71E*#4L)W=W=RYF<&1F+F]R
M9R<L)VAT='`Z+R]W=W<N9G!D9BYO<F<G*3L*("`@("`J"B`@("`@*B!`<&%R
M86T@9FQO870@)&AE:6=H="`@3&EN92!H96EG:'0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("`@4W1R:6YG('1O('!R:6YT+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1L:6YK("`@(%523"!O<B!I9&5N=&EF:65R(')E='5R;F5D(&)Y
M($%D9$QI;FLH*2X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&
M;VYT"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&1,:6YK"B`@("`@*B!`<V5E
M($9I;&5?4$1&.CIM=6QT:4-E;&P*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=$%U=&]086=E0G)E86L*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&AE
M:6=H="P@)'1E>'0L("1L:6YK(#T@)R<I"B`@("!["B`@("`@("`@)&-W(#T@
M)B1T:&ES+3Y?8W5R<F5N=%]F;VYT6R=C=R==.PH@("`@("`@("1W:61T:"`]
M("1T:&ES+3YW("T@)'1H:7,M/E]R:6=H=%]M87)G:6X@+2`D=&AI<RT^>#L*
M("`@("`@("`D=VUA>"`]("@D=VED=&@@+2`R("H@)'1H:7,M/E]C96QL7VUA
M<F=I;BD@*B`Q,#`P("\@)'1H:7,M/E]F;VYT7W-I>F4["B`@("`@("`@)',@
M/2!S=')?<F5P;&%C92@B7'(B+"`G)RP@)'1E>'0I.PH@("`@("`@("1N8B`]
M('-T<FQE;B@D<RD["B`@("`@("`@)'-E<"`]("TQ.PH@("`@("`@("1I(#T@
M,#L*("`@("`@("`D:B`](#`["B`@("`@("`@)&P@/2`P.PH@("`@("`@("1N
M;"`](#$["B`@("`@("`@=VAI;&4@*"1I(#P@)&YB*2!["B`@("`@("`@("`@
M("\J($=E="!N97AT(&-H87)A8W1E<BX@*B\*("`@("`@("`@("`@)&,@/2`D
M<WLD:7T["B`@("`@("`@("`@(&EF("@D8R`]/2`B7&XB*2!["B`@("`@("`@
M("`@("`@("`O*B!%>'!L:6-I="!L:6YE(&)R96%K+B`J+PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F-E;&PH)'=I9'1H+"`D:&5I9VAT+"!S=6)S='(H)',L
M("1J+"`D:2`M("1J*2P@,"P@,BP@)R<L(#`L("1L:6YK*3L*("`@("`@("`@
M("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`D<V5P(#T@+3$["B`@("`@
M("`@("`@("`@("`D:B`]("1I.PH@("`@("`@("`@("`@("`@)&P@/2`P.PH@
M("`@("`@("`@("`@("`@:68@*"1N;"`]/2`Q*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN.PH@("`@("`@
M("`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YW("T@)'1H:7,M/E]R:6=H
M=%]M87)G:6X@+2`D=&AI<RT^>#L*("`@("`@("`@("`@("`@("`@("`D=VUA
M>"`]("@D=VED=&@@+2`R("H@)'1H:7,M/E]C96QL7VUA<F=I;BD@*B`Q,#`P
M("\@)'1H:7,M/E]F;VYT7W-I>F4["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D;FPK*SL*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D8R`]/2`G("<I('L*("`@
M("`@("`@("`@("`@("1S97`@/2`D:3L*("`@("`@("`@("`@("`@("1L<R`]
M("1L.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L("L]("1C=ULD8UT[
M"B`@("`@("`@("`@(&EF("@D;"`^("1W;6%X*2!["B`@("`@("`@("`@("`@
M("`O*B!!=71O;6%T:6,@;&EN92!B<F5A:RX@*B\*("`@("`@("`@("`@("`@
M(&EF("@D<V5P(#T]("TQ*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YX(#X@)'1H:7,M/E]L969T7VUA<F=I;BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`O*B!-;W9E('1O(&YE>'0@;&EN92X@*B\*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^>2`K/2`D:&5I9VAT
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^=R`M
M("1T:&ES+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@("`@
M("`@("`@("`@("`@("1W;6%X(#T@*"1W:61T:"`M(#(@*B`D=&AI<RT^7V-E
M;&Q?;6%R9VEN*2`J(#$P,#`@+R`D=&AI<RT^7V9O;G1?<VEZ93L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("`@
M("`@)&YL*RL["B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&D@/3T@)&HI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F-E;&PH)'=I9'1H+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2`M("1J
M*2P@,"P@,BP@)R<L(#`L("1L:6YK*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-E;&PH)'=I9'1H+"`D
M:&5I9VAT+"!S=6)S='(H)',L("1J+"`D<V5P("T@)&HI+"`P+"`R+"`G)RP@
M,"P@)&QI;FLI.PH@("`@("`@("`@("`@("`@("`@("1I(#T@)'-E<"`K(#$[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<V5P(#T@+3$[
M"B`@("`@("`@("`@("`@("`D:B`]("1I.PH@("`@("`@("`@("`@("`@)&P@
M/2`P.PH@("`@("`@("`@("`@("`@:68@*"1N;"`]/2`Q*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN.PH@
M("`@("`@("`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YW("T@)'1H:7,M
M/E]R:6=H=%]M87)G:6X@+2`D=&AI<RT^>#L*("`@("`@("`@("`@("`@("`@
M("`D=VUA>"`]("@D=VED=&@@+2`R("H@)'1H:7,M/E]C96QL7VUA<F=I;BD@
M*B`Q,#`P("\@)'1H:7,M/E]F;VYT7W-I>F4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D;FPK*SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-E"B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@('T*("`@
M("`@("`O*B!,87-T(&-H=6YK+B`J+PH@("`@("`@(&EF("@D:2`A/2`D:BD@
M>PH@("`@("`@("`@("`D=&AI<RT^8V5L;"@D;"`O(#$P,#`@*B`D=&AI<RT^
M7V9O;G1?<VEZ92P@)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@)&DI+"`P+"`P
M+"`G)RP@,"P@)&QI;FLI.PH@("`@("`@('T*("`@('T*"B`@("`@+RHJ"B`@
M("`@*B!W<FET92!2;W1A=&5D(%1E>'0N"B`@("`@*@H@("`@("H@5W)I=&4@
M=&5X="!A="!A;B!A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>"`@("`@("`@(%@@8V]O<F1I;F%T92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1Y("`@("`@("`@62!C;V]R9&EN871E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@("`@("!497AT('1O('=R:71E+@H@("`@("H@0'!A<F%M
M(&9L;V%T("1T97AT7V%N9VQE("!!;F=L92!T;R!R;W1A=&4@*$5G+B`Y,"`]
M(&)O='1O;2!T;R!T;W`I+@H@("`@("H@0'!A<F%M(&9L;V%T("1F;VYT7V%N
M9VQE("!2;W1A=&4@8VAA<F%C=&5R<R!A<R!W96QL(&%S('1E>'0N"B`@("`@
M*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1F]N=`H@("`@("HO"B`@("`@
M9G5N8W1I;VX@=W)I=&52;W1A=&5D*"1X+"`D>2P@)'1E>'0L("1T97AT7V%N
M9VQE+"`D9F]N=%]A;F=L92`](#`I"B`@("`@>PH@("`@("`@("`O*B!%<V-A
M<&4@=&5X="X@*B\*("`@("`@("`@)'1E>'0@/2`D=&AI<RT^7V5S8V%P92@D
M=&5X="D["@H@("`@("`@("`D9F]N=%]A;F=L92`K/2`Y,"`K("1T97AT7V%N
M9VQE.PH@("`@("`@("`D=&5X=%]A;F=L92`J/2!-7U!)("\@,3@P.PH@("`@
M("`@("`D9F]N=%]A;F=L92`J/2!-7U!)("\@,3@P.PH*("`@("`@("`@)'1E
M>'1?9'@@/2!C;W,H)'1E>'1?86YG;&4I.PH@("`@("`@("`D=&5X=%]D>2`]
M('-I;B@D=&5X=%]A;F=L92D["B`@("`@("`@("1F;VYT7V1X(#T@8V]S*"1F
M;VYT7V%N9VQE*3L*("`@("`@("`@)&9O;G1?9'D@/2!S:6XH)&9O;G1?86YG
M;&4I.PH*("`@("`@("`@)',]('-P<FEN=&8H)T)4("4N,F8@)2XR9B`E+C)F
M("4N,F8@)2XR9B`E+C)F(%1M("@E<RD@5&H@150G+`H@("`@("`@("`@("`@
M("`@("`@("`D=&5X=%]D>"P@)'1E>'1?9'DL("1F;VYT7V1X+"`D9F]N=%]D
M>2P*("`@("`@("`@("`@("`@("`@("`@)'@@*B`D=&AI<RT^7W-C86QE+"`H
M)'1H:7,M/F@M)'DI("H@)'1H:7,M/E]S8V%L92P@)'1E>'0I.PH*("`@("`@
M("`@:68@*"`D=&AI<RT^7V1R87=?8V]L;W(I('L*("`@("`@("`@("`@("1S
M/2=Q("<@+B`D=&AI<RT^7V1R87=?8V]L;W(@+B`G("<@+B`D<R`N("<@42<[
M"B`@("`@("`@('T*("`@("`@("`@)'1H:7,M/E]O=70H)',I.PH@("`@('T*
M"B`@("`O*BH*("`@("`J(%!R:6YT<R!A;B!I;6%G92!I;B!T:&4@<&%G92X@
M5&AE('5P<&5R+6QE9G0@8V]R;F5R(&%N9"!A="!L96%S="!O;F4@;V8*("`@
M("`J('1H92!D:6UE;G-I;VYS(&UU<W0@8F4@<W!E8VEF:65D.R!T:&4@:&5I
M9VAT(&]R('1H92!W:61T:"!C86X@8F4*("`@("`J(&-A;&-U;&%T960@875T
M;VUA=&EC86QL>2!I;B!O<F1E<B!T;R!K965P('1H92!I;6%G92!P<F]P;W)T
M:6]N<RX*("`@("`J(%-U<'!O<G1E9"!F;W)M871S(&%R92!*4$5'(&%N9"!0
M3D<N"B`@("`@*@H@("`@("H@1F]R($I014<L(&%L;"!F;&%V;W)S(&%R92!A
M;&QO=V5D.@H@("`@("H@("`M(&=R87D@<V-A;&5S"B`@("`@*B`@("T@=')U
M92!C;VQO<G,@*#(T(&)I=',I"B`@("`@*B`@("T@0TU92R`H,S(@8FET<RD*
M("`@("`J"B`@("`@*B!&;W(@4$Y'+"!A<F4@86QL;W=E9#H*("`@("`J("`@
M+2!G<F%Y('-C86QE<R!O;B!A="!M;W-T(#@@8FET<R`H,C4V(&QE=F5L<RD*
M("`@("`J("`@+2!I;F1E>&5D(&-O;&]R<PH@("`@("H@("`M('1R=64@8V]L
M;W)S("@R-"!B:71S*0H@("`@("H@8G5T(&%R92!N;W0@<W5P<&]R=&5D.@H@
M("`@("H@("`M($EN=&5R;&%C:6YG"B`@("`@*B`@("T@06QP:&$@8VAA;FYE
M;`H@("`@("H*("`@("`J($EF(&$@=')A;G-P87)E;G0@8V]L;W(@:7,@9&5F
M:6YE9"P@:70@=VEL;"!B92!T86ME;B!I;G1O(&%C8V]U;G0@*&)U=`H@("`@
M("H@=VEL;"!B92!O;FQY(&EN=&5R<')E=&5D(&)Y($%C<F]B870@-"!A;F0@
M86)O=F4I+@H@("`@("H@5&AE(&9O<FUA="!C86X@8F4@<W!E8VEF:65D(&5X
M<&QI8VET;'D@;W(@:6YF97)R960@9G)O;2!T:&4@9FEL90H@("`@("H@97AT
M96YS:6]N+@H@("`@("H@270@:7,@<&]S<VEB;&4@=&\@<'5T(&$@;&EN:R!O
M;B!T:&4@:6UA9V4N"B`@("`@*@H@("`@("H@4F5M87)K.B!I9B!A;B!I;6%G
M92!I<R!U<V5D('-E=F5R86P@=&EM97,L(&]N;'D@;VYE(&-O<'D@=VEL;"!B
M90H@("`@("H@96UB961D960@:6X@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEL92`@($YA;64@;V8@=&AE(&9I;&4@8V]N=&%I
M;FEN9R!T:&4@:6UA9V4N"B`@("`@*B!`<&%R86T@9FQO870@)'@@("`@("`@
M06)S8VES<V$@;V8@=&AE('5P<&5R+6QE9G0@8V]R;F5R+@H@("`@("H@0'!A
M<F%M(&9L;V%T("1Y("`@("`@($]R9&EN871E(&]F('1H92!U<'!E<BUL969T
M(&-O<FYE<BX*("`@("`J($!P87)A;2!F;&]A="`D=VED=&@@("!7:61T:"!O
M9B!T:&4@:6UA9V4@:6X@=&AE('!A9V4N($EF(&5Q=6%L('1O('IE<F\L"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:70@:7,@875T;VUA=&EC86QL
M>2!C86QC=6QA=&5D('1O(&ME97`@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@;W)I9VEN86P@<')O<&]R=&EO;G,N"B`@("`@*B!`<&%R86T@
M9FQO870@)&AE:6=H="`@2&5I9VAT(&]F('1H92!I;6%G92!I;B!T:&4@<&%G
M92X@268@;F]T('-P96-I9FEE9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&]R(&5Q=6%L('1O('IE<F\L(&ET(&ES(&%U=&]M871I8V%L;'D@8V%L
M8W5L871E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1O(&ME97`@
M=&AE(&]R:6=I;F%L('!R;W!O<G1I;VYS+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D='EP92`@($EM86=E(&9O<FUA="X@4&]S<VEB;&4@=F%L=65S(&%R92`H
M8V%S90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN<V5N<VET:79E
M*2`Z($I01RP@2E!%1RP@4$Y'+B!)9B!N;W0@<W!E8VEF:65D+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@('1H92!T>7!E(&ES(&EN9F5R<F5D(&9R
M;VT@=&AE(&9I;&4@97AT96YS:6]N+@H@("`@("H@0'!A<F%M(&UI>&5D("1L
M:6YK("`@(%523"!O<B!I9&5N=&EF:65R(')E='5R;F5D(&)Y($9I;&5?4$1&
M.CIA9&1,:6YK+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F%D9$QI
M;FL*("`@("`J+PH@("`@9G5N8W1I;VX@:6UA9V4H)&9I;&4L("1X+"`D>2P@
M)'=I9'1H(#T@,"P@)&AE:6=H="`](#`L("1T>7!E(#T@)R<L("1L:6YK(#T@
M)R<I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VEM86=E<ULD
M9FEL95TI*2!["B`@("`@("`@("`@("\J($9I<G-T('5S92!O9B!I;6%G92P@
M9V5T('-O;64@9FEL92!I;F9O+B`J+PH@("`@("`@("`@("!I9B`H)'1Y<&4@
M/3T@)R<I('L*("`@("`@("`@("`@("`@("1P;W,@/2!S=')R<&]S*"1F:6QE
M+"`G+B<I.PH@("`@("`@("`@("`@("`@:68@*"1P;W,@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*'-P<FEN=&8H)TEM86=E(&9I;&4@:&%S(&YO(&5X=&5N<VEO;B!A;F0@;F\@
M='EP92!W87,@<W!E8VEF:65D.B`E<R<L("1F:6QE*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D='EP92`]('-U8G-T<B@D9FEL92P@
M)'!O<R`K(#$I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T>7!E(#T@
M<W1R=&]L;W=E<B@D='EP92D["B`@("`@("`@("`@("1M<7(@/2!G971?;6%G
M:6-?<75O=&5S7W)U;G1I;64H*3L*("`@("`@("`@("`@<V5T7VUA9VEC7W%U
M;W1E<U]R=6YT:6UE*#`I.PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)VIP
M9R<@?'P@)'1Y<&4@/3T@)VIP96<G*2!["B`@("`@("`@("`@("`@("`D:6YF
M;R`]("1T:&ES+3Y?<&%R<V5*4$<H)&9I;&4I.PH@("`@("`@("`@("!](&5L
M<V5I9B`H)'1Y<&4@/3T@)W!N9R<I('L*("`@("`@("`@("`@("`@("1I;F9O
M(#T@)'1H:7,M/E]P87)S95!.1R@D9FEL92D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M<W!R:6YT9B@G56YS=7!P;W)T960@:6UA9V4@9FEL92!T>7!E.B`E<R<L("1T
M>7!E*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<V5T7VUA9VEC7W%U
M;W1E<U]R=6YT:6UE*"1M<7(I.PH@("`@("`@("`@("`D:6YF;ULG:2==(#T@
M8V]U;G0H)'1H:7,M/E]I;6%G97,I("L@,3L*("`@("`@("`@("`@)'1H:7,M
M/E]I;6%G97-;)&9I;&5=(#T@)&EN9F\["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&EN9F\@/2`D=&AI<RT^7VEM86=E<ULD9FEL95T["B`@("`@
M("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@86QL('9A<G,@87)E(&-O;G9E
M<G1E9"!T;R!P="!S8V%L92X@*B\*("`@("`@("`D>"`@("`@(#T@)'1H:7,M
M/E]T;U!T*"1X*3L*("`@("`@("`D>2`@("`@(#T@)'1H:7,M/E]T;U!T*"1Y
M*3L*("`@("`@("`D=VED=&@@(#T@)'1H:7,M/E]T;U!T*"1W:61T:"D["B`@
M("`@("`@)&AE:6=H="`]("1T:&ES+3Y?=&]0="@D:&5I9VAT*3L*"B`@("`@
M("`@+RH@268@;F]T('-P96-I9FEE9"!D;R!A=71O;6%T:6,@=VED=&@@86YD
M(&AE:6=H="!C86QC=6QA=&EO;G,N("HO"B`@("`@("`@:68@*&5M<'1Y*"1W
M:61T:"D@)B8@96UP='DH)&AE:6=H="DI('L*("`@("`@("`@("`@)'=I9'1H
M(#T@)&EN9F];)W<G73L*("`@("`@("`@("`@)&AE:6=H="`]("1I;F9O6R=H
M)UT["B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1W:61T:"DI('L*("`@("`@
M("`@("`@)'=I9'1H(#T@)&AE:6=H="`J("1I;F9O6R=W)UT@+R`D:6YF;ULG
M:"==.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D:&5I9VAT*2D@>PH@("`@
M("`@("`@("`D:&5I9VAT(#T@)'=I9'1H("H@)&EN9F];)V@G72`O("1I;F9O
M6R=W)UT["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F
M*"=Q("4N,F8@,"`P("4N,F8@)2XR9B`E+C)F(&-M("]))60@1&\@42<L("1W
M:61T:"P@)&AE:6=H="P@)'@L("1T:&ES+3YH4'0@+2`H)'D@*R`D:&5I9VAT
M*2P@)&EN9F];)VDG72DI.PH*("`@("`@("`O*B!3970@86YY(&QI;FL@:68@
M<F5Q=65S=&5D+B`J+PH@("`@("`@(&EF("@D;&EN:RD@>PH@("`@("`@("`@
M("`D=&AI<RT^7VQI;FLH)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1L:6YK
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!097)F;W)M<R!A
M(&QI;F4@8G)E86LN(%1H92!C=7)R96YT(&%B<V-I<W-A(&=O97,@8F%C:R!T
M;R!T:&4@;&5F=`H@("`@("H@;6%R9VEN(&%N9"!T:&4@;W)D:6YA=&4@:6YC
M<F5A<V5S(&)Y('1H92!A;6]U;G0@<&%S<V5D(&EN('!A<F%M971E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@9FQO870@)&AE:6=H="`@5&AE(&AE:6=H="!O
M9B!T:&4@8G)E86LN($)Y(&1E9F%U;'0L('1H92!V86QU90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&5Q=6%L<R!T:&4@:&5I9VAT(&]F('1H92!L
M87-T('!R:6YT960@8V5L;"X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIC96QL"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE=TQI;F4H)&AE:6=H="`]
M("<G*0H@("`@>PH@("`@("`@("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA
M<F=I;CL*("`@("`@("!I9B`H:7-?<W1R:6YG*"1H96EG:'0I*2!["B`@("`@
M("`@("`@("1T:&ES+3YY("L]("1T:&ES+3Y?;&%S=%]H96EG:'0["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/GD@*ST@)&AE:6=H=#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!A
M8G-C:7-S82!O9B!T:&4@8W5R<F5N="!P;W-I=&EO;B!I;B!U<V5R('5N:71S
M+@H@("`@("H*("`@("`J($!R971U<FX@9FQO870*("`@("`J"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIS9718"B`@("`@*B!`<V5E($9I;&5?4$1&.CIG9719
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9719"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%@H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^>#L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(&%B<V-I<W-A(&]F('1H
M92!C=7)R96YT('!O<VET:6]N+B!)9B!T:&4@<&%S<V5D('9A;'5E(&ES"B`@
M("`@*B!N96=A=&EV92P@:70@:7,@<F5L871I=F4@=&\@=&AE(')I9VAT(&]F
M('1H92!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D>"`@5&AE
M('9A;'5E(&]F('1H92!A8G-C:7-S82X*("`@("`J"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIG9718"B`@("`@*B!`<V5E($9I;&5?4$1&.CIG9719"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS9719"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS
M971860H@("`@("HO"B`@("!F=6YC=&EO;B!S9718*"1X*0H@("`@>PH@("`@
M("`@(&EF("@D>"`^/2`P*2!["B`@("`@("`@("`@("\J($%B<V]L=71E('9A
M;'5E+B`J+PH@("`@("`@("`@("`D=&AI<RT^>"`]("1X.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\J($YE9V%T:79E+"!S;R!R96QA=&EV92!T
M;R!R:6=H="!E9&=E(&]F('1H92!P86=E+B`J+PH@("`@("`@("`@("`D=&AI
M<RT^>"`]("1T:&ES+3YW("L@)'@["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@;W)D:6YA=&4@;V8@=&AE(&-U<G)E;G0@
M<&]S:71I;VX@:6X@=7-E<B!U;FET<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&9L;V%T"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T60H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ9V5T6`H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M<V5T6`H@("`@("HO"B`@("!F=6YC=&EO;B!G9719*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$969I
M;F5S('1H92!O<F1I;F%T92!O9B!T:&4@8W5R<F5N="!P;W-I=&EO;BX@268@
M=&AE('!A<W-E9"!V86QU92!I<PH@("`@("H@;F5G871I=F4L(&ET(&ES(')E
M;&%T:79E('1O('1H92!B;W1T;VT@;V8@=&AE('!A9V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&9L;V%T("1Y("!4:&4@=F%L=64@;V8@=&AE(&]R9&EN871E
M+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F=E=%@*("`@("`J($!S
M964@1FEL95]01$8Z.F=E=%D*("`@("`J($!S964@1FEL95]01$8Z.G-E=%D*
M("`@("`J($!S964@1FEL95]01$8Z.G-E=%A9"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%DH)'DI"B`@("!["B`@("`@("`@:68@*"1Y(#X](#`I('L*("`@
M("`@("`@("`@)'1H:7,M/GD@/2`D>3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^>2`]("1T:&ES+3YH("L@)'D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE<R!T:&4@86)S8VES<V$@86YD
M(&]R9&EN871E(&]F('1H92!C=7)R96YT('!O<VET:6]N+B!)9B!T:&4*("`@
M("`J('!A<W-E9"!V86QU97,@87)E(&YE9V%T:79E+"!T:&5Y(&%R92!R96QA
M=&EV92!R97-P96-T:79E;'D@=&\@=&AE(')I9VAT"B`@("`@*B!A;F0@8F]T
M=&]M(&]F('1H92!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D
M>"`@5&AE('9A;'5E(&]F('1H92!A8G-C:7-S82X*("`@("`J($!P87)A;2!F
M;&]A="`D>2`@5&AE('9A;'5E(&]F('1H92!O<F1I;F%T92X*("`@("`J"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIS9718"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIS9719"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%A9*"1X+"`D>2D*("`@
M('L*("`@("`@("`D=&AI<RT^<V5T62@D>2D["B`@("`@("`@)'1H:7,M/G-E
M=%@H)'@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F%W
M(%!$1B!F:6QE+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F]U='!U
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!G971/=71P=70H*0H@("`@>PH@("`@
M("`@("\J($-H96-K('=H971H97(@9FEL92!H87,@8F5E;B!C;&]S960N("HO
M"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/"`S*2!["B`@("`@("`@("`@
M("1T:&ES+3YC;&]S92@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8G5F9F5R.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@
M=&\@;W5T<'5T('1H92!B=69F97)E9"!D871A('1O('1H92!B<F]W<V5R+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@9FEL
M96YA;64@9F]R('1H92!O=71P=70@9FEL92X*("`@("`J($!P87)A;2!B;V]L
M96%N("1I;FQI;F4@("!4<G5E(&EF(&EN;&EN92P@9F%L<V4@:68@871T86-H
M;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T*"1F:6QE;F%M92`]
M("=U;FMN;W=N+G!D9B<L("1I;FQI;F4@/2!F86QS92D*("`@('L*("`@("`@
M("`O*B!#:&5C:R!W:&5T:&5R(&9I;&4@:&%S(&)E96X@8VQO<V5D+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7W-T871E(#P@,RD@>PH@("`@("`@("`@("`D
M=&AI<RT^8VQO<V4H*3L*("`@("`@("!]"@H@("`@("`@("\J($EF($A45%!?
M1&]W;FQO860@:7,@;F]T(&%V86EL86)L92!R971U<FX@4$5!4E]%<G)O<BX@
M*B\*("`@("`@("!I9B`H(4!I;F-L=61E7V]N8V4@)TA45%`O1&]W;FQO860N
M<&AP)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)TUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?1&]W;FQO860N)RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!H96%D97)S(&AA=F4@8F5E;B!S
M96YT+B`J+PH@("`@("`@(&EF("AH96%D97)S7W-E;G0H*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U5N86)L92!T;R!S96YD
M(%!$1B!F:6QE+"!S;VUE(&1A=&$@:&%S(&%L<F5A9'D@8F5E;B!O=71P=70@
M=&\@8G)O=W-E<BXG*3L*("`@("`@("!]"@H@("`@("`@("\J(%!A<F%M<R!F
M;W(@=&AE(&]U='!U="X@*B\*("`@("`@("`D9&ES<&]S:71I;VX@/2`H(21I
M;FQI;F4I(#\@2%144%]$3U=.3$]!1%]!5%1!0TA-14Y4(#H@2%144%]$3U=.
M3$]!1%])3DQ)3D4["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=D871A)R`@
M("`@("`@("`@("`@(#T^("1T:&ES+3Y?8G5F9F5R+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G8V]N=&5N='1Y<&4G("`@("`@("`]/B`G87!P;&EC871I
M;VXO<&1F)RP*("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G1E;G1D:7-P
M;W-I=&EO;B<@/3X@87)R87DH)&1I<W!O<VET:6]N+"`D9FEL96YA;64I*3L*
M("`@("`@("`O*B!/=71P=70@=&AE(&9I;&4N("HO"B`@("`@("`@<F5T=7)N
M($A45%!?1&]W;FQO860Z.G-T871I8U-E;F0H)'!A<F%M<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!S879E('1H92!01$8@9FEL92!S
M;VUE=VAE<F4@;&]C86P@=&\@=&AE('-E<G9E<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I;&5N86UE(&9O<B!T:&4@
M;W5T<'5T(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H)&9I;&5N
M86UE(#T@)W5N:VYO=VXN<&1F)RD*("`@('L*("`@("`@("`O*B!#:&5C:R!W
M:&5T:&5R(&9I;&4@:&%S(&)E96X@8VQO<V5D+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^7W-T871E(#P@,RD@>PH@("`@("`@("`@("`D=&AI<RT^8VQO<V4H
M*3L*("`@("`@("!]"@H@("`@("`@("1F(#T@9F]P96XH)&9I;&5N86UE+"`G
M=V(G*3L*("`@("`@("!I9B`H(21F*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=5;F%B;&4@=&\@<V%V92!01$8@
M9FEL93H@)7,G+"`D9FEL96YA;64I*3L*("`@("`@("!]"B`@("`@("`@9G=R
M:71E*"1F+"`D=&AI<RT^7V)U9F9E<BP@<W1R;&5N*"1T:&ES+3Y?8G5F9F5R
M*2D["B`@("`@("`@9F-L;W-E*"1F*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M=&]0="@D=F%L*0H@("`@>PH@("`@("`@(')E='5R;B`D=F%L("H@)'1H:7,M
M/E]S8V%L93L*("`@('T*"B`@("!F=6YC=&EO;B`F7V=E=$9O;G1&:6QE*"1F
M;VYT:V5Y+"`D<&%T:"`]("<G*0H@("`@>PH@("`@("`@('-T871I8R`D9F]N
M=%]W:61T:',["@H@("`@("`@(&EF("@A:7-S970H)&9O;G1?=VED=&AS6R1F
M;VYT:V5Y72DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<&%T:"DI('L*
M("`@("`@("`@("`@("`@("1F:6QE(#T@)'!A=&@@+B!S=')T;VQO=V5R*"1F
M;VYT:V5Y*2`N("<N<&AP)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1F:6QE(#T@)T9I;&4O4$1&+V9O;G1S+R<@+B!S=')T;VQO
M=V5R*"1F;VYT:V5Y*2`N("<N<&AP)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!`<F5Q=6ER92`D9FEL93L*("`@("`@("`@("`@:68@*"%I<W-E="@D
M9F]N=%]W:61T:'-;)&9O;G1K97E=*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)T-O=6QD(&YO="!I;F-L
M=61E(&9O;G0@;65T<FEC(&9I;&4Z("5S)RP@)&9I;&4I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F;VYT7W=I9'1H<SL*
M("`@('T*"B`@("!F=6YC=&EO;B!?;&EN:R@D>"P@)'DL("1W:61T:"P@)&AE
M:6=H="P@)&QI;FLI"B`@("!["B`@("`@("`@+RH@4V%V92!L:6YK('1O('!A
M9V4@;&EN:W,@87)R87DN("HO"B`@("`@("`@)'1H:7,M/E]P86=E7VQI;FMS
M6R1T:&ES+3Y?<&%G95U;72`](&%R<F%Y*"1X+"`D>2P@)'=I9'1H+"`D:&5I
M9VAT+"`D;&EN:RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V)E9VEN1&]C*"D*
M("`@('L*("`@("`@("`O*B!3=&%R="!D;V-U;65N="P@8G5T(&]N;'D@:68@
M;F]T('EE="!S=&%R=&5D+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W-T871E
M(#P@,2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-T871E(#T@,3L*("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)R501$8M,2XS)RD["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(%]P=71086=E<R@I"B`@("!["B`@("`@("`@)&YB
M(#T@)'1H:7,M/E]P86=E.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]A
M;&EA<U]N8E]P86=E<RDI('L*("`@("`@("`@("`@+RH@4F5P;&%C92!N=6UB
M97(@;V8@<&%G97,N("HO"B`@("`@("`@("`@(&9O<B`H)&X@/2`Q.R`D;B`\
M/2`D;F([("1N*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%G97-;
M)&Y=(#T@<W1R7W)E<&QA8V4H)'1H:7,M/E]A;&EA<U]N8E]P86=E<RP@)&YB
M+"`D=&AI<RT^7W!A9V5S6R1N72D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"1T:&ES+3Y?9&5F875L=%]O<FEE;G1A=&EO;B`]/2`G
M4"<I('L*("`@("`@("`@("`@)'=0="`]("1T:&ES+3YF=U!T.PH@("`@("`@
M("`@("`D:%!T(#T@)'1H:7,M/F9H4'0["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'=0="`]("1T:&ES+3YF:%!T.PH@("`@("`@("`@("`D:%!T
M(#T@)'1H:7,M/F9W4'0["B`@("`@("`@?0H@("`@("`@("1F:6QT97(@/2`H
M)'1H:7,M/E]C;VUP<F5S<RD@/R`G+T9I;'1E<B`O1FQA=&5$96-O9&4@)R`Z
M("<G.PH@("`@("`@(&9O<B`H)&X@/2`Q.R`D;B`\/2`D;F([("1N*RLI('L*
M("`@("`@("`@("`@+RH@4&%G92`J+PH@("`@("`@("`@("`D=&AI<RT^7VYE
M=V]B:B@I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G/#PO5'EP92`O4&%G
M92<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U!A<F5N="`Q(#`@4B<I
M.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<FEE;G1A=&EO;E]C
M:&%N9V5S6R1N72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*'-P
M<FEN=&8H)R]-961I84)O>"!;,"`P("4N,F8@)2XR9ETG+"`D:%!T+"`D=U!T
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]2
M97-O=7)C97,@,B`P(%(G*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%G95]L:6YK<ULD;ETI*2!["B`@("`@("`@("`@("`@("`O*B!,:6YK
M<R`J+PH@("`@("`@("`@("`@("`@)&%N;F]T<R`]("<O06YN;W1S(%LG.PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86=E7VQI;FMS6R1N
M72!A<R`D<&PI('L*("`@("`@("`@("`@("`@("`@("`D<F5C="`]('-P<FEN
M=&8H)R4N,F8@)2XR9B`E+C)F("4N,F8G+"`D<&Q;,%TL("1P;%LQ72P@)'!L
M6S!=("L@)'!L6S)=+"`D<&Q;,5T@+2`D<&Q;,UTI.PH@("`@("`@("`@("`@
M("`@("`@("1A;FYO=',@+CT@)SP\+U1Y<&4@+T%N;F]T("]3=6)T>7!E("],
M:6YK("]296-T(%LG("X@)')E8W0@+B`G72`O0F]R9&5R(%LP(#`@,%T@)SL*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1P;%LT72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%N;F]T<R`N/2`G+T$@/#PO4R`O
M55))("]54DD@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D<&Q;-%TI("X@)SX^
M/CXG.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1L(#T@)'1H:7,M/E]L:6YK<ULD<&Q;-%U=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:&5I9VAT(#T@:7-S970H)'1H:7,M/E]O
M<FEE;G1A=&EO;E]C:&%N9V5S6R1L6S!=72D@/R`D=U!T(#H@)&A0=#L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&%N;F]T<R`N/2!S<')I;G1F*"<O1&5S
M="!;)60@,"!2("]865H@,"`E+C)F(&YU;&Q=/CXG+"`Q("L@,B`J("1L6S!=
M+"`D:&5I9VAT("T@)&Q;,5T@*B`D=&AI<RT^7W-C86QE*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V]U="@D86YN;W1S+B==)RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]O=70H)R]#;VYT96YT<R`G("X@*"1T:&ES+3Y?
M;B`K(#$I("X@)R`P(%(^/B<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M96YD;V)J)RD["B`@("`@("`@("`@("\J(%!A9V4@8V]N=&5N="`J+PH@("`@
M("`@("`@("`D<"`]("@D=&AI<RT^7V-O;7!R97-S*2`_(&=Z8V]M<')E<W,H
M)'1H:7,M/E]P86=E<ULD;ETI(#H@)'1H:7,M/E]P86=E<ULD;ET["B`@("`@
M("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"<\/"<@+B`D9FEL=&5R("X@)R],96YG=&@@)R`N('-T<FQE;B@D<"D@
M+B`G/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]P=713=')E86TH)'`I.PH@
M("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@("`@("`@?0H@
M("`@("`@("\J(%!A9V5S(')O;W0@*B\*("`@("`@("`D=&AI<RT^7V]F9G-E
M='-;,5T@/2!S=')L96XH)'1H:7,M/E]B=69F97(I.PH@("`@("`@("1T:&ES
M+3Y?;W5T*"<Q(#`@;V)J)RD["B`@("`@("`@)'1H:7,M/E]O=70H)SP\+U1Y
M<&4@+U!A9V5S)RD["B`@("`@("`@)&MI9',@/2`G+TMI9',@6R<["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&YB.R`D:2LK*2!["B`@("`@("`@("`@
M("1K:61S("X]("@S("L@,B`J("1I*2`N("<@,"!2("<["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?;W5T*"1K:61S("X@)UTG*3L*("`@("`@("`D=&AI
M<RT^7V]U="@G+T-O=6YT("<@+B`D;F(I.PH@("`@("`@("1T:&ES+3Y?;W5T
M*'-P<FEN=&8H)R]-961I84)O>"!;,"`P("4N,F8@)2XR9ETG+"`D=U!T+"`D
M:%!T*2D["B`@("`@("`@)'1H:7,M/E]O=70H)SX^)RD["B`@("`@("`@)'1H
M:7,M/E]O=70H)V5N9&]B:B<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P=71&
M;VYT<R@I"B`@("!["B`@("`@("`@)&YF(#T@)'1H:7,M/E]N.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?9&EF9G,@87,@)&1I9F8I('L*("`@("`@("`@
M("`@+RH@16YC;V1I;F=S("HO"B`@("`@("`@("`@("1T:&ES+3Y?;F5W;V)J
M*"D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]4>7!E("]%;F-O9&EN
M9R`O0F%S945N8V]D:6YG("]7:6Y!;G-I16YC;V1I;F<@+T1I9F9E<F5N8V5S
M(%LG("X@)&1I9F8@+B`G73X^)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"=E;F1O8FHG*3L*("`@("`@("!]"B`@("`@("`@)&UQ<B`](&=E=%]M86=I
M8U]Q=6]T97-?<G5N=&EM92@I.PH@("`@("`@('-E=%]M86=I8U]Q=6]T97-?
M<G5N=&EM92@P*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V9O;G1?9FEL
M97,@87,@)&9I;&4@/3X@)&EN9F\I('L*("`@("`@("`@("`@+RH@1F]N="!F
M:6QE(&5M8F5D9&EN9RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]N97=O8FHH
M*3L*("`@("`@("`@("`@)'1H:7,M/E]F;VYT7V9I;&5S6R1F:6QE75LG;B==
M(#T@)'1H:7,M/E]N.PH@("`@("`@("`@("`D<VEZ92`](&9I;&5S:7IE*"1F
M:6QE*3L*("`@("`@("`@("`@:68@*"$D<VEZ92D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=&;VYT(&9I;&4@;F]T(&9O
M=6YD+B<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<\/"],96YG=&@@)R`N("1S:7IE*3L*("`@("`@("`@("`@:68@*'-U8G-T
M<B@D9FEL92P@+3(I(#T]("<N>B<I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*"<O1FEL=&5R("]&;&%T941E8V]D92<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O3&5N9W1H,2`G("X@)&EN9F];
M)VQE;F=T:#$G72D["B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG;&5N
M9W1H,B==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R],96YG
M=&@R("<@+B`D:6YF;ULG;&5N9W1H,B==("X@)R`O3&5N9W1H,R`P)RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SX^)RD["B`@
M("`@("`@("`@("1F(#T@9F]P96XH)&9I;&4L("=R8B<I.PH@("`@("`@("`@
M("`D=&AI<RT^7W!U=%-T<F5A;2AF<F5A9"@D9BP@)'-I>F4I*3L*("`@("`@
M("`@("`@9F-L;W-E*"1F*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N
M9&]B:B<I.PH@("`@("`@('T*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U
M;G1I;64H)&UQ<BD["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]F;VYT<R!A
M<R`D:R`]/B`D9F]N="D@>PH@("`@("`@("`@("`O*B!&;VYT(&]B:F5C=',@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`@("`@
M)'1H:7,M/E]F;VYT<ULD:UU;)VXG72`]("1T:&ES+3Y?;CL*("`@("`@("`@
M("`@)&YA;64@/2`D9F]N=%LG;F%M92==.PH@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G/#PO5'EP92`O1F]N="<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U
M="@G+T)A<V5&;VYT("\G("X@)&YA;64I.PH@("`@("`@("`@("!I9B`H)&9O
M;G1;)W1Y<&4G72`]/2`G8V]R92<I('L*("`@("`@("`@("`@("`@("\J(%-T
M86YD87)D(&9O;G0N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M+U-U8G1Y<&4@+U1Y<&4Q)RD["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@
M(3T@)U-Y;6)O;"<@)B8@)&YA;64@(3T@)UIA<&9$:6YG8F%T<R<I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T5N8V]D:6YG("]7:6Y!
M;G-I16YC;V1I;F<G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($%D9&ET:6]N86P@9F]N="X@
M*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4W5B='EP92`O)R`N
M("1F;VYT6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)R]&:7)S=$-H87(@,S(G*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<O3&%S=$-H87(@,C4U)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M="@G+U=I9'1H<R`G("X@*"1T:&ES+3Y?;B`K(#$I("X@)R`P(%(G*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O1F]N=$1E<V-R:7!T;W(@)R`N
M("@D=&AI<RT^7VX@*R`R*2`N("<@,"!2)RD["B`@("`@("`@("`@("`@("!I
M9B`H)&9O;G1;)V5N8R==*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1F;VYT6R=D:69F)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;W5T*"<O16YC;V1I;F<@)R`N("@D;F8@*R`D9F]N=%LG9&EF
M9B==*2XG(#`@4B<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O16YC;V1I;F<@
M+U=I;D%N<VE%;F-O9&EN9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^7V]U="@G/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N9&]B
M:B<I.PH@("`@("`@("`@("!I9B`H)&9O;G1;)W1Y<&4G72`A/2`G8V]R92<I
M('L*("`@("`@("`@("`@("`@("\J(%=I9'1H<RX@*B\*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@("`@("`@("`D8W<@/2`F
M)&9O;G1;)V-W)UT["B`@("`@("`@("`@("`@("`D<R`]("=;)SL*("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`S,CL@)&D@/#T@,C4U.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`@("`@)',@+CT@)&-W6V-H<B@D:2E=("X@)R`G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)',@+B`G72<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N9&]B
M:B<I.PH@("`@("`@("`@("`@("`@+RH@1&5S8W)I<'1O<BX@*B\*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@("`@("`@("`D
M<R`]("<\/"]4>7!E("]&;VYT1&5S8W)I<'1O<B`O1F]N=$YA;64@+R<@+B`D
M;F%M93L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F;VYT6R=D97-C)UT@
M87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`D<R`N/2`G("\G
M("X@)&L@+B`G("<@+B`D=CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1F:6QE(#T@)&9O;G1;)V9I;&4G73L*("`@("`@("`@("`@("`@
M(&EF("@D9FEL92D@>PH@("`@("`@("`@("`@("`@("`@("1S("X]("<@+T9O
M;G1&:6QE)R`N("@D9F]N=%LG='EP92==(#T]("=4>7!E,2<@/R`G)R`Z("<R
M)RD@+B`G("<@+B`D=&AI<RT^7V9O;G1?9FEL97-;)&9I;&5=6R=N)UT@+B`G
M(#`@4B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V]U="@D<R`N("<^/B<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)V5N9&]B:B<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(%]P=71);6%G97,H*0H@("`@>PH@("`@("`@("1F:6QT
M97(@/2`H)'1H:7,M/E]C;VUP<F5S<RD@/R`G+T9I;'1E<B`O1FQA=&5$96-O
M9&4@)R`Z("<G.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:6UA9V5S(&%S
M("1F:6QE(#T^("1I;F9O*2!["B`@("`@("`@("`@("1T:&ES+3Y?;F5W;V)J
M*"D["B`@("`@("`@("`@("1T:&ES+3Y?:6UA9V5S6R1F:6QE75LG;B==(#T@
M)'1H:7,M/E]N.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G/#PO5'EP92`O
M6$]B:F5C="<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U-U8G1Y<&4@
M+TEM86=E)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O5VED=&@@)R`N
M("1I;F9O6R=W)UTI.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+TAE:6=H
M="`G("X@)&EN9F];)V@G72D["B`@("`@("`@("`@(&EF("@D:6YF;ULG8W,G
M72`]/2`G26YD97AE9"<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<O0V]L;W)3<&%C92!;+TEN9&5X960@+T1E=FEC95)'0B`G("X@*'-T<FQE
M;B@D:6YF;ULG<&%L)UTI+S,@+2`Q*2`N("<@)R`N("@D=&AI<RT^7VX@*R`Q
M*2XG(#`@4ETG*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;W5T*"<O0V]L;W)3<&%C92`O)R`N("1I;F9O6R=C<R==
M*3L*("`@("`@("`@("`@("`@(&EF("@D:6YF;ULG8W,G72`]/2`G1&5V:6-E
M0TU92R<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T1E
M8V]D92!;,2`P(#$@,"`Q(#`@,2`P72<I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O0FET<U!E
M<D-O;7!O;F5N="`G("X@)&EN9F];)V)P8R==*3L*("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)R]&:6QT97(@+R<@+B`D:6YF;ULG9B==*3L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1I;F9O6R=P87)M<R==*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]O=70H)&EN9F];)W!A<FUS)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG=')N<R==*2`F)B!I<U]A
M<G)A>2@D:6YF;ULG=')N<R==*2D@>PH@("`@("`@("`@("`@("`@)'1R;G,@
M/2`G)SL*("`@("`@("`@("`@("`@("1I7VUA>"`](&-O=6YT*"1I;F9O6R=T
M<FYS)UTI.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&E?
M;6%X.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)'1R;G,@+CT@)&EN
M9F];)W1R;G,G75LD:5T@+B`G("<@+B`D:6YF;ULG=')N<R==6R1I72XG("<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M="@G+TUA<VL@6R<@+B`D=')N<R`N("==)RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]O=70H)R],96YG=&@@)R`N('-T<FQE;B@D:6YF
M;ULG9&%T82==*2`N("<^/B<I.PH@("`@("`@("`@("`D=&AI<RT^7W!U=%-T
M<F5A;2@D:6YF;ULG9&%T82==*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)V5N9&]B:B<I.PH*("`@("`@("`@("`@+RH@4&%L971T92X@*B\*("`@("`@
M("`@("`@:68@*"1I;F9O6R=C<R==(#T]("=);F1E>&5D)RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`@("`@("`@("1P
M86P@/2`H)'1H:7,M/E]C;VUP<F5S<RD@/R!G>F-O;7!R97-S*"1I;F9O6R=P
M86PG72D@.B`D:6YF;ULG<&%L)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G/#PG("X@)&9I;'1E<B`N("<O3&5N9W1H("<@+B!S=')L96XH)'!A
M;"D@+B`G/CXG*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<'5T4W1R96%M
M*"1P86PI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N9&]B:B<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(%]P=71297-O=7)C97,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<'5T1F]N
M=',H*3L*("`@("`@("`D=&AI<RT^7W!U=$EM86=E<R@I.PH@("`@("`@("\J
M(%)E<V]U<F-E(&1I8W1I;VYA<GD@*B\*("`@("`@("`D=&AI<RT^7V]F9G-E
M='-;,ET@/2!S=')L96XH)'1H:7,M/E]B=69F97(I.PH@("`@("`@("1T:&ES
M+3Y?;W5T*"<R(#`@;V)J)RD["B`@("`@("`@)'1H:7,M/E]O=70H)SP\+U!R
M;V-3970@6R]01$8@+U1E>'0@+TEM86=E0B`O26UA9V5#("]);6%G94E=)RD[
M"B`@("`@("`@)'1H:7,M/E]O=70H)R]&;VYT(#P\)RD["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]F;VYT<R!A<R`D9F]N="D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V]U="@G+T8G("X@)&9O;G1;)VDG72`N("<@)R`N("1F;VYT6R=N
M)UT@+B`G(#`@4B<I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V]U="@G
M/CXG*3L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]I;6%G97,I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;W5T*"<O6$]B:F5C="`\/"<I.PH@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7VEM86=E<R!A<R`D:6UA9V4I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O22<@+B`D:6UA9V5;)VDG72`N
M("<@)R`N("1I;6%G95LG;B==("X@)R`P(%(G*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7V]U="@G/CXG*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]O=70H)SX^)RD["B`@("`@("`@)'1H:7,M/E]O=70H)V5N
M9&]B:B<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P=71);F9O*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7V]U="@G+U!R;V1U8V5R("<@+B`D=&AI<RT^7W1E
M>'13=')I;F<H)TAO<F1E(%!$1B<I*3L*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?:6YF;ULG=&ET;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)R]4:71L92`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"1T:&ES+3Y?:6YF
M;ULG=&ET;&4G72DI.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?:6YF;ULG<W5B:F5C="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G+U-U8FIE8W0@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D=&AI<RT^
M7VEN9F];)W-U8FIE8W0G72DI.PH@("`@("`@('T*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?:6YF;ULG875T:&]R)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;W5T*"<O075T:&]R("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H
M:7,M/E]I;F9O6R=A=71H;W(G72DI.PH@("`@("`@('T*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3YK97EW;W)D<RDI('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]+97EW;W)D<R`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"1T:&ES
M+3YK97EW;W)D<RDI.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3YC<F5A=&]R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T-R
M96%T;W(@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D=&AI<RT^8W)E871O<BDI
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V]U="@G+T-R96%T:6]N1&%T
M92`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"=$.B<@+B!D871E*"=9;61(:7,G
M*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P=71#871A;&]G*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7V]U="@G+U1Y<&4@+T-A=&%L;V<G*3L*("`@("`@
M("`D=&AI<RT^7V]U="@G+U!A9V5S(#$@,"!2)RD["B`@("`@("`@:68@*"1T
M:&ES+3Y?>F]O;5]M;V1E(#T]("=F=6QL<&%G92<I('L*("`@("`@("`@("`@
M)'1H:7,M/E]O=70H)R]/<&5N06-T:6]N(%LS(#`@4B`O1FET72<I.PH@("`@
M("`@('T@96QS96EF("@D=&AI<RT^7WIO;VU?;6]D92`]/2`G9G5L;'=I9'1H
M)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T]P96Y!8W1I;VX@6S,@
M,"!2("]&:71((&YU;&Q=)RD["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?
M>F]O;5]M;V1E(#T]("=R96%L)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U
M="@G+T]P96Y!8W1I;VX@6S,@,"!2("]865H@;G5L;"!N=6QL(#%=)RD["B`@
M("`@("`@?2!E;'-E:68@*"%I<U]S=')I;F<H)'1H:7,M/E]Z;V]M7VUO9&4I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O3W!E;D%C=&EO;B!;,R`P
M(%(@+UA96B!N=6QL(&YU;&P@)R`N("@D=&AI<RT^7WIO;VU?;6]D92`O(#$P
M,"DN)UTG*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?;&%Y;W5T
M7VUO9&4@/3T@)W-I;F=L92<I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)R]086=E3&%Y;W5T("]3:6YG;&5086=E)RD["B`@("`@("`@?2!E;'-E:68@
M*"1T:&ES+3Y?;&%Y;W5T7VUO9&4@/3T@)V-O;G1I;G5O=7,G*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"<O4&%G94QA>6]U="`O3VYE0V]L=6UN)RD[
M"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?;&%Y;W5T7VUO9&4@/3T@)W1W
M;R<I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]086=E3&%Y;W5T("]4
M=V]#;VQU;6Y,969T)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(%]P=714<F%I;&5R*"D*("`@('L*("`@("`@("`D=&AI<RT^7V]U="@G+U-I
M>F4@)R`N("@D=&AI<RT^7VX@*R`Q*2D["B`@("`@("`@)'1H:7,M/E]O=70H
M)R]2;V]T("<@+B`D=&AI<RT^7VX@+B`G(#`@4B<I.PH@("`@("`@("1T:&ES
M+3Y?;W5T*"<O26YF;R`G("X@*"1T:&ES+3Y?;B`M(#$I("X@)R`P(%(G*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?96YD1&]C*"D*("`@('L*("`@("`@("`D
M=&AI<RT^7W!U=%!A9V5S*"D["B`@("`@("`@)'1H:7,M/E]P=71297-O=7)C
M97,H*3L*("`@("`@("`O*B!);F9O("HO"B`@("`@("`@)'1H:7,M/E]N97=O
M8FHH*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PG*3L*("`@("`@("`D=&AI
M<RT^7W!U=$EN9F\H*3L*("`@("`@("`D=&AI<RT^7V]U="@G/CXG*3L*("`@
M("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@("`@("`@+RH@0V%T86QO
M9R`J+PH@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@)'1H:7,M
M/E]O=70H)SP\)RD["B`@("`@("`@)'1H:7,M/E]P=71#871A;&]G*"D["B`@
M("`@("`@)'1H:7,M/E]O=70H)SX^)RD["B`@("`@("`@)'1H:7,M/E]O=70H
M)V5N9&]B:B<I.PH@("`@("`@("\J($-R;W-S+7)E9B`J+PH@("`@("`@("1O
M(#T@<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*3L*("`@("`@("`D=&AI<RT^7V]U
M="@G>')E9B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<P("<@+B`H)'1H:7,M
M/E]N("L@,2DI.PH@("`@("`@("1T:&ES+3Y?;W5T*"<P,#`P,#`P,#`P(#8U
M-3,U(&8@)RD["B`@("`@("`@9F]R("@D:2`](#$[("1I(#P]("1T:&ES+3Y?
M;CL@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F*"<E
M,#$P9"`P,#`P,"!N("<L("1T:&ES+3Y?;V9F<V5T<ULD:5TI*3L*("`@("`@
M("!]"B`@("`@("`@+RH@5')A:6QE<B`J+PH@("`@("`@("1T:&ES+3Y?;W5T
M*"=T<F%I;&5R)RD["B`@("`@("`@)'1H:7,M/E]O=70H)SP\)RD["B`@("`@
M("`@)'1H:7,M/E]P=714<F%I;&5R*"D["B`@("`@("`@)'1H:7,M/E]O=70H
M)SX^)RD["B`@("`@("`@)'1H:7,M/E]O=70H)W-T87)T>')E9B<I.PH@("`@
M("`@("1T:&ES+3Y?;W5T*"1O*3L*("`@("`@("`D=&AI<RT^7V]U="@G)25%
M3T8G*3L*("`@("`@("`D=&AI<RT^7W-T871E(#T@,SL*("`@('T*"B`@("!F
M=6YC=&EO;B!?8F5G:6Y086=E*"1O<FEE;G1A=&EO;BD*("`@('L*("`@("`@
M("`D=&AI<RT^7W!A9V4K*SL*("`@("`@("`D=&AI<RT^7W!A9V5S6R1T:&ES
M+3Y?<&%G95T@/2`G)SL*("`@("`@("`D=&AI<RT^7W-T871E(#T@,CL*("`@
M("`@("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@("`@("`@
M)'1H:7,M/GD@/2`D=&AI<RT^7W1O<%]M87)G:6X["B`@("`@("`@)'1H:7,M
M/E]L87-T7VAE:6=H="`](#`["B`@("`@("`@+RH@4&%G92!O<FEE;G1A=&EO
M;B`J+PH@("`@("`@(&EF("@A)&]R:65N=&%T:6]N*2!["B`@("`@("`@("`@
M("1O<FEE;G1A=&EO;B`]("1T:&ES+3Y?9&5F875L=%]O<FEE;G1A=&EO;CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;W)I96YT871I;VX@/2!S
M=')T;W5P<&5R*"1O<FEE;G1A=&EO;GLP?2D["B`@("`@("`@("`@(&EF("@D
M;W)I96YT871I;VX@(3T@)'1H:7,M/E]D969A=6QT7V]R:65N=&%T:6]N*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]R:65N=&%T:6]N7V-H86YG97-;
M)'1H:7,M/E]P86=E72`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"1O<FEE;G1A=&EO;B`A/2`D=&AI<RT^7V-U<G)E;G1?
M;W)I96YT871I;VXI('L*("`@("`@("`@("`@+RH@0VAA;F=E(&]R:65N=&%T
M:6]N("HO"B`@("`@("`@("`@(&EF("@D;W)I96YT871I;VX@/3T@)U`G*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^=U!T(#T@)'1H:7,M/F9W4'0["B`@
M("`@("`@("`@("`@("`D=&AI<RT^:%!T(#T@)'1H:7,M/F9H4'0["B`@("`@
M("`@("`@("`@("`D=&AI<RT^=R`@(#T@)'1H:7,M/F9W.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F@@("`]("1T:&ES+3YF:#L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YW4'0@/2`D=&AI<RT^9FA0
M=#L*("`@("`@("`@("`@("`@("1T:&ES+3YH4'0@/2`D=&AI<RT^9G=0=#L*
M("`@("`@("`@("`@("`@("1T:&ES+3YW("`@/2`D=&AI<RT^9F@["B`@("`@
M("`@("`@("`@("`D=&AI<RT^:"`@(#T@)'1H:7,M/F9W.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?<&%G95]B<F5A:U]T<FEG9V5R(#T@
M)'1H:7,M/F@@+2`D=&AI<RT^7V)R96%K7VUA<F=I;CL*("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R96YT7V]R:65N=&%T:6]N(#T@)&]R:65N=&%T:6]N.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?96YD4&%G92@I"B`@("![
M"B`@("`@("`@+RH@16YD(&]F('!A9V4@8V]N=&5N=',@*B\*("`@("`@("`D
M=&AI<RT^7W-T871E(#T@,3L*("`@('T*"B`@("!F=6YC=&EO;B!?;F5W;V)J
M*"D*("`@('L*("`@("`@("`O*B!"96=I;B!A(&YE=R!O8FIE8W0@*B\*("`@
M("`@("`D=&AI<RT^7VXK*SL*("`@("`@("`D=&AI<RT^7V]F9G-E='-;)'1H
M:7,M/E]N72`]('-T<FQE;B@D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@)'1H
M:7,M/E]O=70H)'1H:7,M/E]N("X@)R`P(&]B:B<I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]D;U5N9&5R;&EN92@D>"P@)'DL("1T97AT*0H@("`@>PH@("`@
M("`@("\J(%-E="!T:&4@<F5C=&%N9VQE('=I9'1H(&%C8V]R9&EN9R!T;R!T
M97AT('=I9'1H+B`J+PH@("`@("`@("1W:61T:"`@/2`D=&AI<RT^9V5T4W1R
M:6YG5VED=&@H)'1E>'0L('1R=64I.PH*("`@("`@("`O*B!3970@<F5C=&%N
M9VQE('!O<VET:6]N(&%N9"!H96EG:'0L('5S:6YG('5N9&5R;&EN92!P;W-I
M=&EO;B!A;F0*("`@("`@("`@*B!T:&EC:VYE<W,@<V5T=&EN9W,@<V-A;&5D
M(&)Y('1H92!F;VYT('-I>F4N("HO"B`@("`@("`@)'D@/2`D>2`K("@D=&AI
M<RT^7V-U<G)E;G1?9F]N=%LG=7`G72`J("1T:&ES+3Y?9F]N=%]S:7IE7W!T
M("\@,3`P,"D["B`@("`@("`@)&AE:6=H="`]("TD=&AI<RT^7V-U<G)E;G1?
M9F]N=%LG=70G72`J("1T:&ES+3Y?9F]N=%]S:7IE7W!T("\@,3`P,#L*"B`@
M("`@("`@<F5T=7)N('-P<FEN=&8H)R4N,F8@)2XR9B`E+C)F("4N,F8@<F4@
M9B<L("1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<&%R<V5*4$<H)&9I;&4I"B`@("!["B`@("`@("`@+RH@17AT<F%C
M="!I;F9O(&9R;VT@82!*4$5'(&9I;&4N("HO"B`@("`@("`@)&EM9R`]($!G
M971I;6%G97-I>F4H)&9I;&4I.PH@("`@("`@(&EF("@A)&EM9RD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G36ES
M<VEN9R!O<B!I;F-O<G)E8W0@:6UA9V4@9FEL93H@)7,G+"`D9FEL92DI.PH@
M("`@("`@('T*("`@("`@("!I9B`H)&EM9ULR72`A/2`R*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=.;W0@82!*
M4$5'(&9I;&4Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D:6UG6R=C:&%N;F5L<R==*2!\?"`D:6UG6R=C:&%N;F5L<R==
M(#T](#,I('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@)T1E=FEC95)'0B<[
M"B`@("`@("`@?2!E;'-E:68@*"1I;6=;)V-H86YN96QS)UT@/3T@-"D@>PH@
M("`@("`@("`@("`D8V]L<W!A8V4@/2`G1&5V:6-E0TU92R<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@)T1E=FEC94=R87DG
M.PH@("`@("`@('T*("`@("`@("`D8G!C(#T@:7-S970H)&EM9ULG8FET<R==
M*2`_("1I;6=;)V)I=',G72`Z(#@["@H@("`@("`@("\J(%)E860@=VAO;&4@
M9FEL92X@*B\*("`@("`@("`D9B`](&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@
M("`@("`D9&%T82`](&9R96%D*"1F+"!F:6QE<VEZ92@D9FEL92DI.PH@("`@
M("`@(&9C;&]S92@D9BD["@H@("`@("`@(')E='5R;B!A<G)A>2@G=R<@/3X@
M)&EM9ULP72P@)V@G(#T^("1I;6=;,5TL("=C<R<@/3X@)&-O;'-P86-E+"`G
M8G!C)R`]/B`D8G!C+"`G9B<@/3X@)T1#5$1E8V]D92<L("=D871A)R`]/B`D
M9&%T82D["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<G-E4$Y'*"1F:6QE*0H@
M("`@>PH@("`@("`@("\J($5X=')A8W0@:6YF;R!F<F]M(&$@4$Y'(&9I;&4N
M("HO"B`@("`@("`@)&8@/2!F;W!E;B@D9FEL92P@)W)B)RD["B`@("`@("`@
M:68@*"$D9BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H<W!R:6YT9B@G56YA8FQE('1O(&]P96X@:6UA9V4@9FEL93H@)7,G+"`D
M9FEL92DI.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@<VEG;F%T=7)E
M+B`J+PH@("`@("`@(&EF("AF<F5A9"@D9BP@."D@(3T@8VAR*#$S-RD@+B`G
M4$Y')R`N(&-H<B@Q,RD@+B!C:'(H,3`I("X@8VAR*#(V*2`N(&-H<B@Q,"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN
M=&8H)TYO="!A(%!.1R!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H*
M("`@("`@("`O*B!296%D(&AE861E<B!C:'5N:RX@*B\*("`@("`@("!F<F5A
M9"@D9BP@-"D["B`@("`@("`@:68@*&9R96%D*"1F+"`T*2`A/2`G24A$4B<I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN
M=&8H)TEN8V]R<F5C="!03D<@9FEL93H@)7,G+"`D9FEL92DI.PH@("`@("`@
M('T*("`@("`@("`D=VED=&@@/2`D=&AI<RT^7V9R96%D26YT*"1F*3L*("`@
M("`@("`D:&5I9VAT(#T@)'1H:7,M/E]F<F5A9$EN="@D9BD["B`@("`@("`@
M)&)P8R`](&]R9"AF<F5A9"@D9BP@,2DI.PH@("`@("`@(&EF("@D8G!C(#X@
M."D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R
M:6YT9B@G,38M8FET(&1E<'1H(&YO="!S=7!P;W)T960Z("5S)RP@)&9I;&4I
M*3L*("`@("`@("!]"B`@("`@("`@)&-T(#T@;W)D*&9R96%D*"1F+"`Q*2D[
M"B`@("`@("`@:68@*"1C="`]/2`P*2!["B`@("`@("`@("`@("1C;VQS<&%C
M92`]("=$979I8V5'<F%Y)SL*("`@("`@("!](&5L<V5I9B`H)&-T(#T](#(I
M('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@)T1E=FEC95)'0B<["B`@("`@
M("`@?2!E;'-E:68@*"1C="`]/2`S*2!["B`@("`@("`@("`@("1C;VQS<&%C
M92`]("=);F1E>&5D)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G06QP:&$@8VAA;FYE
M;"!N;W0@<W5P<&]R=&5D.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@
M("`@(&EF("AO<F0H9G)E860H)&8L(#$I*2`A/2`P*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=5;FMN;W=N(&-O
M;7!R97-S:6]N(&UE=&AO9#H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@
M("`@("!I9B`H;W)D*&9R96%D*"1F+"`Q*2D@(3T@,"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G56YK;F]W;B!F
M:6QT97(@;65T:&]D.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@
M(&EF("AO<F0H9G)E860H)&8L(#$I*2`A/2`P*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=);G1E<FQA8VEN9R!N
M;W0@<W5P<&]R=&5D.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@
M(&9R96%D*"1F+"`T*3L*("`@("`@("`D<&%R;7,@/2`G+T1E8V]D95!A<FUS
M(#P\+U!R961I8W1O<B`Q-2`O0V]L;W)S("<@+B`H)&-T(#T](#(@/R`S(#H@
M,2DN)R`O0FET<U!E<D-O;7!O;F5N="`G("X@)&)P8R`N("<@+T-O;'5M;G,@
M)R`N("1W:61T:"XG/CXG.PH@("`@("`@("\J(%-C86X@8VAU;FMS(&QO;VMI
M;F<@9F]R('!A;&5T=&4L('1R86YS<&%R96YC>2!A;F0@:6UA9V4@9&%T82X@
M*B\*("`@("`@("`D<&%L(#T@)R<["B`@("`@("`@)'1R;G,@/2`G)SL*("`@
M("`@("`D9&%T82`]("<G.PH@("`@("`@(&1O('L*("`@("`@("`@("`@)&X@
M/2`D=&AI<RT^7V9R96%D26YT*"1F*3L*("`@("`@("`@("`@)'1Y<&4@/2!F
M<F5A9"@D9BP@-"D["B`@("`@("`@("`@(&EF("@D='EP92`]/2`G4$Q412<I
M('L*("`@("`@("`@("`@("`@("\J(%)E860@<&%L971T92`J+PH@("`@("`@
M("`@("`@("`@)'!A;"`](&9R96%D*"1F+"`D;BD["B`@("`@("`@("`@("`@
M("!F<F5A9"@D9BP@-"D["B`@("`@("`@("`@('T@96QS96EF("@D='EP92`]
M/2`G=%).4R<I('L*("`@("`@("`@("`@("`@("\J(%)E860@=')A;G-P87)E
M;F-Y(&EN9F\@*B\*("`@("`@("`@("`@("`@("1T(#T@9G)E860H)&8L("1N
M*3L*("`@("`@("`@("`@("`@(&EF("@D8W0@/3T@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("1T<FYS(#T@87)R87DH;W)D*'-U8G-T<B@D="P@,2P@,2DI
M*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D8W0@/3T@,BD@>PH@("`@
M("`@("`@("`@("`@("`@("1T<FYS(#T@87)R87DH;W)D*'-U8G-T<B@D="P@
M,2P@,2DI+"!O<F0H<W5B<W1R*"1T+"`S+"`Q*2DL(&]R9"AS=6)S='(H)'0L
M(#4L(#$I*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1P;W,@/2!S=')P;W,H)'0L(&-H<B@P*2D["B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES7VEN="@D<&]S*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=')N<R`](&%R<F%Y*"1P;W,I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&9R
M96%D*"1F+"`T*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=)
M1$%4)RD@>PH@("`@("`@("`@("`@("`@+RH@4F5A9"!I;6%G92!D871A(&)L
M;V-K("HO"B`@("`@("`@("`@("`@("`D9&%T82`N/2!F<F5A9"@D9BP@)&XI
M.PH@("`@("`@("`@("`@("`@9G)E860H)&8L(#0I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)'1Y<&4@/3T@)TE%3D0G*2!["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9R
M96%D*"1F+"`D;B`K(#0I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL
M92`H)&XI.PH*("`@("`@("!I9B`H)&-O;'-P86-E(#T]("=);F1E>&5D)R`F
M)B!E;7!T>2@D<&%L*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H<W!R:6YT9B@G36ES<VEN9R!P86QE='1E(&EN.B`E<R<L("1F
M:6QE*2D["B`@("`@("`@?0H@("`@("`@(&9C;&]S92@D9BD["@H@("`@("`@
M(')E='5R;B!A<G)A>2@G=R<@/3X@)'=I9'1H+"`G:"<@/3X@)&AE:6=H="P@
M)V-S)R`]/B`D8V]L<W!A8V4L("=B<&,G(#T^("1B<&,L("=F)R`]/B`G1FQA
M=&5$96-O9&4G+"`G<&%R;7,G(#T^("1P87)M<RP@)W!A;"<@/3X@)'!A;"P@
M)W1R;G,G(#T^("1T<FYS+"`G9&%T82<@/3X@)&1A=&$I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]F<F5A9$EN="@D9BD*("`@('L*("`@("`@("`O*B!296%D
M(&$@-"UB>71E(&EN=&5G97(@9G)O;2!F:6QE+B`J+PH@("`@("`@("1I("`]
M(&]R9"AF<F5A9"@D9BP@,2DI(#P\(#(T.PH@("`@("`@("1I("L](&]R9"AF
M<F5A9"@D9BP@,2DI(#P\(#$V.PH@("`@("`@("1I("L](&]R9"AF<F5A9"@D
M9BP@,2DI(#P\(#@["B`@("`@("`@)&D@*ST@;W)D*&9R96%D*"1F+"`Q*2D[
M"B`@("`@("`@<F5T=7)N("1I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]T97AT
M4W1R:6YG*"1S*0H@("`@>PH@("`@("`@("\J($9O<FUA="!A('1E>'0@<W1R
M:6YG("HO"B`@("`@("`@<F5T=7)N("<H)R`N("1T:&ES+3Y?97-C87!E*"1S
M*2`N("<I)SL*("`@('T*"B`@("!F=6YC=&EO;B!?97-C87!E*"1S*0H@("`@
M>PH@("`@("`@("\J($%D9"!<(&)E9F]R92!<+"`H(&%N9"`I("HO"B`@("`@
M("`@<F5T=7)N('-T<E]R97!L86-E*&%R<F%Y*"<I)RPG*"<L)UQ<)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=<7"DG+"=<7"@G+"=<
M7%Q<)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1S*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<'5T4W1R96%M*"1S*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;W5T*"=S=')E86TG*3L*("`@("`@("`D=&AI<RT^7V]U="@D<RD[
M"B`@("`@("`@)'1H:7,M/E]O=70H)V5N9'-T<F5A;2<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]O=70H)',I"B`@("!["B`@("`@("`@+RH@061D(&$@;&EN
M92!T;R!T:&4@9&]C=6UE;G0N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A
M=&4@/3T@,BD@>PH@("`@("`@("`@("`D=&AI<RT^7W!A9V5S6R1T:&ES+3Y?
M<&%G95T@+CT@)',@+B`B7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?8G5F9F5R("X]("1S("X@(EQN(CL*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O0U-6+G!H<```
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,#,T
M-@`Q,#4Q-30S,3`V,``P,3<R,#0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G4$5!4BYP
M:'`G.PIR97%U:7)E7V]N8V4@)T9I;&4N<&AP)SL*"B\J*@H@*B!4:&4@1FEL
M95]#4U8@<&%C:V%G92!A;&QO=W,@<F5A9&EN9R!A;F0@8W)E871I;F<@;V8@
M0U-6(&1A=&$@86YD(&9I;&5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP+'8@,2XT+C(N-R`R,#`V+S`S+S,P(#$P.C$U.C(Y
M('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`S(%1O;6%S
M(%9O;B!697-C:&QE<B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"!T:&%T(&ES"B`J(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V
M86EL86)L92!A="!T:')O=6=H"B`J('1H92!W;W)L9"UW:61E+7=E8B!A="!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=2!D
M:60@;F]T"B`J(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4*("H@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$*("H@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&%U=&AO<B`@5&]M87,@5F]N(%9E<V-H;&5R($-O>"`\8V]X
M0&ED96-N970N8V]M/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A8VMA9V4@
M1FEL95]#4U8*("HO"F-L87-S($9I;&5?0U-6('L*"B`@("`O*BH*("`@("`J
M($1I<V-O=F5R<R!T:&4@9F]R;6%T(&]F(&$@0U-6(&9I;&4@*'1H92!N=6UB
M97(@;V8@9FEE;&1S+"!T:&4@<V5P87)A=&]R+`H@("`@("H@=&AE('%U;W1E
M('-T<FEN9RP@86YD('1H92!L:6YE(&)R96%K*2X*("`@("`J"B`@("`@*B!7
M92!C86XG="!U<V4@=&AE(&%U=&]?9&5T96-T7VQI;F5?96YD:6YG<R!02%`@
M<V5T=&EN9RP@8F5C875S92!I="=S(&YO=`H@("`@("H@<W5P<&]R=&5D(&)Y
M(&9G971S*"D@8V]N=')A<GD@=&\@=VAA="!T:&4@;6%N=6%L('-A>7,N"B`@
M("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@(%1H92!#4U8@9FEL92!N86UE"B`@("`@*B!`<&%R86T@87)R87D@("!%
M>'1R82!S97!A<F%T;W)S('1H870@<VAO=6QD(&)E(&-H96-K960@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!F;W)M870@:&%S:"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]V97)&;W)M870H)&9I;&4L("1E
M>'1R85-E<',@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A)&9P(#T@
M0&9O<&5N*"1F:6QE+"`G<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=#;W5L9"!N;W0@;W!E;B!F:6QE.B`G("X@)&9I;&4I
M.PH@("`@("`@('T*"B`@("`@("`@)'-E<',@/2!A<G)A>2@B7'0B+"`G.R<L
M("<Z)RP@)RPG*3L*("`@("`@("`D<V5P<R`](&%R<F%Y7VUE<F=E*"1S97!S
M+"`D97AT<F%397!S*3L*("`@("`@("`D;6%T8VAE<R`](&%R<F%Y*"D["B`@
M("`@("`@)&-R;&8@/2!N=6QL.PH@("`@("`@("1C;VYF(#T@87)R87DH*3L*
M"B`@("`@("`@+RH@5&%K92!T:&4@9FER<W0@,3`@;&EN97,@86YD('-T;W)E
M('1H92!N=6UB97(@;V8@;V-U<G)E;F-E<R!F;W(@96%C:`H@("`@("`@("`J
M('-E<&%R871O<B!I;B!E86-H(&QI;F4N("HO"B`@("`@("`@9F]R("@D:2`]
M(#`[("@D:2`\(#$P*2`F)B`H)&QI;F4@/2!F9V5T<R@D9G`I*3LI('L*("`@
M("`@("`@("`@+RH@1&\@=V4@:&%V92!-86,@;&EN92!E;F1I;F=S/R`J+PH@
M("`@("`@("`@("`D;&EN97,@/2!P<F5G7W-P;&ET*"<O7'(H/R%<;BDO)RP@
M)&QI;F4L(#$P*3L*("`@("`@("`@("`@)&H@/2`P.PH@("`@("`@("`@("`D
M8R`](&-O=6YT*"1L:6YE<RD["B`@("`@("`@("`@(&EF("@D8R`^(#$I('L*
M("`@("`@("`@("`@("`@("1C<FQF(#T@(EQR(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!W:&EL92`H)&D@/"`Q,"`F)B`D:B`\("1C*2!["B`@("`@
M("`@("`@("`@("`D;&EN92`]("1L:6YE<ULD:ET["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1C<FQF*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y*")<<EQN(BP@(EQN(BD@87,@)&,I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D;&EN92P@+7-T<FQE;B@D8RDI
M(#T]("1C*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W)L9B`]
M("1C.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("`@("`@)&HK*SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S97!S
M(&%S("1S97`I('L*("`@("`@("`@("`@("`@("`@("`D;6%T8VAE<ULD<V5P
M75LD:5T@/2!S=6)S=')?8V]U;G0H)&QI;F4L("1S97`I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AI
M<W-E="@D8W)L9BDI('L*("`@("`@("`@("`@)&-O;F9;)V-R;&8G72`]("1C
M<FQF.PH@("`@("`@('T*"B`@("`@("`@+RH@1W)O=7`@=&AE(')E<W5L=',@
M8GD@86UO=6YT(&]F(&5Q=6%L(&]C=7)R96YC97,N("HO"B`@("`@("`@)&9I
M96QD<R`](&%R<F%Y*"D["B`@("`@("`@)&%M;W5N="`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)'-E<"`]/B`D;&EN97,I('L*
M("`@("`@("`@("`@)'1I;65S(#T@87)R87DH*3L*("`@("`@("`@("`@)'1I
M;65S6S!=(#T@,#L*("`@("`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1N
M=6TI('L*("`@("`@("`@("`@("`@(&EF("@D;G5M(#X@,"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:6UE<ULD;G5M72`]("AI<W-E="@D=&EM97-;)&YU
M;5TI*2`_("1T:6UE<ULD;G5M72`K(#$@.B`Q.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&%R<V]R="@D=&EM97,I.PH@
M("`@("`@("`@("`D9FEE;&1S6R1S97!=(#T@:V5Y*"1T:6UE<RD["B`@("`@
M("`@("`@("1A;6]U;G1;)'-E<%T@/2`D=&EM97-;:V5Y*"1T:6UE<RE=.PH@
M("`@("`@('T*("`@("`@("!A<G-O<G0H)&%M;W5N="D["B`@("`@("`@)'-E
M<"`](&ME>2@D86UO=6YT*3L*"B`@("`@("`@)&-O;F9;)V9I96QD<R==(#T@
M)&9I96QD<ULD<V5P72`K(#$["B`@("`@("`@)&-O;F9;)W-E<"==("`@(#T@
M)'-E<#L*"B`@("`@("`@+RH@5&5S="!I9B!T:&5R92!A<F4@9FEE;&1S('=I
M=&@@<75O=&5S(&%R<F]U;F0@:6X@=&AE(&9I<G-T(#4*("`@("`@("`@*B!L
M:6YE<RX@*B\*("`@("`@("`D<75O=&5S(#T@)R)<)R<["B`@("`@("`@)'%U
M;W1E("`]("<G.PH@("`@("`@(')E=VEN9"@D9G`I.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`H)&D@/"`U*2`F)B`H)&QI;F4@/2!F9V5T<R@D9G`I*3L@)&DK
M*RD@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B?"1S97`H6R1Q=6]T
M97-=*2XJ*%LD<75O=&5S72DD<V5P?%4B+"`D;&EN92P@)&UA=&-H*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1M871C:%LQ72`]/2`D;6%T8VA;,ETI('L*
M("`@("`@("`@("`@("`@("`@("`D<75O=&4@/2`D;6%T8VA;,5T["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(GQ>*%LD<75O
M=&5S72DN*BA;)'%U;W1E<UTI)'-E<'PB+"`D;&EN92P@)&UA=&-H*2!\?`H@
M("`@("`@("`@("`@("`@<')E9U]M871C:"@B?"A;)'%U;W1E<UTI+BHH6R1Q
M=6]T97-=*21S97!<<R1\57,B+"`D;&EN92P@)&UA=&-H*2D*("`@("`@("`@
M("`@>PH@("`@("`@("`@("`@("`@:68@*"1M871C:%LQ72`]/2`D;6%T8VA;
M,ETI('L*("`@("`@("`@("`@("`@("`@("`D<75O=&4@/2`D;6%T8VA;,5T[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&-O;F9;)W%U;W1E
M)UT@/2`D<75O=&4["@H@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`O
M+R!86%@@5VAA="!A8F]U="!T<GEI;F<@=&\@9&ES8V]V97(@=&AE(")H96%D
M97(B/PH@("`@("`@(')E='5R;B`D8V]N9CL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E861S(&$@<F]W(&9R;VT@82!#4U8@9FEL92!A;F0@<F5T=7)N<R!I
M="!A<R!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE("!4:&4@;F%M92!O9B!T:&4@0U-6(&9I;&4N"B`@("`@*B!`<&%R86T@
M87)R87D@)&-O;F8@("!4:&4@8V]N9FEG=7)A=&EO;B!F;W(@=&AE($-35B!F
M:6QE+@H@("`@("H*("`@("`J($!R971U<FX@87)R87E\8F]O;&5A;B`@5&AE
M($-35B!D871A(&]R(&9A;'-E(&EF(&YO(&UO<F4@9&%T82!A=F%I;&%B;&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&9I;&4L("8D8V]N9BD*("`@
M('L*("`@("`@("`D9G`@/2!&:6QE7T-35CHZ9V5T4&]I;G1E<B@D9FEL92P@
M)&-O;F8L($9)3$5?34]$15]214%$*3L*("`@("`@("!I9B`H:7-?82@D9G`L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@
M("`@("!]"@H@("`@("`@("1L:6YE(#T@9F=E=',H)&9P*3L*("`@("`@("!I
M9B`H(21L:6YE*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J(%5S92!R96%D475O=&5D*"D@:68@=V4@:&%V92!-
M86,@;&EN92!E;F1I;F=S+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7'(H/R%<;BDO)RP@)&QI;F4I*2!["B`@("`@("`@("`@(&9S965K*"1F<"P@
M+7-T<FQE;B@D;&EN92DL(%-%14M?0U52*3L*("`@("`@("`@("`@<F5T=7)N
M($9I;&5?0U-6.CIR96%D475O=&5D*"1F:6QE+"`D8V]N9BD["B`@("`@("`@
M?0H*("`@("`@("!&:6QE7T-35CHZ7VQI;F4H1FEL95]#4U8Z.E]L:6YE*"D@
M*R`Q*3L*"B`@("`@("`@:68@*"1C;VYF6R=F:65L9',G72`]/2`Q*2!["B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@D;&EN92D["B`@("`@("`@?0H*("`@
M("`@("`D9FEE;&1S(#T@97AP;&]D92@D8V]N9ELG<V5P)UTL("1L:6YE*3L*
M("`@("`@("!I9B`H)&-O;F9;)W%U;W1E)UTI('L*("`@("`@("`@("`@)&QA
M<W0@/2`F)&9I96QD<UMC;W5N="@D9FEE;&1S*2`M(#%=.PH@("`@("`@("`@
M("`O*B!&86QL8F%C:R!T;R!R96%D('1H92!L:6YE('=I=&@@<F5A9%%U;W1E
M9"@I('=H96X@9W5E<W,@=&AA="!T:&4*("`@("`@("`@("`@("H@<VEM<&QE
M(&5X<&QO9&4@=V]N)W0@=V]R:R!R:6=H="X@*B\*("`@("`@("`@("`@:68@
M*"AS=6)S='(H)&QA<W0L("US=')L96XH)&-O;F9;)V-R;&8G72DI(#T]("1C
M;VYF6R=C<FQF)UT@)B8*("`@("`@("`@("`@("`@("`D;&%S='LP?2`]/2`D
M8V]N9ELG<75O=&4G72`F)@H@("`@("`@("`@("`@("`@("1L87-T>W-T<FQE
M;BAR=')I;2@D;&%S="DI("T@,7T@(3T@)&-O;F9;)W%U;W1E)UTI('Q\"B`@
M("`@("`@("`@("`@("`H8V]U;G0H)&9I96QD<RD@(3T@)&-O;F9;)V9I96QD
M<R==*0H@("`@("`@("`@("`@("`@("`@("\O(%A86"!P97)H87!S('1H97)E
M(&ES(&$@<V5P87)A=&]R(&EN<VED92!A('%U;W1E9"!F:65L9`H@("`@("`@
M("`@("`@("`@("`@("\O<')E9U]M871C:"@B?'LD8V]N9ELG<75O=&4G77TN
M*GLD8V]N9ELG<V5P)UU]+BI[)&-O;F9;)W%U;W1E)UU]?%4B+"`D;&EN92D*
M("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@
M("`@9G-E96LH)&9P+"`M<W1R;&5N*"1L:6YE*2P@4T5%2U]#55(I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N($9I;&5?0U-6.CIR96%D475O=&5D*"1F:6QE
M+"`D8V]N9BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;&%S="`](')T<FEM*"1L87-T*3L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1F:65L9',@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@
M("`D9FEE;&1S6R1K72`]($9I;&5?0U-6.CIU;G%U;W1E*"1V+"`D8V]N9ELG
M<75O=&4G72P@)&-O;F9;)V-R;&8G72D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEE
M;&1S6V-O=6YT*"1F:65L9',I("TQ72`](')T<FEM*"1F:65L9'-;8V]U;G0H
M)&9I96QD<RD@+3%=*3L*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D
M9FEE;&1S*2`\("1C;VYF6R=F:65L9',G72D@>PH@("`@("`@("`@("!&:6QE
M7T-35CHZ=V%R;FEN9RAS<')I;G1F*%\H(E=R;VYG(&YU;6)E<B!O9B!F:65L
M9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(I+"!&:6QE
M7T-35CHZ7VQI;F4H*2P@)&-O;F9;)V9I96QD<R==+"!C;W5N="@D9FEE;&1S
M*2DI.PH@("`@("`@("`@("`D9FEE;&1S(#T@87)R87E?;65R9V4H)&9I96QD
M<RP@87)R87E?9FEL;"@P+"`D8V]N9ELG9FEE;&1S)UT@+2!C;W5N="@D9FEE
M;&1S*2P@)R<I*3L*("`@("`@("!](&5L<V5I9B`H8V]U;G0H)&9I96QD<RD@
M/B`D8V]N9ELG9FEE;&1S)UTI('L*("`@("`@("`@("`@1FEL95]#4U8Z.G=A
M<FYI;F<H<W!R:6YT9BA?*")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D
M('1H86X@=&AE(&5X<&5C=&5D("5D+B(I+"!&:6QE7T-35CHZ7VQI;F4H*2P@
M)&-O;F9;)V9I96QD<R==*2D["B`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D
M9FEE;&1S+"`D8V]N9ELG9FEE;&1S)UTI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1F:65L9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!A
M(')O=R!F<F]M(&$@0U-6(&9I;&4@86YD(')E='5R;G,@:70@87,@86X@87)R
M87DN"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!A8FQE('1O(')E860@9FEE;&1S
M('=I=&@@;75L=&EL:6YE(&1A=&$@86YD(&YO<FUA;&EZ97,*("`@("`J(&QI
M;F5B<F5A:W,@=&\@<VEN9VQE(&YE=VQI;F4@8VAA<F%C=&5R<R`H,'@P82DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@5&AE(&YA;64@
M;V8@=&AE($-35B!F:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@
M5&AE(&-O;F9I9W5R871I;VX@9F]R('1H92!#4U8@9FEL92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y?&)O;VQE86X@(%1H92!#4U8@9&%T82!O<B!F
M86QS92!I9B!N;R!M;W)E(&1A=&$@879A:6QA8FQE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96%D475O=&5D*"1F:6QE+"`F)&-O;F8I"B`@("!["B`@("`@
M("`@)&9P(#T@1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF+"!&
M24Q%7TU/1$5?4D5!1"D["B`@("`@("`@:68@*&ES7V$H)&9P+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H*
M("`@("`@("`O*B!!(&)U9F9E<B!W:71H(&%L;"!C:&%R86-T97)S(&]F('1H
M92!C=7)R96YT(&9I96QD(')E860@<V\@9F%R+B`J+PH@("`@("`@("1B=69F
M(#T@)R<["B`@("`@("`@+RH@5&AE(&-U<G)E;G0@8VAA<F%C=&5R+B`J+PH@
M("`@("`@("1C(#T@;G5L;#L*("`@("`@("`O*B!4:&4@<F5A9"!F:65L9',N
M("HO"B`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@+RH@5&AE(&YU
M;6)E<B!O9B!T:&4@8W5R<F5N="!F:65L9"X@*B\*("`@("`@("`D:2`](#$[
M"B`@("`@("`@+RH@07)E('=E(&EN<VED92!A('%U;W1E9"!F:65L9#\@*B\*
M("`@("`@("`D:6Y?<75O=&4@/2!F86QS93L*"B`@("`@("`@=VAI;&4@*"@D
M8V@@/2!F9V5T8R@D9G`I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@+RH@
M4')E=FEO=7,@8VAA<F%C=&5R+B`J+PH@("`@("`@("`@("`D<')E=B`]("1C
M.PH@("`@("`@("`@("`O*B!#=7)R96YT(&-H87)A8W1E<BX@*B\*("`@("`@
M("`@("`@)&,@/2`D8V@["@H@("`@("`@("`@("`O*B!3:6UP;&4@8VAA<F%C
M=&5R+B`J+PH@("`@("`@("`@("!I9B`H)&,@(3T@)&-O;F9;)W%U;W1E)UT@
M)B8*("`@("`@("`@("`@("`@("1C("$]("1C;VYF6R=S97`G72`F)@H@("`@
M("`@("`@("`@("`@<W1R<&]S*"1C;VYF6R=C<FQF)UTL("1C*2`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@("`@("1B=69F("X]("1C.PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@D8V]N9ELG<75O=&4G72`F)B`D8R`]/2`D8V]N9ELG<75O=&4G72`F)@H@
M("`@("`@("`@("`@("`@*"1P<F5V(#T]("1C;VYF6R=S97`G72!\?`H@("`@
M("`@("`@("`@("`@("1P<F5V(#T]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M
M,2D@?'P*("`@("`@("`@("`@("`@("`D<')E=B`]/3T@;G5L;"DI"B`@("`@
M("`@("`@('L*("`@("`@("`@("`@("`@("\J(%%U;W1E(&)E9VEN+B`J+PH@
M("`@("`@("`@("`@("`@)&EN7W%U;W1E(#T@=')U93L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1I;E]Q=6]T92D@>PH@("`@("`@("`@("`@("`@+RH@475O
M=&4@96YD/R`J+PH@("`@("`@("`@("`@("`@:68@*"1C(#T]("1C;VYF6R=S
M97`G72`F)B`D<')E=B`]/2`D8V]N9ELG<75O=&4G72D@>PH@("`@("`@("`@
M("`@("`@("`@("1I;E]Q=6]T92`](&9A;'-E.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1C(#T]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M,2DI('L*
M("`@("`@("`@("`@("`@("`@("`D<W5B(#T@*'-T<FQE;B@D8V]N9ELG8W)L
M9B==*2`^(#$@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5V
M(#T]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M,BP@,2DI"B`@("`@("`@("`@
M("`@("`@("`@("`@(#\@,@H@("`@("`@("`@("`@("`@("`@("`@("`Z(#$[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"AS=')L96XH)&)U9F8I(#X]("1S
M=6(I("8F"B`@("`@("`@("`@("`@("`@("`@("`@("@D8G5F9GMS=')L96XH
M)&)U9F8I("T@)'-U8GT@/3T@)&-O;F9;)W%U;W1E)UTI*0H@("`@("`@("`@
M("`@("`@("`@('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN7W%U;W1E
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@1FEL95]#4U8Z.E]L:6YE*$9I;&5?0U-6.CI?
M;&EN92@I("L@,2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!%;F0@;V8@
M;&EN92!O<B!E;F0@;V8@9FEE;&0N("HO"B`@("`@("`@("`@(&EF("@A)&EN
M7W%U;W1E("8F"B`@("`@("`@("`@("`@("`H)&,@/3T@)&-O;F9;)W-E<"==
M('Q\("1C(#T]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M,2DI*2!["B`@("`@
M("`@("`@("`@("`O*B!-;W)E(&9I96QD<R!T:&%N(&5X<&5C=&5D+B`J+PH@
M("`@("`@("`@("`@("`@:68@*"1C(#T]("1C;VYF6R=S97`G72`F)@H@("`@
M("`@("`@("`@("`@("`@("AC;W5N="@D<F5T*2`K(#$I(#T]("1C;VYF6R=F
M:65L9',G72D@>PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@D8R`A/3T@
M9F%L<V4@)B8@)&,@(3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL("TQ*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8R`](&9G971C*"1F<"D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@($9I;&5?0U-6
M.CIW87)N:6YG*'-P<FEN=&8H7R@B36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB*2P@1FEL95]#4U8Z.E]L:6YE
M*"DL("1C;VYF6R=F:65L9',G72DI.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(&EF("@D<')E=B`]/2!S=6)S='(H)&-O;F9;)V-R;&8G
M72P@+3(L(#$I*2!["B`@("`@("`@("`@("`@("`@("`@)&)U9F8@/2!S=6)S
M='(H)&)U9F8L(#`L("TQ*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`O*B!,97-S(&9I96QD<R!T:&%N(&5X<&5C=&5D+B`J+PH@("`@
M("`@("`@("`@("`@:68@*"@D8R`]/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@
M+3$I*2`F)@H@("`@("`@("`@("`@("`@("`@("@D:2`A/2`D8V]N9ELG9FEE
M;&1S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1I(#T](#$I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@+RH@4VMI<"!E;7!T>2!L:6YE<RX@
M*B\*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@($9I;&5?0U-6
M.CIW87)N:6YG*'-P<FEN=&8H7R@B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(BDL($9I;&5?0U-6
M.CI?;&EN92@I+"`D8V]N9ELG9FEE;&1S)UTL("1I*2D["@H@("`@("`@("`@
M("`@("`@("`@("1R971;72`]($9I;&5?0U-6.CIU;G%U;W1E*"1B=69F+"`D
M8V]N9ELG<75O=&4G72P@)&-O;F9;)V-R;&8G72D["B`@("`@("`@("`@("`@
M("`@("`@)')E="`](&%R<F%Y7VUE<F=E*"1R970L(&%R<F%Y7V9I;&PH,"P@
M)&-O;F9;)V9I96QD<R==("T@)&DL("<G*2D["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R970["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)')E=%M=(#T@1FEL95]#4U8Z.G5N<75O=&4H)&)U9F8L("1C;VYF
M6R=Q=6]T92==+"`D8V]N9ELG8W)L9B==*3L*("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D<F5T*2`]/2`D8V]N9ELG9FEE;&1S)UTI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D8G5F9B`]("<G.PH@("`@("`@("`@("`@("`@)&DK
M*SL*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1B=69F("X]("1C.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&9E;V8H)&9P*2`_(&9A;'-E(#H@)')E=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%=R:71E<R!A(&AA<V@@:6YT;R!A($-35B!F:6QE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("!4:&4@;F%M92!O9B!T:&4@
M0U-6(&9I;&4N"B`@("`@*B!`<&%R86T@87)R87D@)&9I96QD<R`@5&AE($-3
M5B!D871A+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@(%1H92!C;VYF
M:6=U<F%T:6]N(&9O<B!T:&4@0U-6(&9I;&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&9I;&4L("1F
M:65L9',L("8D8V]N9BD*("`@('L*("`@("`@("!I9B`H:7-?82@D9G`@/2!&
M:6QE7T-35CHZ9V5T4&]I;G1E<B@D9FEL92P@)&-O;F8L($9)3$5?34]$15]7
M4DE412DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F
M<#L*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D9FEE;&1S*2`A/2`D
M8V]N9ELG9FEE;&1S)UTI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(BDL("1C;VYF6R=F:65L9',G72P@8V]U
M;G0H)&9I96QD<RDI*3L*("`@("`@("!]"@H@("`@("`@("1W<FET92`]("<G
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1F:65L9',I.R`D
M:2LK*2!["B`@("`@("`@("`@(&EF("@A:7-?;G5M97)I8R@D9FEE;&1S6R1I
M72D@)B8@)&-O;F9;)W%U;W1E)UTI('L*("`@("`@("`@("`@("`@("1W<FET
M92`N/2`D8V]N9ELG<75O=&4G72`N("1F:65L9'-;)&E=("X@)&-O;F9;)W%U
M;W1E)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=W)I=&4@+CT@)&9I96QD<ULD:5T["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1I(#P@*&-O=6YT*"1F:65L9',I("T@,2DI('L*("`@("`@("`@
M("`@("`@("1W<FET92`N/2`D8V]N9ELG<V5P)UT["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=W)I=&4@+CT@)&-O;F9;)V-R;&8G
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%F=W)I
M=&4H)&9P+"`D=W)I=&4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B0V%N;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(BDL("1F:6QE*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@<W5R<F]U;F1I;F<@
M<75O=&5S(&9R;VT@82!S=')I;F<@86YD(&YO<FUA;&EZ97,@;&EN96)R96%K
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@5&AE('-T
M<FEN9R!T;R!U;G%U;W1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75O=&4@
M(%1H92!Q=6]T92!C:&%R86-T97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M<FQF("`@5&AE(&QI;F5B<F5A:R!C:&%R86-T97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!U;G%U;W1E9"!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U;G%U;W1E*"1F:65L9"P@)'%U;W1E+"`D8W)L9BD*("`@
M('L*("`@("`@("`O*B!3:VEP(&5M<'1Y(&9I96QD<R`H9F]R;3H@.SLI("HO
M"B`@("`@("`@:68@*"%S=')L96XH)&9I96QD*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&9I96QD.PH@("`@("`@('T*("`@("`@("!I9B`H)'%U;W1E("8F
M("1F:65L9'LP?2`]/2`D<75O=&4@)B8@)&9I96QD>W-T<FQE;B@D9FEE;&0I
M+3%](#T]("1Q=6]T92D@>PH@("`@("`@("`@("!R971U<FX@<W1R7W)E<&QA
M8V4H)&-R;&8L(")<;B(L('-U8G-T<B@D9FEE;&0L(#$L("TQ*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D9FEE;&0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S(&]R(&=E=',@=&AE(&-U<G)E;G0@;&EN92!B96EN9R!P87)S
M960N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;F4@($EF('-P
M96-I9FEE9"P@=&AE(&-U<G)E;G0@;&EN92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!C=7)R96YT(&QI;F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]L:6YE*"1L:6YE(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T
M:6,@)&-U<G)E;G1?;&EN92`](#`["@H@("`@("`@(&EF("@A:7-?;G5L;"@D
M;&EN92DI('L*("`@("`@("`@("`@)&-U<G)E;G1?;&EN92`]("1L:6YE.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C=7)R96YT7VQI;F4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=V%R;FEN9R!T;R!O<B!R971R:65V
M97,@86YD(')E<V5T<R!T:&4@=V%R;FEN9R!S=&%C:RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("!!('=A<FYI;F<@<W1R:6YG+B`@268@;F]T('-P
M96-I9FEE9"P@=&AE(&5X:7-T:6YG"B`@("`@*B`@("`@("`@("`@("`@("!W
M87)N:6YG<R!W:6QL(&)E(')E='5R;F5D(&EN<W1E860@86YD('1H92!W87)N
M:6YG('-T86-K"B`@("`@*B`@("`@("`@("`@("`@("!G971S(&5M<'1I960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@268@;F\@<&%R86UE=&5R
M(&AA<R!B965N('-P96-I9FEE9"P@=&AE(&QI<W0@;V8@97AI<W1I;F<*("`@
M("`J("`@("`@("`@("`@("`@('=A<FYI;F=S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!W87)N:6YG*"1W87)N:6YG(#T@;G5L;"D*("`@('L*("`@("`@("!S
M=&%T:6,@)'=A<FYI;F=S(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES7VYU
M;&PH)'=A<FYI;F<I*2!["B`@("`@("`@("`@("1R971U<FX@/2`D=V%R;FEN
M9W,["B`@("`@("`@("`@("1W87)N:6YG<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@(')E='5R;B`D<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'=A<FYI
M;F=S6UT@/2`D=V%R;FEN9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@;W(@8W)E871E<R!T:&4@9FEL92!D97-C<FEP=&]R(&%S<V]C:6%T960@
M=VET:"!A(&9I;&4N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&4@(%1H92!N86UE(&]F('1H92!F:6QE
M"B`@("`@*B!`<&%R86T@87)R87D@)&-O;F8@("!4:&4@8V]N9FEG=7)A=&EO
M;@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D92`@5&AE(&]P96X@;6]D92X@
M1DE,15]-3T1%7U)%040@;W(@1DE,15]-3T1%7U=2251%+@H@("`@("H*("`@
M("`J($!R971U<FX@<F5S;W5R8V4@(%1H92!F:6QE(')E<V]U<F-E(&]R(%!%
M05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!O
M:6YT97(H)&9I;&4L("8D8V]N9BP@)&UO9&4@/2!&24Q%7TU/1$5?4D5!1"D*
M("`@('L*("`@("`@("!S=&%T:6,@)')E<V]U<F-E<R`](&%R<F%Y*"D["B`@
M("`@("`@<W1A=&EC("1C;VYF:6<@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG
M;F%T=7)E(#T@)&9I;&4@+B!S97)I86QI>F4H)&-O;F8I.PH@("`@("`@(&EF
M("AI<W-E="@D<F5S;W5R8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@
M("`D8V]N9B`]("1C;VYF:6=;)'-I9VYA='5R95T["B`@("`@("`@("`@(')E
M='5R;B`D<F5S;W5R8V5S6R1S:6=N871U<F5=.PH@("`@("`@('T*("`@("`@
M("!I9B`H:7-?82@D97)R;W(@/2!&:6QE7T-35CHZ7V-H96-K0V]N9FEG*"1C
M;VYF*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@('T*("`@("`@("`D8V]N9FEG6R1S:6=N871U<F5=(#T@
M)&-O;F8["@H@("`@("`@("1F<"`]($!F;W!E;B@D9FEL92P@)&UO9&4I.PH@
M("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-A;B=T(&]P96X@
M9FEL92!<(B5S7"(N(BDL("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@("1R
M97-O=7)C97-;)'-I9VYA='5R95T@/2`D9G`["B`@("`@("`@1FEL95]#4U8Z
M.E]L:6YE*#`I.PH*("`@("`@("!I9B`H)&UO9&4@/3T@1DE,15]-3T1%7U)%
M040@)B8@(65M<'1Y*"1C;VYF6R=H96%D97(G72DI('L*("`@("`@("`@("`@
M:68@*&ES7V$H)&AE861E<B`]($9I;&5?0U-6.CIR96%D*"1F:6QE+"`D8V]N
M9BDL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M:&5A9&5R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&9P.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!C;VYF
M:6=U<F%T:6]N(&=I=F5N(&)Y('1H92!U<V5R+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D8V]N9B`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<W-O8R!A
M<G)A>0H@("`@("H@0'!A<F%M('-T<FEN9R`D97)R;W(@(%1H92!E<G)O<B!W
M:6QL(&)E('=R:71T96X@:&5R92!I9B!A;GD*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-H96-K0V]N9FEG*"8D8V]N9BD*("`@('L*("`@("`@("`O+R!C:&5C
M:R!C;VYF"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]N9BDI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@8V]N9FEG
M=7)A=&EO;BXG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&-O
M;F9;)V9I96QD<R==*2!\?"`A:7-?;G5M97)I8R@D8V]N9ELG9FEE;&1S)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H
M92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O;F9;)W-E<"==*2D@>PH@("`@
M("`@("`@("!I9B`H<W1R;&5N*"1C;VYF6R=S97`G72D@(3T@,2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('-E
M<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(I*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D8V]N9ELG9FEE;&1S)UT@
M/B`Q*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(DYO('-E<&%R871O<B!S<&5C:69I960N(BDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG<75O=&4G72DI('L*("`@("`@("`@("`@
M:68@*'-T<FQE;B@D8V]N9ELG<75O=&4G72D@(3T@,2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('%U;W1E(&-H
M87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(I*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYF
M6R=Q=6]T92==(#T@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T
M*"1C;VYF6R=C<FQF)UTI*2!["B`@("`@("`@("`@("1C;VYF6R=C<FQF)UT@
M/2`B7&XB.PH@("`@("`@('T*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="\`````````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8P`#`Q-C$P,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT
M+W)E4U0O````````````````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-C``,#$V-S4V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U1E>'0O<F535"]&;W)M871T97(O````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,C`W
M,C$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]R95-4+T9O<FUA
M='1E<B]H=&UL+G!H<```````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,3`Q
M`#$P-3$U-#,Q,#8P`#`R,C,W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B]&;W)M871T97(N<&AP)SL*"B\J*@H@*B!4:&4@
M5&5X=%]R95-47T9O<FUA='1E<E]H=&UL.CH@8VQA<W,@:7,@=&AE($A434P@
M9F]R;6%T=&5R+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7W)E4U0O
M<F535"]&;W)M871T97(O:'1M;"YP:'`L=B`Q+C8N,3(N-2`R,#`V+S`Q+S`Q
M(#(Q.C(X.C,Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI
M8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!497AT7W)E4U0*("HO"F-L
M87-S(%1E>'1?<F535%]&;W)M871T97)?:'1M;"!E>'1E;F1S(%1E>'1?<F53
M5%]&;W)M871T97(@>PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@;W5T
M<'5T(&-H87)S970N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?8VAA<G-E="`](&YU;&P["@H@("`@9G5N8W1I;VX@9F]R
M;6%T*"8D;F]D92P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@A:7-S970H)&-H87)S970I*2!["B`@("`@("`@("`@("1C:&%R<V5T(#T@
M)'1H:7,M/E]C:&%R<V5T.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7W-T
M<FEN9R@D;F]D92DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1C:&%R<V5T
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N($!H=&UL<W!E8VEA;&-H87)S
M*"1N;V1E+"!%3E1?455/5$53+"`D8VAA<G-E="D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@:'1M;'-P96-I86QC:&%R
M<R@D;F]D92P@14Y47U%53U1%4RD["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@('-W:71C:"`H)&YO9&4M/E]T>7!E*2!["B`@("`@("`@8V%S
M92`G1&]C=6UE;G0G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C:&EL
M9')E;B@D;F]D92D["@H@("`@("`@(&-A<V4@)TAE861I;F<G.@H@("`@("`@
M("`@("`D;&5V96P@/2`D;F]D92T^9V5T4')O<&5R='DH)VQE=F5L)RD["B`@
M("`@("`@("`@(')E='5R;B`G/&@G("X@)&QE=F5L("X@)SXG("X@)'1H:7,M
M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]H)R`N"B`@("`@("`@("`@("`@("`D
M;&5V96P@+B`G/B<["@H@("`@("`@(&-A<V4@)TQI;FLG.@H@("`@("`@("`@
M("!R971U<FX@)SQA(&AR968](B<@+@H@("`@("`@("`@("`@("`@*&ES<V5T
M*"1C:&%R<V5T*2`_"B`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA
M<G,H)&YO9&4M/F=E=%!R;W!E<G1Y*"=H<F5F)RDL($5.5%]154]415,L("1C
M:&%R<V5T*2`Z"B`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D
M;F]D92T^9V5T4')O<&5R='DH)VAR968G*2P@14Y47U%53U1%4RDI("X*("`@
M("`@("`@("`@("`@("<B/B<@+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M:&EL9')E;B@D;F]D92D@+B`G/"]A/B<["@H@("`@("`@(&-A<V4@)TQI=&5R
M86PM0FQO8VLG.@H@("`@("`@("`@("!L:7-T*"1T97AT*2`]("1N;V1E+3Y?
M8VAI;&1R96X["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@*&ES<V5T
M*"1C:&%R<V5T*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H
M=&UL<W!E8VEA;&-H87)S*"1T97AT+"!%3E1?455/5$53+"`D8VAA<G-E="D@
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H
M87)S*"1T97AT+"!%3E1?455/5$53*2D@+B`G/"]P<F4^)SL*"B`@("`@("`@
M8V%S92`G4&%R86=R87!H)SH*("`@("`@("`@("`@<F5T=7)N("(\<#XB("X@
M)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`B/"]P/B(["@H@("`@("`@(&-A
M<V4@)TEN=&5R<')E=&5D+51E>'0G.@H@("`@("`@("`@("!S=VET8V@@*"1N
M;V1E+3YG9710<F]P97)T>2@G<F]L92<I*2!["B`@("`@("`@("`@(&-A<V4@
M)V5M<&AA<VES)SH*("`@("`@("`@("`@("`@(')E='5R;B`G/&5M/B<@+B`D
M=&AI<RT^7V-H:6QD<F5N*"1N;V1E*2`N("<\+V5M/B<["@H@("`@("`@("`@
M("!C87-E("=L:71E<F%L)SH*("`@("`@("`@("`@("`@(')E='5R;B`G/'1T
M/B<@+B`D=&AI<RT^7V-H:6QD<F5N*"1N;V1E*2`N("<\+W1T/B<["@H@("`@
M("`@("`@("!C87-E("=S=')O;F<G.@H@("`@("`@("`@("`@("`@<F5T=7)N
M("<\<W1R;VYG/B<@+B`D=&AI<RT^7V-H:6QD<F5N*"1N;V1E*2`N("<\+W-T
M<F]N9SXG.PH*("`@("`@("`@("`@8V%S92`G<W5P97)S8W)I<'0G.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("<\<W5P/B<@+B`D=&AI<RT^7V-H:6QD<F5N
M*"1N;V1E*2`N("<\+W-U<#XG.PH*("`@("`@("`@("`@8V%S92`G<W5B<V-R
M:7!T)SH*("`@("`@("`@("`@("`@(')E='5R;B`G/'-U8CXG("X@)'1H:7,M
M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]S=6(^)SL*"B`@("`@("`@("`@(&-A
M<V4@)W1I=&QE+7)E9F5R96YC92<Z"B`@("`@("`@("`@("`@("!R971U<FX@
M)SQC:71E/B<@+B`D=&AI<RT^7V-H:6QD<F5N*"1N;V1E*2`N("<\+V-I=&4^
M)SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`O+R!8
M6%@Z($ES<W5E(&$@=V%R;FEN9RX*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-H:6QD<F5N*"1N;V1E*3L*("`@("`@("`@("`@?0H*("`@("`@
M("!C87-E("=396-T:6]N)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8VAI;&1R96XH)&YO9&4I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?8VAI;&1R96XH)B1N;V1E*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`G
M)SL*("`@("`@("!F;W)E86-H("@D;F]D92T^7V-H:6QD<F5N(&%S("1C:&EL
M9"D@>PH@("`@("`@("`@("`D<F5S=6QT("X]("1T:&ES+3YF;W)M870H)&-H
M:6QD*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O<F535"]087)S
M97(N<&AP````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,3<T
M,``Q,#4Q-30S,3`V,``P,C`W,S``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!497AT7W)E4U1?
M4&%R<V5R.CH@8VQA<W,@:6UP;&5M96YT<R!A('!A<G-E<B!F;W(@<F53=')U
M8W1U<F5D5&5X=`H@*B!D;V-U;65N=',N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U1E>'1?<F535"]R95-4+U!A<G-E<BYP:'`L=B`Q+C@N,BXX(#(P,#8O
M,#$O,#$@,C$Z,C@Z,SD@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\
M:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%1E>'1?<F535`H@
M*B\*8VQA<W,@5&5X=%]R95-47U!A<G-E<B!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<&%R<V4@=')E92X*("`@("`J"B`@("`@*B!`=F%R(%1E>'1?<F535`H@
M("`@("HO"B`@("!V87(@)%]D;V-U;65N=#L*"B`@("`O*BH*("`@("`J($$@
M:&%S:"!O9B!A9&]R;FUE;G0@;&5V96QS+@H@("`@("H*("`@("`J(%1H92!K
M97ES(&%R92!O;F4M8VAA<F%C=&5R(&]R('1W;RUC:&%R86-T97(@<W1R:6YG
M<RX@(%1H92!O;F4M8VAA<F%C=&5R"B`@("`@*B!S=')I;F=S(')E<')E<V5N
M="!U;F1E<FQI;F4@861O<FYM96YT<R!O9B!T:&4@<W!E8VEF:65D(&-H87)A
M8W1E<BP@86YD"B`@("`@*B!T:&4@9&]U8FQE+6-H87)A8W1E<B!K97ES(&%R
M92!T:&4@=6YD97)L:6YE+6%N9"UO=F5R;&EN92!S='EL97,N("!4:&4*("`@
M("`J('9A;'5E<R!A<W-O8VEA=&5D('=I=&@@=&AE(&ME>7,@87)E(&EN=&5G
M97)S(')E<')E<V5N=&EN9R!T:&4*("`@("`J(&%D;W)N;65N="=S(&AE861I
M;F<@;&5V96PN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]A9&]R;FUE;G1,979E;',@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?
M<F535%]087)S97(H*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A('!A<G-E('1R964@<F5P<F5S96YT:6YG(&$@9&]C=6UE;G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AI<R!I<R!T:&4@
M=&5X="!O9B!T:&4@9&]C=6UE;G0@=&\@<&%R<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!497AT7W)E4U0@(%1H92!P87)S92!T<F5E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<&%R<V4H)'1E>'0I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]T97AT(#T@)'1E>'0["@H@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXO<F535"YP:'`G.PH*("`@("`@("`D=&AI<RT^
M7V1O8W5M96YT(#T@)FYE=R!497AT7W)E4U0H)T1O8W5M96YT)RD["B`@("`@
M("`@)'1H:7,M/E]P=7-H4W1A=&4H)'1H:7,M/E]D;V-U;65N="P@)U-E8W1I
M;VXG+"`P*3L*"B`@("`@("`@=VAI;&4@*"1T:&ES+3Y?;F5X="@I*2!["@H@
M("`@("`@("`@("`O+PH@("`@("`@("`@("`O+R!087)S92!A(&`N+B<@9&ER
M96-T:79E+B`@5V4@<F5W<FET92!A;B!@7U\G(&1I<F5C=&EV92!T;R!A"B`@
M("`@("`@("`@("\O(&`N+B!?7SH@)R!D:7)E8W1I=F4@:&5R92X*("`@("`@
M("`@("`@+R\*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*%PN7"Y\
M7U\I7',K*"XJ/RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&EN94)U9F9E<ELP72P@)&TI*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&U;,5T@/3T@)U]?)RD@>PH@("`@("`@("`@("`@("`@("`@("1T
M97AT(#T@)U]?.B`G("X@)&U;,ET["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!W:&EL92`H)'1H:7,M/E]E;G-U
M<F5,:6YE<R@R*2`F)@H@("`@("`@("`@("`@("`@("`@("`@('!R96=?;6%T
M8V@H)R]>("`H6UY<<UTN*C\I7',J)"\G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R6S%=+"`D;2DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2`G("<N)&U;,5T["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]N97AT*"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E1&ER96-T:79E*"1T
M97AT*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O+PH@("`@("`@("`@("`O+R!,;V]K(&9O<B!O=F5R
M;&EN92UA;F0M=6YD97)L:6YE(&AE861I;F=S+@H@("`@("`@("`@("`O+PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]E;G-U<F5,:6YE<R@S*2`F)@H@("`@
M("`@("`@("`@("`@<')E9U]M871C:"@G+UXH+BL_*5QS*B0O)RP@)'1H:7,M
M/E]L:6YE0G5F9F5R6S%=+"`D;&EN94UA=&-H*2`F)@H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C:&5C:T%D;W)N;65N="AA<G)A>2@P+"`R*2P@<W1R;&5N
M*"1L:6YE36%T8VA;,5TI*2D@>PH*("`@("`@("`@("`@("`@("1A9&]R;FUE
M;G14>7!E(#T@)'1H:7,M/E]L:6YE0G5F9F5R6S!=>S!].PH@("`@("`@("`@
M("`@("`@)&%D;W)N;65N=%1Y<&4@+CT@)&%D;W)N;65N=%1Y<&4["@H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]N97AT*"D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYE>'0H*3L*"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N;65N=%1Y<&5=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1N97=,979E;"`]("1T:&ES+3Y?861O<FYM96YT
M3&5V96QS6R1A9&]R;FUE;G14>7!E73L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!O<%1O3&5V96PH)U-E8W1I;VXG+"`D;F5W3&5V96P@+2`Q*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&YE=TQE=F5L(#T@)'1H:7,M/E]G9713=&%T94QE=F5L*"=396-T:6]N)RD@
M*R`Q.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861O<FYM96YT3&5V
M96QS6R1A9&]R;FUE;G14>7!E72`]("1N97=,979E;#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1N;V1E(#T@)B1T:&ES+3Y?;6%K94YO
M9&4H)'1H:7,M/E]C=7)R96YT3F]D92P@)U-E8W1I;VXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;&5V96PG
M(#T^("1N97=,979E;"DI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P=7-H
M4W1A=&4H)&YO9&4L("=396-T:6]N)RP@)&YE=TQE=F5L*3L*("`@("`@("`@
M("`@("`@('!R96=?;6%T8V@H)R]>7',J*"XJ/RE<<RHD+R<L("1L:6YE36%T
M8VA;,5TL("1L:6YE36%T8V@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M
M86ME3F]D92@D=&AI<RT^7V-U<G)E;G1.;V1E+"`G2&5A9&EN9R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L979E;"<@/3X@
M)&YE=TQE=F5L*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QI;F5-871C:%LQ72D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@3&]O
M:R!F;W(@=6YD97)L:6YE(&AE861I;F=S+@H@("`@("`@("`@("`O+PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]E;G-U<F5,:6YE<R@R*2`F)@H@("`@("`@
M("`@("`@("`@<')E9U]M871C:"@G+UXH6UY<<UTN*C\I7',J)"\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQI;F5"=69F97);,%TL
M("1L:6YE36%T8V@I("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H96-K
M061O<FYM96YT*&%R<F%Y*#$I+"!S=')L96XH)&QI;F5-871C:%LQ72DI*2![
M"@H@("`@("`@("`@("`@("`@)&%D;W)N;65N=%1Y<&4@/2`D=&AI<RT^7VQI
M;F5"=69F97);,5U[,'T["B`@("`@("`@("`@("`@("`D=&AI<RT^7VYE>'0H
M*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V%D;W)N;65N
M=$QE=F5L<ULD861O<FYM96YT5'EP95TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&YE=TQE=F5L(#T@)'1H:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N
M;65N=%1Y<&5=.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&]P5&],
M979E;"@G4V5C=&EO;B<L("1N97=,979E;"`M(#$I.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F5W3&5V96P@/2`D
M=&AI<RT^7V=E=%-T871E3&5V96PH)U-E8W1I;VXG*2`K(#$["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N;65N
M=%1Y<&5=(#T@)&YE=TQE=F5L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&YO9&4@/2`F)'1H:7,M/E]M86ME3F]D92@D=&AI<RT^7V-U
M<G)E;G1.;V1E+"`G4V5C=&EO;B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L979E;"<@/3X@)&YE=TQE=F5L
M*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!U<VA3=&%T92@D;F]D92P@
M)U-E8W1I;VXG+"`D;F5W3&5V96PI.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M86ME3F]D92@D=&AI<RT^7V-U<G)E;G1.;V1E+"`G2&5A9&EN9R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L979E;"<@
M/3X@)&YE=TQE=F5L*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&QI;F5-871C:%LQ72D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@
M4&%R<V4@82!@.CHG('!A<F%G<F%P:"X*("`@("`@("`@("`@+R\*("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',J.CI<<RHD+R<L("1T:&ES+3Y?
M;&EN94)U9F9E<ELP72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F5X
M="@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S94QI=&5R86Q";&]C
M:R@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O(%!A<G-E(&$@<&%R86=R
M87!H+B`@5V4@96YD('1H92!P87)A9W)A<&@@=VAE;B!W92!R971U<FX@=&\*
M("`@("`@("`@("`@+R\@82!L;W=E<B!I;F1E;G1A=&EO;B!L979E;"!O<B!E
M;F-O=6YT97(@82!B;&%N:R!L:6YE+@H@("`@("`@("`@("`O+PH@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+UXH7',J*2A;7EQS72XJ/RE<<RHD+R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&EN94)U9F9E
M<ELP72P@)&TI*2!["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@
M("`@("`@("`@("`@("`@)&QE=F5L(#T@<W1R;&5N*"1M6S%=*3L*("`@("`@
M("`@("`@("`@('=H:6QE("@D=&AI<RT^7V5N<W5R94QI;F5S*#(I("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+UXH7',J*2A;7EQS
M72XJ/RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQI;F5"=69F97);,5TL("1M*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')L96XH)&U;,5TI(#P@)&QE=F5L*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2`G("<@+B`D;5LR73L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VYE>'0H*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D=')A:6QI;F=,:71E<F%L(#T@9F%L
M<V4["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH+BI;7EQS
M73HI.EQS*B0O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T97AT(#T@)&U;,5T["B`@("`@("`@("`@("`@("`@("`@)'1R86EL:6YG
M3&ET97)A;"`]('1R=64["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:"@G+UXH+BH_*5QS*CHZ7',J)"\G+"`D=&5X="P@)&TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LQ73L*("`@("`@("`@("`@
M("`@("`@("`D=')A:6QI;F=,:71E<F%L(#T@=')U93L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:V5.;V1E*"1T:&ES
M+3Y?8W5R<F5N=$YO9&4L("=087)A9W)A<&@G+"!A<G)A>2@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="D["@H@("`@("`@("`@
M("`@("`@:68@*"1T<F%I;&EN9TQI=&5R86PI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VYE>'0H*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<G-E3&ET97)A;$)L;V-K*"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@6%A8.B!(86YD;&4@9V%R8F%G92!L:6YE+@H*("`@("`@("!]
M.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]D;V-U;65N=#L*("`@('T*"B`@
M("!F=6YC=&EO;B`F7VUA:V5.;V1E*"8D<&%R96YT+"`D='EP92P@)'!R;W!S
M(#T@87)R87DH*2P@)&-H:6QD5&5X="`](&YU;&PI"B`@("!["B`@("`@("`@
M)&YO9&4@/2`F;F5W(%1E>'1?<F535"@D='EP92D["B`@("`@("`@9F]R96%C
M:"`H)'!R;W!S(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D
M;F]D92T^<V5T4')O<&5R='DH)&YA;64L("1V86QU92D["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-?;G5L;"@D<&%R96YT*2D@>PH@("`@("`@("`@("`D
M<&%R96YT+3YA<'!E;F1#:&EL9"@D;F]D92D["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-?;G5L;"@D8VAI;&1497AT*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W!A<G-E26YL:6YE*"1N;V1E+"`D8VAI;&1497AT*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1N;V1E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&UU;'1I<&QE(&%D;W)N96UN="!L:6YE<R!I;B!T:&4@;&EN92!B
M=69F97(@86YD(&UA:V5S('-U<F4@=&AE>0H@("`@("H@87)E(&%D;W)N;65N
M=',@86YD('1H870@86QL(&%R92!I9&5N=&EC86P@861O<FYM96YT<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&QI;F5S("`@("`@("!!;B!A<G)A>2!O9B!L:6YE(&YU;6)E
M<G,@=&\@8VAE8VL@:68@=&AE>2!A<F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%D;W)N;65N=',N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6EN3&5N9W1H("!4:&4@;6EN:6UU;2!L96YG=&@@9F]R('1H:7,@861O
M<FYM96YT+B`@5&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D969A=6QT(&ES(#$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!7:&5T:&5R('1H:7,@;&EN92!I<R!A;B!A9&]R;FUE;G0@=VAI8V@@;6%T
M8VAE<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@86)O=F4@8W)I=&5R
M:6$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:T%D;W)N;65N="@D;&EN
M97,@/2!A<G)A>2@P*2P@)&UI;DQE;F=T:"`](#$I"B`@("!["B`@("`@("`@
M)&-H<B`](&YU;&P["B`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1I*2![
M"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UXH6UYA+7I!+5HP+3E<
M>#=F+5QX9F9<<UTK*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;&EN94)U9F9E<ELD:5TL("1M*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1C:'(I*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R
M;&5N*"1M6S%=*2`\("1M:6Y,96YG=&@I('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D8VAR(#T@)&U;,5U[,'T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1M6S%=*2`A/2`D;6EN3&5N9W1H
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1M:6Y,96YG
M=&@@/2!S=')L96XH)&U;,5TI.PH@("`@("`@("`@("!F;W(@*"1J(#T@,#L@
M)&H@/"!S=')L96XH)&U;,5TI.R`D:BLK*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&U;,5U[)&I]("$]("1C:'(I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N
M8W1I;VX@)E]P87)S94EN;&EN92@F)&YO9&4L("1T97AT*0H@("`@>PH@("`@
M("`@('-T871I8R`D86QI87-E<R`](&%R<F%Y*"=S=7`G(#T^("=S=7!E<G-C
M<FEP="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-U8B<@
M/3X@)W-U8G-C<FEP="<I.PH@("`@("`@('-T871I8R`D<V-H96UA<R`](&%R
M<F%Y*"=H='1P)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:'1T<',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F='`G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I<F,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T96QN970G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=N97=S)RD["@H@("`@("`@('=H
M:6QE("AS=')L96XH)'1E>'0I(#X@,"D@>PH@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY<*EPJ*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I7"I<*B@N*BDD
M+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K
M94YO9&4H)&YO9&4L("=);G1E<G!R971E9"U497AT)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W)O;&4G(#T^("=S=')O;F<G
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&U;,5TI.PH@
M("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E
M;'-E:68@*'!R96=?;6%T8V@H)R]>7"HH*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE<
M*B@N*BDD+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;6%K94YO9&4H)&YO9&4L("=);G1E<G!R971E9"U497AT)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W)O;&4G(#T^("=E
M;7!H87-I<R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@
M("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UY@8"@N*C\I8&`H+BHI)"\G
M+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D<W5B(#T@)B1T:&ES
M+3Y?;6%K94YO9&4H)&YO9&4L("=);G1E<G!R971E9"U497AT)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L
M92<@/3X@)VQI=&5R86PG*2D["B`@("`@("`@("`@("`@("`D<W5B+3YA<'!E
M;F1#:&EL9"@D;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=
M.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UXZ*%MA+7HM
M72LI.F`H*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE@*"XJ*20O)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0L("1M*2D@>PH@("`@("`@
M("`@("`@("`@)')O;&4@/2`D;5LQ73L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D86QI87-E<ULD;5LQ75TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)')O;&4@/2`D86QI87-E<ULD;5LQ75T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D<W5B(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L
M("=);G1E<G!R971E9"U497AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L92<@/3X@)')O;&4I*3L*("`@
M("`@("`@("`@("`@(&EF("@D<F]L92`]/2`G;&ET97)A;"<I('L*("`@("`@
M("`@("`@("`@("`@("`D<W5B+3YA<'!E;F1#:&EL9"@D;5LR72D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R<V5);FQI;F4H)'-U8BP@)&U;,ETI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LS73L*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>8"@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_
M*6`Z*%MA+7HM72LI.B@N*BDD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1R;VQE
M(#T@)&U;,ET["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%L:6%S97-;
M)&U;,EU=*2D@>PH@("`@("`@("`@("`@("`@("`@("1R;VQE(#T@)&%L:6%S
M97-;)&U;,EU=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'-U8B`]("8D=&AI<RT^7VUA:V5.;V1E*"1N;V1E+"`G26YT97)P<F5T960M
M5&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W)O;&4G(#T^("1R;VQE*2D["B`@("`@("`@("`@("`@("!I
M9B`H)')O;&4@/3T@)VQI=&5R86PG*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-U8BT^87!P96YD0VAI;&0H)&U;,5TI.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E26YL:6YE
M*"1S=6(L("1M6S%=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1T97AT(#T@)&U;,UT["B`@("`@("`@("`@('T@96QS96EF("AP<F5G
M7VUA=&-H*"<O7F`H*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE@7U\H+BHI)"\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&EN:R@D;F]D92P@)&U;
M,5TL('1R=64I.PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@
M("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>8"@H/SI<7%Q<+GQ;
M7EQ<7%Q=*2H_*6!?*"XJ*20O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)S94QI;FLH)&YO9&4L("1M6S%=+"!F86QS92D["B`@("`@("`@("`@
M("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:"@G+UY@*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I8"@N*BDD+R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97AT+"`D;2DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=);G1E
M<G!R971E9"U497AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W)O;&4G(#T^("=T:71L92UR969E<F5N8V4G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&U;,5TI.PH@("`@("`@("`@
M("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]>*"@_.B<@+B!J;VEN*"=\)RP@)'-C:&5M87,I("X@("<I
M.EPO7"];+3`M.6$M>B,E)BLN7"\Z.S]?7%Q^72M;+3`M.6$M>B,E)BM<+U]<
M7'Y=*2@N*BDD+VDG+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D
M<W5B(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=,:6YK)RP@87)R87DH
M)VAR968G(#T^("1M6S%=*2D["B`@("`@("`@("`@("`@("`D<W5B+3YA<'!E
M;F1#:&EL9"@D;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=
M.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UXH6V$M>C`M
M.2U=*T!;82UZ,"TY+5PN72M<+EMA+7HP+3DM72LI*"XJ*20O:2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97AT+"`D;2DI('L*("`@
M("`@("`@("`@("`@("1S=6(@/2`F)'1H:7,M/E]M86ME3F]D92@D;F]D92P@
M)TQI;FLG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=H<F5F)R`]/B`G;6%I;'1O.B<@+B`D;5LQ72DI.PH@("`@
M("`@("`@("`@("`@)'-U8BT^87!P96YD0VAI;&0H)&U;,5TI.PH@("`@("`@
M("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E;'-E:68@
M*'!R96=?;6%T8V@H)R]>*%QW*RE?7&(H+BHI)"\G+"`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&EN:R@D;F]D92P@)&U;
M,5TL(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7EQ<7%Q<<R@N*BDD
M+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("\O($)A8VMS;&%S
M:"UE<V-A<&5D('=H:71E<W!A8V4@8VAA<F%C=&5R<R!A<F4@<F5M;W9E9"!F
M<F]M"B`@("`@("`@("`@("`@("`O+R!T:&4@9&]C=6UE;G0N"B`@("`@("`@
M("`@("`@("`D=&5X="`]("1M6S%=.PH@("`@("`@("`@("!](&5L<V5I9B`H
M<')E9U]M871C:"@G+UY<7%Q<*"XI*"XJ*20O)RP@)'1E>'0L("1M*2D@>PH@
M("`@("`@("`@("`@("`@)&,@/2`D;5LQ73L*("`@("`@("`@("`@("`@("1T
M97AT(#T@)&U;,ET["B`@("`@("`@("`@("`@("`D;F]D92T^87!P96YD0VAI
M;&0H)&,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M+R\@6%A8.B!792!S:&]U;&0@=')Y('1O('5S92!A(')E9V5X<"!T;R!G<F%B
M(&%S(&UU8V@@=&5X="!A<PH@("`@("`@("`@("`@("`@+R\@<&]S<VEB;&4L
M('1H96X@9F%L;"!T:')O=6=H('1O('1H92!S:6YG;&4M8VAA<F%C=&5R(&-A
M<V4*("`@("`@("`@("`@("`@("\O(&EF('=E(&-A;B=T(&=E="!A;GET:&EN
M9RX*"B`@("`@("`@("`@("`@("`D8R`]('-U8G-T<B@D=&5X="P@,"P@,2D[
M"B`@("`@("`@("`@("`@("`D=&5X="`]('-U8G-T<B@D=&5X="P@,2D["B`@
M("`@("`@("`@("`@("`D;F]D92T^87!P96YD0VAI;&0H)&,I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)O9'D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!087)S97,@86X@86YO;GEM;W5S(&]R(&YA;65D
M(&QI;FLN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(%1E>'1?<F535"`@("`@("`@("`@5&AE('!A<F5N="!N
M;V1E(&9O<B!T:&4@;&EN:RX*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@
M("`@("`@(%1H92!T97AT('1O('!A<G-E+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&%N;VYY;6]U<R`@5VAE=&AE<B!T:&ES(&ES(&%N(&%N;VYY;6]U<R!L
M:6YK+@H@("`@("H*("`@("`J($!R971U<FX@5&5X=%]R95-4("!4:&4@;F5W
M(&QI;FL@;F]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]P87)S94QI;FLH
M)B1N;V1E+"`D=&5X="P@)&%N;VYY;6]U<R`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1L:6YK(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=,:6YK)RD[
M"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O/"@N*BD^+R<L("1T97AT+"`D
M;2DI('L*("`@("`@("`@("`@)&QI;FLM/G-E=%!R;W!E<G1Y*"=H<F5F)RP@
M)&U;,5TI.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH6UX\72L_
M*5QS*CPO)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)&QI;FLM
M/F%P<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@("`@("`@("`@(&EF("@A)&%N
M;VYY;6]U<RD@>PH@("`@("`@("`@("`@("`@("`@("1L:6YK+3YS9710<F]P
M97)T>2@G;F%M92<L("1T:&ES+3Y?;F]R;6%L:7IE3F%M92@D;5LQ72DI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68@*"$D86YO;GEM;W5S*2!["B`@("`@("`@("`@
M("`@("`D;&EN:RT^<V5T4')O<&5R='DH)VYA;64G+"`D=&AI<RT^7VYO<FUA
M;&EZ94YA;64H)'1E>'0I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;&EN:RT^87!P96YD0VAI;&0H)'1E>'0I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1A;F]N>6UO=7,@)B8@:7-?;G5L;"@D;&EN:RT^9V5T4')O<&5R='DH
M)VAR968G*2DI('L*("`@("`@("`@("`@)'1H:7,M/E]Q=65U94%N;VYY;6]U
M<U)E9F5R96YC92@D;&EN:RP@)VQI;FLG*3L*("`@("`@("!](&5L<V5I9B`H
M(21A;F]N>6UO=7,@)B8@(6ES7VYU;&PH)&QI;FLM/F=E=%!R;W!E<G1Y*"=N
M86UE)RDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<'5T3F%M9612969E<F5N
M8V4H)&QI;FLL("=L:6YK)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&QI;FL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!.;W)M86QI>F5S(&%N(&]B
M:F5C="!N86UE+@H@("`@("H@5&AI<R!M96%N<R!T:&%T('=E(&QO=V5R8V%S
M92!I="!A;F0@;F]R;6%L:7IE(&%N>2!W:&ET97-P86-E(&EN(&ET+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($$@;F%M92!T;R!N;W)M
M86QI>F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!N;W)M
M86QI>F5D(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]N;W)M86QI>F5.
M86UE*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H
M)R]<<RLO)RP@)R`G+"!S=')T;VQO=V5R*"1N86UE*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!087)S97,@86YD(&5X96-U=&5S(&$@8"XN)R!D:7)E8W1I
M=F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@02!D:7)E8W1I=F4@=&\@97AE8W5T
M92P@;&5S<R!T:&4@;&5A9&EN9R!@+BX@)RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W!A<G-E1&ER96-T:79E*"1T97AT*0H@("`@>PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7E]?.EQS*B@N*C\I7',J)"\G+"`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O($%N;VYY;6]U<R!L:6YK
M(&1E9FEN:71I;VX*("`@("`@("`@("`@+R\*("`@("`@("`@("`@)&1E9FX@
M/2`F;F5W(%1E>'1?<F535"@G3&EN:R<I.PH@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY;82UZ,"TY+5TK0%MA+7HP+3DM7"Y=*UPN6V$M>C`M.2U=
M*R0O:2<L("1M6S%=*2D@>PH@("`@("`@("`@("`@("`@)&U;,5T@/2`G;6%I
M;'1O.B<@+B`D;5LQ73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&5F
M;BT^<V5T4')O<&5R='DH)VAR968G+"`D;5LQ72D["B`@("`@("`@("`@("1T
M:&ES+3Y?<75E=65!;F]N>6UO=7-$969I;FET:6]N*"1D969N+"`G;&EN:R<I
M.PH@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7EQS*E\H+BH_*3I<
M<RHH+BH_*5QS*B0O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`O+PH@
M("`@("`@("`@("`O+R!.86UE9"!L:6YK(&1E9FEN:71I;VX*("`@("`@("`@
M("`@+R\*("`@("`@("`@("`@)&1E9FX@/2`F;F5W(%1E>'1?<F535"@G3&EN
M:R<I.PH@("`@("`@("`@("`D9&5F;BT^<V5T4')O<&5R='DH)VYA;64G+"`D
M=&AI<RT^7VYO<FUA;&EZ94YA;64H)&U;,5TI*3L*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>6V$M>C`M.2U=*T!;82UZ,"TY+5PN72M<+EMA+7HP
M+3DM72LD+VDG+"`D;5LR72DI('L*("`@("`@("`@("`@("`@("1M6S)=(#T@
M)VUA:6QT;SHG("X@)&U;,ET["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&1E9FXM/G-E=%!R;W!E<G1Y*"=H<F5F)RP@)&U;,ETI.PH@("`@("`@("`@
M("`D=&AI<RT^7W!U=$YA;65D1&5F:6YI=&EO;B@D9&5F;BP@)VQI;FLG*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:VEP<R!B;&%N:R!L
M:6YE<R!U;G1I;"!W92!F:6YD(&]N92!W92!C86X@9V5T('1H92!I;F1E;G1A
M=&EO;B!L979E;`H@("`@("H@9G)O;2P@=&AE;BP@9V%T:&5R<R!L:6YE<R!U
M;G1I;"!W92!H879E(&$@9&EF9F5R96YT(&QE=F5L+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<&%R<V5,:71E<F%L0FQO8VLH*0H@("`@>PH@("`@("`@(&EF
M("@A)'1H:7,M/E]E;G-U<F5,:6YE<R@Q*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!W:&EL92`H<')E9U]M871C
M:"@G+UY<<RHD+R<L("1T:&ES+3Y?;&EN94)U9F9E<ELP72DI('L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7VYE>'0H*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]>*%QS*RDH+BH_*5QS*B0O)RP@)'1H:7,M
M/E]L:6YE0G5F9F5R6S!=+"`D;2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D;&5V96P@/2!S=')L96XH)&U;,5TI
M.PH@("`@("`@("1T97AT(#T@)&U;,ET["@H@("`@("`@(&EF("@D=&AI<RT^
M7VYE>'0H*2D@>PH@("`@("`@("`@("`D<F4@/2`G+UXH/SH@>R<@+B`D;&5V
M96P@+B`G?2@N*C\I?"@I*5QS*B0O)SL*("`@("`@("`@("`@=VAI;&4@*'!R
M96=?;6%T8V@H)')E+"`D=&AI<RT^7VQI;F5"=69F97);,%TL("1M*2D@>PH@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@(EQN(B`N("1M6S%=.PH@("`@("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7VYE>'0H*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D;"`]("8D=&AI<RT^7VUA:V5.;V1E*"1T
M:&ES+3Y?8W5R<F5N=$YO9&4L("=,:71E<F%L+4)L;V-K)RP@87)R87DH*2D[
M"B`@("`@("`@)&PM/F%P<&5N9$-H:6QD*'!R96=?<F5P;&%C92@G+UQS*R0O
M<R<L("<G+"`D=&5X="DI.PH*("`@("`@("`O+R!86%@Z($1I<G1Y(&AA8VLA
M"B`@("`@("`@87)R87E?=6YS:&EF="@D=&AI<RT^7VQI;F5"=69F97(L("<G
M*3L*("`@('T*"B`@("`O+RTM+2T*("`@("\O($QI;F4M<F5A9&EN9R!M96UB
M97)S"B`@("`O+RTM+2T*"B`@("`O*BH*("`@("`J(%1H92!R96UA:6YD97(@
M;V8@=&AE('1E>'0@=V4@87)E('!A<G-I;F<L(&)E:6YG(&UO9&EF:65D(&)Y
M(%]G971,:6YE*"D*("`@("`J(&%N9"!?;F5X="@I+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?=&5X=#L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F('1H
M92!L:6YE<R!W92!H879E('!E96ME9"!A="X*("`@("`J"B`@("`@*B!4:&4@
M9FER<W0@96QE;65N="!I<R!T:&4@;&EN92!W92!A<F4@8W5R<F5N=&QY('=O
M<FMI;F<@=VET:"!A;F0@<V\@;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VQI
M;F5"=69F97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4F5T<FEE=F5S
M('1H92!N97AT(&QI;F4@9G)O;2!A(&)L;V-K(&]F('1E>'0N"B`@("`@*@H@
M("`@("H@5V4@<F5P;&%C92!T86)S('=I=&@@."!S<&%C97,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971,:6YE*"D*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3Y?=&5X
M="D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@)&D@/2!S=')P;W,H)'1H:7,M/E]T97AT+"`B7&XB*3L*("`@
M("`@("!I9B`H)&D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1L:6YE(#T@
M<W5B<W1R*"1T:&ES+3Y?=&5X="P@,"P@)&DI.PH@("`@("`@("`@("`D=&AI
M<RT^7W1E>'0@/2!S=6)S='(H)'1H:7,M/E]T97AT+"`D:2`K(#$I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1L:6YE(#T@)'1H:7,M/E]T97AT
M.PH@("`@("`@("`@("`D=&AI<RT^7W1E>'0@/2`G)SL*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+UQT+R<L("<@("`@("`@("<L
M("1L:6YE*3L*("`@('T*"B`@("`O*BH*("`@("`J($)U;7!S('1O('1H92!N
M97AT(&QI;F4@:6X@=&AE(&EN<'5T+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?;F5X="@I"B`@("!["B`@
M("`@("`@+R\@4W!E8VEA;"!C87-E('1H92!F:7)S="!T:6UE("=R;W5N9"X*
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]L:6YE0G5F9F5R*2`]/2`P*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V5N<W5R94QI;F5S*#$I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^7V5N<W5R94QI;F5S*#(I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@87)R87E?<VAI9G0H)'1H:7,M/E]L:6YE0G5F9F5R*3L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S('-U<F4@
M=&AE<F4@:7,@82!C97)T86EN(&YU;6)E<B!O9B!L:6YE<R!A="!M:6YI;75M
M(&EN('1H92!L:6YE"B`@("`@*B!B=69F97(N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M=6YT("!4:&ES(&ES('1H92!N=6UB97(@;V8@;&EN97,@=VAI8V@@;75S="!B
M92!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8G5F9F5R
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=V4@<W5C8V5E9&5D+B`@5V4@8V%N(&9A:6P@870*("`@("`J("`@("`@
M("`@("`@("`@("`@96YD+6]F+69I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]E;G-U<F5,:6YE<R@D8V]U;G0@/2`Q*0H@("`@>PH@("`@("`@('=H:6QE
M("AC;W5N="@D=&AI<RT^7VQI;F5"=69F97(I(#P@)&-O=6YT*2!["B`@("`@
M("`@("`@("1L:6YE(#T@)'1H:7,M/E]G971,:6YE*"D["B`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1L:6YE*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&EN
M94)U9F9E<EM=(#T@)&QI;F4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\O+2TM+0H@("`@+R\@06YO;GEM;W5S(')E9F5R
M96YC97,@86YD(&1E9FEN:71I;VYS"B`@("`O+RTM+2T*"B`@("!V87(@)%]A
M;F]N>6UO=7-2969E<F5N8V5S(#T@87)R87DH*3L*("`@('9A<B`D7V%N;VYY
M;6]U<T1E9FEN:71I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-I
M;F-E(&%N;VYY;6]U<R!R969E<F5N8V5S(&%N9"!D969I;FET:6]N<R`H92YG
M+B!F;V]T;F]T97,L(&QI;FMS*2!D;PH@("`@("H@;F]T(&YE960@=&\@8F4@
M9&5F:6YE9"`B:6X@;&]C:W-T97`B(&%C8V]R9&EN9R!T;R!T:&4@<W!E8RP@
M=V4@8W)E871E"B`@("`@*B!T:&4@<&%R=&EA;"!P87)S92!N;V1E(&EN(&)O
M=&@@<&QA8V5S(&%N9"!U<V4@=&AI<R!N:69T>2!S>7-T96T@=&\*("`@("`J
M('%U975E(&]R(&UE<F=E(&EN(&5A8V@@<&QA8V4N("!.;W1E('1H870@=&AE
M(')E9F5R96YC92!I<R!T:&4@(FUA<W1E<B(*("`@("`J(&YO9&4N("!4:&4@
M9&5F:6YI=&EO;B!G971S('1H<F]W;B!A=V%Y('-I;F-E(&ET(')E86QL>2!I
M<VXG="!I;B!T:&4*("`@("`J('!A<G-E('1R964@86YY=V%Y+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!O
M8FIE8W0@)B1N;V1E("!4:&4@;F]D92!T;R!Q=65U92!O<B!M97)G92!T;RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("!4:&4@='EP92!O9B!A;F]N
M>6UO=7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75E=65!;F]N
M>6UO=7-2969E<F5N8V4H)B1N;V1E+"`D='EP92D*("`@('L*("`@("`@("!I
M9B`H(6%R<F%Y7VME>5]E>&ES=',H)'1Y<&4L("1T:&ES+3Y?86YO;GEM;W5S
M1&5F:6YI=&EO;G,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?86YO;GEM;W5S
M1&5F:6YI=&EO;G-;)'1Y<&5=(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&-O=6YT*"1T:&ES+3Y?86YO;GEM;W5S1&5F:6YI=&EO;G-;)'1Y
M<&5=*2`^(#`I('L*("`@("`@("`@("`@)&1E9FX@/2`F)'1H:7,M/E]A;F]N
M>6UO=7-$969I;FET:6]N<ULD='EP95U;,%T["B`@("`@("`@("`@(&%R<F%Y
M7W-H:69T*"1T:&ES+3Y?86YO;GEM;W5S1&5F:6YI=&EO;G-;)'1Y<&5=*3L*
M("`@("`@("`@("`@)'1H:7,M/E]M97)G94YO9&50<F]P97)T:65S*"1N;V1E
M+"`D9&5F;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]A;F]N>6UO=7-2969E<F5N8V5S6R1T>7!E75M=(#T@)B1N;V1E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($AA;F1L97,@86X@86YO;GEM
M;W5S(&1E9FEN:71I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)&YO9&4@(%1H92!N;V1E
M('1O('%U975E(&]R(&UE<F=E(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T>7!E("`@5&AE('1Y<&4@;V8@86YO;GEM;W5S(&]B:F5C="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W%U975E06YO;GEM;W5S1&5F:6YI=&EO;B@F)&YO
M9&4L("1T>7!E*0H@("`@>PH@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T
M<R@D='EP92P@)'1H:7,M/E]A;F]N>6UO=7-2969E<F5N8V5S*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%N;VYY;6]U<U)E9F5R96YC97-;)'1Y<&5=(#T@
M87)R87DH*3L*("`@("`@("!]"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M86YO;GEM;W5S4F5F97)E;F-E<ULD='EP95TI(#X@,"D@>PH@("`@("`@("`@
M("`D<F5F(#T@)B1T:&ES+3Y?86YO;GEM;W5S4F5F97)E;F-E<ULD='EP95U;
M,%T["B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T:&ES+3Y?86YO;GEM;W5S
M4F5F97)E;F-E<ULD='EP95TI.PH@("`@("`@("`@("`D=&AI<RT^7VUE<F=E
M3F]D95!R;W!E<G1I97,H)')E9BP@)&YO9&4I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?86YO;GEM;W5S1&5F:6YI=&EO;G-;)'1Y
M<&5=6UT@/2`F)&YO9&4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@365R9V5S('1H92!P<F]P97)T:65S(&9R;VT@96%C:"!N;V1E(&EN=&\@
M=&AE(&]T:&5R(&YO9&4N"B`@("`@*@H@("`@("H@5&AE(&YO9&4@='EP92!I
M<R!N;W0@8VAA;F=E9"`H9F]R('1H92!C87-E('=H97)E('=E(&AA=F4@82!F
M;V]T;F]T90H@("`@("H@<F5F97)E;F-E(&%N9"!A(&9O;W1N;W1E(&1E9FEN
M:71I;VXI+"!B=70@8F]T:"!N;V1E<R!W:6QL(&AA=F4@86QL"B`@("`@*B!P
M<F]P97)T:65S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1N;V1E("!4:&4@<F5F97)E;F-E
M(&YO9&4N"B`@("`@*B!`<&%R86T@;V)J96-T("8D9&5F;B`@5&AE(&1E9FEN
M:71I;VX@;F]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VUE<F=E3F]D95!R
M;W!E<G1I97,H)B1N;V1E+"`F)&1E9FXI"B`@("!["B`@("`@("`@+R\@6%A8
M.B!792!S:&]U;&0@;6%K92!S=7)E('1H97)E(&ES(&YO(&-O;&QI<VEO;BX*
M("`@("`@("!F;W)E86-H("@D9&5F;BT^7W!R;W!E<G1I97,@87,@)&YA;64@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1N;V1E+3YS9710<F]P97)T>2@D
M;F%M92P@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&YO
M9&4M/E]P<F]P97)T:65S(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@
M("`@("`D9&5F;BT^<V5T4')O<&5R='DH)&YA;64L("1V86QU92D["B`@("`@
M("`@?0H@("`@?0H*("`@("\O+2TM+0H@("`@+R\@3F%M960@<F5F97)E;F-E
M<R!A;F0@9&5F:6YI=&EO;G,*("`@("\O+2TM+0H*("`@('9A<B`D7VYA;65D
M4F5F97)E;F-E<R`](&%R<F%Y*"D["B`@("!V87(@)%]N86UE9$1E9FEN:71I
M;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&YA;65D
M(')E9F5R96YC92!P87)S92!N;V1E(&EN(&$@:&%S:"!S;R!W92!C86X@;&%T
M97(@;65R9V4*("`@("`J('!R;W!E<G1I97,@=VET:"!A(&1E9FEN:71I;VXN
M("!)9B!W92!A;')E861Y(&AA=F4@82!D969I;FET:6]N+"!D;PH@("`@("H@
M=&AE(&UE<F=E(&YO=RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@5&5X=%]R95-4("8D;F]D92`@5&AE('!A
M<G-E('1R964@;F]D92X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@
M("!4:&4@='EP92!O9B!N86UE9"!R969E<F5N8V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!W92!S=6-C97-S9G5L
M;'D@861D960@=&AE(')E9F5R96YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!U=$YA;65D4F5F97)E;F-E*"8D;F]D92P@)'1Y<&4I"B`@("!["B`@("`@
M("`@)&YA;64@/2`D;F]D92T^9V5T4')O<&5R='DH)VYA;64G*3L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]N86UE9%)E9F5R96YC97-;)'1Y<&5=6R1N
M86UE72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7VYA;65D4F5F97)E;F-E<ULD='EP95U;)&YA;65=
M(#T@)B1N;V1E.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65D1&5F
M:6YI=&EO;G-;)'1Y<&5=6R1N86UE72DI('L*("`@("`@("`@("`@)&1E9FX@
M/2`F)'1H:7,M/E]N86UE9$1E9FEN:71I;VYS6R1T>7!E75LD;F%M95T["B`@
M("`@("`@("`@("1T:&ES+3Y?;65R9V5.;V1E4')O<&5R=&EE<R@D;F]D92P@
M)&1E9FXI.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H92!I;G9E<G-E(&]F('M`;&EN:R!?<'5T3F%M
M9612969E<F5N8V4H*7TN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P=71.86UE9$1E9FEN:71I;VXH)B1N
M;V1E+"`D='EP92D*("`@('L*("`@("`@("`D;F%M92`]("1N;V1E+3YG9710
M<F]P97)T>2@G;F%M92<I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA
M;65D1&5F:6YI=&EO;G-;)'1Y<&5=6R1N86UE72DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VYA;65D
M1&5F:6YI=&EO;G-;)'1Y<&5=6R1N86UE72`]("8D;F]D93L*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]N86UE9%)E9F5R96YC97-;)'1Y<&5=6R1N86UE
M72DI('L*("`@("`@("`@("`@)')E9B`]("8D=&AI<RT^7VYA;65D4F5F97)E
M;F-E<ULD='EP95U;)&YA;65=.PH@("`@("`@("`@("`D=&AI<RT^7VUE<F=E
M3F]D95!R;W!E<G1I97,H)')E9BP@)&YO9&4I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O+RTM+2T*("`@("\O(%-T871E
M('-T86-K(&UA;F%G96UE;G0*("`@("\O+2TM+0H*("`@("\J*@H@("`@("H@
M5&AE('-T871E('-T86-K+@H@("`@("H*("`@("`J($ET(&ES('5S960@=&\@
M:V5E<"!T<F%C:R!O9B!N97-T960@8F]D>2UL979E;"!E;&5M96YT<R!A;F0@
M:&]W('1H97D*("`@("`J(&UI9VAT(&5N9"X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-T871E4W1A8VL@/2!A<G)A>2@I
M.PH*("`@('9A<B`D7V-U<G)E;G1.;V1E.PH*("`@(&9U;F-T:6]N(%]P=7-H
M4W1A=&4H)B1N;V1E+"`D<W1A=&54>7!E+"`D;&5V96PI"B`@("!["B`@("`@
M("`@)'-T871E(#T@)FYE=R!497AT7W)E4U1?4&%R<V5R7W-T871E*"1N;V1E
M+"`D<W1A=&54>7!E+"`D;&5V96PI.PH@("`@("`@("1T:&ES+3Y?<W1A=&53
M=&%C:UM=(#T@)B1S=&%T93L*("`@("`@("`D=&AI<RT^7V-U<G)E;G1.;V1E
M(#T@)B1N;V1E.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G9713=&%T94QE=F5L
M*"1S=&%T951Y<&4I"B`@("!["B`@("`@("`@9F]R("@D:2`](&-O=6YT*"1T
M:&ES+3Y?<W1A=&53=&%C:RD@+2`Q.R`D:2`^/2`P.R`D:2TM*2!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W-T871E4W1A8VM;)&E=+3YS=&%T951Y<&4@
M/3T@)'-T871E5'EP92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<W1A=&53=&%C:ULD:5TM/FQE=F5L.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`P.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P
M;W!4;TQE=F5L*"1S=&%T951Y<&4L("1L979E;"D*("`@('L*("`@("`@("!W
M:&EL92`H)'1H:7,M/E]G9713=&%T94QE=F5L*"1S=&%T951Y<&4I(#X@)&QE
M=F5L*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&]P*"D["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]P;W`H*0H@("`@>PH@("`@("`@(&%R<F%Y
M7W!O<"@D=&AI<RT^7W-T871E4W1A8VLI.PH@("`@("`@(&EF("AC;W5N="@D
M=&AI<RT^7W-T871E4W1A8VLI*2!["B`@("`@("`@("`@("1S=&%T92`]("8D
M=&AI<RT^7W-T871E4W1A8VM;8V]U;G0H)'1H:7,M/E]S=&%T95-T86-K*2`M
M(#%=.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1.;V1E(#T@)B1S=&%T
M92T^;F]D93L*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S
M<R!R97!R97-E;G1S(&$@;F]D92!O;B!T:&4@<&%R<V5R)W,@<W1A=&4@<W1A
M8VLN"B`J"B`J($!P86-K86=E(%1E>'1?<F535`H@*B\*8VQA<W,@5&5X=%]R
M95-47U!A<G-E<E]S=&%T92!["@H@("`@=F%R("1N;V1E.PH@("`@=F%R("1S
M=&%T951Y<&4["B`@("!V87(@)&QE=F5L.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)&YO9&4@
M("`@("!4:&ES(&ES('1H92!P87)S92!N;V1E(&%S<V]C:6%T960@=VET:"!T
M:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T871E+B`@
M0FQO8VLM;&5V96P@96QE;65N=',@<&%R<V5D(&EN('1H:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1A=&4@=VEL;"!B92!C:&EL9')E
M;B!O9B!T:&ES(&YO9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=&%T951Y
M<&4@($-U<G)E;G1L>2!O;FQY("=396-T:6]N)RX*("`@("`J($!P87)A;2!M
M:7AE9"`D;&5V96P@("`@("`@5&AI<R!I<R!T:&4@;F5S=&EN9R!L979E;"!O
M9B!T:&ES('-T871E('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?
M<F535%]087)S97)?<W1A=&4H)B1N;V1E+"`D<W1A=&54>7!E+"`D;&5V96PI
M"B`@("!["B`@("`@("`@)'1H:7,M/FYO9&4@/2`F)&YO9&4["B`@("`@("`@
M)'1H:7,M/G-T871E5'EP92`]("1S=&%T951Y<&4["B`@("`@("`@)'1H:7,M
M/FQE=F5L(#T@)&QE=F5L.PH@("`@?0H*?0H`````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E
M>'0O<F535"]&;W)M871T97(N<&AP````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S0S-``Q,#4Q-30S,3`V,``P,C$T,S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!497AT7W)E4U1?1F]R;6%T=&5R.CH@8VQA<W,@:7,@=&AE(&9R86UE=V]R
M:R!F;W(@<F5N9&5R:6YG"B`J(')E4W1R=6-T=7)E9%1E>'0@9&]C=6UE;G1S
M('1O(&1I9F9E<F5N="!M961I82`H92YG+B!(5$U,*2X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO5&5X=%]R95-4+W)E4U0O1F]R;6%T=&5R+G!H<"QV(#$N
M-2XQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,SD@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R
M;VYO<WES+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED
M(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N
M($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E
M(%1E>'1?<F535`H@*B\*8VQA<W,@5&5X=%]R95-47T9O<FUA='1E<B!["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!D<FEV97(M<W!E8VEF:6,@<&%R86UE
M=&5R<R!F;W(@9F]R;6%T=&EN9RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V%R9W,["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W0@82!N97<@9F]R;6%T=&5R+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("!!
M<F=U;65N=',@<W!E8VEF:6,@=&\@=&AI<R!F;W)M871T97(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%1E>'1?<F535%]&;W)M871T97(H)&%R9W,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?87)G<R`]("1A<F=S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T(&$@;F5W(&9O<FUA='1E<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@($YA;64@;V8@
M=&AE(&9O<FUA='1I;F<@9')I=F5R('1O(&-O;G-T<G5C="X*("`@("`J($!P
M87)A;2!A<G)A>2`D87)G<R`@("`@06X@87)R87D@;V8@9')I=F5R+7-P96-I
M9FEC('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!497AT7W)E
M4U1?1F]R;6%T=&5R("!4:&4@9F]R;6%T=&5R"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9F86-T;W)Y*"1D<FEV97(L("1A<F=S(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@
M;&ES="@D<&%T:"P@)&1R:79E<BD@/2`D9')I=F5R.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1P871H(#T@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+T9O<FUA='1E<B\G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@/2`G5&5X
M=%]R95-47T9O<FUA='1E<E\G("X@)&1R:79E<CL*("`@("`@("!R97%U:7)E
M7V]N8V4@)'!A=&@@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@("1F;W)M
M871T97(@/2`F;F5W("1C;&%S<R@D87)G<RD["B`@("`@("`@<F5T=7)N("1F
M;W)M871T97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@=&AE(&1O
M8W5M96YT+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!P87)A;2!497AT7W)E4U0@)&1O8W5M96YT("!4:&4@9&]C=6UE;G0@=V4@
M=VEL;"!R96YD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("`@
M("`@5&AE(&]U='!U="!C:&%R<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!F
M;W)M870H)B1D;V-U;65N="P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T1I
M9F8O````````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-C``,#$V-S4Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U1E>'0O1&EF9B]296YD97)E<B\`````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,C`U,3<`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]$:69F+U)E;F1E<F5R
M+VEN;&EN92YP:'``````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-#4U`#$P
M-3$U-#,Q,#8P`#`R,C4Q,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=497AT+T1I9F8O
M4F5N9&5R97(N<&AP)SL*"B\J*@H@*B`B26YL:6YE(B!D:69F(')E;F1E<F5R
M+@H@*@H@*B!4:&ES(&-L87-S(')E;F1E<G,@9&EF9G,@:6X@=&AE(%=I:VDM
M<W1Y;&4@(FEN;&EN92(@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]497AT7T1I9F8O1&EF9B]296YD97)E<B]I;FQI;F4N<&AP+'8@,2XT+C$P
M+C$Q(#(P,#8O,#8O,38@,30Z,#@Z,34@8VAU8VL@17AP("0*("H*("H@0&%U
M=&AO<B`@0VEP<FEA;B!0;W!O=FEC:0H@*B!`<&%C:V%G92!497AT7T1I9F8*
M("HO"F-L87-S(%1E>'1?1&EF9E]296YD97)E<E]I;FQI;F4@97AT96YD<R!4
M97AT7T1I9F9?4F5N9&5R97(@>PH*("`@("\J*@H@("`@("H@3G5M8F5R(&]F
M(&QE861I;F<@8V]N=&5X="`B;&EN97,B('1O('!R97-E<G9E+@H@("`@("HO
M"B`@("!V87(@)%]L96%D:6YG7V-O;G1E>'1?;&EN97,@/2`Q,#`P,#L*"B`@
M("`O*BH*("`@("`J($YU;6)E<B!O9B!T<F%I;&EN9R!C;VYT97AT(")L:6YE
M<R(@=&\@<')E<V5R=F4N"B`@("`@*B\*("`@('9A<B`D7W1R86EL:6YG7V-O
M;G1E>'1?;&EN97,@/2`Q,#`P,#L*"B`@("`O*BH*("`@("`J(%!R969I>"!F
M;W(@:6YS97)T960@=&5X="X*("`@("`J+PH@("`@=F%R("1?:6YS7W!R969I
M>"`]("<\:6YS/B<["@H@("`@+RHJ"B`@("`@*B!3=69F:7@@9F]R(&EN<V5R
M=&5D('1E>'0N"B`@("`@*B\*("`@('9A<B`D7VEN<U]S=69F:7@@/2`G/"]I
M;G,^)SL*"B`@("`O*BH*("`@("`J(%!R969I>"!F;W(@9&5L971E9"!T97AT
M+@H@("`@("HO"B`@("!V87(@)%]D96Q?<')E9FEX(#T@)SQD96P^)SL*"B`@
M("`O*BH*("`@("`J(%-U9F9I>"!F;W(@9&5L971E9"!T97AT+@H@("`@("HO
M"B`@("!V87(@)%]D96Q?<W5F9FEX(#T@)SPO9&5L/B<["@H@("`@+RHJ"B`@
M("`@*B!(96%D97(@9F]R(&5A8V@@8VAA;F=E(&)L;V-K+@H@("`@("HO"B`@
M("!V87(@)%]B;&]C:U]H96%D97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%=H
M870@87)E('=E(&-U<G)E;G1L>2!S<&QI='1I;F<@;VX_(%5S960@=&\@<F5C
M=7)S92!T;R!S:&]W('=O<F0M;&5V96P*("`@("`J(&-H86YG97,N"B`@("`@
M*B\*("`@('9A<B`D7W-P;&ET7VQE=F5L(#T@)VQI;F5S)SL*"B`@("!F=6YC
M=&EO;B!?8FQO8VM(96%D97(H)'AB96<L("1X;&5N+"`D>6)E9RP@)'EL96XI
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VM?:&5A9&5R.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$)L;V-K*"1H96%D97(I"B`@("![
M"B`@("`@("`@<F5T=7)N("1H96%D97(["B`@("!]"@H@("`@9G5N8W1I;VX@
M7VQI;F5S*"1L:6YE<RP@)'!R969I>"`]("<@)RP@)&5N8V]D92`]('1R=64I
M"B`@("!["B`@("`@("`@:68@*"1E;F-O9&4I('L*("`@("`@("`@("`@87)R
M87E?=V%L:R@D;&EN97,L(&%R<F%Y*"8D=&AI<RP@)U]E;F-O9&4G*2D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]S<&QI=%]L979E;"`]/2`G
M=V]R9',G*2!["B`@("`@("`@("`@(')E='5R;B!I;7!L;V1E*"<G+"`D;&EN
M97,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!I;7!L
M;V1E*")<;B(L("1L:6YE<RD@+B`B7&XB.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!?861D960H)&QI;F5S*0H@("`@>PH@("`@("`@(&%R<F%Y
M7W=A;&LH)&QI;F5S+"!A<G)A>2@F)'1H:7,L("=?96YC;V1E)RDI.PH@("`@
M("`@("1L:6YE<ULP72`]("1T:&ES+3Y?:6YS7W!R969I>"`N("1L:6YE<ULP
M73L*("`@("`@("`D;&EN97-;8V]U;G0H)&QI;F5S*2`M(#%=("X]("1T:&ES
M+3Y?:6YS7W-U9F9I>#L*("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YE<R@D
M;&EN97,L("<@)RP@9F%L<V4I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D96QE
M=&5D*"1L:6YE<RP@)'=O<F1S(#T@9F%L<V4I"B`@("!["B`@("`@("`@87)R
M87E?=V%L:R@D;&EN97,L(&%R<F%Y*"8D=&AI<RP@)U]E;F-O9&4G*2D["B`@
M("`@("`@)&QI;F5S6S!=(#T@)'1H:7,M/E]D96Q?<')E9FEX("X@)&QI;F5S
M6S!=.PH@("`@("`@("1L:6YE<UMC;W5N="@D;&EN97,I("T@,5T@+CT@)'1H
M:7,M/E]D96Q?<W5F9FEX.PH@("`@("`@(')E='5R;B`D=&AI<RT^7VQI;F5S
M*"1L:6YE<RP@)R`G+"!F86QS92D["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H
M86YG960H)&]R:6<L("1F:6YA;"D*("`@('L*("`@("`@("`O*B!)9B!W92=V
M92!A;')E861Y('-P;&ET(&]N('=O<F1S+"!D;VXG="!T<GD@=&\@9&\@<V\@
M86=A:6X@+2!J=7-T"B`@("`@("`@("H@9&ES<&QA>2X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]S<&QI=%]L979E;"`]/2`G=V]R9',G*2!["B`@("`@("`@
M("`@("1P<F5F:7@@/2`G)SL*("`@("`@("`@("`@=VAI;&4@*"1O<FEG6S!=
M("$]/2!F86QS92`F)B`D9FEN86Q;,%T@(3T](&9A;'-E("8F"B`@("`@("`@
M("`@("`@("`@("!S=6)S='(H)&]R:6=;,%TL(#`L(#$I(#T]("<@)R`F)@H@
M("`@("`@("`@("`@("`@("`@<W5B<W1R*"1F:6YA;%LP72P@,"P@,2D@/3T@
M)R`G*2!["B`@("`@("`@("`@("`@("`D<')E9FEX("X]('-U8G-T<B@D;W)I
M9ULP72P@,"P@,2D["B`@("`@("`@("`@("`@("`D;W)I9ULP72`]('-U8G-T
M<B@D;W)I9ULP72P@,2D["B`@("`@("`@("`@("`@("`D9FEN86Q;,%T@/2!S
M=6)S='(H)&9I;F%L6S!=+"`Q*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)'!R969I>"`N("1T:&ES+3Y?9&5L971E9"@D;W)I9RD@+B`D
M=&AI<RT^7V%D9&5D*"1F:6YA;"D["B`@("`@("`@?0H*("`@("`@("`D=&5X
M=#$@/2!I;7!L;V1E*")<;B(L("1O<FEG*3L*("`@("`@("`D=&5X=#(@/2!I
M;7!L;V1E*")<;B(L("1F:6YA;"D["@H@("`@("`@("\J($YO;BUP<FEN=&EN
M9R!N97=L:6YE(&UA<FME<BX@*B\*("`@("`@("`D;FP@/2`B7#`B.PH*("`@
M("`@("`O*B!792!W86YT('1O('-P;&ET(&]N('=O<F0@8F]U;F1A<FEE<RP@
M8G5T('=E(&YE960@=&\*("`@("`@("`@*B!P<F5S97)V92!W:&ET97-P86-E
M(&%S('=E;&PN(%1H97)E9F]R92!W92!S<&QI="!O;B!W;W)D<RP*("`@("`@
M("`@*B!B=70@:6YC;'5D92!A;&P@8FQO8VMS(&]F('=H:71E<W!A8V4@:6X@
M=&AE('=O<F1L:7-T+B`J+PH@("`@("`@("1D:69F(#T@)FYE=R!497AT7T1I
M9F8H)'1H:7,M/E]S<&QI=$]N5V]R9',H)'1E>'0Q+"`D;FPI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S<&QI=$]N5V]R9',H
M)'1E>'0R+"`D;FPI*3L*"B`@("`@("`@+RH@1V5T('1H92!D:69F(&EN(&EN
M;&EN92!F;W)M870N("HO"B`@("`@("`@)')E;F1E<F5R(#T@)FYE=R!497AT
M7T1I9F9?4F5N9&5R97)?:6YL:6YE*&%R<F%Y7VUE<F=E*"1T:&ES+3YG9710
M87)A;7,H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-P;&ET7VQE=F5L
M)R`]/B`G=V]R9',G*2DI.PH*("`@("`@("`O*B!2=6X@=&AE(&1I9F8@86YD
M(&=E="!T:&4@;W5T<'5T+B`J+PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C
M92@D;FPL(")<;B(L("1R96YD97)E<BT^<F5N9&5R*"1D:69F*2D@+B`B7&XB
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S<&QI=$]N5V]R9',H)'-T<FEN9RP@
M)&YE=VQI;F5%<V-A<&4@/2`B7&XB*0H@("`@>PH@("`@("`@("\O($EG;F]R
M92!<,#L@;W1H97)W:7-E('1H92!W:&EL92!L;V]P('=I;&P@;F5V97(@9FEN
M:7-H+@H@("`@("`@("1S=')I;F<@/2!S=')?<F5P;&%C92@B7#`B+"`G)RP@
M)'-T<FEN9RD["@H@("`@("`@("1W;W)D<R`](&%R<F%Y*"D["B`@("`@("`@
M)&QE;F=T:"`]('-T<FQE;B@D<W1R:6YG*3L*("`@("`@("`D<&]S(#T@,#L*
M"B`@("`@("`@=VAI;&4@*"1P;W,@/"`D;&5N9W1H*2!["B`@("`@("`@("`@
M("\O($5A="!A('=O<F0@=VET:"!A;GD@<')E8V5D:6YG('=H:71E<W!A8V4N
M"B`@("`@("`@("`@("1S<&%C97,@/2!S=')S<&XH<W5B<W1R*"1S=')I;F<L
M("1P;W,I+"`B(%QN(BD["B`@("`@("`@("`@("1N97AT<&]S(#T@<W1R8W-P
M;BAS=6)S='(H)'-T<FEN9RP@)'!O<R`K("1S<&%C97,I+"`B(%QN(BD["B`@
M("`@("`@("`@("1W;W)D<UM=(#T@<W1R7W)E<&QA8V4H(EQN(BP@)&YE=VQI
M;F5%<V-A<&4L('-U8G-T<B@D<W1R:6YG+"`D<&]S+"`D<W!A8V5S("L@)&YE
M>'1P;W,I*3L*("`@("`@("`@("`@)'!O<R`K/2`D<W!A8V5S("L@)&YE>'1P
M;W,["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'=O<F1S.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]E;F-O9&4H)B1S=')I;F<I"B`@("!["B`@("`@("`@
M)'-T<FEN9R`](&AT;6QS<&5C:6%L8VAA<G,H)'-T<FEN9RD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]497AT+T1I9F8O4F5N9&5R97(O=6YI9FEE9"YP
M:'``````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q,#``,3`U,34T,S$P-C``
M,#(R-C0Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)U1E>'0O1&EF9B]296YD97)E<BYP
M:'`G.PH*+RHJ"B`J(")5;FEF:65D(B!D:69F(')E;F1E<F5R+@H@*@H@*B!4
M:&ES(&-L87-S(')E;F1E<G,@=&AE(&1I9F8@:6X@8VQA<W-I8R`B=6YI9FEE
M9"!D:69F(B!F;W)M870N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?
M1&EF9B]$:69F+U)E;F1E<F5R+W5N:69I960N<&AP+'8@,2XS+C$P+C,@,C`P
M-B\P,2\P."`P,3HS-SHR,"!J86X@17AP("0*("H*("H@0'!A8VMA9V4@5&5X
M=%]$:69F"B`J+PIC;&%S<R!497AT7T1I9F9?4F5N9&5R97)?=6YI9FEE9"!E
M>'1E;F1S(%1E>'1?1&EF9E]296YD97)E<B!["@H@("`@+RHJ"B`@("`@*B!.
M=6UB97(@;V8@;&5A9&EN9R!C;VYT97AT(")L:6YE<R(@=&\@<')E<V5R=F4N
M"B`@("`@*B\*("`@('9A<B`D7VQE861I;F=?8V]N=&5X=%]L:6YE<R`](#0[
M"@H@("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@=')A:6QI;F<@8V]N=&5X="`B
M;&EN97,B('1O('!R97-E<G9E+@H@("`@("HO"B`@("!V87(@)%]T<F%I;&EN
M9U]C;VYT97AT7VQI;F5S(#T@-#L*"B`@("!F=6YC=&EO;B!?8FQO8VM(96%D
M97(H)'AB96<L("1X;&5N+"`D>6)E9RP@)'EL96XI"B`@("!["B`@("`@("`@
M:68@*"1X;&5N("$](#$I('L*("`@("`@("`@("`@)'AB96<@+CT@)RPG("X@
M)'AL96X["B`@("`@("`@?0H@("`@("`@(&EF("@D>6QE;B`A/2`Q*2!["B`@
M("`@("`@("`@("1Y8F5G("X]("<L)R`N("1Y;&5N.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@(D!`("TD>&)E9R`K)'EB96<@0$`B.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]A9&1E9"@D;&EN97,I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?;&EN97,H)&QI;F5S+"`G*R<I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]D96QE=&5D*"1L:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]L:6YE<R@D;&EN97,L("<M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V-H86YG960H)&]R:6<L("1F:6YA;"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]D96QE=&5D*"1O<FEG*2`N("1T:&ES+3Y?861D960H)&9I;F%L
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O
M1&EF9B]296YD97)E<BYP:'``````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,C8S,P`Q,#4Q-30S,3`V,``P,C$R,S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($$@8VQA
M<W,@=&\@<F5N9&5R($1I9F9S(&EN(&1I9F9E<F5N="!F;W)M871S+@H@*@H@
M*B!4:&ES(&-L87-S(')E;F1E<G,@=&AE(&1I9F8@:6X@8VQA<W-I8R!D:69F
M(&9O<FUA="X@270@:7,@:6YT96YD960@=&AA=`H@*B!T:&ES(&-L87-S(&)E
M(&-U<W1O;6EZ960@=FEA(&EN:&5R:71A;F-E+"!T;R!O8G1A:6X@9F%N8VEE
M<B!O=71P=71S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T1I9F8O
M1&EF9B]296YD97)E<BYP:'`L=B`Q+C4N,3`N-R`R,#`U+S$R+S$V(#$Q.C0T
M.C`P(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("HO"F-L
M87-S(%1E>'1?1&EF9E]296YD97)E<B!["@H@("`@+RHJ"B`@("`@*B!.=6UB
M97(@;V8@;&5A9&EN9R!C;VYT97AT(")L:6YE<R(@=&\@<')E<V5R=F4N"B`@
M("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@;&5F="!A="!Z97)O(&9O<B!T
M:&ES(&-L87-S+"!B=70@<W5B8VQA<W-E<R!M87D@=V%N="!T;PH@("`@("H@
M<V5T('1H:7,@=&\@;W1H97(@=F%L=65S+@H@("`@("HO"B`@("!V87(@)%]L
M96%D:6YG7V-O;G1E>'1?;&EN97,@/2`P.PH*("`@("\J*@H@("`@("H@3G5M
M8F5R(&]F('1R86EL:6YG(&-O;G1E>'0@(FQI;F5S(B!T;R!P<F5S97)V92X*
M("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!L969T(&%T('IE<F\@9F]R
M('1H:7,@8VQA<W,L(&)U="!S=6)C;&%S<V5S(&UA>2!W86YT('1O"B`@("`@
M*B!S970@=&AI<R!T;R!O=&AE<B!V86QU97,N"B`@("`@*B\*("`@('9A<B`D
M7W1R86EL:6YG7V-O;G1E>'1?;&EN97,@/2`P.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?1&EF9E]2
M96YD97)E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!F;W)E
M86-H("@D<&%R86US(&%S("1P87)A;2`]/B`D=F%L=64I('L*("`@("`@("`@
M("`@)'8@/2`G7R<@+B`D<&%R86T["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^)'8I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^)'8@/2`D=F%L
M=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@86YY(')E;F1E<F5R('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06QL('!A<F%M971E<G,@;V8@=&AI<R!R96YD
M97)E<B!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M<R@I
M"B`@("!["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H9V5T7V]B:F5C=%]V87)S*"1T:&ES*2!A<R`D:R`]/B`D=BD@>PH@
M("`@("`@("`@("!I9B`H)&M[,'T@/3T@)U\G*2!["B`@("`@("`@("`@("`@
M("`D<&%R86US6W-U8G-T<B@D:RP@,2E=(#T@)'8["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5N9&5R<R!A(&1I9F8N"B`@("`@*@H@("`@("H@0'!A
M<F%M(%1E>'1?1&EF9B`D9&EF9B`@02!497AT7T1I9F8@;V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9F]R;6%T=&5D(&]U='!U
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1D:69F*0H@("`@>PH@
M("`@("`@("1X:2`]("1Y:2`](#$["B`@("`@("`@)&)L;V-K(#T@9F%L<V4[
M"B`@("`@("`@)&-O;G1E>'0@/2!A<G)A>2@I.PH*("`@("`@("`D;FQE860@
M/2`D=&AI<RT^7VQE861I;F=?8V]N=&5X=%]L:6YE<SL*("`@("`@("`D;G1R
M86EL(#T@)'1H:7,M/E]T<F%I;&EN9U]C;VYT97AT7VQI;F5S.PH*("`@("`@
M("`D;W5T<'5T(#T@)'1H:7,M/E]S=&%R=$1I9F8H*3L*"B`@("`@("`@)&1I
M9F9S(#T@)&1I9F8M/F=E=$1I9F8H*3L*("`@("`@("!F;W)E86-H("@D9&EF
M9G,@87,@)&D@/3X@)&5D:70I('L*("`@("`@("`@("`@:68@*&ES7V$H)&5D
M:70L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&)L;V-K*2D@>PH@("`@("`@("`@("`@("`@("`@("1K
M965P(#T@)&D@/3T@8V]U;G0H)&1I9F9S*2`M(#$@/R`D;G1R86EL(#H@)&YL
M96%D("L@)&YT<F%I;#L*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H
M)&5D:70M/F]R:6<I(#P]("1K965P*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1B;&]C:UM=(#T@)&5D:70["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1N=')A:6PI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT97AT(#T@87)R87E?
M<VQI8V4H)&5D:70M/F]R:6<L(#`L("1N=')A:6PI.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&)L;V-K6UT@/2`F;F5W(%1E>'1?1&EF9E]/<%]C
M;W!Y*"1C;VYT97AT*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?8FQO8VLH
M)'@P+"`D;G1R86EL("L@)'AI("T@)'@P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'DP+"`D;G1R86EL("L@
M)'EI("T@)'DP+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&)L;V-K*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&)L;V-K(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-O;G1E>'0@/2`D961I
M="T^;W)I9SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)&)L;V-K*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1C;VYT97AT(#T@87)R87E?<VQI8V4H)&-O;G1E>'0L(&-O=6YT*"1C;VYT
M97AT*2`M("1N;&5A9"D["B`@("`@("`@("`@("`@("`@("`@)'@P(#T@)'AI
M("T@8V]U;G0H)&-O;G1E>'0I.PH@("`@("`@("`@("`@("`@("`@("1Y,"`]
M("1Y:2`M(&-O=6YT*"1C;VYT97AT*3L*("`@("`@("`@("`@("`@("`@("`D
M8FQO8VL@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D8V]N
M=&5X="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8FQO8VM;72`]("9N
M97<@5&5X=%]$:69F7T]P7V-O<'DH)&-O;G1E>'0I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1B
M;&]C:UM=(#T@)&5D:70["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@D961I="T^;W)I9RD@>PH@("`@("`@("`@("`@("`@)'AI("L](&-O=6YT
M*"1E9&ET+3YO<FEG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)&5D:70M/F9I;F%L*2!["B`@("`@("`@("`@("`@("`D>6D@*ST@8V]U;G0H
M)&5D:70M/F9I;F%L*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1B;&]C:RDI('L*("`@("`@("`@("`@)&]U='!U
M="`N/2`D=&AI<RT^7V)L;V-K*"1X,"P@)'AI("T@)'@P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'DP+"`D>6D@+2`D>3`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8FQO8VLI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70@+B`D=&AI<RT^7V5N
M9$1I9F8H*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8FQO8VLH)'AB96<L("1X
M;&5N+"`D>6)E9RP@)'EL96XL("8D961I=',I"B`@("!["B`@("`@("`@)&]U
M='!U="`]("1T:&ES+3Y?<W1A<G1";&]C:R@D=&AI<RT^7V)L;V-K2&5A9&5R
M*"1X8F5G+"`D>&QE;BP@)'EB96<L("1Y;&5N*2D["@H@("`@("`@(&9O<F5A
M8V@@*"1E9&ET<R!A<R`D961I="D@>PH@("`@("`@("`@("!S=VET8V@@*'-T
M<G1O;&]W97(H9V5T7V-L87-S*"1E9&ET*2DI('L*("`@("`@("`@("`@8V%S
M92`G=&5X=%]D:69F7V]P7V-O<'DG.@H@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2`D=&AI<RT^7V-O;G1E>'0H)&5D:70M/F]R:6<I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=T97AT7V1I9F9?;W!?
M861D)SH*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]A9&1E
M9"@D961I="T^9FEN86PI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=T97AT7V1I9F9?;W!?9&5L971E)SH*("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]D96QE=&5D*"1E9&ET+3YO<FEG
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M=&5X=%]D:69F7V]P7V-H86YG92<Z"B`@("`@("`@("`@("`@("`D;W5T<'5T
M("X]("1T:&ES+3Y?8VAA;F=E9"@D961I="T^;W)I9RP@)&5D:70M/F9I;F%L
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&]U='!U="`N("1T:&ES+3Y?96YD0FQO
M8VLH*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<W1A<G1$:69F*"D*("`@('L*
M("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@7V5N9$1I
M9F8H*0H@("`@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("!F=6YC
M=&EO;B!?8FQO8VM(96%D97(H)'AB96<L("1X;&5N+"`D>6)E9RP@)'EL96XI
M"B`@("!["B`@("`@("`@:68@*"1X;&5N(#X@,2D@>PH@("`@("`@("`@("`D
M>&)E9R`N/2`G+"<@+B`H)'AB96<@*R`D>&QE;B`M(#$I.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'EL96X@/B`Q*2!["B`@("`@("`@("`@("1Y8F5G("X]
M("<L)R`N("@D>6)E9R`K("1Y;&5N("T@,2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'AB96<@+B`H)'AL96X@/R`H)'EL96X@/R`G8R<@.B`G9"<I
M(#H@)V$G*2`N("1Y8F5G.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$)L
M;V-K*"1H96%D97(I"B`@("!["B`@("`@("`@<F5T=7)N("1H96%D97(@+B`B
M7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N(%]E;F1";&]C:R@I"B`@("!["B`@
M("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N(%]L:6YE<R@D
M;&EN97,L("1P<F5F:7@@/2`G("<I"B`@("!["B`@("`@("`@<F5T=7)N("1P
M<F5F:7@@+B!I;7!L;V1E*")<;B1P<F5F:7@B+"`D;&EN97,I("X@(EQN(CL*
M("`@('T*"B`@("!F=6YC=&EO;B!?8V]N=&5X="@D;&EN97,I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;&EN97,H)&QI;F5S*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?861D960H)&QI;F5S*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VQI;F5S*"1L:6YE<RP@)SXG*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?9&5L971E9"@D;&EN97,I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;&EN97,H)&QI;F5S+"`G/"<I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]C:&%N9V5D*"1O<FEG+"`D9FEN86PI"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&5L971E9"@D;W)I9RD@+B`B+2TM7&XB("X@)'1H:7,M/E]A
M9&1E9"@D9FEN86PI.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9BYP:'``````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,S4U-``Q,#4Q-30S,3`V
M,``P,3<T-S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1E>'1?1&EF9@H@*@H@*B!'96YE<F%L($%0
M22!F;W(@9V5N97)A=&EN9R!A;F0@9F]R;6%T=&EN9R!D:69F<R`M('1H92!D
M:69F97)E;F-E<R!B971W965N"B`J('1W;R!S97%U96YC97,@;V8@<W1R:6YG
M<RX*("H*("H@5&AE(%!(4"!D:69F(&-O9&4@=7-E9"!I;B!T:&ES('!A8VMA
M9V4@=V%S(&]R:6=I;F%L;'D@=W)I='1E;B!B>2!'96]F9G)E>0H@*B!4+B!$
M86ER:6MI(&%N9"!I<R!U<V5D('=I=&@@:&ES('!E<FUI<W-I;VXN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1&EF9B]$:69F+G!H<"QV(#$N,3$N
M,BXW(#(P,#8O,#(O,#8@,#`Z,C4Z-3(@:F%N($5X<"`D"B`J"B`J($!P86-K
M86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI
M(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*B\*8VQA<W,@5&5X=%]$:69F('L*
M"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(&-H86YG97,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]E9&ET<SL*"B`@("`O
M*BH*("`@("`J($-O;7!U=&5S(&1I9F9S(&)E='=E96X@<V5Q=65N8V5S(&]F
M('-T<FEN9W,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1F<F]M7VQI
M;F5S("!!;B!A<G)A>2!O9B!S=')I;F=S+B`@5'EP:6-A;&QY('1H97-E(&%R
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!L:6YE<R!F<F]M
M(&$@9FEL92X*("`@("`J($!P87)A;2!A<G)A>2`D=&]?;&EN97,@("`@06X@
M87)R87D@;V8@<W1R:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]$
M:69F*"1F<F]M7VQI;F5S+"`D=&]?;&EN97,I"B`@("!["B`@("`@("`@87)R
M87E?=V%L:R@D9G)O;5]L:6YE<RP@87)R87DH)'1H:7,L("=?=')I;4YE=VQI
M;F5S)RDI.PH@("`@("`@(&%R<F%Y7W=A;&LH)'1O7VQI;F5S+"!A<G)A>2@D
M=&AI<RP@)U]T<FEM3F5W;&EN97,G*2D["@H@("`@("`@(&EF("AE>'1E;G-I
M;VY?;&]A9&5D*"=X9&EF9B<I*2!["B`@("`@("`@("`@("1E;F=I;F4@/2`F
M;F5W(%1E>'1?1&EF9E]%;F=I;F5?>&1I9F8H*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D96YG:6YE(#T@)FYE=R!497AT7T1I9F9?16YG:6YE
M7VYA=&EV92@I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]E9&ET<R`]
M("1E;F=I;F4M/F1I9F8H)&9R;VU?;&EN97,L("1T;U]L:6YE<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!A<G)A>2!O9B!D:69F97)E
M;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&EF9B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?961I=',["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VUP=71E<R!A(')E=F5R<V5D(&1I9F8N"B`@("`@*@H@("`@("H@
M17AA;7!L93H*("`@("`J(#QC;V1E/@H@("`@("H@)&1I9F8@/2`F;F5W(%1E
M>'1?1&EF9B@D;&EN97,Q+"`D;&EN97,R*3L*("`@("`J("1R978@/2`D9&EF
M9BT^<F5V97)S92@I.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!R
M971U<FX@5&5X=%]$:69F("!!($1I9F8@;V)J96-T(')E<')E<V5N=&EN9R!T
M:&4@:6YV97)S92!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("!O
M<FEG:6YA;"!D:69F+B`@3F]T92!T:&%T('=E('!U<G!O<V5L>2!D;VXG="!R
M971U<FX@80H@("`@("H@("`@("`@("`@("`@("`@("`@(')E9F5R96YC92!H
M97)E+"!S:6YC92!T:&ES(&5S<V5N=&EA;&QY(&ES(&$@8VQO;F4H*0H@("`@
M("H@("`@("`@("`@("`@("`@("`@(&UE=&AO9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5V97)S92@I"B`@("!["B`@("`@("`@:68@*'9E<G-I;VY?8V]M
M<&%R92AZ96YD7W9E<G-I;VXH*2P@)S(G+"`G/B<I*2!["B`@("`@("`@("`@
M("1R978@/2!C;&]N92@D=&AI<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)')E=B`]("1T:&ES.PH@("`@("`@('T*("`@("`@("`D<F5V+3Y?
M961I=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?961I
M=',@87,@)&5D:70I('L*("`@("`@("`@("`@)')E=BT^7V5D:71S6UT@/2`D
M961I="T^<F5V97)S92@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E
M=CL*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!F;W(@86X@96UP='D@
M9&EF9BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M='=O('-E<75E;F-E<R!W97)E(&ED96YT:6-A;"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-%;7!T>2@I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]E9&ET<R!A<R`D961I="D@>PH@("`@("`@("`@("!I9B`H(6ES7V$H)&5D
M:70L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP=71E<R!T
M:&4@;&5N9W1H(&]F('1H92!,;VYG97-T($-O;6UO;B!3=6)S97%U96YC92`H
M3$-3*2X*("`@("`J"B`@("`@*B!4:&ES(&ES(&UO<W1L>2!F;W(@9&EA9VYO
M<W1I8R!P=7)P;W-E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%1H92!L96YG=&@@;V8@=&AE($Q#4RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&-S*"D*("`@('L*("`@("`@("`D;&-S(#T@,#L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7V5D:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@(&EF("AI
M<U]A*"1E9&ET+"`G5&5X=%]$:69F7T]P7V-O<'DG*2D@>PH@("`@("`@("`@
M("`@("`@)&QC<R`K/2!C;W5N="@D961I="T^;W)I9RD["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L8W,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!O<FEG:6YA;"!S970@;V8@;&EN97,N"B`@
M("`@*@H@("`@("H@5&AI<R!R96-O;G-T<G5C=',@=&AE("1F<F]M7VQI;F5S
M('!A<F%M971E<B!P87-S960@=&\@=&AE(&-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!O<FEG:6YA;"!S97%U96YC92!O
M9B!S=')I;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971/<FEG:6YA;"@I
M"B`@("!["B`@("`@("`@)&QI;F5S(#T@87)R87DH*3L*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V5D:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@(&EF
M("@D961I="T^;W)I9RD@>PH@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E
M*"1L:6YE<RP@8V]U;G0H)&QI;F5S*2P@,"P@)&5D:70M/F]R:6<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;&EN97,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!F:6YA;"!S970@;V8@;&EN
M97,N"B`@("`@*@H@("`@("H@5&AI<R!R96-O;G-T<G5C=',@=&AE("1T;U]L
M:6YE<R!P87)A;65T97(@<&%S<V5D('1O('1H92!C;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<V5Q=65N8V4@;V8@<W1R
M:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1FEN86PH*0H@("`@>PH@
M("`@("`@("1L:6YE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]E9&ET<R!A<R`D961I="D@>PH@("`@("`@("`@("!I9B`H)&5D:70M
M/F9I;F%L*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)&QI;F5S
M+"!C;W5N="@D;&EN97,I+"`P+"`D961I="T^9FEN86PI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;&EN97,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F5S('1R86EL:6YG(&YE=VQI;F5S(&9R;VT@
M82!L:6YE(&]F('1E>'0N(%1H:7,@:7,@;65A;G0@=&\@8F4@=7-E9`H@("`@
M("H@=VET:"!A<G)A>5]W86QK*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;&EN92`@5&AE(&QI;F4@=&\@=')I;2X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1K97D@(%1H92!I;F1E>"!O9B!T:&4@;&EN92!I;B!T:&4@87)R
M87DN($YO="!U<V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=')I;4YE=VQI
M;F5S*"8D;&EN92P@)&ME>2D*("`@('L*("`@("`@("`D;&EN92`]('-T<E]R
M97!L86-E*&%R<F%Y*")<;B(L(")<<B(I+"`G)RP@)&QI;F4I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAE8VMS(&$@9&EF9B!F;W(@=F%L:61I='DN"B`@
M("`@*@H@("`@("H@5&AI<R!I<R!H97)E(&]N;'D@9F]R(&1E8G5G9VEN9R!P
M=7)P;W-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K*"1F<F]M7VQI
M;F5S+"`D=&]?;&EN97,I"B`@("!["B`@("`@("`@:68@*'-E<FEA;&EZ92@D
M9G)O;5]L:6YE<RD@(3T@<V5R:6%L:7IE*"1T:&ES+3YG971/<FEG:6YA;"@I
M*2D@>PH@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")296-O;G-T<G5C=&5D
M(&]R:6=I;F%L(&1O97-N)W0@;6%T8V@B+"!%7U5315)?15)23U(I.PH@("`@
M("`@('T*("`@("`@("!I9B`H<V5R:6%L:7IE*"1T;U]L:6YE<RD@(3T@<V5R
M:6%L:7IE*"1T:&ES+3YG971&:6YA;"@I*2D@>PH@("`@("`@("`@("!T<FEG
M9V5R7V5R<F]R*")296-O;G-T<G5C=&5D(&9I;F%L(&1O97-N)W0@;6%T8V@B
M+"!%7U5315)?15)23U(I.PH@("`@("`@('T*"B`@("`@("`@)')E=B`]("1T
M:&ES+3YR979E<G-E*"D["B`@("`@("`@:68@*'-E<FEA;&EZ92@D=&]?;&EN
M97,I("$]('-E<FEA;&EZ92@D<F5V+3YG971/<FEG:6YA;"@I*2D@>PH@("`@
M("`@("`@("!T<FEG9V5R7V5R<F]R*")2979E<G-E9"!O<FEG:6YA;"!D;V5S
M;B=T(&UA=&-H(BP@15]54T527T524D]2*3L*("`@("`@("!]"B`@("`@("`@
M:68@*'-E<FEA;&EZ92@D9G)O;5]L:6YE<RD@(3T@<V5R:6%L:7IE*"1R978M
M/F=E=$9I;F%L*"DI*2!["B`@("`@("`@("`@('1R:6=G97)?97)R;W(H(E)E
M=F5R<V5D(&9I;F%L(&1O97-N)W0@;6%T8V@B+"!%7U5315)?15)23U(I.PH@
M("`@("`@('T*"B`@("`@("`@)'!R979T>7!E(#T@;G5L;#L*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V5D:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@
M(&EF("@D<')E=G1Y<&4@/3T@9V5T7V-L87-S*"1E9&ET*2D@>PH@("`@("`@
M("`@("`@("`@=')I9V=E<E]E<G)O<B@B161I="!S97%U96YC92!I<R!N;VXM
M;W!T:6UA;"(L($5?55-%4E]%4E)/4BD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'!R979T>7!E(#T@9V5T7V-L87-S*"1E9&ET*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H*+RHJ"B`J("1(;W)D
M93H@9G)A;65W;W)K+U1E>'1?1&EF9B]$:69F+G!H<"QV(#$N,3$N,BXW(#(P
M,#8O,#(O,#8@,#`Z,C4Z-3(@:F%N($5X<"`D"B`J"B`J($!P86-K86=E(%1E
M>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER
M:6MI0&1A:7)I:VDN;W)G/@H@*B\*8VQA<W,@5&5X=%]-87!P961$:69F(&5X
M=&5N9',@5&5X=%]$:69F('L*"B`@("`O*BH*("`@("`J($-O;7!U=&5S(&$@
M9&EF9B!B971W965N('-E<75E;F-E<R!O9B!S=')I;F=S+@H@("`@("H*("`@
M("`J(%1H:7,@8V%N(&)E('5S960@=&\@8V]M<'5T92!T:&EN9W,@;&EK92!C
M87-E+6EN<V5N<VET=F4@9&EF9G,L(&]R(&1I9F9S"B`@("`@*B!W:&EC:"!I
M9VYO<F4@8VAA;F=E<R!I;B!W:&ET92US<&%C92X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&9R;VU?;&EN97,@("`@("`@("!!;B!A<G)A>2!O9B!S
M=')I;F=S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1T;U]L:6YE<R`@("`@("`@
M("`@06X@87)R87D@;V8@<W1R:6YG<RX*("`@("`J($!P87)A;2!A<G)A>2`D
M;6%P<&5D7V9R;VU?;&EN97,@(%1H:7,@87)R87D@<VAO=6QD(&AA=F4@=&AE
M('-A;64@<VEZ90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;G5M8F5R(&]F(&5L96UE;G1S(&%S("1F<F]M7VQI;F5S+B`@5&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;&5M
M96YT<R!I;B`D;6%P<&5D7V9R;VU?;&EN97,@86YD"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;6%P<&5D7W1O7VQI;F5S(&%R
M92!W:&%T(&ES(&%C='5A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C;VUP87)E9"!W:&5N(&-O;7!U=&EN9R!T:&4@9&EF
M9BX*("`@("`J($!P87)A;2!A<G)A>2`D;6%P<&5D7W1O7VQI;F5S("`@(%1H
M:7,@87)R87D@<VAO=6QD(&AA=F4@=&AE('-A;64@;G5M8F5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O9B!E;&5M96YT<R!A
M<R`D=&]?;&EN97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?36%P<&5D
M1&EF9B@D9G)O;5]L:6YE<RP@)'1O7VQI;F5S+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1M87!P961?9G)O;5]L:6YE<RP@)&UA<'!E9%]T;U]L
M:6YE<RD*("`@('L*("`@("`@("!A<W-E<G0H8V]U;G0H)&9R;VU?;&EN97,I
M(#T](&-O=6YT*"1M87!P961?9G)O;5]L:6YE<RDI.PH@("`@("`@(&%S<V5R
M="AC;W5N="@D=&]?;&EN97,I(#T](&-O=6YT*"1M87!P961?=&]?;&EN97,I
M*3L*"B`@("`@("`@<&%R96YT.CI497AT7T1I9F8H)&UA<'!E9%]F<F]M7VQI
M;F5S+"`D;6%P<&5D7W1O7VQI;F5S*3L*"B`@("`@("`@)'AI(#T@)'EI(#T@
M,#L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7V5D
M:71S*3L@)&DK*RD@>PH@("`@("`@("`@("`D;W)I9R`]("8D=&AI<RT^7V5D
M:71S6R1I72T^;W)I9SL*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1O<FEG
M*2D@>PH@("`@("`@("`@("`@("`@)&]R:6<@/2!A<G)A>5]S;&EC92@D9G)O
M;5]L:6YE<RP@)'AI+"!C;W5N="@D;W)I9RDI.PH@("`@("`@("`@("`@("`@
M)'AI("L](&-O=6YT*"1O<FEG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&9I;F%L(#T@)B1T:&ES+3Y?961I='-;)&E=+3YF:6YA;#L*("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1F:6YA;"DI('L*("`@("`@("`@("`@("`@
M("1F:6YA;"`](&%R<F%Y7W-L:6-E*"1T;U]L:6YE<RP@)'EI+"!C;W5N="@D
M9FEN86PI*3L*("`@("`@("`@("`@("`@("1Y:2`K/2!C;W5N="@D9FEN86PI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J($-L
M87-S('5S960@:6YT97)N86QL>2!B>2!$:69F('1O(&%C='5A;&QY(&-O;7!U
M=&4@=&AE(&1I9F9S+B`@5&AI<R!C;&%S<PH@*B!U<V5S('1H92!X9&EF9B!0
M14-,('!A8VMA9V4@*&AT='`Z+R]P96-L+G!H<"YN970O<&%C:V%G92]X9&EF
M9BD@=&\@8V]M<'5T90H@*B!T:&4@9&EF9F5R96YC97,@8F5T=V5E;B!T:&4@
M='=O(&EN<'5T(&%R<F%Y<RX*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\
M:F]N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J"B`J($!A
M8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F7T5N9VEN95]X9&EF
M9B!["@H@("`@9G5N8W1I;VX@9&EF9B@D9G)O;5]L:6YE<RP@)'1O7VQI;F5S
M*0H@("`@>PH@("`@("`@("\J($-O;G9E<G0@=&AE('1W;R!I;G!U="!A<G)A
M>7,@:6YT;R!S=')I;F=S(&9O<B!X9&EF9B!P<F]C97-S:6YG+B`J+PH@("`@
M("`@("1F<F]M7W-T<FEN9R`](&EM<&QO9&4H(EQN(BP@)&9R;VU?;&EN97,I
M.PH@("`@("`@("1T;U]S=')I;F<@/2!I;7!L;V1E*")<;B(L("1T;U]L:6YE
M<RD["@H@("`@("`@("\J($1I9F8@=&AE('1W;R!S=')I;F=S(&%N9"!C;VYV
M97)T('1H92!R97-U;'0@=&\@86X@87)R87DN("HO"B`@("`@("`@)&1I9F8@
M/2!X9&EF9E]S=')I;F=?9&EF9B@D9G)O;5]S=')I;F<L("1T;U]S=')I;F<L
M(&-O=6YT*"1T;U]L:6YE<RDI.PH@("`@("`@("1D:69F(#T@97AP;&]D92@B
M7&XB+"`D9&EF9BD["@H@("`@("`@("\J(%=A;&L@=&AR;W5G:"!T:&4@9&EF
M9B!O;F4@;&EN92!A="!A('1I;64N("!792!B=6EL9"!T:&4@)&5D:71S"B`@
M("`@("`@("H@87)R87D@;V8@9&EF9B!O<&5R871I;VYS(&)Y(')E861I;F<@
M=&AE(&9I<G-T(&-H87)A8W1E<B!O9B!T:&4*("`@("`@("`@*B!X9&EF9B!O
M=71P=70@*'=H:6-H(&ES(&EN('1H92`B=6YI9FEE9"!D:69F(B!F;W)M870I
M+@H@("`@("`@("`J"B`@("`@("`@("H@3F]T92!T:&%T('=E(&1O;B=T(&AA
M=F4@96YO=6=H(&EN9F]R;6%T:6]N('1O(&1E=&5C="`B8VAA;F=E9"(*("`@
M("`@("`@*B!L:6YE<R!U<VEN9R!T:&ES(&%P<')O86-H+"!S;R!W92!C86XG
M="!A9&0@5&5X=%]$:69F7T]P7V-H86YG960*("`@("`@("`@*B!I;G-T86YC
M97,@=&\@=&AE("1E9&ET<R!A<G)A>2X@(%1H92!R97-U;'0@:7,@<W1I;&P@
M<&5R9F5C=&QY"B`@("`@("`@("H@=F%L:60L(&%L8F5I="!A(&QI='1L92!L
M97-S(&1E<V-R:7!T:79E(&%N9"!E9F9I8VEE;G0N("HO"B`@("`@("`@)&5D
M:71S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9&EF9B!A<R`D;&EN
M92D@>PH@("`@("`@("`@("!S=VET8V@@*"1L:6YE6S!=*2!["B`@("`@("`@
M("`@(&-A<V4@)R`G.@H@("`@("`@("`@("`@("`@)&5D:71S6UT@/2`F;F5W
M(%1E>'1?1&EF9E]/<%]C;W!Y*&%R<F%Y*'-U8G-T<B@D;&EN92P@,2DI*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G*R<Z
M"B`@("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P
M7V%D9"AA<G)A>2AS=6)S='(H)&QI;F4L(#$I*2D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)RTG.@H@("`@("`@("`@("`@
M("`@)&5D:71S6UT@/2`F;F5W(%1E>'1?1&EF9E]/<%]D96QE=&4H87)R87DH
M<W5B<W1R*"1L:6YE+"`Q*2DI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D961I=',[
M"B`@("!]"@I]"@HO*BH*("H@0VQA<W,@=7-E9"!I;G1E<FYA;&QY(&)Y($1I
M9F8@=&\@86-T=6%L;'D@8V]M<'5T92!T:&4@9&EF9G,N("!4:&ES(&-L87-S
M(&ES"B`J(&EM<&QE;65N=&5D('5S:6YG(&YA=&EV92!02%`@8V]D92X*("H*
M("H@5&AE(&%L9V]R:71H;2!U<V5D(&AE<F4@:7,@;6]S=&QY(&QI9G1E9"!F
M<F]M('1H92!P97)L(&UO9'5L90H@*B!!;&=O<FET:&TZ.D1I9F8@*'9E<G-I
M;VX@,2XP-BD@8GD@3F5D($MO;GHL('=H:6-H(&ES(&%V86EL86)L92!A=#H*
M("H@:'1T<#HO+W=W=RYP97)L+F-O;2]#4$%.+V%U=&AO<G,O:60O3B].12].
M141+3TY:+T%L9V]R:71H;2U$:69F+3$N,#8N>FEP"B`J"B`J($UO<F4@:61E
M87,@87)E('1A:V5N(&9R;VTZ"B`J(&AT='`Z+R]W=W<N:6-S+G5C:2YE9'4O
M?F5P<'-T96EN+S$V,2\Y-C`R,CDN:'1M;`H@*@H@*B!3;VUE(&ED96%S("AA
M;F0@82!B:70@;V8@8V]D92D@87)E('1A:V5N(&9R;VT@86YA;'EZ92YC+"!O
M9B!'3E4*("H@9&EF9G5T:6QS+3(N-RP@=VAI8V@@8V%N(&)E(&9O=6YD(&%T
M.@H@*B!F='`Z+R]G;G5D:7-T+F=N=2YO<F<O<'5B+V=N=2]D:69F=71I;',O
M9&EF9G5T:6QS+3(N-RYT87(N9WH*("H*("H@4V]M92!I9&5A<R`H<W5B9&EV
M:7-I;VX@8GD@3D-(54Y+4R`^(#(L(&%N9"!S;VUE(&]P=&EM:7IA=&EO;G,I
M(&%R92!F<F]M"B`J($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I
M<FEK:2YO<F<^+B!4:&4@;W)I9VEN86P@4$A0('9E<G-I;VX@;V8@=&AI<PH@
M*B!C;V1E('=A<R!W<FET=&5N(&)Y(&AI;2P@86YD(&ES('5S960O861A<'1E
M9"!W:71H(&AI<R!P97)M:7-S:6]N+@H@*@H@*B!`875T:&]R("!'96]F9G)E
M>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*B!`<&%C:V%G
M92!497AT7T1I9F8*("H*("H@0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!4
M97AT7T1I9F9?16YG:6YE7VYA=&EV92!["@H@("`@9G5N8W1I;VX@9&EF9B@D
M9G)O;5]L:6YE<RP@)'1O7VQI;F5S*0H@("`@>PH@("`@("`@("1N7V9R;VT@
M/2!C;W5N="@D9G)O;5]L:6YE<RD["B`@("`@("`@)&Y?=&\@/2!C;W5N="@D
M=&]?;&EN97,I.PH*("`@("`@("`D=&AI<RT^>&-H86YG960@/2`D=&AI<RT^
M>6-H86YG960@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YX=B`]("1T:&ES
M+3YY=B`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/GAI;F0@/2`D=&AI<RT^
M>6EN9"`](&%R<F%Y*"D["B`@("`@("`@=6YS970H)'1H:7,M/G-E<2D["B`@
M("`@("`@=6YS970H)'1H:7,M/FEN7W-E<2D["B`@("`@("`@=6YS970H)'1H
M:7,M/FQC<RD["@H@("`@("`@("\O(%-K:7`@;&5A9&EN9R!C;VUM;VX@;&EN
M97,N"B`@("`@("`@9F]R("@D<VMI<"`](#`[("1S:VEP(#P@)&Y?9G)O;2`F
M)B`D<VMI<"`\("1N7W1O.R`D<VMI<"LK*2!["B`@("`@("`@("`@(&EF("@D
M9G)O;5]L:6YE<ULD<VMI<%T@(3T]("1T;U]L:6YE<ULD<VMI<%TI('L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YX8VAA;F=E9%LD<VMI<%T@/2`D=&AI<RT^>6-H86YG961;)'-K
M:7!=(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!3:VEP('1R86EL
M:6YG(&-O;6UO;B!L:6YE<RX*("`@("`@("`D>&D@/2`D;E]F<F]M.R`D>6D@
M/2`D;E]T;SL*("`@("`@("!F;W(@*"1E;F1S:VEP(#T@,#L@+2TD>&D@/B`D
M<VMI<"`F)B`M+21Y:2`^("1S:VEP.R`D96YD<VMI<"LK*2!["B`@("`@("`@
M("`@(&EF("@D9G)O;5]L:6YE<ULD>&E=("$]/2`D=&]?;&EN97-;)'EI72D@
M>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/GAC:&%N9V5D6R1X:5T@/2`D=&AI<RT^>6-H86YG961;
M)'EI72`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@26=N;W)E(&QI
M;F5S('=H:6-H(&1O(&YO="!E>&ES="!I;B!B;W1H(&9I;&5S+@H@("`@("`@
M(&9O<B`H)'AI(#T@)'-K:7`[("1X:2`\("1N7V9R;VT@+2`D96YD<VMI<#L@
M)'AI*RLI('L*("`@("`@("`@("`@)'AH87-H6R1F<F]M7VQI;F5S6R1X:5U=
M(#T@,3L*("`@("`@("!]"B`@("`@("`@9F]R("@D>6D@/2`D<VMI<#L@)'EI
M(#P@)&Y?=&\@+2`D96YD<VMI<#L@)'EI*RLI('L*("`@("`@("`@("`@)&QI
M;F4@/2`D=&]?;&EN97-;)'EI73L*("`@("`@("`@("`@:68@*"@D=&AI<RT^
M>6-H86YG961;)'EI72`](&5M<'1Y*"1X:&%S:%LD;&EN95TI*2D@>PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'EH87-H6R1L:6YE72`](#$["B`@("`@("`@("`@("1T:&ES+3YY=EM=
M(#T@)&QI;F4["B`@("`@("`@("`@("1T:&ES+3YY:6YD6UT@/2`D>6D["B`@
M("`@("`@?0H@("`@("`@(&9O<B`H)'AI(#T@)'-K:7`[("1X:2`\("1N7V9R
M;VT@+2`D96YD<VMI<#L@)'AI*RLI('L*("`@("`@("`@("`@)&QI;F4@/2`D
M9G)O;5]L:6YE<ULD>&E=.PH@("`@("`@("`@("!I9B`H*"1T:&ES+3YX8VAA
M;F=E9%LD>&E=(#T@96UP='DH)'EH87-H6R1L:6YE72DI*2!["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^>'9;72`]("1L:6YE.PH@("`@("`@("`@("`D=&AI<RT^>&EN9%M=
M(#T@)'AI.PH@("`@("`@('T*"B`@("`@("`@+R\@1FEN9"!T:&4@3$-3+@H@
M("`@("`@("1T:&ES+3Y?8V]M<&%R97-E<2@P+"!C;W5N="@D=&AI<RT^>'8I
M+"`P+"!C;W5N="@D=&AI<RT^>78I*3L*"B`@("`@("`@+R\@365R9V4@961I
M=',@=VAE;B!P;W-S:6)L92X*("`@("`@("`D=&AI<RT^7W-H:69T0F]U;F1A
M<FEE<R@D9G)O;5]L:6YE<RP@)'1H:7,M/GAC:&%N9V5D+"`D=&AI<RT^>6-H
M86YG960I.PH@("`@("`@("1T:&ES+3Y?<VAI9G1";W5N9&%R:65S*"1T;U]L
M:6YE<RP@)'1H:7,M/GEC:&%N9V5D+"`D=&AI<RT^>&-H86YG960I.PH*("`@
M("`@("`O+R!#;VUP=71E('1H92!E9&ET(&]P97)A=&EO;G,N"B`@("`@("`@
M)&5D:71S(#T@87)R87DH*3L*("`@("`@("`D>&D@/2`D>6D@/2`P.PH@("`@
M("`@('=H:6QE("@D>&D@/"`D;E]F<F]M('Q\("1Y:2`\("1N7W1O*2!["B`@
M("`@("`@("`@(&%S<V5R="@D>6D@/"`D;E]T;R!\?"`D=&AI<RT^>&-H86YG
M961;)'AI72D["B`@("`@("`@("`@(&%S<V5R="@D>&D@/"`D;E]F<F]M('Q\
M("1T:&ES+3YY8VAA;F=E9%LD>6E=*3L*"B`@("`@("`@("`@("\O(%-K:7`@
M;6%T8VAI;F<@(G-N86ME(BX*("`@("`@("`@("`@)&-O<'D@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!W:&EL92`H)'AI(#P@)&Y?9G)O;2`F)B`D>6D@/"`D
M;E]T;PH@("`@("`@("`@("`@("`@("`@)B8@(21T:&ES+3YX8VAA;F=E9%LD
M>&E=("8F("$D=&AI<RT^>6-H86YG961;)'EI72D@>PH@("`@("`@("`@("`@
M("`@)&-O<'E;72`]("1F<F]M7VQI;F5S6R1X:2LK73L*("`@("`@("`@("`@
M("`@("LK)'EI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D8V]P
M>2D@>PH@("`@("`@("`@("`@("`@)&5D:71S6UT@/2`F;F5W(%1E>'1?1&EF
M9E]/<%]C;W!Y*"1C;W!Y*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+R\@1FEN9"!D96QE=&5S("8@861D<RX*("`@("`@("`@("`@)&1E;&5T92`]
M(&%R<F%Y*"D["B`@("`@("`@("`@('=H:6QE("@D>&D@/"`D;E]F<F]M("8F
M("1T:&ES+3YX8VAA;F=E9%LD>&E=*2!["B`@("`@("`@("`@("`@("`D9&5L
M971E6UT@/2`D9G)O;5]L:6YE<ULD>&DK*UT["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1A9&0@/2!A<G)A>2@I.PH@("`@("`@("`@("!W:&EL92`H
M)'EI(#P@)&Y?=&\@)B8@)'1H:7,M/GEC:&%N9V5D6R1Y:5TI('L*("`@("`@
M("`@("`@("`@("1A9&1;72`]("1T;U]L:6YE<ULD>6DK*UT["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D9&5L971E("8F("1A9&0I('L*("`@
M("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?3W!?8VAA
M;F=E*"1D96QE=&4L("1A9&0I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&1E
M;&5T92D@>PH@("`@("`@("`@("`@("`@)&5D:71S6UT@/2`F;F5W(%1E>'1?
M1&EF9E]/<%]D96QE=&4H)&1E;&5T92D["B`@("`@("`@("`@('T@96QS96EF
M("@D861D*2!["B`@("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X
M=%]$:69F7T]P7V%D9"@D861D*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1E9&ET<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($1I=FED97,@=&AE($QA<F=E<W0@0V]M;6]N(%-U8G-E<75E;F-E("A,0U,I
M(&]F('1H92!S97%U96YC97,@*%A/1D8L"B`@("`@*B!83$E-*2!A;F0@*%E/
M1D8L(%E,24TI(&EN=&\@3D-(54Y+4R!A<'!R;WAI;6%T96QY(&5Q=6%L;'D@
M<VEZ960*("`@("`J('-E9VUE;G1S+@H@("`@("H*("`@("`J(%)E='5R;G,@
M*$Q#4RP@4%13*2X@($Q#4R!I<R!T:&4@;&5N9W1H(&]F('1H92!,0U,N(%!4
M4R!I<R!A;B!A<G)A>2!O9@H@("`@("H@3D-(54Y+4RLQ("A8+"!9*2!I;F1E
M>&5S(&=I=FEN9R!T:&4@9&EV:6YG('!O:6YT<R!B971W965N('-U8@H@("`@
M("H@<V5Q=65N8V5S+B`@5&AE(&9I<G-T('-U8BUS97%U96YC92!I<R!C;VYT
M86EN960@:6X@*%@P+"!8,2DL("A9,"P@63$I+`H@("`@("H@=&AE('-E8V]N
M9"!I;B`H6#$L(%@R*2P@*%DQ+"!9,BD@86YD('-O(&]N+B`@3F]T92!T:&%T
M("A8,"P@63`I(#T]"B`@("`@*B`H6$]&1BP@64]&1BD@86YD("A86TY#2%5.
M2U-=+"!96TY#2%5.2U-=*2`]/2`H6$Q)32P@64Q)32DN"B`@("`@*@H@("`@
M("H@5&AI<R!F=6YC=&EO;B!A<W-U;65S('1H870@=&AE(&9I<G-T(&QI;F5S
M(&]F('1H92!S<&5C:69I960@<&]R=&EO;G,@;V8*("`@("`J('1H92!T=V\@
M9FEL97,@9&\@;F]T(&UA=&-H+"!A;F0@;&EK97=I<V4@=&AA="!T:&4@;&%S
M="!L:6YE<R!D;R!N;W0*("`@("`J(&UA=&-H+B`@5&AE(&-A;&QE<B!M=7-T
M('1R:6T@;6%T8VAI;F<@;&EN97,@9G)O;2!T:&4@8F5G:6YN:6YG(&%N9"!E
M;F0*("`@("`J(&]F('1H92!P;W)T:6]N<R!I="!I<R!G;VEN9R!T;R!S<&5C
M:69Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&EA9R`H)'AO9F8L("1X;&EM
M+"`D>6]F9BP@)'EL:6TL("1N8VAU;FMS*0H@("`@>PH@("`@("`@("1F;&EP
M(#T@9F%L<V4["@H@("`@("`@(&EF("@D>&QI;2`M("1X;V9F(#X@)'EL:6T@
M+2`D>6]F9BD@>PH@("`@("`@("`@("`O*B!4:&EN9W,@<V5E;7,@9F%S=&5R
M("A))VT@;F]T('-U<F4@22!U;F1E<G-T86YD('=H>2D@=VAE;B!T:&4*("`@
M("`@("`@("`@("H@<VAO<G1E<W0@<V5Q=65N8V4@:7,@:6X@6"X@*B\*("`@
M("`@("`@("`@)&9L:7`@/2!T<G5E.PH@("`@("`@("`@("!L:7-T("@D>&]F
M9BP@)'AL:6TL("1Y;V9F+"`D>6QI;2D*("`@("`@("`@("`@("`@(#T@87)R
M87DH)'EO9F8L("1Y;&EM+"`D>&]F9BP@)'AL:6TI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1F;&EP*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`D>6QI
M;2`M(#$[("1I(#X]("1Y;V9F.R`D:2TM*2!["B`@("`@("`@("`@("`@("`D
M>6UA=&-H97-;)'1H:7,M/GAV6R1I75U;72`]("1I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`]("1Y;&EM
M("T@,3L@)&D@/CT@)'EO9F8[("1I+2TI('L*("`@("`@("`@("`@("`@("1Y
M;6%T8VAE<ULD=&AI<RT^>79;)&E=75M=(#T@)&D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3YL8W,@/2`P.PH@("`@("`@("1T
M:&ES+3YS97%;,%T]("1Y;V9F("T@,3L*("`@("`@("`D=&AI<RT^:6Y?<V5Q
M(#T@87)R87DH*3L*("`@("`@("`D>6UI9'-;,%T@/2!A<G)A>2@I.PH*("`@
M("`@("`D;G5M97(@/2`D>&QI;2`M("1X;V9F("L@)&YC:'5N:W,@+2`Q.PH@
M("`@("`@("1X(#T@)'AO9F8["B`@("`@("`@9F]R("@D8VAU;FL@/2`P.R`D
M8VAU;FL@/"`D;F-H=6YK<SL@)&-H=6YK*RLI('L*("`@("`@("`@("`@:68@
M*"1C:'5N:R`^(#`I('L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\/2`D=&AI<RT^;&-S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@
M)'EM:61S6R1I75LD8VAU;FL@+2`Q72`]("1T:&ES+3YS97%;)&E=.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D>#$@
M/2`D>&]F9B`K("AI;G0I*"@D;G5M97(@*R`H)'AL:6TM)'AO9F8I*B1C:'5N
M:RD@+R`D;F-H=6YK<RD["B`@("`@("`@("`@(&9O<B`H.R`D>"`\("1X,3L@
M)'@K*RD@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2`D9FQI<"`_("1T:&ES
M+3YY=ELD>%T@.B`D=&AI<RT^>'9;)'A=.PH@("`@("`@("`@("`@("`@:68@
M*&5M<'1Y*"1Y;6%T8VAE<ULD;&EN95TI*2!["B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D;6%T8VAE<R`]("1Y;6%T8VAE<ULD;&EN95T["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D;6%T8VAE<R!A<R`D>2D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^:6Y?<V5Q6R1Y72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&L@/2`D=&AI<RT^7VQC<U!O<R@D>2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&%S<V5R="@D:R`^(#`I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D>6UI9'-;)&M=(#T@)'EM:61S6R1K("T@,5T["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!W:&EL
M92`H;&ES="@D:G5N:RP@)'DI(#T@96%C:"@D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'D@/B`D=&AI<RT^<V5Q6R1K("T@,5TI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@87-S97)T*"1Y(#P@)'1H:7,M/G-E
M<5LD:UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!/<'1I;6EZ871I
M;VXZ('1H:7,@:7,@82!C;VUM;VX@8V%S93H@;F5X="!M871C:"!I<PH@("`@
M("`@("`@("`@("`@("`@("`@("`@*B!J=7-T(')E<&QA8VEN9R!P<F5V:6]U
M<R!M871C:"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FEN
M7W-E<5LD=&AI<RT^<V5Q6R1K75T@/2!F86QS93L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E<5LD:UT@/2`D>3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FEN7W-E<5LD>5T@/2`Q.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("AE;7!T>2@D=&AI<RT^:6Y?<V5Q6R1Y72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&L@/2`D=&AI<RT^7VQC<U!O<R@D
M>2D["B`@("`@("`@("`@("`@("`@("`@("`@(&%S<V5R="@D:R`^(#`I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D>6UI9'-;)&M=(#T@)'EM:61S6R1K
M("T@,5T["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<V5P<UM=(#T@
M)&9L:7`@/R!A<G)A>2@D>6]F9BP@)'AO9F8I(#H@87)R87DH)'AO9F8L("1Y
M;V9F*3L*("`@("`@("`D>6UI9"`]("1Y;6ED<ULD=&AI<RT^;&-S73L*("`@
M("`@("!F;W(@*"1N(#T@,#L@)&X@/"`D;F-H=6YK<R`M(#$[("1N*RLI('L*
M("`@("`@("`@("`@)'@Q(#T@)'AO9F8@*R`H:6YT*2@H)&YU;65R("L@*"1X
M;&EM("T@)'AO9F8I("H@)&XI("\@)&YC:'5N:W,I.PH@("`@("`@("`@("`D
M>3$@/2`D>6UI9%LD;ET@*R`Q.PH@("`@("`@("`@("`D<V5P<UM=(#T@)&9L
M:7`@/R!A<G)A>2@D>3$L("1X,2D@.B!A<G)A>2@D>#$L("1Y,2D["B`@("`@
M("`@?0H@("`@("`@("1S97!S6UT@/2`D9FQI<"`_(&%R<F%Y*"1Y;&EM+"`D
M>&QI;2D@.B!A<G)A>2@D>&QI;2P@)'EL:6TI.PH*("`@("`@("!R971U<FX@
M87)R87DH)'1H:7,M/FQC<RP@)'-E<',I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]L8W-0;W,H)'EP;W,I"B`@("!["B`@("`@("`@)&5N9"`]("1T:&ES+3YL
M8W,["B`@("`@("`@:68@*"1E;F0@/3T@,"!\?"`D>7!O<R`^("1T:&ES+3YS
M97%;)&5N9%TI('L*("`@("`@("`@("`@)'1H:7,M/G-E<5LK*R1T:&ES+3YL
M8W-=(#T@)'EP;W,["B`@("`@("`@("`@("1T:&ES+3YI;E]S97%;)'EP;W-=
M(#T@,3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YL8W,["B`@("`@("`@
M?0H*("`@("`@("`D8F5G(#T@,3L*("`@("`@("!W:&EL92`H)&)E9R`\("1E
M;F0I('L*("`@("`@("`@("`@)&UI9"`]("AI;G0I*"@D8F5G("L@)&5N9"D@
M+R`R*3L*("`@("`@("`@("`@:68@*"1Y<&]S(#X@)'1H:7,M/G-E<5LD;6ED
M72D@>PH@("`@("`@("`@("`@("`@)&)E9R`]("1M:60@*R`Q.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&5N9"`]("1M:60["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&%S<V5R="@D>7!O<R`A
M/2`D=&AI<RT^<V5Q6R1E;F1=*3L*"B`@("`@("`@)'1H:7,M/FEN7W-E<5LD
M=&AI<RT^<V5Q6R1E;F1=72`](&9A;'-E.PH@("`@("`@("1T:&ES+3YS97%;
M)&5N9%T@/2`D>7!O<SL*("`@("`@("`D=&AI<RT^:6Y?<V5Q6R1Y<&]S72`]
M(#$["B`@("`@("`@<F5T=7)N("1E;F0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6YD<R!,0U,@;V8@='=O('-E<75E;F-E<RX*("`@("`J"B`@("`@*B!4
M:&4@<F5S=6QT<R!A<F4@<F5C;W)D960@:6X@=&AE('9E8W1O<G,@)'1H:7,M
M/GMX+'E]8VAA;F=E9%M=+"!B>0H@("`@("H@<W1O<FEN9R!A(#$@:6X@=&AE
M(&5L96UE;G0@9F]R(&5A8V@@;&EN92!T:&%T(&ES(&%N(&EN<V5R=&EO;B!O
M<@H@("`@("H@9&5L971I;VX@*&EE+B!I<R!N;W0@:6X@=&AE($Q#4RDN"B`@
M("`@*@H@("`@("H@5&AE('-U8G-E<75E;F-E(&]F(&9I;&4@,"!I<R`H6$]&
M1BP@6$Q)32D@86YD(&QI:V5W:7-E(&9O<B!F:6QE(#$N"B`@("`@*@H@("`@
M("H@3F]T92!T:&%T(%A,24TL(%E,24T@87)E(&5X8VQU<VEV92!B;W5N9',N
M("!!;&P@;&EN92!N=6UB97)S(&%R90H@("`@("H@;W)I9VEN+3`@86YD(&1I
M<V-A<F1E9"!L:6YE<R!A<F4@;F]T(&-O=6YT960N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C;VUP87)E<V5Q("@D>&]F9BP@)'AL:6TL("1Y;V9F+"`D>6QI
M;2D*("`@('L*("`@("`@("`O*B!3;&ED92!D;W=N('1H92!B;W1T;VT@:6YI
M=&EA;"!D:6%G;VYA;"X@*B\*("`@("`@("!W:&EL92`H)'AO9F8@/"`D>&QI
M;2`F)B`D>6]F9B`\("1Y;&EM"B`@("`@("`@("`@("`@("8F("1T:&ES+3YX
M=ELD>&]F9ET@/3T@)'1H:7,M/GEV6R1Y;V9F72D@>PH@("`@("`@("`@("`K
M*R1X;V9F.PH@("`@("`@("`@("`K*R1Y;V9F.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4VQI9&4@=7`@=&AE('1O<"!I;FET:6%L(&1I86=O;F%L+B`J+PH@
M("`@("`@('=H:6QE("@D>&QI;2`^("1X;V9F("8F("1Y;&EM(#X@)'EO9F8*
M("`@("`@("`@("`@("`@)B8@)'1H:7,M/GAV6R1X;&EM("T@,5T@/3T@)'1H
M:7,M/GEV6R1Y;&EM("T@,5TI('L*("`@("`@("`@("`@+2TD>&QI;3L*("`@
M("`@("`@("`@+2TD>6QI;3L*("`@("`@("!]"@H@("`@("`@(&EF("@D>&]F
M9B`]/2`D>&QI;2!\?"`D>6]F9B`]/2`D>6QI;2D@>PH@("`@("`@("`@("`D
M;&-S(#T@,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!4:&ES
M(&ES(&%D(&AO8R!B=70@<V5E;7,@=&\@=V]R:R!W96QL+B`@)&YC:'5N:W,@
M/0H@("`@("`@("`@("`@*B!S<7)T*&UI;B@D>&QI;2`M("1X;V9F+"`D>6QI
M;2`M("1Y;V9F*2`O(#(N-2D[("1N8VAU;FMS(#T*("`@("`@("`@("`@("H@
M;6%X*#(L;6EN*#@L*&EN="DD;F-H=6YK<RDI.R`J+PH@("`@("`@("`@("`D
M;F-H=6YK<R`](&UI;B@W+"`D>&QI;2`M("1X;V9F+"`D>6QI;2`M("1Y;V9F
M*2`K(#$["B`@("`@("`@("`@(&QI<W0H)&QC<RP@)'-E<',I"B`@("`@("`@
M("`@("`@("`]("1T:&ES+3Y?9&EA9R@D>&]F9BP@)'AL:6TL("1Y;V9F+"`D
M>6QI;2P@)&YC:'5N:W,I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1L8W,@
M/3T@,"D@>PH@("`@("`@("`@("`O*B!8(&%N9"!9('-E<75E;F-E<R!H879E
M(&YO(&-O;6UO;B!S=6)S97%U96YC93H@;6%R:R!A;&P*("`@("`@("`@("`@
M("H@8VAA;F=E9"X@*B\*("`@("`@("`@("`@=VAI;&4@*"1Y;V9F(#P@)'EL
M:6TI('L*("`@("`@("`@("`@("`@("1T:&ES+3YY8VAA;F=E9%LD=&AI<RT^
M>6EN9%LD>6]F9BLK75T@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M('=H:6QE("@D>&]F9B`\("1X;&EM*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^>&-H86YG961;)'1H:7,M/GAI;F1;)'AO9F8K*UU=(#T@,3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%5S92!T
M:&4@<&%R=&ET:6]N<R!T;R!S<&QI="!T:&ES('!R;V)L96T@:6YT;R!S=6)P
M<F]B;&5M<RX@*B\*("`@("`@("`@("`@<F5S970H)'-E<',I.PH@("`@("`@
M("`@("`D<'0Q(#T@)'-E<'-;,%T["B`@("`@("`@("`@('=H:6QE("@D<'0R
M(#T@;F5X="@D<V5P<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M
M<&%R97-E<2`H)'!T,5LP72P@)'!T,ELP72P@)'!T,5LQ72P@)'!T,ELQ72D[
M"B`@("`@("`@("`@("`@("`D<'0Q(#T@)'!T,CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D:G5S=',@:6YS97)T
M<R]D96QE=&5S(&]F(&ED96YT:6-A;"!L:6YE<R!T;R!J;VEN(&-H86YG97,@
M87,@;75C:"!A<PH@("`@("H@<&]S<VEB;&4N"B`@("`@*@H@("`@("H@5V4@
M9&\@<V]M971H:6YG('=H96X@82!R=6X@;V8@8VAA;F=E9"!L:6YE<R!I;F-L
M=61E(&$@;&EN92!A="!O;F4@96YD"B`@("`@*B!A;F0@:&%S(&%N(&5X8VQU
M9&5D+"!I9&5N=&EC86P@;&EN92!A="!T:&4@;W1H97(N("!792!A<F4@9G)E
M92!T;PH@("`@("H@8VAO;W-E('=H:6-H(&ED96YT:6-A;"!L:6YE(&ES(&EN
M8VQU9&5D+B`@8&-O;7!A<F5S97$G('5S=6%L;'D@8VAO;W-E<PH@("`@("H@
M=&AE(&]N92!A="!T:&4@8F5G:6YN:6YG+"!B=70@=7-U86QL>2!I="!I<R!C
M;&5A;F5R('1O(&-O;G-I9&5R('1H90H@("`@("H@9F]L;&]W:6YG(&ED96YT
M:6-A;"!L:6YE('1O(&)E('1H92`B8VAA;F=E(BX*("`@("`J"B`@("`@*B!4
M:&ES(&ES(&5X=')A8W1E9"!V97)B871I;2!F<F]M(&%N86QY>F4N8R`H1TY5
M(&1I9F9U=&EL<RTR+C<I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<VAI9G1"
M;W5N9&%R:65S*"1L:6YE<RP@)B1C:&%N9V5D+"`D;W1H97)?8VAA;F=E9"D*
M("`@('L*("`@("`@("`D:2`](#`["B`@("`@("`@)&H@/2`P.PH*("`@("`@
M("!A<W-E<G0H)V-O=6YT*"1L:6YE<RD@/3T@8V]U;G0H)&-H86YG960I)RD[
M"B`@("`@("`@)&QE;B`](&-O=6YT*"1L:6YE<RD["B`@("`@("`@)&]T:&5R
M7VQE;B`](&-O=6YT*"1O=&AE<E]C:&%N9V5D*3L*"B`@("`@("`@=VAI;&4@
M*#$I('L*("`@("`@("`@("`@+RH@4V-A;B!F;W)W87)D('1O(&9I;F0@=&AE
M(&)E9VEN;FEN9R!O9B!A;F]T:&5R(')U;B!O9@H@("`@("`@("`@("`@*B!C
M:&%N9V5S+B!!;'-O(&ME97`@=')A8VL@;V8@=&AE(&-O<G)E<W!O;F1I;F<@
M<&]I;G0@:6X@=&AE"B`@("`@("`@("`@("`J(&]T:&5R(&9I;&4N"B`@("`@
M("`@("`@("`J"B`@("`@("`@("`@("`J(%1H<F]U9VAO=70@=&AI<R!C;V1E
M+"`D:2!A;F0@)&H@87)E(&%D:G5S=&5D('1O9V5T:&5R('-O('1H870*("`@
M("`@("`@("`@("H@=&AE(&9I<G-T("1I(&5L96UE;G1S(&]F("1C:&%N9V5D
M(&%N9"!T:&4@9FER<W0@)&H@96QE;65N=',@;V8*("`@("`@("`@("`@("H@
M)&]T:&5R7V-H86YG960@8F]T:"!C;VYT86EN('1H92!S86UE(&YU;6)E<B!O
M9B!Z97)O<R`H=6YC:&%N9V5D"B`@("`@("`@("`@("`J(&QI;F5S*2X*("`@
M("`@("`@("`@("H*("`@("`@("`@("`@("H@1G5R=&AE<FUO<F4L("1J(&ES
M(&%L=V%Y<R!K97!T('-O('1H870@)&H@/3T@)&]T:&5R7VQE;B!O<@H@("`@
M("`@("`@("`@*B`D;W1H97)?8VAA;F=E9%LD:ET@/3T@9F%L<V4N("HO"B`@
M("`@("`@("`@('=H:6QE("@D:B`\("1O=&AE<E]L96X@)B8@)&]T:&5R7V-H
M86YG961;)&I=*2!["B`@("`@("`@("`@("`@("`D:BLK.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!W:&EL92`H)&D@/"`D;&5N("8F("$@)&-H86YG
M961;)&E=*2!["B`@("`@("`@("`@("`@("!A<W-E<G0H)R1J(#P@)&]T:&5R
M7VQE;B`F)B`A("1O=&AE<E]C:&%N9V5D6R1J72<I.PH@("`@("`@("`@("`@
M("`@)&DK*SL@)&HK*SL*("`@("`@("`@("`@("`@('=H:6QE("@D:B`\("1O
M=&AE<E]L96X@)B8@)&]T:&5R7V-H86YG961;)&I=*2!["B`@("`@("`@("`@
M("`@("`@("`@)&HK*SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"1I(#T]("1L96XI('L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<W1A<G0@
M/2`D:3L*"B`@("`@("`@("`@("\J($9I;F0@=&AE(&5N9"!O9B!T:&ES(')U
M;B!O9B!C:&%N9V5S+B`J+PH@("`@("`@("`@("!W:&EL92`H*RLD:2`\("1L
M96X@)B8@)&-H86YG961;)&E=*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9&\@>PH@("`@("`@("`@
M("`@("`@+RH@4F5C;W)D('1H92!L96YG=&@@;V8@=&AI<R!R=6X@;V8@8VAA
M;F=E<RP@<V\@=&AA="!W92!C86X*("`@("`@("`@("`@("`@("`J(&QA=&5R
M(&1E=&5R;6EN92!W:&5T:&5R('1H92!R=6X@:&%S(&=R;W=N+B`J+PH@("`@
M("`@("`@("`@("`@)')U;FQE;F=T:"`]("1I("T@)'-T87)T.PH*("`@("`@
M("`@("`@("`@("\J($UO=F4@=&AE(&-H86YG960@<F5G:6]N(&)A8VLL('-O
M(&QO;F<@87,@=&AE('!R979I;W5S"B`@("`@("`@("`@("`@("`@*B!U;F-H
M86YG960@;&EN92!M871C:&5S('1H92!L87-T(&-H86YG960@;VYE+B`@5&AI
M<R!M97)G97,*("`@("`@("`@("`@("`@("`J('=I=&@@<')E=FEO=7,@8VAA
M;F=E9"!R96=I;VYS+B`J+PH@("`@("`@("`@("`@("`@=VAI;&4@*"1S=&%R
M="`^(#`@)B8@)&QI;F5S6R1S=&%R="`M(#%=(#T]("1L:6YE<ULD:2`M(#%=
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-H86YG961;+2TD<W1A<G1=(#T@
M,3L*("`@("`@("`@("`@("`@("`@("`D8VAA;F=E9%LM+21I72`](&9A;'-E
M.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@D<W1A<G0@/B`P("8F("1C
M:&%N9V5D6R1S=&%R="`M(#%=*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1S=&%R="TM.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!A<W-E<G0H)R1J(#X@,"<I.PH@("`@("`@("`@("`@("`@("`@
M('=H:6QE("@D;W1H97)?8VAA;F=E9%LM+21J72D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@87-S97)T*"<D:B`^/2`P("8F("$D;W1H97)?
M8VAA;F=E9%LD:ETG*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`O*B!3970@0T]24D534$].1$E.1R!T;R!T:&4@96YD(&]F('1H92!C
M:&%N9V5D(')U;BP@870@=&AE"B`@("`@("`@("`@("`@("`@*B!L87-T('!O
M:6YT('=H97)E(&ET(&-O<G)E<W!O;F1S('1O(&$@8VAA;F=E9"!R=6X@:6X@
M=&AE"B`@("`@("`@("`@("`@("`@*B!O=&AE<B!F:6QE+B!#3U)215-03TY$
M24Y'(#T]($Q%3B!M96%N<R!N;R!S=6-H('!O:6YT(&AA<PH@("`@("`@("`@
M("`@("`@("H@8F5E;B!F;W5N9"X@*B\*("`@("`@("`@("`@("`@("1C;W)R
M97-P;VYD:6YG(#T@)&H@/"`D;W1H97)?;&5N(#\@)&D@.B`D;&5N.PH*("`@
M("`@("`@("`@("`@("\J($UO=F4@=&AE(&-H86YG960@<F5G:6]N(&9O<G=A
M<F0L('-O(&QO;F<@87,@=&AE(&9I<G-T"B`@("`@("`@("`@("`@("`@*B!C
M:&%N9V5D(&QI;F4@;6%T8VAE<R!T:&4@9F]L;&]W:6YG('5N8VAA;F=E9"!O
M;F4N("!4:&ES"B`@("`@("`@("`@("`@("`@*B!M97)G97,@=VET:"!F;VQL
M;W=I;F<@8VAA;F=E9"!R96=I;VYS+B`@1&\@=&AI<R!S96-O;F0L('-O"B`@
M("`@("`@("`@("`@("`@*B!T:&%T(&EF('1H97)E(&%R92!N;R!M97)G97,L
M('1H92!C:&%N9V5D(')E9VEO;B!I<R!M;W9E9`H@("`@("`@("`@("`@("`@
M("H@9F]R=V%R9"!A<R!F87(@87,@<&]S<VEB;&4N("HO"B`@("`@("`@("`@
M("`@("!W:&EL92`H)&D@/"`D;&5N("8F("1L:6YE<ULD<W1A<G1=(#T]("1L
M:6YE<ULD:5TI('L*("`@("`@("`@("`@("`@("`@("`D8VAA;F=E9%LD<W1A
M<G0K*UT@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`D8VAA;F=E9%LD
M:2LK72`](#$["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1I(#P@)&QE
M;B`F)B`D8VAA;F=E9%LD:5TI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&DK*SL*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M("`@(&%S<V5R="@G)&H@/"`D;W1H97)?;&5N("8F("$@)&]T:&5R7V-H86YG
M961;)&I=)RD["B`@("`@("`@("`@("`@("`@("`@)&HK*SL*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&H@/"`D;W1H97)?;&5N("8F("1O=&AE<E]C:&%N
M9V5D6R1J72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]R<F5S<&]N
M9&EN9R`]("1I.PH@("`@("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&H@
M/"`D;W1H97)?;&5N("8F("1O=&AE<E]C:&%N9V5D6R1J72D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&HK*SL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!W:&EL92`H)')U;FQE;F=T:"`A/2`D:2`M("1S
M=&%R="D["@H@("`@("`@("`@("`O*B!)9B!P;W-S:6)L92P@;6]V92!T:&4@
M9G5L;'DM;65R9V5D(')U;B!O9B!C:&%N9V5S(&)A8VL@=&\@80H@("`@("`@
M("`@("`@*B!C;W)R97-P;VYD:6YG(')U;B!I;B!T:&4@;W1H97(@9FEL92X@
M*B\*("`@("`@("`@("`@=VAI;&4@*"1C;W)R97-P;VYD:6YG(#P@)&DI('L*
M("`@("`@("`@("`@("`@("1C:&%N9V5D6RTM)'-T87)T72`](#$["B`@("`@
M("`@("`@("`@("`D8VAA;F=E9%LM+21I72`](#`["B`@("`@("`@("`@("`@
M("!A<W-E<G0H)R1J(#X@,"<I.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1O
M=&AE<E]C:&%N9V5D6RTM)&I=*2!["B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!A<W-E
M<G0H)R1J(#X](#`@)B8@(21O=&AE<E]C:&%N9V5D6R1J72<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E
M>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER
M:6MI0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L
M87-S(%1E>'1?1&EF9E]/<"!["@H@("`@=F%R("1O<FEG.PH@("`@=F%R("1F
M:6YA;#L*"B`@("!F=6YC=&EO;B!R979E<G-E*"D*("`@('L*("`@("`@("!T
M<FEG9V5R7V5R<F]R*"=!8G-T<F%C="!M971H;V0G+"!%7U5315)?15)23U(I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&YO<FEG*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/F]R:6<@/R!C;W5N="@D=&AI<RT^;W)I9RD@.B`P.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&YF:6YA;"@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YF:6YA;"`_(&-O=6YT*"1T:&ES+3YF:6YA;"D@.B`P.PH@
M("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R
M("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@
M*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9E]/<%]C
M;W!Y(&5X=&5N9',@5&5X=%]$:69F7T]P('L*"B`@("!F=6YC=&EO;B!497AT
M7T1I9F9?3W!?8V]P>2@D;W)I9RP@)&9I;F%L(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D9FEN86PI*2!["B`@("`@("`@("`@("1F
M:6YA;"`]("1O<FEG.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;W)I9R`]
M("1O<FEG.PH@("`@("`@("1T:&ES+3YF:6YA;"`]("1F:6YA;#L*("`@('T*
M"B`@("!F=6YC=&EO;B`F<F5V97)S92@I"B`@("!["B`@("`@("`@)')E=F5R
M<V4@/2`F;F5W(%1E>'1?1&EF9E]/<%]C;W!Y*"1T:&ES+3YF:6YA;"P@)'1H
M:7,M/F]R:6<I.PH@("`@("`@(')E='5R;B`D<F5V97)S93L*("`@('T*"GT*
M"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R
M97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@0&%C
M8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F9?3W!?9&5L971E(&5X
M=&5N9',@5&5X=%]$:69F7T]P('L*"B`@("!F=6YC=&EO;B!497AT7T1I9F9?
M3W!?9&5L971E*"1L:6YE<RD*("`@('L*("`@("`@("`D=&AI<RT^;W)I9R`]
M("1L:6YE<SL*("`@("`@("`D=&AI<RT^9FEN86P@/2!F86QS93L*("`@('T*
M"B`@("!F=6YC=&EO;B`F<F5V97)S92@I"B`@("!["B`@("`@("`@)')E=F5R
M<V4@/2`F;F5W(%1E>'1?1&EF9E]/<%]A9&0H)'1H:7,M/F]R:6<I.PH@("`@
M("`@(')E='5R;B`D<F5V97)S93L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G
M92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\
M9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@0&%C8V5S<R!P<FEV871E"B`J
M+PIC;&%S<R!497AT7T1I9F9?3W!?861D(&5X=&5N9',@5&5X=%]$:69F7T]P
M('L*"B`@("!F=6YC=&EO;B!497AT7T1I9F9?3W!?861D*"1L:6YE<RD*("`@
M('L*("`@("`@("`D=&AI<RT^9FEN86P@/2`D;&EN97,["B`@("`@("`@)'1H
M:7,M/F]R:6<@/2!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B`F<F5V97)S
M92@I"B`@("!["B`@("`@("`@)')E=F5R<V4@/2`F;F5W(%1E>'1?1&EF9E]/
M<%]D96QE=&4H)'1H:7,M/F9I;F%L*3L*("`@("`@("!R971U<FX@)')E=F5R
M<V4["B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A
M=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO
M<F<^"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F
M7T]P7V-H86YG92!E>'1E;F1S(%1E>'1?1&EF9E]/<"!["@H@("`@9G5N8W1I
M;VX@5&5X=%]$:69F7T]P7V-H86YG92@D;W)I9RP@)&9I;F%L*0H@("`@>PH@
M("`@("`@("1T:&ES+3YO<FEG(#T@)&]R:6<["B`@("`@("`@)'1H:7,M/F9I
M;F%L(#T@)&9I;F%L.PH@("`@?0H*("`@(&9U;F-T:6]N("9R979E<G-E*"D*
M("`@('L*("`@("`@("`D<F5V97)S92`]("9N97<@5&5X=%]$:69F7T]P7V-H
M86YG92@D=&AI<RT^9FEN86PL("1T:&ES+3YO<FEG*3L*("`@("`@("!R971U
M<FX@)')E=F5R<V4["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T9L;W=E9"YP:'``````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8W,C$`,3`U,34T,S$P
M-C``,#(P,#,W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@5&5X=%]&;&]W960Z.B!C;&%S<R!P
M<F]V:61E<R!C;VUM;VX@;65T:&]D<R!F;W(@;6%N:7!U;&%T:6YG('1E>'0*
M("H@=7-I;F<@=&AE(&5N8V]D:6YG(&1E<V-R:6)E9"!I;B!21D,@,S8W-B`H
M)V9L;W=E9"<@=&5X="DN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?
M1FQO=V5D+T9L;W=E9"YP:'`L=B`Q+C$T+C$P+C$W(#(P,#8O,#,O,3$@,#DZ
M-3`Z,C(@:F%N($5X<"`D"B`J"B`J(%1H:7,@8VQA<W,@:7,@8F%S960@;VX@
M=&AE(%1E>'0Z.D9L;W=E9"!P97)L(&UO9'5L92`H5F5R<VEO;B`P+C$T*2!F
M;W5N9`H@*B!I;B!T:&4@0U!!3B!P97)L(')E<&]S:71O<GDN("!4:&ES(&UO
M9'5L92!I<R!R96QE87-E9"!U;F1E<B!T:&4@4&5R;`H@*B!L:6-E;G-E+"!W
M:&EC:"!I<R!C;VUP871I8FQE('=I=&@@=&AE($Q'4$PN"B`J"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#,@4&AI;&EP($UA:PH@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S
M(%1E>'1?1FQO=V5D('L*"B`@("`O*BH*("`@("`J(%1H92!M87AI;75M(&QE
M;F=T:"!T:&%T(&$@;&EN92!I<R!A;&QO=V5D('1O(&)E("AU;FQE<W,@9F%C
M960@=VET:`H@("`@("H@=VET:"!A('=O<F0@=&AA="!I<R!U;G)E87-O;F%B
M;'D@;&]N9RDN(%1H:7,@8VQA<W,@=VEL;"!R92UW<F%P(&$*("`@("`J(&QI
M;F4@:68@:70@97AC965D<R!T:&ES(&QE;F=T:"X*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?;6%X;&5N9W1H(#T@-S@[
M"@H@("`@+RHJ"B`@("`@*B!7:&5N('1H:7,@8VQA<W,@=W)A<',@82!L:6YE
M+"!T:&4@;F5W;'D@8W)E871E9"!L:6YE<R!W:6QL(&)E('-P;&ET"B`@("`@
M*B!A="!T:&ES(&QE;F=T:"X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1?;W!T;&5N9W1H(#T@-S(["@H@("`@+RHJ"B`@
M("`@*B!4:&4@=&5X="!T;R!B92!F;W)M871T960N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&5X=#L*"B`@("`O*BH*
M("`@("`J(%1H92!C86-H960@;W5T<'5T(&]F('1H92!F;W)M871T:6YG+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;W5T
M<'5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!C:&%R86-T97(@<V5T
M(&]F('1H92!T97AT+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V-H87)S970["@H@("`@+RHJ"B`@("`@*B!#;VYV97)T
M('1E>'0@=7-I;F<@1&5L4W`_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N
M"B`@("`@*B\*("`@('9A<B`D7V1E;'-P(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("`@("!4:&4@=&5X="!T;R!P<F]C97-S+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@;V8@)'1E>'0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?1FQO=V5D*"1T97AT+"`D8VAA
M<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]T97AT(#T@)'1E
M>'0["B`@("`@("`@)'1H:7,M/E]C:&%R<V5T(#T@)&-H87)S970["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&UA>&EM=6T@;&5N9W1H(&]F(&$@
M;&EN92!O9B!T97AT+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M
M87@@($$@;F5W('9A;'5E(&9O<B`D7VUA>&QE;F=T:"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T36%X3&5N9W1H*"1M87@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]M87AL96YG=&@@/2`D;6%X.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!O<'1I;6%L(&QE;F=T:"!O9B!A(&QI;F4@;V8@=&5X="X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X("!!(&YE=R!V86QU92!F
M;W(@)%]O<'1L96YG=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=$QE
M;F=T:"@D;W!T*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!T;&5N9W1H(#T@
M)&]P=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!W:&5T:&5R('1O(&9O
M<FUA="!T97-T('5S:6YG($1E;%-P+@H@("`@("H*("`@("`J($!S:6YC92!(
M;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5L<W`@
M(%5S92!$96Q3<#\*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5L4W`H)&1E
M;'-P*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&5L<W`@/2`H8F]O;"D@)&1E
M;'-P.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5F;W)M871S('1H92!I;G!U
M="!S=')I;F<L('=H97)E('1H92!S=')I;F<@:7,@)V9O<FUA=#UF;&]W960G
M('!L86EN"B`@("`@*B!T97AT(&%S(&1E<V-R:6)E9"!I;B!21D,@,C8T-BX*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<75O=&4@($%D9"!L979E
M;"!O9B!Q=6]T:6YG('1O(&5A8V@@;&EN93\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('1E>'0@8V]N=F5R=&5D('1O(%)&0R`R-C0V("=F
M:7AE9"<@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T9I>&5D*"1Q
M=6]T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1T>'0@/2`G)SL*"B`@("`@
M("`@)'1H:7,M/E]R969O<FUA="AF86QS92P@)'%U;W1E*3L*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V]U='!U="!A<R`D=F%L*2!["B`@("`@("`@("`@
M("1T>'0@+CT@)'9A;%LG=&5X="==("X@(EQN(CL*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N(')T<FEM*"1T>'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5F;W)M871S('1H92!I;G!U="!S=')I;F<L(&%N9"!R971U<FYS('1H92!O
M=71P=70@:6X@86X@87)R87D@9F]R;6%T"B`@("`@*B!W:71H('%U;W1E(&QE
M=F5L(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1Q=6]T92`@061D(&QE=F5L(&]F('%U;W1I;F<@=&\@96%C:"!L:6YE/PH@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%R<F%Y
M<R!W:71H('1H92!F;VQL;W=I;F<@96QE;65N=',Z"B`@("`@*B`\<')E/@H@
M("`@("H@)VQE=F5L)R`M(%1H92!Q=6]T92!L979E;"!O9B!T:&4@8W5R<F5N
M="!L:6YE+@H@("`@("H@)W1E>'0G("`M(%1H92!T97AT(&9O<B!T:&4@8W5R
M<F5N="!L:6YE+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1O1FEX961!<G)A>2@D<75O=&4@/2!F86QS92D*("`@('L*("`@("`@("`D
M=&AI<RT^7W)E9F]R;6%T*&9A;'-E+"`D<75O=&4I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E9F]R
M;6%T<R!T:&4@:6YP=70@<W1R:6YG+"!W:&5R92!T:&4@<W1R:6YG(&ES("=F
M;W)M870]9FEX960G('!L86EN"B`@("`@*B!T97AT(&%S(&1E<V-R:6)E9"!I
M;B!21D,@,C8T-BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<75O
M=&4@($%D9"!L979E;"!O9B!Q=6]T:6YG('1O(&5A8V@@;&EN93\*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@8V]N=F5R=&5D('1O
M(%)&0R`R-C0V("=F;&]W960G(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=&]&;&]W960H)'%U;W1E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1X
M="`]("<G.PH*("`@("`@("`D=&AI<RT^7W)E9F]R;6%T*'1R=64L("1Q=6]T
M92D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]O=71P=70@87,@)'9A;"D@
M>PH@("`@("`@("`@("`D='AT("X]("1V86Q;)W1E>'0G72`N(")<;B(["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D='AT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5F;W)M871S('1H92!I;G!U="!S=')I;F<L('=H97)E('1H92!S
M=')I;F<@:7,@)V9O<FUA=#UF;&]W960G('!L86EN"B`@("`@*B!T97AT(&%S
M(&1E<V-R:6)E9"!I;B!21D,@,C8T-BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=&]F;&]W
M960@($-O;G9E<G0@=&\@9FQO=V5D/PH@("`@("H@0'!A<F%M(&)O;VQE86X@
M)'%U;W1E("`@("!!9&0@;&5V96P@;V8@<75O=&EN9R!T;R!E86-H(&QI;F4_
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F(&%R<F%Y
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E9F]R;6%T*"1T;V9L;W=E9"P@
M)'%U;W1E*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7V]U
M='!U="DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]O=71P=70@/2!A<G)A>2@I.PH@("`@("`@("1T97AT(#T@
M97AP;&]D92@B7&XB+"`D=&AI<RT^7W1E>'0I.PH*("`@("`@("`O*B!3970@
M=F%R:6%B;&5S('5S960@:6X@<F5G97AP<RX@*B\*("`@("`@("`D9&5L<W`@
M/2`H)'1O9FQO=V5D("8F("1T:&ES+3Y?9&5L<W`I(#\@,2`Z(#`["B`@("`@
M("`@)&]P="`]("1T:&ES+3Y?;W!T;&5N9W1H("T@,2`M("1D96QS<#L*"B`@
M("`@("`@+RH@4')O8V5S<R!M97-S86=E(&QI;F4@8GD@;&EN92X@*B\*("`@
M("`@("!D;R!["B`@("`@("`@("`@("1L:6YE(#T@87)R87E?<VAI9G0H)'1E
M>'0I.PH*("`@("`@("`@("`@+RH@4&5R(%)&0R`R-C0V(%LT+C-=+"!T:&4@
M)U5S96YE="!3:6=N871U<F4@0V]N=F5N=&EO;B<@;&EN90H@("`@("`@("`@
M("`@*B`H1$%32"!$05-((%-0*2!I<R!N;W0@8V]N<VED97)E9"!F;&]W960N
M("!7871C:"!F;W(@=&AI<R!W:&5N"B`@("`@("`@("`@("`J(&1E86QI;F<@
M=VET:"!P;W1E;G1I86QL>2!F;&]W960@;&EN97,N("HO"@H@("`@("`@("`@
M("`O*B!4:&4@;F5X="!T:')E92!S=&5P<R!C;VUE(&9R;VT@4D9#(#(V-#8@
M6S0N,ETN("HO"B`@("`@("`@("`@("\J(%-415`@,3H@1&5T97)M:6YE('%U
M;W1E(&QE=F5L(&9O<B!L:6YE+B`J+PH@("`@("`@("`@("!I9B`H*"1N=6U?
M<75O=&5S(#T@)'1H:7,M/E]N=6UQ=6]T97,H)&QI;F4I*2D@>PH@("`@("`@
M("`@("`@("`@)&QI;F4@/2!S=6)S='(H)&QI;F4L("1N=6U?<75O=&5S*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@3VYL>2!C;VUB:6YE(&QI
M;F5S(&EF('=E(&%R92!C;VYV97)T:6YG('1O(&9L;W=E9"!O<B!I9B!T:&4*
M("`@("`@("`@("`@("H@8W5R<F5N="!L:6YE(&ES('%U;W1E9"X@*B\*("`@
M("`@("`@("`@:68@*"$D=&]F;&]W960@?'P@)&YU;5]Q=6]T97,I('L*("`@
M("`@("`@("`@("`@("\J(%-415`@,CH@4F5M;W9E('-P86-E('-T=69F:6YG
M(&9R;VT@;&EN92X@*B\*("`@("`@("`@("`@("`@("1L:6YE(#T@)'1H:7,M
M/E]U;G-T=69F*"1L:6YE*3L*"B`@("`@("`@("`@("`@("`O*B!35$50(#,Z
M(%-H;W5L9"!W92!I;G1E<G!R970@=&AI<R!L:6YE(&%S(&9L;W=E9#\*("`@
M("`@("`@("`@("`@("`J(%=H:6QE(&QI;F4@:7,@9FQO=V5D("AN;W0@96UP
M='D@86YD('1H97)E(&ES(&$@<W!A8V4*("`@("`@("`@("`@("`@("`J(&%T
M('1H92!E;F0@;V8@=&AE(&QI;F4I+"!A;F0@=&AE<F4@:7,@82!N97AT(&QI
M;F4L(&%N9"!T:&4*("`@("`@("`@("`@("`@("`J(&YE>'0@;&EN92!H87,@
M=&AE('-A;64@<75O=&4@9&5P=&@L(&%D9"!T;R!T:&4@8W5R<F5N=`H@("`@
M("`@("`@("`@("`@("H@;&EN92X@02!L:6YE(&ES(&YO="!F;&]W960@:68@
M:70@:7,@82!S:6=N871U<F4@;&EN92X@*B\*("`@("`@("`@("`@("`@('=H
M:6QE("@A96UP='DH)&QI;F4I("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M*"1L:6YE("$]("<M+2`G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("@D
M;&EN97MS=')L96XH)&QI;F4I+3%](#T]("<@)RD@)B8*("`@("`@("`@("`@
M("`@("`@("`@("`A96UP='DH)'1E>'0I("8F"B`@("`@("`@("`@("`@("`@
M("`@("`@*"1T:&ES+3Y?;G5M<75O=&5S*"1T97AT6S!=*2`]/2`D;G5M7W%U
M;W1E<RDI('L*("`@("`@("`@("`@("`@("`@("`O*B!)9B!$96Q3<"!I<R!Y
M97,@86YD('1H:7,@:7,@9FQO=V5D(&EN<'5T+"!W92!N965D('1O"B`@("`@
M("`@("`@("`@("`@("`@("H@<F5M;W9E('1H92!T<F%I;&EN9R!S<&%C92X@
M*B\*("`@("`@("`@("`@("`@("`@("!I9B`H(21T;V9L;W=E9"`F)B`D=&AI
M<RT^7V1E;'-P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L:6YE(#T@
M<W5B<W1R*"1L:6YE+"`P+"`M,2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1L:6YE("X]("1T:&ES+3Y?=6YS='5F9BAS
M=6)S='(H87)R87E?<VAI9G0H)'1E>'0I+"`D;G5M7W%U;W1E<RDI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!%
M;G-U<F4@;&EN92!I<R!F:7AE9"P@<VEN8V4@=V4@86QR96%D>2!J;VEN960@
M86QL(&9L;W=E9`H@("`@("`@("`@("`@*B!L:6YE<RX@4F5M;W9E(&%L;"!T
M<F%I;&EN9R`G("<@9G)O;2!T:&4@;&EN92X@*B\*("`@("`@("`@("`@:68@
M*"1L:6YE("$]("<M+2`G*2!["B`@("`@("`@("`@("`@("`D;&EN92`](')T
M<FEM*"1L:6YE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@26YC
M<F5M96YT('%U;W1E(&1E<'1H(&EF('=E)W)E('%U;W1I;F<N("HO"B`@("`@
M("`@("`@(&EF("@D<75O=&4I('L*("`@("`@("`@("`@("`@("1N=6U?<75O
M=&5S*RL["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%1H92!Q=6]T
M92!P<F5F:7@@9F]R('1H92!L:6YE+B`J+PH@("`@("`@("`@("`D<75O=&5S
M='(@/2!S=')?<F5P96%T*"<^)RP@)&YU;5]Q=6]T97,I.PH*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1L:6YE*2D@>PH@("`@("`@("`@("`@("`@+RH@3&EN
M92!I<R!E;7!T>2X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M6UT@/2!A<G)A>2@G=&5X="<@/3X@)'%U;W1E<W1R+"`G;&5V96PG(#T^("1N
M=6U?<75O=&5S*3L*("`@("`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1T:&ES
M+3Y?;6%X;&5N9W1H*2!\?"`H*%-T<FEN9SHZ;&5N9W1H*"1L:6YE+"`D=&AI
M<RT^7V-H87)S970I("L@)&YU;5]Q=6]T97,I(#P]("1T:&ES+3Y?;6%X;&5N
M9W1H*2D@>PH@("`@("`@("`@("`@("`@+RH@3&EN92!D;V5S(&YO="!R97%U
M:7)E(')E=W)A<'!I;F<N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U=%M=(#T@87)R87DH)W1E>'0G(#T^("1Q=6]T97-T<B`N("1T:&ES+3Y?
M<W1U9F8H)&QI;F4L("1N=6U?<75O=&5S+"`D=&]F;&]W960I+"`G;&5V96PG
M(#T^("1N=6U?<75O=&5S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1M:6X@/2`D;G5M7W%U;W1E<R`K(#$["@H@("`@("`@("`@
M("`@("`@+RH@4F5W<F%P('1H:7,@<&%R86=R87!H+B`J+PH@("`@("`@("`@
M("`@("`@=VAI;&4@*"1L:6YE*2!["B`@("`@("`@("`@("`@("`@("`@+RH@
M4W1U9F8@86YD(')E+7%U;W1E('1H92!L:6YE+B`J+PH@("`@("`@("`@("`@
M("`@("`@("1L:6YE(#T@)'%U;W1E<W1R("X@)'1H:7,M/E]S='5F9B@D;&EN
M92P@)&YU;5]Q=6]T97,L("1T;V9L;W=E9"D["B`@("`@("`@("`@("`@("`@
M("`@)&QI;F5?;&5N9W1H(#T@4W1R:6YG.CIL96YG=&@H)&QI;F4L("1T:&ES
M+3Y?8VAA<G-E="D["B`@("`@("`@("`@("`@("`@("`@:68@*"1L:6YE7VQE
M;F=T:"`\/2`D=&AI<RT^7V]P=&QE;F=T:"D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`O*B!296UA:6YI;F<@<V5C=&EO;B!O9B!L:6YE(&ES('-H;W)T
M(&5N;W5G:"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=71P=71;72`](&%R<F%Y*"=T97AT)R`]/B`D;&EN92P@)VQE=F5L)R`]/B`D
M;G5M7W%U;W1E<RD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D;2`](%-T<FEN9SHZ<F5G
M97A-871C:"@D;&EN92P@87)R87DH)UXH+GLG("X@)&UI;B`N("<L)R`N("1O
M<'0@+B`G?2D@*"XJ*2<L("=>*"Y[)R`N("1M:6X@+B`G+"<@+B`D=&AI<RT^
M7VUA>&QE;F=T:"`N("=]*2`H+BHI)RP@)UXH+GLG("X@)&UI;B`N("<L?2D_
M("@N*BDG*2P@)'1H:7,M/E]C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`O*B!792!N965D('1O('=R87`@=&5X="!A="!A(&-E<G1A:6X@
M;G5M8F5R(&]F"B`@("`@("`@("`@("`@("`@("`@("`@("`J("IC:&%R86-T
M97)S*BP@;F]T(&$@8V5R=&%I;B!N=6UB97(@;V8@*F)Y=&5S*CL*("`@("`@
M("`@("`@("`@("`@("`@("`@("H@=&AU<R!T:&4@;F5E9"!F;W(@82!M=6QT
M:6)Y=&4@8V%P86)L92!R96=E>"X*("`@("`@("`@("`@("`@("`@("`@("`@
M("H@268@82!M=6QT:6)Y=&4@<F5G97@@:7-N)W0@879A:6QA8FQE+"!W92!A
M<F4@<W1U8VL*("`@("`@("`@("`@("`@("`@("`@("`@("H@=VET:"!P<F5G
M7VUA=&-H*"D@*'1H92!F=6YC=&EO;B!W:6QL('-T:6QL('=O<FL@+0H@("`@
M("`@("`@("`@("`@("`@("`@("`@*B!W92!W:6QL(&IU<W0@8F4@;&5F="!W
M:71H('-H;W)T97(@<F]W<R!T:&%N(&5X<&5C=&5D"B`@("`@("`@("`@("`@
M("`@("`@("`@("`J(&EF(&UU;'1I8GET92!C:&%R86-T97)S(&5X:7-T(&EN
M('1H92!R;W<I+@H@("`@("`@("`@("`@("`@("`@("`@("`@*@H@("`@("`@
M("`@("`@("`@("`@("`@("`@*B!!;&=O<FET:&EM.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@*B`Q+B!4<GD@=&\@9FEN9"!A('-T<FEN9R!A<R!L;VYG
M(&%S(%]O<'1L96YG=&@N"B`@("`@("`@("`@("`@("`@("`@("`@("`J(#(N
M(%1R>2!T;R!F:6YD(&$@<W1R:6YG(&%S(&QO;F<@87,@7VUA>&QE;F=T:"X*
M("`@("`@("`@("`@("`@("`@("`@("`@("H@,RX@5&%K92!T:&4@9FER<W0@
M=V]R9"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1M
M6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&U;,5T@/2`D
M;5LR73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M6S)=(#T@)R<[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=71;72`](&%R<F%Y*"=T97AT)R`]/B`D;5LQ
M72`N("<@)R`N("@H)&1E;'-P*2`_("<@)R`Z("<G*2P@)VQE=F5L)R`]/B`D
M;G5M7W%U;W1E<RD["B`@("`@("`@("`@("`@("`@("`@("`@("1L:6YE(#T@
M)&U;,ET["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+RH@3VYE(&5X8V5S<VEV96QY(&QO;F<@=V]R9"!L
M969T(&]N(&QI;F4N("!"90H@("`@("`@("`@("`@("`@("`@("`@("`@*B!A
M8G-O;'5T96QY('-U<F4@:70@9&]E<R!N;W0@97AC965D(#DY."!C:&%R86-T
M97)S"B`@("`@("`@("`@("`@("`@("`@("`@("`J(&EN(&QE;F=T:"!O<B!E
M;'-E('=E(&UU<W0@=')U;F-A=&4N("HO"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D;&EN95]L96YG=&@@/B`Y.3@I('L@"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U=%M=(#T@87)R87DH)W1E>'0G
M(#T^(%-T<FEN9SHZ<W5B<W1R*"1L:6YE+"`P+"`Y.3@L("1T:&ES+3Y?8VAA
M<G-E="DL("=L979E;"<@/3X@)&YU;5]Q=6]T97,I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&QI;F4@/2!3=')I;F<Z.G-U8G-T<B@D;&EN92P@
M.3DX+"!N=6QL+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O=71P=71;72`](&%R<F%Y*"=T97AT)R`]/B`D;&EN92P@)VQE
M=F5L)R`]/B`D;G5M7W%U;W1E<RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T@=VAI;&4@*"%E;7!T>2@D=&5X="DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(&QE861I;F<@)SXG
M(&-H87)A8W1E<G,@:6X@=&AE('1E>'0@:6YP=70N"B`@("`@*B`G/B<@8VAA
M<F%C=&5R<R!A<F4@9&5F:6YE9"!B>2!21D,@,C8T-B!T;R!I;F1I8V%T92!A
M('%U;W1E9"!L:6YE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O
M(&%N86QY>F4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@
M;G5M8F5R(&]F(&QE861I;F<@<75O=&4@8VAA<F%C=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VYU;7%U;W1E<R@D=&5X="D*("`@('L*("`@("`@("!R
M971U<FX@<W1R<W!N*"1T97AT+"`G/B<I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4W!A8V4M<W1U9F9S(&EF(&ET('-T87)T<R!W:71H("<@)R!O<B`G/B<@
M;W(@)T9R;VT@)RP@;W(@:68*("`@("`J('%U;W1E(&1E<'1H(&ES(&YO;BUZ
M97)O("AF;W(@865S=&AE=&EC(')E87-O;G,@<V\@=&AA="!T:&5R92!I<R!A
M"B`@("`@*B!S<&%C92!A9G1E<B!T:&4@)SXG*2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("`@("`@("!4:&4@=&5X="!T;R!S='5F9BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YU;5]Q=6]T97,@(%1H92!Q=6]T92UL979E;"!O9B!T:&ES(&QI
M;F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=&]F;&]W960@("!!<F4@=V4@
M8V]N=F5R=&EN9R!T;R!F;&]W960@=&5X=#\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('-T=69F960@=&5X="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W-T=69F*"1T97AT+"`D;G5M7W%U;W1E<RP@)'1O9FQO=V5D*0H@
M("`@>PH@("`@("`@(&EF("@D=&]F;&]W960@)B8*("`@("`@("`@("`@*"1N
M=6U?<75O=&5S('Q\('!R96=?;6%T8V@H(B]>*#\Z('P^?$9R;VT@?$9R;VTD
M*2\B+"`D=&5X="DI*2!["B`@("`@("`@("`@(')E='5R;B`G("<@+B`D=&5X
M=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@56YS='5F9G,@82!S<&%C92!S='5F9F5D(&QI;F4N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@=6YS='5F9BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N<W1U9F9E9"!T97AT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?=6YS='5F9B@D=&5X="D*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1T97AT*2`F)B`H)'1E>'1[,'T@/3T@)R`G*2D@
M>PH@("`@("`@("`@("`D=&5X="`]('-U8G-T<B@D=&5X="P@,2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"GT*````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T1I9F8S+G!H<```````````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34R-C(`,3`U,34T
M,S$P-C``,#$W-34P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U1E>'0O1&EF9BYP:'`G
M.PH*+RHJ"B`J($$@8VQA<W,@9F]R(&-O;7!U=&EN9R!T:')E92!W87D@9&EF
M9G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1&EF9B]$:69F,RYP
M:'`L=B`Q+C(N,3`N,R`R,#`U+S$P+S$X(#$Q.C`Q.C,Q(&IA;B!%>'`@)`H@
M*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@
M5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("HO"F-L87-S(%1E
M>'1?1&EF9C,@97AT96YD<R!497AT7T1I9F8@>PH*("`@("\J*@H@("`@("H@
M0V]N9FQI8W0@8V]U;G1E<BX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1?8V]N9FQI8W1I;F=";&]C:W,@/2`P.PH*("`@
M("\J*@H@("`@("H@0V]M<'5T97,@9&EF9B!B971W965N(#,@<V5Q=65N8V5S
M(&]F('-T<FEN9W,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1O<FEG
M("`@(%1H92!O<FEG:6YA;"!L:6YE<R!T;R!U<V4N"B`@("`@*B!`<&%R86T@
M87)R87D@)&9I;F%L,2`@5&AE(&9I<G-T('9E<G-I;VX@=&\@8V]M<&%R92!T
M;RX*("`@("`J($!P87)A;2!A<G)A>2`D9FEN86PR("!4:&4@<V5C;VYD('9E
M<G-I;VX@=&\@8V]M<&%R92!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X
M=%]$:69F,R@D;W)I9RP@)&9I;F%L,2P@)&9I;F%L,BD*("`@('L*("`@("`@
M("!I9B`H97AT96YS:6]N7VQO861E9"@G>&1I9F8G*2D@>PH@("`@("`@("`@
M("`D96YG:6YE(#T@)FYE=R!497AT7T1I9F9?16YG:6YE7WAD:69F*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5N9VEN92`]("9N97<@5&5X
M=%]$:69F7T5N9VEN95]N871I=F4H*3L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?961I=',@/2`D=&AI<RT^7V1I9F8S*"1E;F=I;F4M/F1I9F8H)&]R
M:6<L("1F:6YA;#$I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E;F=I;F4M/F1I9F8H)&]R:6<L("1F:6YA;#(I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!M97)G961/=71P=70H)&QA8F5L,2`](&9A;'-E+"`D
M;&%B96PR(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&QI;F5S(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5D:71S(&%S("1E9&ET*2![
M"B`@("`@("`@("`@(&EF("@D961I="T^:7-#;VYF;&EC="@I*2!["B`@("`@
M("`@("`@("`@("`O*B!&25A-13H@=&AI<R!S:&]U;&0@<')O8F%B;'D@8F4@
M;6]V960@<V]M97=H97)E(&5L<V4N("HO"B`@("`@("`@("`@("`@("`D;&EN
M97,@/2!A<G)A>5]M97)G92@D;&EN97,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G/#P\/#P\/"<@+B`H)&QA8F5L,2`_
M("<@)R`N("1L86)E;#$@.B`G)RDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5D:70M/F9I;F%L,2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"(]/3T]/3T](BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D961I="T^9FEN86PR
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)SX^/CX^/CXG("X@*"1L86)E;#(@/R`G("<@+B`D;&%B96PR(#H@)R<I*2D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;F9L:6-T:6YG0FQO8VMS*RL[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;&EN97,@
M/2!A<G)A>5]M97)G92@D;&EN97,L("1E9&ET+3YM97)G960H*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&EN97,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V1I9F8S*"1E9&ET<S$L("1E9&ET<S(I"B`@("!["B`@
M("`@("`@)&5D:71S(#T@87)R87DH*3L*("`@("`@("`D8F(@/2`F;F5W(%1E
M>'1?1&EF9C-?0FQO8VM"=6EL9&5R*"D["@H@("`@("`@("1E,2`](&-U<G)E
M;G0H)&5D:71S,2D["B`@("`@("`@)&4R(#T@8W5R<F5N="@D961I=',R*3L*
M("`@("`@("!W:&EL92`H)&4Q('Q\("1E,BD@>PH@("`@("`@("`@("!I9B`H
M)&4Q("8F("1E,B`F)B!I<U]A*"1E,2P@)U1E>'1?1&EF9E]/<%]C;W!Y)RD@
M)B8@:7-?82@D93(L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@
M("`@("`@("`O*B!792!H879E(&-O<'D@8FQO8VMS(&9R;VT@8F]T:"!D:69F
M<RX@5&AI<R!I<R!T:&4@*&]N;'DI"B`@("`@("`@("`@("`@("`@*B!T:6UE
M('=E('=A;G0@=&\@96UI="!A(&1I9F8S(&-O<'D@8FQO8VLN("!&;'5S:"!C
M=7)R96YT"B`@("`@("`@("`@("`@("`@*B!D:69F,R!D:69F(&)L;V-K+"!I
M9B!A;GDN("HO"B`@("`@("`@("`@("`@("!I9B`H)&5D:70@/2`D8F(M/F9I
M;FES:"@I*2!["B`@("`@("`@("`@("`@("`@("`@)&5D:71S6UT@/2`D961I
M=#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D;F-O<'D@
M/2!M:6XH)&4Q+3YN;W)I9R@I+"`D93(M/FYO<FEG*"DI.PH@("`@("`@("`@
M("`@("`@87-S97)T*"1N8V]P>2`^(#`I.PH@("`@("`@("`@("`@("`@)&5D
M:71S6UT@/2`F;F5W(%1E>'1?1&EF9C-?3W!?8V]P>2AA<G)A>5]S;&EC92@D
M93$M/F]R:6<L(#`L("1N8V]P>2DI.PH*("`@("`@("`@("`@("`@(&EF("@D
M93$M/FYO<FEG*"D@/B`D;F-O<'DI('L*("`@("`@("`@("`@("`@("`@("!A
M<G)A>5]S<&QI8V4H)&4Q+3YO<FEG+"`P+"`D;F-O<'DI.PH@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7W-P;&EC92@D93$M/F9I;F%L+"`P+"`D;F-O<'DI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D93$@/2!N97AT*"1E9&ET<S$I.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(&EF("@D93(M/FYO<FEG*"D@/B`D;F-O<'DI('L*("`@
M("`@("`@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)&4R+3YO<FEG+"`P+"`D
M;F-O<'DI.PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D93(M
M/F9I;F%L+"`P+"`D;F-O<'DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D93(@/2!N97AT*"1E9&ET<S(I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@:68@*"1E,2`F)B`D93(I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&4Q+3YO<FEG("8F("1E,BT^;W)I9RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;F]R:6<@/2!M:6XH)&4Q+3YN;W)I9R@I+"`D93(M/FYO<FEG
M*"DI.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W)I9R`](&%R<F%Y7W-P
M;&EC92@D93$M/F]R:6<L(#`L("1N;W)I9RD["B`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y7W-P;&EC92@D93(M/F]R:6<L(#`L("1N;W)I9RD["B`@
M("`@("`@("`@("`@("`@("`@("`@("1B8BT^:6YP=70H)&]R:6<I.PH@("`@
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)&4Q+"`G5&5X=%]$:69F7T]P7V-O<'DG*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8F(M/F]U=#$H87)R87E?<W!L:6-E*"1E,2T^9FEN86PL
M(#`L("1N;W)I9RDI.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES7V$H)&4R+"`G5&5X=%]$:69F7T]P7V-O<'DG
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8F(M/F]U=#(H87)R87E?
M<W!L:6-E*"1E,BT^9FEN86PL(#`L("1N;W)I9RDI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I
M9B`H)&4Q("8F("$@)&4Q+3YO<FEG*2!["B`@("`@("`@("`@("`@("`@("`@
M)&)B+3YO=70Q*"1E,2T^9FEN86PI.PH@("`@("`@("`@("`@("`@("`@("1E
M,2`](&YE>'0H)&5D:71S,2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H)&4R("8F("$@)&4R+3YO<FEG*2!["B`@("`@("`@("`@
M("`@("`@("`@)&)B+3YO=70R*"1E,BT^9FEN86PI.PH@("`@("`@("`@("`@
M("`@("`@("1E,B`](&YE>'0H)&5D:71S,BD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D961I="`]
M("1B8BT^9FEN:7-H*"DI('L*("`@("`@("`@("`@)&5D:71S6UT@/2`D961I
M=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D961I=',["B`@("!]"@I]
M"@HO*BH*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F
M<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J"B`J($!A
M8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F,U]/<"!["@H@("`@
M9G5N8W1I;VX@5&5X=%]$:69F,U]/<"@D;W)I9R`](&9A;'-E+"`D9FEN86PQ
M(#T@9F%L<V4L("1F:6YA;#(@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI
M<RT^;W)I9R`]("1O<FEG(#\@)&]R:6<@.B!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3YF:6YA;#$@/2`D9FEN86PQ(#\@)&9I;F%L,2`Z(&%R<F%Y*"D["B`@
M("`@("`@)'1H:7,M/F9I;F%L,B`]("1F:6YA;#(@/R`D9FEN86PR(#H@87)R
M87DH*3L*("`@('T*"B`@("!F=6YC=&EO;B!M97)G960H*0H@("`@>PH@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]M97)G960I*2!["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^9FEN86PQ(#T]/2`D=&AI<RT^9FEN86PR*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUE<F=E9"`]("8D=&AI<RT^9FEN86PQ.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/F9I;F%L,2`]/3T@)'1H:7,M
M/F]R:6<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;65R9V5D(#T@)B1T
M:&ES+3YF:6YA;#(["B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^9FEN
M86PR(#T]/2`D=&AI<RT^;W)I9RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M97)G960@/2`F)'1H:7,M/F9I;F%L,3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;65R9V5D(#T@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7VUE<F=E9#L*("`@('T*"B`@("!F=6YC=&EO;B!I<T-O;F9L:6-T*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FUE<F=E9"@I(#T]/2!F86QS93L*
M("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO
M<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*
M("H*("H@0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F8S7T]P
M7V-O<'D@97AT96YD<R!497AT7T1I9F8S7T]P('L*"B`@("!F=6YC=&EO;B!4
M97AT7T1I9F8S7T]P7T-O<'DH)&QI;F5S(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@)'1H:7,M/F]R:6<@/2`D;&EN97,@/R`D;&EN97,@.B!A<G)A>2@I.PH@
M("`@("`@("1T:&ES+3YF:6YA;#$@/2`F)'1H:7,M/F]R:6<["B`@("`@("`@
M)'1H:7,M/F9I;F%L,B`]("8D=&AI<RT^;W)I9SL*("`@('T*"B`@("!F=6YC
M=&EO;B!M97)G960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;W)I
M9SL*("`@('T*"B`@("!F=6YC=&EO;B!I<T-O;F9L:6-T*"D*("`@('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@
M5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A
M:7)I:VE`9&%I<FEK:2YO<F<^"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*
M8VQA<W,@5&5X=%]$:69F,U]";&]C:T)U:6QD97(@>PH*("`@(&9U;F-T:6]N
M(%1E>'1?1&EF9C-?0FQO8VM"=6EL9&5R*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7VEN:70H*3L*("`@('T*"B`@("!F=6YC=&EO;B!I;G!U="@D;&EN97,I
M"B`@("!["B`@("`@("`@:68@*"1L:6YE<RD@>PH@("`@("`@("`@("`D=&AI
M<RT^7V%P<&5N9"@D=&AI<RT^;W)I9RP@)&QI;F5S*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@;W5T,2@D;&EN97,I"B`@("!["B`@("`@("`@
M:68@*"1L:6YE<RD@>PH@("`@("`@("`@("`D=&AI<RT^7V%P<&5N9"@D=&AI
M<RT^9FEN86PQ+"`D;&EN97,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!O=70R*"1L:6YE<RD*("`@('L*("`@("`@("!I9B`H)&QI;F5S*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?87!P96YD*"1T:&ES+3YF:6YA;#(L("1L
M:6YE<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&ES16UP='DH
M*0H@("`@>PH@("`@("`@(')E='5R;B`A)'1H:7,M/F]R:6<@)B8@(21T:&ES
M+3YF:6YA;#$@)B8@(21T:&ES+3YF:6YA;#(["B`@("!]"@H@("`@9G5N8W1I
M;VX@9FEN:7-H*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FES16UP='DH
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&5D:70@/2`F;F5W(%1E>'1?1&EF9C-?3W`H)'1H
M:7,M/F]R:6<L("1T:&ES+3YF:6YA;#$L("1T:&ES+3YF:6YA;#(I.PH@("`@
M("`@("`@("`D=&AI<RT^7VEN:70H*3L*("`@("`@("`@("`@<F5T=7)N("1E
M9&ET.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?:6YI="@I"B`@
M("!["B`@("`@("`@)'1H:7,M/F]R:6<@/2`D=&AI<RT^9FEN86PQ(#T@)'1H
M:7,M/F9I;F%L,B`](&%R<F%Y*"D["B`@("!]"@H@("`@9G5N8W1I;VX@7V%P
M<&5N9"@F)&%R<F%Y+"`D;&EN97,I"B`@("!["B`@("`@("`@87)R87E?<W!L
M:6-E*"1A<G)A>2P@<VEZ96]F*"1A<G)A>2DL(#`L("1L:6YE<RD["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]497AT+W)E4U0N<&AP````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#<Q-S(`,3`U,34T,S$P-C``,#$W-#<S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@5&5X=%]R95-4.CH@8VQA<W,@<F5P<F5S96YT<R!A('!A
M<G-E(&YO9&4@;V8@82!R95-T<G5C='5R961497AT"B`J(&1O8W5M96YT(&%N
M9"!P<F]V:61E<R!A;B!!4$D@9F]R('!A<G-I;F<@<F53=')U8W1U<F5D5&5X
M="!D;V-U;65N=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?<F53
M5"]R95-4+G!H<"QV(#$N-2XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%S;VX@32X@1F5L
M:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC
M;VT^"B`J($!P86-K86=E(%1E>'1?<F535`H@*B\*8VQA<W,@5&5X=%]R95-4
M('L*"B`@("`O*BH*("`@("`J(%1H92!P87)S92!N;V1E('1Y<&4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]T>7!E.PH*("`@("\J*@H@("`@("H@06X@87)R
M87D@;V8@=&AE('!A<G-E(&YO9&4G<R!C:&EL9')E;BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V-H:6QD<F5N(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($$@:&%S:"!O9B!P87)S92!N;V1E('!R;W!E<G1I97,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W!R;W!E<G1I97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M='EP92`@5&AI<R!I<R!T:&4@;F]D92!T>7!E+B`@5&AE(&1E9F%U;'0@:7,@
M)T1O8W5M96YT)RX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]R95-4*"1T
M>7!E(#T@)T1O8W5M96YT)RD*("`@('L*("`@("`@("`D=&AI<RT^7W1Y<&4@
M/2`D='EP93L*("`@('T*"B`@("`O*BH*("`@("`J($%P<&5N9',@82!C:&EL
M9"!P87)S92!N;V1E('1O('1H:7,@<&%R<V4@;F]D92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG?%1E>'1?<F535"`F)&-H:6QD("!4:&ES(&ES('1H
M92!S=')I;F<@;W(@;V)J96-T(&-H:6QD"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T;R!A<'!E;F0@=&\@=&AI<R!P87)S92!N
M;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!E;F1#:&EL9"@F)&-H:6QD
M*0H@("`@>PH@("`@("`@("1N(#T@8V]U;G0H)'1H:7,M/E]C:&EL9')E;BD[
M"B`@("`@("`@:68@*&ES7W-T<FEN9R@D8VAI;&0I("8F("1N(#X@,"`F)B!I
M<U]S=')I;F<H)'1H:7,M/E]C:&EL9')E;ELD;B`M(#%=*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V-H:6QD<F5N6R1N("T@,5T@+CT@)&-H:6QD.PH@("`@
M("`@('T@96QS96EF("AI<U]S=')I;F<H)&-H:6QD*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-H:6QD<F5N6UT@/2`D8VAI;&0["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/E]C:&EL9')E;EM=(#T@)B1C:&EL9#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!V86QU
M92!O9B!A('!A<G-E(&YO9&4@<')O<&5R='DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@(%1H92!P<F]P97)T>2=S(&YA;64N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('!R;W!E<G1Y)W,@=F%L=64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%!R;W!E<G1Y*"1N86UE+"`D=F%L
M=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]P<F]P97)T:65S6R1N86UE72`]
M("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@
M=F%L=64@;V8@82!P87)S92!N;V1E('!R;W!E<G1Y+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!P<F]P97)T>2=S(&YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P<F]P97)T>2=S('9A
M;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<F]P97)T>2@D;F%M92D*
M("`@('L*("`@("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&YA;64L("1T
M:&ES+3Y?<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!R;W!E<G1I97-;
M)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@1'5M<',@=&AI<R!P87)S
M92!N;V1E(&%N9"!I=',@8VAI;&1R96XN"B`@("`@*B!4:&ES(&UE=&AO9"!I
M<R!F;W(@9&5B=6=G:6YG('!U<G!O<V5S+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1L979E;"`@5&AI<R!I<R!T:&4@:6YD96YT(&QE=F5L(&]F
M('1H:7,@<&%R<V4@;F]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@9'5M<"@D
M;&5V96P@/2`P*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L
M979E;#L@)&DK*RD@>PH@("`@("`@("`@("!E8VAO("<@("<["B`@("`@("`@
M?0H@("`@("`@(&5C:&\@)'1H:7,M/E]T>7!E+"`G.CHG.PH@("`@("`@(&MS
M;W)T*"1T:&ES+3Y?<')O<&5R=&EE<RD["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]P<F]P97)T:65S(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@
M("`@("!E8VAO("<@)RP@)&YA;64L("<](B<L('!R96=?<F5P;&%C92@G+ULB
M7%Q<7%TO)RP@)UQ<)#$G+"`D=F%L=64I+`H@("`@("`@("`@("`@("`@)R(G
M.PH@("`@("`@('T*("`@("`@("!E8VAO(")<;B(["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D8VAI;&0I('L*("`@("`@("`@("`@
M:68@*&ES7W-T<FEN9R@D8VAI;&0I*2!["B`@("`@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`H)&QE=F5L("L@,2D[("1I*RLI('L*("`@("`@("`@
M("`@("`@("`@("!E8VAO("<@("<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E8VAO("<B)RP@<')E9U]R97!L86-E*"<O6R)<7%Q<72\G
M+"`G7%PD,2<L("1C:&EL9"DL(")<(EQN(CL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1C:&EL9"T^9'5M<"@D;&5V96P@*R`Q*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%!A<G-E<R!A(')E4W1R=6-T=7)E9%1E>'0@9&]C=6UE;G0N"B`@("`@*@H@
M("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@(%1H:7,@:7,@=&AE('1E>'0@;V8@=&AE(&1O8W5M96YT('=E('=A;G0@
M=&\@<&%R<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!497AT7W)E4U0@(%1H
M92!P87)S960@9&]C=6UE;G0@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<&%R<V4H)'1E>'0I"B`@("!["B`@("`@
M("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]R95-4+U!A
M<G-E<BYP:'`G.PH@("`@("`@("1P87)S97(@/2`F;F5W(%1E>'1?<F535%]0
M87)S97(H*3L*("`@("`@("!R971U<FX@)'!A<G-E<BT^<&%R<V4H)'1E>'0I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO````````````````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C``,#$U-C$U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-
M3"]70EA-3"\`````````````````````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,38U,#8`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T141"\`````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q
M-S$R,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO5T)834PO1%1$
M+U-Y;F--3$1E=DEN9BYP:'``````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4W
M-#``,3`U,34T,S$P-C``,#(R,#<V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)UA-3"]7
M0EA-3"]$5$0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?
M5T)834PO5T)834PO1%1$+U-Y;F--3$1E=DEN9BYP:'`L=B`Q+C0N,3(N-2`R
M,#`V+S`S+S$Q(#`Y.C4U.C(S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^
M"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I
M8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY(#(P,#$*("H@9F]U;F0@870@
M:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3%]$5$1?4WEN
M8TU,1&5V26YF(&5X=&5N9',@6$U,7U="6$U,7T141"!["@H@("`@9G5N8W1I
M;VX@:6YI="@I"B`@("!["B`@("`@("`@+RH@=&AI<R!C;V1E('1A8FQE(&AA
M<R!B965N(&5X=')A8W1E9"!F<F]M(&QI8G=B>&UL"B`@("`@("`@("H@*'-E
M92!H='1P.B\O;&EB=V)X;6PN87EM97)I8VLN8V]M+RD@8GD@=7-I;F<*("`@
M("`@("`@*@H@("`@("`@("`J(&=R97`@)UPB6UY<(ETJ7"(L("HP>"XN+"`P
M>"XN('TL)R!W8GAM;%]T86)L97,N8PH@("`@("`@("`J('P@<V5D("UE("=S
M(UXN*EPB7"A;7EPB72I<*5PB+"`J7"@P>"XN7"DL(%PH,'@N+EPI('TL+BHD
M(R`@("`@("`@7"1T:&ES+3YS971486=<*%PS+"!<(EPQ7")<*3L@+R\@7#(C
M9R<*("`@("`@("`@*B\*"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`U+"`B
M0U1#87`B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P-BP@
M(D-45'EP92(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`W
M+"`B1&%T85-T;W)E(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,#@L(")$871A5'EP92(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#`Y+"`B1&5V240B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS
M971486<H,'@P82P@(D1E=DEN9B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#!B+"`B1&5V5'EP(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,&,L(")$:7-P;&%Y3F%M92(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#!D+"`B1%--96TB*3L@+R\@,'@P,`H@("`@
M("`@("1T:&ES+3YS971486<H,'@P92P@(D5X="(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#!F+"`B1G=6(BD[("\O(#!X,#`*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,3`L(")(=U8B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@Q,2P@(DUA;B(I.R`O+R`P>#`P"B`@("`@("`@
M)'1H:7,M/G-E=%1A9R@P>#$R+"`B36%X1U5)1%-I>F4B*3L@+R\@,'@P,`H@
M("`@("`@("1T:&ES+3YS971486<H,'@Q,RP@(DUA>$E$(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,30L(")-87A-96TB*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q-2P@(DUO9"(I.R`O+R`P>#`P
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$V+"`B3T5-(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3<L(")087)A;4YA;64B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q."P@(E!R;W!.86UE(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3DL(")2>"(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%A+"`B4G@M4')E9B(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%B+"`B4VAA<F5D
M365M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,6,L(")3
M:7IE(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,60L(")3
M;W5R8V52968B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q
M92P@(E-W5B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%F
M+"`B4WEN8T-A<"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#(P+"`B4WEN8U1Y<&4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@R,2P@(E1X(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,C(L(")4>"U0<F5F(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,C,L(")686Q%;G5M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,C0L(")697)#5"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#(U+"`B5F5R1%1$(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,C8L(")83F%M(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,C<L(")85F%L(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,C@L(")55$,B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@R.2P@(E-U<'!O<G1.=6UB97)/9D-H86YG97,B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R82P@(E-U<'!O<G1,87)G
M94]B:G,B*3L@+R\@,'@P,`H*("`@("`@("!I9B`H)'1H:7,M/G9E<G-I;VX@
M/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO
M+U-93D--3"\O1%1$($1E=DEN9B`Q+C`O+T5.)RP@)W-Y;F-M;#ID979I;F8Q
M+C`G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%5222@G<WEN8VUL.F1E=FEN
M9C$N,"<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS
M971#;V1E4&%G92@P+"`G+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,2\O14XG
M+"`G<WEN8VUL.F1E=FEN9C$N,2<I.PH@("`@("`@("`@("`D=&AI<RT^<V5T
M55))*"=S>6YC;6PZ9&5V:6YF,2XQ)RD["B`@("`@("`@?0H@("`@?0H*?0H`
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O4WEN8TU,365T26YF+G!H
M<``````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#0R,P`Q,#4Q-30S,3`V,``P
M,C(Q,#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"FEN8VQU9&5?;VYC92`G6$U,+U="6$U,+T141"YP:'`G.PH*
M+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+UA-3%]70EA-3"]70EA-3"]$5$0O
M4WEN8TU,365T26YF+G!H<"QV(#$N-"XQ,BXU(#(P,#8O,#,O,3$@,#DZ-34Z
M,S,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N
M>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@1G)O;2!":6YA
M<GD@6$U,($-O;G1E;G0@1F]R;6%T(%-P96-I9FEC871I;VX@5F5R<VEO;B`Q
M+C,L(#(U($IU;'D@,C`P,0H@*B!F;W5N9"!A="!H='1P.B\O=W=W+G=A<&9O
M<G5M+F]R9PH@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!P86-K86=E(%A-3%]70EA-
M3`H@*B\*8VQA<W,@6$U,7U="6$U,7T141%]3>6YC34Q-971);F8@97AT96YD
M<R!834Q?5T)834Q?1%1$('L*"B`@("!F=6YC=&EO;B!I;FET*"D*("`@('L*
M("`@("`@("`O*B!T:&ES(&-O9&4@=&%B;&4@:&%S(&)E96X@97AT<F%C=&5D
M(&9R;VT@;&EB=V)X;6P*("`@("`@("`@*B`H<V5E(&AT='`Z+R]L:6)W8GAM
M;"YA>6UE<FEC:RYC;VTO*2!B>2!U<VEN9PH@("`@("`@("`J"B`@("`@("`@
M("H@9W)E<"`G7");7EPB72I<(BP@*C!X+BXL(#!X+BX@?2PG('=B>&UL7W1A
M8FQE<RYC"B`@("`@("`@("H@?"!S960@+64@)W,C7BXJ7")<*%M>7")=*EPI
M7"(L("I<*#!X+BY<*2P@7"@P>"XN7"D@?2PN*B0C("`@("`@("!<)'1H:7,M
M/G-E=%1A9UPH7#,L(%PB7#%<(EPI.R`O+R!<,B-G)PH@("`@("`@("`J+PH*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#4L(")!;F-H;W(B*3L@+R\@,'@P
M,0H@("`@("`@("1T:&ES+3YS971486<H,'@P-BP@(D5-22(I.R`O+R`P>#`Q
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`W+"`B1F]R;6%T(BD[("\O(#!X
M,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#@L(")&<F5E240B*3L@+R\@
M,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@P.2P@(D9R965-96TB*3L@
M+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@P82P@(DQA<W0B*3L@
M+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@P8BP@(DUA<FLB*3L@
M+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@P8RP@(DUA>$US9U-I
M>F4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q-2P@(DUA
M>$]B:E-I>F4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@P
M9"P@(DUE;2(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!E
M+"`B365T26YF(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,&8L(").97AT(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,3`L(").97AT3F]N8V4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS9714
M86<H,'@Q,2P@(E-H87)E9$UE;2(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#$R+"`B4VEZ92(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#$S+"`B5'EP92(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#$T+"`B5F5R<VEO;B(I.R`O+R`P>#`Q"@H@("`@("`@(&EF
M("@D=&AI<RT^=F5R<VEO;B`]/2`P*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971#;V1E4&%G92@P+"`G+2\O4UE.0TU,+R]$5$0@4WEN8TU,(#$N,"\O14XG
M+"`G<WEN8VUL.G-Y;F-M;#$N,"<I.PH@("`@("`@("`@("`D=&AI<RT^<V5T
M0V]D95!A9V4H,2P@)RTO+U-93D--3"\O1%1$($UE=$EN9B`Q+C`O+T5.)RP@
M)W-Y;F-M;#IM971I;F8Q+C`G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%52
M22@G<WEN8VUL.FUE=&EN9C$N,"<I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3YS971#;V1E4&%G92@P+"`G+2\O4UE.0TU,+R]$5$0@
M4WEN8TU,(#$N,2\O14XG+"`G<WEN8VUL.G-Y;F-M;#$N,2<I.PH@("`@("`@
M("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,2P@)RTO+U-93D--3"\O1%1$($UE
M=$EN9B`Q+C$O+T5.)RP@)W-Y;F-M;#IM971I;F8Q+C$G*3L*("`@("`@("`@
M("`@)'1H:7,M/G-E=%5222@G<WEN8VUL.FUE=&EN9C$N,2<I.PH@("`@("`@
M("`@("`O+R1T:&ES+3YS97154DDH)W-Y;F-M;#IM971I;F8G*3L@+R\@9F]R
M('-O;64@9G5N;GD@<F5A<V]N+"!L:6)W8GAM;"!P<F]D=6-E<R!N;R`Z;65T
M:6YF,2XQ(&AE<F4*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O4WEN
M8TU,+G!H<```````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S$S,P`Q
M,#4Q-30S,3`V,``P,C$P,#``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G6$U,+U="6$U,
M+T141"YP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+UA-3%]70EA-
M3"]70EA-3"]$5$0O4WEN8TU,+G!H<"QV(#$N-BXQ,BXU(#(P,#8O,#,O,3$@
M,#DZ-34Z,3(@:F%N($5X<"`D"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT
M96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY
M(#(P,#$*("H@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`
M<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!P86-K86=E(%A-
M3%]70EA-3`H@*B\*8VQA<W,@6$U,7U="6$U,7T141%]3>6YC34P@97AT96YD
M<R!834Q?5T)834Q?1%1$('L*"B`@("!F=6YC=&EO;B!I;FET*"D*("`@('L*
M("`@("`@("`O*B!T:&ES(&-O9&4@=&%B;&4@:&%S(&)E96X@97AT<F%C=&5D
M(&9R;VT@;&EB=V)X;6P*("`@("`@("`@*B`H<V5E(&AT='`Z+R]L:6)W8GAM
M;"YA>6UE<FEC:RYC;VTO*2!B>2!U<VEN9PH@("`@("`@("`J"B`@("`@("`@
M("H@9W)E<"`G7");7EPB72I<(BP@*C!X+BXL(#!X+BX@?2PG('=B>&UL7W1A
M8FQE<RYC"B`@("`@("`@("H@?"!S960@+64@)W,C7BXJ7")<*%M>7")=*EPI
M7"(L("I<*#!X+BY<*2P@7"@P>"XN7"D@?2PN*B0C("`@("`@("!<)'1H:7,M
M/G-E=%1A9UPH7#,L(%PB7#%<(EPI.R`O+R!<,B-G)PH@("`@("`@("`J+PH*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#4L(")!9&0B*3L@+R\@,'@P,`H@
M("`@("`@("1T:&ES+3YS971486<H,'@P-BP@(D%L97)T(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#<L(")!<F-H:79E(BD[("\O(#!X
M,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#@L(")!=&]M:6,B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P.2P@(D-H86PB*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P82P@(D-M9"(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!B+"`B0VUD240B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P8RP@(D-M9%)E9B(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!D+"`B0V]P>2(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!E+"`B0W)E9"(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!F+"`B1&%T82(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$P+"`B1&5L971E(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3$L(")%>&5C(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3(L(")&:6YA;"(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$S+"`B1V5T(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,30L("))=&5M(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,34L("),86YG(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,38L("),;V-.86UE
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3<L("),;V-5
M4DDB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q."P@(DUA
M<"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$Y+"`B36%P
M271E;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%A+"`B
M365T82(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%B+"`B
M37-G240B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q8RP@
M(DUS9U)E9B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%D
M+"`B3F]297-P(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,64L(").;U)E<W5L=',B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@Q9BP@(E!U="(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#(P+"`B4F5P;&%C92(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#(Q+"`B4F5S<%5222(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#(R+"`B4F5S=6QT<R(I.R`O+R`P>#`P"B`@("`@("`@)'1H
M:7,M/G-E=%1A9R@P>#(S+"`B4V5A<F-H(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,C0L(")397%U96YC92(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#(U+"`B4V5S<VEO;DE$(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C8L(")39G1$96PB*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-RP@(E-O=7)C92(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(X+"`B4V]U<F-E4F5F(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,CDL(")3=&%T=7,B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R82P@(E-Y;F,B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R8BP@(E-Y;F-"
M;V1Y(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,F,L(")3
M>6YC2&1R(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,F0L
M(")3>6YC34PB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R
M92P@(E1A<F=E="(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#)F+"`B5&%R9V5T4F5F(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,S`L(")297-E<G9E9"!F;W(@9G5T=7)E('5S92(I.R`O+R`P>#`P
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#,Q+"`B5F5R1%1$(BD[("\O(#!X
M,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,S(L(")697)0<F]T;R(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#,S+"`B3G5M8F5R3V9#
M:&%N9V5D(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,S0L
M(")-;W)E1&%T82(I.R`O+R`P>#`P"@H@("`@("`@(&EF("@D=&AI<RT^=F5R
M<VEO;B`]/2`P*2!["B`@("`@("`@("`@("1T:&ES+3YS971#;V1E4&%G92@P
M+"`G+2\O4UE.0TU,+R]$5$0@4WEN8TU,(#$N,"\O14XG+"`G<WEN8VUL.G-Y
M;F-M;#$N,"<I.PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,2P@
M)RTO+U-93D--3"\O1%1$($UE=$EN9B`Q+C`O+T5.)RP@)W-Y;F-M;#IM971I
M;F8Q+C`G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%5222@G<WEN8VUL.G-Y
M;F-M;#$N,"<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YS971#;V1E4&%G92@P+"`G+2\O4UE.0TU,+R]$5$0@4WEN8TU,(#$N,2\O
M14XG+"`G<WEN8VUL.G-Y;F-M;#$N,2<I.PH@("`@("`@("`@("`D=&AI<RT^
M<V5T0V]D95!A9V4H,2P@)RTO+U-93D--3"\O1%1$($UE=$EN9B`Q+C$O+T5.
M)RP@)W-Y;F-M;#IM971I;F8Q+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E
M=%5222@G<WEN8VUL.G-Y;F-M;#$N,2<I.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+UA-3"]70EA-3"]#;VYT96YT2&%N9&QE<BYP:'``````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-C`W,0`Q,#4Q-30S,3`V,``P,C(Q,S``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@9G)A;65W;W)K+UA-3%]70EA-3"]70EA-3"]#;VYT96YT2&%N
M9&QE<BYP:'`L=B`Q+CDN,3`N-R`R,#`V+S`U+S`Q(#$R.C`U.C$U(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@
M/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@1G)O
M;2!":6YA<GD@6$U,($-O;G1E;G0@1F]R;6%T(%-P96-I9FEC871I;VX@5F5R
M<VEO;B`Q+C,L(#(U($IU;'D@,C`P,0H@*B!F;W5N9"!A="!H='1P.B\O=W=W
M+G=A<&9O<G5M+F]R9PH@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L
M87-S(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE<B!["@H@("`@=F%R("1?8W5R
M<F5N=%5R:3L*("`@('9A<B`D7V]U='!U="`]("<G.PH*("`@('9A<B`D7V]P
M87%U94AA;F1L97(["@H@("`@+RHJ"B`@("`@*B!#:&%R<V5T+@H@("`@("HO
M"B`@("!V87(@)%]C:&%R<V5T(#T@)U541BTX)SL*"B`@("`O*BH*("`@("`J
M(%="6$U,(%9E<G-I;VXN"B`@("`@*B`Q+"`R+"!O<B`S('-U<'!O<G1E9`H@
M("`@("HO"B`@("!V87(@)%]W8GAM;%9E<G-I;VX@/2`R.PH*("`@(&9U;F-T
M:6]N(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE<B@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]C=7)R96YT57)I(#T@)FYE=R!834Q?5T)834Q?3&EF;U%U975E
M*"D["B`@("!]"@H@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D97)R;W(I"B`@
M("!["B`@("`@("`@:6YC;'5D95]O;F-E("=014%2+G!H<"<["B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971#:&%R<V5T4W1R*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]C:&%R<V5T.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-H87)S
M970H)&-S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VAA<G-E="`]("1C<SL*
M("`@('T*"B`@("!F=6YC=&EO;B!G971697)S:6]N*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]W8GAM;%9E<G-I;VX["B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T5F5R<VEO;B@D=BD*("`@('L*("`@("`@("`D=&AI<RT^7W=B
M>&UL5F5R<VEO;B`](#(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T3W5T<'5T
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]O=71P=70["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T3W5T<'5T4VEZ92@I"B`@("!["B`@("`@("`@
M<F5T=7)N('-T<FQE;B@D=&AI<RT^7V]U='!U="D["B`@("!]"@H@("`@9G5N
M8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SPG("X@)&5L96UE;G0[
M"@H@("`@("`@("1C=7)R96YT57)I(#T@)'1H:7,M/E]C=7)R96YT57)I+3YT
M;W`H*3L*"B`@("`@("`@:68@*"@H(21C=7)R96YT57)I*2!\?"`H)&-U<G)E
M;G15<FD@(3T@)'5R:2DI("8F("1U<FDI('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@)R!X;6QN<STB)R`N("1U<FD@+B`G(B<["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7V-U<G)E;G15<FDM/G!U<V@H)'5R:2D["@H@
M("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D871T<BD@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]U='!U="`N/2`G("<@+B`D871T<ELG871T<FEB=71E)UT@
M+B`G/2(G("X@)&%T=');)W9A;'5E)UT@+B`G(B<["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2`G/B<["B`@("!]"@H@("`@9G5N8W1I
M;VX@96YD16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@("`D
M=&AI<RT^7V]U='!U="`N/2`G/"\G("X@)&5L96UE;G0@+B`G/B<["@H@("`@
M("`@("1T:&ES+3Y?8W5R<F5N=%5R:2T^<&]P*"D["B`@("!]"@H@("`@9G5N
M8W1I;VX@8VAA<F%C=&5R<R@D<W1R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;W5T<'5T("X]("1S='(["B`@("!]"@H@("`@9G5N8W1I;VX@;W!A<75E*"1O
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1O.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-E=$]P87%U94AA;F1L97(H)&]P87%U94AA;F1L97(I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]O<&%Q=65(86YD;&5R(#T@)&]P87%U
M94AA;F1L97(["B`@("!]"@H@("`@9G5N8W1I;VX@<F5M;W9E3W!A<75E2&%N
M9&QE<B@I"B`@("!["B`@("`@("`@=6YS970H)'1H:7,M/E]O<&%Q=65(86YD
M;&5R*3L*("`@('T*"B`@("!F=6YC=&EO;B!C<F5A=&53=6)(86YD;&5R*"D*
M("`@('L*("`@("`@("`D;F%M92`](&=E=%]C;&%S<R@D=&AI<RD[("\O(&-L
M;VYE(&-U<G)E;G0@8VQA<W,*("`@("`@("`D<V@@/2`F;F5W("1N86UE*"D[
M"B`@("`@("`@)'-H+3YS971#:&%R<V5T*"1T:&ES+3YG971#:&%R<V5T4W1R
M*"DI.PH@("`@("`@("1S:"T^<V5T5F5R<VEO;B@D=&AI<RT^9V5T5F5R<VEO
M;B@I*3L*("`@("`@("!R971U<FX@)'-H.PH@("`@?0H*?0H*8VQA<W,@6$U,
M7U="6$U,7TQI9F]1=65U92!["@H@("`@=F%R("1?<75E=64@/2!A<G)A>2@I
M.PH*("`@(&9U;F-T:6]N(%A-3%]70EA-3%],:69O475E=64H*0H@("`@>PH@
M("`@?0H*("`@(&9U;F-T:6]N('!U<V@H)&]B:BD*("`@('L*("`@("`@("`D
M=&AI<RT^7W%U975E6UT@/2`D;V)J.PH@("`@?0H*("`@(&9U;F-T:6]N('!O
M<"@I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?<75E=64I*2![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>5]P;W`H)'1H:7,M/E]Q=65U92D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('1O<"@I"B`@("!["B`@("`@
M("`@:68@*"1C;W5N="`](&-O=6YT*"1T:&ES+3Y?<75E=64I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W%U975E6R1C;W5N="`M(#%=.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]834PO5T)834PO1%1$+G!H<```````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#8V-#<`,3`U,34T,S$P-C``,#$W-C0T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO1%1$+G!H<"QV
M(#$N-BXQ,BXU(#(P,#8O,#,O,3$@,#DZ-34Z,#$@:F%N($5X<"`D"B`J"B`J
M($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N
M(%9E<G-I;VX@,2XS+"`R-2!*=6QY(#(P,#$*("H@9F]U;F0@870@:'1T<#HO
M+W=W=RYW87!F;W)U;2YO<F<*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!
M;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!P86-K86=E(%A-3%]70EA-3`H@*B\*8VQA<W,@6$U,7U="
M6$U,7T141"!["@H@("`@=F%R("1V97)S:6]N.PH@("`@=F%R("1I;G1486=S
M.PH@("`@=F%R("1I;G1!='1R:6)U=&5S.PH@("`@=F%R("1S=')486=S.PH@
M("`@=F%R("1S=')!='1R:6)U=&5S.PH@("`@=F%R("1I;G1#;V1E4&%G97,[
M"B`@("!V87(@)'-T<D-O9&5086=E<SL*("`@('9A<B`D<W1R0V]D95!A9V5S
M55)).PH@("`@=F%R("154DD["B`@("!V87(@)%A-3$Y3.PH@("`@=F%R("1$
M4$D["@H@("`@9G5N8W1I;VX@6$U,7U="6$U,7T141"@D=BD*("`@('L*("`@
M("`@("`D=&AI<RT^=F5R<VEO;B`]("1V.PH@("`@("`@("1T:&ES+3YI;FET
M*"D["B`@("!]"@H@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("!]"@H@
M("`@9G5N8W1I;VX@<V5T071T<FEB=71E*"1I;G1!='1R:6)U=&4L("1S=')!
M='1R:6)U=&4I"B`@("!["B`@("`@("`@)'1H:7,M/G-T<D%T=')I8G5T97-;
M)'-T<D%T=')I8G5T95T@/2`D:6YT071T<FEB=71E.PH@("`@("`@("1T:&ES
M+3YI;G1!='1R:6)U=&5S6R1I;G1!='1R:6)U=&5=(#T@)'-T<D%T=')I8G5T
M93L*("`@('T*"B`@("!F=6YC=&EO;B!S971486<H)&EN=%1A9RP@)'-T<E1A
M9RD*("`@('L*("`@("`@("`D=&AI<RT^<W1R5&%G<ULD<W1R5&%G72`]("1I
M;G1486<["B`@("`@("`@)'1H:7,M/FEN=%1A9W-;)&EN=%1A9UT@/2`D<W1R
M5&%G.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-O9&5086=E*"1I;G1#;V1E
M4&%G92P@)'-T<D-O9&5086=E+"`D<W1R0V]D95!A9V554DDI"B`@("!["B`@
M("`@("`@)'1H:7,M/G-T<D-O9&5086=E<U5225LD<W1R0V]D95!A9V554DE=
M(#T@)&EN=$-O9&5086=E.PH@("`@("`@("1T:&ES+3YS=')#;V1E4&%G97-;
M)'-T<D-O9&5086=E72`]("1I;G1#;V1E4&%G93L*("`@("`@("`D=&AI<RT^
M:6YT0V]D95!A9V5S6R1I;G1#;V1E4&%G95T@/2`D<W1R0V]D95!A9V4["B`@
M("!]"@H@("`@9G5N8W1I;VX@=&]486=3='(H)'1A9RD*("`@('L*("`@("`@
M("!R971U<FX@:7-S970H)'1H:7,M/FEN=%1A9W-;)'1A9UTI(#\@)'1H:7,M
M/FEN=%1A9W-;)'1A9UT@.B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!T
M;T%T=')I8G5T95-T<B@D871T<FEB=71E*0H@("`@>PH@("`@("`@(')E='5R
M;B!I<W-E="@D=&AI<RT^:6YT5&%G<ULD871T<FEB=71E72D@/R`D=&AI<RT^
M:6YT5&%G<ULD871T<FEB=71E72`Z(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1O0V]D95!A9V53='(H)&-O9&5086=E*0H@("`@>PH@("`@("`@(')E
M='5R;B!I<W-E="@D=&AI<RT^:6YT0V]D95!A9V5S6R1C;V1E4&%G95TI(#\@
M)'1H:7,M/FEN=$-O9&5086=E<ULD8V]D95!A9V5=(#H@9F%L<V4["B`@("!]
M"@H@("`@9G5N8W1I;VX@=&]486=);G0H)'1A9RD*("`@('L*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/G-T<E1A9W-;)'1A9UTI(#\@)'1H:7,M/G-T
M<E1A9W-;)'1A9UT@.B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!T;T%T
M=')I8G5T94EN="@D871T<FEB=71E*0H@("`@>PH@("`@("`@(')E='5R;B!I
M<W-E="@D=&AI<RT^<W1R071T<FEB=71E<ULD871T<FEB=71E72D@/R`D=&AI
M<RT^<W1R071T<FEB=71E<ULD871T<FEB=71E72`Z(&9A;'-E.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1O0V]D95!A9V5);G0H)&-O9&5086=E*0H@("`@>PH@
M("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^<W1R0V]D95!A9V5S6R1C;V1E
M4&%G95TI(#\@)'1H:7,M/G-T<D-O9&5086=E<ULD8V]D95!A9V5=(#H@9F%L
M<V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]#;V1E4&%G955222@D=7)I*0H@
M("`@>PH@("`@("`@("1U<FD@/2!S=')T;VQO=V5R*"1U<FDI.PH@("`@("`@
M(&EF*"%I<W-E="@D=&AI<RT^<W1R0V]D95!A9V5S55))6R1U<FE=*2D@>PH@
M("`@("`@("`@("!D:64H(G5N86)L92!T;R!F:6YD(&-O9&5P86=E(&9O<B`D
M=7)I(5QN(BD["B`@("`@("`@?0H*("`@("`@("`D<F5T(#T@:7-S970H)'1H
M:7,M/G-T<D-O9&5086=E<U5225LD=7)I72D@/R`D=&AI<RT^<W1R0V]D95!A
M9V5S55))6R1U<FE=(#H@9F%L<V4["@H@("`@("`@(')E='5R;B`D<F5T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T=&5R(&9O<B!P<F]P97)T>2!V97)S
M:6]N+@H@("`@("H@0')E='5R;B!686QU92!O9B!P<F]P97)T>2!V97)S:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971697)S:6]N*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/G9E<G-I;VX["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971T97(@9F]R('!R;W!E<G1Y('9E<G-I;VXN"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=B`@3F5W('9A;'5E(&]F('!R;W!E<G1Y('9E<G-I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%9E<G-I;VXH)'8I"B`@("!["B`@
M("`@("`@)'1H:7,M/G9E<G-I;VX@/2`D=CL*("`@('T*"B`@("`O*BH*("`@
M("`J($=E='1E<B!F;W(@<')O<&5R='D@55))+@H@("`@("H@0')E='5R;B!6
M86QU92!O9B!P<F]P97)T>2!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%5222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y54DD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(%5222X*("`@
M("`J($!P87)A;2!S=')I;F<@)'4@($YE=R!V86QU92!O9B!P<F]P97)T>2!5
M4DDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%5222@D=2D*("`@('L*("`@
M("`@("`D=&AI<RT^55))(#T@)'4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M971T97(@9F]R('!R;W!E<G1Y($1022X*("`@("`J($!R971U<FX@5F%L=64@
M;V8@<')O<&5R='D@1%!)+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$4$DH
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^1%!).PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!$4$DN"B`@("`@*B!`
M<&%R86T@1%!)($YE=R!V86QU92!O9B!P<F]P97)T>2!$4$DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$1022@D9"D*("`@('L*("`@("`@("`D=&AI<RT^
M1%!)(#T@)&0["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O6$U,+U="6$U,+T141$UA;F%G97(N<&AP````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`U,34U`#$P-3$U-#,Q,#8P`#`R,3$S,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*:6YC
M;'5D95]O;F-E("=834PO5T)834PO1%1$+U-Y;F--3"YP:'`G.PII;F-L=61E
M7V]N8V4@)UA-3"]70EA-3"]$5$0O4WEN8TU,365T26YF+G!H<"<["FEN8VQU
M9&5?;VYC92`G6$U,+U="6$U,+T141"]3>6YC34Q$979);F8N<&AP)SL*"B\J
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO1%1$36%N
M86=E<BYP:'`L=B`Q+C,N,3(N,3$@,C`P-B\P-2\P,2`Q,CHP-3HQ-2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS
M(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R
M;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E
M<G-I;VX@,2XS+"`R-2!*=6QY"B`J(#(P,#$@9F]U;F0@870@:'1T<#HO+W=W
M=RYW87!F;W)U;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC
M;&%S<R!834Q?5T)834Q?1%1$36%N86=E<B!["@H@("`@+RHJ"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-T<D141"`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W-T<D141%5222`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%A-3%]70EA-3%]$5$1-86YA9V5R*"D*("`@('L*("`@("`@("`D
M=&AI<RT^<F5G:7-T97)$5$0H)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C`O
M+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ+C`G+"!N97<@6$U,7U="6$U,7T141%]3
M>6YC34PH,"DI.PH@("`@("`@("1T:&ES+3YR96=I<W1E<D141"@G+2\O4UE.
M0TU,+R]$5$0@4WEN8TU,(#$N,2\O14XG+"`G<WEN8VUL.G-Y;F-M;#$N,2<L
M(&YE=R!834Q?5T)834Q?1%1$7U-Y;F--3"@Q*2D["@H@("`@("`@("1T:&ES
M+3YR96=I<W1E<D141"@G+2\O4UE.0TU,+R]$5$0@365T26YF(#$N,"\O14XG
M+"`G<WEN8VUL.FUE=&EN9C$N,"<L(&YE=R!834Q?5T)834Q?1%1$7U-Y;F--
M3$UE=$EN9B@P*2D["B`@("`@("`@)'1H:7,M/G)E9VES=&5R1%1$*"<M+R]3
M64Y#34PO+T141"!-971);F8@,2XQ+R]%3B<L("=S>6YC;6PZ;65T:6YF,2XQ
M)RP@;F5W(%A-3%]70EA-3%]$5$1?4WEN8TU,365T26YF*#$I*3L*"B`@("`@
M("`@)'1H:7,M/G)E9VES=&5R1%1$*"<M+R]364Y#34PO+T141"!$979);F8@
M,2XP+R]%3B<L("=S>6YC;6PZ9&5V:6YF,2XP)RP@;F5W(%A-3%]70EA-3%]$
M5$1?4WEN8TU,1&5V26YF*#`I*3L*("`@("`@("`D=&AI<RT^<F5G:7-T97)$
M5$0H)RTO+U-93D--3"\O1%1$($1E=DEN9B`Q+C$O+T5.)RP@)W-Y;F-M;#ID
M979I;F8Q+C$G+"!N97<@6$U,7U="6$U,7T141%]3>6YC34Q$979);F8H,2DI
M.PH@("`@?0H*("`@("\J*@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T26YS
M=&%N8V4H)'!U8FQI8TED96YT:69I97(I"B`@("!["B`@("`@("`@)'!U8FQI
M8TED96YT:69I97(@/2!S=')T;VQO=V5R*"1P=6)L:6-)9&5N=&EF:65R*3L*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]S=')$5$1;)'!U8FQI8TED96YT
M:69I97)=*2D@>PH@("`@("`@("`@("`D9'1D(#T@)B1T:&ES+3Y?<W1R1%1$
M6R1P=6)L:6-)9&5N=&EF:65R73L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D9'1D(#T@;G5L;#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D
M=&0["B`@("!]"@H@("`@+RHJ"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971)
M;G-T86YC955222@D=7)I*0H@("`@>PH@("`@("`@("1U<FD@/2!S=')T;VQO
M=V5R*"1U<FDI.PH*("`@("`@("`O+R!S;VUE(&UA;G5A;"!H86-K<SH*("`@
M("`@("!I9B`H)'5R:2`]/2`G<WEN8VUL.G-Y;F-M;"<I('L*("`@("`@("`@
M("`@)'5R:2`]("=S>6YC;6PZ<WEN8VUL,2XP)SL*("`@("`@("!]"B`@("`@
M("`@:68@*"1U<FD@/3T@)W-Y;F-M;#IM971I;F8G*2!["B`@("`@("`@("`@
M("1U<FD@/2`G<WEN8VUL.FUE=&EN9C$N,"<["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=7)I(#T]("=S>6YC;6PZ9&5V:6YF)RD@>PH@("`@("`@("`@("`D
M=7)I(#T@)W-Y;F-M;#ID979I;F8Q+C`G.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<W1R1%1$55))6R1U<FE=*2D@>PH@("`@("`@
M("`@("`D9'1D(#T@)B1T:&ES+3Y?<W1R1%1$55))6R1U<FE=.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1D=&0@/2!N=6QL.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&1T9#L*("`@('T*"B`@("`O*BH*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5G:7-T97)$5$0H)'!U8FQI8TED96YT:69I97(L("1U
M<FDL("8D9'1D*0H@("`@>PH@("`@("`@("1P=6)L:6-)9&5N=&EF:65R(#T@
M<W1R=&]L;W=E<B@D<'5B;&EC261E;G1I9FEE<BD["B`@("`@("`@)&1T9"T^
M<V5T1%!)*"1P=6)L:6-)9&5N=&EF:65R*3L*"B`@("`@("`@)'1H:7,M/E]S
M=')$5$1;)'!U8FQI8TED96YT:69I97)=(#T@)&1T9#L*("`@("`@("`D=&AI
M<RT^7W-T<D141%5225MS=')T;VQO=V5R*"1U<FDI72`]("1D=&0["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO5T)834PO16YC
M;V1E<BYP:'``````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C<W
M,C``,3`U,34T,S$P-C``,#(P-C`S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)UA-3"]7
M0EA-3"YP:'`G.PII;F-L=61E7V]N8V4@)UA-3"]70EA-3"]#;VYT96YT2&%N
M9&QE<BYP:'`G.PII;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$5$1-86YA9V5R
M+G!H<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*
M("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T5N8V]D97(N
M<&AP+'8@,2XR-2XQ,"XQ,R`R,#`V+S`U+S,Q(#$W.C`V.C,W('-E;'-K>2!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@
M/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@1G)O
M;2!":6YA<GD@6$U,($-O;G1E;G0@1F]R;6%T(%-P96-I9FEC871I;VX@5F5R
M<VEO;B`Q+C,L(#(U($IU;'D*("H@,C`P,2!F;W5N9"!A="!H='1P.B\O=W=W
M+G=A<&9O<G5M+F]R9PH@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L
M87-S(%A-3%]70EA-3%]%;F-O9&5R(&5X=&5N9',@6$U,7U="6$U,7T-O;G1E
M;G1(86YD;&5R('L*"B`@("!V87(@)%]S=')I;F=S(#T@87)R87DH*3L*"B`@
M("!V87(@)%]S=')I;F=486)L93L*"B`@("!V87(@)%]H87-7<FET=&5N2&5A
M9&5R(#T@9F%L<V4["@H@("`@=F%R("1?9'1D.PH*("`@('9A<B`D7V]U='!U
M="`]("<G.PH*("`@('9A<B`D7W5R:7,@/2!A<G)A>2@I.PH*("`@('9A<B`D
M7W5R:4YU;7,@/2!A<G)A>2@I.PH*("`@('9A<B`D7V-U<G)E;G154DD["@H@
M("`@=F%R("1?<W5B4&%R<V5R(#T@;G5L;#L*("`@('9A<B`D7W-U8E!A<G-E
M<E-T86-K(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!834P@<&%R<V5R+@H@
M("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?
M<&%R<V5R.PH*("`@("\J*@H@("`@("H@5&AE($141"!-86YA9V5R+@H@("`@
M("H*("`@("`J($!V87(@6$U,7U="6$U,7T141$UA;F%G97(*("`@("`J+PH@
M("`@=F%R("1?9'1D36%N86=E<CL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?5T)834Q?16YC;V1E<B@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]D=&1-86YA9V5R(#T@)FYE=R!834Q?
M5T)834Q?1%1$36%N86=E<B@I.PH@("`@("`@("1T:&ES+3Y?<W1R:6YG5&%B
M;&4@/2`F;F5W(%A-3%]70EA-3%](87-H5&%B;&4H*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1A:V4@=&AE(&EN<'5T("1X;6P@86YD('1U<FX@:70@:6YT
M;R!70EA-3"X@5&AI<R!I<R!?;F]T7R!T:&4*("`@("`J(&EN=&5N9&5D('=A
M>2!O9B!U<VEN9R!T:&ES(&-L87-S+B!)="!I<R!D97)I=F5D(&9R;VT*("`@
M("`J($-O;G1E;G1H86YD;&5R(&%N9"!O;F4@<VAO=6QD('5S92!I="!A<R!A
M($-O;G1E;G1(86YD;&5R(&%N9`H@("`@("H@<')O9'5C92!T:&4@6$U,+7-T
M<G5C='5R92!W:71H('-T87)T16QE;65N="@I+"!E;F1%;&5M96YT*"DL"B`@
M("`@*B!A;F0@8VAA<F%C=&5R<R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!E
M;F-O9&4H)'AM;"D*("`@('L*("`@("`@("`O+R!#<F5A=&4@=&AE(%A-3"!P
M87)S97(@86YD('-E="!M971H;V0@<F5F97)E;F-E<RX*("`@("`@("`D=&AI
M<RT^7W!A<G-E<B`]('AM;%]P87)S97)?8W)E871E7VYS*"1T:&ES+3Y?8VAA
M<G-E="D["B`@("`@("`@>&UL7W-E=%]O8FIE8W0H)'1H:7,M/E]P87)S97(L
M("1T:&ES*3L*("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'1H:7,M
M/E]P87)S97(L(%A-3%]/4%1)3TY?0T%315]&3TQ$24Y'+"!F86QS92D["B`@
M("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H:7,M/E]P87)S97(L
M("=?<W1A<G1%;&5M96YT)RP@)U]E;F1%;&5M96YT)RD["B`@("`@("`@>&UL
M7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G
M7V-H87)A8W1E<G,G*3L*("`@("`@("!X;6Q?<V5T7W!R;V-E<W-I;F=?:6YS
M=')U8W1I;VY?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)R<I.PH@("`@("`@
M('AM;%]S971?97AT97)N86Q?96YT:71Y7W)E9E]H86YD;&5R*"1T:&ES+3Y?
M<&%R<V5R+"`G)RD["@H@("`@("`@(&EF("@A>&UL7W!A<G-E*"1T:&ES+3Y?
M<&%R<V5R+"`D>&UL*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H<W!R:6YT9B@G6$U,(&5R<F]R.B`E<R!A="!L:6YE("5D)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H)'1H:7,M/E]P
M87)S97(I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1T:&ES+3Y?
M<&%R<V5R*2DI.PH@("`@("`@('T*"B`@("`@("`@>&UL7W!A<G-E<E]F<F5E
M*"1T:&ES+3Y?<&%R<V5R*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T
M<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!W:6QL('=R:71E('1H
M92!C;W)R96-T(&AE861E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E
M2&5A9&5R*"1U<FDI"B`@("!["B`@("`@("`@)'1H:7,M/E]D=&0@/2`F)'1H
M:7,M/E]D=&1-86YA9V5R+3YG971);G-T86YC955222@D=7)I*3L*("`@("`@
M("!I9B`H(21T:&ES+3Y?9'1D*2!["B`@("`@("`@("`@("\O(%1/1$\Z('!R
M;W!E<B!E<G)O<B!H86YD;&EN9PH@("`@("`@("`@("!D:64H)U5N86)L92!T
M;R!F:6YD(&1T9"!F;W(@)R`N("1U<FDI.PH@("`@("`@('T*("`@("`@("`D
M9'!I4W1R:6YG(#T@)'1H:7,M/E]D=&0M/F=E=$1022@I.PH*("`@("`@("`O
M+R!3970@5F5R<VEO;B!.=6UB97(@9G)O;2!396-T:6]N(#4N-`H@("`@("`@
M("\O('9E<G-I;VX@/2!U7VEN=#@*("`@("`@("`O+R!C=7)R96YT;'D@,2P@
M,B!O<B`S"B`@("`@("`@)'1H:7,M/G=R:71E5F5R<VEO;DYU;6)E<B@D=&AI
M<RT^7W=B>&UL5F5R<VEO;BD["@H@("`@("`@("\O(%-E="!$;V-U;65N="!0
M=6)L:6,@261E=&EF:65R(&9R;VT@4V5C=&EO;B`U+C4*("`@("`@("`O+R!P
M=6)L:6-I9"`](&UB7W5?:6YT,S(@?"`H('IE<F\@:6YD97@@*0H@("`@("`@
M("\O('IE<F\@/2!U7VEN=#@*("`@("`@("`O+R!C;VYT86EN:6YG('1H92!V
M86QU92!Z97)O("@P*0H@("`@("`@("\O(%1H92!A8W1U86P@1%!)(&ES(&1E
M=&5R;6EN960@869T97(@=&AE(%-T<FEN9R!486)L92!I<R!R96%D+@H@("`@
M("`@("1T:&ES+3YW<FET941O8W5M96YT4'5B;&EC261E;G1I9FEE<B@D9'!I
M4W1R:6YG+"`D=&AI<RT^7W-T<FEN9W,I.PH*("`@("`@("`O+R!3970@0VAA
M<G-E="!F<F]M(#4N-@H@("`@("`@("\O(&-H87)S970@/2!M8E]U7VEN=#,R
M"B`@("`@("`@)'1H:7,M/G=R:71E0VAA<G-E="@D=&AI<RT^7V-H87)S970I
M.PH*("`@("`@("`O+R!3970@4W1R:6YG(%1A8FQE(&9R;VT@-2XW"B`@("`@
M("`@+R\@<W1R8C$@/2!L96YG=&@@*F)Y=&4*("`@("`@("`D=&AI<RT^=W)I
M=&53=')I;F=486)L92@D=&AI<RT^7W-T<FEN9W,L("1T:&ES+3Y?8VAA<G-E
M="P@)'1H:7,M/E]S=')I;F=486)L92D["@H@("`@("`@("1T:&ES+3Y?8W5R
M<F5N=%5222`]("1U<FD["@H@("`@("`@("1T:&ES+3Y?:&%S5W)I='1E;DAE
M861E<B`]('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&5697)S:6]N
M3G5M8F5R*"1V97)S:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<B@D=F5R<VEO;BD["B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&5$
M;V-U;65N=%!U8FQI8TED96YT:69I97(H)&1P:5-T<FEN9RP@)B1S=')I;F=S
M*0H@("`@>PH@("`@("`@("1I(#T@6$U,7U="6$U,.CIG971$4$E);G0H)&1P
M:5-T<FEN9RD["@H@("`@("`@(&EF("@D:2`]/2`P*2!["B`@("`@("`@("`@
M("1S=')I;F=S6S!=(#T@)&1P:5-T<FEN9SL*("`@("`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@8VAR*#`I.PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U
M="`N/2!C:'(H,"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@6$U,
M7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"`D:2D["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('=R:71E0VAA<G-E="@D8VAA
M<G-E="D*("`@('L*("`@("`@("`D8W,@/2!834Q?5T)834PZ.F=E=$-H87)S
M971);G0H)&-H87)S970I.PH*("`@("`@("!I9B`H)&-S(#T](#`I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;G-U<'!O<G1E
M9"!#:&%R<V5T.B`G("X@)&-H87)S970I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U
M='!U="P@)&-S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=W)I
M=&53=')I;F=486)L92@D<W1R:6YG<RP@)&-H87)S970L("1S=')I;F=486)L
M92D*("`@('L*("`@("`@("`D<W1R:6YG0GET97,@/2!A<G)A>2@I.PH@("`@
M("`@("1C;W5N="`](#`["B`@("`@("`@9F]R96%C:"`H)'-T<FEN9W,@87,@
M)'-T<BD@>PH@("`@("`@("`@("`D8GET97,@/2`D=&AI<RT^7V=E=$)Y=&5S
M*"1S='(L("1C:&%R<V5T*3L*("`@("`@("`@("`@)'-T<FEN9T)Y=&5S(#T@
M87)R87E?;65R9V4H)'-T<FEN9T)Y=&5S+"`D8GET97,I.PH@("`@("`@("`@
M("`D;G5L;$QE;F=T:"`]("1T:&ES+3Y?861D3G5L;$)Y=&4H)&)Y=&5S*3L*
M("`@("`@("`@("`@)'1H:7,M/E]S=')I;F=486)L92T^<V5T*"1S='(L("1C
M;W5N="D["B`@("`@("`@("`@("1C;W5N="`K/2!C;W5N="@D8GET97,I("L@
M)&YU;&Q,96YG=&@["B`@("`@("`@?0H*("`@("`@("!834Q?5T)834PZ.FEN
M=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L(&-O=6YT*"1S=')I;F=">71E
M<RDI.PH@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&EM<&QO9&4H)R<L("1S
M=')I;F=">71E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&53=')I;F<H
M)'-T<BP@)&-S*0H@("`@>PH@("`@("`@("1B>71E<R`]("1T:&ES+3Y?9V5T
M0GET97,H)'-T<BP@)&-S*3L*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!I
M;7!L;V1E*"<G+"`D8GET97,I.PH@("`@("`@("1T:&ES+3YW<FET94YU;&PH
M)&-S*3L*("`@('T*"B`@("!F=6YC=&EO;B!W<FET94YU;&PH)&-H87)S970I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*#`I.PH@("`@
M("`@(')E='5R;B`Q.PH@("`@?0H*("`@(&9U;F-T:6]N(%]A9&1.=6QL0GET
M92@F)&)Y=&5S*0H@("`@>PH@("`@("`@("1B>71E<UM=(#T@8VAR*#`I.PH@
M("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G971">71E
M<R@D<W1R:6YG+"`D8W,I"B`@("!["B`@("`@("`@)'-T<FEN9R`](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)'-T<FEN9RP@)&-S+"`G=71F+3@G*3L*("`@
M("`@("`D;F)Y=&5S(#T@<W1R;&5N*"1S=')I;F<I.PH*("`@("`@("`D8GET
M97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1N8GET
M97,[("1I*RLI('L*("`@("`@("`@("`@)&)Y=&5S6UT@/2`D<W1R:6YG>R1I
M?3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8GET97,["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W-P;&ET55))*"1T86<I"B`@("!["B`@("`@("`@)'!A
M<G1S(#T@97AP;&]D92@G.B<L("1T86<I.PH@("`@("`@("1N86UE(#T@87)R
M87E?<&]P*"1P87)T<RD["B`@("`@("`@)'5R:2`](&EM<&QO9&4H)SHG+"`D
M<&%R=',I.PH@("`@("`@(')E='5R;B!A<G)A>2@D=7)I+"`D;F%M92D["B`@
M("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1N86UE+"`D
M871T<FEB=71E<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]S=6)087)S
M97(@/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?:&%S5W)I
M='1E;DAE861E<BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G=R:71E2&5A
M9&5R*"1U<FDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7V-U<G)E;G154DD@(3T@)'5R:2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/F-H86YG96-O9&5P86=E*"1U<FDI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W-U8E!A<G-E<B`]/2!N=6QL*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^=W)I=&5486<H)&YA;64L("1A='1R:6)U=&5S
M+"!T<G5E+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97(M/G-T87)T16QE
M;65N="@D=7)I+"1N86UE+"`D871T<FEB=71E<RD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-U8E!A<G-E
M<E-T86-K*RL["B`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R+3YS=&%R
M=$5L96UE;G0H)'5R:2PD;F%M92PD871T<FEB=71E<RD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$5L96UE;G0H)'!A<G-E<BP@)'1A
M9RP@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@;&ES="@D=7)I+"`D;F%M
M92D@/2`D=&AI<RT^7W-P;&ET55))*"1T86<I.PH*("`@("`@("`D=&AI<RT^
M<W1A<G1%;&5M96YT*"1U<FDL("1N86UE+"`D871T<FEB=71E<RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@;W!A<75E*"1O*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T]005%5
M12D["B`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?
M;W5T<'5T+"!S=')L96XH)&\I*3L*("`@("`@("`D=&AI<RT^7V]U='!U="`N
M/2`D;SL*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S*"1C:&%R<RD*
M("`@('L*("`@("`@("`D8VAA<G,@/2!T<FEM*"1C:&%R<RD["@H@("`@("`@
M(&EF("AS=')L96XH)&-H87)S*2D@>PH@("`@("`@("`@("`O*B!792!D969I
M;FET96QY(&1O;B=T('=A;G0@86YY('=H:71E<W!A8V4N("HO"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7W-U8E!A<G-E<B`]/2!N=6QL*2!["B`@("`@("`@
M("`@("`@("`D:2`]("1T:&ES+3Y?<W1R:6YG5&%B;&4M/F=E="@D8VAA<G,I
M.PH@("`@("`@("`@("`@("`@:68@*"1I("$](&YU;&PI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,
M3T)!3%]43TM%3E]35%)?5"D["B`@("`@("`@("`@("`@("`@("`@6$U,7U="
M6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"`D:2D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E])
M*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W)I=&53=')I;F<H)&-H
M87)S+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S=6)0
M87)S97(M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?8VAA<F%C=&5R<R@D<&%R<V5R
M+"`D8VAA<G,I"B`@("!["B`@("`@("`@)'1H:7,M/F-H87)A8W1E<G,H)&-H
M87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!W<FET951A9R@D;F%M92P@)&%T
M=')S+"`D:&%S0V]N=&5N="P@)&-S*0H@("`@>PH@("`@("`@(&EF("@D871T
M<G,@(3T@;G5L;"`F)B`A8V]U;G0H)&%T=')S*2D@>PH@("`@("`@("`@("`D
M871T<G,@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)'0@/2`D=&AI<RT^
M7V1T9"T^=&]486=);G0H)&YA;64I.PH@("`@("`@(&EF("@D="`]/2`M,2D@
M>PH@("`@("`@("`@("`D:2`]("1T:&ES+3Y?<W1R:6YG5&%B;&4M/F=E="@D
M;F%M92D["B`@("`@("`@("`@(&EF("@D:2`]/2!N=6QL*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&YA;64@+B`G(&ES
M(&YO="!F;W5N9"!I;B!3=')I;F<@5&%B;&4@;W(@1%1$)RD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H)&%T=')S(#T](&YU
M;&P@)B8@(21H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E4
M15)!3"D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')S(#T](&YU
M;&P@)B8@)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%
M4D%,7T$I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1A='1R<R`A/2!N
M=6QL("8F("1H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E4
M15)!3%]#*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D871T<G,@(3T@
M;G5L;"`F)B`A)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E],
M251%4D%,7T%#*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!834Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L("1I
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EF("@D871T<G,@/3T@;G5L;"`F)B`A)&AA<T-O;G1E;G0I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D="D["B`@("`@("`@
M("`@('T@96QS96EF("@D871T<G,@/3T@;G5L;"`F)B`D:&%S0V]N=&5N="D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*"1T('P@
M-C0I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')S("$](&YU;&P@)B8@
M)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<B@D="!\(#$R."D["B`@("`@("`@("`@('T@96QS96EF("@D871T
M<G,@(3T@;G5L;"`F)B`A)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D="!\(#$Y,BD["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("@D871T<G,@(3T@;G5L;"`F)B!I
M<U]A<G)A>2@D871T<G,I("8F(&-O=6YT*"1A='1R<RD@/B`P*2!["B`@("`@
M("`@("`@("1T:&ES+3YW<FET94%T=')I8G5T97,H)&%T=')S+"`D8W,I.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!W<FET94%T=')I8G5T97,H
M)&%T=')S+"`D8W,I"B`@("!["B`@("`@("`@9F]R96%C:"`H)&%T=')S(&%S
M("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&AI<RT^=W)I=&5!
M='1R:6)U=&4H)&YA;64L("1V86QU92P@)&-S*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/
M2T5.7T5.1"D["B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&5!='1R:6)U=&4H
M)&YA;64L("1V86QU92P@)&-S*0H@("`@>PH@("`@("`@("1A(#T@)'1H:7,M
M/E]D=&0M/G1O071T<FEB=71E*"1N86UE*3L*("`@("`@("!I9B`H)&$@/3T@
M+3$I('L*("`@("`@("`@("`@)&D@/2`D=&AI<RT^7W-T<FEN9U1A8FQE+3YG
M970H)&YA;64I.PH@("`@("`@("`@("!I9B`H)&D@/3T@;G5L;"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1N86UE("X@
M)R!I<R!N;W0@9F]U;F0@:6X@4W1R:6YG(%1A8FQE(&]R($141"<I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P
M=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3"D["B`@
M("`@("`@("`@("`@("!834Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M
M/E]O=71P=70L("1I*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1A.PH@("`@("`@('T*
M"B`@("`@("`@)&D@/2`D=&AI<RT^7W-T<FEN9U1A8FQE+3YG970H)&YA;64I
M.PH@("`@("`@(&EF("@D:2`A/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]4
M*3L*("`@("`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES
M+3Y?;W5T<'5T+"`D:2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?
M4U127TDI.PH@("`@("`@("`@("`D=&AI<RT^=W)I=&53=')I;F<H)'9A;'5E
M+"`D8W,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!E;F1%;&5M
M96YT*"1U<FDL("1N86UE*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W-U
M8E!A<G-E<B`]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.1"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97(M/F5N9$5L
M96UE;G0H)'5R:2P@)&YA;64I.PH@("`@("`@("`@("`D=&AI<RT^7W-U8E!A
M<G-E<E-T86-K+2T["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]S=6)087)S
M97)3=&%C:R`]/2`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U
M="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]/4$%1544I.PH*("`@
M("`@("`@("`@("`@(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^
M7V]U='!U="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')L96XH)'1H:7,M/E]S=6)087)S97(M/F=E=$]U='!U="@I*2D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D=&AI<RT^7W-U
M8E!A<G-E<BT^9V5T3W5T<'5T*"D["@H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S=6)087)S97(@/2!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]E;F1%;&5M96YT*"1P87)S97(L("1T86<I
M"B`@("!["B`@("`@("`@;&ES="@D=7)I+"`D;F%M92D@/2`D=&AI<RT^7W-P
M;&ET55))*"1T86<I.PH@("`@("`@("1T:&ES+3YE;F1%;&5M96YT*"1U<FDL
M("1N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%N9V5C;V1E<&%G92@D
M=7)I*0H@("`@>PH@("`@("`@("\O($!T;V1O.B!T:&ES(&ES(&$@:&%C:R$*
M("`@("`@("!I9B`H)'1H:7,M/E]D=&0M/F=E=%9E<G-I;VXH*2`]/2`Q("8F
M("%P<F5G7VUA=&-H*"<O,5PN,20O)RP@)'5R:2DI('L*("`@("`@("`@("`@
M)'5R:2`N/2`G,2XQ)SL*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?
M9'1D+3YG971697)S:6]N*"D@/3T@,"`F)B`A<')E9U]M871C:"@G+S%<+C`D
M+R<L("1U<FDI*2!["B`@("`@("`@("`@("1U<FD@+CT@)S$N,"<["B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@("1C<"`]("1T:&ES+3Y?9'1D+3YT;T-O
M9&5086=E55))*"1U<FDI.PH@("`@("`@(&EF("AS=')L96XH)&-P*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1T9"`]("8D=&AI<RT^7V1T9$UA;F%G97(M
M/F=E=$EN<W1A;F-E55))*"1U<FDI.PH*("`@("`@("`@("`@)'1H:7,M/E]O
M=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U=)5$-(7U!!
M1T4I.PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H)&-P*3L*
M("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT55))(#T@)'5R:3L*"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97(@/2`F
M;F5W(%A-3%]70EA-3%]%;F-O9&5R*'1R=64I.PH@("`@("`@("`@("`D=&AI
M<RT^7W-U8E!A<G-E<E-T86-K(#T@,3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'971T97(@9F]R('!R;W!E<G1Y(&]U='!U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T3W5T<'5T*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]O=71P=70["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T3W5T
M<'5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N('-T<FQE;B@D=&AI<RT^
M7V]U='!U="D["B`@("!]"@I]"@``````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+UA-3"]70EA-3"]$96-O9&5R+G!H<```````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`T-S<Q-P`Q,#4Q-30S,3`V,``P,C`V,#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"FEN8VQU9&5?;VYC92`G6$U,+U="6$U,+G!H<"<["FEN8VQU9&5?;VYC92`G
M6$U,+U="6$U,+T141$UA;F%G97(N<&AP)SL*:6YC;'5D95]O;F-E("=834PO
M5T)834PO0V]N=&5N=$AA;F1L97(N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]834Q?5T)834PO5T)834PO1&5C;V1E<BYP:'`L=B`Q+C(R+C$P
M+C@@,C`P-B\P,2\P,2`R,3HR.#HT-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N
M8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT
M96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY
M"B`J(#(P,#$@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*
M("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?5T)834Q?1&5C
M;V1E<B!E>'1E;F1S(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE<B!["@H@("`@
M+RHJ"B`@("`@*B!$;V-U;65N="!0=6)L:6,@261E;G1I9FEE<B!T>7!E"B`@
M("`@*B`Q(&UB7W5?:6YT,S(@=V5L;"!K;F]W;B!T>7!E"B`@("`@*B`R('-T
M<FEN9R!T86)L90H@("`@("H@9G)O;2!S<&5C(&)U="!C;VYV97)T960@:6YT
M;R!A('-T<FEN9RX*("`@("`J"B`@("`@*B!$;V-U;65N="!0=6)L:6,@261E
M;G1I9FEE<@H@("`@("H@57-E9"!W:71H(&1P:51Y<&4N"B`@("`@*B\*("`@
M('9A<B`D7V1P:3L*"B`@("`O*BH*("`@("`J(%-T<FEN9R!T86)L92!A<R!D
M969I;F5D(&EN(#4N-PH@("`@("HO"B`@("!V87(@)%]S=')I;F=486)L92`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYT96YT(&AA;F1L97(N"B`@
M("`@*B!#=7)R96YT;'D@:G5S="!O=71P=71S(')A=R!834PN"B`@("`@*B\*
M("`@('9A<B`D7V-H.PH*("`@('9A<B`D7W1A9T141#L*"B`@("!V87(@)%]P
M<F5V071T<FEB=71E1%1$.PH*("`@('9A<B`D7V%T=')I8G5T94141#L*"B`@
M("`O*BH*("`@("`J(%-T871E('9A<FEA8FQE<RX*("`@("`J+PH@("`@=F%R
M("1?=&%G4W1A8VL@/2!A<G)A>2@I.PH@("`@=F%R("1?:7-!='1R:6)U=&4[
M"B`@("!V87(@)%]I<T1A=&$@/2!F86QS93L*"B`@("!V87(@)%]E<G)O<B`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE($141"!-86YA9V5R+@H@("`@
M("H*("`@("`J($!V87(@6$U,7U="6$U,7T141$UA;F%G97(*("`@("`J+PH@
M("`@=F%R("1?9'1D36%N86=E<CL*"B`@("`O*BH*("`@("`J(%1H92!S=')I
M;F<@<&]S:71I;VXN"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B\*("`@('9A<B`D7W-T<G!O<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?5T)834Q?1&5C;V1E<B@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]D=&1-86YA9V5R(#T@)FYE=R!834Q?
M5T)834Q?1%1$36%N86=E<B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M<R!T:&4@8V]N=&5N=$AA;F1L97(@=&AA="!W:6QL(')E8V5I=F4@=&AE(&]U
M='!U="!O9B!T:&4*("`@("`J(&1E8V]D:6YG+@H@("`@("H*("`@("`J($!P
M87)A;2!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(@)&-H(%1H92!C;VYT96YT
M2&%N9&QE<@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#;VYT96YT2&%N9&QE
M<B@F)&-H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V@@/2`F)&-H.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&]N92!B>71E(&9R;VT@=&AE(&EN
M<'5T('-T<F5A;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G!U
M="`@5&AE(%="6$U,(&EN<'5T('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0GET92@D:6YP=70I"B`@("!["B`@("`@("`@<F5T=7)N(&]R9"@D
M:6YP=71[)'1H:7,M/E]S=')P;W,K*WTI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&%K97,@82!70EA-3"!I;G!U="!D;V-U;65N="!A;F0@<F5T=7)N<R!D
M96-O9&5D(%A-3"X*("`@("`J($AO=V5V97(@=&AE('!R969E<G)E9"!A;F0@
M;6]R92!E9F9E8VEE;G0@;65T:&]D(&ES('1O"B`@("`@*B!U<V4@9&5C;V1E
M*"D@<F%T:&5R('1H86X@9&5C;V1E5&]3=')I;F<H*2!A;F0@:&%V92!A;@H@
M("`@("H@87!P<F]P<FEA=&4@8V]N=&5N=$AA;F1L97(@9&5A;"!W:71H('1H
M92!D96-O9&5D(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=V)X;6P@(%1H92!70EA-3"!D;V-U;65N="!T;R!D96-O9&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D96-O9&5D(%A-3"!D;V-U;65N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E5&]3=')I;F<H)'=B>&UL
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V@@/2`F;F5W(%A-3%]70EA-3%]#
M;VYT96YT2&%N9&QE<B@I.PH*("`@("`@("`D<B`]("1T:&ES+3YD96-O9&4H
M)'=B>&UL*3L*("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'(["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-H+3YG971/=71P=70H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1A:V5S(&$@5T)834P@:6YP=70@9&]C=6UE;G0@86YD(&1E8V]D
M97,@:70N"B`@("`@*B!$96-O9&EN9R!R97-U;'0@:7,@9&ER96-T;'D@<&%S
M<V5D('1O('1H92!C;VYT96YT2&%N9&QE<BX*("`@("`J($$@8V]N=&5N=&AA
M;F1L97(@;75S="!B92!S970@=7-I;F<@<V5T0V]N=&5N=$AA;F1L97(*("`@
M("`J('!R:6]R('1O(&EN=F]C871I;VX@;V8@=&AI<R!M971H;V0*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1W8GAM;"`@5&AE(%="6$U,(&1O8W5M
M96YT('1O(&1E8V]D92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5C;V1E*"1W8GAM;"D*("`@('L*("`@("`@("`D=&AI<RT^7V5R
M<F]R(#T@9F%L<V4[("\O(')E<V5T('-T871E"@H@("`@("`@("1T:&ES+3Y?
M<W1R<&]S(#T@,#L*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?8V@I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G3F\@0V]N
M=&5N=&AA;F1L97(@9&5F:6YE9"XG*3L*("`@("`@("!]"@H@("`@("`@("\O
M($=E="!697)S:6]N($YU;6)E<B!F<F]M(%-E8W1I;VX@-2XT"B`@("`@("`@
M+R\@=F5R<VEO;B`]('5?:6YT.`H@("`@("`@("\O(&-U<G)E;G1L>2`Q+"`R
M(&]R(#,*("`@("`@("`D=&AI<RT^7W=B>&UL5F5R<VEO;B`]("1T:&ES+3YG
M971697)S:6]N3G5M8F5R*"1W8GAM;"D["@H@("`@("`@("\O($=E="!$;V-U
M;65N="!0=6)L:6,@261E=&EF:65R(&9R;VT@4V5C=&EO;B`U+C4*("`@("`@
M("`O+R!P=6)L:6-I9"`](&UB7W5?:6YT,S(@?"`H>F5R;R!I;F1E>"D*("`@
M("`@("`O+R!Z97)O(#T@=5]I;G0X"B`@("`@("`@+R\@0V]N=&%I;FEN9R!T
M:&4@=F%L=64@>F5R;R`H,"D*("`@("`@("`O+R!4:&4@86-T=6%L($1022!I
M<R!D971E<FUI;F5D(&%F=&5R('1H92!3=')I;F<@5&%B;&4@:7,@<F5A9"X*
M("`@("`@("`D9'!I4W1R=6-T(#T@)'1H:7,M/F=E=$1O8W5M96YT4'5B;&EC
M261E;G1I9FEE<B@D=V)X;6PI.PH*("`@("`@("`O+R!'970@0VAA<G-E="!F
M<F]M(#4N-@H@("`@("`@("\O(&-H87)S970@/2!M8E]U7VEN=#,R"B`@("`@
M("`@)'1H:7,M/E]C:&%R<V5T(#T@)'1H:7,M/F=E=$-H87)S970H)'=B>&UL
M*3L*"B`@("`@("`@+R\@1V5T(%-T<FEN9R!486)L92!F<F]M(#4N-PH@("`@
M("`@("\O('-T<F(Q(#T@;&5N9W1H("IB>71E"B`@("`@("`@)'1H:7,M/G)E
M=')I979E4W1R:6YG5&%B;&4H)'=B>&UL*3L*"B`@("`@("`@+R\@1V5T($1O
M8W5M96YT(%!U8FQI8R!)9&5T:69I97(@9G)O;2!396-T:6]N(#4N-2X*("`@
M("`@("`D=&AI<RT^7V1P:2`]("1T:&ES+3YG971$;V-U;65N=%!U8FQI8TED
M96YT:69I97));7!L*"1D<&E3=')U8W1;)V1P:51Y<&4G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D<&E3=')U8W1;)V1P:4YU;6)E<B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S=')I;F=486)L92D["@H@("`@("`@("\O($YO=R!T:&4@
M<F5A;"!F=6X@8F5G:6YS+@H@("`@("`@("\O($9R;VT@4V5C=&EO;G,@-2XR
M(&%N9"`U+C@*"@H@("`@("`@("\O($1E9F%U;'0@8V]N=&5N="!H86YD;&5R
M+@H@("`@("`@("1T:&ES+3Y?9'1D36%N86=E<B`]("9N97<@6$U,7U="6$U,
M7T141$UA;F%G97(H*3L*"B`@("`@("`@+R\@1V5T('1H92!S=&%R=&EN9R!$
M5$0N"B`@("`@("`@)'1H:7,M/E]T86=$5$0@/2`D=&AI<RT^7V1T9$UA;F%G
M97(M/F=E=$EN<W1A;F-E*"1T:&ES+3Y?9'!I*3L*"B`@("`@("`@:68@*"$D
M=&AI<RT^7W1A9T141"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)TYO($141"!F;W5N9"!F;W(@)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)'1H:7,M/E]D<&D@+B`G+R<*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("1D<&E3=')U8W1;)V1P:4YU;6)E<B==*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?871T<FEB=71E1%1$(#T@)'1H
M:7,M/E]T86=$5$0["@H@("`@("`@('=H:6QE("AE;7!T>2@D=&AI<RT^7V5R
M<F]R*2`F)B`D=&AI<RT^7W-T<G!O<R`\('-T<FQE;B@D=V)X;6PI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?9&5C;V1E*"1W8GAM;"D["B`@("`@("`@?0H@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]E<G)O<BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?97)R;W(["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9E<G-I;VY.=6UB
M97(H)&EN<'5T*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9V5T0GET
M92@D:6YP=70I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$1O8W5M96YT4'5B
M;&EC261E;G1I9FEE<B@D:6YP=70I"B`@("!["B`@("`@("`@)&D@/2!834Q?
M5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RD[
M"B`@("`@("`@:68@*"1I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=D<&E4>7!E)R`]/B`R+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)V1P:4YU;6)E<B<@/3X@)'1H:7,M/F=E=$)Y=&4H)&EN<'5T*2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=D<&E4>7!E
M)R`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V1P:4YU;6)E<B<@
M/3X@)&DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971$;V-U
M;65N=%!U8FQI8TED96YT:69I97));7!L*"1D<&E4>7!E+"`D9'!I3G5M8F5R
M*0H@("`@>PH@("`@("`@(&EF("@D9'!I5'EP92`]/2`Q*2!["B`@("`@("`@
M("`@(')E='5R;B!834Q?5T)834PZ.F=E=$1025-T<FEN9R@D9'!I3G5M8F5R
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=%-T<FEN9U1A8FQE16YT<GDH)&1P:4YU;6)E<BD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C=&5R(&5N
M8V]D:6YG+B!/;FQY(&1E9F%U;'0@8VAA<F%C=&5R"B`@("`@*B!E;F-O9&EN
M9W,@9G)O;2!*,E-%(&%R92!S=7!P;W)T960N("!&<F]M"B`@("`@*B!H='1P
M.B\O=W=W+FEA;F$N;W)G+V%S<VEG;FUE;G1S+V-H87)A8W1E<BUS971S(&%N
M9`H@("`@("H@:'1T<#HO+VIA=F$N<W5N+F-O;2]J,G-E+S$N-"XR+V1O8W,O
M87!I+VIA=F$O;FEO+V-H87)S970O0VAA<G-E="YH=&UL"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-H87)S970H)&EN<'5T*0H@("`@>PH@("`@("`@("1C
M<R`](%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?
M<W1R<&]S*3L*("`@("`@("!R971U<FX@6$U,7U="6$U,.CIG971#:&%R<V5T
M4W1R:6YG*"1C<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@
M=&AE('-T<FEN9R!T86)L92X*("`@("`J(%1H92!S=')I;F<@=&%B;&4@8V]N
M<VES=',@;V8@86X@;6)?=5]I;G0S,B!L96YG=&@*("`@("`J(&%N9"!T:&5N
M(&QE;F=T:"!B>71E<R!F;W)M:6YG('1H92!T86)L92X*("`@("`J(%)E9F5R
M96YC97,@=&\@=&AE('-T<FEN9R!T86)L92!R969E<B!T;R!T:&4*("`@("`J
M('-T87)T:6YG('!O<VET:6]N(&]F('1H92`H;G5L;"!T97)M:6YA=&5D*0H@
M("`@("H@<W1R:6YG(&EN('1H:7,@=&%B;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E=')I979E4W1R:6YG5&%B;&4H)&EN<'5T*0H@("`@>PH@("`@("`@
M("1S:7IE(#T@6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H
M:7,M/E]S=')P;W,I.PH@("`@("`@("1T:&ES+3Y?<W1R:6YG5&%B;&4@/2!S
M=6)S='(H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RP@)'-I>F4I.PH@("`@("`@
M("1T:&ES+3Y?<W1R<&]S("L]("1S:7IE.PH@("`@("`@("\O('!R:6YT(")S
M=')I;F=T86)L92@D<VEZ92DZ(B`N("1T:&ES+3Y?<W1R:6YG5&%B;&4@+B)<
M;B(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4W1R:6YG5&%B;&5%;G1R>2@D
M:6YD97@I"B`@("!["B`@("`@("`@:68@*"1I;F1E>"`^/2!S=')L96XH)'1H
M:7,M/E]S=')I;F=486)L92DI('L*("`@("`@("`@("`@)'1H:7,M/E]E<G)O
M<B`]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H+3YR86ES945R<F]R*"=)
M;G9A;&ED(&]F9G-E="`G("X@)&EN9&5X"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("<@=F%L=64@96YC;W5N=&5R960@87)O=6YD
M('!O<VET:6]N("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)'1H:7,M/E]S=')P;W,*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)RX@0G)O:V5N('=B>&UL/R<I.PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`O+R!C;W!Y(&]F(&UE
M=&AO9"!T97)M<W1R(&)U="!W:71H;W5T(&UO9&EF:6-A=&EO;B!O9B!T:&ES
M+3Y?<W1R<&]S"@H@("`@("`@("1S='(@/2`G(R<[("\O(&UU<W0@<W1A<G0@
M=VET:"!N;VYE;7!T>2!S=')I;F<@=&\@86QL;W<@87)R87D@86-C97-S"@H@
M("`@("`@("1I(#T@,#L*("`@("`@("`D8V@@/2`D=&AI<RT^7W-T<FEN9U1A
M8FQE6R1I;F1E>"LK73L*("`@("`@("!I9B`H;W)D*"1C:"D@/3T@,"D@>PH@
M("`@("`@("`@("!R971U<FX@)R<[("\O(&1O;B=T(')E='5R;B`G(R<*("`@
M("`@("!]"@H@("`@("`@('=H:6QE("AO<F0H)&-H*2`A/2`P*2!["B`@("`@
M("`@("`@("1S=');)&DK*UT@/2`D8V@["B`@("`@("`@("`@(&EF("@D:6YD
M97@@/CT@<W1R;&5N*"1T:&ES+3Y?<W1R:6YG5&%B;&4I*2!["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8V@@
M/2`D=&AI<RT^7W-T<FEN9U1A8FQE6R1I;F1E>"LK73L*("`@("`@("!]"B`@
M("`@("`@+R\@<')I;G0@(G-T<FEN9R!T86)L92!E;G1R>3H@)'-T<EQN(CL*
M("`@("`@("!R971U<FX@)'-T<CL*"B`@("!]"@H@("`@9G5N8W1I;VX@7V1E
M8V]D92@D:6YP=70I"B`@("!["B`@("`@("`@)'1O:V5N(#T@)'1H:7,M/F=E
M=$)Y=&4H)&EN<'5T*3L*("`@("`@("`D<W1R(#T@)R<["@H@("`@("`@("\O
M('!R:6YT(")P;W-I=&EO;CH@(B`N("1T:&ES+3Y?<W1R<&]S("X@(B!T;VME
M;CH@(B`N("1T;VME;B`N("(@<W1R,3`Z("(@+B!S=6)S='(H)&EN<'5T+"`D
M=&AI<RT^7W-T<G!O<RP@,3`I("X@(EQN(CL@+R\@0'1O9&\Z(')E;6]V92!D
M96)U9R!O=71P=70*"B`@("`@("`@<W=I=&-H("@D=&]K96XI('L*("`@("`@
M("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U127TDZ"B`@("`@("`@
M("`@("\O(%-E8W1I;VX@-2XX+C0N,0H@("`@("`@("`@("`D<W1R(#T@)'1H
M:7,M/G1E<FUS='(H)&EN<'5T*3L*("`@("`@("`@("`@)'1H:7,M/E]C:"T^
M8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@("`@("`@+R\@<')I;G0@(G-T<CHD
M<W1R7&XB.R`O+R!`5$]$3R!296UO=F4@9&5B=6<@8V]D90H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.
M7U-44E]4.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C$*("`@("`@
M("`@("`@)'@@/2!834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D
M=&AI<RT^7W-T<G!O<RD["B`@("`@("`@("`@("1S='(@/2`D=&AI<RT^9V5T
M4W1R:6YG5&%B;&5%;G1R>2@D>"D["B`@("`@("`@("`@("1T:&ES+3Y?8V@M
M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,#H*("`@("`@
M("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,3H*("`@("`@
M("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,CH*("`@("`@
M("`@("`@+R\@4V5C=&EO;B`U+C@N-"XR"B`@("`@("`@("`@("1S='(@/2`D
M=&AI<RT^=&5R;7-T<B@D:6YP=70I.PH@("`@("`@("`@("`D=&AI<RT^7V-H
M+3YC:&%R86-T97)S*"1S='(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%]47S`Z"B`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%]47S$Z"B`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%]47S(Z"B`@("`@
M("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,@H@("`@("`@("`@("`D<W1R(#T@
M)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT>2A834Q?5T)834PZ.DU"54EN=#,R
M5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RDI.PH@("`@("`@("`@("`D
M=&AI<RT^7V-H+3YC:&%R86-T97)S*"1S='(I.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\P
M.@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,3H*
M("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47S(Z"B`@
M("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,@H@("`@("`@("`@("`D97AT
M96YS:6]N(#T@)'1H:7,M/F=E=$)Y=&4H)&EN<'5T*3L*("`@("`@("`@("`@
M)'1H:7,M/E]C:"T^8VAA<F%C=&5R<R@D97AT96YS:6]N*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%
M3E]%3E1)5%DZ"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,PH@("`@
M("`@("`@("`O+R!50U,M-"!C:')A8W1E<B!E;F-O9&EN9S\*("`@("`@("`@
M("`@)&5N=&ET>2`]("1T:&ES+3YE;G1I='DH6$U,7U="6$U,.CI-0E5);G0S
M,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*"B`@("`@("`@("`@
M("1T:&ES+3Y?8V@M/F-H87)A8W1E<G,H)R8C)R`N("1E;G1I='D@+B`G.R<I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7U!).@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT
M+C0*("`@("`@("`@("`@+R\@=&AR;W<@;F5W($E/17AC97!T:6]N"B`@("`@
M("`@("`@("\O(&1I92@B5T)834P@9VQO8F%L('1O:V5N('!R;V-E<W-I;F<@
M:6YS=')U8W1I;VXH4$DL("(@*R!T;VME;B`K("(I(&ES('5N<W5P<&]R=&5D
M(5QN(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]7
M0EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3#H*("`@("`@("`@("`@+R\@4V5C
M=&EO;B`U+C@N-"XU"B`@("`@("`@("`@("1S='(@/2`D=&AI<RT^9V5T4W1R
M:6YG5&%B;&5%;G1R>2A834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T
M+"`D=&AI<RT^7W-T<G!O<RDI.PH@("`@("`@("`@("`D=&AI<RT^<&%R<V54
M86<H)&EN<'5T+"`D<W1R+"!F86QS92P@9F%L<V4I.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)
M5$5204Q?03H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XU"B`@("`@
M("`@("`@("1S='(@/2`D=&AI<RT^9V5T4W1R:6YG5&%B;&5%;G1R>2A834Q?
M5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RDI
M.PH@("`@("`@("`@("`D=&AI<RT^<&%R<V5486<H)&EN<'5T+"`D<W1R+"!T
M<G5E+"!F86QS92D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3%]!0SH*("`@("`@("`@
M("`@+R\@4V5C=&EO;B`U+C@N-"XU"B`@("`@("`@("`@("1S='(@/2`D=&AI
M<RT^9V5T4W1R:6YG5&%B;&5%;G1R>2A834Q?5T)834PZ.DU"54EN=#,R5&])
M;G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RDI.PH@("`@("`@("`@("`D=&AI
M<RT^<&%R<V5486<H)&EN<'5T+"`D<W1R:6YG+"!T<G5E+"!T<G5E*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E],251%4D%,7T,Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX
M+C0N-0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN9U1A8FQE
M16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M
M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M/G!A<G-E5&%G*"1I;G!U
M="P@)'-T<BP@9F%L<V4L('1R=64I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T]005%513H*("`@
M("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XV"B`@("`@("`@("`@("1S:7IE
M(#T@6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S
M=')P;W,I.PH@("`@("`@("`@("`O+R!P<FEN="`B;W!A<75E(&]F('-I>F4@
M)'-I>F5<;B([("\O($!T;V1O(')E;6]V92!D96)U9PH@("`@("`@("`@("`D
M8B`]('-U8G-T<B@D:6YP=70L("1T:&ES+3Y?<W1R<&]S+"`D<VEZ92D["B`@
M("`@("`@("`@("1T:&ES+3Y?<W1R<&]S("L]("1S:7IE.PH*("`@("`@("`@
M("`@+R\@;W!A<75E(&1A=&$@:6YS:61E(&$@/&1A=&$^(&5L96UE;G0@;6%Y
M(&]R(&UA>2!N;W0@8F4*("`@("`@("`@("`@+R\@82!N97-T960@=V)X;6P@
M9&]C=6UE;G0@*&9O<B!E>&%M<&QE(&1E=FEN9B!D871A*2X*("`@("`@("`@
M("`@+R\@5V4@9FEN9"!O=70@8GD@8VAE8VMI;F<@=&AE(&9I<G-T(&)Y=&4@
M;V8@=&AE(&1A=&$Z(&EF(&ET)W,*("`@("`@("`@("`@+R\@,2P@,B!O<B`S
M('=E(&5X<&5C="!I="!T;R!B92!T:&4@=F5R<VEO;B!N=6UB97(@;V8@82!W
M8GAM;`H@("`@("`@("`@("`O+R!D;V-U;65N="!A;F0@=&AU<R!S=&%R="!A
M(&YE=R!W8GAM;"!D96-O9&5R(&EN<W1A;F-E(&]N(&ET+@H*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?:7-$871A("8F(&]R9"@D8BD@/#T@,3`I('L*("`@
M("`@("`@("`@("`@("1D96-O9&5R(#T@)FYE=R!834Q?5T)834Q?1&5C;V1E
M<BAT<G5E*3L*("`@("`@("`@("`@("`@("1D96-O9&5R+3YS971#;VYT96YT
M2&%N9&QE<B@D=&AI<RT^7V-H*3L*("`@("`@("`@("`@("`@("1S(#T@)&1E
M8V]D97(M/F1E8V]D92@D8BD["B`@("`@("`@+R\@("`@("`@("`@("`@("`@
M+RH@+R\@0'1O9&\Z($9)6$U%(&-U<G)E;G1L>2!W92!C86XG="!D96-O9&4@
M3F]K:6$*("`@("`@("`@("`@("`@("\O($1E=DEN9B!D871A+B!3;R!I9VYO
M<F4@97)R;W(@9F]R('1H92!T:6UE(&)E96EN9RX*("`@("`@("!I9B`H:7-?
M82@D<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?97)R;W(@/2`D<SL*("`@("`@("`@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O+R`J+PH@("`@
M("`@("`@("`@("`@+R\@)'1H:7,M/E]C:"T^8VAA<F%C=&5R<R@D<RD["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!N;W)M86P@
M;W!A<75E(&)E:&%V:6]U<CH@:G5S="!C;W!Y('1H92!R87<@9&%T83H@*B\*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V@M/F-H87)A8W1E<G,H("1B*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@;VQD(&%P<')O86-H('1O
M(&1E86P@=VET:"!O<&%Q=64@9&%T82!I;G-I9&4@0V]N=&5N=$AA;F1L97(Z
M"B`@("`@("`@("`@("\O($9)6$U%($]P87%U92!I<R!U<V5D(&)Y(%-93D--
M3"X@($]P87%U92!D871A('1H870@9&5P96YD<R!O;B!T:&4@8V]N=&5X=`H@
M("`@("`@("`@("`O+R!I9B`H8V]N=&5N=$AA;F1L97(@:6YS=&%N8V5O9B!/
M<&%Q=65#;VYT96YT2&%N9&QE<BD@>PH@("`@("`@("`@("`O+R`@("`@*"A/
M<&%Q=65#;VYT96YT2&%N9&QE<BEC;VYT96YT2&%N9&QE<BDN;W!A<75E*&(I
M.PH@("`@("`@("`@("`O+R!](&5L<V4@>PH@("`@("`@("`@("`O+R`@("`@
M4W1R:6YG('-T<B`](&YE=R!3=')I;F<H8BP@,"P@<VEZ92P@8VAA<G-E="D[
M"B`@("`@("`@("`@("\O("`@("!C:&%R6UT@8VAA<G,@/2!S='(N=&]#:&%R
M07)R87DH*3L*"B`@("`@("`@("`@("\O("`@("!C;VYT96YT2&%N9&QE<BYC
M:&%R86-T97)S*&-H87)S+"`P+"!C:&%R<RYL96YG=&@I.PH@("`@("`@("`@
M("`O+R!]"@H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T5.1#H*("`@("`@("`@("`@+R\@4V5C=&EO
M;B`U+C@N-"XW+C$*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YE;F1486<H
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E]35TE40TA?4$%'13H*("`@("`@("`@("`@+R\@4V5C
M=&EO;B`U+C@N-"XW+C(*("`@("`@("`@("`@)&-O9&5086=E(#T@)'1H:7,M
M/F=E=$)Y=&4H)&EN<'5T*3L*("`@("`@("`@("`@+R\@<')I;G0@(G-W:71C
M:"!T;R!C;V1E<&%G92`D8V]D95!A9V5<;B([("\O($!T;V1O.B!R96UO=F4@
M9&5B=6<@8V]D90H@("`@("`@("`@("`D=&AI<RT^<W=I=&-H16QE;65N=$-O
M9&5086=E*"1C;V1E4&%G92D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XR"B`@("`@
M("`@("`@("\O(%-E8W1I;VX@-2XX+C,*("`@("`@("`@("`@)&AA<T%T=')I
M8G5T97,@/2`H*"1T;VME;B`F(#!X.#`I("$](#`I.PH@("`@("`@("`@("`D
M:&%S0V]N=&5N="`]("@H)'1O:V5N("8@,'@T,"D@(3T@,"D["B`@("`@("`@
M("`@("1R96%L5&]K96X@/2`D=&]K96X@)B`P>#-&.PH@("`@("`@("`@("`D
M<W1R(#T@)'1H:7,M/F=E=%1A9R@D<F5A;%1O:V5N*3L*"B`@("`@("`@("`@
M("\O('!R:6YT(")E;&5M96YT.B1S=')<;B([("\O($!43T1/(%)E;6]V92!D
M96)U9R!C;V1E"B`@("`@("`@("`@("1T:&ES+3YP87)S951A9R@D:6YP=70L
M("1S='(L("1H87-!='1R:6)U=&5S+"`D:&%S0V]N=&5N="D["@H@("`@("`@
M("`@("!I9B`H)')E86Q4;VME;B`]/2`P>#!F*2!["B`@("`@("`@("`@("`@
M("`O+R!S=&]R92!I9B!W92=R92!I;G-I9&4@82!$871A('1A9RX@5&AI<R!M
M87D@8V]N=&%I;@H@("`@("`@("`@("`@("`@+R\@86X@861D:71I;VYA;"!E
M;F-L;W-E9"!W8GAM;"!D;V-U;65N="!O;B!W:&EC:"!W92!H879E"B`@("`@
M("`@("`@("`@("`O+R!T;R!R=6X@82!S97!E<F%T92!E;F-O9&5R"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VES1&%T82`]('1R=64["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VES1&%T82`](&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!P87)S951A9R@D:6YP=70L("1T86<L
M("1H87-!='1R:6)U=&5S+"`D:&%S0V]N=&5N="D*("`@('L*("`@("`@("`D
M871T<G,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D:&%S071T<FEB=71E<RD@
M>PH@("`@("`@("`@("`D871T<G,@/2`D=&AI<RT^9V5T071T<FEB=71E<R@D
M:6YP=70I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:"T^<W1A<G1%
M;&5M96YT*"1T:&ES+3YG971#=7)R96YT55))*"DL("1T86<L("1A='1R<RD[
M"@H@("`@("`@(&EF("@D:&%S0V]N=&5N="D@>PH@("`@("`@("`@("`O+R!&
M25A-12!)(&9O<F=O="!W:&%T(&1O97,@=&AI<R!D;V5S+B!.;W0@<W5R92!I
M9B!T:&ES(&ES"B`@("`@("`@("`@("\O(')I9VAT/PH@("`@("`@("`@("`D
M=&AI<RT^7W1A9U-T86-K6UT@/2`D=&%G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?8V@M/F5N9$5L96UE;G0H)'1H:7,M/F=E=$-U
M<G)E;G154DDH*2P@)'1A9RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(&5N9%1A9R@I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M=&%G4W1A8VLI*2!["B`@("`@("`@("`@("1T86<@/2!A<G)A>5]P;W`H)'1H
M:7,M/E]T86=3=&%C:RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1A9R`]("=5;FMN;W=N)SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M8V@M/F5N9$5L96UE;G0H)'1H:7,M/F=E=$-U<G)E;G154DDH*2P@)'1A9RD[
M"@H@("`@("`@(')E='5R;B`D=&%G.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=$%T=')I8G5T97,H)&EN<'5T*0H@("`@>PH@("`@("`@("1T:&ES+3YS=&%R
M=$=E=$%T=')I8G5T97,H*3L*("`@("`@("`D:&%S36]R94%T=')I8G5T97,@
M/2!T<G5E.PH*("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH@("`@("`@("1A
M='1R(#T@;G5L;#L*("`@("`@("`D=F%L=64@/2!N=6QL.PH@("`@("`@("1T
M;VME;B`](&YU;&P["@H@("`@("`@('=H:6QE("@D:&%S36]R94%T=')I8G5T
M97,I('L*("`@("`@("`@("`@)'1O:V5N(#T@)'1H:7,M/F=E=$)Y=&4H)&EN
M<'5T*3L*"B`@("`@("`@("`@('-W:71C:"`H)'1O:V5N*2!["B`@("`@("`@
M("`@("\O($%T=')I8G5T92!S<&5C:69I960N"B`@("`@("`@("`@(&-A<V4@
M6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,.@H@("`@("`@("`@("`@
M("`@+R\@4V5C=&EO;B`U+C@N-"XU"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&%T='(I*2!["B`@("`@("`@("`@("`@("`@("`@)&%T=')S6UT@/2!A
M<G)A>2@G871T<FEB=71E)R`]/B`D871T<BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D871T<B`]("1T:&ES+3YG
M9713=')I;F=486)L945N=')Y*%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D
M:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("\O(%9A;'5E('-P96-I9FEE9"X*("`@("`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S`Z"B`@("`@
M("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\Q.@H@
M("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?
M,CH*("`@("`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,@H@("`@("`@
M("`@("`@("`@)'9A;'5E("X]("1T:&ES+3YT97)M<W1R*"1I;G!U="D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@6$U,7U="
M6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\P.@H@("`@("`@("`@("!C87-E(%A-
M3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,3H*("`@("`@("`@("`@8V%S
M92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%]47S(Z"B`@("`@("`@("`@
M("`@("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@("`@("1V86QU
M92`N/2`D=&AI<RT^9V5T4W1R:6YG5&%B;&5%;G1R>2A834Q?5T)834PZ.DU"
M54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RDI.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?15A47S`Z"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E]%6%1?,3H*("`@("`@("`@("`@8V%S92!834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7T585%\R.@H@("`@("`@("`@("`@("`@+R\@4V5C
M=&EO;B`U+C@N-"XR"B`@("`@("`@("`@("`@("`D=F%L=64@+CT@)&EN<'5T
M6R1T:&ES+3Y?<W1R<&]S*RM=.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?14Y42519
M.@H@("`@("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XS"B`@("`@("`@
M("`@("`@("`D=F%L=64@+CT@)'1H:7,M/F5N=&ET>2A834Q?5T)834PZ.DU"
M54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RDI.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?4U127TDZ"B`@("`@("`@("`@("`@("`O+R!396-T:6]N
M(#4N."XT+C$*("`@("`@("`@("`@("`@("1V86QU92`N/2`D=&AI<RT^=&5R
M;7-T<B@D:6YP=70I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U127U0Z"B`@("`@
M("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C$*("`@("`@("`@("`@("`@
M("1V86QU92`N/2`D=&AI<RT^9V5T4W1R:6YG5&%B;&5%;G1R>2A834Q?5T)8
M34PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RDI.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%A-3%]7
M0EA-3%]'3$]"04Q?5$]+14Y?3U!!455%.@H@("`@("`@("`@("`@("`@+R\@
M4V5C=&EO;B`U+C@N-"XV"B`@("`@("`@("`@("`@("`D<VEZ92`](%A-3%]7
M0EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*3L*
M("`@("`@("`@("`@("`@("1B(#T@<W5B<W1R*"1I;G!U="P@)'1H:7,M/E]S
M=')P;W,L("1T:&ES+3Y?<W1R<&]S("L@)'-I>F4I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S=')P;W,@*ST@)'-I>F4["@H@("`@("`@("`@("`@("`@
M)'9A;'5E("X]("1B.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?14Y$.@H@("`@("`@
M("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XW+C$*("`@("`@("`@("`@("`@
M("1H87--;W)E071T<FEB=71E<R`](&9A;'-E.PH@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1A='1R*2D@>PH@("`@("`@("`@("`@("`@("`@("1A='1R
M<UM=(#T@87)R87DH)V%T=')I8G5T92<@/3X@)&%T='(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35TE40TA?
M4$%'13H*("`@("`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-RXR"B`@
M("`@("`@("`@("`@("`D8V]D95!A9V4@/2`D=&AI<RT^9V5T0GET92@D:6YP
M=70I.PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!R979!='1R:6)U
M=&5$5$0I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!R979!='1R
M:6)U=&5$5$0@/2`D=&AI<RT^7V%T=')I8G5T94141#L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^<W=I=&-H071T<FEB=71E
M0V]D95!A9V4H)&-O9&5086=E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(&EF("@D=&]K
M96X@/B`Q,C@I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T
M='(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R<UM=(#T@87)R
M87DH)V%T=')I8G5T92<@/3X@)&%T='(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D=F%L=64I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D871T<B`]
M("1T:&ES+3Y?871T<FEB=71E1%1$+3YT;T%T=')I8G5T92@D=&]K96XI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O
M+R!686QU92X*("`@("`@("`@("`@("`@("`@("`D=F%L=64@+CT@)'1H:7,M
M/E]A='1R:6)U=&5$5$0M/G1O071T<FEB=71E*"1T;VME;BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^7W!R979!='1R:6)U
M=&5$5$0I('L*("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5$5$0@/2`D
M=&AI<RT^7W!R979!='1R:6)U=&5$5$0["B`@("`@("`@("`@("1T:&ES+3Y?
M<')E=D%T=')I8G5T94141"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/G-T;W!'971!='1R:6)U=&5S*"D["B`@("!]"@H@("`@9G5N8W1I
M;VX@<W1A<G1'971!='1R:6)U=&5S*"D*("`@('L*("`@("`@("`D=&AI<RT^
M7VES071T<FEB=71E(#T@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!S=&]P
M1V5T071T<FEB=71E<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I<T%T=')I
M8G5T92`](&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-U<G)E;G15
M4DDH*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VES071T<FEB=71E*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1A9T141"T^9V5T55))*"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M871T<FEB=71E1%1$+3YG97154DDH*3L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@=W)I=&53=')I;F<H)'-T<BD*("`@('L*("`@("`@("`D=&AI
M<RT^7V-H+3YC:&%R86-T97)S*"1S='(I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%1A9R@D=&%G*0H@("`@>PH@("`@("`@("\O(%-H;W5L9"!K;F]W('=H
M:6-H('-T871E(&ET(&ES(&EN+@H@("`@("`@(')E='5R;B`D=&AI<RT^7W1A
M9T141"T^=&]486=3='(H)'1A9RD["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M071T<FEB=71E*"1A='1R:6)U=&4I"B`@("!["B`@("`@("`@+R\@4VAO=6QD
M(&MN;W<@=VAI8V@@<W1A=&4@:70@:7,@:6XN"B`@("`@("`@)'1H:7,M/E]A
M='1R:6)U=&5$5$0M/G1O071T<FEB=71E26YT*"1A='1R:6)U=&4I.PH@("`@
M?0H*("`@(&9U;F-T:6]N('-W:71C:$5L96UE;G1#;V1E4&%G92@D8V]D95!A
M9V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]T86=$5$0@/2`F)'1H:7,M/E]D
M=&1-86YA9V5R+3YG971);G-T86YC92@D=&AI<RT^7W1A9T141"T^=&]#;V1E
M4&%G95-T<B@D8V]D95!A9V4I*3L*("`@("`@("`D=&AI<RT^<W=I=&-H071T
M<FEB=71E0V]D95!A9V4H)&-O9&5086=E*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!S=VET8VA!='1R:6)U=&5#;V1E4&%G92@D8V]D95!A9V4I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]A='1R:6)U=&5$5$0@/2`F)'1H:7,M/E]D=&1-86YA
M9V5R+3YG971);G-T86YC92@D=&AI<RT^7V%T=')I8G5T94141"T^=&]#;V1E
M4&%G95-T<B@D8V]D95!A9V4I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@:&5X('9E<G-I;VX@;V8@=&AE(&)A<V4@,3`@)&5N=&ET>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@96YT:71Y*"1E;G1I='DI"B`@("!["B`@
M("`@("`@<F5T=7)N(&1E8VAE>"@D96YT:71Y*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E861S(&$@;G5L;"!T97)M:6YA=&5D('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@=&5R;7-T<B@D:6YP=70I"B`@("!["B`@("`@("`@
M)'-T<B`]("<C)SL@+R\@;75S="!S=&%R="!W:71H(&YO;F5M<'1Y('-T<FEN
M9R!T;R!A;&QO=R!A<G)A>2!A8V-E<W,*("`@("`@("`D:2`](#`["B`@("`@
M("`@)&-H(#T@)&EN<'5T6R1T:&ES+3Y?<W1R<&]S*RM=.PH@("`@("`@(&EF
M("AO<F0H)&-H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G)SL@+R\@
M9&]N)W0@<F5T=7)N("<C)PH@("`@("`@('T*("`@("`@("!W:&EL92`H;W)D
M*"1C:"D@(3T@,"D@>PH@("`@("`@("`@("`D<W1R6R1I*RM=(#T@)&-H.PH@
M("`@("`@("`@("`D8V@@/2`D:6YP=71;)'1H:7,M/E]S=')P;W,K*UT["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'-T<CL*("`@('T*"GT*"@``````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO4U9'+G!H<```````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3,R,38`
M,3`U,34T,S$P-C``,#$V-S<Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!834Q?4U9'"B`J"B`J(%=R
M87!P97(@8VQA<W,@=&AA="!P<F]V:61E<R!S;VUE(&5X86UP;&5S(&%N9"!A
M(&9E=R!C;VYV96YI96YC90H@*B!M971H;V1S+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]834Q?4U9'+U-61RYP:'`L=B`Q+C$W+C$P+C0@,C`P-B\P,2\P
M,2`R,3HR.#HT-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D<@
M>PH*("`@(&9U;F-T:6]N(&5X86UP;&4H*0H@("`@>PH@("`@("`@("\O($-R
M96%T92!A;B!I;G-T86YC92!O9B!834Q?4U9'7T1O8W5M96YT+B!!;&P@;W1H
M97(@;V)J96-T<PH@("`@("`@("\O('=I;&P@8F4@861D960@=&\@=&AI<R!I
M;G-T86YC92!F;W(@<')I;G1I;F<N(%-E="!T:&4@:&5I9VAT"B`@("`@("`@
M+R\@86YD('=I9'1H(&]F('1H92!V:65W<&]R="X*("`@("`@("`D<W9G(#T@
M)FYE=R!834Q?4U9'7T1O8W5M96YT*&%R<F%Y*"=W:61T:"<@/3X@-#`P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE
M:6=H="<@/3X@,C`P*2D["@H@("`@("`@("\O($-R96%T92!A;B!I;G-T86YC
M92!O9B!834Q?4U9'7T=R;W5P+B!3970@=&AE('-T>6QE+`H@("`@("`@("\O
M('1R86YS9F]R;7,@9F]R(&-H:6QD(&]B:F5C=',N"B`@("`@("`@)&<@/2`F
M;F5W(%A-3%]35D=?1W)O=7`H87)R87DH)W-T>6QE)R`]/B`G<W1R;VME.F)L
M86-K)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=')A;G-F;W)M)R`]/B`G=')A;G-L871E*#(P,"`Q,#`I)RDI.PH*("`@("`@
M("`O+R!!9&0@82!P87)E;G0@=&\@=&AE(&<@:6YS=&%N8V4N"B`@("`@("`@
M)&<M/F%D9%!A<F5N="@D<W9G*3L*"B`@("`@("`@+R\@5&AE('-A;64@<F5S
M=6QT<R!C86X@8F4@86-C;VUP;&ES:&5D(&)Y(&UA:VEN9R!G(&$@8VAI;&0@
M;V8@=&AE('-V9RX*("`@("`@("`O+R`D<W9G+3YA9&1#:&EL9"@D9RD["@H@
M("`@("`@("\O($-R96%T92!A;F0@86YI;6%T92!A(&-I<F-L92X*("`@("`@
M("`D8VER8VQE(#T@)FYE=R!834Q?4U9'7T-I<F-L92AA<G)A>2@G8W@G(#T^
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8WDG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<B<@/3X@,3`P+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`G<W1R;VME+7=I9'1H
M.C,G*2D["B`@("`@("`@)&-I<F-L92T^861D0VAI;&0H;F5W(%A-3%]35D=?
M06YI;6%T92AA<G)A>2@G871T<FEB=71E3F%M92<@/3X@)W(G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%T=')I8G5T951Y<&4G(#T^("=834PG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9R;VTG(#T^(#`L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=&\G(#T^(#<U+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1U<B<@/3X@)S-S)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=F:6QL)R`]/B`G9G)E97IE)RDI*3L*("`@("`@("`D8VER8VQE+3YA
M9&1#:&EL9"AN97<@6$U,7U-61U]!;FEM871E*&%R<F%Y*"=A='1R:6)U=&5.
M86UE)R`]/B`G9FEL;"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E5'EP92<@/3X@)T-3
M4R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9G)O;2<@/3X@)V=R965N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T;R<@/3X@
M)W)E9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9'5R)R`]/B`G,W,G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&PG(#T^
M("=F<F5E>F4G*2DI.PH*("`@("`@("`O+R!-86ME('1H92!C:7)C;&4@82!C
M:&EL9"!O9B!G+@H@("`@("`@("1G+3YA9&1#:&EL9"@D8VER8VQE*3L*"B`@
M("`@("`@+R\@0W)E871E(&%N9"!A;FEM871E('-O;64@=&5X="X*("`@("`@
M("`D=&5X="`]("9N97<@6$U,7U-61U]497AT*&%R<F%Y*"=T97AT)R`]/B`G
M4U9'(&-H87)T(2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=X)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G>2<@/3X@,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`G9F]N="US:7IE.C(P.W1E>'0M
M86YC:&]R.FUI9&1L93LG*2D["B`@("`@("`@)'1E>'0M/F%D9$-H:6QD*&YE
M=R!834Q?4U9'7T%N:6UA=&4H87)R87DH)V%T=')I8G5T94YA;64G(#T^("=F
M;VYT+7-I>F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=A='1R:6)U=&54>7!E)R`]/B`G875T;R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V9R;VTG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1O)R`]/B`R,"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9'5R)R`]
M/B`G,W,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=F:6QL)R`]/B`G9G)E97IE)RDI*3L*"B`@("`@("`@
M+R\@36%K92!T:&4@=&5X="!A(&-H:6QD(&]F(&<N"B`@("`@("`@)&<M/F%D
M9$-H:6QD*"1T97AT*3L*"B`@("`@("`@+R\@4V5N9"!A(&UE<W-A9V4@=&\@
M=&AE('-V9R!I;G-T86YC92!T;R!S=&%R="!P<FEN=&EN9RX*("`@("`@("`D
M<W9G+3YP<FEN=$5L96UE;G0H*3L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'
M7T5L96UE;G0*("H*("H@5&AI<R!I<R!T:&4@8F%S92!C;&%S<R!F;W(@=&AE
M(&1I9F9E<F5N="!35D<@16QE;65N=`H@*B!/8FIE8W1S+B!%>'1E;F0@=&AI
M<R!C;&%S<R!T;R!C<F5A=&4@82!N97<@4U9'($5L96UE;G0N"B`J"B`J($!P
M86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?16QE;65N="!["@H@
M("`@=F%R("1?96QE;65N=',@/2!N=6QL.PH@("`@=F%R("1?<W1Y;&4@/2!N
M=6QL.PH@("`@=F%R("1?=')A;G-F;W)M(#T@;G5L;#L*("`@('9A<B`D7VED
M(#T@;G5L;#L*"B`@("!F=6YC=&EO;B!834Q?4U9'7T5L96UE;G0H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D<"`]/B`D=BD@>PH@("`@("`@("`@("`D<&%R86T@/2`G7R<@+B`D<#L*
M("`@("`@("`@("`@)'1H:7,M/B1P87)A;2`]("1V.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($UO<W0@4U9'(&5L96UE;G1S(&-A;B!C;VYT
M86EN(&-H:6QD(&5L96UE;G1S+B!4:&ES(&UE=&AO9"!C86QL<PH@("`@("H@
M=&AE('!R:6YT16QE;65N="!M971H;V0@;V8@86YY(&-H:6QD(&5L96UE;G0@
M861D960@=&\@=&AI<PH@("`@("H@;V)J96-T(&)Y('5S92!O9B!T:&4@861D
M0VAI;&0@;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE
M;G0H*0H@("`@>PH@("`@("`@("\O($QO;W`@86YD(&-A;&PN"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?96QE;65N=',@87,@)&-H:6QD*2!["B`@("`@
M("`@("`@("`@("`D8VAI;&0M/G!R:6YT16QE;65N="@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!M971H
M;V0@861D<R!A;B!O8FIE8W0@<F5F97)E;F-E("AO<B!V86QU92P@:68@)&-O
M<'D@:7,*("`@("`J('1R=64I('1O('1H92!?96QE;65N=',@87)R87DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9$-H:6QD*"8D96QE;65N="P@)&-O<'D@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&-O<'DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]E;&5M96YT<UM=(#T@)B1E;&5M96YT+3YC;W!Y*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]E;&5M96YT<UM=
M(#T@)B1E;&5M96YT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H:7,@;65T:&]D('-E;F1S(&$@;65S<V%G92!T;R!T:&4@<&%S<V5D(&5L
M96UE;G0@<F5Q=65S=&EN9R!T;PH@("`@("H@8F4@861D960@87,@82!C:&EL
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&%R96YT*"8D<&%R96YT*0H@
M("`@>PH@("`@("`@(&EF("AI<U]S=6)C;&%S<U]O9B@D<&%R96YT+"`G6$U,
M7U-61U]%;&5M96YT)RDI('L*("`@("`@("`@("`@)'!A<F5N="T^861D0VAI
M;&0H)'1H:7,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!C;W!Y
M*"D*("`@('L*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R
M<VEO;B@I+"`G,B<L("<^)RDI('L*("`@("`@("`@("`@<F5T=7)N(&-L;VYE
M*"1T:&ES*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D>&UL7W-V
M9R`]("1T:&ES.PH@("`@("`@("`@("!R971U<FX@)'AM;%]S=F<["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4')I;G0@96%C:"!O9B!T:&4@
M<&%S<V5D('!A<F%M971E<G,L(&EF('1H97D@87)E('-E="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<')I;G1087)A;7,H*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*&9U;F-?9V5T7V%R9W,H*2!A<R`D<&%R86TI('L*("`@("`@("`@("`@
M)%]P87)A;2`]("=?)R`N("1P87)A;3L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3XD7W!A<F%M*2D@>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D
M<&%R86TI('L*("`@("`@("`@("`@("`@(&-A<V4@)V9I;'1E<B<Z"B`@("`@
M("`@("`@("`@("`@("`@96-H;R`G(&9I;'1E<CTB=7)L*",G("X@)'1H:7,M
M/B1?<&%R86T@+B`G*2(G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@
M96-H;R`G("<@+B!S=')?<F5P;&%C92@G7R<L("<M)RP@)'!A<F%M*2`N("<]
M(B<@+B`D=&AI<RT^)%]P87)A;2`N("<B)SL*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O+R!3970@86YY(&YA;65D(&%T=')I8G5T92!O
M9B!A;B!E;&5M96YT('1O(&$@=F%L=64N"B`@("!F=6YC=&EO;B!S971087)A
M;2@D<&%R86TL("1V86QU92D*("`@('L*("`@("`@("`D871T<B`]("=?)R`N
M("1P87)A;3L*("`@("`@("`D=&AI<RT^)&%T='(@/2`D=F%L=64["B`@("!]
M"@H@("`@+R\@1V5T(&%N>2!N86UE9"!A='1R:6)U=&4@;V8@86X@96QE;65N
M="X*("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1P87)A;2D*("`@('L*("`@("`@
M("`D871T<B`]("=?)R`N("1P87)A;3L*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/B1A='1R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/B1A='1R
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!0<FEN="!O=70@=&AE(&]B:F5C="!F
M;W(@9&5B=6=G:6YG+@H@("`@9G5N8W1I;VX@9&5B=6<H*0H@("`@>PH@("`@
M("`@(&5C:&\@)SQP<F4^)SL@=F%R7V1U;7`H)'1H:7,I.R!E8VAO("<\+W!R
M93XG.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?1G)A9VUE;G0*("H*("H@
M0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]&<F%G;65N="!E
M>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?=VED=&@["B`@
M("!V87(@)%]H96EG:'0["B`@("!V87(@)%]V:65W0F]X.PH@("`@=F%R("1?
M>#L*("`@('9A<B`D7WD["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*
M("`@('L*("`@("`@("!E8VAO("<\<W9G)SL*("`@("`@("`D=&AI<RT^<')I
M;G1087)A;7,H)VED)RP@)W=I9'1H)RP@)VAE:6=H="<L("=X)RP@)WDG+"`G
M=FEE=T)O>"<L("=S='EL92<I.PH@("`@("`@(&5C:&\@)R!X;6QN<STB:'1T
M<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B('AM;&YS.GAL:6YK/2)H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(CXG("X@(EQN(CL*("`@("`@("!P87)E
M;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@(&5C:&\@(CPO<W9G/EQN(CL*
M("`@('T*"B`@("!F=6YC=&EO;B!B=69F97)/8FIE8W0H*0H@("`@>PH@("`@
M("`@(&]B7W-T87)T*"D["B`@("`@("`@)'1H:7,M/G!R:6YT16QE;65N="@I
M.PH@("`@("`@("1O=71P=70@/2!O8E]G971?8V]N=&5N=',H*3L*("`@("`@
M("!O8E]E;F1?8VQE86XH*3L*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@
M("!]"GT*"B\J*@H@*B!834Q?4U9'7T1O8W5M96YT"B`J"B`J(%1H:7,@97AT
M96YD<R!T:&4@6$U,7U-61U]&<F%G;65N="!C;&%S<RX@270@=W)A<',@=&AE
M(%A-3%]35D=?1G)A;65N="!O=71P=70*("H@=VET:"!A(&-O;G1E;G0@:&5A
M9&5R+"!X;6P@9&5F:6YI=&EO;B!A;F0@9&]C='EP92X*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]$;V-U;65N="!E>'1E;F1S
M(%A-3%]35D=?1G)A9VUE;G0@>PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N
M="@I"B`@("!["B`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z(&EM86=E
M+W-V9RMX;6PG*3L*"B`@("`@("`@<')I;G0H)SP_>&UL('9E<G-I;VX](C$N
M,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SXG+B)<;B(I.PH@("`@("`@('!R
M:6YT*"<\(41/0U194$4@<W9G(%!50DQ)0R`B+2\O5S-#+R]$5$0@4U9'(#$N
M,"\O14XB"@D@("`@("`@(")H='1P.B\O=W=W+G<S+F]R9R]44B\R,#`Q+U)%
M0RU35D<M,C`P,3`Y,#0O1%1$+W-V9S$P+F1T9"(^)R`N(")<;B(I.PH*("`@
M("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@?0H*?0H*+RHJ"B`J
M(%A-3%]35D=?1W)O=7`*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA
M<W,@6$U,7U-61U]'<F]U<"!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@
M("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO
M("<\9R<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=S='EL
M92<L("=T<F%N<V9O<FTG+"`G9FEL=&5R)RD["B`@("`@("`@<')I;G0H(CY<
M;B(I.PH@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@
M<')I;G0H(CPO9SY<;B(I.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?5&5X
M='!A=&@*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-6
M1U]497AT<&%T:"!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R
M("1?=&5X=#L*("`@('9A<B`D7W@["B`@("!V87(@)%]Y.PH@("`@=F%R("1?
M9'@["B`@("!V87(@)%]D>3L*("`@('9A<B`D7W)O=&%T93L*("`@('9A<B`D
M7W1E>'1,96YG=&@["B`@("!V87(@)%]L96YG=&A!9&IU<W0["B`@("!V87(@
M)%]C:&%R<V5T.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@D96QE;65N
M="`]("=T97AT<&%T:"<I"B`@("!["B`@("`@("`@96-H;R`G/"<@+B`D96QE
M;65N=#L*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W@G+"`G
M>2<L("=D>"<L("=D>2<L("=R;W1A=&4G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=&5X=$QE;F=T:"<L("=L96YG=&A!9&IU<W0G+"`G<W1Y;&4G
M+"`G=')A;G-F;W)M)RD["B`@("`@("`@96-H;R`G/B<["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?8VAA<G-E="DI('L*("`@("`@("`@("`@96-H;R!`
M:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7W1E>'0L($5.5%]#3TU0050L("1T
M:&ES+3Y?8VAA<G-E="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1T:&ES+3Y?=&5X="D["B`@("`@("`@
M?0H@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@96-H
M;R`B/"\D96QE;65N=#Y<;B(["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA
M<&4H)'@L("1Y+"`D=&5X="D*("`@('L*("`@("`@("`D=&AI<RT^7W@@/2`D
M>#L*("`@("`@("`D=&AI<RT^7WD@/2`D>3L*("`@("`@("`D=&AI<RT^7W1E
M>'0@/2`D=&5X=#L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U1E>'0*("H*
M("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]497AT(&5X
M=&5N9',@6$U,7U-61U]497AT<&%T:"!["@H@("`@9G5N8W1I;VX@<')I;G1%
M;&5M96YT*"D*("`@('L*("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@G
M=&5X="<I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1X+"`D>2P@
M)'1E>'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@)'@["B`@("`@("`@
M)'1H:7,M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]T97AT(#T@)'1E>'0[
M"B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]4<W!A;@H@*@H@*B!`<&%C:V%G
M92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U1S<&%N(&5X=&5N9',@6$U,
M7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]T97AT.PH@("`@=F%R("1?>#L*
M("`@('9A<B`D7WD["B`@("!V87(@)%]D>#L*("`@('9A<B`D7V1Y.PH@("`@
M=F%R("1?<F]T871E.PH@("`@=F%R("1?=&5X=$QE;F=T:#L*("`@('9A<B`D
M7VQE;F=T:$%D:G5S=#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@
M("`@>PH@("`@("`@(&5C:&\@)SQT<W!A;B<["B`@("`@("`@)'1H:7,M/G!R
M:6YT4&%R86US*"=I9"<L("=X)RP@)WDG+"`G9'@G+"`G9'DG+"`G<F]T871E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1E>'1,96YG=&@G+"`G
M;&5N9W1H061J=7-T)RP@)W-T>6QE)RP@)W1R86YS9F]R;2<I.PH@("`@("`@
M(&5C:&\@)SXG("X@)'1H:7,M/E]T97AT.PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!P87)E;G0Z.G!R
M:6YT16QE;65N="@I.PH@("`@("`@('T*("`@("`@("!E8VAO("(\+W1S<&%N
M/EQN(CL*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D>"P@)'DL("1T
M97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X.PH@("`@("`@("1T
M:&ES+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=&5X="`@/2`D=&5X=#L*
M("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T-I<F-L90H@*@H@*B!`<&%C:V%G
M92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T-I<F-L92!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?8W@["B`@("!V87(@)%]C>3L*
M("`@('9A<B`D7W(["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@
M('L*("`@("`@("!E8VAO("<\8VER8VQE)SL*"B`@("`@("`@)'1H:7,M/G!R
M:6YT4&%R86US*"=I9"<L("=C>"<L("=C>2<L("=R)RP@)W-T>6QE)RP@)W1R
M86YS9F]R;2<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE
M;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@
M86YD(&5N9"!T86<N"B`@("`@("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@
M("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@(&5C:&\@
M(CPO8VER8VQE/EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!0<FEN="!S:&]R="!T86<N"B`@("`@("`@("`@(&5C:&\@(B\^7&XB.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D8W@L("1C
M>2P@)'(I"B`@("!["B`@("`@("`@)'1H:7,M/E]C>"`]("1C>#L*("`@("`@
M("`D=&AI<RT^7V-Y(#T@)&-Y.PH@("`@("`@("1T:&ES+3Y?<B`@/2`D<CL*
M("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7TQI;F4*("H*("H@0'!A8VMA9V4@
M6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U],:6YE(&5X=&5N9',@6$U,7U-6
M1U]%;&5M96YT('L*"B`@("!V87(@)%]X,3L*("`@('9A<B`D7WDQ.PH@("`@
M=F%R("1?>#(["B`@("!V87(@)%]Y,CL*"B`@("!F=6YC=&EO;B!P<FEN=$5L
M96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQL:6YE)SL*("`@("`@("`D
M=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W@Q)RP@)WDQ)RP@)W@R)RP@)WDR
M)RP@)W-T>6QE)RD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE
M;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R
M="!A;F0@96YD('1A9RX*("`@("`@("`@("`@<')I;G0H(CY<;B(I.PH@("`@
M("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!P
M<FEN="@B/"]L:6YE/EQN(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!P<FEN="@B+SY<
M;B(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D
M>#$L("1Y,2P@)'@R+"`D>3(I"B`@("!["B`@("`@("`@)'1H:7,M/E]X,2`]
M("1X,3L*("`@("`@("`D=&AI<RT^7WDQ(#T@)'DQ.PH@("`@("`@("1T:&ES
M+3Y?>#(@(#T@)'@R.PH@("`@("`@("1T:&ES+3Y?>3(@(#T@)'DR.PH@("`@
M?0H*?0H*+RHJ"B`J(%A-3%]35D=?4F5C=`H@*@H@*B!`<&%C:V%G92!834Q?
M4U9'"B`J+PIC;&%S<R!834Q?4U9'7U)E8W0@97AT96YD<R!834Q?4U9'7T5L
M96UE;G0@>PH*("`@('9A<B`D7W@["B`@("!V87(@)%]Y.PH@("`@=F%R("1?
M=VED=&@["B`@("!V87(@)%]H96EG:'0["B`@("!V87(@)%]R>#L*("`@('9A
M<B`D7W)Y.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@
M("`@("`@96-H;R`G/')E8W0G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M
M<R@G:60G+"`G>"<L("=Y)RP@)W=I9'1H)RP@)VAE:6=H="<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R>"<L("=R>2<L("=S='EL92<I.PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@
M("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@
M("`@("`@("`@('!R:6YT*"(^7&XB*3L*("`@("`@("`@("`@<&%R96YT.CIP
M<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@<')I;G0H(CPO<F5C=#Y<;B(I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%!R:6YT('-H;W)T
M('1A9RX*("`@("`@("`@("`@<')I;G0H(B\^7&XB*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'@L("1Y+"`D=VED=&@L("1H
M96EG:'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@)'@["B`@("`@("`@
M)'1H:7,M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]W:61T:"`@/2`D=VED
M=&@["B`@("`@("`@)'1H:7,M/E]H96EG:'0@(#T@)&AE:6=H=#L*("`@('T*
M"GT*"B\J*@H@*B!834Q?4U9'7T5L;&EP<V4*("H*("H@0'!A8VMA9V4@6$U,
M7U-61PH@*B\*8VQA<W,@6$U,7U-61U]%;&QI<'-E(&5X=&5N9',@6$U,7U-6
M1U]%;&5M96YT('L*"B`@("!V87(@)%]C>#L*("`@('9A<B`D7V-Y.PH@("`@
M=F%R("1?<G@["B`@("!V87(@)%]R>3L*"B`@("!F=6YC=&EO;B!P<FEN=$5L
M96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQE;&QI<'-E)SL*("`@("`@
M("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)V-X)RP@)V-Y)RP@)W)X)RP@
M)W)Y)RP@)W-T>6QE)RP@)W1R86YS9F]R;2<I.PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN
M="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@("`@('!R
M:6YT*"(^7&XB*3L*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H
M*3L*("`@("`@("`@("`@<')I;G0H(CPO96QL:7!S93Y<;B(I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O(%!R:6YT('-H;W)T('1A9RX*("`@
M("`@("`@("`@<')I;G0H(B`O/EQN(BD["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N('-E=%-H87!E*"1C>"P@)&-Y+"`D<G@L("1R>2D*("`@('L*
M("`@("`@("`D=&AI<RT^7V-X(#T@)&-X.PH@("`@("`@("1T:&ES+3Y?8WD@
M/2`D8WD["B`@("`@("`@)'1H:7,M/E]R>"`@/2`D<G@["B`@("`@("`@)'1H
M:7,M/E]R>2`@/2`D<GD["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]0;VQY
M;&EN90H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'
M7U!O;'EL:6YE(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@
M)%]P;VEN=',["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*
M("`@("`@("!E8VAO("<\<&]L>6QI;F4G.PH@("`@("`@("1T:&ES+3YP<FEN
M=%!A<F%M<R@G:60G+"`G<&]I;G1S)RP@)W-T>6QE)RP@)W1R86YS9F]R;2<I
M.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*
M("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@
M=&%G+@H@("`@("`@("`@("!P<FEN="@B/EQN(BD["B`@("`@("`@("`@('!A
M<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@('!R:6YT*"(\+W!O
M;'EL:6YE/EQN(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!P<FEN="@B+SY<;B(I.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D<&]I;G1S
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&]I;G1S(#T@)'!O:6YT<SL*("`@
M('T*"GT*"B\J*@H@*B!834Q?4U9'7U!O;'EG;VX*("H*("H@0'!A8VMA9V4@
M6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]0;VQY9V]N(&5X=&5N9',@6$U,
M7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]P;VEN=',["@H@("`@9G5N8W1I
M;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\<&]L>6=O
M;B<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=P;VEN=',G
M+"`G<W1Y;&4G+"`G=')A;G-F;W)M)RD["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H
M:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@<')I;G0H
M(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@
M("`@("`@("`@("!P<FEN="@B/"]P;VQY9V]N/EQN(BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@
M("`@("!P<FEN="@B+SY<;B(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!S9713:&%P92@D<&]I;G1S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&]I;G1S(#T@)'!O:6YT<SL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U!A
M=&@*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]0
M871H(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]D.PH*
M("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H
M;R`G/'!A=&@G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G
M9"<L("=S='EL92<L("=T<F%N<V9O<FTG*3L*("`@("`@("!I9B`H:7-?87)R
M87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@
M8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!P<FEN
M="@B/EQN(BD["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D[
M"B`@("`@("`@("`@('!R:6YT*"(\+W!A=&@^7&XB*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O+R!0<FEN="!S:&]R="!T86<N"B`@("`@("`@
M("`@('!R:6YT*"(O/EQN(BD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N('-E=%-H87!E*"1D*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9"`]("1D
M.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?26UA9V4*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]);6%G92!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?>#L*("`@('9A<B`D7WD["B`@
M("!V87(@)%]W:61T:#L*("`@('9A<B`D7VAE:6=H=#L*("`@('9A<B`D7VAR
M968["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@
M("!E8VAO("<\:6UA9V4G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G
M:60G+"`G>"<L("=Y)RP@)W=I9'1H)RP@)VAE:6=H="<L("=S='EL92<I.PH@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]H<F5F*2D@>PH@("`@("`@("`@
M("!E8VAO("<@>&QI;FLZ:')E9CTB)R`N("1T:&ES+3Y?:')E9B`N("<B)SL*
M("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N
M=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A
M;F0@96YD('1A9RX*("`@("`@("`@("`@96-H;R`B/EQN(CL*("`@("`@("`@
M("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@96-H;R`B
M/"]I;6%G93Y<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!E8VAO("(@+SY<;B(["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1X+"`D>2P@
M)'=I9'1H+"`D:&5I9VAT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X
M.PH@("`@("`@("1T:&ES+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=VED
M=&@@(#T@)'=I9'1H.PH@("`@("`@("1T:&ES+3Y?:&5I9VAT("`]("1H96EG
M:'0["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]!;FEM871E"B`J"B`J($!P
M86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?06YI;6%T92!E>'1E
M;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?871T<FEB=71E3F%M
M93L*("`@('9A<B`D7V%T=')I8G5T951Y<&4["B`@("!V87(@)%]F<F]M.PH@
M("`@=F%R("1?=&\["B`@("!V87(@)%]B96=I;CL*("`@('9A<B`D7V1U<CL*
M("`@('9A<B`D7V9I;&P["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*
M("`@('L*("`@("`@("!E8VAO("<\86YI;6%T92<["B`@("`@("`@)'1H:7,M
M/G!R:6YT4&%R86US*"=I9"<L("=A='1R:6)U=&5.86UE)RP@)V%T=')I8G5T
M951Y<&4G+"`G9G)O;2<L("=T;R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=B96=I;B<L("=D=7(G+"`G9FEL;"<I.PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN
M="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@("`@(&5C
M:&\@(CY<;B(["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D[
M"B`@("`@("`@("`@(&5C:&\@(CPO86YI;6%T93Y<;B(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@96-H;R`B("\^7&XB.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D871T<FEB=71E3F%M92P@)&%T
M=')I8G5T951Y<&4@/2`G)RP@)&9R;VT@/2`G)RP*("`@("`@("`@("`@("`@
M("`@("`@("1T;R`]("<G+"`D8F5G:6X@/2`G)RP@)&1U<B`]("<G+"`D9FEL
M;"`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?871T<FEB=71E3F%M92`]
M("1A='1R:6)U=&5.86UE.PH@("`@("`@("1T:&ES+3Y?871T<FEB=71E5'EP
M92`]("1A='1R:6)U=&54>7!E.PH@("`@("`@("1T:&ES+3Y?9G)O;2`@/2`D
M9G)O;3L*("`@("`@("`D=&AI<RT^7W1O(#T@)'1O.PH@("`@("`@("1T:&ES
M+3Y?8F5G:6X@/2`D8F5G:6X["B`@("`@("`@)'1H:7,M/E]D=7(@/2`D9'5R
M.PH@("`@("`@("1T:&ES+3Y?9FEL;"`]("1F:6QL.PH@("`@?0H*?0H*+RHJ
M"B`J(%A-3%]35D=?1FEL=&5R"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO
M"F-L87-S(%A-3%]35D=?1FEL=&5R(&5X=&5N9',@6$U,7U-61U]%;&5M96YT
M('L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@
M(&5C:&\@)SQF:6QT97(G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G
M:60G*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI
M('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E
M;F0@=&%G+@H@("`@("`@("`@("!E8VAO("(^7&XB.PH@("`@("`@("`@("!P
M87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!E8VAO("(\+V9I
M;'1E<CY<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`B
M("\^7&XB.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!A9&10<FEM
M:71I=F4H)'!R:6UI=&EV92P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI
M<RT^861D0VAI;&0H;F5W(%A-3%]35D=?1FEL=&5R4')I;6ET:79E*"1P<FEM
M:71I=F4L("1P87)A;7,I*3L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T9I
M;'1E<E!R:6UI=&EV90H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S
M<R!834Q?4U9'7T9I;'1E<E!R:6UI=&EV92!E>'1E;F1S(%A-3%]35D=?16QE
M;65N="!["@H@("`@=F%R("1?<')I;6ET:79E<R`](&%R<F%Y*"=";&5N9"<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T-O;&]R36%T<FEX)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G0V]M<&]N96YT5')A;G-F
M97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=#;VUP;W-I=&4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=#;VYV;VQV94UA=')I
M>"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T1I9F9U<V5,:6=H
M=&EN9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T1I<W!L86-E
M;65N=$UA<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T9L;V]D
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1V%U<W-I86Y";'5R
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G26UA9V4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=-97)G92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)TUO<G!H;VQO9WDG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=/9F9S970G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=3<&5C=6QA<DQI9VAT:6YG)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G5&EL92<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U1U<F)U;&5N8V4G*3L*"B`@("!V87(@)%]P<FEM:71I=F4["@H@
M("`@=F%R("1?:6X["B`@("!V87(@)%]I;C(["B`@("!V87(@)%]R97-U;'0[
M"B`@("!V87(@)%]X.PH@("`@=F%R("1?>3L*("`@('9A<B`D7V1X.PH@("`@
M=F%R("1?9'D["B`@("!V87(@)%]W:61T:#L*("`@('9A<B`D7VAE:6=H=#L*
M("`@('9A<B`D7VUO9&4["B`@("!V87(@)%]T>7!E.PH@("`@=F%R("1?=F%L
M=65S.PH@("`@=F%R("1?;W!E<F%T;W(["B`@("!V87(@)%]K,3L*("`@('9A
M<B`D7VLR.PH@("`@=F%R("1?:S,["B`@("!V87(@)%]K-#L*("`@('9A<B`D
M7W-U<F9A8V538V%L93L*("`@('9A<B`D7V1I9F9U<V5#;VYS=&%N=#L*("`@
M('9A<B`D7VME<FYE;%5N:71,96YG=&@["B`@("!V87(@)%]F;&]O<E]C;VQO
M<CL*("`@('9A<B`D7V9L;V]D7V]P86-I='D["@H@("`@9G5N8W1I;VX@6$U,
M7U-61U]&:6QT97)0<FEM:71I=F4H)'!R:6UI=&EV92P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@<&%R96YT.CI834Q?4U9'7T5L96UE;G0H
M)'!A<F%M<RD["B`@("`@("`@)'1H:7,M/E]P<FEM:71I=F4@/2`D<')I;6ET
M:79E.PH@("`@?0H*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("![
M"B`@("`@("`@)&YA;64@/2`G9F4G("X@)'1H:7,M/E]P<FEM:71I=F4["B`@
M("`@("`@96-H;R`G/"<@+B`D;F%M93L*("`@("`@("`D=&AI<RT^<')I;G10
M87)A;7,H)VED)RP@)W@G+"`G>2<L("=D>"<L("=D>2<L("=W:61T:"<L("=H
M96EG:'0G+"`G:6XG+"`G:6XR)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E<W5L="<L("=M;V1E)RP@)W1Y<&4G+"`G=F%L=65S)RP@)V]P97)A
M=&]R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)VLQ)RP@)VLR)RP@
M)VLS)RP@)VLT)RP@)W-U<F9A8V538V%L92<L("=S=&1$979I871I;VXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&EF9G5S94-O;G-T86YT)RP@
M)VME<FYE;%5N:71,96YG=&@G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9FQO;V1?8V]L;W(G+"`G9FQO;V1?;W!A8VET>2<I.PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("`O
M+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@
M("`@(&5C:&\@(CY<;B(["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M
M96YT*"D["B`@("`@("`@("`@(&5C:&\@)SPO)R`N("1N86UE("X@)SXG.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@)R\^)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W(@9F5-97)G92!E;&5M96YT
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D365R9V5.;V1E*"1I;BD*("`@
M('L*("`@("`@("`D=&AI<RT^861D0VAI;&0H;F5W(%A-3%]35D=?1FEL=&5R
M365R9V5.;V1E*&%R<F%Y*"=I;B<@/3X@)&EN*2DI.PH@("`@?0H*?0H*+RHJ
M"B`J(%A-3%]35D=?1FEL=&5R365R9V5.;V1E"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?1FEL=&5R365R9V5.;V1E(&5X=&5N
M9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]I;CL*"B`@("!F=6YC
M=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQF94UE
M<F=E3F]D92<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I;B<I.PH@
M("`@("`@(&5C:&\@)R\^)SL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U5S
M90H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U5S
M92!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?<WEM8F]L
M.PH*("`@(&9U;F-T:6]N(%A-3%]35D=?57-E*"1S>6UB;VPL("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('!A<F5N=#HZ6$U,7U-61U]%;&5M
M96YT*"1P87)A;7,I.PH@("`@("`@("1T:&ES+3Y?<WEM8F]L(#T@)'-Y;6)O
M;#L*("`@('T*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@
M("`@("`@(&5C:&\@)SQU<V4@>&QI;FLZ:')E9CTB(R<@+B`D=&AI<RT^7W-Y
M;6)O;"`N("<B+SXG.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?1&5F<PH@
M*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T1E9G,@
M97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@(&9U;F-T:6]N('!R:6YT
M16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/&1E9G,G.PH@("`@("`@
M("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y;&4G+"`G=')A;G-F;W)M
M)RD["B`@("`@("`@96-H;R`B/EQN(CL*("`@("`@("!P87)E;G0Z.G!R:6YT
M16QE;65N="@I.PH@("`@("`@(&5C:&\@(CPO9&5F<SY<;B(["B`@("!]"@I]
M"@HO*BH*("H@6$U,7U-61U]-87)K97(*("H*("H@0'!A8VMA9V4@6$U,7U-6
M1PH@*B\*8VQA<W,@6$U,7U-61U]-87)K97(@97AT96YD<R!834Q?4U9'7T5L
M96UE;G0@>PH*("`@('9A<B`D7W)E9E@["B`@("!V87(@)%]R9699.PH@("`@
M=F%R("1?;6%R:V5R56YI=',["B`@("!V87(@)%]M87)K97)7:61T:#L*("`@
M('9A<B`D7VUA<FME<DAE:6=H=#L*("`@('9A<B`D7V]R:65N=#L*"B`@("!F
M=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQM
M87)K97(G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<F5F
M6"<L("=R9699)RP@)VUA<FME<E5N:71S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUA<FME<E=I9'1H)RP@)VUA<FME<DAE:6=H="<L("=O<FEE
M;G0G*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI
M('L@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@
M("`@("`@("!P<FEN="@B/EQN(BD["B`@("`@("`@("`@('!A<F5N=#HZ<')I
M;G1%;&5M96YT*"D["B`@("`@("`@("`@('!R:6YT*"(\+VUA<FME<CY<;B(I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT*"(O/EQN(BD[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1R9698
M(#T@)R<L("1R9699(#T@)R<L("1M87)K97)5;FET<R`]("<G+`H@("`@("`@
M("`@("`@("`@("`@("`@)&UA<FME<E=I9'1H(#T@)R<L("1M87)K97)(96EG
M:'0@/2`G)RP@)&]R:65N="`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<F5F6"`]("1R9698.PH@("`@("`@("1T:&ES+3Y?<F5F62`@/2`D<F5F63L*
M("`@("`@("`D=&AI<RT^7VUA<FME<E5N:71S(#T@)&UA<FME<E5N:71S.PH@
M("`@("`@("1T:&ES+3Y?;6%R:V5R5VED=&@@/2`D;6%R:V5R5VED=&@["B`@
M("`@("`@)'1H:7,M/E]M87)K97)(96EG:'0@/2`D;6%R:V5R2&5I9VAT.PH@
M("`@("`@("1T:&ES+3Y?;W)I96YT(#T@)&]R:65N=#L*("`@('T*"GT*"B\J
M*@H@*B!834Q?4U9'7U1I=&QE"B`J"B`J($!P86-K86=E(%A-3%]35D<**B\*
M8VQA<W,@6$U,7U-61U]4:71L92!E>'1E;F1S(%A-3%]35D=?16QE;65N="![
M"@H@("`@=F%R("1?=&ET;&4["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT
M*"D*("`@('L*("`@("`@("!E8VAO("<\=&ET;&4G.PH@("`@("`@("1T:&ES
M+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y;&4G*3L*("`@("`@("!P<FEN="@B
M/EQN(BD["B`@("`@("`@<')I;G0H)'1H:7,M/E]T:71L92D["B`@("`@("`@
M<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("!P<FEN="@B/"]T:71L
M93Y<;B(I.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?1&5S8PH@*@H@*B!`
M<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T1E<V,@97AT96YD
M<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7V1E<V,["@H@("`@9G5N
M8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\9&5S
M8R<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=S='EL92<I
M.PH@("`@("`@(&5C:&\@)SXG("X@)'1H:7,M/E]D97-C.PH@("`@("`@('!A
M<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@96-H;R`B/"]D97-C/EQN
M(CL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U1R968*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]4<F5F(&5X=&5N9',@6$U,
M7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]T97AT.PH@("`@=F%R("1?>#L*
M("`@('9A<B`D7WD["B`@("!V87(@)%]D>#L*("`@('9A<B`D7V1Y.PH@("`@
M=F%R("1?<F]T871E.PH@("`@=F%R("1?=&5X=$QE;F=T:#L*("`@('9A<B`D
M7VQE;F=T:$%D:G5S=#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@
M("`@>PH@("`@("`@(&5C:&\@)SQT<F5F)SL*("`@("`@("`D=&AI<RT^<')I
M;G1087)A;7,H)VED)RP@)W@G+"`G>2<L("=D>"<L("=D>2<L("=R;W1A=&4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5X=$QE;F=T:"<L("=L
M96YG=&A!9&IU<W0G+"`G<W1Y;&4G*3L*("`@("`@("!E8VAO("<^)R`N("1T
M:&ES+3Y?=&5X=#L*("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@
M("`@("`@(&5C:&\@(CPO=')E9CY<;B(["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO5T)834PN<&AP````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(R,#8`
M,3`U,34T,S$P-C``,#$W,C$V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*BH*("H@0V]N<W1A;G1S(&%R92!F
M<F]M($)I;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!6
M97)S:6]N"B`J(#$N,RP@,C4@2G5L>2`R,#`Q(&9O=6YD(&%T(&AT='`Z+R]W
M=W<N=V%P9F]R=6TN;W)G"B`J+PH*+RHJ"B`J($9R;VT@-RXQ($=L;V)A;"!4
M;VME;G,N"B`J+PH*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-7
M251#2%]004=%)RP@,"D[("`O+R`P>#`P"F1E9FEN92@G6$U,7U="6$U,7T=,
M3T)!3%]43TM%3E]%3D0G+"`Q*3L@("`@("`@("`@+R\@,'@P,0ID969I;F4H
M)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?14Y42519)RP@,BD[("`@("`@("\O
M(#!X,#(*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]))RP@
M,RD[("`@("`@("`O+R`P>#`S"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]4
M3TM%3E],251%4D%,)RP@-"D[("`@("`@+R\@,'@P-`H*9&5F:6YE*"=834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S`G+"`V-"D[("`@("`O+R`P>#0P
M"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\Q)RP@-C4I
M.R`@("`@+R\@,'@T,0ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?
M15A47TE?,B<L(#8V*3L@("`@("\O(#!X-#(*9&5F:6YE*"=834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7U!))RP@-C<I.R`@("`@("`@("`O+R`P>#0S"F1E9FEN
M92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T,G+"`V."D[("`@
M+R\@,'@T-`H*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%]4
M7S`G+"`Q,C@I.R`@("`O+R`P>#@P"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]%6%1?5%\Q)RP@,3(Y*3L@("`@+R\@,'@X,0ID969I;F4H)UA-
M3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,B<L(#$S,"D[("`@("\O(#!X
M.#(*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]4)RP@,3,Q
M*3L@("`@("`O+R`P>#@S"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%
M3E],251%4D%,7T$G+"`Q,S(I.R`@+R\@,'@X-`H*9&5F:6YE*"=834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7T585%\P)RP@,3DR*3L@("`@("`O+R`P>$,P"F1E
M9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,2<L(#$Y,RD[("`@
M("`@+R\@,'A#,0ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A4
M7S(G+"`Q.30I.R`@("`@("\O(#!X0S(*9&5F:6YE*"=834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7T]005%512<L(#$Y-2D[("`@("`O+R`P>$,S"F1E9FEN92@G
M6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T%#)RP@,3DV*3L@+R\@
M,'A#-`H*+RHJ"B`J($YO="!S=7)E('=H97)E(&1E9FEN960N"B`J($%$1"!#
M2$%05$52"B`J+PID969I;F4H)T1025]$5$1?5TU,7S%?,"<L("<M+R]705!&
M3U)532\O1%1$(%=-3"`Q+C`O+T5.)RD["F1E9FEN92@G1%!)7T141%]75$%?
M,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@5U1!(#$N,"\O14XG*3L*9&5F:6YE
M*"=$4$E?1%1$7U=-3%\Q7S$G+"`G+2\O5T%01D]254TO+T141"!734P@,2XQ
M+R]%3B<I.PID969I;F4H)T1025]$5$1?4TE?,5\Q)RP@)RTO+U=!4$9/4E5-
M+R]$5$0@4TD@,2XQ+R]%3B<I.PID969I;F4H)T1025]$5$1?4TQ?,5\P)RP@
M)RTO+U=!4$9/4E5-+R]$5$0@4TP@,2XP+R]%3B<I.PID969I;F4H)T1025]$
M5$1?0T]?,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@0T\@,2XP+R]%3B<I.PID
M969I;F4H)T1025]$5$1?0TA!3DY%3%\Q7S$G+"`G+2\O5T%01D]254TO+T14
M1"!#2$%.3D5,(#$N,2\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7U=-3%\Q7S(G
M+"`G+2\O5T%01D]254TO+T141"!734P@,2XR+R]%3B<I.PID969I;F4H)T10
M25]$5$1?5TU,7S%?,R<L("<M+R]705!&3U)532\O1%1$(%=-3"`Q+C,O+T5.
M)RD["F1E9FEN92@G1%!)7T141%]04D]67S%?,"<L("<M+R]705!&3U)532\O
M1%1$(%!23U8@,2XP+R]%3B<I.PID969I;F4H)T1025]$5$1?5U1!7U=-3%\Q
M7S(G+"`G+2\O5T%01D]254TO+T141"!75$$M5TU,(#$N,B\O14XG*3L*9&5F
M:6YE*"=$4$E?1%1$7T-(04Y.14Q?,5\R)RP@)RTO+U=!4$9/4E5-+R]$5$0@
M0TA!3DY%3"`Q+C(O+T5.)RD["F1E9FEN92@G1%!)7T141%]364Y#34Q?,5\P
M)RP@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C`O+T5.)RD["F1E9FEN92@G
M1%!)7T141%]$159)3D9?,5\P)RP@)RTO+U-93D--3"\O1%1$($1E=DEN9B`Q
M+C`O+T5.)RD["F1E9FEN92@G1%!)7T141%]364Y#34Q?,5\Q)RP@)RTO+U-9
M3D--3"\O1%1$(%-Y;F--3"`Q+C$O+T5.)RD["F1E9FEN92@G1%!)7T141%]$
M159)3D9?,5\Q)RP@)RTO+U-93D--3"\O1%1$($1E=DEN9B`Q+C$O+T5.)RD[
M"@HO*BH*("H@3VYL>2!D969A=6QT(&-H87)A8W1E<B!E;F-O9&EN9W,@9G)O
M;2!*,E-%(&%R92!C=7)R96YT;'D@<W5P<&]R=&5D+@H@*B\*9&5F:6YE*"=#
M2$%24T547U537T%30TE))RP@)U53+4%30TE))RD["F1E9FEN92@G0TA!4E-%
M5%])4T]?.#@U.5\Q)RP@)TE33RTX.#4Y+3$G*3L*9&5F:6YE*"=#2$%24T54
M7U541E\X)RP@)U541BTX)RD["F1E9FEN92@G0TA!4E-%5%]55$9?,39"12<L
M("=55$8M,39"12<I.PID969I;F4H)T-(05)3151?551&7S$V3$4G+"`G551&
M+3$V3$4G*3L*9&5F:6YE*"=#2$%24T547U541E\Q-B<L("=55$8M,38G*3L*
M"B\J*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M
M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+G!H<"QV(#$N,3,N,3(N."`R
M,#`V+S`S+S$S(#`Y.C$V.C(U(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!8
M34Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3"!["@H@("`@+RHJ"B`@("`@
M*B!$96-O9&EN9R!-=6QT:2UB>71E($EN=&5G97)S(&9R;VT@4V5C=&EO;B`U
M+C$*("`@("`J"B`@("`@*B!5<V4@;&]N9R!B96-A=7-E(&ET(&ES('5N<VEG
M;F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!-0E5);G0S,E1O26YT*"1I;BP@
M)B1P;W,I"B`@("!["B`@("`@("`@)'9A;"`](#`["@H@("`@("`@(&1O('L*
M("`@("`@("`@("`@)&(@/2!O<F0H)&EN6R1P;W,K*UTI.PH@("`@("`@("`@
M("`D=F%L(#P\/2`W.R`O+R!":71S:&EF="!L969T(#<@8FET<RX*("`@("`@
M("`@("`@)'9A;"`K/2`H)&(@)B`Q,C<I.PH@("`@("`@('T@=VAI;&4@*"@D
M8B`F(#$R."D@(3T@,"D["@H@("`@("`@(')E='5R;B`D=F%L.PH@("`@?0H*
M("`@("\J*@H@("`@("H@16YC;V1I;F<@375L=&DM8GET92!);G1E9V5R<R!F
M<F]M(%-E8W1I;VX@-2XQ"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN=%1O34)5
M26YT,S(H)B1O=70L("1I*0H@("`@>PH@("`@("`@(&EF("@D:2`^(#(V.#0S
M-30U-2D@>PH@("`@("`@("`@("`D8GET97,P(#T@,"!\(%A-3%]70EA-3#HZ
M9V5T0FET<R@P+"`D:2D["B`@("`@("`@("`@("1B>71E<S$@/2`Q,C@@?"!8
M34Q?5T)834PZ.F=E=$)I=',H,2P@)&DI.PH@("`@("`@("`@("`D8GET97,R
M(#T@,3(X('P@6$U,7U="6$U,.CIG971":71S*#(L("1I*3L*("`@("`@("`@
M("`@)&)Y=&5S,R`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET<R@S+"`D:2D[
M"B`@("`@("`@("`@("1B>71E<S0@/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I
M=',H-"P@)&DI.PH*("`@("`@("`@("`@)&]U="`N/2!C:'(H)&)Y=&5S-"D@
M+B!C:'(H)&)Y=&5S,RD@+B!C:'(H)&)Y=&5S,BD@+B!C:'(H)&)Y=&5S,2D@
M+B!C:'(H)&)Y=&5S,"D["B`@("`@("`@?2!E;'-E:68@*"1I(#X@,C`Y-S$U
M,2D@>PH@("`@("`@("`@("`D8GET97,P(#T@,"!\(%A-3%]70EA-3#HZ9V5T
M0FET<R@P+"`D:2D["B`@("`@("`@("`@("1B>71E<S$@/2`Q,C@@?"!834Q?
M5T)834PZ.F=E=$)I=',H,2P@)&DI.PH@("`@("`@("`@("`D8GET97,R(#T@
M,3(X('P@6$U,7U="6$U,.CIG971":71S*#(L("1I*3L*("`@("`@("`@("`@
M)&)Y=&5S,R`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET<R@S+"`D:2D["@H@
M("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,S*2`N(&-H<B@D8GET97,R
M*2`N(&-H<B@D8GET97,Q*2`N(&-H<B@D8GET97,P*3L*("`@("`@("!](&5L
M<V5I9B`H)&D@/B`Q-C,X,RD@>PH@("`@("`@("`@("`D8GET97,P(#T@,"!\
M(%A-3%]70EA-3#HZ9V5T0FET<R@P+"`D:2D["B`@("`@("`@("`@("1B>71E
M<S$@/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,2P@)&DI.PH@("`@("`@
M("`@("`D8GET97,R(#T@,3(X('P@6$U,7U="6$U,.CIG971":71S*#(L("1I
M*3L*"B`@("`@("`@("`@("1O=70@+CT@8VAR*"1B>71E<S(I("X@8VAR*"1B
M>71E<S$I("X@8VAR*"1B>71E<S`I.PH@("`@("`@('T@96QS96EF("@D:2`^
M(#$R-RD@>PH@("`@("`@("`@("`D8GET97,P(#T@,"!\(%A-3%]70EA-3#HZ
M9V5T0FET<R@P+"`D:2D["B`@("`@("`@("`@("1B>71E<S$@/2`Q,C@@?"!8
M34Q?5T)834PZ.F=E=$)I=',H,2P@)&DI.PH*("`@("`@("`@("`@)&]U="`N
M/2!C:'(H)&)Y=&5S,2D@+B!C:'(H)&)Y=&5S,"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&)Y=&5S,"`](#`@?"!834Q?5T)834PZ.F=E=$)I
M=',H,"P@)&DI.PH*("`@("`@("`@("`@)&]U="`N/2!C:'(H)&)Y=&5S,"D[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=$)I=',H)&YU;2P@
M)&PI"B`@("!["B`@("`@("`@<W=I=&-H("@D;G5M*2!["B`@("`@("`@8V%S
M92`P.@H@("`@("`@("`@("!R971U<FX@)&P@)B`Q,C<[("\O(#!X-T8*"B`@
M("`@("`@8V%S92`Q.@H@("`@("`@("`@("!R971U<FX@*"1L(#X^(#<I("8@
M,3(W.R`O+R`P>#=&"@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@<F5T
M=7)N("@D;"`^/B`Q-"D@)B`Q,C<[("\O(#!X-T8*"B`@("`@("`@8V%S92`S
M.@H@("`@("`@("`@("!R971U<FX@*"1L(#X^(#(Q*2`F(#$R-SL@+R\@,'@W
M1@H*("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@(')E='5R;B`H)&P@/CX@
M,C@I("8@,3(W.R`O+R`P>#=&"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M,#L*("`@('T*"B`@("!F=6YC=&EO;B!G971$4$E3=')I;F<H)&DI"B`@("![
M"B`@("`@("`@+RHJ"B`@("`@("`@("H@041$($-(05!415(*("`@("`@("`@
M*B\*("`@("`@("`D1%!)4W1R:6YG(#T@87)R87DH,B`]/B!$4$E?1%1$7U=-
M3%\Q7S`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#,@/3X@1%!)7T14
M1%]75$%?,5\P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`T(#T^($10
M25]$5$1?5TU,7S%?,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@-2`]
M/B!$4$E?1%1$7U-)7S%?,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M-B`]/B!$4$E?1%1$7U-,7S%?,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@-R`]/B!$4$E?1%1$7T-/7S%?,"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@."`]/B!$4$E?1%1$7T-(04Y.14Q?,5\Q+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Y(#T^($1025]$5$1?5TU,7S%?,BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,3`@/3X@1%!)7T141%]734Q?,5\S+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Q,2`]/B!$4$E?1%1$7U!23U9?,5\P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,B`]/B!$4$E?1%1$7U=4
M05]734Q?,5\R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,R`]/B!$
M4$E?1%1$7T-(04Y.14Q?,5\R+`H*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@3F]T(&%L;"!3>6YC34P@8VQI96YT<R!K;F]W('1H:7,L('-O('=E
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('-H;W5L9"!U<V4@=&AE
M('-T<FEN9R!T86)L92X*("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M,'A&1#$@/3X@1%!)7T141%]364Y#34Q?,5\Q+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`T,#0Y(#T^($1025]$5$1?4UE.0TU,7S%?,"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@-#`U,"`]/B!$4$E?1%1$7T1%5DE.1E\Q
M7S`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#0P-3$@/3X@1%!)7T14
M1%]364Y#34Q?,5\Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`T,#4R
M(#T^($1025]$5$1?1$5624Y&7S%?,2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*3L*("`@("`@("!R971U<FX@:7-S970H)$1025-T<FEN9ULD:5TI
M(#\@)$1025-T<FEN9ULD:5T@.B!N=6QL.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$1024EN="@D9'!I*0H@("`@>PH@("`@("`@("\J*@H@("`@("`@("`J
M($%$1"!#2$%05$52"B`@("`@("`@("HO"B`@("`@("`@)$1024EN="`](&%R
M<F%Y*$1025]$5$1?5TU,7S%?,"`]/B`R+`H@("`@("`@("`@("`@("`@("`@
M("`@("!$4$E?1%1$7U=405\Q7S`@/3X@,RP*("`@("`@("`@("`@("`@("`@
M("`@("`@1%!)7T141%]734Q?,5\Q(#T^(#0L"B`@("`@("`@("`@("`@("`@
M("`@("`@($1025]$5$1?4TE?,5\Q(#T^(#4L"B`@("`@("`@("`@("`@("`@
M("`@("`@($1025]$5$1?4TQ?,5\P(#T^(#8L"B`@("`@("`@("`@("`@("`@
M("`@("`@($1025]$5$1?0T]?,5\P(#T^(#<L"B`@("`@("`@("`@("`@("`@
M("`@("`@($1025]$5$1?0TA!3DY%3%\Q7S$@/3X@."P*("`@("`@("`@("`@
M("`@("`@("`@("`@1%!)7T141%]734Q?,5\R(#T^(#DL"B`@("`@("`@("`@
M("`@("`@("`@("`@($1025]$5$1?5TU,7S%?,R`]/B`Q,"P*("`@("`@("`@
M("`@("`@("`@("`@("`@1%!)7T141%]04D]67S%?,"`]/B`Q,2P*("`@("`@
M("`@("`@("`@("`@("`@("`@1%!)7T141%]75$%?5TU,7S%?,B`]/B`Q,BP*
M("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]#2$%.3D5,7S%?,B`]
M/B`Q,RP*"B`@("`@("`@("`@("`@("`@("`@("`@("\O($YO="!A;&P@4WEN
M8TU,(&-L:65N=',@:VYO=R!T:&ES+"!S;R!M87EB92!W90H@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!S:&]U;&0@=7-E('1H92!S=')I;F<@=&%B;&4N
M"B`@("`@("`@("`@("`@("`@("`@("`@($1025]$5$1?4UE.0TU,7S%?,"`]
M/B`T,#0Y+`H@("`@("`@("`@("`@("`@("`@("`@("!$4$E?1%1$7T1%5DE.
M1E\Q7S`@/3X@-#`U,"P*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T14
M1%]364Y#34Q?,5\Q(#T^(#0P-3$L"B`@("`@("`@("`@("`@("`@("`@("`@
M($1025]$5$1?1$5624Y&7S%?,2`]/B`T,#4R"B`@("`@("`@("`@("`@("`@
M("`@("`@("\O($1025]$5$1?4UE.0TU,7S%?,2`]/B`P>$9$,2P*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@1%!)7T141%]$159)3D9?,5\Q(#T^(#!X
M1D0R+`H@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("!R971U
M<FX@:7-S970H)$1024EN=%LD9'!I72D@/R`D1%!)26YT6R1D<&E=(#H@,#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)A8W1E<B!E
M;F-O9&EN9RX*("`@("`J(&]N;'D@9&5F875L="!C:&%R86-T97(@96YC;V1I
M;F=S(&9R;VT@2C)312!A<F4@<W5P<&]R=&5D"B`@("`@*B!F<F]M(&AT='`Z
M+R]W=W<N:6%N82YO<F<O87-S:6=N;65N=',O8VAA<F%C=&5R+7-E=',*("`@
M("`J(&%N9"!H='1P.B\O:F%V82YS=6XN8V]M+VHR<V4O,2XT+C(O9&]C<R]A
M<&DO:F%V82]N:6\O8VAA<G-E="]#:&%R<V5T+FAT;6P*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T0VAA<G-E=%-T<FEN9R@D8W,I"B`@("!["B`@("`@("`@
M+RHJ"B`@("`@("`@("H@1G)O;2!H='1P.B\O=W=W+FEA;F$N;W)G+V%S<VEG
M;FUE;G1S+V-H87)A8W1E<BUS971S"B`@("`@("`@("HO"B`@("`@("`@)&-H
M87)S9713=')I;F<@/2!A<G)A>2@S(#T^("=54RU!4T-)22<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`T(#T^("=)4T\M.#@U.2TQ)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$P-B`]/B`G551&+3@G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,3`Q,R`]/B`G551&+3$V
M0D4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,3`Q-"`]/B`G
M551&+3$V3$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,3`Q
M-2`]/B`G551&+3$V)RD["@H@("`@("`@(')E='5R;B!I<W-E="@D8VAA<G-E
M=%-T<FEN9ULD8W-=*2`_("1C:&%R<V5T4W1R:6YG6R1C<UT@.B!N=6QL.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C=&5R(&5N
M8V]D:6YG+@H@("`@("H*("`@("`J($]N;'D@9&5F875L="!C:&%R86-T97(@
M96YC;V1I;F=S(&9R;VT@2C)312!A<F4@<W5P<&]R=&5D+@H@("`@("H*("`@
M("`J($9R;VT@:'1T<#HO+W=W=RYI86YA+F]R9R]A<W-I9VYM96YT<R]C:&%R
M86-T97(M<V5T<R!A;F0*("`@("`J(&AT='`Z+R]J879A+G-U;BYC;VTO:C)S
M92\Q+C0N,B]D;V-S+V%P:2]J879A+VYI;R]C:&%R<V5T+T-H87)S970N:'1M
M;`H@("`@("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T26YT*"1C<RD*("`@
M('L*("`@("`@("`O*BH*("`@("`@("`@*B!&<F]M(&AT='`Z+R]W=W<N:6%N
M82YO<F<O87-S:6=N;65N=',O8VAA<F%C=&5R+7-E=',*("`@("`@("`@*B\*
M("`@("`@("`D8VAA<G-E=$EN="`](&%R<F%Y*"=54RU!4T-)22<@/3X@,RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=)4T\M.#@U.2TQ)R`]/B`T
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U541BTX)R`]/B`Q,#8L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G551&+3$V0D4G(#T^(#$P
M,3,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G551&+3$V3$4G(#T^
M(#$P,30L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G551&+3$V)R`]
M/B`Q,#$U*3L*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1C:&%R<V5T26YT6R1C
M<UTI(#\@)&-H87)S971);G1;)&-S72`Z(&YU;&P["B`@("!]"@I]"@HO*BH*
M("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?5T)834Q?2&%S
M:%1A8FQE('L*"B`@("!V87(@)%]H.PH*("`@(&9U;F-T:6]N('-E="@D:RP@
M)'8I"B`@("!["B`@("`@("`@)'1H:7,M/E]H6R1K72`]("1V.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E="@D:RD*("`@('L*("`@("`@("!R971U<FX@:7-S
M970H)'1H:7,M/E]H6R1K72D@/R`D=&AI<RT^7VA;)&M=(#H@;G5L;#L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O5D93+P``````````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q-38Q,P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+P``````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C``,#$W-#0R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+P``````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,C,R-S$`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO8V]P>2YP:'```````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S8Q`#$P-3$U-#,Q,#8P`#`R
M-#<V,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RHJ"B`J(%-T<F%T96=Y(&9O<B!W<FET:6YG(&9I;&4@=&\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2P@=&AE;B!C;W!Y:6YG('1O(%9&4RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP+'8@,2XQ+C@N-"`R,#`V+S`Q
M+S`Q(#(Q.C(X.C0T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\
M:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%9&4U])4T\*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!61E-?25-/5W)I=&5R7U)E
M86Q/=71P=713=')A=&5G>5]C;W!Y(&5X=&5N9',@5D937TE33U=R:71E<E]2
M96%L3W5T<'5T4W1R871E9WD@>PH*("`@('9A<B`D7W1E;7!&:6QE;F%M92`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!'970@82!R96%L(&9I;&5N86UE('1O
M('=H:6-H('=E(&-A;B!W<FET92X*("`@("`J"B`@("`@*B!);B!T:&ES(&EM
M<&QE;65N=&%T:6]N+"!W92!C<F5A=&4@86YD('-T;W)E(&$@=&5M<&]R87)Y
M(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971296%L1FEL96YA
M;64H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?=&5M<$9I
M;&5N86UE*2D@>PH*("`@("`@("`@("`@)'1M<%]L;V-A=&EO;G,@/2!A<G)A
M>2@G+W1M<"<L("<O=F%R+W1M<"<L("=C.EQ7551E;7`G+"`G8SI<=&5M<"<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V,Z7'=I;F1O
M=W-<=&5M<"<L("=C.EQW:6YN=%QT96UP)RD["@H@("`@("`@("`@("`O*B!&
M:7)S="P@=')Y(%!(4"=S('5P;&]A9%]T;7!?9&ER(&1I<F5C=&EV92X@*B\*
M("`@("`@("`@("`@)'1M<"`](&EN:5]G970H)W5P;&]A9%]T;7!?9&ER)RD[
M"@H@("`@("`@("`@("`O*B!/=&AE<G=I<V4L('1R>2!T;R!D971E<FUI;F4@
M=&AE(%1-4$1)4B!E;G9I<F]N;65N=`H@("`@("`@("`@("`@*B!V87)I86)L
M92X@*B\*("`@("`@("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@
M("`@("`@("`D=&UP(#T@9V5T96YV*"=435!$25(G*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@268@=V4@<W1I;&P@8V%N;F]T(&1E=&5R;6EN
M92!A('9A;'5E+"!T:&5N(&-Y8VQE('1H<F]U9V@@80H@("`@("`@("`@("`@
M*B!L:7-T(&]F('!R97-E="!P;W-S:6)I;&ET:65S+B`J+PH@("`@("`@("`@
M("!W:&EL92`H96UP='DH)'1M<"D@)B8@8V]U;G0H)'1M<%]L;V-A=&EO;G,I
M*2!["B`@("`@("`@("`@("`@("`D=&UP7V-H96-K(#T@87)R87E?<VAI9G0H
M)'1M<%]L;V-A=&EO;G,I.PH@("`@("`@("`@("`@("`@:68@*$!I<U]D:7(H
M)'1M<%]C:&5C:RDI('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)'1M
M<%]C:&5C:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D=&AI<RT^7W1E;7!&:6QE;F%M92`]('1E;7!N86TH)'1M<"P@)VES;R<I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&5M<$9I;&5N
M86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(&9I;FES:&5D*"D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]T96UP1FEL96YA;64I*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@D=&AI<RT^7W1E;7!&:6QE;F%M92DI('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R%>*"XJ
M*2\H6UXO72HI)"$G+"`D=&AI<RT^7W1A<F=E=$9I;&4L("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`D9&ER(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@
M("1F:6QE(#T@)&UA=&-H97-;,ET["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&1I<B`]("<G.PH@("`@("`@("`@("`D9FEL92`]("1T:&ES+3Y?
M=&%R9V5T1FEL93L*("`@("`@("!]"@H@("`@("`@("1R97,@/2`D=&AI<RT^
M7W1A<F=E=%9F<RT^=W)I=&4H)&1I<BP@)&9I;&4L("1T:&ES+3Y?=&5M<$9I
M;&5N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=')U92D["B`@("`@("`@0'5N;&EN:R@D=&AI<RT^7W1E;7!&:6QE;F%M
M92D["B`@("`@("`@)'1H:7,M/E]T96UP1FEL96YA;64@/2!N=6QL.PH@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@?0H*?0H*````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<```````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-3$T`#$P
M-3$U-#,Q,#8P`#`R-3(U,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RHJ"B`J(%-T<F%T96=Y(&9O<B!D:7)E
M8W1L>2!W<FET:6YG(&]U='!U="!F:6QE('1O(%9&4RX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V1I<F5C="YP:'`L=B`Q+C$N."XU(#(P,#8O,#$O,#$@,C$Z
M,C@Z-#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O
M;F]S>7,L($Q,0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E
M0&-R;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5D937TE33PH@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("HO"F-L87-S(%9&4U])4T]7<FET97)?4F5A;$]U='!U
M=%-T<F%T96=Y7V1I<F5C="!E>'1E;F1S(%9&4U])4T]7<FET97)?4F5A;$]U
M='!U=%-T<F%T96=Y('L*"B`@("!F=6YC=&EO;B!G971296%L1FEL96YA;64H
M*0H@("`@>PH@("`@("`@("\J(%-O('=E('-H;W5L9&XG="!B92!A8V-E<W-I
M;F<@7V=E=$YA=&EV95!A=&@H*2X@($EF('=E(&AA9"!R96%L"B`@("`@("`@
M("H@86-C97-S(&-O;G1R;VPL('1H870@=V]U;&0@8F4@<')O=&5C=&5D(&%N
M9"!W92=D(&)E(&$@9G)I96YD+"!A<PH@("`@("`@("`J('1H870@:7,@=&AE
M('!O:6YT(&]F('1H:7,@97AC97)C:7-E+B`J+PH@("`@("`@("1F:6QE;F%M
M92`]("1T:&ES+3Y?=&%R9V5T5F9S+3Y?9V5T3F%T:79E4&%T:"@D=&AI<RT^
M7W1A<F=E=$9I;&4I.PH*("`@("`@("`O*B!-86ME('-U<F4@=&AE('!A=&@@
M=&\@=&AE(&9I;&4@97AI<W1S+B`J+PH@("`@("`@("1D:7(@/2!D:7)N86UE
M*"1F:6QE;F%M92D["B`@("`@("`@=VAI;&4@*"%`:7-?9&ER*"1D:7(I*2![
M"B`@("`@("`@("`@(&EF("@A0&UK9&ER*"1D:7(L(#`W-34I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D:7(I*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D9&ER(#T@9&ER;F%M92@D9&ER*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL96YA;64["B`@("!]"@H@("`@
M9G5N8W1I;VX@9FEN:7-H960H*0H@("`@>PH@("`@("`@("\J($YO=&AI;F<@
M=&\@9&\N("HO"B`@("!]"@I]"@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+P``````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C``,#(S,#<P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'``````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,34Q-@`Q,#4Q-30S
M,3`V,``P,C0U-30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J*@H@*B!3=')A=&5G>2!F;W(@8V]P>6EN9R!I
M;G!U="!T<F5E(&]U="!O9B!A(%9&4PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<"QV(#$N,2XX+C4@,C`P-B\P,2\P,2`R,3HR.#HT-"!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH
M='1P.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M
M/@H@*B!`<&%C:V%G92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B\*8VQA<W,@5D937TE33U=R:71E<E]296%L26YP=713=')A=&5G>5]C;W!Y
M(&5X=&5N9',@5D937TE33U=R:71E<E]296%L26YP=713=')A=&5G>2!["@H@
M("`@=F%R("1?=&5M<%!A=&@@/2!N=6QL.PH*("`@(&9U;F-T:6]N(&=E=%)E
M86Q0871H*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W1E
M;7!0871H*2D@>PH@("`@("`@("`@("`D=&UP7VQO8V%T:6]N<R`](&%R<F%Y
M*"<O=&UP)RP@)R]V87(O=&UP)RP@)V,Z7%=55&5M<"<L("=C.EQT96UP)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8SI<=VEN9&]W
M<UQT96UP)RP@)V,Z7'=I;FYT7'1E;7`G*3L*"B`@("`@("`@("`@("\J($9I
M<G-T+"!T<GD@4$A0)W,@=7!L;V%D7W1M<%]D:7(@9&ER96-T:79E+B`J+PH@
M("`@("`@("`@("`D=&UP(#T@:6YI7V=E="@G=7!L;V%D7W1M<%]D:7(G*3L*
M"B`@("`@("`@("`@("\J($]T:&5R=VES92P@=')Y('1O(&1E=&5R;6EN92!T
M:&4@5$U01$E2(&5N=FER;VYM96YT"B`@("`@("`@("`@("`J('9A<FEA8FQE
M+B`J+PH@("`@("`@("`@("!I9B`H96UP='DH)'1M<"DI('L*("`@("`@("`@
M("`@("`@("1T;7`@/2!G971E;G8H)U1-4$1)4B<I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!)9B!W92!S=&EL;"!C86YN;W0@9&5T97)M:6YE
M(&$@=F%L=64L('1H96X@8WEC;&4@=&AR;W5G:"!A"B`@("`@("`@("`@("`J
M(&QI<W0@;V8@<')E<V5T('!O<W-I8FEL:71I97,N("HO"B`@("`@("`@("`@
M('=H:6QE("AE;7!T>2@D=&UP*2`F)B!C;W5N="@D=&UP7VQO8V%T:6]N<RDI
M('L*("`@("`@("`@("`@("`@("1T;7!?8VAE8VL@/2!A<G)A>5]S:&EF="@D
M=&UP7VQO8V%T:6]N<RD["B`@("`@("`@("`@("`@("!I9B`H0&ES7V1I<B@D
M=&UP7V-H96-K*2D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2`D=&UP
M7V-H96-K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H96UP='DH)'1M<"DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1T:&ES+3Y?=&5M<%!A=&@@/2!T96UP;F%M*"1T;7`L("=I<V]D)RD["B`@
M("`@("`@("`@($!U;FQI;FLH)'1H:7,M/E]T96UP4&%T:"D["@H@("`@("`@
M("`@("`D<F5S(#T@)'1H:7,M/E]C;W!Y5&]496UP4&%T:"@I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&5M<%!A=&@["B`@("!]"@H@("`@
M9G5N8W1I;VX@9FEN:7-H960H*0H@("`@>PH@("`@("`@(')E='5R;B!61E-?
M25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y7V-O<'DZ.E]R96UO=F5296-U
M<G-I=F4H)'1H:7,M/E]T96UP4&%T:"D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;6]V95)E8W5R<VEV92@D<&%T:"D*("`@('L*("`@("`@("`D9&@@/2!`
M;W!E;F1I<B@D<&%T:"D["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D9&@I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%T
M:"DI.PH@("`@("`@('T*("`@("`@("!W:&EL92`H*"1E;G0@/2!R96%D9&ER
M*"1D:"DI("$]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H)&5N="`]/2`G
M+B<@?'P@)&5N="`]/2`G+BXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9U;&P@/2!S<')I;G1F
M*"<E<R\E<R<L("1P871H+"`D96YT*3L*("`@("`@("`@("`@:68@*&ES7V1I
M<B@D9G5L;"DI('L*("`@("`@("`@("`@("`@("1R97,@/2!61E-?25-/5W)I
M=&5R7U)E86Q);G!U=%-T<F%T96=Y7V-O<'DZ.E]R96UO=F5296-U<G-I=F4H
M)&9U;&PI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@:68@*"%`=6YL:6YK*"1F=6QL*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U
M;&0@;F]T('5N;&EN:R!<(B5S7"(N(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9G5L;"DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&-L;W-E9&ER*"1D:"D["@H@("`@("`@(&EF("@A0')M9&ER*"1P871H*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(BDL("1F=6QL*2D["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]C;W!Y5&]496UP4&%T:"@I"B`@
M("!["B`@("`@("`@)&1I<E-T86-K(#T@87)R87DH)R<I.PH*("`@("`@("!W
M:&EL92`H8V]U;G0H)&1I<E-T86-K*2`^(#`I('L*("`@("`@("`@("`@)&1I
M<B`](&%R<F%Y7W-H:69T*"1D:7)3=&%C:RD["B`@("`@("`@("`@(&EF("AE
M;7!T>2@D9&ER*2D@>PH@("`@("`@("`@("`@("`@)'1A<F=E="`]("1T:&ES
M+3Y?=&5M<%!A=&@["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&%R9V5T(#T@<W!R:6YT9B@G)7,O)7,G+"`D=&AI<RT^7W1E;7!0
M871H+"`D9&ER*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(4!M
M:V1I<B@D=&%R9V5T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB
M+B(I+"`D=&%R9V5T*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S
M;W5R8V50871H(#T@)'1H:7,M/E]S;W5R8V52;V]T.PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1D:7(I*2!["B`@("`@("`@("`@("`@("`D<V]U<F-E4&%T
M:"`N/2`G+R<@+B`D9&ER.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M;&ES="`]("1T:&ES+3Y?<V]U<F-E5F9S+3YL:7-T1F]L9&5R*"1S;W5R8V50
M871H+"!N=6QL+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;&ES
M=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&QI<W0@
M87,@)&5N=')Y*2!["B`@("`@("`@("`@("`@("!I9B`H)&5N=')Y6R=T>7!E
M)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T
M>2@D9&ER*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&ER4W1A8VM;
M72`]("1E;G1R>5LG;F%M92==.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1D:7)3=&%C:UM=(#T@<W!R
M:6YT9B@G)7,O)7,G+"`D9&ER+"`D96YT<GE;)VYA;64G72D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D9&%T82`]("1T:&ES+3Y?<V]U<F-E5F9S+3YR96%D
M*"1S;W5R8V50871H+"`D96YT<GE;)VYA;64G72D["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)'1A<F=E=$9I;&4@/2!S
M<')I;G1F*"<E<R\E<R<L("1T87)G970L("1E;G1R>5LG;F%M92==*3L*("`@
M("`@("`@("`@("`@("`@("`D9F@@/2!`9F]P96XH)'1A<F=E=$9I;&4L("=W
M)RD["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]R97-O=7)C92@D9F@I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W
M<FET:6YG+B(I+"`D=&%R9V5T1FEL92DI.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!I9B`H9G=R:71E*"1F:"P@)&1A=&$I
M("$]('-T<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")%<G)O<B!W<FET
M:6YG(%PB)7-<(BXB*2P@)'1A<F=E=$9I;&4I*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F:"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V1I<F5C="YP:'``````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-#8`
M,3`U,34T,S$P-C``,#(U,#4T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*BH*("H@4W1R871E9WD@9F]R(&1I
M<F5C=&QY(&%C8V5S<VEN9R!I;G!U="!T<F5E(&EN(&$@)V9I;&4G(%9&4PH@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]D:7)E8W0N<&AP+'8@,2XQ+C@N-"`R,#`V
M+S`Q+S`Q(#(Q.C(X.C0T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M
M+SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC
M92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%9&4U])4T\*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!61E-?25-/5W)I=&5R
M7U)E86Q);G!U=%-T<F%T96=Y7V1I<F5C="!E>'1E;F1S(%9&4U])4T]7<FET
M97)?4F5A;$EN<'5T4W1R871E9WD@>PH*("`@(&9U;F-T:6]N(&=E=%)E86Q0
M871H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S;W5R8V569G,M
M/E]G971.871I=F50871H*"1T:&ES+3Y?<V]U<F-E4F]O="D["B`@("!]"@H@
M("`@9G5N8W1I;VX@9FEN:7-H960H*0H@("`@>PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'``````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#4S-34`,3`U,34T,S$P-C``,#(T,#`W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@16YC87!S=6QA
M=&4@<W1R871E9VEE<R!F;W(@86)I;&ET>2!T;R!W<FET92!O=71P=70@=&\@
M<F5A;"!F:6QE+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP+'8@,2XQ+C@N
M-R`R,#`V+S`Q+S`Q(#(Q.C(X.C0S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S
M>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN
M($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%9&
M4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!61E-?25-/
M5W)I=&5R7U)E86Q/=71P=713=')A=&5G>2!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@5D93('1O('=H:6-H('=E('=I;&P@=W)I=&4@=&AE(&9I;&4N"B`@("`@
M*@H@("`@("H@0'9A<B!61E,*("`@("`J+PH@("`@=F%R("1?=&%R9V5T5F9S
M.PH*("`@("\J*@H@("`@("H@5VAE<F4@=&\@<W1O<F4@=&AE(&9I;&4@:6X@
M=&AE(%9&4RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]T87)G971&:6QE.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("8D=&%R9V5T5F9S("`@
M("`@("!4:&4@5D93('1O('=H:6-H('=E('=I;&P@=W)I=&4@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T1FEL92`@("`@("`@5&AE('!A=&@@
M86YD(&YA;64@;V8@9FEL92!T;R!W<FET92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@5D937TE33U=R:71E<E]296%L3W5T<'5T4W1R871E9WDH)B1T87)G9716
M9G,L("1T87)G971&:6QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&%R9V5T
M5F9S(#T@)B1T87)G97169G,["B`@("`@("`@)'1H:7,M/E]T87)G971&:6QE
M(#T@)'1A<F=E=$9I;&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396QE8W0@
M86YD(&-R96%T92!A(&-O;F-R971E('-T<F%T96=Y(&9O<B!U<VEN9R!A(')E
M86P@;W5T<'5T(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F
M)'1A<F=E=%9F<R`@("`@("`@5&AE(%9&4R!T;R!W:&EC:"!W92!W:6QL('=R
M:71E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5S=6QT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T1FEL92`@
M("`@("`@5&AE('!A=&@@86YD(&9I;&5N86UE(&]F('1H92!T87)G970*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I;&4@=VET
M:&EN('1H92!61E,N"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@($$@8V]N8W)E
M=&4@;W5T<'5T('-T<F%T96=Y(&]B:F5C="!O<B!014%27T5R<F]R(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9F86-T;W)Y*"8D=&%R9V5T5F9S+"`D=&%R9V5T1FEL92D*("`@
M('L*("`@("`@("!I9B`H<W1R=&]L;W=E<BAG971?8VQA<W,H)'1A<F=E=%9F
M<RDI(#T]("=V9G-?9FEL92<I('L*("`@("`@("`@("`@)&UE=&AO9"`]("=D
M:7)E8W0G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M971H;V0@
M/2`G8V]P>2<["B`@("`@("`@?0H*("`@("`@("!I;F-L=61E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+U)E86Q/=71P=713=')A=&5G>2\G("X@)&UE
M=&AO9"`N"B`@("`@("`@("`@("`@("`@("`@("`G+G!H<"<["B`@("`@("`@
M)&-L87-S(#T@)U9&4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T96=Y7R<@
M+B`D;65T:&]D.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UE=&AO
M9"DI.PH@("`@("`@('T*"B`@("`@("`@)'-T<F%T96=Y(#T@)FYE=R`D8VQA
M<W,H)'1A<F=E=%9F<RP@)'1A<F=E=$9I;&4I.PH@("`@("`@(')E='5R;B`D
M<W1R871E9WD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!R96%L(&9I
M;&5S>7-T96T@9FEL96YA;64@=V4@8V%N('=R:71E('1O+@H@("`@("H*("`@
M("`J($!A8G-T<F%C=`H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@9FEL
M96YA;64@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971296%L1FEL96YA;64H*0H@("`@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DYO="!I;7!L96UE;G1E9"XB*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!);F1I8V%T92!T:&%T('=E)W)E(&1O;F4@
M=W)I=&EN9R!T;R!T:&4@<F5A;"!F:6QE+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H@0')E='5R;B!M:7AE9"`@("!.=6QL(&]R(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEN:7-H960H
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO
M="!I;7!L96UE;G1E9"XB*2D["B`@("!]"@I]"@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#<P-P`Q,#4Q-30S,3`V
M,``P,C$V,S,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B\J*@H@*B!$<FEV97(@9F]R('5S:6YG(&UK:7-O9G,@
M9F]R(&-R96%T:6YG($E33R!I;6%G97,N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP+'8@,2XQ
M+C@N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C0S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O
M;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N
M($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E
M(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!61E-?
M25-/5W)I=&5R7VUK:7-O9G,@97AT96YD<R!61E-?25-/5W)I=&5R('L*"B`@
M("!F=6YC=&EO;B!P<F]C97-S*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<"<["B`@("`@("`@)&EN<'5T4W1R871E9WD@/2`F5D937TE33U=R:71E<E]2
M96%L26YP=713=')A=&5G>3HZ9F%C=&]R>2@D=&AI<RT^7W-O=7)C959F<RP@
M)'1H:7,M/E]P87)A;7-;)W-O=7)C95)O;W0G72D["B`@("`@("`@:68@*&ES
M7V$H)&EN<'5T4W1R871E9WDL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1I;G!U=%-T<F%T96=Y.PH@("`@("`@('T*"B`@("`@("`@
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]296%L3W5T<'5T
M4W1R871E9WDN<&AP)SL*("`@("`@("`D;W5T<'5T4W1R871E9WD@/2`F5D93
M7TE33U=R:71E<E]296%L3W5T<'5T4W1R871E9WDZ.F9A8W1O<GDH)'1H:7,M
M/E]T87)G97169G,L("1T:&ES+3Y?<&%R86US6R=T87)G971&:6QE)UTI.PH@
M("`@("`@(&EF("AI<U]A*"1O=71P=713=')A=&5G>2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&]U='!U=%-T<F%T96=Y.PH@("`@
M("`@('T*"B`@("`@("`@)&-M9"`]('-P<FEN=&8H)VUK:7-O9G,@+7%U:65T
M("UR("U*("UO("5S("5S(#XO9&5V+VYU;&PG+`H@("`@("`@("`@("`@("`@
M("`@("`@(&5S8V%P97-H96QL87)G*"1O=71P=713=')A=&5G>2T^9V5T4F5A
M;$9I;&5N86UE*"DI+`H@("`@("`@("`@("`@("`@("`@("`@(&5S8V%P97-H
M96QL87)G*"1I;G!U=%-T<F%T96=Y+3YG971296%L4&%T:"@I*2D["B`@("`@
M("`@)')E<R`]('-Y<W1E;2@D8VUD+"`D96,I.PH*("`@("`@("`O*B!#;W5L
M9"!B92!A(&QO="!O9B!S<&%C92!U<V5D+B`@1VEV92!B;W1H(&$@8VAA;F-E
M('1O(&-L96%N('5P(&5V96X*("`@("`@("`@*B!I9B!O;F4@97)R;W)S(&]U
M="X@*B\*("`@("`@("`D9FEN4F5S,2`]("1I;G!U=%-T<F%T96=Y+3YF:6YI
M<VAE9"@I.PH@("`@("`@("1F:6Y297,R(#T@)&]U='!U=%-T<F%T96=Y+3YF
M:6YI<VAE9"@I.PH@("`@("`@(&EF("AI<U]A*"1F:6Y297,Q+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEN4F5S,3L*("`@("`@
M("!]"B`@("`@("`@:68@*&ES7V$H)&9I;E)E<S(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1F:6Y297,R.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1R97,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(I*3L*("`@("`@("!]"B`@("`@("`@:68@*"1E8R`A/2`P*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(BDL("1E8RDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!I
M9B!W92!C86X@=7-E('1H:7,@9')I=F5R('1O(&UA:V4@:6UA9V5S"B`@("`@
M*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!W92!C86X@=7-E('1H:7,@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')A=&5G>4%V
M86EL86)L92@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@:68@=V4@8V%N(&9I
M;F0@86YD(&5X96-U=&4@=&AE(&!M:VES;V9S)R!C;VUM86YD+B`J+PH@("`@
M("`@("1R97,@/2!S>7-T96TH(FUK:7-O9G,@+6AE;'`@/B]D978O;G5L;"`R
M/B8Q(BP@)&5C*3L*("`@("`@("!I9B`H)')E<R`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H
M)&5C("$](#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*"@``````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8W
M-P`Q,#4Q-30S,3`V,``P,C,V,30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J*@H@*B!%;F-A<'-U;&%T92!S
M=')A=&5G:65S(&9O<B!G971T:6YG(&$@<F5A;"P@;&]C86P@9FEL97-Y<W1E
M;2!S=')U8W1U<F4@9G)O;0H@*B!A(%9&4RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP+'8@,2XQ+C@N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C0S(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT
M='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^
M"B`J($!P86-K86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M+PIC;&%S<R!61E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y('L*"B`@
M("`O*BH*("`@("`J($$@<F5F97)E;F-E('1O('1H92!S;W5R8V4@5D93('=E
M('=A;G0@=&\@<F5A9"X*("`@("`J"B`@("`@*B!`=F%R(%9&4PH@("`@("HO
M"B`@("!V87(@)%]S;W5R8V569G,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE(')O;W0@9&ER96-T;W)Y('=I=&AI;B!T:&4@<V]U<F-E(%9&4PH@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O=7)C
M95)O;W0["@H@("`@9G5N8W1I;VX@5D937TE33U=R:71E<E]296%L26YP=713
M=')A=&5G>2@F)'-O=7)C959F<RP@)'-O=7)C95)O;W0I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]S;W5R8V569G,@/2`F)'-O=7)C959F<SL*("`@("`@("`D
M=&AI<RT^7W-O=7)C95)O;W0@/2`F)'-O=7)C95)O;W0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@82!R96%L('!A=&@@=&\@=&AE(&EN<'5T('1R964N
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("`@($$@<W1R:6YG('=I=&@@=&AE(')E86P@<&%T:"P@;W(@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971296%L4&%T
M:"@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F]T(&EM<&QE;65N=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN
M9&EC871E('=E(&%R92!F:6YI<VAE9"!W:71H('1H:7,@:6YP=70@<W1R871E
M9WDN"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("`@("`@("!.=6QL(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9FEN:7-H960H*0H@("`@>PH@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!I;7!L96UE;G1E9"XB*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-I9&4@=VAI8V@@<W1R871E9WD@
M=&\@=7-E('1O(&=E="!A(')E86P@1E,@86YD(&-R96%T92!I="X*("`@("`J
M"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F
M)'-O=7)C959F<R`@("`@("`@5&AE(%9&4R!W92!W86YT('1O(')E860@9G)O
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)'-O=7)C95)O;W0@("`@("`@(%1H
M92!R;V]T(&1I<F5C=&]R>2!I;B!T:&%T(%9&4RX*("`@("`J($!R971U<FX@
M;V)J96-T("`@02!C;VYC<F5T92!S=')A=&5G>2!O<B!014%27T5R<F]R(&EF
M(&YO('-T<F%T96=Y(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@(&%V86EL
M86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@9F%C=&]R>2@F)'-O=7)C959F
M<RP@)'-O=7)C95)O;W0I"B`@("!["B`@("`@("`@:68@*'-T<G1O;&]W97(H
M9V5T7V-L87-S*"1S;W5R8V569G,I*2`]/2`G=F9S7V9I;&4G*2!["B`@("`@
M("`@("`@("1M971H;V0@/2`G9&ER96-T)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;65T:&]D(#T@)V-O<'DG.PH@("`@("`@('T*"B`@("`@
M("`@0&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4F5A;$EN
M<'5T4W1R871E9WDO)R`N("1M971H;V0@+@H@("`@("`@("`@("`@("`@("`@
M("`@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=61E-?25-/5W)I=&5R7U)E
M86Q);G!U=%-T<F%T96=Y7R<@+B`D;65T:&]D.PH@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2!<(B5S7"(N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UE=&AO9"DI.PH@("`@("`@('T*"B`@("`@("`@)'-T
M<F%T96=Y(#T@)FYE=R`D8VQA<W,H)'-O=7)C959F<RP@)'-O=7)C95)O;W0I
M.PH@("`@("`@(')E='5R;B`D<W1R871E9WD["B`@("!]"@I]"@H`````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&
M4R])4T]7<FET97(N<&AP````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C4S-P`Q,#4Q-30S,3`V,``P,C`Q-C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J(%9&4R!!4$D@9F]R(&%B<W1R86-T
M960@8W)E871I;VX@;V8@25-/("A#1"U23TTI(&9I;&5S>7-T96US+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`L=B`Q+C$N."XW(#(P,#8O,#$O,#$@,C$Z,C@Z-#,@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO
M+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@
M0'!A8VMA9V4@5D937TE33PH@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L
M87-S(%9&4U])4T]7<FET97(@>PH*("`@("\J*@H@("`@("H@02!61E,@;V)J
M96-T('5S960@9F]R(')E861I;F<@=&AE('-O=7)C92!F:6QE<PH@("`@("H*
M("`@("`J($!V87(@5D93"B`@("`@*B\*("`@('9A<B`D7W-O=7)C959F<R`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!!(%9&4R!O8FIE8W0@=7-E9"!F;W(@
M=W)I=&EN9R!T:&4@25-/(&EM86=E"B`@("`@*@H@("`@("H@0'9A<B!61E,*
M("`@("`J+PH@("`@=F%R("1?=&%R9V5T5F9S(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P
M87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A
M(&YE=R!61E-?25-/5W)I=&5R(&]B:F5C=`H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E-?25-/5W)I=&5R*"8D<V]U<F-E
M5F9S+"`F)'1A<F=E=%9F<RP@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI
M<RT^7W-O=7)C959F<R`]("8D<V]U<F-E5F9S.PH@("`@("`@("1T:&ES+3Y?
M=&%R9V5T5F9S(#T@)B1T87)G97169G,["B`@("`@("`@)'1H:7,M/E]P87)A
M;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H
M92!)4T\@:6UA9V4*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!.=6QL(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<')O8V5S<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T(&EM<&QE;65N
M=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@8W)E
M871E(&$@8V]N8W)E=&4@5D937TE33U=R:71E<B!S=6)C;&%S<RX*("`@("`J
M"B`@("`@*B!4:&ES(&UE=&AO9"!U<V5S(&ET<R!P87)A;65T97)S(&%N9"!C
M:&5C:W,@=&AE('-Y<W1E;2!T;R!D971E<FUI;F4*("`@("`J('1H92!M;W-T
M(&%P<')O<')I871E('-U8F-L87-S('1O('5S92!F;W(@8G5I;&1I;F<@25-/
M(&EM86=E<RX@($EF"B`@("`@*B!N;VYE(&ES(&9O=6YD+"!A;B!E<G)O<B!I
M<R!R86ES960N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)'-O=7)C
M959F<R`@("`@(%)E9F5R96YC92!T;R!T:&4@5D93(&]B:F5C="!F<F]M('=H
M:6-H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&9I;&5S('=I;&P@8F4@<F5A9"!T;R!C<F5A=&4@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@25-/(&EM86=E+@H@("`@("H@
M0'!A<F%M(&]B:F5C="`F)'1A<F=E=%9F<R`@("`@(%)E9F5R96YC92!T;R!T
M:&4@5D93(&]B:F5C="!T;R!W:&EC:"!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!)4T\@:6UA9V4@=VEL;"!B92!W<FET=&5N
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("`@($AA<V@@
M;V8@<&%R86UE=&5R<R!F;W(@8W)E871I;F<@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:6UA9V4Z"B`@("`@*B`@("`@("`@
M("`@("`@)W-O=7)C95)O;W0G(#T^("`@("!!(&1I<F5C=&]R>2!I;B!T:&4@
M<V]U<F-E(%9&4R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9I;&5S('1O(&)E(')E860@9G)O;2!F;W(@=&AE(&EM86=E
M+@H@("`@("H@("`@("`@("`@("`@("=T87)G971&:6QE)R`]/B`@("`@4&%T
M:"!A;F0@9FEL96YA;64@;V8@=&AE($E33R!F:6QE('1O"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!W<FET92!I;G1O('1H92!T
M87)G970@5D93+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("`@("`@
M("`@("`@("`@("!!(&YE=VQY(&-R96%T960@8V]N8W)E=&4@5D937TE33U=R
M:71E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-U
M8F-L87-S+"!O<B!A(%!%05)?17)R;W(@;VX@86X@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"8D<V]U<F-E5F9S+"`F)'1A<F=E=%9F
M<RP@)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG
M=&%R9V5T1FEL92==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(BDI.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)'!A<F%M<ULG<V]U<F-E4F]O="==*2D@>PH@("`@("`@("`@("`D<&%R86US
M6R=S;W5R8V52;V]T)UT@/2`G+R<["B`@("`@("`@?0H*("`@("`@("`O*B!2
M:6=H="!N;W<L(&UK:7-O9G,@:7,@=&AE(&]N;'D@9')I=F5R+"!B=70@;6%K
M92!S=7)E('=E(&-A;@H@("`@("`@("`J('-U<'!O<G0@:70N("HO"B`@("`@
M("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R])4T]7<FET
M97(O;6MI<V]F<RYP:'`G.PH@("`@("`@(&EF("A61E-?25-/5W)I=&5R7VUK
M:7-O9G,Z.G-T<F%T96=Y079A:6QA8FQE*"DI('L*("`@("`@("`@("`@)&ES
M;W=R:71E<B`]("9N97<@5D937TE33U=R:71E<E]M:VES;V9S*"1S;W5R8V56
M9G,L("1T87)G97169G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US*3L*("`@("`@("`@("`@
M<F5T=7)N("1I<V]W<FET97(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+B(I*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]6
M1E,O3V)J96-T+G!H<```````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,C$R,C4`,3`U,34T,S$P-C``,#$W-3,Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+U9&4RYP:'`G.PH*+RHJ
M"B`J($$@=W)A<'!E<B!F;W(@=&AE(%9&4R!C;&%S<R!T;R!R971U<FX@;V)J
M96-T<RP@:6YS=&5A9"!O9B!A<G)A>7,N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U9&4R]61E,O3V)J96-T+G!H<"QV(#$N,3(N,3`N,3$@,C`P-B\P-2\S
M,2`P-#HU,#HP,B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@2F]N(%=O;V0@/&IO;D!J96QL>6)O8BYC;RYU:SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IO;B!7;V]D(#QJ;VY`:F5L;'EB;V(N8V\N
M=6L^"B`J($!P86-K86=E(%9&4PH@*B\*8VQA<W,@5D937T]B:F5C="!["@H@
M("`@+RHJ"B`@("`@*B!4:&4@86-T=6%L('9F<R!T:&%T(&1O97,@=&AE('=O
M<FL*("`@("`J"B`@("`@*B!`=F%R(%9&4PH@("`@("HO"B`@("!V87(@)%]V
M9G,["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!P871H('1H870@:&%S
M(&)E96X@<&%S<V5D('1O(&QI<W1&;VQD97(L(&EF('1H:7,*("`@("`J(&-H
M86YG97,L('1H92!L:7-T('=I;&P@8F4@<F5B=6EL="X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C=7)R96YT4&%T:#L*
M"B`@("`O*BH*("`@("`J(%1H92!R971U<FX@=F%L=64@9G)O;2!A('-T86YD
M87)D(%9&4R!L:7-T1F]L9&5R(&-A;&PL('1O"B`@("`@*B!B92!R96%D('=I
M=&@@=&AE($]B:F5C="!L:7-T1F]L9&5R+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?9F]L9&5R3&ES=#L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($EF('EO=2!P87-S
M(&EN(&%N(&5X:7-T:6YG(%9&4R!O8FIE8W0L(&ET('=I;&P@8F4@=7-E9"!A
M<R!T:&4@5D93"B`@("`@*B!O8FIE8W0@9F]R('1H:7,@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!61E,@)B1V9G,@(%1H92!61E,@;V)J96-T('1O
M('=R87`N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9&4U]/8FIE8W0H)B1V9G,I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1V9G,I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?=F9S(#T@)'9F<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!61E-?3V)J
M96-T(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9&
M4R!S=6)C;&%S<R!T;R!R971U<FXN($EF"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2!T:&5N('=E('=I;&P@;&]O
M:R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV97);,%TO
M;&EB+U9&4R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S
M=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@5D93
M7T]B:F5C="`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@5D937T]B:F5C
M="!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@9F%L
M<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y
M*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1V
M9G,@/2`F5D93.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I
M*3L*("`@("`@("`D=F9S;V)J96-T(#T@)FYE=R!61E-?3V)J96-T*"1V9G,I
M.PH@("`@("`@(')E='5R;B`D=F9S;V)J96-T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N
M8W)E=&4@5D93(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9')I=F5R+B!)
M="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO"B`@("`@
M*B!61E,@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E
M;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E
M9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F:6QE(&)A8VME;F1S("AA;F0L"B`@
M("`@*B!T:'5S+"!M=6QT:7!L92!61E,@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER
M960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D
M(&%S.B`D=F%R(#T@)E9&4SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@5D93
M('-U8F-L87-S('1O(')E='5R;BX@268*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`D9')I=F5R(&ES(&%N(&%R<F%Y('1H96X@=V4@=VEL;"!L;V]K
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72]L
M:6(O5D93+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI
M;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U
M8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!61E-?
M3V)J96-T("!4:&4@8V]N8W)E=&4@5D937T]B:F5C="!R969E<F5N8V4L(&]R
M(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1V9G,@/2`F5D93.CIS:6YG
M;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI.PH@("`@("`@("1V
M9G-O8FIE8W0@/2`F;F5W(%9&4U]/8FIE8W0H)'9F<RD["B`@("`@("`@<F5T
M=7)N("1V9G-O8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T
M:&4@8W)E9&5N=&EA;',@=&AA="!W92!H879E('1O('-E92!I9B!T:&5R92!I
M<R!A('9A;&ED(&QO9VEN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!D97-C<FEB:6YG('1H92!P
M<F]B;&5M"B`@("`@*B`@("`@("`@("`@("`@("!I9B!T:&4@8W)E9&5N=&EA
M;',@87)E(&EN=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K0W)E
M9&5N=&EA;',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^
M8VAE8VM#<F5D96YT:6%L<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M(&-O;F9I9W5R871I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@06X@87-S;V-I871I=F4@87)R87D@;V8@<&%R
M86UE=&5R(&YA;64O=F%L=64*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!P86ER<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4&%R86US*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F9S+3YS9710
M87)A;7,H)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9I;&4@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5A9"@D<&%T:"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]V9G,M/G)E860H9&ER;F%M92@D<&%T:"DL(&)A<V5N86UE
M*"1P871H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@
M:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T;7!&:6QE("`@("`@5&AE('1E;7!O<F%R>2!F
M:6QE(&-O;G1A:6YI;F<@=&AE(&1A=&$@=&\@8F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=&]R960N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T
M;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)'!A=&@L("1T;7!&:6QE+"`D875T
M;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W9F<RT^=W)I=&4H9&ER;F%M92@D<&%T:"DL(&)A<V5N86UE*"1P871H*2P@
M)'1M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W1O<F4@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T
M82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@
M5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871A("`@("`@("`@5&AE(&9I;&4@9&%T82X*("`@("`J($!P
M87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T
M92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L("1D
M871A+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W9F<RT^=W)I=&5$871A*&1I<FYA;64H)'!A=&@I+"!B87-E
M;F%M92@D<&%T:"DL("1D871A+"`D875T;V-R96%T92`](&9A;'-E*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9I;&4@9G)O;2!T:&4@5D93
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H
M('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&
M:6QE*"1P871H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^
M9&5L971E1FEL92AD:7)N86UE*"1P871H*2P@8F%S96YA;64H)'!A=&@I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M92!A(&9I;&4@:6X@=&AE(%9&
M4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@
M;VQD('!A=&@@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O
M;&1N86UE("!4:&4@;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F5W<&%T:"`@5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96YA;64H)&]L9'!A=&@L("1N97=P871H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W9F<RT^<F5N86UE*&1I<FYA;64H)&]L9'!A
M=&@I+"!B87-E;F%M92@D;VQD<&%T:"DL(&1I<FYA;64H)&YE=W!A=&@I+"!B
M87-E;F%M92@D;F5W<&%T:"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E(&$@9F]L9&5R(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@=&AE(&9O;&1E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C<F5A=&5&;VQD97(H)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=F9S+3YC<F5A=&5&;VQD97(H9&ER;F%M92@D<&%T:"DI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"!4:&4@
M<&%T:"!O9B!T:&4@9F]L9&5R('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE
M=&5&;VQD97(H)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=F9S+3YD96QE=&5&;VQD97(H9&ER;F%M92@D<&%T:"DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(%9&4U],:7-T271E;2!O8FIE8W0@:68@
M=&AE(&9O;&1E<B!C86X*("`@("`J(&)E(')E860L(&]R(&$@4$5!4E]%<G)O
M<B!I9B!I="!C86XG="!B92X@4F5T=7)N<R!F86QS92!O;F-E"B`@("`@*B!T
M:&4@9F]L9&5R(&AA<R!B965N(&-O;7!L971E;'D@<F5A9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@9&ER
M971O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1FEL92!L:7-T
M("AA<G)A>2D@;VX@<W5C8V5S<RP@82!014%27T5R<F]R"B`@("`@*B`@("`@
M("`@("`@("`@("!O8FIE8W0@;VX@9F%I;'5R92P@;W(@9F%L<V4@:68@=&AE
M(&9O;&1E<B!I<PH@("`@("H@("`@("`@("`@("`@("`@8V]M<&QE=&5L>2!R
M96%D+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R*"1P871H*0H@
M("`@>PH@("`@("`@(&EF("@A*"1P871H(#T]/2`D=&AI<RT^7V-U<G)E;G10
M871H*2D@>PH@("`@("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3Y?=F9S
M+3YL:7-T1F]L9&5R*"1P871H*3L*("`@("`@("`@("`@:68@*"1F;VQD97),
M:7-T*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O;&1E<DQI<W0@/2`D
M9F]L9&5R3&ES=#L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!A
M=&@@/2`D<&%T:#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@
M;F]T(')E860@)7,N(BDL("1P871H*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O3&ES=$ET96TN<&AP)SL*("`@("`@("!I9B`H)&9I;&4@/2!A<G)A>5]S
M:&EF="@D=&AI<RT^7V9O;&1E<DQI<W0I*2!["B`@("`@("`@("`@("1F:6QE
M(#T@)FYE=R!61E-?3&ES=$ET96TH)'!A=&@L("1F:6QE*3L*("`@("`@("`@
M("`@<F5T=7)N("1F:6QE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&%N9V5S('!E<FUI<W-I;VYS(&9O<B!A;B!)=&5M(&]N('1H92!61E,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@2&]L
M9',@=&AE('!A=&@@;V8@9&ER96-T;W)Y(&]F('1H92!)=&5M+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5$]$3PH@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H
M86YG95!E<FUI<W-I;VYS*"1P871H+"`D<&5R;6ES<VEO;BD*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F-H86YG95!E<FUI<W-I;VYS*&1I
M<FYA;64H)'!A=&@I+"!B87-E;F%M92@D<&%T:"DL("1P97)M:7-S:6]N*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;&ES="!O9B!A9&1I
M=&EO;F%L(&-R961E;G1I86QS(')E<75I<F5D+"!I9B!A;GDN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@0W)E9&5N=&EA;"!L:7-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971297%U:7)E9$-R961E;G1I86QS*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F=E=%)E<75I<F5D0W)E9&5N
M=&EA;',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@87)R
M87D@<W!E8VEF:6-Y:6YG('=H870@<&5R;6ES<VEO;G,@87)E(&-H86YG96%B
M;&4@9F]R('1H:7,*("`@("`J(&EM<&QE;65N=&%T:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($-H86YG96%B;&4@<&5R;6ES:6]N<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T36]D:69I86)L95!E<FUI<W-I;VYS*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F=E=$UO9&EF:6%B
M;&5097)M:7-S:6]N<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V4@
M86YY(')E<V]U<F-E<R!T:&%T(&YE960@=&\@8F4@8VQO<V5D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]V9G,M/E]D:7-C
M;VYN96-T*"D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+U9&4R]S;6(N<&AP````````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`U-C`Q-@`Q,#4Q-30S,3`V,``P,3<Q,3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%-T871E;&5S<R!61E,@:6UP;&5M96YT871I;VX@9F]R(&$@4TU"
M('-E<G9E<BP@8F%S960@;VX@<VUB8VQI96YT+@H@*@H@*B!297%U:7)E9"!V
M86QU97,@9F]R("1P87)A;7,Z"B`J(#QP<F4^"B`J("`@)W5S97)N86UE)R`@
M+2!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!3
M34(@<V5R=F5R+@H@*B`@("=P87-S=V]R9"<@("T@5&AE('!A<W-W;W)D('=I
M=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@4TU"('-E<G9E<BX*("H@("`G
M:&]S='-P96,G("`M(%1H92!334(@<V5R=F5R('1O(&-O;FYE8W0@=&\N"B`J
M("`@)W!O<G0G("`@("`@+2!4:&4@4TU"('!O<G0@;G5M8F5R('1O(&-O;FYE
M8W0@=&\N"B`J("`@)W-H87)E)R`@("`@+2!4:&4@<VAA<F4@=&\@86-C97-S
M(&]N('1H92!334(@<V5R=F5R+@H@*B`@("=S;6)C;&EE;G0G("T@5&AE('!A
M=&@@=&\@=&AE("=S;6)C;&EE;G0G(&5X96-U=&%B;&4N"B`J(#PO<')E/@H@
M*@H@*B!/<'1I;VYA;"!V86QU97,@9F]R("1P87)A;7,Z"B`J(#QP<F4^"B`J
M("`@)VEP861D<F5S<R<@+2!4:&4@861D<F5S<R!O9B!T:&4@<V5R=F5R('1O
M(&-O;FYE8W0@=&\N"B`J(#PO<')E/@H@*@H@*B!&=6YC=&EO;G,@;F]T(&EM
M<&QE;65N=&5D.@H@*B`@("T@8VAA;F=E4&5R;6ES<VEO;G,H*3H@5&AE(%--
M0B!P97)M:7-S:6]N('-T>6QE(&1O97,@;F]T(&9I="!W:71H('1H90H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@;6]D=6QE+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`L=B`Q+C$Q+C(N."`R,#`V+S`U
M+S,Q(#`T.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]D96)A<V4@8V]P
M>7)I9VAT(#(P,#(@4&%U;"!'87)E874@/'!A=6Q`>&AA=VLN;F5T/BX@($%D
M87!T960@=VET:`H@*B!P97)M:7-S:6]N(&)Y(%!A=')I8V4@3&5V97-Q=64@
M/'=A>6YE0'!T869F+F-A/B!F<F]M('!H<'-M8BTP+C@@8V]D92P@86YD"B`J
M(&-O;G9E<G1E9"!T;R!T:&4@3$=03"X@(%!L96%S92!D;R!N;W0@=&%U;G0@
M;W)I9VEN86P@875T:&]R+"!C;VYT86-T"B`J(%!A=')I8V4@3&5V97-Q=64@
M;W(@9&5V0&QI<W1S+FAO<F1E+F]R9RX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@(%!A=6P@1V%R96%U(#QP875L0'AH87=K+FYE=#X*("H@0&%U=&AO
M<B`@4&%T<FEC92!,979E<W%U92`\=V%Y;F5`<'1A9F8N8V$^"B`J($!S:6YC
M92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!61E,*("HO"F-L87-S(%9&4U]S
M;6(@97AT96YD<R!61E,@>PH*("`@("\J*@H@("`@("H@3&ES="!O9B!A9&1I
M=&EO;F%L(&-R961E;G1I86QS(')E<75I<F5D(&9O<B!T:&ES(%9&4R!B86-K
M96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?8W)E9&5N=&EA;',@/2!A<G)A>2@G=7-E<FYA;64G+"`G<&%S<W=O<F0G
M*3L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES<VEO;G,@86YD(&EF
M('1H97D@8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FUI
M<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G<F5A
M9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F
M86QS92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L
M<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@
M("`@("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET
M92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DI.PH*("`@("\J*@H@
M("`@("H@075T:&5N=&EC871E<R!A('5S97(@;VX@=&AE(%--0B!S97)V97(@
M86YD('-H87)E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("`D8VUD(#T@
M87)R87DH)W%U:70G*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM86YD
M*"<G+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB*2D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T<FEE=F5S(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O
M('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I
M;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@9FEL92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D
M*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!L:7-T*"1P871H+"`D;F%M
M92D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D<&%T:"P@)&YA;64I
M.PH@("`@("`@("1T96UP(#T@)'1H:7,M/E]G971496UP1FEL92@I.PH@("`@
M("`@("1C;60@/2!A<G)A>2@G9V5T(%PB)R`N("1N86UE("X@)UPB("<@+B`D
M=&5M<"D["B`@("`@("`@)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@D<&%T:"P@
M)&-M9"D["B`@("`@("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("!]"B`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D=&5M<"DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA
M;64I*2D["B`@("`@("`@?0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H
M)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@)&9I;&4@/2!F
M:6QE7V=E=%]C;VYT96YT<R@D=&5M<"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&9P(#T@9F]P96XH)'1E;7`L("=R)RD["B`@("`@("`@("`@
M("1F:6QE(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D=&5M<"DI.PH@("`@("`@
M("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"B`@("`@("`@=6YL:6YK*"1T
M96UP*3L*("`@("`@("!I9B`H)&9I;&4I('L*("`@("`@("`@("`@<F5T=7)N
M("1F:6QE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE
M*2DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A
M(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N
M86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@
M("!4:&4@=&5M<&]R87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;R!B
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T;W)E9"X*
M("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A
M;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M92@D<&%T:"P@)&YA;64L("1T;7!&:6QE+"`D875T;V-R96%T92`](&9A;'-E
M*0H@("`@>PH@("`@("`@("\O($1O=6)L92!Q=6]T97,@;F]T(&%L;&]W960@
M:6X@4TU"(&9I;&5N86UE+@H@("`@("`@("1N86UE(#T@<W1R7W)E<&QA8V4H
M)R(G+"`B)R(L("1N86UE*3L*"B`@("`@("`@;&ES="@D<&%T:"P@)&YA;64I
M(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*
M("`@("`@("`D8VUD(#T@87)R87DH)W!U="!<(B<@+B`D=&UP1FEL92`N("=<
M(B!<(B<@+B`D;F%M92`N("=<(B<I.PH@("`@("`@("\O(&1O('=E(&YE960@
M=&\@9FER<W0@875T;V-R96%T92!T:&4@9&ER96-T;W)Y/PH@("`@("`@(&EF
M("@D875T;V-R96%T92D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@D<&%T:"P@)&-M9"D["B`@("`@("`@
M:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@82!F:6QE(&EN('1H92!61E,@
M9G)O;2!R87<@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE
M('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@("!4
M:&4@9FEL92!D871A+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A
M=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T
M;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1T;7!&:6QE(#T@)'1H
M:7,M/E]G971496UP1FEL92@I.PH@("`@("`@("1F<"`](&9O<&5N*"1T;7!&
M:6QE+"`G=V(G*3L*("`@("`@("!F=W)I=&4H)&9P+"`D9&%T82D["B`@("`@
M("`@9F-L;W-E*"1F<"D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YW<FET
M92@D<&%T:"P@)&YA;64L("1T;7!&:6QE+"`D875T;V-R96%T92D["B`@("`@
M("`@=6YL:6YK*"1T;7!&:6QE*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!F:6QE(&9R;VT@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@
M<&%T:"!T;R!D96QE=&4@=&AE(&9I;&4@9G)O;2X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5L971E1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@
M;&ES="@D<&%T:"P@)&YA;64I(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA
M;F0H)'!A=&@L("1N86UE*3L*("`@("`@("`D8VUD(#T@87)R87DH)V1E;"!<
M(B<@+B`D;F%M92`N("=<(B<I.PH@("`@("`@("1E<G(@/2`D=&AI<RT^7V-O
M;6UA;F0H)'!A=&@L("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAE8VMS(&EF(&$@9VEV96X@<&%T:&YA;64@:7,@82!F;VQD97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@
M=&AE(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F
M:6QE(&]R(&9O;&1E<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!I="!I<R!A(&9O;&1E<BP@9F%L<V4@;W1H97)W:7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T9O;&1E<B@D<&%T:"P@)&YA;64I
M"B`@("!["B`@("`@("`@;&ES="@D<&%T:"P@)&YA;64I(#T@)'1H:7,M/E]E
M<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*("`@("`@("`D8VUD
M(#T@87)R87DH)W%U:70G*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM
M86YD*"1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I+"`D8VUD*3L*("`@
M("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@9F]L9&5R(&9R
M;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@("!4:&4@<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&YA;64@;V8@
M=&AE(&9O;&1E<B!T;R!D96QE=&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F5C=7)S:79E("!&;W)C92!A(')E8W5R<VEV92!D96QE=&4_"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5L971E1F]L9&5R*"1P871H+"`D;F%M92P@)')E8W5R<VEV
M92`](&9A;'-E*0H@("`@>PH@("`@("`@("1I<T1I<B`](&9A;'-E.PH@("`@
M("`@("1D:7)#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H*3L*("`@
M("`@("!F;W)E86-H("@D9&ER0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@
M("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64@)B8@)&9I;&5;)W1Y<&4G
M72`]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("`D:7-$:7(@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@A)&ES1&ER*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B7"(E<UPB(&ES(&YO="!A
M(&1I<F5C=&]R>2XB*2P@)'!A=&@@+B`G+R<@+B`D;F%M92DI.PH@("`@("`@
M('T*"B`@("`@("`@)&9I;&5?;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1T
M:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*3L*("`@("`@("!I9B`H:7-?
M82@D9FEL95]L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D9FEL95]L:7-T.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F:6QE
M7VQI<W0@)B8@(21R96-U<G-I=F4I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@
M*"1F:6QE6R=T>7!E)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YD96QE=&5&;VQD97(H)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTL("1R96-U<G-I=F4I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YD96QE=&5&:6QE*"1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA
M;64I+"`D9FEL95LG;F%M92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+R\@4F5A;&QY(&1E;&5T92!T:&4@9F]L9&5R+@H@("`@
M("`@(&QI<W0H)'!A=&@L("1N86UE*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#
M;VUM86YD*"1P871H+"`D;F%M92D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=R
M;61I<B!<(B<@+B`D;F%M92`N("=<(B<I.PH@("`@("`@("1E<G(@/2`D=&AI
M<RT^7V-O;6UA;F0H)'!A=&@L("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E
M<G(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M;VQD97(@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE
M*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@82!F
M:6QE(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD<&%T:"`@5&AE(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@
M9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@
M9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?
M17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D
M;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)&YE=W!A
M=&@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@1&]U8FQE('%U;W1E<R!N;W0@
M86QL;W=E9"!I;B!334(@9FEL96YA;64N"B`@("`@("`@)&YE=VYA;64@/2!S
M=')?<F5P;&%C92@G(B<L("(G(BP@)&YE=VYA;64I.PH*("`@("`@("!L:7-T
M*"1F:6QE+"`D;F%M92D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D
M;VQD;F%M92P@)&YE=VYA;64I.PH@("`@("`@("1C;60@/2!A<G)A>2@G<F5N
M86UE(%PB)R`N("!S=')?<F5P;&%C92@G+R<L("=<7%Q<)RP@)&]L9'!A=&@I
M("X@)UQ<)R`N("1F:6QE("X@)UPB(%PB)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<E]R97!L86-E*"<O)RP@)UQ<7%PG+"`D
M;F5W<&%T:"D@+B`G7%PG("X@)&YA;64@+B`G7"(G*3L*("`@("`@("!I9B`H
M:7-?82@D97)R(#T@)'1H:7,M/E]C;VUM86YD*"<G+"`D8VUD*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB
M+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&5S(&$@9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@9&ER96-T;W)Y('1O
M(&-R96%T92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M<F5A=&5&;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("\O($1O
M=6)L92!Q=6]T97,@;F]T(&%L;&]W960@:6X@4TU"(&9I;&5N86UE+@H@("`@
M("`@("1N86UE(#T@<W1R7W)E<&QA8V4H)R(G+"`B)R(L("1N86UE*3L*"B`@
M("`@("`@;&ES="@D9&ER+"`D;6MD:7(I(#T@)'1H:7,M/E]E<V-A<&53:&5L
M;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*("`@("`@("`D8VUD(#T@87)R87DH
M)VUK9&ER(%PB)R`N("1M:V1I<B`N("=<(B<I.PH@("`@("`@("1E<G(@/2`D
M=&AI<RT^7V-O;6UA;F0H)&1I<BP@)&-M9"D["B`@("`@("`@:68@*&ES7V$H
M)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA
M;64I*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!U;G-O<G1E9"!F:6QE(&QI<W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@
M<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O(&=E="!T:&4@9FEL92!L:7-T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<BX*("`@("`J($!P
M87)A;2!M:7AE9"`D9FEL=&5R("`@("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT
M97(@8F%S960@;VX@9FEL96YA;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_(%1H:7,@:7,@:7)R96QE=F%N="!W
M:71H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-M8F-L:65N
M="X*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO=R!D:7)E
M8W1O<FEE<R!O;FQY/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ0
M14%27T5R<F]R("!&:6QE(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R*"1P871H(#T@
M)R<L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL97,@/2!T<G5E+"`D9&ER;VYL
M>2`](&9A;'-E*0H@("`@>PH@("`@("`@(&QI<W0H)'!A=&@I(#T@)'1H:7,M
M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@I.PH@("`@("`@("1C;60@/2!A
M<G)A>2@G;',G*3L*("`@("`@("`D<F5S(#T@)'1H:7,M/E]C;VUM86YD*"1P
M871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@
M("`@("`D;G5M7VQI;F5S(#T@8V]U;G0H)')E<RD["B`@("`@("`@)&9I;&5S
M(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1R(#T@,#L@)'(@/"`D;G5M7VQI
M;F5S.R`D<BLK*2!["B`@("`@("`@("`@("\O($UA=&-H(&9I;&4@;&ES=&EN
M9RX*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*%QS7',N*UQS>S8L
M?2DO)RP@)')E<ULD<ETI*2!["B`@("`@("`@("`@("`@("`O+R!3<&QI="!I
M;G1O(&-O;'5M;G,@870@979E<GD@<VEX('-P86-E<PH@("`@("`@("`@("`@
M("`@)'-P;&ET,2`]('!R96=?<W!L:70H)R]<<WLV+'TO)RP@=')I;2@D<F5S
M6R1R72DI.PH@("`@("`@("`@("`@("`@+R\@268@=&AE(&9I;&4@;F%M92!I
M<VXG="`N(&]R("XN"B`@("`@("`@("`@("`@("!I9B`H)'-P;&ET,5LP72`A
M/2`G+B<@)B8@)'-P;&ET,5LP72`A/2`G+BXG*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1S<&QI=#%;,ETI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\O($EF('1H97)E(&ES(&$@<VUA;&P@9FEL92!S:7IE+"!I
M;F8@8V]U;&0@8F4@<W!L:70*("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M:6YT;R`S(&-O;',N"B`@("`@("`@("`@("`@("`@("`@("`@("1S<&QI=#%;
M,5T@+CT@)R`G("X@)'-P;&ET,5LR73L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@+R\@4W!L:70@9FEL92!I;F8@870@979E
M<GD@;VYE(&]R(&UO<F4@<W!A8V5S+@H@("`@("`@("`@("`@("`@("`@("1S
M<&QI=#(@/2!P<F5G7W-P;&ET*"<O7',K+R<L("1S<&QI=#%;,5TI.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1S<&QI=#);,%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O($EF('1H97)E(&ES(&YO(&9I
M;&4@871T<BP@<VAI9G0@8V]L<R!O=F5R+@H@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]U;G-H:69T*"1S<&QI=#(L("<G*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&UY7VYA;64@/2`D<W!L
M:70Q6S!=.PH*("`@("`@("`@("`@("`@("`@("`O+R!&:6QT97(@;W5T(&1O
M=&9I;&5S(&EF('1H97D@87)E;B=T('=A;G1E9"X*("`@("`@("`@("`@("`@
M("`@("!I9B`H(21D;W1F:6QE<R`F)B!S=6)S='(H)&UY7VYA;64L(#`L(#$I
M(#T]("<N)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("1M
M>5]S:7IE(#T@)'-P;&ET,ELQ73L*("`@("`@("`@("`@("`@("`@("`D97AT
M7VYA;64@/2!E>'!L;V1E*"<N)RP@)&UY7VYA;64I.PH*("`@("`@("`@("`@
M("`@("`@("!I9B`H*'-T<G!O<R@D<W!L:70R6S!=+"`G1"<I("$]/2!F86QS
M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UY7W1Y<&4@/2`G*BID
M:7(G.PH@("`@("`@("`@("`@("`@("`@("`@("`D;7E?<VEZ92`]("TQ.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1M>5]T>7!E(#T@5D93.CIS=')T;VQO=V5R*"1E>'1?;F%M95MC
M;W5N="@D97AT7VYA;64I("T@,5TI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D;7E?9&%T92`]('-T<G1O=&EM92@D<W!L
M:70R6S1=("X@)R`G("X@)'-P;&ET,ELS72`N("<@)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-P;&ET,ELV72`N("<@
M)R`N("1S<&QI=#);-5TI.PH@("`@("`@("`@("`@("`@("`@("1F:6QE9&%T
M82`](&%R<F%Y*"=O=VYE<B<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V=R;W5P)R`]/B`G)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<&5R;7,G(#T^("<G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D
M;7E?;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G='EP92<@/3X@)&UY7W1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1A=&4G(#T^("1M>5]D871E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S:7IE)R`]/B`D;7E?<VEZ
M92D["B`@("`@("`@("`@("`@("`@("`@+R\@=V%T8V@@9F]R(&9I;'1E<G,@
M86YD(&1I<F]N;'D*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]F
M:6QT97)-871C:"@D9FEL=&5R+"`D;7E?;F%M92DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1D:7)O;FQY("8F("1M>5]T>7!E("$]/2`G*BID
M:7(G*2!["B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D9FEL97-;)&9I;&5D
M871A6R=N86UE)UU=(#T@)&9I;&5D871A.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9FEL97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@
M;V8@9F]L9&5R<R!I;B!S<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T
M:&4@9&ER96-T;W)Y('1O(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R
M86T@;6EX960@)&9I;'1E<B`@("`@("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT
M97(@8F%S960@;VX@9F]L9&5R;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1D;W1F;VQD97)S("!);F-L=61E(&1O=&9O;&1E<G,_($ER<F5L979A;G0@
M9F]R(%--0BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%
M<G)O<B`@1F]L9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R<R@D<&%T:"`]("<G
M+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9O;&1E<G,@/2!T<G5E*0H@("`@>PH@
M("`@("`@("1F;VQD97)S(#T@87)R87DH*3L*("`@("`@("`D9F]L9&5R(#T@
M87)R87DH*3L*"B`@("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^;&ES=$9O
M;&1E<B@D<&%T:"P@;G5L;"P@)&1O=&9O;&1E<G,L('1R=64I.PH@("`@("`@
M(&EF("AI<U]A*"1F;VQD97),:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D9F]L9&5R3&ES=#L*("`@("`@("!]"@H@("`@("`@
M("\O(&1I<FYA;64@=VEL;"!S=')I<"!L87-T(&-O;7!O;F5N="!F<F]M('!A
M=&@L(&5V96X@;VX@82!D:7)E8W1O<GD*("`@("`@("`D9F]L9&5R6R=V86PG
M72`](&1I<FYA;64H)'!A=&@I.PH@("`@("`@("1F;VQD97);)V%B8G)E=B==
M(#T@)RXN)SL*("`@("`@("`D9F]L9&5R6R=L86)E;"==(#T@)RXN)SL*"B`@
M("`@("`@)&9O;&1E<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O;&1E<CL*"B`@
M("`@("`@9F]R96%C:"`H)&9O;&1E<DQI<W0@87,@)&9I;&5S*2!["B`@("`@
M("`@("`@("1F;VQD97);)W9A;"==(#T@)'1H:7,M/E]G9710871H*"1P871H
M+"`D9FEL97-;)VYA;64G72D["B`@("`@("`@("`@("1F;VQD97);)V%B8G)E
M=B==(#T@)&9I;&5S6R=N86UE)UT["B`@("`@("`@("`@("1F;VQD97);)VQA
M8F5L)UT@/2`D9F]L9&5R6R=V86PG73L*"B`@("`@("`@("`@("1F;VQD97)S
M6R1F;VQD97);)W9A;"==72`]("1F;VQD97(["B`@("`@("`@?0H*("`@("`@
M("!K<V]R="@D9F]L9&5R<RD["B`@("`@("`@<F5T=7)N("1F;VQD97)S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]P:65S(&$@9FEL92!T:')O=6=H('1H
M92!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO;B!O9B!T:&4@9FEL
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;W!Y*"1P871H+"`D;F%M92P@)&1E<W0I
M"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L
M("1N86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XG("X@<')E9U]Q
M=6]T92@D;W)I9RD@+B`G+S\D?"<L("1D97-T*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@8V]P>2!F:6QE*',I
M("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@)&9I;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L
M9&5R*"1D97-T+"!N=6QL+"!T<G5E*3L*("`@("`@("!F;W)E86-H("@D9FEL
M94-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M
M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(B5S(&%L<F5A9'D@97AI<W1S+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D:7-$:7(@/2!F86QS93L*("`@("`@
M("`D9&ER0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L;"P@
M9F%L<V4I.PH@("`@("`@(&9O<F5A8V@@*"1D:7)#:&5C:R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92`F)B`D
M9FEL95LG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("1I
M<T1I<B`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1I<T1I<BD@>PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T949O;&1E<B@D9&5S="P@)&YA
M;64I.PH*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^;&ES
M=$9O;&1E<B@D;W)I9RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE7VQI
M<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^8V]P>2@D;W)I9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEL95LG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I
M*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T;7!&:6QE(#T@)'1H:7,M/E]C<F5A=&5496UP
M1FEL92@D<&%T:"P@)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D=&UP
M1FEL92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(BDL("1O<FEG*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1R97,@/2`D=&AI<RT^=W)I=&4H)&1E<W0L("1N86UE+"`D=&UP1FEL92D[
M"B`@("`@("`@("`@('5N;&EN:R@D=&UP1FEL92D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]P>2!F86EL
M960Z("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@82!F:6QE('1H<F]U9V@@
M=&AE(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N(&]F('1H92!F
M:6QE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H)'!A=&@L("1N86UE+"`D9&5S
M="D*("`@('L*("`@("`@("`D;W)I9R`]("1T:&ES+3Y?9V5T4&%T:"@D<&%T
M:"P@)&YA;64I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G
M7W%U;W1E*"1O<FEG*2`N("<O/R1\)RP@)&1E<W0I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;FYO="!M;W9E(&9I;&4H
M<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(I*3L*("`@("`@
M("!]"@H@("`@("`@("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D
M9&5S="P@;G5L;"P@=')U92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C
M:R!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]
M/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*"(E<R!A;')E861Y(&5X:7-T<RXB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G9710871H*"1D97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&5R<B`]("1T:&ES+3YR96YA;64H)'!A=&@L
M("1N86UE+"`D9&5S="P@)&YA;64I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G9710871H*"1D97-T+"`D;F%M92DI*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!F=6QL('!A=&@@;V8@86X@:71E;2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!D:7)E8W1O<GD@
M;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M;F%M92!O9B!T:&4@:71E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!&=6QL('!A=&@@=VAE;B`D<&%T:"!I<W-E="!A;F0@:G5S="`D;F%M92!W
M:&5N(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9710871H*"1P
M871H+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H)'!A=&@@(3T]("<G*2![
M"B`@("`@("`@("`@("!R971U<FX@*"1P871H("X@)R\G("X@)&YA;64I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&YA;64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!297!L86-E;65N="!F;W(@97-C87!E<VAE;&QC;60H*2P@=F%R
M:6%B;&4@;&5N9W1H(&%R9W,L(&%S('=E(&]N;'D@=V%N=`H@("`@("H@8V5R
M=&%I;B!C:&%R86-T97)S(&5S8V%P960N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2`@
M4W1R:6YG<R!T;R!E<V-A<&4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>0H@("`@("HO"B`@("!F=6YC=&EO;B!?97-C87!E4VAE;&Q#;VUM86YD*"D*
M("`@('L*("`@("`@("`D<F5T(#T@87)R87DH*3L*("`@("`@("`D87)G<R`]
M(&9U;F-?9V5T7V%R9W,H*3L*("`@("`@("!F;W)E86-H("@D87)G<R!A<R`D
M87)G*2!["B`@("`@("`@("`@("1R971;72`]('-T<E]R97!L86-E*&%R<F%Y
M*"<[)RP@)UQ<)RDL(&%R<F%Y*"=<.R<L("=<7%Q<)RDL("1A<F<I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($5X96-U=&5S(&$@8V]M;6%N9"!A;F0@<F5T=7)N<R!O=71P=70@;&EN
M97,@:6X@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VUD("!#;VUM86YD('1O(&)E
M(&5X96-U=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@07)R87D@
M;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V5X96-U=&4H)&-M9"D*("`@('L*("`@("`@("`D8VUD(#T@<W1R
M7W)E<&QA8V4H)R(M524B)RP@)RU.)RP@)&-M9"D["B`@("`@("`@97AE8R@D
M8VUD+"`D;W5T+"`D<F5T*3L*"B`@("`@("`@+R\@26X@<V]M92!C87-E<RP@
M*&QI:V4@=')Y:6YG('1O(&1E;&5T92!A(&YO;F5X:7-T86YT(&9I;&4I+`H@
M("`@("`@("\O('-M8F-L:65N="!W:6QL(')E='5R;B!S=6-C97-S("AA="!L
M96%S="!O;B`R+C(N-R!V97)S:6]N($DG;0H@("`@("`@("\O('1E<W1I;F<@
M;VXI+B!3;R!T<GD@=&\@;6%T8V@@97)R;W(@<W1R:6YG<RP@979E;B!A9G1E
M<B!S=6-C97-S+@H@("`@("`@(&EF("@D<F5T("$](#`I('L*("`@("`@("`@
M("`@)&5R<B`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D;W5T(&%S("1L
M:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1L:6YE+"`G57-A
M9V4Z)RD@/3T](#`I('L*("`@("`@("`@("`@("`@("`@("`D97)R(#T@)T-O
M;6UA;F0@<WEN=&%X(&EN8V]R<F5C="<["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M<W1R<&]S*"1L:6YE+"`G15)24U)6)RD@(3T](&9A;'-E('Q\"B`@("`@("`@
M("`@("`@("`@("`@<W1R<&]S*"1L:6YE+"`G15)21$]3)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<B`]('!R96=?<F5P;&%C92@G
M+RXJ7"@H+BLI7"DN*B\G+"`G7%PQ)RP@)&QI;F4I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@A)&5R<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M97)R(#T@)&QI;F4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@A)&5R<BD@>PH@("`@("`@("`@("`@("`@
M)&5R<B`]("1O=70@/R`D;W5T6V-O=6YT*"1O=70I("T@,5T@.B`D<F5T.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"1E<G(I.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&5R
M<F]R<R!E=F5N(&]N('-U8V-E<W,N"B`@("`@("`@)&5R<B`]("<G.PH@("`@
M("`@(&9O<F5A8V@@*"1O=70@87,@)&QI;F4I('L*("`@("`@("`@("`@:68@
M*'-T<G!O<R@D;&EN92P@)TY47U-405154U].3U]354-(7T9)3$4G*2`A/3T@
M9F%L<V4@?'P*("`@("`@("`@("`@("`@('-T<G!O<R@D;&EN92P@)TY47U-4
M05154U]/0DI%0U1?3D%-15].3U1?1D]53D0G*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1E<G(@/2!?*").;R!S=6-H(&9I;&4B*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S
M*"1L:6YE+"`G3E1?4U1!5%537T%#0T534U]$14Y)140G*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("1E<G(@/2!?*")097)M:7-S:6]N($1E;FEE
M9"(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D97)R*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"1E<G(I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1O=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!3
M34(@8V]M;6%N9',@+2!W:71H;W5T(&%U=&AE;G1I8V%T:6]N("T@86YD(')E
M='5R;G,@;W5T<'5T"B`@("`@*B!L:6YE<R!I;B!A<G)A>2X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A=&@@($)A<V4@<&%T:"!F;W(@8V]M;6%N9"X*("`@("`J($!P87)A
M;2!A<G)A>2`D8VUD("`@0V]M;6%N9',@=&\@8F4@97AE8W5T960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@07)R87D@;VX@<W5C8V5S<RP@9F%L
M<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;6UA;F0H
M)'!A=&@L("1C;60I"B`@("!["B`@("`@("`@;&ES="@D<VAA<F4I(#T@)'1H
M:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'1H:7,M/E]P87)A;7-;)W-H87)E
M)UTI.PH@("`@("`@('!U=&5N=B@G4$%34U=$/2<@+B`D=&AI<RT^7W!A<F%M
M<ULG<&%S<W=O<F0G72D["B`@("`@("`@)&EP;W!T:6]N(#T@*&ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=I<&%D9')E<W,G72DI(#\@*"<@+4D@)R`N("1T:&ES
M+3Y?<&%R86US6R=I<&%D9')E<W,G72D@.B!N=6QL.PH@("`@("`@("1F=6QL
M8VUD(#T@)'1H:7,M/E]P87)A;7-;)W-M8F-L:65N="==("X*("`@("`@("`@
M("`@)R`B+R\G("X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@+B`G+R<@
M+B`D<VAA<F4@+B`G(B<@+@H@("`@("`@("`@("`G("(M<"<@+B`D=&AI<RT^
M7W!A<F%M<ULG<&]R="==("X@)R(G("X*("`@("`@("`@("`@)R`B+54G("X@
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@+B`G(B<@+@H@("`@("`@("`@
M("`G("U$("(G("X@)'!A=&@@+B`G(B`G("X*("`@("`@("`@("`@)&EP;W!T
M:6]N("X*("`@("`@("`@("`@)R`M8R`B)SL*("`@("`@("!F;W)E86-H("@D
M8VUD(&%S("1C*2!["B`@("`@("`@("`@("1F=6QL8VUD("X]("1C("X@(CLB
M.PH@("`@("`@('T*("`@("`@("`D9G5L;&-M9"`N/2`G(B<["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?97AE8W5T92@D9G5L;&-M9"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971R:65V97,@82!F:6QE(&9R;VT@=&AE(%9&4R!A;F0@
M<W1O<F5S(&ET('1O(&$@=&5M<&]R87)Y(&9I;&4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!T96UP;W)A<GD@9FEL96YA
M;64@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C<F5A=&5496UP1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@
M("`@("`@;&ES="@D<&%T:"P@)&YA;64I(#T@)'1H:7,M/E]E<V-A<&53:&5L
M;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*("`@("`@("`D=&5M<"`]("1T:&ES
M+3Y?9V5T5&5M<$9I;&4H*3L*("`@("`@("`D8VUD(#T@87)R87DH)V=E="!<
M(B<@+B`D;F%M92`N("=<(B`G("X@)'1E;7`I.PH@("`@("`@("1E<G(@/2`D
M=&AI<RT^7V-O;6UA;F0H)'!A=&@L("1C;60I.PH@("`@("`@(&EF("AI<U]A
M*"1E<G(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1E
M<G(["B`@("`@("`@?0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'1E;7`I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI
M<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1E;7`["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U9&4R]'0RYP:'``````````````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8V-@`Q,#4Q-30S,3`V,``P,38V
M,C0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J($-L87-S(&9O<B!P<F]V:61I;F<@9V%R8F%G92!C;VQL
M96-T:6]N(&9O<B!A;GD@5D93(&EN<W1A;F-E+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]61E,O5D93+T=#+G!H<"QV(#$N-"XQ,BXX(#(P,#8O,#$O,#$@
M,C$Z,C@Z-#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?1T,@>PH*
M("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL96-T(&9I;&5S(&EN('1H92!6
M1E,@<W1O<F%G92!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M(%9&4R`F
M)'9F<R`@("`@(%1H92!61E,@;V)J96-T('1O('!E<F9O<FT@9V%R8F%G92!C
M;VQL96-T:6]N(&]N+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@(%1H
M92!61E,@<&%T:"!T;R!C;&5A;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1S
M96-S("!4:&4@;6EN:6UU;2!A;6]U;G0@;V8@=&EM92`H:6X@<V5C;VYD<RD@
M<F5Q=6ER960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!B969O<F4@
M82!F:6QE(&ES(')E;6]V960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=C*"8D
M=F9S+"`D<&%T:"P@)'-E8W,@/2`S-#4V,#`I"B`@("!["B`@("`@("`@+RH@
M02`Q)2!C:&%N8V4@=V4@=VEL;"!R=6X@9V%R8F%G92!C;VQL96-T:6]N(&1U
M<FEN9R!A(&-A;&PN("HO"B`@("`@("`@:68@*')A;F0H,"P@.3DI(#T](#`I
M('L*("`@("`@("`@("`@+RH@36%K92!S=7)E(&-L96%N:6YG(&ES(&1O;F4@
M<F5C=7)S:79E;'DN("HO"B`@("`@("`@("`@("1F:6QE<R`]("1V9G,M/FQI
M<W1&;VQD97(H)'!A=&@L(&YU;&PL('1R=64L(&9A;'-E+"!T<G5E*3L*("`@
M("`@("`@("`@:68@*"%I<U]A*"1F:6QE<RP@)U!%05)?17)R;W(G*2`F)B!I
M<U]A<G)A>2@D9FEL97,I*2!["B`@("`@("`@("`@("`@("`D;6]D=&EM92`]
M('1I;64H*2`M("1S96-S.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9I
M;&5S(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;%LG
M9&%T92==(#P@)&UO9'1I;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'9F<RT^9&5L971E1FEL92@D<&%T:"P@)'9A;%LG;F%M92==*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+W-Q;"YP
M:'``````````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,3`T-#`W`#$P-3$U-#,Q,#8P`#`Q-S$R-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RHJ"B`J($9I;&4@=F%L
M=64@9F]R('9F<U]T>7!E(&-O;'5M;BX*("HO"F1E9FEN92@G5D937T9)3$4G
M+"`Q*3L*"B\J*@H@*B!&;VQD97(@=F%L=64@9F]R('9F<U]T>7!E(&-O;'5M
M;BX*("HO"F1E9FEN92@G5D937T9/3$1%4B<L(#(I.PH*+RHJ"B`J(%9&4R!I
M;7!L96UE;G1A=&EO;B!F;W(@4$A0)W,@4$5!4B!D871A8F%S92!A8G-T<F%C
M=&EO;B!L87EE<BX*("H*("H@4F5Q=6ER960@=F%L=65S(&9O<B`D<&%R86US
M.CQP<F4^"B`J("`@("`@)W!H<'1Y<&4G("`@("`@(%1H92!D871A8F%S92!T
M>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J
M($]P=&EO;F%L('9A;'5E<SH\<')E/@H@*B`@("`@("=T86)L92<@("`@("`@
M("!4:&4@;F%M92!O9B!T:&4@=F9S('1A8FQE(&EN("=D871A8F%S92<N($1E
M9F%U;'1S('1O"B`J("`@("`@("`@("`@("`@("`@("`@("=H;W)D95]V9G,G
M+CPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B87-E(&EM<&QE
M;65N=&%T:6]N<SH\<')E/@H@*B`@("`@("=H;W-T<W!E8R<@("`@("!4:&4@
M:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`@("`G<')O
M=&]C;VPG("`@("`@5&AE(&-O;6UU;FEC871I;VX@<')O=&]C;VP@*"=T8W`G
M+"`G=6YI>"<L(&5T8RXI+@H@*B`@("`@("=D871A8F%S92<@("`@("!4:&4@
M;F%M92!O9B!T:&4@9&%T86)A<V4N"B`J("`@("`@)W5S97)N86UE)R`@("`@
M(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+@H@*B`@("`@("=P87-S=V]R9"<@("`@("!4:&4@<&%S<W=O<F0@
M87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@("`@)V]P=&EO;G,G
M("`@("`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O('1H92!D871A
M8F%S92X*("H@("`@("`G='1Y)R`@("`@("`@("`@5&AE(%1462!O;B!W:&EC
M:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`@("`G<&]R="<@
M("`@("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@
M9&%T86)A<V4N/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R
M('1H92!61E,@8V%N(&)E(&9O=6YD(&EN"B`J(&1A=&$O=F9S+G-Q;"X*("H*
M("H@1&%T86)A<V4@<W!E8VEF:6,@;F]T97,Z"B`J"B`J($U34U%,.@H@*B`\
M<')E/@H@*B`M(%1H92!V9G-?9&%T82!F:65L9"!M=7-T(&)E(&]F('1Y<&4@
M24U!1T4N"B`J("T@66]U(&YE960@=&AE(&9O;&QO=VEN9R!P:'`N:6YI('-E
M='1I;F=S.@H@*B`@("`[(%9A;&ED(')A;F=E(#`@+2`R,30W-#@S-C0W+B!$
M969A=6QT(#T@-#`Y-BX*("H@("`@;7-S<6PN=&5X=&QI;6ET(#T@,"`[('IE
M<F\@=&\@<&%S<R!T:')O=6=H"B`J"B`J("`@(#L@5F%L:60@<F%N9V4@,"`M
M(#(Q-#<T.#,V-#<N($1E9F%U;'0@/2`T,#DV+@H@*B`@("!M<W-Q;"YT97AT
M<VEZ92`](#`@.R!Z97)O('1O('!A<W,@=&AR;W5G:`H@*B`\+W!R93X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP+'8@,2XX-2XT
M+C(V(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E(%9&4PH@*B\*
M8VQA<W,@5D937W-Q;"!E>'1E;F1S(%9&4R!["@H@("`@+RHJ"B`@("`@*B!(
M86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@
M("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D8B`](&9A
M;'-E.PH*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!F:6QE<VEZ92!F
M<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT(%1H92!F:6QE('-I>F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-I>F4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C
M;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O
M;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN
M.PH@("`@("`@('T*"B`@("`@("`@)&QE;F=T:%]O<"`]("1T:&ES+3Y?9V5T
M1FEL95-I>F5/<"@I.PH@("`@("`@("1S<6P@/2!S<')I;G1F*`H@("`@("`@
M("`@("`G4T5,14-4("5S*'9F<U]D871A*2!&4D]-("5S(%=(15)%('9F<U]P
M871H(#T@/R!!3D0@=F9S7VYA;64@/2`_)RP*("`@("`@("`@("`@)&QE;F=T
M:%]O<"P*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT*("`@
M("`@("`I.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^7V-O;G9E
M<G10871H*"1P871H*2P@)&YA;64I.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q
M;"P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1S:7IE(#T@)'1H:7,M/E]D
M8BT^9V5T3VYE*"1S<6PL("1V86QU97,I.PH*("`@("`@("!I9B`H:7-?;G5L
M;"@D<VEZ92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7,O)7-<(BXB*2P@)'!A=&@L("1N86UE*2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'-I>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!S:7IE(&]F(&$@9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5&AE('-I>F4@;V8@=&AE(&9O;&1E<B!I;B!B>71E<R!O<B!014%27T5R<F]R
M(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$9O;&1E<E-I>F4H)'!A=&@@/2!N=6QL+"`D;F%M
M92`](&YU;&PI"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE
M8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@
M("`D=VAE<F4@/2`H:7-?;G5L;"@D<&%T:"DI(#\@;G5L;"`Z('-P<FEN=&8H
M)U=(15)%('9F<U]P871H(#T@)7,G+"`H*"%S=')L96XH)'!A=&@I*2`_("<B
M(B<@.B`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^7V-O;G9E<G10871H*"1P
M871H*2DI*3L*("`@("`@("`D;&5N9W1H7V]P(#T@)'1H:7,M/E]G971&:6QE
M4VEZ94]P*"D["B`@("`@("`@)'-Q;"`]('-P<FEN=&8H"B`@("`@("`@("`@
M("=314Q%0U0@4U5-*"5S*'9F<U]D871A*2D@1E)/32`E<R`E<R<L"B`@("`@
M("`@("`@("1L96YG=&A?;W`L"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==+`H@("`@("`@("`@("`D=VAE<F4*("`@("`@("`I.PH@("`@
M("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M("1S:7IE(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1S<6PI.PH*("`@("`@("!R
M971U<FX@)'-I>F4@(3T](&YU;&P@/R`D<VEZ92`Z(#`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971R:65V92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T
M;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F
M:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R96%D0FQO8B@D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P@)W9F<U]D871A)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G=F9S7W!A=&@G(#T^("1T:&ES+3Y?8V]N=F5R
M=%!A=&@H)'!A=&@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=V9G-?;F%M92<@/3X@)&YA;64I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E<R!A('!A<G0@;V8@82!F:6QE(&9R;VT@=&AE(%9&
M4RX@4&%R=&EC=6QA<FQY('5S969U;`H@("`@("H@=VAE;B!R96%D:6YG(&QA
M<F=E(&9I;&5S('=H:6-H('=O=6QD(&5X8V5E9"!T:&4@4$A0(&UE;6]R>0H@
M("`@("H@;&EM:71S(&EF('1H97D@=V5R92!S=&]R960@:6X@82!S=')I;F<N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A=&@@("`@("`@5&AE
M('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&YA;64@("`@("`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&]F9G-E="`@("`@5&AE(&]F9G-E="!O9B!T:&4@
M<&%R="X@*%1H92!N97<@;V9F<V5T('=I;&P@8F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T;W)E9"!I;B!H97)E*2X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1L96YG=&@@("`@(%1H92!L96YG=&@@;V8@=&AE('!A
M<G0N($EF('1H92!L96YG=&@@/2`M,2P@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!W:&]L92!P87)T(&%F=&5R('1H92!O9F9S970@
M:7,@<F5T<FEE=F5D+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;6]R92!B>71E<R!A<F4@9VEV96X@87,@97AI<W1S(&%F=&5R('1H
M92!G:79E;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V9F
M<V5T+B!/;FQY('1H92!A=F%I;&%B;&4@8GET97,@87)E(')E860N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<F5M86EN:6YG("!4:&4@8GET97,@=&AA="!A
M<F4@;&5F="P@869T97(@=&AE('!A<G0@=&AA="!I<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T<FEE=F5D+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E861087)T*"1P871H+"`D;F%M92P@)B1O9F9S970L("1L96YG
M=&@@/2`M,2P@)B1R96UA:6YI;F<I"B`@("!["B`@("`@("`@)&-O;FX@/2`D
M=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@
M("`@?0H*("`@("`@("`D9&%T82`]("1T:&ES+3Y?<F5A9$)L;V(H)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTL("=V9G-?9&%T82<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=V9G-?<&%T:"<@/3X@)'1H:7,M
M/E]C;VYV97)T4&%T:"@D<&%T:"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=V9G-?;F%M92<@/3X@)&YA;64I*3L*"B`@("`@
M("`@+R\@0V%L8W5L871E(&AO=R!M86YY(&)Y=&5S($U54U0@8F4@<F5A9"P@
M<V\@=&AE(')E;6%I;F=I;F<*("`@("`@("`O+R!B>71E<R!A;F0@=&AE(&YE
M=R!O9F9S970@8V%N(&)E(&-A;&-U;&%T960@8V]R<F5C=&QY+@H@("`@("`@
M("1S:7IE(#T@<W1R;&5N("@D9&%T82D["B`@("`@("`@:68@*"1L96YG=&@@
M/3T@+3$@?'P@*"@D;&5N9W1H("L@)&]F9G-E="D@/B`D<VEZ92DI('L*("`@
M("`@("`@("`@)&QE;F=T:"`]("1S:7IE("T@)&]F9G-E=#L*("`@("`@("!]
M"B`@("`@("`@:68@*"1R96UA:6YI;F<@/"`P*2!["B`@("`@("`@("`@("1R
M96UA:6YI;F<@/2`P.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2!S=6)S
M='(H)&1A=&$L("1O9F9S970L("1L96YG=&@I.PH@("`@("`@("1O9F9S970@
M/2`D;V9F<V5T("L@)&QE;F=T:#L*("`@("`@("`D<F5M86EN:6YG(#T@)'-I
M>F4@+2`D;V9F<V5T.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3=&]R97,@82!F:6QE(&EN('1H92!61E,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H
M('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T;7!&:6QE("`@("`@5&AE('1E;7!O<F%R>2!F:6QE(&-O
M;G1A:6YI;F<@=&AE(&1A=&$@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B92!S=&]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=W)I=&4H)'!A=&@L("1N86UE+"`D=&UP1FEL92P@)&%U
M=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("`O*B!$;VXG="!N965D
M('1O(&-H96-K('%U;W1A(&AE<F4@<VEN8V4@:70@=VEL;"!B92!C:&5C:V5D
M('=H96X*("`@("`@("`@*B!W<FET941A=&$H*2!I<R!C86QL960N("HO"B`@
M("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G
M*2D@>PH@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1T
M;7!&:6QE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<VEZ92`]
M(&9I;&5S:7IE*"1T;7!&:6QE*3L*("`@("`@("`@("`@:68@*"1S:7IE(#T]
M/2`P*2!["B`@("`@("`@("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D871A1E`@/2!`9F]P
M96XH)'1M<$9I;&4L("=R8B<I.PH@("`@("`@("`@("`@("`@:68@*"$D9&%T
M8490*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(I+"`D=&UP1FEL92DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&1A=&$@/2!`9G)E860H)&1A=&%&4"P@)'-I
M>F4I.PH@("`@("`@("`@("`@("`@0&9C;&]S92@D9&%T8490*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YW<FET
M941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@)&%U=&]C<F5A=&4I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4W1O<F4@82!F:6QE(&EN('1H92!61E,@9G)O
M;2!R87<@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O
M('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@
M9FEL92!D871A+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@
M($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=R:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T;V-R96%T92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O
M=&%7<FET92@G<W1R:6YG)RP@)&1A=&$I.PH@("`@("`@(&EF("AI<U]A*"1R
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1P
M871H(#T@)'1H:7,M/E]C;VYV97)T4&%T:"@D<&%T:"D["@H@("`@("`@("\J
M($-H96-K('1O('-E92!I9B!T:&4@9&%T82!A;')E861Y(&5X:7-T<RX@*B\*
M("`@("`@("`D<W%L(#T@<W!R:6YT9B@G4T5,14-4('9F<U]I9"!&4D]-("5S
M(%=(15)%('9F<U]P871H("5S($%.1"!V9G-?;F%M92`](#\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("AE;7!T>2@D<&%T:"D@)B8@)'1H:7,M/E]D
M8BT^9&)S>6YT87@@/3T@)V]C:3@G*2`_("<@25,@3E5,3"<@.B`G(#T@)R`N
M("1T:&ES+3Y?9&(M/G%U;W1E*"1P871H*2D["B`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"1N86UE*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YG971/;F4H
M)'-Q;"P@)'9A;'5E<RD["@H@("`@("`@(&EF("AI<U]A*"1I9"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G*"1I9"P@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A:7-?;G5L;"@D:60I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W5P9&%T94)L;V(H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M("=V9G-?9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&$L(&%R<F%Y*"=V9G-?:60G(#T^("1I9"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W9F<U]M;V1I
M9FEE9"<@/3X@=&EM92@I*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@0VAE8VL@=&\@<V5E(&EF('1H92!F;VQD97(@86QR96%D>2!E>&ES
M=',N("HO"B`@("`@("`@("`@("1D:7)S(#T@97AP;&]D92@G+R<L("1P871H
M*3L*("`@("`@("`@("`@)'!A=&A?;F%M92`](&%R<F%Y7W!O<"@D9&ER<RD[
M"B`@("`@("`@("`@("1P87)E;G0@/2!I;7!L;V1E*"<O)RP@)&1I<G,I.PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3YI<T9O;&1E<B@D<&%R96YT+"`D<&%T
M:%]N86UE*2D@>PH@("`@("`@("`@("`@("`@:68@*"$D875T;V-R96%T92D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(BDL("1P871H
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T
M95!A=&@H)'!A=&@I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D:60@
M/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H)&ED+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;G-E<G1";&]B*"1T:&ES+3Y?
M<&%R86US6R=T86)L92==+"`G=F9S7V1A=&$G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D871A+"!A<G)A>2@G=F9S7VED)R`]
M/B`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=V9G-?='EP92<@/3X@5D937T9)3$4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V
M9G-?<&%T:"<@/3X@)'!A=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=V9G-?;F%M92<@/3X@)&YA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=V9G-?;6]D:69I960G(#T^('1I;64H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9F<U]O
M=VYE<B<@/3X@)'1H:7,M/E]P87)A;7-;)W5S97(G72DI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9I;&4@9G)O;2!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE
M=&5&:6QE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D<F5S(#T@)'1H
M:7,M/E]C:&5C:U%U;W1A1&5L971E*"1P871H+"`D;F%M92D["B`@("`@("`@
M:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@)'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H*"1P871H*3L*
M"B`@("`@("`@)'-Q;"`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%
M('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@)7,@04Y$('9F<U]N86UE(#T@
M/R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@*&5M<'1Y*"1P871H*2`F
M)B`D=&AI<RT^7V1B+3YD8G-Y;G1A>"`]/2`G;V-I."<I(#\@)R!)4R!.54Q,
M)R`Z("<@/2`G("X@)'1H:7,M/E]D8BT^<75O=&4H)'!A=&@I*3L*("`@("`@
M("`D=F%L=65S(#T@87)R87DH5D937T9)3$4L("1N86UE*3L*("`@("`@("`D
M=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-Q;"P@)'9A;'5E<RD["@H@("`@
M("`@(&EF("@D=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;64@82!F
M:6QE(&]R(&9O;&1E<B!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&]L9&YA;64@(%1H92!O;&0@9FEL96YA
M;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A
M=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE
M("!4:&4@;F5W(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T
M:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D*("`@('L*("`@("`@
M("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A
M*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M8V]N;CL*("`@("`@("!]"@H@("`@("`@(&EF("AS=')P;W,H)&YE=W!A=&@L
M("<O)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)E;G0@/2`G)SL*
M("`@("`@("`@("`@)'!A=&@@/2`D;F5W<&%T:#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!L:7-T*"1P87)E;G0L("1P871H*2`](&5X<&QO9&4H
M)R\G+"`D;F5W<&%T:"P@,BD["B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H
M:7,M/FES1F]L9&5R*"1P87)E;G0L("1P871H*2D@>PH@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1N97=P
M871H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1O
M;&1P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T:"@D;VQD<&%T:"D["B`@("`@
M("`@)&YE=W!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H*"1N97=P871H*3L*
M"B`@("`@("`@)'-Q;"`@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G73L*("`@("`@("`D<W%L("X]("<@4T54('9F<U]P871H(#T@/RP@
M=F9S7VYA;64@/2`_+"!V9G-?;6]D:69I960@/2`_(%=(15)%('9F<U]P871H
M(#T@/R!!3D0@=F9S7VYA;64@/2`_)SL*("`@("`@("`D=&AI<RT^;&]G*"1S
M<6PL(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"1N97=P871H+"`D;F5W;F%M92P@=&EM92@I+"`D;VQD<&%T:"P@)&]L9&YA
M;64I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-Q
M;"P@)'9A;'5E<RD["@H@("`@("`@(&EF("@D=&AI<RT^7V1B+3YA9F9E8W1E
M9%)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@)')E;F%M92`]("1T:&ES+3Y?<F5C=7)S:79E4F5N
M86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*3L*
M("`@("`@("!I9B`H:7-?82@D<F5N86UE+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1T:&ES+3YL;V<H)')E;F%M92P@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(I+"`D<F5N
M86UE+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&9O
M;&1E<B!O;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@($AO;&1S('1H92!P871H(&]F(&1I<F5C=&]R>2!T;R!C<F5A=&4@
M9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@2&]L9',@=&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E1F]L
M9&5R*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES
M+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]
M"@H@("`@("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72D["B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YL;V<H)&ED+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@('T*"B`@
M("`@("`@)'-Q;"`@/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US
M6R=T86)L92==.PH@("`@("`@("1S<6P@+CT@)R`H=F9S7VED+"!V9G-?='EP
M92P@=F9S7W!A=&@L('9F<U]N86UE+"!V9G-?;6]D:69I960L('9F<U]O=VYE
M<BD@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_*2<["B`@("`@("`@)'1H:7,M
M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1V86QU97,@
M/2!A<G)A>2@D:60L(%9&4U]&3TQ$15(L("1T:&ES+3Y?8V]N=F5R=%!A=&@H
M)'!A=&@I+"`D;F%M92P@=&EM92@I+"`D=&AI<RT^7W!A<F%M<ULG=7-E<B==
M*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V
M86QU97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R
M(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9F]L9&5R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&9O;&1E<B!N86UE('1O('5S
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@
M<F5C=7)S:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H)'!A
M=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D
M8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O
M;FX["B`@("`@("`@?0H*("`@("`@("`D<&%T:"`]("1T:&ES+3Y?8V]N=F5R
M=%!A=&@H)'!A=&@I.PH*("`@("`@("`D9F]L9&5R4&%T:"`]("1T:&ES+3Y?
M9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I.PH*("`@("`@("`O*B!#:&5C
M:R!I9B!N;W0@<F5C=7)S:79E(&%N9"!F86EL(&EF(&1I<F5C=&]R>2!N;W0@
M96UP='D@*B\*("`@("`@("!I9B`H(21R96-U<G-I=F4I('L*("`@("`@("`@
M("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9F]L9&5R4&%T
M:"P@;G5L;"P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1F;VQD97),
M:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*"1F;VQD97),:7-T+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1F;VQD97),:7-T.PH@("`@("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1F;VQD97),:7-T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%T:"`N
M("<O)R`N("1N86UE*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J($9I<G-T(&1E;&5T92!E=F5R>71H:6YG(&)E;&]W('1H92!F;VQD
M97(L('-O(&EF(&5R<F]R('=E"B`@("`@("`@("H@9V5T(&YO(&]R<&AA;G,@
M*B\*("`@("`@("`D<W%L(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%
M4D4@=F9S7W!A=&@@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("AE
M;7!T>2@D9F]L9&5R4&%T:"D@)B8@)'1H:7,M/E]D8BT^9&)S>6YT87@@/3T@
M)V]C:3@G*2`_("<@25,@3E5,3"<@.B`G($Q)2T4@)R`N("1T:&ES+3Y?9&(M
M/G%U;W1E*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D9F]L9&5R4&%T:"P@)R4G
M*2DI.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("1D96QE=&5#;VYT96YT<R`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1S<6PI.PH@("`@("`@(&EF("AI<U]A*"1D96QE=&5#;VYT96YT<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G*"1D96QE=&5#
M;VYT96YT<RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%9&
M4R!R96-U<G-I=F5L>3H@)7,N(BDL("1D96QE=&5#;VYT96YT<RT^9V5T365S
M<V%G92@I*2D["B`@("`@("`@?0H*("`@("`@("`O*B!.;W<@9&5L971E(&5V
M97)Y=&AI;F<@:6YS:61E('1H92!F;VQD97(N("HO"B`@("`@("`@)'-Q;"`]
M('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('9F<U]P871H("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72P*("`@("`@("`@("`@("`@("`@("`@("`H96UP='DH)'!A=&@I("8F("1T
M:&ES+3Y?9&(M/F1B<WEN=&%X(#T]("=O8VDX)RD@/R`G($E3($Y53$PG(#H@
M)R`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D9F]L9&5R4&%T:"DI.PH@("`@
M("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M("1D96QE=&4@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<W%L*3L*("`@("`@("!I
M9B`H:7-?82@D9&5L971E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1T:&ES+3YL;V<H)&1E;&5T92P@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(I+"`D9&5L971E+3YG971-
M97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@("\J($%L;"!O:R!N;W<@
M9&5L971E('1H92!A8W1U86P@9F]L9&5R("HO"B`@("`@("`@)'-Q;"`]('-P
M<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('9F<U]P871H("5S($%.1"!V
M9G-?;F%M92`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("AE;7!T
M>2@D<&%T:"D@)B8@)'1H:7,M/E]D8BT^9&)S>6YT87@@/3T@)V]C:3@G*2`_
M("<@25,@3E5,3"<@.B`G(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1P871H
M*2D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N86UE*3L*("`@("`@("`D
M=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D9&5L
M971E(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-Q;"P@)'9A;'5E<RD["B`@("`@
M("`@:68@*&ES7V$H)&1E;&5T92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^;&]G*"1D96QE=&4L(%!%05)?3$]'7T524BD["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB*2P@)&1E;&5T92T^
M9V5T365S<V%G92@I*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1E
M;&5T93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@
M=&AE(&-O;G1E;G1S(&]F(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@("`@("`@5&AE(&1I<F5C=&]R>2!P871H+@H@("`@
M("H@0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("!3=')I;F<O:&%S:"!O9B!I
M=&5M<R!T;R!F:6QT97(@8F%S960@;VX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9FEL96YA;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D9&ER;VYL>2`@(%-H;W<@9&ER96-T;W)I97,@;VYL>3\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!&:6QE(&QI<W0@;VX@<W5C8V5S<R!O<B!F
M86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES=$9O
M;&1E<B@D<&%T:"P@)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A;'-E*0H@
M("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@
M("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)'!A=&@@/2`D
M=&AI<RT^7V-O;G9E<G10871H*"1P871H*3L*"B`@("`@("`@+R\@1FEX(&9O
M<B!/<F%C;&4@;F]T(&1I9F9E<F5N=&EA=&EN9R!B971W965N("<G(&%N9"!.
M54Q,+@H@("`@("`@(&EF("AE;7!T>2@D<&%T:"D@)B8@)'1H:7,M/E]D8BT^
M9&)S>6YT87@@/3T@)V]C:3@G*2!["B`@("`@("`@("`@("1W:&5R92`]("=V
M9G-?<&%T:"!)4R!.54Q,)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=VAE<F4@/2`G=F9S7W!A=&@@/2`G("X@)'1H:7,M/E]D8BT^<75O=&4H
M)'!A=&@I.PH@("`@("`@('T*"B`@("`@("`@)&QE;F=T:%]O<"`]("1T:&ES
M+3Y?9V5T1FEL95-I>F5/<"@I.PH@("`@("`@("1S<6P@/2!S<')I;G1F*"=3
M14Q%0U0@=F9S7VYA;64L('9F<U]T>7!E+"`E<RAV9G-?9&%T82DL('9F<U]M
M;V1I9FEE9"P@=F9S7V]W;F5R($923TT@)7,@5TA%4D4@)7,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("1L96YG=&A?;W`L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@)'=H97)E*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%
M05)?3$]'7T1%0E5'*3L*("`@("`@("`D9FEL94QI<W0@/2`D=&AI<RT^7V1B
M+3YG971!;&PH)'-Q;"D["B`@("`@("`@:68@*&ES7V$H)&9I;&5,:7-T+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL94QI<W0[
M"B`@("`@("`@?0H*("`@("`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D;&EN92D@>PH@("`@("`@("`@("`O
M+R!&:6QT97(@;W5T(&1O=&9I;&5S(&EF('1H97D@87)E;B=T('=A;G1E9"X*
M("`@("`@("`@("`@:68@*"$D9&]T9FEL97,@)B8@<W5B<W1R*"1L:6YE6S!=
M+"`P+"`Q*2`]/2`G+B<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL95LG;F%M92==(#T@)&QI
M;F5;,%T["@H@("`@("`@("`@("!I9B`H)&QI;F5;,5T@/3T@5D937T9)3$4I
M('L*("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G+B<L("1L:6YE
M6S!=*3L*"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&YA;64I(#T](#$I
M('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ;F]N
M92<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z.G-T<G1O;&]W97(H)&YA;65;8V]U
M;G0H)&YA;64I("T@,5TI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1F:6QE6R=S:7IE)UT@/2`D;&EN95LR73L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1L:6YE6S%=(#T](%9&4U]&3TQ$15(I('L*("`@("`@("`@
M("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BID:7(G.PH@("`@("`@("`@("`@
M("`@)&9I;&5;)W-I>F4G72`]("TQ.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D9FEL95LG9&%T92==(#T@)&QI;F5;,UT["B`@("`@("`@("`@("1F
M:6QE6R=O=VYE<B==(#T@)&QI;F5;-%T["B`@("`@("`@("`@("1F:6QE6R=P
M97)M<R==(#T@)R<["B`@("`@("`@("`@("1F:6QE6R=G<F]U<"==(#T@)R<[
M"@H@("`@("`@("`@("`O+R!F:6QT97)I;F<*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?9FEL=&5R36%T8V@H)&9I;'1E<BP@)&9I;&5;)VYA;64G72DI('L*
M("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9&ER
M;VYL>2`F)B`D9FEL95LG='EP92==("$]/2`G*BID:7(G*2!["B`@("`@("`@
M("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5S6R1F:6QE6R=N
M86UE)UU=(#T@)&9I;&4["B`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!S;W)T960@;&ES="!O9B!F;VQD97)S(&EN('-P
M96-I9FEE9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=&\@
M9V5T('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1I
M<F5C=&]R>2!L:7-T(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R
M("`@("`@("!3=')I;F<O:&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;VQD97)L
M:7-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9O;&1E<G,@($EN8VQU
M9&4@9&]T9F]L9&5R<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&
M;VQD97(@;&ES="!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD97)S*"1P
M871H(#T@)R<L("1F:6QT97(@/2!A<G)A>2@I+"`D9&]T9F]L9&5R<R`]('1R
M=64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*
M("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D<&%T
M:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I.PH*("`@("`@("`D<W%L
M("`]("=314Q%0U0@=F9S7VYA;64L('9F<U]P871H($923TT@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==.PH@("`@("`@("1S<6P@+CT@)R!72$5212!V
M9G-?<&%T:"`](#\@04Y$('9F<U]T>7!E(#T@/R<["B`@("`@("`@)'1H:7,M
M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1V86QU97,@
M/2!A<G)A>2@D<&%T:"P@5D937T9/3$1%4BD["@H@("`@("`@("1F;VQD97),
M:7-T(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1S<6PL("1V86QU97,I.PH@("`@
M("`@(&EF("AI<U]A*"1F;VQD97),:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D9F]L9&5R3&ES=#L*("`@("`@("!]"@H@("`@
M("`@("1F;VQD97)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9F]L
M9&5R3&ES="!A<R`D;&EN92D@>PH@("`@("`@("`@("`D9F]L9&5R6R=V86PG
M72`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;&EN95LQ72P@)&QI;F5;,%TI
M.PH@("`@("`@("`@("`D9F]L9&5R6R=A8F)R978G72`]("<G.PH@("`@("`@
M("`@("`D9F]L9&5R6R=L86)E;"==(#T@)R<["@H@("`@("`@("`@("`D8V]U
M;G0@/2!S=6)S=')?8V]U;G0H)&9O;&1E<ELG=F%L)UTL("<O)RD["@H@("`@
M("`@("`@("`D>"`](#`["B`@("`@("`@("`@('=H:6QE("@D>"`\("1C;W5N
M="D@>PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@)R`@
M("`G.PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG;&%B96PG72`N/2`G("`@
M("<["B`@("`@("`@("`@("`@("`D>"LK.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D9F]L9&5R6R=A8F)R978G72`N/2`D;&EN95LP73L*("`@("`@
M("`@("`@)&9O;&1E<ELG;&%B96PG72`N/2`D;&EN95LP73L*"B`@("`@("`@
M("`@("1S=')L96X@/2!61E,Z.G-T<FQE;B@D9F]L9&5R6R=L86)E;"==*3L*
M("`@("`@("`@("`@:68@*"1S=')L96X@/B`R-BD@>PH@("`@("`@("`@("`@
M("`@)&9O;&1E<ELG86)B<F5V)UT@/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG
M72P@,"P@*"1C;W5N="`J(#0I*3L*("`@("`@("`@("`@("`@("1L96YG=&@@
M/2`H,CD@+2`H)&-O=6YT("H@-"DI("\@,CL*("`@("`@("`@("`@("`@("1F
M;VQD97);)V%B8G)E=B==("X]('-U8G-T<B@D9F]L9&5R6R=L86)E;"==+"`H
M)&-O=6YT("H@-"DL("1L96YG=&@I.PH@("`@("`@("`@("`@("`@)&9O;&1E
M<ELG86)B<F5V)UT@+CT@)RXN+B<["B`@("`@("`@("`@("`@("`D9F]L9&5R
M6R=A8F)R978G72`N/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG72P@+3$@*B`D
M;&5N9W1H+"`D;&5N9W1H*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&9O=6YD(#T@9F%L<V4["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QT97(@
M87,@)&9L='(I('L*("`@("`@("`@("`@("`@(&EF("@D9F]L9&5R6R=V86PG
M72`]/2`D9FQT<BD@>PH@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("`D9F]L9&5R<ULD
M9F]L9&5R6R=V86PG75T@/2`D9F]L9&5R.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!K<V]R="@D9F]L9&5R<RD["B`@("`@("`@<F5T=7)N
M("1F;VQD97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE<R!A;&P@
M8VAI;&0@<&%T:',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@
M=&AE(&9O;&1E<B!T;R!R96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@9F]L9&5R;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E8W5R
M<VEV95)E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W
M;F%M92D*("`@('L*("`@("`@("`D;VQD<&%T:"`]("1T:&ES+3Y?8V]N=F5R
M=%!A=&@H)&]L9'!A=&@I.PH@("`@("`@("1N97=P871H(#T@)'1H:7,M/E]C
M;VYV97)T4&%T:"@D;F5W<&%T:"D["@H@("`@("`@("1S<6P@(#T@)U-%3$5#
M5"!V9G-?;F%M92!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G73L*
M("`@("`@("`D<W%L("X]("<@5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?
M<&%T:"`](#\G.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH5D937T9/3$1%4BP@
M)'1H:7,M/E]G971.871I=F50871H*"1O;&1P871H+"`D;VQD;F%M92DI.PH*
M("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3Y?9&(M/F=E=$-O;"@D<W%L
M+"`P+"`D=F%L=65S*3L*"B`@("`@("`@9F]R96%C:"`H)&9O;&1E<DQI<W0@
M87,@)&9O;&1E<BD@>PH@("`@("`@("`@("`D=&AI<RT^7W)E8W5R<VEV95)E
M;F%M92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&]L9'!A=&@L("1O;&1N86UE
M*2P@)&9O;&1E<BP@)'1H:7,M/E]G971.871I=F50871H*"1N97=P871H+"`D
M;F5W;F%M92DL("1F;VQD97(I.PH@("`@("`@('T*"B`@("`@("`@)'-Q;"`]
M("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@)R!3150@
M=F9S7W!A=&@@/2`_(%=(15)%('9F<U]P871H(#T@/R<["B`@("`@("`@)'1H
M:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1V86QU
M97,@/2!A<G)A>2@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&YE=W!A=&@L("1N
M97=N86UE*2P@)'1H:7,M/E]G971.871I=F50871H*"1O;&1P871H+"`D;VQD
M;F%M92DI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M)'-Q;"P@)'9A;'5E<RD["@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@9G5L;"!F:6QE;F%M92!O;B!T
M:&4@;F%T:79E(&9I;&5S>7-T96TL(&9R;VT@82!61E,*("`@("`J('!A=&@@
M86YD(&YA;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(%9&4R!F:6QE('!A
M=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@5D93(&9I;&5N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"!N
M871I=F4@9FEL96YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971.871I
M=F50871H*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H96UP='DH
M)'!A=&@I*2!["B`@("`@("`@("`@(')E='5R;B`D;F%M93L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A96UP='DH)'!A=&@I*2!["B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]M92==*2`F)@H@("`@("`@("`@
M("`@("`@<')E9U]M871C:"@G?%Y^+S\H+BHI)'PG+"`D<&%T:"P@)&UA=&-H
M97,I*2!["B`@("`@("`@("`@("`@("`D<&%T:"`]("1T:&ES+3Y?<&%R86US
M6R=H;VUE)UT@+B`G+R<@+B`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P871H("X@)R\G("X@)&YA;64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@<&5R
M<VES=&5N="!C;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]D8B`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A<F%M<RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<75I<F5D(#T@
M87)R87DH)W!H<'1Y<&4G*3L*("`@("`@("`@("`@9F]R96%C:"`H)')E<75I
M<F5D(&%S("1V86PI('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P87)A;7-;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB*2P@)'9A
M;"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=D871A8F%S92==*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@
M/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@/2`G)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=H;W-T
M<W!E8R==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO
M<W1S<&5C)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T86)L92==*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:&]R9&5?=F9S)SL*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@
M4U%,('-E<G9E<B!U<VEN9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@*B\*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("`@("`@
M("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P
M97)S:7-T96YT)R`]/B`A96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E
M;G0G72DI*3L*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@D=&AI
M<RT^7V1B+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@)&5R<F]R
M(#T@)'1H:7,M/E]D8CL*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(@/2!F
M86QS93L*("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@
M("`@('T*"@H@("`@("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T
M:6]N<RX*("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YP:'!T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)4
M04))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$
M0E]03U)404))3$E465]25%))32D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],
M3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH@("`@("`@("`@
M("!]"@H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R;VT@=&AE(%-13"!S97)V97(@
M86YD(&-L96%N('5P('1H92!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C
M="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&(I('L*("`@("`@("`@
M("`@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("`D=&AI
M<RT^7V1B(#T@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1A8FQE("`@("!43T1/"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:65L9"`@("`@5$]$3PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D8W)I=&5R:6$@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96%D0FQO8B@D=&%B
M;&4L("1F:65L9"P@)&-R:71E<FEA*0H@("`@>PH@("`@("`@(&EF("@A8V]U
M;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G66]U(&UU<W0@<W!E8VEF>2!T:&4@9F5T8V@@8W)I=&5R:6$G
M*3L*("`@("`@("!]"@H@("`@("`@("1W:&5R92`]("<G.PH*("`@("`@("!S
M=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X*2!["B`@("`@("`@8V%S92`G
M;V-I."<Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1C<FET97)I82!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=VAE
M<F4I*2!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E("X]("<@04Y$("<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R92`N/2`D:V5Y
M("X@)R!)4R!.54Q,)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'=H97)E("X]("1K97D@+B`G(#T@)R`N("1T:&ES
M+3Y?9&(M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE;G0@/2!/0TE087)S92@D
M=&AI<RT^7V1B+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%4D4@
M)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEE;&0L("1T86)L92P@)'=H97)E*2D["B`@("`@("`@("`@($]#245X
M96-U=&4H)'-T871E;65N="D["B`@("`@("`@("`@(&EF("A/0TE&971C:$EN
M=&\H)'-T871E;65N="P@)&QO8BDI('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D;&]B6S!=+3YL;V%D*"D["B`@("`@("`@("`@("`@("!I9B`H:7-?
M;G5L;"@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'0@
M/2!014%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@;&]A9"!344P@9&%T82XG
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR86ES945R<F]R*"=5;F%B
M;&4@=&\@;&]A9"!344P@9&%T82XG*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T96UE;G0I.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@9F]R96%C
M:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1W:&5R92DI('L*("`@("`@("`@("`@("`@("`@
M("`D=VAE<F4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1W:&5R92`N/2`D:V5Y("X@)R`]("<@+B`D=&AI<RT^7V1B
M+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<W%L(#T@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%4D4@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&0L("1T86)L92P@)'=H
M97)E*3L*("`@("`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YG971/
M;F4H)'-Q;"D["@H@("`@("`@("`@("!I9B`H:7-?;G5L;"@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`@("`@)')E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H
M)U5N86)L92!T;R!L;V%D(%-13"!D871A+B<I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YD8G-Y
M;G1A>"D@>PH@("`@("`@("`@("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@
M("`@("`@("`@("`@("1R97-U;'0@/2!P86-K*"=()R`N('-T<FQE;B@D<F5S
M=6QT*2P@)')E<W5L="D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$
M3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1A8FQE("`@("`@(%1/1$\*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I96QD("`@("`@(%1/1$\*("`@("`J($!P87)A;2!S=')I
M;F<@)&1A=&$@("`@("`@(%1/1$\*("`@("`J($!P87)A;2!S=')I;F<@)&%T
M=')I8G5T97,@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M3T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;G-E<G1";&]B*"1T86)L92P@
M)&9I96QD+"`D9&%T82P@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@)&9I
M96QD<R`](&%R<F%Y*"D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["@H@
M("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT87@I('L*("`@("`@
M("!C87-E("=O8VDX)SH*("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T
M97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("1F:65L
M9'-;72`]("1K97D["B`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D=&AI
M<RT^7V1B+3YQ=6]T95-M87)T*"1V86QU92D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1S=&%T96UE;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+3YC
M;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*"5S+"`E<RDG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!604Q515,@*"5S
M+"!%35!465]"3$]"*"DI(%)%5%523DE.1R`E<R!)3E1/(#IB;&]B)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M;7!L;V1E*"<L("<L("1F:65L9',I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9FEE;&0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)'9A;'5E
M<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F:65L9"DI.PH*("`@("`@("`@("`@)&QO8B`]($]#24YE=T1E<V-R:7!T
M;W(H)'1H:7,M/E]D8BT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@($]#24)I
M;F1">4YA;64H)'-T871E;65N="P@)SIB;&]B)RP@)&QO8BP@+3$L(%-13%1?
M0DQ/0BD["B`@("`@("`@("`@($]#245X96-U=&4H)'-T871E;65N="P@3T-)
M7T1%1D%53%0I.PH@("`@("`@("`@("`D;&]B+3YS879E*"1D871A*3L*("`@
M("`@("`@("`@)')E<W5L="`]($]#24-O;6UI="@D=&AI<RT^7V1B+3YC;VYN
M96-T:6]N*3L*("`@("`@("`@("`@)&QO8BT^9G)E92@I.PH@("`@("`@("`@
M("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T96UE;G0I.PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L="`_('1R=64@.B!014%2.CIR86ES945R<F]R*"=5;FMN
M;W=N($5R<F]R)RD["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("`@("`D9FEE;&1S6UT@/2`D:V5Y.PH@("`@("`@("`@("`@("`@
M)'9A;'5E<UM=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H)7,L("5S*2!6
M04Q515,@*"5S*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@
M)RP@)&9I96QD<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I
M96QD+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<_)R`N('-T<E]R
M97!E870H)RP@/R<L(&-O=6YT*"1V86QU97,I*2D["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YD
M8G-Y;G1A>"D@>PH@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("!C87-E
M("=P9W-Q;"<Z"B`@("`@("`@("`@("1V86QU97-;72`](&)I;C)H97@H)&1A
M=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@)'9A;'5E<UM=(#T@)&1A=&$["B`@("`@("`@?0H*("`@("`@
M("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D=&AI<RT^;&]G
M*"1Q=65R>2P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A8FQE("`@("`@5$]$3PH@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@("`@("!43T1/"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A("`@("`@(%1/1$\*("`@("`J($!P87)A;2!S
M=')I;F<@)'=H97)E("`@("`@5$]$3PH@("`@("H@0'!A<F%M(&%R<F%Y("1A
M;'-O=7!D871E("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?=7!D871E0FQO8B@D=&%B;&4L
M("1F:65L9"P@)&1A=&$L("1W:&5R92P@)&%L<V]U<&1A=&4I"B`@("!["B`@
M("`@("`@)&9I96QD<R`](&%R<F%Y*"D["B`@("`@("`@)'9A;'5E<R`](&%R
M<F%Y*"D["@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT87@I
M('L*("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@)'=H97)E<W1R
M:6YG(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1W:&5R92!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=VAE
M<F5S=')I;F<I*2!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG
M("X]("<@04Y$("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=VAE<F5S=')I;F<@+CT@)&ME>2`N("<@/2`G("X@)'1H:7,M/E]D8BT^
M<75O=&4H)'9A;'5E*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-T
M871E;65N="`]($]#25!A<G-E*"1T:&ES+3Y?9&(M/F-O;FYE8W1I;VXL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*"=314Q%
M0U0@)7,@1E)/32`E<R!72$5212`E<R!&3U(@55!$051%)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&%B;&4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M:&5R97-T<FEN9RDI.PH*("`@("`@("`@("`@3T-)17AE8W5T92@D<W1A=&5M
M96YT+"!/0TE?1$5&055,5"D["B`@("`@("`@("`@($]#249E=&-H26YT;R@D
M<W1A=&5M96YT+"`D;&]B*3L*("`@("`@("`@("`@)&QO8ELP72T^<V%V92@D
M9&%T82D["B`@("`@("`@("`@("1R97-U;'0@/2!/0TE#;VUM:70H)'1H:7,M
M/E]D8BT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1L;V);,%TM/F9R964H
M*3L*("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0@/R!T<G5E(#H@4$5!4CHZ<F%I
M<V5%<G)O<B@G56YK;F]W;B!%<G)O<B<I.PH*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`D=7!D871E<W1R:6YG(#T@)R<["B`@("`@("`@("`@("1V
M86QU97,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D86QS;W5P
M9&%T92!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@)'5P
M9&%T97-T<FEN9R`N/2`D:V5Y("X@)R`](#\L("<["B`@("`@("`@("`@("`@
M("`D=F%L=65S6UT@/2`D=F%L=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'5P9&%T97-T<FEN9R`N/2`D9FEE;&0@+B`G(#T@/R<["B`@("`@("`@
M("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT87@I('L*("`@("`@("`@
M("`@8V%S92`G;7-S<6PG.@H@("`@("`@("`@("!C87-E("=P9W-Q;"<Z"B`@
M("`@("`@("`@("`@("`D=F%L=65S6UT@/2!B:6XR:&5X*"1D871A*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@("`@("1V86QU97-;72`]("1D871A.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=VAE<F5S=')I;F<@/2`G)SL*("`@("`@("`@("`@
M9F]R96%C:"`H)'=H97)E(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1W:&5R97-T<FEN9RDI('L*("`@("`@("`@
M("`@("`@("`@("`D=VAE<F5S=')I;F<@+CT@)R!!3D0@)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`D:V5Y
M("X@)R`](#\G.PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'9A;'5E
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*"=54$1!5$4@)7,@4T54("5S(%=(15)%("5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'5P9&%T97-T<FEN9RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=VAE<F5S=')I;F<I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"@H@("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@
M("1T:&ES+3YL;V<H)'%U97)Y+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1H92!P871H;F%M92!F<F]M
M(')E9W5L87(@9FEL97-Y<W1E;2!F;W)M('1O('1H92!I;G1E<FYA;`H@("`@
M("H@9F]R;6%T(&YE961E9"!T;R!A8V-E<W,@=&AE(&9I;&4@:6X@=&AE(&1A
M=&%B87-E+@H@("`@("H@3F%M96QY+"!W92!W:6QL('1R96%T("<O)R!A<R!A
M(&)A<V4@9&ER96-T;W)Y(&%S('1H:7,@:7,@<')E='1Y(&UU8V@*("`@("`J
M('1H92!S=&%N9&%R9"!W87D@=&\@86-C97-S(&)A<V4@9&ER96-T;W)I97,@
M;W9E<B!M;W-T(&9I;&5S>7-T96US+@I]("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@($$@
M5D93('!A=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P
M871H('=I=&@@86YY(&)E9VEN;FEN9R!S;&%S:"!S=')I<'!E9"!O9F8N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T4&%T:"@D<&%T:"D*("`@('L*
M("`@("`@("!I9B`H(65M<'1Y*"1P871H*2`F)B`H<W1R<&]S*"1P871H+"`G
M+R<I(#T]/2`P*2D@>PH@("`@("`@("`@("`D<&%T:"`]('-T<G9A;"AS=6)S
M='(H)'!A=&@L(#$I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%T
M:#L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T1FEL95-I>F5/<"@I"B`@("![
M"B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YD8G-Y;G1A>"D@>PH@("`@
M("`@(&-A<V4@)VUY<W%L)SH*("`@("`@("`@("`@<F5T=7)N("=,14Y'5$@G
M.PH*("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@<F5T=7)N("=,
M14Y'5$A")SL*"B`@("`@("`@8V%S92`G;7-S<6PG.@H@("`@("`@(&-A<V4@
M)W-Y8F%S92<Z"B`@("`@("`@("`@(')E='5R;B`G1$%404Q%3D=42"<["@H@
M("`@("`@(&-A<V4@)W!G<W%L)SH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!R971U<FX@)T]#5$547TQ%3D=42"<["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]61E,O;75S<6PN<&AP````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,V,C<`,3`U,34T,S$P-C``,#$W-#<V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-Q;"YP
M:'`G.PH*+RHJ"B`J(%!E<FUI<W-I;VX@9F]R(')E860@86-C97-S+@H@*B\*
M9&5F:6YE*"=61E-?1DQ!1U]214%$)RP@,2D["@HO*BH*("H@4&5R;6ES<VEO
M;B!F;W(@<F5A9"!A8V-E<W,N"B`J+PID969I;F4H)U9&4U]&3$%'7U=2251%
M)RP@,BD["@HO*BH*("H@375L=&D@57-E<B!61E,@:6UP;&5M96YT871I;VX@
M9F]R(%!(4"=S(%!%05(@9&%T86)A<V4*("H@86)S=')A8W1I;VX@;&%Y97(N
M"B`J"B`J(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A<F%M<SH\<')E/@H@*B`@
M("`@("=P:'!T>7!E)R`@("`@("!4:&4@9&%T86)A<V4@='EP92`H:64N("=P
M9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!V
M86QU97,Z/'!R93X*("H@("`@("`G=&%B;&4G("`@("`@("`@5&AE(&YA;64@
M;V8@=&AE('9F<R!T86)L92!I;B`G9&%T86)A<V4G+B!$969A=6QT<R!T;PH@
M*B`@("`@("`@("`@("`@("`@("`@("`G:&]R9&5?;75V9G,G+CPO<')E/@H@
M*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B87-E(&EM<&QE;65N=&%T:6]N
M<SH\<')E/@H@*B`@("`@("=H;W-T<W!E8R<@("`@("!4:&4@:&]S=&YA;64@
M;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`@("`G<')O=&]C;VPG("`@
M("`@5&AE(&-O;6UU;FEC871I;VX@<')O=&]C;VP@*"=T8W`G+"`G=6YI>"<L
M(&5T8RXI+@H@*B`@("`@("=D871A8F%S92<@("`@("!4:&4@;F%M92!O9B!T
M:&4@9&%T86)A<V4N"B`J("`@("`@)W5S97)N86UE)R`@("`@(%1H92!U<V5R
M;F%M92!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@
M*B`@("`@("=P87-S=V]R9"<@("`@("!4:&4@<&%S<W=O<F0@87-S;V-I871E
M9"!W:71H("=U<V5R;F%M92<N"B`J("`@("`@)V]P=&EO;G,G("`@("`@($%D
M9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O('1H92!D871A8F%S92X*("H@
M("`@("`G='1Y)R`@("`@("`@("`@5&AE(%1462!O;B!W:&EC:"!T;R!C;VYN
M96-T('1O('1H92!D871A8F%S92X*("H@("`@("`G<&]R="<@("`@("`@("`@
M5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N
M/"]P<F4^"B`J"B`J($MN;W=N($ES<W5E<SH*("H@1&5L971E(&ES(&YO="!R
M96-U<VEV92P@<V\@9FEL97,@86YD(&9O;&1E<G,@=&AA="!U<V5D('1O(&)E
M(&EN(&$@9F]L9&5R"B`J('1H870@9V5T<R!D96QE=&5D(&QI=F4@9F]R979E
M<B!I;B!T:&4@9&%T86)A<V4L(&]R(')E+6%P<&5A<B!W:&5N('1H92!F;VQD
M97(*("H@:7,@<F5C<F5A=&5D+@H@*B!296YA;64@:&%S('1H92!S86UE(&ES
M<W5E+"!S;R!F:6QE<R!A<F4@;&]S="!I9B!A(&9O;&1E<B!I<R!R96YA;65D
M+@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@5D93(&-A;B!B
M92!F;W5N9"!I;@H@*B!D871A+VUU=F9S+G-Q;"X*("H*("H@1&%T86)A<V4@
M<W!E8VEF:6,@;F]T97,Z"B`J"B`J($U34U%,.@H@*B`M(%1H92!V9G-?9&%T
M82!F:65L9"!M=7-T(&)E(&]F('1Y<&4@24U!1T4N"B`J("T@66]U(&YE960@
M=&AE(&9O;&QO=VEN9R!P:'`N:6YI('-E='1I;F=S.@H@*B`\8V]D93X*("H@
M("`@.R!686QI9"!R86YG92`P("T@,C$T-S0X,S8T-RX@1&5F875L="`](#0P
M.38N"B`J("`@(&US<W%L+G1E>'1L:6UI="`](#`@.R!Z97)O('1O('!A<W,@
M=&AR;W5G:`H@*@H@*B`@("`[(%9A;&ED(')A;F=E(#`@+2`R,30W-#@S-C0W
M+B!$969A=6QT(#T@-#`Y-BX*("H@("`@;7-S<6PN=&5X='-I>F4@/2`P(#L@
M>F5R;R!T;R!P87-S('1H<F]U9V@*("H@/"]C;V1E/@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<"QV(#$N,S`N-"XQ-B`R,#`V
M+S`U+S,Q(#`T.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<&%C:V%G92!61E,*("HO"F-L
M87-S(%9&4U]M=7-Q;"!E>'1E;F1S(%9&4U]S<6P@>PH*("`@("\J*@H@("`@
M("H@3&ES="!O9B!P97)M:7-S:6]N<R!A;F0@:68@=&AE>2!C86X@8F4@8VAA
M;F=E9"!I;B!T:&ES(%9&4PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?<&5R;6ES<VEO;G,@/2!A<G)A>2@*("`@("`@("`G
M;W=N97(G(#T^(&%R<F%Y*"=R96%D)R`]/B!F86QS92P@)W=R:71E)R`]/B!F
M86QS92P@)V5X96-U=&4G(#T^(&9A;'-E*2P*("`@("`@("`G9W)O=7`G(#T^
M(&%R<F%Y*"=R96%D)R`]/B!F86QS92P@)W=R:71E)R`]/B!F86QS92P@)V5X
M96-U=&4G(#T^(&9A;'-E*2P*("`@("`@("`G86QL)R`@(#T^(&%R<F%Y*"=R
M96%D)R`]/B!T<G5E+"`@)W=R:71E)R`]/B!T<G5E+"`@)V5X96-U=&4G(#T^
M(&9A;'-E*0H@("`@*3L*"B`@("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I
M;B!T:&4@5D93(&9R;VT@<F%W(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F
M:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H
M92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A
M("`@("`@("`@5&AE(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N
M("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE
M<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@
M)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T
M:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C
M;VYN*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!W<FET92!A8V-E<W,@=&\@
M=&AI<R!A;F0@86QL('!A<F5N=`H@("`@("`@("`J('!A=&AS+B`J+PH@("`@
M("`@(&EF("@D<&%T:"`A/2`G)RD@>PH@("`@("`@("`@("`D<&%T:',@/2!E
M>'!L;V1E*"<O)RP@)'!A=&@I.PH@("`@("`@("`@("`D<&%T:%]N86UE(#T@
M87)R87E?<&]P*"1P871H<RD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES
M1F]L9&5R*&EM<&QO9&4H)R\G+"`D<&%T:',I+"`D<&%T:%]N86UE*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"$D875T;V-R96%T92D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(BDL("1P871H*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)'!A=&@I
M.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1P871H<UM=(#T@)'!A=&A?
M;F%M93L*("`@("`@("`@("`@)'!R979I;W5S(#T@)R<["@H@("`@("`@("`@
M("!F;W)E86-H("@D<&%T:',@87,@)'1H:7-P871H*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT<R`]("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I;G1F*"=3
M14Q%0U0@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M93T@/R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1P<F5V:6]U<RP@
M)'1H:7-P871H*2D["B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R
M97-U;'1S*2!\?"!C;W5N="@D<F5S=6QT<RD@/"`Q*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(&-R96%T92!61E,@9FEL92XB*2D["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@)&%L;&]W960@/2!F86QS93L*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1R97-U;'1S(&%S("1R97-U;'0I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)')E<W5L=%LP72`]/2`D=&AI<RT^7W!A<F%M<ULG=7-E
M<B==('Q\("1R97-U;'1;,5T@)B!61E-?1DQ!1U]74DE412D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D86QL;W=E9"`]('1R=64["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H(21A;&QO=V5D
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB*2D["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'!R979I;W5S(#T@
M)'1H:7-P871H.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@<&%R96YT.CIW<FET941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@
M)&%U=&]C<F5A=&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@
M9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1E;&5T949I;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@
M("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&-O;FXI*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N
M;CL*("`@("`@("!]"@H@("`@("`@("1F:6QE3&ES="`]("1T:&ES+3Y?9&(M
M/F=E=$%L;"AS<')I;G1F*"=314Q%0U0@=F9S7VED+"!V9G-?;W=N97(L('9F
M<U]P97)M<R!&4D]-("5S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S
M7VYA;64](#\@04Y$('9F<U]T>7!E(#T@/R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D<&%T:"P@)&YA;64L(%9&4U]&24Q%*2D["@H@("`@("`@
M(&EF("@A:7-?87)R87DH)&9I;&5,:7-T*2!\?"!C;W5N="@D9FEL94QI<W0I
M(#P@,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%1H97)E(&UA>2!B92!O;F4@;W(@;6]R92!F:6QE<R!W:71H
M('1H92!S86UE(&YA;64@8G5T('1H90H@("`@("`@("`@('5S97(@;6%Y(&YO
M="!H879E(')E860@86-C97-S('1O('1H96TL('-O(&1O97-N)W0@<V5E"B`@
M("`@("`@("`@=&AE;2X@4V\@=V4@:&%V92!T;R!D96QE=&4@=&AE(&]N92!T
M:&5Y(&AA=F4@86-C97-S('1O+B`J+PH@("`@("`@(&9O<F5A8V@@*"1F:6QE
M3&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;,5T@/3T@
M)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D9FEL95LR72`F(%9&4U]&3$%'
M7U=2251%*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@=F9S7VED
M(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)&9I;&5;,%TI*3L*"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]D8BT^
M869F96-T9612;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O($9)6$U%.B`G06-C97-S($1E;FEE9"!D96QE=&EN9R!F:6QE("5S
M+R5S)PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N(BDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5N86UE(&$@9FEL92!O<B!F;VQD97(@:6X@=&AE(%9&4RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD('!A=&@@
M=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N86UE("!4
M:&4@;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T
M:"`@5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I
M"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@("`@
M<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5,:7-T(#T@
M)'1H:7,M/E]D8BT^9V5T06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?:60L('9F
M<U]O=VYE<BP@=F9S7W!E<FUS($923TT@)7,*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F
M<U]P871H(#T@/R!!3D0@=F9S7VYA;64](#\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@D;VQD<&%T:"P@)&]L9&YA;64I*3L*"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D9FEL94QI<W0I('Q\(&-O=6YT*"1F:6QE
M3&ES="D@/"`Q*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(BDI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*'-T<G!O<R@D;F5W<&%T:"P@)R\G*2`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@)'!A<F5N="`]("<G.PH@("`@("`@("`@("`D
M<&%T:"`]("1N97=P871H.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&QI<W0H)'!A<F5N="P@)'!A=&@I(#T@97AP;&]D92@G+R<L("1N97=P871H
M+"`R*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D=&AI<RT^:7-&;VQD97(H
M)'!A<F5N="P@)'!A=&@I*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)&YE=W!A=&@I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@5&AE<F4@;6%Y(&)E
M(&]N92!O<B!M;W)E(&9I;&5S('=I=&@@=&AE('-A;64@;F%M92!B=70@=&AE
M('5S97(@;6%Y"B`@("`@("`@("H@;F]T(&AA=F4@<F5A9"!A8V-E<W,@=&\@
M=&AE;2P@<V\@9&]E<VXG="!S964@=&AE;2X@4V\@=V4@:&%V92!T;PH@("`@
M("`@("`J(')E;F%M92!T:&4@;VYE('1H97D@:&%V92!A8V-E<W,@=&\N("HO
M"B`@("`@("`@9F]R96%C:"`H)&9I;&5,:7-T(&%S("1F:6QE*2!["B`@("`@
M("`@("`@(&EF("@D9FEL95LQ72`]/2`D=&AI<RT^7W!A<F%M<ULG=7-E<B==
M('Q\("1F:6QE6S)=("8@5D937T9,04=?5U))5$4I('L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=54$1!
M5$4@)7,@4T54('9F<U]P871H(#T@/RP@=F9S7VYA;64@/2`_+"!V9G-?;6]D
M:69I960@/2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!72$5212!V9G-?:60@/2`_)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;F5W<&%T:"P@)&YE=VYA
M;64L('1I;64H*2P@)&9I;&5;,%TI*3L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N(BDL("1O;&1P871H+"`D;VQD;F%M92DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&9O;&1E<B!O;B!T
M:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@($AO
M;&1S('1H92!P871H(&]F(&1I<F5C=&]R>2!T;R!C<F5A=&4@9F]L9&5R+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@2&]L9',@=&AE(&YA;64@;V8@
M=&AE(&YE=R!F;VQD97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E1F]L9&5R*"1P871H
M+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C;VYN*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`O*B!M
M86ME('-U<F4@=V4@:&%V92!W<FET92!A8V-E<W,@=&\@=&AI<R!A;F0@86QL
M('!A<F5N="!P871H<R`J+PH@("`@("`@(&EF("@D<&%T:"`A/2`B(BD@>PH@
M("`@("`@("`@("`D<&%T:',@/2!E>'!L;V1E*"<O)RP@)'!A=&@I.PH@("`@
M("`@("`@("`D<')E=FEO=7,@/2`G)SL*"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1P871H<R!A<R`D=&AI<W!A=&@I('L*("`@("`@("`@("`@("`@("1R97-U
M;'1S(#T@)'1H:7,M/E]D8BT^9V5T06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?
M;W=N97(L('9F<U]P97)M<R!&4D]-("5S"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(
M15)%('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64](#\G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D<')E
M=FEO=7,L("1T:&ES<&%T:"DI.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<F5S=6QT<RD@?'P@8V]U;G0H)')E<W5L=',I(#P@,2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@)&%L;&]W960@/2!F86QS93L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1R97-U;'1S(&%S("1R97-U;'0I('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LP72`]/2`D=&AI<RT^
M7W!A<F%M<ULG=7-E<B==('Q\("1R97-U;'1;,5T@)B!61E-?1DQ!1U]74DE4
M12D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D86QL;W=E9"`]('1R=64[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I
M9B`H(21A;&QO=V5D*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(I*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`D<')E=FEO=7,@/2`D=&AI<W!A=&@["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&(M/G%U97)Y*'-P<FEN=&8H)TE.4T525"!)3E1/("5S("AV9G-?:60L('9F
M<U]T>7!E+"!V9G-?<&%T:"P@=F9S7VYA;64L('9F<U]M;V1I9FEE9"P@=F9S
M7V]W;F5R+"!V9G-?<&5R;7,I"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_+"`_*2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@D:60L(%9&4U]&3TQ$15(L("1P871H+"`D;F%M
M92P@=&EM92@I+"`D=&AI<RT^7W!A<F%M<ULG=7-E<B==+"`P*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F:6QE(&9R;VT@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@
M<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&9O;&1E<FYA;64@=&\@=7-E+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)')E8W5R<VEV92`@1F]R8V4@82!R96-U
M<G-I=F4@9&5L971E/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@
M)&YA;64L("1R96-U<G-I=F4@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N
M;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1C;VYN*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)')E8W5R<VEV92D@>PH@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/F5M<'1Y1F]L9&5R*"1P871H("X@)R\G("X@)&YA
M;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L:7-T(#T@
M)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@@+B`G+R<@+B`D;F%M92D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*&-O=6YT*"1L:7-T*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%T
M:"`N("<O)R`N("1N86UE*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1F:6QE3&ES="`]("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I;G1F
M*"=314Q%0U0@=F9S7VED+"!V9G-?;W=N97(L('9F<U]P97)M<R!&4D]-("5S
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE/2`_
M($%.1"!V9G-?='EP92`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D<&%T:"P@)&YA;64L(%9&4U]&3TQ$15(I*3L*"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D9FEL94QI<W0I('Q\(&-O=6YT*"1F:6QE3&ES
M="D@/"`Q*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@
M("`@?0H*("`@("`@("`O*B!4:&5R92!M87D@8F4@;VYE(&]R(&UO<F4@9F]L
M9&5R<R!W:71H('1H92!S86UE(&YA;64@8G5T(&%S('1H92!U<V5R"B`@("`@
M("`@("H@;6%Y(&YO="!H879E(')E860@86-C97-S('1O('1H96TL('1H97D@
M9&]N)W0@<V5E('1H96TN(%-O('=E(&AA=F4@=&\*("`@("`@("`@*B!D96QE
M=&4@=&AE(&]N92!T:&5Y(&AA=F4@86-C97-S('1O("HO"B`@("`@("`@9F]R
M96%C:"`H)&9I;&5,:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D
M9FEL95LQ72`]/2`D=&AI<RT^7W!A<F%M<ULG=7-E<B==('Q\("1F:6QE6S)=
M("8@5D937T9,04=?5U))5$4I('L*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$14Q%5$4@1E)/32`E<R!7
M2$5212!V9G-?:60@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D9FEL95LP72DI.PH*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+B(I*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+R\@1DE8344Z("=!8V-E<W,@1&5N:65D
M(&1E;&5T:6YG(&9O;&1E<B`E<R\E<R<*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@;&ES="!O9B!T
M:&4@8V]N=&5N=',@;V8@82!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y
M+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("!3=')I;F<O:&%S
M:"!T;R!F:6QT97(@9FEL92]D:7)N86UE(&]N+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&1O=&9I;&5S("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&1I<F]N;'D@("!3:&]W(&]N;'D@9&ER96-T;W)I97,_"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1FEL92!L:7-T(&]N('-U8V-E
M<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VQI<W1&;VQD97(H)'!A=&@L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL97,@
M/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&QE
M;F=T:%]O<"`]("1T:&ES+3Y?9V5T1FEL95-I>F5/<"@I.PH@("`@("`@("1F
M:6QE3&ES="`]("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I;G1F*"=314Q%0U0@
M=F9S7VYA;64L('9F<U]T>7!E+"!V9G-?;6]D:69I960L('9F<U]O=VYE<BP@
M=F9S7W!E<FUS+"`E<RAV9G-?9&%T82D@1E)/32`E<PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]P
M871H(#T@/R!!3D0@*'9F<U]O=VYE<B`](#\@;W(@=F9S7W!E<FUS("8F(#\I
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&5N9W1H7V]P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)'!A=&@L("1T:&ES+3Y?<&%R86US6R=U<V5R)UTL(%9&4U]&3$%'7U)%040I
M*3L*("`@("`@("!I9B`H:7-?82@D9FEL94QI<W0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE3&ES=#L*("`@("`@("!]"@H@
M("`@("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&9I
M;&5,:7-T(&%S("1L:6YE*2!["B`@("`@("`@("`@("\O($9I;'1E<B!O=70@
M9&]T9FEL97,@:68@=&AE>2!A<F5N)W0@=V%N=&5D+@H@("`@("`@("`@("!I
M9B`H(21D;W1F:6QE<R`F)B!S=6)S='(H)&QI;F5;,%TL(#`L(#$I(#T]("<N
M)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/2!S=')I<'-L87-H97,H)&QI
M;F5;,%TI.PH*("`@("`@("`@("`@:68@*"1L:6YE6S%=(#T](%9&4U]&24Q%
M*2!["B`@("`@("`@("`@("`@("`D;F%M92`](&5X<&QO9&4H)RXG+"`D;&EN
M95LP72D["@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1N86UE*2`]/2`Q
M*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*FYO
M;F4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG='EP92==(#T@5D93.CIS=')T;VQO=V5R*"1N86UE6V-O
M=6YT*"1N86UE*2`M(#%=*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`D9FEL95LG<VEZ92==(#T@)&QI;F5;-5T["B`@("`@("`@("`@
M('T@96QS96EF("@D;&EN95LQ72`]/2!61E-?1D],1$52*2!["B`@("`@("`@
M("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ9&ER)SL*("`@("`@("`@("`@
M("`@("1F:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&9I;&5;)V1A=&4G72`]("1L:6YE6S)=.PH@("`@("`@("`@("`D
M9FEL95LG;W=N97(G72`]("1L:6YE6S-=.PH*("`@("`@("`@("`@)&QI;F5;
M-%T@/2!I;G1V86PH)&QI;F5;-%TI.PH@("`@("`@("`@("`D9FEL95LG<&5R
M;7,G72`@/2`H)&QI;F5;,5T@/3T@5D937T9/3$1%4BD@/R`G9"<@.B`G+2<[
M"B`@("`@("`@("`@("1F:6QE6R=P97)M<R==("X]("=R=RTG.PH@("`@("`@
M("`@("`D9FEL95LG<&5R;7,G72`N/2`H)&QI;F5;-%T@)B!61E-?1DQ!1U]2
M14%$*2`_("=R)R`Z("<M)SL*("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@
M+CT@*"1L:6YE6S1=("8@5D937T9,04=?5U))5$4I(#\@)W<G(#H@)RTG.PH@
M("`@("`@("`@("`D9FEL95LG<&5R;7,G72`N/2`G+2<["B`@("`@("`@("`@
M("1F:6QE6R=G<F]U<"==(#T@)R<["@H@("`@("`@("`@("`O+R!F:6QT97)I
M;F<*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9FEL=&5R36%T8V@H)&9I;'1E
M<BP@)&9I;&5;)VYA;64G72DI('L*("`@("`@("`@("`@("`@('5N<V5T*"1F
M:6QE*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@D9&ER;VYL>2`F)B`D9FEL95LG='EP92==("$]
M/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&9I;&5S6R1F:6QE6R=N86UE)UU=(#T@)&9I;&4["B`@("`@("`@
M("`@('5N<V5T*"1F:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9FEL97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('!E<FUI<W-I
M;VYS(&9O<B!A;B!)=&5M(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@2&]L9',@=&AE('!A=&@@;V8@9&ER96-T;W)Y
M(&]F('1H92!)=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@2&]L
M9',@=&AE(&YA;64@;V8@=&AE($ET96TN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA;F=E4&5R
M;6ES<VEO;G,H)'!A=&@L("1N86UE+"`D<&5R;6ES<VEO;BD*("`@('L*("`@
M("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1C;VYN*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O
M;FX["B`@("`@("`@?0H*("`@("`@("`D=F%L(#T@:6YT=F%L*'-U8G-T<B@D
M<&5R;6ES<VEO;BP@+3$I*3L*("`@("`@("`D<&5R;2`](#`["B`@("`@("`@
M)'!E<FT@?#T@*"1V86P@)B`T*2`_(%9&4U]&3$%'7U)%040@.B`P.PH@("`@
M("`@("1P97)M('P]("@D=F%L("8@,BD@/R!61E-?1DQ!1U]74DE412`Z(#`[
M"@H@("`@("`@("1F:6QE3&ES="`]("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I
M;G1F*"=314Q%0U0@=F9S7VED+"!V9G-?;W=N97(L('9F<U]P97)M<R!&4D]-
M("5S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'!A
M=&@L("1N86UE*2D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&9I;&5,:7-T
M*2!\?"!C;W5N="@D9FEL94QI<W0I(#P@,2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@("\J(%1H97)E(&UA>2!B92!O
M;F4@;W(@;6]R92!F:6QE<R!W:71H('1H92!S86UE(&YA;64@8G5T('1H92!U
M<V5R(&UA>0H@("`@("`@("`J(&YO="!H879E(')E860@86-C97-S('1O('1H
M96TL('-O(&1O97-N)W0@<V5E('1H96TN(%-O('=E(&AA=F4@=&\*("`@("`@
M("`@*B!C:&UO9"!T:&4@;VYE('1H97D@:&%V92!A8V-E<W,@=&\N("HO"B`@
M("`@("`@9F]R96%C:"`H)&9I;&5,:7-T(&%S("1F:6QE*2!["B`@("`@("`@
M("`@(&EF("@D9FEL95LQ72`]/2`D=&AI<RT^7W!A<F%M<ULG=7-E<B==('Q\
M("1F:6QE6S)=("8@5D937T9,04=?5U))5$4I('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=54$1!5$4@
M)7,@4T54('9F<U]P97)M<R`](#\*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]I9"`](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1P97)M
M+"`D9FEL95LP72DI.PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB*2P@)'!A=&@L("1N86UE*2D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U9&4R]F='`N<&AP````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`W-3(S-``Q,#4Q-30S,3`V,``P,3<Q,C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%9&4R!I;7!L96UE;G1A=&EO;B!F;W(@86X@1E10('-E<G9E
M<BX*("H*("H@4F5Q=6ER960@=F%L=65S(&9O<B`D<&%R86US.CQP<F4^"B`J
M("`@("`@)W5S97)N86UE)R`@("`@("!4:&4@=7-E<FYA;64@=VET:"!W:&EC
M:"!T;R!C;VYN96-T('1O('1H92!F='`@<V5R=F5R+@H@*B`@("`@("=P87-S
M=V]R9"<@("`@("`@5&AE('!A<W-W;W)D('=I=&@@=VAI8V@@=&\@8V]N;F5C
M="!T;R!T:&4@9G1P('-E<G9E<BX*("H@("`@("`G:&]S='-P96,G("`@("`@
M(%1H92!F='`@<V5R=F5R('1O(&-O;FYE8W0@=&\N/"]P<F4^"B`J"B`J($]P
M=&EO;F%L('9A;'5E<R!F;W(@)'!A<F%M<SH\<')E/@H@*B`@("`@("=M87!L
M;V-A;&ED<R<@("`@268@=')U92!A;F0@=&AE(%!/4TE8(&5X=&5N<VEO;B!I
M<R!A=F%I;&%B;&4L('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@9')I
M=F5R('=I;&P@;6%P('1H92!U<V5R(&%N9"!G<F]U<"!)1',@<F5T=7)N960@
M9G)O;0H@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE($944"!S97)V97(@
M=VET:"!T:&4@;&]C86P@241S(&9R;VT@=&AE(&QO8V%L"B`J("`@("`@("`@
M("`@("`@("`@("`@("!P87-S=V]R9"!F:6QE+B`@5&AI<R!I<R!U<V5F=6P@
M;VYL>2!I9B!T:&4@1E10('-E<G9E<@H@*B`@("`@("`@("`@("`@("`@("`@
M("`@:7,@<G5N;FEN9R!O;B!L;V-A;&AO<W0@;W(@:68@=&AE(&QO8V%L('5S
M97(O9W)O=7`*("H@("`@("`@("`@("`@("`@("`@("`@($E$<R!A<F4@:61E
M;G1I8V%L('1O('1H92!R96UO=&4@1E10('-E<G9E<BX*("H@("`@("`G<&%S
M=B<@("`@("`@("`@($EF('1R=64L(&-O;FYE8W1I;VX@=VEL;"!B92!S970@
M=&\@<&%S<VEV92!M;V1E+@H@*B`@("`@("=P;W)T)R`@("`@("`@("`@5&AE
M('!O<G0@=7-E9"!T;R!C;VYN96-T('1O('1H92!F='`@<V5R=F5R(&EF(&]T
M:&5R"B`J("`@("`@("`@("`@("`@("`@("`@("!T:&%N(#(Q+@H@*B`@("`@
M("=S<VPG("`@("`@("`@("`@268@=')U92P@86YD(%!(4"!H860@8F5E;B!C
M;VUP:6QE9"!W:71H($]P96Y34TP*("H@("`@("`@("`@("`@("`@("`@("`@
M('-U<'!O<G0L(%1,4R!T<F%N<W!O<G0M;&5V96P@96YC<GEP=&EO;B!W:6QL
M(&)E"B`J("`@("`@("`@("`@("`@("`@("`@("!N96=O=&EA=&5D('=I=&@@
M=&AE('-E<G9E<BX*("H@("`@("`G=&EM96]U="<@("`@("`@($EF(&1E9FEN
M960L('5S92!T:&ES('9A;'5E(&%S('1H92!T:6UE;W5T(&9O<B!T:&4*("H@
M("`@("`@("`@("`@("`@("`@("`@('-E<G9E<BX\+W!R93X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP+'8@,2XW-2XT+C(Q(#(P
M,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@5F%R9VAE<V4@/&UI
M:V4N=F%R9VAE<V5`87-C96QL871E8V@N8V]M/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($UI8VAA96P@5F%R9VAE<V4@/&UI:V4N=F%R9VAE<V5`
M87-C96QL871E8V@N8V]M/@H@*B!`<&%C:V%G92!61E,*("HO"F-L87-S(%9&
M4U]F='`@97AT96YD<R!61E,@>PH*("`@("\J*@H@("`@("H@3&ES="!O9B!A
M9&1I=&EO;F%L(&-R961E;G1I86QS(')E<75I<F5D(&9O<B!T:&ES(%9&4R!B
M86-K96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?8W)E9&5N=&EA;',@/2!A<G)A>2@G=7-E<FYA;64G+"`G<&%S<W=O
M<F0G*3L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES<VEO;G,@86YD
M(&EF('1H97D@8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E
M<FUI<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G
M<F5A9"<@/3X@=')U92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@
M=')U92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@=')U
M92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92DL"B`@("`@
M("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@)W=R:71E)R`]
M/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92DI.PH*("`@("\J*@H@("`@("H@
M5F%R:6%B;&4@:&]L9&EN9R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@9G1P('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@
M('9A<B`D7W-T<F5A;2`](&9A;'-E.PH*("`@("\J*@H@("`@("H@3&]C86P@
M8V%C:&4@87)R87D@9F]R('5S97(@241S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?=6ED<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!,;V-A;"!C86-H92!A<G)A>2!F;W(@9W)O=7`@241S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9VED
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S:7IE
M(&]F(&$@9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H
M92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('-I>F4@
M;V8@=&AE(&9I;&4@:6X@8GET97,@;W(@4$5!4E]%<G)O<B!O;@H@("`@("H@
M("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S:7IE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T
M:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@
M("!]"@H@("`@("`@(&EF("@H)'-I>F4@/2!`9G1P7W-I>F4H)'1H:7,M/E]S
M=')E86TL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'-I>F4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971R:65V97,@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@
M=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)'!A=&@L
M("1N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T
M*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@
M)'1M<$9I;&4@/2`D=&AI<RT^7V=E=%1E;7!&:6QE*"D["B`@("`@("`@)&9E
M=&-H(#T@0&9T<%]G970H)'1H:7,M/E]S=')E86TL("1T;7!&:6QE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@
M)&YA;64I+"!&5%!?0DE.05)9*3L*("`@("`@("!I9B`H)&9E=&-H(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB*2P@
M)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@
M("`@("`@("1S:7IE(#T@9FEL97-I>F4H)'1M<$9I;&4I.PH@("`@("`@(&EF
M("@D<VEZ92`]/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@
M("`@?0H*("`@("`@("!I9B`H3U-?5TE.1$]74RD@>PH@("`@("`@("`@("`D
M;6]D92`]("=R8B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO
M9&4@/2`G<B<["B`@("`@("`@?0H*("`@("`@("!I9B`H9G5N8W1I;VY?97AI
M<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2!["B`@("`@("`@("`@("1D871A
M(#T@9FEL95]G971?8V]N=&5N=',H)'1M<$9I;&4I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1T;7!&:6QE+"`D;6]D92D[
M"B`@("`@("`@("`@("1D871A(#T@9G)E860H)&9P+"`D<VEZ92D["B`@("`@
M("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@('T*("`@("`@("!U;FQI;FLH
M)'1M<$9I;&4I.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3=&]R97,@82!F:6QE(&EN('1H92!61E,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H('1O
M('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T;7!&:6QE("`@("`@5&AE('1E;7!O<F%R>2!F:6QE(&-O;G1A
M:6YI;F<@=&AE(&1A=&$@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B92!S=&]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T
M;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=W)I=&4H)'!A=&@L("1N86UE+"`D=&UP1FEL92P@)&%U=&]C
M<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?
M8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@
M("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%7<FET92@G9FEL92<L
M("1T;7!&:6QE*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%`9G1P7W!U="@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G
M9710871H*"1P871H+"`D;F%M92DL("1T;7!&:6QE+"!&5%!?0DE.05)9*2D@
M>PH@("`@("`@("`@("!I9B`H)&%U=&]C<F5A=&4I('L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)'!A=&@I.PH@
M("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%`9G1P7W!U="@D
M=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DL
M("1T;7!&:6QE+"!&5%!?0DE.05)9*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P
M871H+"`D;F%M92DI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@82!F:6QE(&EN('1H92!61E,@9G)O
M;2!R87<@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O
M('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@
M9FEL92!D871A+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@
M($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=R:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T;V-R96%T92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O
M=&%7<FET92@G<W1R:6YG)RP@)&1A=&$I.PH@("`@("`@(&EF("AI<U]A*"1R
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@?0H*("`@("`@("`D=&UP1FEL92`]("1T:&ES+3Y?9V5T5&5M
M<$9I;&4H*3L*("`@("`@("`D9G`@/2!F;W!E;B@D=&UP1FEL92P@)W=B)RD[
M"B`@("`@("`@9G=R:71E*"1F<"P@)&1A=&$I.PH@("`@("`@(&9C;&]S92@D
M9G`I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G=R:71E*"1P871H+"`D
M;F%M92P@)'1M<$9I;&4L("1A=71O8W)E871E*3L*("`@("`@("!U;FQI;FLH
M)'1M<$9I;&4I.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O(&1E
M;&5T92!T:&4@9FEL92!F<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&9I;&5N86UE('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&
M:6QE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D<F5S(#T@)'1H:7,M
M/E]C:&5C:U%U;W1A1&5L971E*"1P871H+"`D;F%M92D["B`@("`@("`@:68@
M*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%`9G1P7V1E;&5T92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M
M/E]G9710871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@
M)&YA;64I*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A(&=I=F5N(&ET96T@:7,@
M82!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A<F5N="!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@:71E;2!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!I="!I<R!A(&9O;&1E<BP@9F%L<V4@;W1H97)W:7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<T9O;&1E<B@D<&%T:"P@)&YA;64I"B`@
M("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@
M9F%L<V4["B`@("`@("`@)&]L9&1I<B`]("1T:&ES+3YG971#=7)R96YT1&ER
M96-T;W)Y*"D["@H@("`@("`@("\J(%-E92!I9B!W92!C86X@8VAA;F=E('1O
M('1H92!G:79E;B!P871H+B`J+PH@("`@("`@(&EF("A`9G1P7V-H9&ER*"1T
M:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI
M('L*("`@("`@("`@("`@)')E<W5L="`]('1R=64["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7W-E=%!A=&@H)&]L9&1I<BD["@H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&9O
M;&1E<B!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@("`@("`@5&AE('!A<F5N="!F;VQD97(N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R
M('1O(&1E;&5T92X*("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@
M($9O<F-E(&$@<F5C=7)S:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&
M;VQD97(H)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I
M9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D:7-$:7(@/2!F86QS
M93L*("`@("`@("`D9&ER0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T
M:"D["B`@("`@("`@9F]R96%C:"`H)&1I<D-H96-K(&%S("1F:6QE*2!["B`@
M("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE("8F("1F:6QE
M6R=T>7!E)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@)&ES1&ER
M(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)&ES1&ER*2!["B`@("`@("`@("`@
M("1F:6QE7VQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D=&AI<RT^7V=E=%!A
M=&@H)'!A=&@L("1N86UE*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1F:6QE
M7VQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D9FEL95]L:7-T.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M8V]U;G0H)&9I;&5?;&ES="D@)B8@(21R96-U<G-I=F4I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D9FEL95]L:7-T
M(&%S("1F:6QE*2!["B`@("`@("`@("`@("`@("!I9B`H)&9I;&5;)W1Y<&4G
M72`]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YD96QE=&5&;VQD97(H)'1H:7,M/E]G9710871H*"1P871H+"`D
M;F%M92DL("1F:6QE6R=N86UE)UTL("1R96-U<G-I=F4I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F1E;&5T949I;&4H)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92DL("1F:6QE6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(4!F='!?
M<FUD:7(H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@
M)&YA;64I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S
M7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(4!F
M='!?9&5L971E*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A
M=&@L("1N86UE*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<
M(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&$@9FEL92!I;B!T:&4@5D93+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@
M<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9&YA
M;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I;&5N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W
M;F%M92D*("`@('L*("`@("`@("!I9B`H:7-?82@D8V]N;B`]("1T:&ES+3Y?
M8V]N;F5C="@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@
M/2`D=&AI<RT^875T;V-R96%T95!A=&@H)&YE=W!A=&@I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%`9G1P7W)E;F%M92@D=&AI<RT^7W-T<F5A;2P@)'1H
M:7,M/E]G9710871H*"1O;&1P871H+"`D;VQD;F%M92DL("1T:&ES+3Y?9V5T
M4&%T:"@D;F5W<&%T:"P@)&YE=VYA;64I*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)&]L9'!A
M=&@L("1O;&1N86UE*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@9F]L9&5R(&]N
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A<F5N="!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A
M=&5&;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@
M)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%`9G1P7VUK9&ER*"1T:&ES+3Y?<W1R96%M
M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(I+"`D=&AI<RT^7V=E
M=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('!E<FUI
M<W-I;VYS(&9O<B!A;B!I=&5M(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE('!A<F5N="!F;VQD97(@
M;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@
M("!4:&4@;F%M92!O9B!T:&4@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@
M)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O('-E="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C:&%N9V5097)M:7-S:6]N<R@D<&%T:"P@)&YA;64L("1P97)M:7-S:6]N
M*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`
M9G1P7W-I=&4H)'1H:7,M/E]S=')E86TL("=#2$U/1"`G("X@)'!E<FUI<W-I
M;VX@+B`G("<@+B`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB
M)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;B!A;B!U;G-O<G1E9"!F:6QE(&QI<W0@;V8@=&AE
M('-P96-I9FEE9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@
M("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("!3=')I;F<O:&%S:"!T
M;R!F:6QT97(@9FEL92]D:7)N86UE(&]N+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&1O=&9I;&5S("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&1I<F]N;'D@("!3:&]W(&]N;'D@9&ER96-T;W)I97,_"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@1FEL92!L:7-T(&]N('-U8V-E<W,@
M;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?;&ES=$9O;&1E<B@D<&%T:"`]("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O
M=&9I;&5S(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)O
M;FQY(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@
M("`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@("1T>7!E(#T@5D93.CIS
M=')T;VQO=V5R*$!F='!?<WES='EP92@D=&AI<RT^7W-T<F5A;2DI.PH@("`@
M("`@(&EF("@D='EP92`]/2`G=6YK;F]W;B<I('L*("`@("`@("`@("`@+R\@
M1V\@=VET:"!U;FEX+7-T>6QE(&QI<W1I;F=S(&)Y(&1E9F%U;'0N"B`@("`@
M("`@("`@("1T>7!E(#T@)W5N:7@G.PH@("`@("`@('T@96QS96EF("AS=')P
M;W,H)'1Y<&4L("=W:6XG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1Y
M<&4@/2`G=VEN)SL*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T>7!E+"`G
M;F5T=V%R92<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D='EP92`]("=N
M971W87)E)SL*("`@("`@("!]"@H@("`@("`@("1O;&1D:7(@/2`D=&AI<RT^
M9V5T0W5R<F5N=$1I<F5C=&]R>2@I.PH@("`@("`@(&EF("@A96UP='DH)'!A
M=&@I*2!["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^7W-E=%!A=&@H)'!A
M=&@I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"1T>7!E(#T]("=U;FEX)RD@>PH@
M("`@("`@("`@("`O+R!)9B!W92!D;VXG="!W86YT(&1O=&9I;&5S+"!792!C
M86X@<V%V92!W;W)K(&AE<F4@8GD@;F]T"B`@("`@("`@("`@("\O(&1O:6YG
M(&%N(&QS("UA(&%N9"!T:&5N(&YO="!D;VEN9R!T:&4@8VAE8VL@;&%T97(@
M*&)Y"B`@("`@("`@("`@("\O('-E='1I;F<@)&1O=&9I;&5S('1O('1R=64L
M('1H92!I9B!I<R!S:&]R="UC:7)C=6ET960I+@H@("`@("`@("`@("!I9B`H
M)&1O=&9I;&5S*2!["B`@("`@("`@("`@("`@("`D;&ES="`](&9T<%]R87=L
M:7-T*"1T:&ES+3Y?<W1R96%M+"`G+6%L)RD["B`@("`@("`@("`@("`@("`D
M9&]T9FEL97,@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&QI<W0@/2!F='!?<F%W;&ES="@D=&AI<RT^7W-T<F5A;2P@
M)RUL)RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("1L:7-T(#T@9G1P7W)A=VQI<W0H)'1H:7,M/E]S=')E86TL("<G*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?87)R87DH)&QI<W0I*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D;VQD9&ER*2D@>PH@("`@("`@("`@("`@
M("`@)')E<R`]("1T:&ES+3Y?<V5T4&%T:"@D;VQD9&ER*3L*("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@
M("`@("!]"@H@("`@("`@("\J($EF("=M87!L;V-A;&ED<R<@:7,@<V5T+"!C
M:&5C:R!F;W(@=&AE(%!/4TE8(&5X=&5N<VEO;BX@*B\*("`@("`@("`D;6%P
M:61S(#T@9F%L<V4["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG;6%P;&]C86QI9',G72D@)B8*("`@("`@("`@("`@97AT96YS:6]N7VQO
M861E9"@G<&]S:7@G*2D@>PH@("`@("`@("`@("`D;6%P:61S(#T@=')U93L*
M("`@("`@("!]"@H@("`@("`@("1C=7)R=&EM92`]('1I;64H*3L*"B`@("`@
M("`@9F]R96%C:"`H)&QI<W0@87,@)&QI;F4I('L*("`@("`@("`@("`@)&9I
M;&4@/2!A<G)A>2@I.PH@("`@("`@("`@("`D:71E;2`]('!R96=?<W!L:70H
M)R]<<RLO)RP@)&QI;F4I.PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W5N
M:7@G('Q\("@D='EP92`]/2`G=VEN)R`F)B`A<')E9U]M871C:"@G?%QD7&0M
M7&1<9"U<9%QD?"<L("1I=&5M6S!=*2DI('L*("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D:71E;2D@/"`X('Q\('-U8G-T<B@D;&EN92P@,"P@-2D@/3T@
M)W1O=&%L)RD@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@
M/2`D:71E;5LP73L*("`@("`@("`@("`@("`@(&EF("@D;6%P:61S*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W5I9'-;)&ET
M96U;,EU=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GD@/2!P
M;W-I>%]G971P=W5I9"@D:71E;5LR72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=6ED<ULD:71E;5LR75T@/2`H96UP='DH)&5N=')Y*2D@
M/R`D:71E;5LR72`Z("1E;G1R>5LG;F%M92==.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D9FEL95LG;W=N97(G72`]("1T
M:&ES+3Y?=6ED<ULD:71E;5LR75T["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W5I9'-;)&ET96U;,UU=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D96YT<GD@/2!P;W-I>%]G971G<F=I9"@D:71E;5LS
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=6ED<ULD:71E
M;5LS75T@/2`H96UP='DH)&5N=')Y*2D@/R`D:71E;5LS72`Z("1E;G1R>5LG
M;F%M92==.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG9W)O=7`G72`]("1T:&ES+3Y?=6ED<ULD:71E;5LS75T[
M"@H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D9FEL95LG;W=N97(G72`]("1I=&5M6S)=.PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=G<F]U<"==(#T@)&ET96U;,UT["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D9FEL95LG;F%M92==(#T@<W5B<W1R*"1L
M:6YE+"!S=')P;W,H)&QI;F4L('-P<FEN=&8H(B5S("4R<R`E-7,B+"`D:71E
M;5LU72P@)&ET96U;-ETL("1I=&5M6S==*2D@*R`Q,RD["@H@("`@("`@("`@
M("`@("`@+R\@1FEL=&5R(&]U="`G+B<@86YD("<N+B<@96YT<FEE<RX*("`@
M("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EPN7"X_7"\_)"\G+"`D
M9FEL95LG;F%M92==*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($9I;'1E
M<B!O=70@9&]T9FEL97,@:68@=&AE>2!A<F5N)W0@=V%N=&5D+@H@("`@("`@
M("`@("`@("`@:68@*"$D9&]T9FEL97,@)B8@<W5B<W1R*"1F:6QE6R=N86UE
M)UTL(#`L(#$I(#T]("<N)RD@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1P,2`]
M('-U8G-T<B@D9FEL95LG<&5R;7,G72P@,"P@,2D["B`@("`@("`@("`@("`@
M("!I9B`H)'`Q(#T]/2`G;"<I('L*("`@("`@("`@("`@("`@("`@("`D9FEL
M95LG;&EN:R==(#T@<W5B<W1R*"1F:6QE6R=N86UE)UTL('-T<G!O<R@D9FEL
M95LG;F%M92==+"`G+3XG*2`K(#,I.PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=N86UE)UT@/2!S=6)S='(H)&9I;&5;)VYA;64G72P@,"P@<W1R<&]S
M*"1F:6QE6R=N86UE)UTL("<M/B<I("T@,2D["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&5;)W1Y<&4G72`]("<J*G-Y;2<["@H@("`@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YI<T9O;&1E<B@G)RP@)&9I;&5;)VQI;FLG72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VQI;FMT>7!E
M)UT@/2`G*BID:7(G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)T<R`]
M(&5X<&QO9&4H)R\G+"`D9FEL95LG;&EN:R==*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M97AP;&]D92@G+B<L(&%R<F%Y7W!O<"@D<&%R=',I*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D;F%M92D@/3T@,2!\?"`H)&YA;65;,%T@/3T]("<G("8F(&-O=6YT
M*"1N86UE*2`]/2`R*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=L:6YK='EP92==
M(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9I;&5;)VQI;FMT>7!E)UT@/2!61E,Z.G-T<G1O;&]W97(H87)R87E?
M<&]P*"1N86UE*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@D<#$@/3T]("=D
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BID
M:7(G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D;F%M92`](&5X<&QO9&4H)RXG+"`D9FEL95LG;F%M92==*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&YA;64I(#T](#$@?'P@*'-U
M8G-T<B@D9FEL95LG;F%M92==+"`P+"`Q*2`]/3T@)RXG("8F(&-O=6YT*"1N
M86UE*2`]/2`R*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG
M='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`](%9&
M4SHZ<W1R=&]L;W=E<B@D;F%M95MC;W5N="@D;F%M92D@+2`Q72D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"1F:6QE6R=T>7!E)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G
M72`]("1I=&5M6S1=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*'-T<G!O<R@D:71E;5LW72P@)SHG*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("`@("`D9FEL95LG9&%T92==(#T@<W1R=&]T:6UE*"1I
M=&5M6S==("X@)SHP,"<@+B`D:71E;5LU72`N("<@)R`N("1I=&5M6S9=("X@
M)R`G("X@9&%T92@G62<L("1C=7)R=&EM92DI.PH@("`@("`@("`@("`@("`@
M("`@("\O($EF('1H92!F='`@<V5R=F5R(')E<&]R=',@82!F:6QE(&UO9&EF
M:6-A=&EO;B!D871E(&UO<F4*("`@("`@("`@("`@("`@("`@("`O+R!L97-S
M('1H86X@;VYE(&1A>2!I;B!T:&4@9G5T=7)E+"!D;VXG="!T<GD@=&\@<W5B
M=')A8W0*("`@("`@("`@("`@("`@("`@("`O+R!A('EE87(@9G)O;2!T:&4@
M9&%T92X@(%1H97)E(&ES(&YO('=A>2!T;R!K;F]W+"!F;W(*("`@("`@("`@
M("`@("`@("`@("`O+R!E>&%M<&QE+"!I9B!T:&4@5D93('-E<G9E<B!A;F0@
M=&AE(&9T<"!S97)V97(@<F5S:61E"B`@("`@("`@("`@("`@("`@("`@+R\@
M:6X@9&EF9F5R96YT('1I;65Z;VYE<RX@(%=E('-H;W5L9"!S:6UP;'D@<F5P
M;W)T('1O('1H90H@("`@("`@("`@("`@("`@("`@("\O("!U<V5R('=H870@
M=&AE($944"!S97)V97(@:7,@<F5T=7)N:6YG+@H@("`@("`@("`@("`@("`@
M("`@(&EF("@D9FEL95LG9&%T92==(#X@*"1C=7)R=&EM92`K(#@V-#`P*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG9&%T92==(#T@<W1R
M=&]T:6UE*"1I=&5M6S==("X@)SHP,"<@+B`D:71E;5LU72`N("<@)R`N("1I
M=&5M6S9=("X@)R`G("X@*&1A=&4H)UDG+"`D8W5R<G1I;64I("T@,2DI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V1A=&4G72`]('-T<G1O=&EM
M92@G,#`Z,#`Z,#`G("X@)&ET96U;-5T@+B`G("<@+B`D:71E;5LV72`N("<@
M)R`N("1I=&5M6S==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E:68@*"1T>7!E(#T]("=N971W87)E)RD@>PH@("`@("`@("`@("`@
M("`@)&9I;&4@/2!!<G)A>2@I.PH@("`@("`@("`@("`@("`@)&9I;&5;)W!E
M<FUS)UT@/2`D:71E;5LQ73L*("`@("`@("`@("`@("`@("1F:6QE6R=O=VYE
M<B==(#T@)&ET96U;,ET["B`@("`@("`@("`@("`@("!I9B`H)&ET96U;,%T@
M/3T@)V0G*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]
M("<J*F1I<B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2`D:71E
M;5LS73L*("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/2`D:71E;5LW
M73L*("`@("`@("`@("`@("`@("1I;F1E>"`](#@["B`@("`@("`@("`@("`@
M("!W:&EL92`H)&EN9&5X(#P@8V]U;G0H)&ET96TI*2!["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)VYA;64G72`N/2`G("<@+B`D:71E;5LD:6YD97A=
M.PH@("`@("`@("`@("`@("`@("`@("1I;F1E>"LK.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@
M2&%N9&QE(%=I;F1O=W,@1E10('-E<G9E<G,@<F5T=7)N:6YG($1/4RUS='EL
M92!F:6QE"B`@("`@("`@("`@("`@("`@*B!L:7-T:6YG<RX@*B\*("`@("`@
M("`@("`@("`@("1F:6QE6R=P97)M<R==(#T@)R<["B`@("`@("`@("`@("`@
M("`D9FEL95LG;W=N97(G72`]("<G.PH@("`@("`@("`@("`@("`@)&9I;&5;
M)V=R;W5P)UT@/2`G)SL*("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@
M/2`D:71E;5LS73L*("`@("`@("`@("`@("`@("1I;F1E>"`](#0["B`@("`@
M("`@("`@("`@("!W:&EL92`H)&EN9&5X(#P@8V]U;G0H)&ET96TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&9I;&5;)VYA;64G72`N/2`G("<@+B`D:71E
M;5LD:6YD97A=.PH@("`@("`@("`@("`@("`@("`@("1I;F1E>"LK.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9I;&5;)V1A=&4G72`]
M('-T<G1O=&EM92@D:71E;5LP72`N("<@)R`N("1I=&5M6S%=*3L*("`@("`@
M("`@("`@("`@(&EF("@D:71E;5LR72`]/2`G/$1)4CXG*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("TQ.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG<VEZ92==
M(#T@)&ET96U;,ET["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!E>'!L
M;V1E*"<N)RP@)&9I;&5;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1N86UE*2`]/2`Q('Q\("AS=6)S='(H)&9I;&5;)VYA;64G
M72P@,"P@,2D@/3T]("<N)R`F)B!C;W5N="@D;F%M92D@/3T@,BDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z.G-T<G1O;&]W97(H)&YA
M;65;8V]U;G0H)&YA;64I("T@,5TI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+R\@1FEL=&5R:6YG+@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]F:6QT97)-
M871C:"@D9FEL=&5R+"`D9FEL95LG;F%M92==*2D@>PH@("`@("`@("`@("`@
M("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D:7)O;FQY("8F("1F:6QE
M6R=T>7!E)UT@(3T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@('5N<V5T
M*"1F:6QE*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D9FEL97-;)&9I;&5;)VYA;64G75T@/2`D9FEL
M93L*("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES<V5T*"1O;&1D:7(I*2!["B`@("`@("`@("`@("1R97,@/2`D
M=&AI<RT^7W-E=%!A=&@H)&]L9&1I<BD["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D9FEL97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R
M=&5D(&QI<W0@;V8@9F]L9&5R<R!I;B!T:&4@<W!E8VEF:65D(&1I<F5C=&]R
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@
M5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2!T;R!G970@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R
M+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("`@($AA<V@@;V8@
M:71E;7,@=&\@9FEL=&5R(&)A<V5D(&]N(&9O;&1E<FQI<W0N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D9&]T9F]L9&5R<R`@26YC;'5D92!D;W1F;VQD97)S
M/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9O;&1E<B!L:7-T(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D
M9FEL=&5R(#T@;G5L;"P@)&1O=&9O;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@
M("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES
M7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9O;&1E<G,@/2!A<G)A>2@I
M.PH@("`@("`@("1F;VQD97(@/2!A<G)A>2@I.PH*("`@("`@("`D9F]L9&5R
M3&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL+"`D9&]T9F]L
M9&5R<RP@=')U92D["B`@("`@("`@:68@*&ES7V$H)&9O;&1E<DQI<W0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F;VQD97),:7-T
M.PH@("`@("`@('T*"B`@("`@("`@)&9O;&1E<ELG=F%L)UT@/2`D=&AI<RT^
M7W!A<F5N=$1I<B@D<&%T:"D["B`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@
M/2`G+BXG.PH@("`@("`@("1F;VQD97);)VQA8F5L)UT@/2`G+BXG.PH*("`@
M("`@("`D9F]L9&5R<ULD9F]L9&5R6R=V86PG75T@/2`D9F]L9&5R.PH*("`@
M("`@("!F;W)E86-H("@D9F]L9&5R3&ES="!A<R`D9FEL97,I('L*("`@("`@
M("`@("`@)&9O;&1E<ELG=F%L)UT@/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L
M("1F:6QE<ULG;F%M92==*3L*("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V
M)UT@/2`D9FEL97-;)VYA;64G73L*("`@("`@("`@("`@)&9O;&1E<ELG;&%B
M96PG72`]("1F;VQD97);)W9A;"==.PH*("`@("`@("`@("`@)&9O;&1E<G-;
M)&9O;&1E<ELG=F%L)UU=(#T@)&9O;&1E<CL*("`@("`@("!]"@H@("`@("`@
M(&MS;W)T*"1F;VQD97)S*3L*("`@("`@("!R971U<FX@)&9O;&1E<G,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;W!I97,@82!F:6QE('1H<F]U9V@@=&AE
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A=&@@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;W)I9VEN86P@9FEL92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!N86UE(&]F('1H92!D
M97-T:6YA=&EO;B!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@
M)&YA;64L("1D97-T*0H@("`@>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G
M9710871H*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H
M)WQ>)R`N('!R96=?<75O=&4H)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T
M(&-O<'D@9FEL92AS*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H
M92!S86UE+B(I*3L*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@)&9I;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T
M+"!N=6QL+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D9FEL94-H96-K+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL94-H96-K
M.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D9FEL94-H96-K(&%S("1F
M:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(B5S(&%L<F5A9'D@97AI<W1S+B(I+"`D=&AI<RT^7V=E=%!A
M=&@H)&1E<W0L("1N86UE*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D:7-$:7(@/2!F86QS93L*("`@("`@("`D9&ER0VAE8VL@/2`D
M=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L;"P@9F%L<V4I.PH@("`@("`@
M(&EF("AI<U]A*"1D:7)#:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&1I<D-H96-K.PH@("`@("`@('T*("`@("`@("!F;W)E
M86-H("@D9&ER0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F
M:6QE6R=N86UE)UT@/3T@)&YA;64@)B8@)&9I;&5;)W1Y<&4G72`]/2`G*BID
M:7(G*2!["B`@("`@("`@("`@("`@("`D:7-$:7(@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@D:7-$:7(I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YC<F5A=&5&;VQD97(H)&1E<W0L("1N86UE*3L*"B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D9FEL95]L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'1H:7,M/E]G9710
M871H*"1P871H+"`D;F%M92DI.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL
M95]L:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F-O<'DH)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DL("1F
M:6QE6R=N86UE)UTL("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T;7!&:6QE(#T@)'1H:7,M/E]G971496UP1FEL92@I
M.PH@("`@("`@("`@("`D9F5T8V@@/2!`9G1P7V=E="@D=&AI<RT^7W-T<F5A
M;2P@)'1M<$9I;&4L("1O<FEG+"!&5%!?0DE.05)9*3L*("`@("`@("`@("`@
M:68@*"$D9F5T8V@I('L*("`@("`@("`@("`@("`@('5N;&EN:R@D=&UP1FEL
M92D["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(I+"`D;W)I
M9RDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(4!F='!?<'5T
M*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE
M*2P@)'1M<$9I;&4L($944%]"24Y!4EDI*2!["B`@("`@("`@("`@("`@("!U
M;FQI;FLH)'1M<$9I;&4I.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")&86EL960@=&\@8V]P>2!T;R!<(B5S
M7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('5N;&EN:R@D=&UP1FEL92D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($UO=F5S(&$@9FEL92!T:')O=6=H('1H92!B86-K96YD+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!O
M<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&YA;64@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D97-T("!4:&4@9&5S=&EN871I;VX@9FEL92!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO=F4H)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@("`@("`D
M;W)I9R`]("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I.PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G7W%U;W1E*"1O<FEG*2`N("<O
M/R1\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D-A;FYO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I
M<R!W:71H:6X@<V]U<F-E+B(I*3L*("`@("`@("!]"@H@("`@("`@("1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@)&9I;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L
M9&5R*"1D97-T+"!N=6QL+"!T<G5E*3L*("`@("`@("!F;W)E86-H("@D9FEL
M94-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M
M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(B5S(&%L<F5A9'D@97AI<W1S+B(I+"`D
M=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!F='!?<F5N86UE*"1T:&ES+3Y?
M<W1R96%M+"`D;W)I9RP@)'1H:7,M/E]G9710871H*"1D97-T+"`D;F%M92DI
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(I+"`D=&AI<RT^7V=E
M=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C
M=7)R96YT('=O<FMI;F<@9&ER96-T;W)Y(&]N('1H92!&5%`@<V5R=F5R+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N="!W;W)K
M:6YG(&1I<F5C=&]R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N
M=$1I<F5C=&]R>2@I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&-O;FYE8W1E
M9"`]("1T:&ES+3Y?8V]N;F5C="@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8V]N;F5C=&5D.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@9G1P7W!W9"@D=&AI<RT^7W-T<F5A;2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&%N9V5S('1H92!C=7)R96YT(&1I<F5C=&]R>2!O;B!T:&4@
M<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O(&-H86YG
M92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,L(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5T4&%T:"@D<&%T:"D*("`@('L*("`@("`@("!I9B`H
M(4!F='!?8VAD:7(H)'1H:7,M/E]S=')E86TL("1P871H*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N(BDL("1P871H*2D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@9G5L;"!P871H(&]F(&%N(&ET96TN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE(&1I<F5C=&]R>2!O9B!T:&4@:71E;2X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!I=&5M+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($9U;&P@<&%T:"!T;R!T:&4@9FEL92!W:&5N
M("1P871H(&ES(&YO="!E;7!T>2!A;F0@:G5S=`H@("`@("H@("`@("`@("`@
M("`@("`@)&YA;64@=VAE;B!N;W0@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T4&%T:"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*"1P
M871H("$]/2`G)RD@>PH@("`@("`@("`@("!R971U<FX@*"1P871H("X@)R\G
M("X@)&YA;64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@*"1N86UE*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F5N="!D:7)E
M8W1O<GD@;V8@=&AE('-P96-I9FEE9"!P871H+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@(%1H92!P871H('1O(&=E="!T:&4@<&%R96YT(&]F+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R96YT(&1I<F5C=&]R>2`H<W1R
M:6YG*2!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@
M("`@("`@("`@(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&%R96YT1&ER*"1P871H*0H@("`@>PH@("`@("`@("1C;VYN(#T@
M)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@
M("`@('T*"B`@("`@("`@)&]L9&1I<B`]("1T:&ES+3YG971#=7)R96YT1&ER
M96-T;W)Y*"D["B`@("`@("`@0&9T<%]C9'5P*"1T:&ES+3Y?<W1R96%M*3L*
M"B`@("`@("`@)'!A<F5N="`]("1T:&ES+3YG971#=7)R96YT1&ER96-T;W)Y
M*"D["B`@("`@("`@)'1H:7,M/E]S9710871H*"1O;&1D:7(I.PH*("`@("`@
M("!I9B`H(21P87)E;G0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<F5N=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C;VYN
M96-T:6]N('1O('1H92!&5%`@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]S=')E86T@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M(&EF("@A97AT96YS:6]N7VQO861E9"@G9G1P)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!&5%`@97AT96YS
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(BDI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R86US*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5Q=6ER960@/2!A
M<G)A>2@G:&]S='-P96,G+"`G=7-E<FYA;64G+"`G<&%S<W=O<F0G*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)')E<75I<F5D(&%S("1V86PI('L*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)'9A;%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!6
M1E,@8V]N9FEG=7)A=&EO;BXB*2P@)'9A;"DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#;VYN96-T('1O('1H
M92!F='`@<V5R=F5R('5S:6YG('1H92!S=7!P;&EE9"!P87)A;65T97)S+B`J
M+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S<VPG
M72DI('L*("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9T
M<%]S<VQ?8V]N;F5C="<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S=')E86T@/2!`9G1P7W-S;%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H
M;W-T<W!E8R==+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S=')E86T@/2!`9G1P7V-O;FYE8W0H
M)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL("1T:&ES+3Y?<&%R86US6R=P
M;W)T)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]S=')E86TI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(BDI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8V]N;F5C=&5D(#T@0&9T
M<%]L;V=I;B@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]P87)A;7-;)W5S97)N
M86UE)UTL("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*3L*("`@("`@("`@
M("`@:68@*"$D8V]N;F5C=&5D*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG<&%S=B==*2D@>PH@("`@("`@("`@("`@("`@
M0&9T<%]P87-V*"1T:&ES+3Y?<W1R96%M+"!T<G5E*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG=&EM
M96]U="==*2D@>PH@("`@("`@("`@("`@("`@9G1P7W-E=%]O<'1I;VXH)'1H
M:7,M/E]S=')E86TL($944%]424U%3U547U-%0RP@)'1H:7,M/E]P87)A;7-;
M)W1I;65O=70G72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C
M=',@9G)O;2!T:&4@1E10('-E<G9E<B!A;F0@8VQE86YS('5P('1H92!C;VYN
M96-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@0&9T
M<%]Q=6ET*"1T:&ES+3Y?<W1R96%M*3L*("`@("`@("`D=&AI<RT^7W-T<F5A
M;2`](&9A;'-E.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U9&4R]"<F]W<V5R+G!H<```````````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C8S-@`Q,#4Q-30S,3`V,``P,3<W-3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M($-L87-S(&9O<B!P<F]V:61I;F<@82!G96YE<FEC(%5)(&9O<B!A;GD@5D93
M(&EN<W1A;F-E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+T)R
M;W=S97(N<&AP+'8@,2XX+C$P+CD@,C`P-B\P-2\S,2`P-#HU,#HP,B!S;'5S
M87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?0G)O=W-E<B!["@H@("`@+RHJ
M"B`@("`@*B!4:&4@5D93(&EN<W1A;F-E('1H870@=V4@87)E(&)R;W=S:6YG
M+@H@("`@("H*("`@("`J($!V87(@5D93"B`@("`@*B\*("`@('9A<B`D7W9F
M<SL*"B`@("`O*BH*("`@("`J(%1H92!D:7)E8W1O<GD@=VAE<F4@=&AE('1E
M;7!L871E<R!T;R!U<V4@87)E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7W1E;7!L871E<SL*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(%9&4R`F)'9F<R`@
M("`@("`@("!!(%9&4R!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M96UP;&%T97,@(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@5D937T)R;W=S
M97(H)B1V9G,L("1T96UP;&%T97,I"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1V9G,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?=F9S(#T@)'9F<SL*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]T96UP;&%T97,@/2`D=&5M<&QA=&5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!61E,@;V)J96-T(&EN
M('1H92!L;V-A;"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(%9&4R`F
M)'9F<R`@02!61E,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9716
M1E-/8FIE8W0H)B1V9G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]V9G,@/2`F
M)'9F<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@(%1/1$\*("`@("`J($!P87)A
M;2!B;V]L96%N("1D;W1F:6QE<R`@5$]$3PH@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&1I<F]N;'D@("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5)
M*"1P871H+"`D9&]T9FEL97,@/2!F86QS92P@)&1I<F]N;'D@/2!F86QS92D*
M("`@('L*("`@("`@("`D=&AI<RT^7W9F<RT^;&ES=$9O;&1E<B@D<&%T:"P@
M)&1O=&9I;&5S+"`D9&ER;VYL>2D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+W-Q;%]F:6QE+G!H<```````
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<R-#4T`#$P-3$U
M-#,Q,#8P`#`R,#$S,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J($9I;&4@=F%L=64@9F]R('9F<U]T
M>7!E(&-O;'5M;BX*("HO"F1E9FEN92@G5D937T9)3$4G+"`Q*3L*"B\J*@H@
M*B!&;VQD97(@=F%L=64@9F]R('9F<U]T>7!E(&-O;'5M;BX*("HO"F1E9FEN
M92@G5D937T9/3$1%4B<L(#(I.PH*+RHJ"B`J(%9&4SHZ(&EM<&QE;65N=&%T
M:6]N('5S:6YG(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX*("H@
M;&%Y97(@86YD(&QO8V%L(&9I;&4@<WES=&5M(&9O<B!F:6QE('-T;W)A9V4N
M"B`J"B`J(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A<F%M<SH\<')E/@H@*B`@
M("`@("=P:'!T>7!E)R`@("`@("!4:&4@9&%T86)A<V4@='EP92`H:64N("=P
M9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+@H@*B`@("`@("=V9G-R;V]T)R`@("`@
M("!4:&4@<F]O="!D:7)E8W1O<GD@;V8@=VAE<F4@=&AE(&9I;&5S('-H;W5L
M9"!B90H@*B`@("`@("`@("`@("`@("`@("`@("!A8W1U86QL>2!S=&]R960N
M/"]P<F4^"B`J"B`J($]P=&EO;F%L('9A;'5E<SH\<')E/@H@*B`@("`@("=T
M86)L92<@("`@("`@("!4:&4@;F%M92!O9B!T:&4@=F9S('1A8FQE(&EN("=D
M871A8F%S92<N($1E9F%U;'1S('1O"B`J("`@("`@("`@("`@("`@("`@("`@
M("=H;W)D95]V9G,G+CPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A
M=&%B87-E(&EM<&QE;65N=&%T:6]N<SH\<')E/@H@*B`@("`@("=H;W-T<W!E
M8R<@("`@("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*
M("H@("`@("`G<')O=&]C;VPG("`@("`@5&AE(&-O;6UU;FEC871I;VX@<')O
M=&]C;VP@*"=T8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@("`@("=D871A8F%S
M92<@("`@("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N"B`J("`@("`@)W5S
M97)N86UE)R`@("`@(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("`@("=P87-S=V]R9"<@("`@("!4
M:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@
M("`@)V]P=&EO;G,G("`@("`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S
M('1O('1H92!D871A8F%S92X*("H@("`@("`G='1Y)R`@("`@("`@("`@5&AE
M(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@
M("`@("`G<&]R="<@("`@("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J(%1H92!T86)L92!S
M=')U8W1U<F4@9F]R('1H92!61E,@8V%N(&)E(&9O=6YD(&EN"B`J(&1A=&$O
M=F9S+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`L=B`Q+C0T+C0N,C(@,C`P-B\P-2\S,2`P-#HU,#HP,B!S;'5S
M87)Z($5X<"`D"B`J"B`J($!A=71H;W(@($UI8VAA96P@5F%R9VAE<V4@/&UI
M:V4N=F%R9VAE<V5`87-C96QL871E8V@N8V]M/@H@*B!`<&%C:V%G92!61E,*
M("HO"F-L87-S(%9&4U]S<6Q?9FEL92!E>'1E;F1S(%9&4R!["@H@("`@+RHJ
M"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B87-E(&-O;FYE
M8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@
M)%]D8B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ
M92!O9B!A(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T
M:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!S:7IE
M(&]F('1H92!F:6QE(&EN(&)Y=&5S(&]R(%!%05)?17)R;W(@;VX*("`@("`J
M("`@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*"@D<VEZ
M92`]($!F:6QE<VEZ92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N
M86UE*2DI(#T]/2!F86QS92E["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S+R5S7"(N(BP@)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T<FEE=F4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@
M<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F
M:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)'!A=&@L("1N
M86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I
M;&4@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*"B`@
M("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G
M*2D@>PH@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1F
M:6QE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G`@/2!`9F]P
M96XH)&9I;&4L("=R8B<I.PH@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1D871A(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D9FEL92DI.PH@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I
M;B!T:&4@5D93+"!W:71H('1H92!D871A(&-O<&EE9"!F<F]M(&$@=&5M<&]R
M87)Y"B`@("`@*B!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA
M;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&UP1FEL92`@("`@
M(%1H92!T96UP;W)A<GD@9FEL92!C;VYT86EN:6YG('1H92!D871A('1O(&)E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1O<F5D+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L
M;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1P871H
M+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@+RH@3F\@;F5E9"!T;R!C:&5C:R!Q=6]T82!H97)E(&%S('=E
M('=I;&P@8VAE8VL@:70@=VAE;B!W92!C86QL"B`@("`@("`@("H@=W)I=&5$
M871A*"DN("HO"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?
M9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D=&UP1FEL92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&1A=&%&4"`]($!F;W!E;B@D=&UP1FEL92P@)W)B)RD["B`@("`@
M("`@("`@("1D871A(#T@0&9R96%D*"1D871A1E`L(&9I;&5S:7IE*"1T;7!&
M:6QE*2D["B`@("`@("`@("`@(&9C;&]S92@D9&%T8490*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YW<FET941A=&$H)'!A=&@L("1N86UE
M+"`D9&%T82P@)&%U=&]C<F5A=&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4W1O<F4@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@
M=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E
M871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@
M)&YA;64L("1D871A+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%7<FET92@G<W1R:6YG)RP@
M)&1A=&$I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@
M("`D9G`@/2!`9F]P96XH)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D
M;F%M92DL("=W)RD["B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@
M:68@*"1A=71O8W)E871E*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D=&AI<RT^7V=E=$YA=&EV
M95!A=&@H)'!A=&@L("1N86UE*2P@)W<G*3L*("`@("`@("`@("`@("`@(&EF
M("@A)&9P*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(BDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!F=W)I=&4H)&9P
M+"`D9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]W<FET95-13$1A=&$H
M)'!A=&@L("1N86UE+"`D875T;V-R96%T92DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A
M=&@L("1N86UE*2D["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&9I;&4@:6X@
M=&AE(&1A=&%B87-E(&%N9"!T:&4@9FEL92!S>7-T96TN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE
M(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;VQD
M(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S="`@5&AE(&YE
M=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1P871H+"`D;F%M92P@)&1E
M<W0I"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=$YA=&EV95!A
M=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XG
M("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L("1D97-T*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@;6]V
M92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92XB*2D[
M"B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F
M:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@;G5L;"P@9F%L
M<V4I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*
M("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*'-T<G!O<R@D9&5S="P@)'1H:7,M/E]G971344Q.
M871I=F50871H*"1P871H+"`D;F%M92DI("$]/2!F86QS92D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H
M:7,M/G)E;F%M92@D<&%T:"P@)&YA;64L("1D97-T+"`D;F%M92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;W!I97,@82!F:6QE('1H<F]U9V@@=&AE(&)A
M8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE
M('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N(&]F('1H92!F:6QE+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O<'DH)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@
M("`@("`D;W)I9R`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA
M;64I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G7W%U;W1E
M*"1O<FEG*2`N("<O/R1\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S
M;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92XB*2D["B`@("`@
M("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@
M("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F:6QE0VAE
M8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@;G5L;"P@9F%L<V4I.PH@
M("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@
M("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*'-T<G!O<R@D9&5S="P@)'1H:7,M/E]G971344Q.871I=F50
M871H*"1P871H+"`D;F%M92DI("$]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?9&ER*"1O<FEG
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R96-U<G-I=F5#;W!Y
M*"1P871H+"`D;F%M92P@)&1E<W0I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%`8V]P>2@D;W)I9RP@)'1H:7,M/E]G971.871I=F50871H*"1D97-T+"`D
M;F%M92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@
M("`@("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72D["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)TE.4T52
M5"!)3E1/("5S("AV9G-?:60L('9F<U]T>7!E+"!V9G-?<&%T:"P@=F9S7VYA
M;64L('9F<U]M;V1I9FEE9"P@=F9S7V]W;F5R*2!604Q515,@*#\L(#\L(#\L
M(#\L(#\L(#\I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)&ED
M+"!61E-?1DE,12P@)&1E<W0L("1N86UE+"!T:6UE*"DL("1T:&ES+3Y?<&%R
M86US6R=U<V5R)UTI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!U;FQI;FLH)'1H
M:7,M/E]G971.871I=F50871H*"1D97-T+"`D;F%M92DI.PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&9O;&1E<B!O
M;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M($AO;&1S('1H92!P871H(&]F(&1I<F5C=&]R>2!T;R!C<F5A=&4@9F]L9&5R
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@2&]L9',@=&AE(&YA;64@
M;V8@=&AE(&YE=R!F;VQD97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E1F]L9&5R*"1P
M871H+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@
M("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*'-P<FEN=&8H)TE.4T525"!)3E1/("5S("AV9G-?:60L('9F<U]T>7!E+"!V
M9G-?<&%T:"P@=F9S7VYA;64L('9F<U]M;V1I9FEE9"P@=F9S7V]W;F5R*0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%9!
M3%5%4R`H/RP@/RP@/RP@/RP@/RP@/RDG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)&ED+"!61E-?1D],1$52+"`D<&%T:"P@)&YA;64L('1I;64H*2P@)'1H
M:7,M/E]P87)A;7-;)W5S97(G72DI.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H(4!M:V1I<B@D=&AI<RT^7V=E
M=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$5412!&4D]-
M("5S(%=(15)%('9F<U]I9"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@D:60I*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5N86UE(&$@9FEL92!O<B!F;VQD97(@:6X@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD
M('!A=&@@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N
M86UE("!4:&4@;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F5W<&%T:"`@5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE
M=VYA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("!I
M9B`H<W1R<&]S*"1N97=P871H+"`G+R<I(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("`D<&%R96YT(#T@)R<["B`@("`@("`@("`@("1P871H(#T@)&YE=W!A
M=&@["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D<&%R96YT
M+"`D<&%T:"D@/2!E>'!L;V1E*"<O)RP@)&YE=W!A=&@L(#(I.PH@("`@("`@
M('T*("`@("`@("!I9B`H(21T:&ES+3YI<T9O;&1E<B@D<&%R96YT+"`D<&%T
M:"DI('L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YA
M=71O8W)E871E4&%T:"@D;F5W<&%T:"DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M<W!R:6YT9B@G55!$051%("5S(%-%5"!V9G-?<&%T:"`](#\L('9F<U]N86UE
M(#T@/RP@=F9S7VUO9&EF:65D(#T@/PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@
M=F9S7VYA;64@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1N97=P871H
M+"`D;F5W;F%M92P@=&EM92@I+"`D;VQD<&%T:"P@)&]L9&YA;64I*3L*"B`@
M("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C=&5D4F]W<R@I(#T](#`I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-?82@D=&AI<RT^7W)E8W5R<VEV95-13%)E;F%M92@D;VQD<&%T:"P@
M)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P
M<FEN=&8H)U501$%412`E<R!3150@=F9S7W!A=&@@/2`_+"!V9G-?;F%M92`]
M(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;VQD<&%T:"P@)&]L9&YA
M;64L("1N97=P871H+"`D;F5W;F%M92DI.PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`:7-?9&ER*"1T
M:&ES+3Y?9V5T3F%T:79E4&%T:"@D;F5W<&%T:"DI*2!["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97,@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)&YE=W!A
M=&@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)')E<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%`
M<F5N86UE*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA
M;64I+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&YE=W!A=&@L("1N97=N86UE
M*2DI('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*'-P<FEN=&8H)U501$%412`E<R!3150@=F9S7W!A=&@@/2`_+"!V9G-?;F%M
M92`](#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;VQD<&%T:"P@)&]L
M9&YA;64L("1N97=P871H+"`D;F5W;F%M92DI.PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R(&9R;VT@=&AE(%9&
M4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4
M:&4@<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&9O;&1E<FYA;64@=&\@=7-E
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E8W5R<VEV92`@1F]R8V4@82!R
M96-U<G-I=F4@9&5L971E/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T
M:"P@)&YA;64L("1R96-U<G-I=F4@/2!F86QS92D*("`@('L*("`@("`@("`D
M8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C
M;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N
M;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5C=7)S:79E*2!["B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^96UP='E&;VQD97(H)'!A=&@@+B`G
M+R<@+B`D;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&QI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"`N("<O)R`N("1N86UE
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H8V]U;G0H)&QI<W0I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P871H("X@)R\G("X@)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P
M<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@
M=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH5D937T9/3$1%4BP@)'!A=&@L("1N86UE*2D["@H@("`@("`@
M(&EF("@D=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P('Q\(&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/E]R96-U<G-I=F5344Q$96QE=&4H)'!A=&@L("1N86UE*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]R96-U
M<G-I=F5,1E-$96QE=&4H)'!A=&@L("1N86UE*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(BDI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$96QE=&4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S=&]R
M92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1FEL92@D<&%T
M:"P@)&YA;64I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1
M=6]T841E;&5T92@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AI<U]A*"1R
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$14Q%5$4@1E)/
M32`E<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]P871H(#T@/R!!3D0@
M=F9S7VYA;64@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*%9&4U]&24Q%
M+"`D<&%T:"P@)&YA;64I*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F
M9F5C=&5D4F]W<R@I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%`=6YL:6YK*"1T:&ES+3Y?9V5T3F%T:79E4&%T
M:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&$@;&ES="!O9B!T:&4@8V]N=&5N=',@;V8@82!F
M;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("!4:&4@9&ER96-T;W)Y('!A=&@N"B`@("`@*B!`<&%R86T@;6EX960@)&9I
M;'1E<B`@("`@(%-T<FEN9R]H87-H(&]F(&ET96US('1O(&9I;'1E<B!B87-E
M9"!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE;F%M
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO=R!D;W1F
M:6QE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO=R!D
M:7)E8W1O<FEE<R!O;FQY/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($9I;&4@;&ES="!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]L:7-T1F]L9&5R*"1P871H+"`D9FEL=&5R
M(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1I<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]
M("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@
M("`@("!]"@H@("`@("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("`@("`@)&9I
M;&5,:7-T(#T@87)R87DH*3L*"B`@("`@("`@)&9I;&5,:7-T(#T@)'1H:7,M
M/E]D8BT^9V5T06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?;F%M92P@=F9S7W1Y
M<&4L('9F<U]M;V1I9FEE9"P@=F9S7V]W;F5R($923TT@)7,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!V
M9G-?<&%T:"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'!A
M=&@I*3L*("`@("`@("!I9B`H:7-?82@D9FEL94QI<W0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE3&ES=#L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D;&EN92D@>PH@("`@
M("`@("`@("`O+R!&:6QT97(@;W5T(&1O=&9I;&5S(&EF('1H97D@87)E;B=T
M('=A;G1E9"X*("`@("`@("`@("`@:68@*"$D9&]T9FEL97,@)B8@<W5B<W1R
M*"1L:6YE6S!=+"`P+"`Q*2`]/2`G+B<I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL95LG;F%M
M92==(#T@)&QI;F5;,%T["@H@("`@("`@("`@("!I9B`H)&QI;F5;,5T@/3T@
M5D937T9)3$4I('L*("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G
M+B<L("1L:6YE6S!=*3L*"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&YA
M;64I(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==
M(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z.G-T<G1O;&]W97(H
M)&YA;65;8V]U;G0H)&YA;64I("T@,5TI.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2!F:6QE<VEZ92@D=&AI
M<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1L:6YE6S!=*2D["B`@("`@("`@
M("`@('T@96QS96EF("@D;&EN95LQ72`]/2!61E-?1D],1$52*2!["B`@("`@
M("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ9&ER)SL*("`@("`@("`@
M("`@("`@("1F:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&9I;&5;)V1A=&4G72`]("1L:6YE6S)=.PH@("`@("`@("`@
M("`D9FEL95LG;W=N97(G72`]("1L:6YE6S-=.PH@("`@("`@("`@("`D9FEL
M95LG<&5R;7,G72`]("<G.PH@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]
M("<G.PH*("`@("`@("`@("`@+R\@1FEL=&5R:6YG+@H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]F:6QT97)-871C:"@D9FEL=&5R+"`D9FEL95LG;F%M92==
M*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1D:7)O;FQY("8F("1F:6QE6R=T>7!E)UT@(3T]("<J*F1I<B<I('L*("`@
M("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL97-;)&9I
M;&5;)VYA;64G75T@/2`D9FEL93L*("`@("`@("`@("`@=6YS970H)&9I;&4I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!S;W)T960@;&ES="!O9B!F;VQD97)S
M(&EN('-P96-I9FEE9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O
M<GD@=&\@9V5T('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&1I<F5C=&]R>2!L:7-T(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`D
M9FEL=&5R("`@("`@("!3=')I;F<O:&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@
M8F%S960@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;VQD97)L:7-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9O;&1E<G,@
M($EN8VQU9&4@9&]T9F]L9&5R<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!&;VQD97(@;&ES="!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O
M;&1E<G,H)'!A=&@@/2`G)RP@)&9I;'1E<B`](&%R<F%Y*"DL("1D;W1F;VQD
M97)S(#T@=')U92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@
M("`@("1S<6P@/2!S<')I;G1F*"=314Q%0U0@=F9S7VYA;64L('9F<U]P871H
M($923TT@)7,@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?='EP92`](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*3L*"B`@("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^7V1B+3YG971!
M;&PH)'-Q;"P@87)R87DH)'!A=&@L("161E-?1D],1$52*2D["B`@("`@("`@
M:68@*&ES7V$H)&9O;&1E<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1F;VQD97),:7-T.PH@("`@("`@('T*"B`@("`@("`@
M)&9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F;VQD97),
M:7-T(&%S("1L:6YE*2!["B`@("`@("`@("`@("1F;VQD97);)W9A;"==(#T@
M)'1H:7,M/E]G971.871I=F50871H*"1L:6YE6S%=+"`D;&EN95LP72D["B`@
M("`@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@)R<["B`@("`@("`@("`@
M("1F;VQD97);)VQA8F5L)UT@/2`G)SL*"B`@("`@("`@("`@("1C;W5N="`]
M('-U8G-T<E]C;W5N="@D9F]L9&5R6R=V86PG72P@)R\G*3L*"B`@("`@("`@
M("`@("1X(#T@,#L*("`@("`@("`@("`@=VAI;&4@*"1X(#P@)&-O=6YT*2![
M"B`@("`@("`@("`@("`@("`D9F]L9&5R6R=A8F)R978G72`N/2`G("`@("<[
M"B`@("`@("`@("`@("`@("`D9F]L9&5R6R=L86)E;"==("X]("<@("`@)SL*
M("`@("`@("`@("`@("`@("1X*RL["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1F;VQD97);)V%B8G)E=B==("X]("1L:6YE6S!=.PH@("`@("`@("`@
M("`D9F]L9&5R6R=L86)E;"==("X]("1L:6YE6S!=.PH*("`@("`@("`@("`@
M)'-T<FQE;B`](%9&4SHZ<W1R;&5N*"1F;VQD97);)VQA8F5L)UTI.PH@("`@
M("`@("`@("!I9B`H)'-T<FQE;B`^(#(V*2!["B`@("`@("`@("`@("`@("`D
M9F]L9&5R6R=A8F)R978G72`]('-U8G-T<B@D9F]L9&5R6R=L86)E;"==+"`P
M+"`H)&-O=6YT("H@-"DI.PH@("`@("`@("`@("`@("`@)&QE;F=T:"`]("@R
M.2`M("@D8V]U;G0@*B`T*2D@+R`R.PH@("`@("`@("`@("`@("`@)&9O;&1E
M<ELG86)B<F5V)UT@+CT@<W5B<W1R*"1F;VQD97);)VQA8F5L)UTL("@D8V]U
M;G0@*B`T*2P@)&QE;F=T:"D["B`@("`@("`@("`@("`@("`D9F]L9&5R6R=A
M8F)R978G72`N/2`G+BXN)SL*("`@("`@("`@("`@("`@("1F;VQD97);)V%B
M8G)E=B==("X]('-U8G-T<B@D9F]L9&5R6R=L86)E;"==+"`M,2`J("1L96YG
M=&@L("1L96YG=&@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9F]U
M;F0@/2!F86QS93L*("`@("`@("`@("`@9F]R96%C:"`H)&9I;'1E<B!A<R`D
M9FQT<BD@>PH@("`@("`@("`@("`@("`@:68@*"1F;VQD97);)W9A;"==(#T]
M("1F;'1R*2!["B`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@("1F;VQD97)S6R1F;VQD
M97);)W9A;"==72`]("1F;VQD97(["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&MS;W)T*"1F;VQD97)S*3L*("`@("`@("!R971U<FX@)&9O
M;&1E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-I=F5L>2!C;W!I
M97,@=&AE(&-O;G1E;G1S(&]F(&$@9F]L9&5R('1O(&$@9&5S=&EN871I;VXN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&1I
M<F5C=&]R>2!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N
M86UE(&]F('1H92!D:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M97-T("!4:&4@9&5S=&EN871I;VX@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<F5C=7)S:79E0V]P>2@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@
M>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E1F]L9&5R*"1D97-T
M+"`D;F%M92D["@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`D9FEL95]L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'1H
M:7,M/E]G971344Q.871I=F50871H*"1P871H+"`D;F%M92DI.PH*("`@("`@
M("!F;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^8V]P>2@D=&AI<RT^7V=E=%-13$YA=&EV95!A
M=&@H)'!A=&@L("1N86UE*2P@)&9I;&5;)VYA;64G72P@)'1H:7,M/E]G9713
M44Q.871I=F50871H*"1D97-T+"`D;F%M92DI.PH*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@?0H*("`@("\J*@H@("`@("H@4W1O
M<F4@82!F:6QE<R!I;F9O<FUA=&EO;B!W:71H:6X@=&AE(&1A=&%B87-E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T
M:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@
M("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S
M/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]W<FET95-13$1A=&$H)'!A=&@L("1N86UE+"`D875T
M;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1FEL92!A;')E861Y(&5X:7-T<R!I;B!D871A8F%S90H@
M("`@("`@(&EF("@D=&AI<RT^97AI<W1S*"1P871H+"`D;F%M92DI('L*("`@
M("`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`G(%-%5"!V9G-?;6]D
M:69I960@/2`_)R`N"B`@("`@("`@("`@("`@("`@("`@("<@5TA%4D4@=F9S
M7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G.PH@("`@("`@("`@("`D=F%L
M=65S(#T@87)R87DH=&EM92@I+"`D<&%T:"P@)&YA;64I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D["@H@("`@("`@("`@("`D<75E<GD@
M/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*
M("`@("`@("`@("`@("`@("`@("`@)R`H=F9S7VED+"!V9G-?='EP92P@=F9S
M7W!A=&@L('9F<U]N86UE+"!V9G-?;6]D:69I960L)R`N"B`@("`@("`@("`@
M("`@("`@("`@("<@=F9S7V]W;F5R*2!604Q515,@*#\L(#\L(#\L(#\L(#\L
M(#\I)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1I9"P@5D937T9)
M3$4L("1P871H+"`D;F%M92P@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97(G72D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU
M97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE<R!A;&P@8VAI;&0@
M<&%T:',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE(&]L9"!P871H(&]F
M('1H92!F;VQD97(@=&\@<F5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD;F%M92`@5&AE(&]L9"!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F5W<&%T:"`@5&AE(&YE=R!P871H(&]F('1H92!F;VQD97(@=&\@<F5N86UE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!N86UE
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]R96-U<G-I=F5344Q296YA;64H)&]L9'!A=&@L("1O
M;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@("!["B`@("`@("`@)&9O
M;&1E<DQI<W0@/2`D=&AI<RT^7V1B+3YG971#;VPH<W!R:6YT9B@G4T5,14-4
M('9F<U]N86UE($923TT@)7,@5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?
M<&%T:"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH5D93
M7T9/3$1%4BP@)'1H:7,M/E]G971344Q.871I=F50871H*"1O;&1P871H+"`D
M;VQD;F%M92DI*3L*"B`@("`@("`@9F]R96%C:"`H)&9O;&1E<DQI<W0@87,@
M)&9O;&1E<BD@>PH@("`@("`@("`@("`D=&AI<RT^7W)E8W5R<VEV95-13%)E
M;F%M92@D=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H)&]L9'!A=&@L("1O;&1N
M86UE*2P@)&9O;&1E<BP@)'1H:7,M/E]G971344Q.871I=F50871H*"1N97=P
M871H+"`D;F5W;F%M92DL("1F;VQD97(I.PH@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)U501$%412`E
M<R!3150@=F9S7W!A=&@@/2`_(%=(15)%('9F<U]P871H(#T@/R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@D=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H)&YE
M=W!A=&@L("1N97=N86UE*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]G971344Q.871I=F50871H*"1O;&1P
M871H+"`D;VQD;F%M92DI*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F;VQD
M97)S(&-O;G1E;G1S(&9R;VT@=&AE(%9&4R!I;B!T:&4@4U%,(&1A=&%B87-E
M+`H@("`@("H@<F5C=7)S:79E;'DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE
M('!A=&@@;V8@=&AE(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F;VQD97)N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5C=7)S
M:79E4U%,1&5L971E*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G1$5,151%($923TT@
M)7,@5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?<&%T:"`](#\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH5D937T9)3$4L("1T:&ES+3Y?9V5T4U%,3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M
M/E]D8BT^9V5T0V]L*'-P<FEN=&8H)U-%3$5#5"!V9G-?;F%M92!&4D]-("5S
M(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@/2`_)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`P+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*%9&4U]&3TQ$15(L("1T:&ES+3Y?
M9V5T4U%,3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*2D["@H@("`@("`@(&9O
M<F5A8V@@*"1F;VQD97),:7-T(&%S("1F;VQD97(I('L*("`@("`@("`@("`@
M)'1H:7,M/E]R96-U<G-I=F5344Q$96QE=&4H)'1H:7,M/E]G971344Q.871I
M=F50871H*"1P871H+"`D;F%M92DL("1F;VQD97(I.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%
M3$5412!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7VYA;64@
M/2`_($%.1"!V9G-?<&%T:"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M5D937T9/3$1%4BP@)&YA;64L("1P871H*2D["@H@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R
M<R!C;VYT96YT<R!F<F]M('1H92!61E,L(')E8W5R<VEV96QY+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!F;VQD97(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@9F]L9&5R;F%M92!T;R!U<V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W)E8W5R<VEV94Q&4T1E;&5T92@D<&%T:"P@)&YA;64I"B`@
M("!["B`@("`@("`@)&1I<B`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T
M:"P@)&YA;64I.PH@("`@("`@("1D:"`]($!O<&5N9&ER*"1D:7(I.PH*("`@
M("`@("!W:&EL92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H)&1H*2DI
M('L*("`@("`@("`@("`@:68@*"1F:6QE("$]("<N)R`F)B`D9FEL92`A/2`G
M+BXG*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?9&ER*"1D:7(@+B`G+R<@
M+B`D9FEL92DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E8W5R
M<VEV94Q&4T1E;&5T92AE;7!T>2@D<&%T:"D@/R`D;F%M92`Z("1P871H("X@
M)R\G("X@)&YA;64L("1F:6QE*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D9&ER("X@)R\G("X@)&9I
M;&4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@($!C;&]S961I<B@D9&@I.PH*("`@("`@("!R971U<FX@<FUD
M:7(H)&1I<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O
M<&5N(&$@<&5R<VES=&5N="!C;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]D8B`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A<F%M
M<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D<F5Q=6ER960@/2!A<G)A>2@G<&AP='EP92<L("=V9G-R;V]T)RD["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9"!A<R`D=F%L*2!["B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R1V86Q=*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN(BDL("1V86PI*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N
M86UE)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;64G72`]("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==(#T@)VAO<F1E7W9F<R<["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V97(@=7-I;F<@
M=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9$
M0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1E<G)O<B`]("1T:&ES+3Y?9&(["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B(#T@9F%L<V4["B`@("`@("`@("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3970@
M1$(@<&]R=&%B:6QI='D@;W!T:6]N<RX*("`@("`@("`@("`@<W=I=&-H("@D
M=&AI<RT^7V1B+3YP:'!T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L
M)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R
M=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)4
M04))3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG
M+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%
M4E)/4E,I.PH@("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R
M;VT@=&AE(%-13"!S97)V97(@86YD(&-L96%N('5P('1H92!C;VYN96-T:6]N
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?9&(I('L*("`@("`@("`@("`@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I
M.PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@9F%L<V4["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@9G5L;"!F:6QE;F%M92!O
M;B!T:&4@;F%T:79E(&9I;&5S>7-T96TL(&9R;VT@82!61E,*("`@("`J('!A
M=&@@86YD(&YA;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(%9&4R!F:6QE
M('!A=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@5D93(&9I
M;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L
M;"!N871I=F4@9FEL96YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971.
M871I=F50871H*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H(65M
M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M92`]("<O)R`N("1N86UE
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!A=&@I*2!["B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]M92==*2`F)@H@
M("`@("`@("`@("`@("`@<')E9U]M871C:"@G?%Y^+S\H+BHI)'PG+"`D<&%T
M:"P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D<&%T:"`]("1T:&ES
M+3Y?<&%R86US6R=H;VUE)UT@("X@)R\G("X@)&UA=&-H97-;,5T["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<F%M<ULG
M=F9S<F]O="==("X@)R\G("X@)'!A=&@@+B`D;F%M93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7-;)W9F<W)O
M;W0G72`N("1N86UE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!A(&9U;&P@4U%,(&9I;&5N86UE(&]N('1H92!N871I=F4@9FEL
M97-Y<W1E;2P@9G)O;2!A(%9&4PH@("`@("H@<&%T:"!A;F0@;F%M92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@5D93(&9I;&4@<&%T:"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!61E,@9FEL96YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F=6QL(&YA=&EV92!F:6QE;F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%-13$YA=&EV95!A=&@H)'!A
M=&@L("1N86UE*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%T:"DI('L*
M("`@("`@("`@("`@<F5T=7)N("1N86UE.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1P871H("X@)R\G("X@)&YA;64["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O5D93+V9I;&4N<&AP````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#4U-#`Q`#$P-3$U-#,Q,#8P`#`Q-S(T-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!A('-T86YD87)D(&9I
M;&5S>7-T96TN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@
M("`G=F9S<F]O="<@(%1H92!R;V]T('!A=&@\+W!R93X*("H*("H@3F]T93H@
M5&AE('5S97(@=&AA="!Y;W5R('=E8G-E<G9E<B!R=6YS(&%S("AC;VUM;VYL
M>2`G;F]B;V1Y)RP*("H@)V%P86-H92<L(&]R("=W=W<M9&%T82<I($U54U0@
M:&%V92!R96%D+W=R:71E('!E<FUI<W-I;VX@=&\@=&AE"B`J(&1I<F5C=&]R
M>2!Y;W4@<W!E8VEF>2!A<R!T:&4@)W9F<W)O;W0G+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP+'8@,2XV,RXT+C(Q(#(P,#8O
M,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H"B`J
M($!P86-K86=E(%9&4PH@*B\*8VQA<W,@5D937V9I;&4@97AT96YD<R!61E,@
M>PH*("`@("\J*@H@("`@("H@3&ES="!O9B!P97)M:7-S:6]N<R!A;F0@:68@
M=&AE>2!C86X@8F4@8VAA;F=E9"!I;B!T:&ES(%9&4PH@("`@("H@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W!E<FUI<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A
M>2@G<F5A9"<@/3X@=')U92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@
M/3X@=')U92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@
M=')U92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92DL"B`@
M("`@("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@)W=R:71E
M)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92D*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($9I;&5S>7-T96T@8F%S960@5D93
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!61E-?9FEL92@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!P87)E;G0Z.E9&4R@D<&%R86US*3L*"B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==*2D@>PH@("`@
M("`@("`@("!I9B`H<W5B<W1R*"1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UTL
M("TQ*2`]/2`G+R<@?'P*("`@("`@("`@("`@("`@('-U8G-T<B@D=&AI<RT^
M7W!A<F%M<ULG=F9S<F]O="==+"`M,2D@/3T@)UQ<)RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72`]('-U8G-T<B@D=&AI
M<RT^7W!A<F%M<ULG=F9S<F]O="==+"`P+"!S=')L96XH)'1H:7,M/E]P87)A
M;7-;)W9F<W)O;W0G72D@+2`Q*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@9FEL97-I>F4@
M9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@5&AE(&9I;&4@<VEZ92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@
M("`@)'-I>F4@/2!`9FEL97-I>F4H)'1H:7,M/E]G971.871I=F50871H*"1P
M871H+"`D;F%M92DI.PH@("`@("`@(&EF("@D<VEZ92`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB*2P@
M)'!A=&@L("1N86UE*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<VEZ
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&$@9FEL92!F<F]M
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96%D*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D
M9FEL92`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I.PH@
M("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S
M)RDI('L*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D
M9FEL92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@0&9O
M<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@("`@("`@:68@*"$D9G`I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D9FEL97-I>F4@/2!F:6QE<VEZ92@D9FEL92D["B`@("`@("`@("`@
M(&EF("@D9FEL97-I>F4@/3T@,"D@>PH@("`@("`@("`@("`@("`@)&1A=&$@
M/2`G)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D
M871A(#T@9G)E860H)&9P+"`D9FEL97-I>F4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@
M<&%R="!O9B!A(&9I;&4@9G)O;2!T:&4@5D93+B!087)T:6-U;&%R;'D@=7-E
M9G5L('=H96X*("`@("`J(')E861I;F<@;&%R9V4@9FEL97,@=VAI8V@@=V]U
M;&0@97AC965D('1H92!02%`@;65M;W)Y(&QI;6ET<R!I9B!T:&5Y"B`@("`@
M*B!W97)E('-T;W)E9"!I;B!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%T:"`@("`@
M("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D;F%M92`@("`@("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D;V9F<V5T("`@("!4:&4@;V9F<V5T(&]F
M('1H92!P87)T+B`H5&AE(&YE=R!O9F9S970@=VEL;`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8F4@<W1O<F5D(&EN(&AE<F4I+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&QE;F=T:"`@("`@5&AE(&QE;F=T:"!O9B!T
M:&4@<&%R="X@268@=&AE(&QE;F=T:"`]("TQ+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE('=H;VQE('!A<G0@869T97(@=&AE(&]F
M9G-E="!I<R!R971R:65V960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!)9B!M;W)E(&)Y=&5S(&%R92!G:79E;B!A<R!E>&ES=',@869T
M97(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G:79E
M;B!O9F9S970N($]N;'D@=&AE(&%V86EL86)L92!B>71E<R!A<F4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E860N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<F5M86EN:6YG("!4:&4@8GET97,@=&AA="!A<F4@;&5F
M="P@869T97(@=&AE('!A<G0@=&AA=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:7,@<F5T<FEE=F5D+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E861">71E4F%N9V4H)'!A=&@L("1N86UE+"`F)&]F9G-E="P@)&QE;F=T
M:"`]("TQ+"`F)')E;6%I;FEN9RD*("`@('L*("`@("`@("!I9B`H)&]F9G-E
M="`\(#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&
M4R!F:6QE+B(I+"`D;V9F<V5T*2D["B`@("`@("`@?0H*("`@("`@("`O+R!#
M86QC=6QA=&4@:&]W(&UA;GD@8GET97,@35535"!B92!R96%D+"!S;R!T:&4@
M<F5M86EN9VEN9PH@("`@("`@("\O(&)Y=&5S(&%N9"!T:&4@;F5W(&]F9G-E
M="!C86X@8F4@8V%L8W5L871E9"!C;W)R96-T;'DN"B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@
M("`D<VEZ92`](&9I;&5S:7IE("@D9FEL92D["B`@("`@("`@:68@*"1L96YG
M=&@@/3T@+3$@?'P@*"@D;&5N9W1H("L@)&]F9G-E="D@/B`D<VEZ92DI('L*
M("`@("`@("`@("`@)&QE;F=T:"`]("1S:7IE("T@)&]F9G-E=#L*("`@("`@
M("!]"B`@("`@("`@:68@*"1R96UA:6YI;F<@/"`P*2!["B`@("`@("`@("`@
M("1R96UA:6YI;F<@/2`P.PH@("`@("`@('T*"B`@("`@("`@)&9P(#T@0&9O
M<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB*2D["B`@("`@("`@?0H@("`@("`@(&9S965K*"1F<"P@
M)&]F9G-E="D["B`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L("1L96YG=&@I
M.PH@("`@("`@("1O9F9S970@/2!F=&5L;"@D9G`I.PH@("`@("`@("1R96UA
M:6YI;F<@/2`D<VEZ92`M("1O9F9S970["@H@("`@("`@(&9C;&]S92@D9G`I
M.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3=&]R92!A(&9I;&4@:6X@=&AE(%9&4RP@=VET:"!T:&4@9&%T82!C;W!I
M960@9G)O;2!A('1E;7!O<F%R>0H@("`@("H@9FEL92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O
M<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I
M;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R87)Y(&9I;&4@8V]N=&%I;FEN
M9R!T:&4@9&%T82!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T;W)E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E
M871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!W<FET92@D<&%T:"P@)&YA;64L("1T;7!&:6QE+"`D875T;V-R96%T
M92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%`:7-?9&ER*"1T:&ES+3Y?
M9V5T3F%T:79E4&%T:"@D<&%T:"DI*2!["B`@("`@("`@("`@(&EF("@D875T
M;V-R96%T92D@>PH@("`@("`@("`@("`@("`@)')E<R`]("1T:&ES+3YA=71O
M8W)E871E4&%T:"@D<&%T:"D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1
M=6]T85=R:71E*"=F:6QE)RP@)'1M<$9I;&4I.PH@("`@("`@(&EF("AI<U]A
M*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97,["B`@("`@("`@?0H*("`@("`@("`O+R!3:6YC92!W92!A;')E861Y(&AA
M=F4@=&AE(&1A=&$@:6X@82!F:6QE+"!D;VXG="!R96%D(&ET"B`@("`@("`@
M+R\@:6YT;R!02%`G<R!M96UO<GD@870@86QL("T@:G5S="!C;W!Y*"D@:70@
M=&\@=&AE(&YE=PH@("`@("`@("\O(&QO8V%T:6]N+B!792!L96%V92!I="!T
M;R!T:&4@8V%L;&5R('1O(&-L96%N('5P('1H90H@("`@("`@("\O('1E;7!O
M<F%R>2!F:6QE+"!S;R!W92!D;VXG="!U<V4@<F5N86UE*"DN"B`@("`@("`@
M:68@*$!C;W!Y*"1T;7!&:6QE+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A
M=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D
M*2XB*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@
M82!F:6QE(&EN('1H92!D871A8F%S92!A;F0@=&AE(&9I;&4@<WES=&5M+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O
M('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1P871H
M+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^
M7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E
M9U]M871C:"@G?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L("1D
M97-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")#86YN;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN
M('-O=7)C92XB*2D["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K(#T@
M)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&9A;'-E*3L*("`@("`@("!F;W)E
M86-H("@D9FEL94-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D
M9FEL95LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@;6]V92!61E,@9FEL
M92XB*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A
M0')E;F%M92@D;W)I9RP@)'1H:7,M/E]G971.871I=F50871H*"1D97-T+"`D
M;F%M92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]P
M:65S(&$@9FEL92!T:')O=6=H('1H92!B86-K96YD+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F
M:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N
M86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!D
M97-T:6YA=&EO;B!O9B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W!Y*"1P871H
M+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^
M7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E
M9U]M871C:"@G?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L("1D
M97-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO
M;B!A<F4@=&AE('-A;64N(BDI.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5#
M:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T+"!F86QS92D["B`@("`@
M("`@9F]R96%C:"`H)&9I;&5#:&5C:R!A<R`D9FEL92D@>PH@("`@("`@("`@
M("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H(4!C;W!Y*"1O<FEG+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&1E
M<W0L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(BDI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3=&]R92!A(&9I;&4@:6X@=&AE(%9&4R!F<F]M(')A=R!D871A+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T
M:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C
M<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H
M+"`D;F%M92P@)&1A=&$L("1A=71O8W)E871E(#T@=')U92D*("`@('L*("`@
M("`@("!I9B`H(4!I<U]D:7(H)'1H:7,M/E]G971.871I=F50871H*"1P871H
M*2DI('L*("`@("`@("`@("`@:68@*"1A=71O8W)E871E*2!["B`@("`@("`@
M("`@("`@("`D<F5S(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!4<F5A="!A;B!A='1E;7!T('1O('=R:71E(&%N(&5M<'1Y(&9I
M;&4@87,@82!T;W5C:"@I(&-A;&PL"B`@("`@("`@+R\@<VEN8V4@;W1H97)W
M:7-E('1H92!F:6QE('=I;&P@;F]T(&)E(&-R96%T960@870@86QL+@H@("`@
M("`@(&EF("@A<W1R;&5N*"1D871A*2D@>PH@("`@("`@("`@("!I9B`H0'1O
M=6-H*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(I*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE
M8VM1=6]T85=R:71E*"=S=')I;F<G+"`D9&%T82D["B`@("`@("`@:68@*&ES
M7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<SL*("`@("`@("!]"@H@("`@("`@("\O($]T:&5R=VES92!W92!G;R!A
M:&5A9"!A;F0@=')Y('1O('=R:71E(&]U="!T:&4@9FEL92X*("`@("`@("`D
M9G`@/2!`9F]P96XH)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M
M92DL("=W)RD["B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@9F]R('=R:71I;F<N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`
M9G=R:71E*"1F<"P@)&1A=&$I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5L971E(&$@9FEL92!F<F]M('1H92!61E,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949I;&4H
M)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7V-H
M96-K475O=&%$96QE=&4H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`=6YL:6YK*"1T:&ES+3Y?
M9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R(&9R;VT@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@
M("!4:&4@<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&9O;&1E<FYA;64@=&\@
M=7-E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E8W5R<VEV92`@1F]R8V4@
M82!R96-U<G-I=F4@9&5L971E/PH@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1F]L9&5R*"1P
M871H+"`D;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@D<F5C=7)S:79E*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^96UP='E&;VQD97(H)'!A=&@@+B`G+R<@+B`D;F%M92D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&QI<W0@/2`D=&AI<RT^;&ES=$9O
M;&1E<B@D<&%T:"`N("<O)R`N("1N86UE*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D;&ES=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H8V]U
M;G0H)&QI<W0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P871H("X@)R\G("X@)&YA
M;64I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%`
M<FUD:7(H)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T
M97,@82!F;VQD97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F
M<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9O;&1E<FYA
M;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T:"P@)&YA
M;64I"B`@("!["B`@("`@("`@:68@*"%`;6MD:7(H)'1H:7,M/E]G971.871I
M=F50871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H96-K(&EF(&$@9VEV96X@<&%T:&YA;64@
M:7,@82!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE('!A=&@@=&\@=&AE(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!F:6QE+V9O;&1E<B!N86UE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!I="!I<R!A(&9O;&1E<BP@9F%L
M<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T9O;&1E<B@D
M<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N($!I<U]D:7(H)'1H
M:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VAA;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@:71E;2!I
M;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M("`@("`@("!4:&4@<&%T:"!O9B!D:7)E8W1O<GD@;V8@=&AE(&ET96TN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&YA;64@;V8@
M=&AE(&ET96TN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@
M5&AE(&]C=&%L('9A;'5E(&]F('1H92!N97<@<&5R;6ES<VEO;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C:&%N9V5097)M:7-S:6]N<R@D<&%T:"P@)&YA;64L("1P97)M:7-S
M:6]N*0H@("`@>PH@("`@("`@(&EF("@A0&-H;6]D*"1T:&ES+3Y?9V5T3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I+"`D<&5R;6ES<VEO;BDI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(I
M+"`D<&%T:"P@)&YA;64I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@;&ES="!O9B!T
M:&4@8V]N=&5N=',@;V8@82!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y
M+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("!3=')I;F<O:&%S
M:"!T;R!F:6QT97(@9FEL92]D:7)N86UE(&]N+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&1O=&9I;&5S("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&1I<F]N;'D@("!3:&]W(&]N;'D@9&ER96-T;W)I97,_"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@1FEL92!L:7-T(&]N('-U8V-E
M<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]L:7-T1F]L9&5R*"1P871H+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9I;&5S
M(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)O;FQY(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@("`@
M("`D<&%T:"`](&ES<V5T*"1P871H*2`_("1T:&ES+3Y?9V5T3F%T:79E4&%T
M:"@D<&%T:"D@.B`D=&AI<RT^7V=E=$YA=&EV95!A=&@H*3L*"B`@("`@("`@
M:68@*"%`:7-?9&ER*"1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*").;W0@82!D:7)E8W1O<GDB*2D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(4!C:&1I<B@D<&%T:"DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+B(I*3L*("`@("`@("!]"@H@("`@("`@("1H86YD;&4@
M/2!O<&5N9&ER*"1P871H*3L*("`@("`@("!W:&EL92`H*"1E;G1R>2`](')E
M861D:7(H)&AA;F1L92DI("$]/2!F86QS92D@>PH@("`@("`@("`@("`O+R!&
M:6QT97(@;W5T("<N)R!A;F0@)RXN)R!E;G1R:65S+@H@("`@("`@("`@("!I
M9B`H)&5N=')Y(#T]("<N)R!\?"`D96YT<GD@/3T@)RXN)RD@>PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O($9I;'1E<B!O=70@9&]T9FEL97,@:68@=&AE>2!A<F5N)W0@=V%N=&5D
M+@H@("`@("`@("`@("!I9B`H(21D;W1F:6QE<R`F)B!S=6)S='(H)&5N=')Y
M+"`P+"`Q*2`]/2`G+B<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&:6QE(&YA;64*("`@("`@
M("`@("`@)&9I;&5;)VYA;64G72`]("1E;G1R>3L*"B`@("`@("`@("`@("\O
M(%5N:7@@<W1Y;&4@9FEL92!P97)M:7-S:6]N<PH@("`@("`@("`@("`D9FEL
M95LG<&5R;7,G72`]("1T:&ES+3Y?9V5T56YI>%!E<FUS*&9I;&5P97)M<R@D
M96YT<GDI*3L*"B`@("`@("`@("`@("\O($]W;F5R"B`@("`@("`@("`@("1F
M:6QE6R=O=VYE<B==(#T@9FEL96]W;F5R*"1E;G1R>2D["B`@("`@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)W!O<VEX7V=E='!W=6ED)RDI('L*("`@
M("`@("`@("`@("`@("1O=VYE<B`]('!O<VEX7V=E='!W=6ED*"1F:6QE6R=O
M=VYE<B==*3L*("`@("`@("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)&]W
M;F5R6R=N86UE)UT["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($=R
M;W5P"B`@("`@("`@("`@("1F:6QE6R=G<F]U<"==(#T@9FEL96=R;W5P*"1E
M;G1R>2D["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)W!O<VEX
M7V=E=&=R9VED)RDI('L*("`@("`@("`@("`@("`@("1G<F]U<"`]('!O<VEX
M7V=E=&=R9VED*"1F:6QE6R=G<F]U<"==*3L*("`@("`@("`@("`@("`@("1F
M:6QE6R=G<F]U<"==(#T@)&=R;W5P6R=N86UE)UT["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O(%-I>F4*("`@("`@("`@("`@)&9I;&5;)W-I>F4G
M72`](&9I;&5S:7IE*"1E;G1R>2D["@H@("`@("`@("`@("`O+R!$871E"B`@
M("`@("`@("`@("1F:6QE6R=D871E)UT@/2!F:6QE;71I;64H)&5N=')Y*3L*
M"B`@("`@("`@("`@("\O(%1Y<&4*("`@("`@("`@("`@:68@*$!I<U]D:7(H
M)&5N=')Y*2`F)B`A:7-?;&EN:R@D96YT<GDI*2!["B`@("`@("`@("`@("`@
M("`D9FEL95LG<&5R;7,G72`]("=D)R`N("1F:6QE6R=P97)M<R==.PH@("`@
M("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@
M("`@("`@("`D9FEL95LG<VEZ92==(#T@+3$["B`@("`@("`@("`@('T@96QS
M96EF("AI<U]L:6YK*"1E;G1R>2DI('L*("`@("`@("`@("`@("`@("1F:6QE
M6R=P97)M<R==(#T@)VPG("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@
M("`@("`D9FEL95LG='EP92==(#T@)RHJ<WEM)SL*("`@("`@("`@("`@("`@
M("1F:6QE6R=L:6YK)UT@/2!R96%D;&EN:R@D96YT<GDI.PH@("`@("`@("`@
M("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@
M("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL95LG;&EN:R==*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]D:7(H)&9I;&5;)VQI;FLG72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@/2`G
M*BID:7(G.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]L:6YK
M*"1F:6QE6R=L:6YK)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=L:6YK='EP92==(#T@)RHJ<WEM)SL*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H:7-?9FEL92@D9FEL95LG;&EN:R==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D97AT(#T@97AP;&]D92@G+B<L("1F:6QE6R=L
M:6YK)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(2AC;W5N="@D
M97AT*2`]/2`Q('Q\("@D97AT6S!=(#T]/2`G)R`F)B!C;W5N="@D97AT*2`]
M/2`R*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=L
M:6YK='EP92==(#T@5D93.CIS=')T;VQO=V5R*"1E>'1;8V]U;G0H)&5X="D@
M+2`Q72D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE6R=L:6YK='EP92==(#T@)RHJ8G)O:V5N)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*&ES7V9I;&4H
M)&5N=')Y*2D@>PH@("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G
M+2<@+B`D9FEL95LG<&5R;7,G73L*("`@("`@("`@("`@("`@("1E>'0@/2!E
M>'!L;V1E*"<N)RP@)&5N=')Y*3L*"B`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)&5X="D@/3T@,2!\?"`H<W5B<W1R*"1F:6QE6R=N86UE)UTL(#`L(#$I
M(#T]/2`G+B<@)B8@8V]U;G0H)&5X="D@/3T@,BDI('L*("`@("`@("`@("`@
M("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E
M)UT@/2!61E,Z.G-T<G1O;&]W97(H)&5X=%MC;W5N="@D97AT*2`M(#%=*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@
M("`@("`@(&EF("@H9FEL97!E<FUS*"1E;G1R>2D@)B`P>$,P,#`I(#T](#!X
M0S`P,"D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=P97)M<R==(#T@
M)W,G("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H*&9I;&5P97)M<R@D96YT<GDI("8@,'@V,#`P*2`]/2`P>#8P,#`I('L*
M("`@("`@("`@("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]("=B)R`N("1F
M:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"AF:6QE
M<&5R;7,H)&5N=')Y*2`F(#!X,C`P,"D@/3T@,'@R,#`P*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G8R<@+B`D9FEL95LG<&5R
M;7,G73L*("`@("`@("`@("`@("`@('T@96QS96EF("@H9FEL97!E<FUS*"1E
M;G1R>2D@)B`P>#$P,#`I(#T](#!X,3`P,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=P97)M<R==(#T@)W`G("X@)&9I;&5;)W!E<FUS)UT["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=P97)M<R==(#T@)S\G("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($9I;'1E
M<FEN9RX*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9FEL=&5R36%T8V@H)&9I
M;'1E<BP@)&9I;&5;)VYA;64G72DI('L*("`@("`@("`@("`@("`@('5N<V5T
M*"1F:6QE*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D9&ER;VYL>2`F)B`D9FEL95LG='EP92==
M("$]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D[
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&9I;&5S6R1F:6QE6R=N86UE)UU=(#T@)&9I;&4["B`@("`@
M("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9FEL97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R
M=&5D(&QI<W0@;V8@9F]L9&5R<R!I;B!S<&5C:69I960@9&ER96-T;W)Y+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@
M<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O(&=E="!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@
M("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@("`@2&%S:"!O9B!I=&5M
M<R!T;R!F:6QT97(@8F%S960@;VX@9F]L9&5R;&ES="X*("`@("`J($!P87)A
M;2!B;V]L96%N("1D;W1F;VQD97)S("!);F-L=61E(&1O=&9O;&1E<G,_"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1F]L9&5R(&QI<W0@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD97)S*"1P871H(#T@)R<L("1F:6QT
M97(@/2!N=6QL+"`D9&]T9F]L9&5R<R`]('1R=64I"B`@("!["B`@("`@("`@
M)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D
M8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O
M;FX["B`@("`@("`@?0H*("`@("`@("`D9F]L9&5R<R`](&%R<F%Y*"D["B`@
M("`@("`@)&9O;&1E<G-;9&ER;F%M92@D<&%T:"E=(#T@87)R87DH)W9A;"<@
M/3X@9&ER;F%M92@D<&%T:"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V%B8G)E=B<@/3X@)RXN)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^("<N+B<I
M.PH*("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P
M871H+"!N=6QL+"`D9&]T9F]L9&5R<RP@=')U92D["B`@("`@("`@:68@*&ES
M7V$H)&9O;&1E<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1F;VQD97),:7-T.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)&9O;&1E<DQI<W0@87,@)&YA;64@/3X@)&9I;&5S*2!["B`@("`@("`@
M("`@("1F;VQD97)S6R1N86UE72`](&%R<F%Y*"=V86PG(#T^("1P871H("X@
M)R\G("X@)&9I;&5S6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=A8F)R978G(#T^("1F:6QE<ULG;F%M92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^("1P
M871H("X@)R\G("X@)&9I;&5S6R=N86UE)UTI.PH@("`@("`@('T*"B`@("`@
M("`@:W-O<G0H)&9O;&1E<G,I.PH*("`@("`@("!R971U<FX@)&9O;&1E<G,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@56YI>"!S='EL92!P97)M
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<&5R;7,@(%1H92!P97)M:7-S:6]N<R!T;R!S
M970N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%5N:7@@<W1Y;&4@
M<&5R;7,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9715;FEX4&5R;7,H)'!E
M<FUS*0H@("`@>PH@("`@("`@("\O($1E=&5R;6EN92!P97)M:7-S:6]N<PH@
M("`@("`@("1O=VYE<ELG<F5A9"==("`@(#T@*"1P97)M<R`F(#`P-#`P*2`_
M("=R)R`Z("<M)SL*("`@("`@("`D;W=N97);)W=R:71E)UT@("`]("@D<&5R
M;7,@)B`P,#(P,"D@/R`G=R<@.B`G+2<["B`@("`@("`@)&]W;F5R6R=E>&5C
M=71E)UT@/2`H)'!E<FUS("8@,#`Q,#`I(#\@)W@G(#H@)RTG.PH@("`@("`@
M("1G<F]U<%LG<F5A9"==("`@(#T@*"1P97)M<R`F(#`P,#0P*2`_("=R)R`Z
M("<M)SL*("`@("`@("`D9W)O=7!;)W=R:71E)UT@("`]("@D<&5R;7,@)B`P
M,#`R,"D@/R`G=R<@.B`G+2<["B`@("`@("`@)&=R;W5P6R=E>&5C=71E)UT@
M/2`H)'!E<FUS("8@,#`P,3`I(#\@)W@G(#H@)RTG.PH@("`@("`@("1W;W)L
M9%LG<F5A9"==("`@(#T@*"1P97)M<R`F(#`P,#`T*2`_("=R)R`Z("<M)SL*
M("`@("`@("`D=V]R;&1;)W=R:71E)UT@("`]("@D<&5R;7,@)B`P,#`P,BD@
M/R`G=R<@.B`G+2<["B`@("`@("`@)'=O<FQD6R=E>&5C=71E)UT@/2`H)'!E
M<FUS("8@,#`P,#$I(#\@)W@G(#H@)RTG.PH*("`@("`@("`O+R!!9&IU<W0@
M9F]R(%-5240L(%-'240@86YD('-T:6-K>2!B:70*("`@("`@("!I9B`H)'!E
M<FUS("8@,'@X,#`I('L*("`@("`@("`@("`@)&]W;F5R6R=E>&5C=71E)UT@
M/2`H)&]W;F5R6R=E>&5C=71E)UT@/3T@)W@G*2`_("=S)R`Z("=3)SL*("`@
M("`@("!]"B`@("`@("`@:68@*"1P97)M<R`F(#!X-#`P*2!["B`@("`@("`@
M("`@("1G<F]U<%LG97AE8W5T92==(#T@*"1G<F]U<%LG97AE8W5T92==(#T]
M("=X)RD@/R`G<R<@.B`G4R<["B`@("`@("`@?0H@("`@("`@(&EF("@D<&5R
M;7,@)B`P>#(P,"D@>PH@("`@("`@("`@("`D=V]R;&1;)V5X96-U=&4G72`]
M("@D=V]R;&1;)V5X96-U=&4G72`]/2`G>"<I(#\@)W0G(#H@)U0G.PH@("`@
M("`@('T*"B`@("`@("`@)'5N:7A097)M<R`]("1O=VYE<ELG<F5A9"==("X@
M)&]W;F5R6R=W<FET92==("X@)&]W;F5R6R=E>&5C=71E)UT@+@H@("`@("`@
M("`@("`@("`@("`@("`D9W)O=7!;)W)E860G72`N("1G<F]U<%LG=W)I=&4G
M72`N("1G<F]U<%LG97AE8W5T92==("X*("`@("`@("`@("`@("`@("`@("`@
M)'=O<FQD6R=R96%D)UT@+B`D=V]R;&1;)W=R:71E)UT@+B`D=V]R;&1;)V5X
M96-U=&4G73L*"B`@("`@("`@<F5T=7)N("1U;FEX4&5R;7,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296YA;64@82!F:6QE(&]R(&9O;&1E<B!I;B!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H
M92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I;&5N86UE+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H
M+"`D;F5W;F%M92D*("`@('L*("`@("`@("!I9B`H(4!I<U]D:7(H)'1H:7,M
M/E]G971.871I=F50871H*"1N97=P871H*2DI('L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<R`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D;F5W<&%T:"DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!R96YA
M;64H)'1H:7,M/E]G971.871I=F50871H*"1O;&1P871H+"`D;VQD;F%M92DL
M"B`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D
M;F5W<&%T:"P@)&YE=VYA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N(BDL("1O;&1P871H+"`D;VQD;F%M92DI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@82!F=6QL(&9I;&5N86UE(&]N('1H92!N871I=F4@9FEL97-Y
M<W1E;2P@9G)O;2!A(%9&4PH@("`@("H@<&%T:"!A;F0@;F%M92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@5D93(&9I;&4@<&%T:"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!61E,@9FEL96YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!F=6QL(&YA=&EV92!F:6QE;F%M92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$YA=&EV95!A=&@H)'!A=&@@/2`G
M)RP@)&YA;64@/2`G)RD*("`@('L*("`@("`@("`D;F%M92`](&)A<V5N86UE
M*"1N86UE*3L*("`@("`@("!I9B`H(65M<'1Y*"1N86UE*2D@>PH@("`@("`@
M("`@("`D;F%M92`]('-T<E]R97!L86-E*"<N+B<L("<G+"`D;F%M92D["B`@
M("`@("`@("`@(&EF("AS=6)S='(H)&YA;64L(#`L(#$I("$]("<O)RD@>PH@
M("`@("`@("`@("`@("`@)&YA;64@/2`G+R<@+B`D;F%M93L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D<&%T:"DI('L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=H;VUE)UTI
M("8F"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"=\7GXO/R@N*BDD?"<L
M("1P871H+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1P871H(#T@
M)'1H:7,M/E]P87)A;7-;)VAO;64G72`N("<O)R`N("1M871C:&5S6S%=.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&%T:"`]('-T<E]R97!L86-E
M*"<N+B<L("<G+"`D<&%T:"D["B`@("`@("`@("`@(&EF("AS=6)S='(H)'!A
M=&@L(#`L(#$I(#T]("<O)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%R86US6R=V9G-R;V]T)UT@+B`D<&%T:"`N("1N86UE.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%R86US6R=V9G-R;V]T)UT@+B`G+R<@+B`D<&%T:"`N("1N86UE.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UT@+B`D;F%M93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3='5B('1O(&-H96-K(&EF('=E
M(&AA=F4@82!V86QI9"!C;VYN96-T:6]N+B!-86ME<R!S=7)E('1H870*("`@
M("`J('1H92!V9G-R;V]T(&ES(')E861A8FQE+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@:68@=F9S<F]O="!I<R!R96%D86)L92P@4$5!4E]%<G)O<B!I9B!I="!I
M<VXG="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@
M("`@("`@(&EF("@H0&ES7V1I<B@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==
M*2`F)@H@("`@("`@("`@("`@0&ES7W)E861A8FQE*"1T:&ES+3Y?<&%R86US
M6R=V9G-R;V]T)UTI*2!\?`H@("`@("`@("`@("!`;6MD:7(H)'1H:7,M/E]P
M87)A;7-;)W9F<W)O;W0G72DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(I*3L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&
M4R],:7-T271E;2YP:'``````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#4S-``Q,#4Q-30S,3`V,``P,C`P-C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J($%N
M(&ET96T@<F5T=7)N960@9G)O;2!A(&9O;&1E<B!L:7-T+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]61E,O5D93+TQI<W1)=&5M+G!H<"QV(#$N,3$N,3`N
M-R`R,#`V+S`U+S,Q(#`T.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!*;VX@5V]O9"`\:F]N0&IE;&QY8F]B+F-O+G5K
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%=O;V0@/&IO;D!J
M96QL>6)O8BYC;RYU:SX*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?
M3&ES=$ET96T@>PH*("`@("\J*@H@("`@("H@5D93('!A=&@*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P871H.PH*("`@
M("\J*@H@("`@("H@1FEL96YA;64*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]N86UE.PH*("`@("\J*@H@("`@("H@1FEL
M92!P97)M:7-S:6]N<R`H*FYI>"!F;W)M870Z(&1R=WAR=WAR=W@I"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&5R;7,[
M"@H@("`@+RHJ"B`@("`@*B!/=VYE<B!U<V5R"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;W=N97(["@H@("`@+RHJ"B`@
M("`@*B!/=VYE<B!G<F]U<`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V=R;W5P.PH*("`@("\J*@H@("`@("H@4VEZ92X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S
M:7IE.PH*("`@("\J*@H@("`@("H@3&%S="!M;V1I9FEE9"!D871E+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1A=&4[
M"@H@("`@+RHJ"B`@("`@*B!4>7!E"B`@("`@*B`@("XJ("`@("`@+2T@($9I
M;&4@97AT96YS:6]N"B`@("`@*B`@("HJ;F]N92`@+2T@(%5N<F5C;V=N:7IE
M9"!T>7!E"B`@("`@*B`@("HJ<WEM("`@+2T@(%-Y;6QI;FL*("`@("`J("`@
M*BID:7(@("`M+2`@1&ER96-T;W)Y"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?='EP93L*"B`@("`O*BH*("`@("`J(%1Y
M<&4@;V8@=&%R9V5T(&EF('1Y<&4@:7,@)RHJ<WEM)RX*("`@("`J($Y"+B!.
M;W0@86QL(&)A8VME;F1S(&%R92!C87!A8FQE(&]F(&1I<W1I;F=U:7-H:6YG
M(&%L;"!O9B!T:&5S92X*("`@("`J("`@+BH@("`@("`@("TM("!&:6QE(&5X
M=&5N<VEO;@H@("`@("H@("`J*FYO;F4@("`@+2T@(%5N<F5C;V=N:7IE9"!T
M>7!E"B`@("`@*B`@("HJ<WEM("`@("`M+2`@4WEM;&EN:R!T;R!A('-Y;6QI
M;FL*("`@("`J("`@*BID:7(@("`@("TM("!$:7)E8W1O<GD*("`@("`J("`@
M*BIB<F]K96X@("TM("!487)G970@;F]T(&9O=6YD("T@8G)O:V5N(&QI;FL*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]L
M:6YK='EP93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@
M("`@("H@4F5Q=6ER97,@=&AE('!A=&@@=&\@=&AE(&9I;&4L(&%N9"!I="=S
M(&%R<F%Y(&]F('!R;W!E<G1I97,L"B`@("`@*B!R971U<FYE9"!F<F]M(&$@
M<W1A;F1A<F0@5D93.CIL:7-T1F]L9&5R*"D@8V%L;"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@5&AE('!A=&@@=&\@=&AE(&9I
M;&4N"B`@("`@*B!`<&%R86T@87)R87D@)&9I;&5!<G)A>2`@06X@87)R87D@
M;V8@9FEL92!P<F]P97)T:65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E-?
M3&ES=$ET96TH)'!A=&@L("1F:6QE07)R87DI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]P871H(#T@)'!A=&@@+B`G+R<@+B`D9FEL94%R<F%Y6R=N86UE)UT[
M"B`@("`@("`@)'1H:7,M/E]N86UE(#T@)&9I;&5!<G)A>5LG;F%M92==.PH@
M("`@("`@("1T:&ES+3Y?9&ER;F%M92`]("1P871H.PH@("`@("`@("1T:&ES
M+3Y?<&5R;7,@/2`D9FEL94%R<F%Y6R=P97)M<R==.PH@("`@("`@("1T:&ES
M+3Y?;W=N97(@/2`D9FEL94%R<F%Y6R=O=VYE<B==.PH@("`@("`@("1T:&ES
M+3Y?9W)O=7`@/2`D9FEL94%R<F%Y6R=G<F]U<"==.PH@("`@("`@("1T:&ES
M+3Y?<VEZ92`]("1F:6QE07)R87E;)W-I>F4G73L*("`@("`@("`D=&AI<RT^
M7V1A=&4@/2`D9FEL94%R<F%Y6R=D871E)UT["B`@("`@("`@)'1H:7,M/E]T
M>7!E(#T@)&9I;&5!<G)A>5LG='EP92==.PH@("`@("`@("1T:&ES+3Y?;&EN
M:W1Y<&4@/2`D9FEL94%R<F%Y6R=L:6YK='EP92==.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+T)L;V-K+P``````````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,38R,#<`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O0FQO8VLO=&EM92YP:'``````
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#0W`#$P
M-3$U-#,Q,#8P`#`Q-S8U-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*)&)L;V-K7VYA;64@/2!?*")#=7)R96YT
M(%1I;64B*3L*"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C:R]T:6UE
M+G!H<"QV(#$N,38@,C`P-"\Q,2\R,R`Q-3HQ-SHU,R!C:'5C:R!%>'`@)`H@
M*@H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO
M8VM?2&]R9&5?=&EM92!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@
M)%]A<'`@/2`G:&]R9&4G.PH*("`@(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D<&%R86US(#T@87)R87DH)W1I;64G(#T^(&%R
M<F%Y*"=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E1I;64@9F]R
M;6%T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1E9F%U;'0G(#T^("<R-"UH;W5R)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=65S)R`]
M/B!A<G)A>2@G,C0M:&]U<B<@/3X@7R@B,C0@2&]U<B!&;W)M870B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G,3(M:&]U<B<@/3X@7R@B,3(@2&]U<B!&;W)M
M870B*2DI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G
M;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("`@5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L
M92@I"B`@("!["B`@("`@("`@<F5T=7)N(%\H(D-U<G)E;G0@5&EM92(I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@=&AI
M<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C
M;VYT96YT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W1I;64G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1I;64G72`]("<R-"UH;W5R
M)SL*("`@("`@("!]"@H@("`@("`@("\O(%-E="!T:&4@=&EM97IO;F4@=F%R
M:6%B;&4L(&EF(&%V86EL86)L92X*("`@("`@("!.3%,Z.G-E=%1I;65:;VYE
M*"D["@H@("`@("`@("1H=&UL(#T@)SQT86)L92!W:61T:#TB,3`P)2(@:&5I
M9VAT/2(Q,#`E(CX\='(^/'1D('-T>6QE/2)F;VYT+69A;6EL>3IV97)D86YA
M.V9O;G0M<VEZ93HQ.'!X.R(@86QI9VX](F-E;G1E<B(@=F%L:6=N/2)M:61D
M;&4B/B<["B`@("`@("`@)&AT;6P@+CT@<W1R9G1I;64H)R5!+"`E0B`E9"P@
M)5D@)RD["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=T:6UE)UT@/3T@
M)S(T+6AO=7(G*2!["B`@("`@("`@("`@("1H=&UL("X]('-T<F9T:6UE*"<E
M2#HE32<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H=&UL("X]
M('-T<F9T:6UE*"<E23HE32`E<"<I.PH@("`@("`@('T*("`@("`@("`D:'1M
M;"`N/2`G/"]T9#X\+W1R/CPO=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N("1H
M=&UL.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,S8U-``Q,#4Q-30S
M,3`V,``P,C$U-S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J($1I<V%B;&4@8FQO8VL@:68@;F]T(&-O;F9I
M9W5R960N("HO"FEF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG=V5A=&AE
M<F1O=&-O;2==6R=P87)T;F5R7VED)UTI("8F"B`@("`A96UP='DH)$=,3T)!
M3%-;)V-O;F8G75LG=V5A=&AE<F1O=&-O;2==6R=L:6-E;G-E7VME>2==*2D@
M>PH@("`@)&)L;V-K7VYA;64@/2!?*")W96%T:&5R+F-O;2(I.PI]"@HO*BH*
M("H@5&AE($AO<F1E7T)L;V-K7W=E871H97)D;W1C;VT@8VQA<W,@<')O=FED
M97,@86X@87!P;&5T(&9O<B!T:&4*("H@<&]R=&%L('-C<F5E;B!T;R!D:7-P
M;&%Y('=E871H97(@86YD(&9O<F5C87-T(&1A=&$@9G)O;2!W96%T:&5R+F-O
M;0H@*B!F;W(@82!S<&5C:69I960@;&]C871I;VXN"B`J"B`J("1(;W)D93H@
M:&]R9&4O;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP+'8@,2XS-RXT+C$S
M(#(P,#4O,3(O,#4@,#,Z-#$Z,#`@8VAU8VL@17AP("0*("H*("H@0'!A8VMA
M9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7W=E
M871H97)D;W1C;VT@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?
M87!P(#T@)VAO<F1E)SL*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G
M;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("`@5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L
M92@I"B`@("!["B`@("`@("`@<F5T=7)N(%\H(E=E871H97(@1F]R96-A<W0B
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!P87)A;65T97)S('1O(&=O
M('=I=&@@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;B!A<G)A>2!C;VYT86EN:6YG('1H92!P87)A;65T97)S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("!I9B`H(2A`
M:6YC;'5D95]O;F-E("=397)V:6-E<R]796%T:&5R+G!H<"<I('Q\"B`@("`@
M("`@("`@("$H0&EN8VQU9&5?;VYC92`G0V%C:&4N<&AP)RD@?'P*("`@("`@
M("`@("`@(2A`:6YC;'5D95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G*2!\
M?`H@("`@("`@("`@("`A:6YI7V=E="@G86QL;W=?=7)L7V9O<&5N)RDI('L*
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U1H92!W96%T:&5R+F-O
M;2!B;&]C:R!W:6QL(&YO="!W;W)K('=I=&AO=70@4$5!4EPG<R!397)V:6-E
M<U]796%T:&5R+"!#86-H92P@86YD(%A-3%\@4V5R:6%L:7IE<B!P86-K86=E
M<RP@86YD(&%L;&]W7W5R;%]F;W!E;B!E;F%B;&5D+B!2=6X@8'!E87(@:6YS
M=&%L;"!397)V:6-E<U]796%T:&5R($-A8VAE(%A-3%]397)I86QI>F5RM"!A
M;F0@96YS=7)E('1H870@86QL;W=?=7)L7V9O<&5N(&ES(&5N86)L960@:6X@
M<&AP+FEN:2XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=E<G)O<B<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E<G)O<B<L"B`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(D5R<F]R(BDL"B`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%\H(E1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(I"B`@("`@("`@("`@("`@("`I
M"B`@("`@("`@("`@("D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQO8V%T:6]N)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`O+R`G='EP92<@/3X@)W=E
M871H97)D;W1C;VTG+`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G
M=&5X="<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(DQO8V%T
M:6]N(BDL"B`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=";W-T
M;VXL($U!)PH@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=U
M;FET<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^
M("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B56YI
M=',B*2P*("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)W-T86YD
M87)D)RP*("`@("`@("`@("`@("`@("`@("`G,"<@/3X@)VYO;F4G+`H@("`@
M("`@("`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<W1A;F1A<F0G(#T^(%\H(E-T86YD87)D(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("=M971R:6,G(#T^(%\H(DUE=')I8R(I
M"B`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@*2P*("`@
M("`@("`@("`@("`@("=D87ES)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@("`@("=N
M86UE)R`]/B!?*")&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M(BDL"B`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<S)RP*("`@
M("`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@)S$G(#T^("<Q)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)S(G(#T^("<R)RP*("`@("`@("`@("`@("`@("`@("`@("`@)S,G
M(#T^("<S)RP*("`@("`@("`@("`@("`@("`@("`@("`@)S0G(#T^("<T)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)S4G(#T^("<U)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@)S8G(#T^("<V)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)S<G(#T^("<W)RP*("`@("`@("`@("`@("`@("`@("`@("`@)S@G
M(#T^("<X)RP*("`@("`@("`@("`@("`@("`@("`@("`@)SDG(#T^("<Y)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)S$P)R`]/B`G,3`G"B`@("`@("`@
M("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@
M("`@("=D971A:6QE9$9O<F5C87-T)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("`@("`@("`@("`@
M("`@("`G;F%M92<@/3X@7R@B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(I
M+`H@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`P"B`@("`@("`@
M("`@("`@("`I"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!C;VYT
M96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V]N=&5N="@I"B`@("!["B`@("`@("`@:68@*"$H0&EN8VQU9&5?;VYC92`G
M4V5R=FEC97,O5V5A=&AE<BYP:'`G*2!\?`H@("`@("`@("`@("`A*$!I;F-L
M=61E7V]N8V4@)T-A8VAE+G!H<"<I('Q\"B`@("`@("`@("`@("%I;FE?9V5T
M*"=A;&QO=U]U<FQ?9F]P96XG*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G5&AE('=E871H97(N8V]M(&)L;V-K('=I;&P@;F]T('=O<FL@
M=VET:&]U="!T:&4@4$5!4E-E<G9I8V5S7U=E871H97(@86YD($-A8VAE('!A
M8VMA9V5S+"!A;F0@86QL;W=?=7)L7V9O<&5N(&5N86)L960N(%)U;B!P96%R
M(&EN<W1A;&P@4V5R=FEC97-?5V5A=&AE<B!#86-H92P@86YD(&5N<W5R92!T
M:&%T(&%L;&]W7W5R;%]F;W!E;E]W<F%P<&5R<R!I<R!E;F%B;&5D(&EN('!H
M<"YI;FDN)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U
M<FX@7R@B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M(BD["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72DI('L*("`@
M("`@("`@("`@<F5T=7)N(%\H(DYO(&QO8V%T:6]N(&ES('-E="XB*3L*("`@
M("`@("!]"@H@("`@("`@("1W96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E
M871H97(Z.G-E<G9I8V4H)U=E871H97)$;W1#;VTG*3L*("`@("`@("`D=V5A
M=&AE<D1O=$-O;2T^<V5T06-C;W5N=$1A=&$H"B`@("`@("`@("`@("AI<W-E
M="@D8V]N9ELG=V5A=&AE<F1O=&-O;2==6R=P87)T;F5R7VED)UTI(#\@)&-O
M;F9;)W=E871H97)D;W1C;VTG75LG<&%R=&YE<E]I9"==(#H@)R<I+`H@("`@
M("`@("`@("`H:7-S970H)&-O;F9;)W=E871H97)D;W1C;VTG75LG;&EC96YS
M95]K97DG72D@/R`D8V]N9ELG=V5A=&AE<F1O=&-O;2==6R=L:6-E;G-E7VME
M>2==(#H@)R<I*3L*"B`@("`@("`@)&-A8VAE1&ER(#T@2&]R9&4Z.F=E=%1E
M;7!$:7(H*3L*("`@("`@("!I9B`H(21C86-H941I<BD@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(BDL("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1W96%T:&5R1&]T0V]M
M+3YS971#86-H92@G9FEL92<L(&%R<F%Y*"=C86-H95]D:7(G(#T^("@D8V%C
M:&5$:7(@+B`G+R<I*2D["B`@("`@("`@?0H@("`@("`@("1W96%T:&5R1&]T
M0V]M+3YS971$871E5&EM949O<FUA="@G;2YD+EDG+"`G2#II)RD["B`@("`@
M("`@)'=E871H97)$;W1#;VTM/G-E=%5N:71S1F]R;6%T*"1T:&ES+3Y?<&%R
M86US6R=U;FET<R==*3L*("`@("`@("`D=6YI=',@/2`D=V5A=&AE<D1O=$-O
M;2T^9V5T56YI='-&;W)M870H*3L*"B`@("`@("`@+R\@268@=&AE('5S97(@
M96YT97)E9"!A('II<"!C;V1E(&9O<B!T:&4@;&]C871I;VXL(&YO(&YE960@
M=&\*("`@("`@("`O+R!S96%R8V@@*'=E871H97(N8V]M(&%C8V5P=',@>FEP
M(&-O9&5S(&%S(&QO8V%T:6]N($E$<RDN"B`@("`@("`@+R\@5&AE(&QO8V%T
M:6]N($E$('-H;W5L9"!A;')E861Y(&AA=F4@8F5E;B!V86QI9&%T960@:6X*
M("`@("`@("`O+R!G971087)A;7,N"B`@("`@("`@)'-E87)C:"`]("AP<F5G
M7VUA=&-H*"<O7&(H/SI<7&1[-7TH+5Q<9'LU?2D_*7PH/SI;02U:77LT?5Q<
M9'LT?2E<8B\G+`H@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG;&]C871I
M;VXG72P@)&UA=&-H97,I(#\*("`@("`@("`@("`@)&UA=&-H97-;,%T@.@H@
M("`@("`@("`@("`D=V5A=&AE<D1O=$-O;2T^<V5A<F-H3&]C871I;VXH)'1H
M:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI*3L*("`@("`@("!I9B`H:7-?82@D
M<V5A<F-H+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@('-W:71C:"`H
M)'-E87)C:"T^9V5T0V]D92@I*2!["B`@("`@("`@("`@(&-A<V4@4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]315)624-%7TY/5%]&3U5.1#H*("`@("`@("`@
M("`@("`@(')E='5R;B!?*")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(BD["B`@("`@("`@("`@(&-A<V4@4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]53DM.3U=.7TQ/0T%424]..@H@("`@("`@("`@("`@("`@<F5T
M=7)N(%\H(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(BD["B`@("`@("`@
M("`@(&-A<V4@4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?
M1$%403H*("`@("`@("`@("`@("`@(')E='5R;B!?*")397)V97(@9&%T82!W
M<F]N9R!O<B!N;W0@879A:6QA8FQE+B(I.PH@("`@("`@("`@("!C87-E(%-%
M4E9)0T537U=%051(15)?15)23U)?0T%#2$5?24Y)5%]&04E,140Z"B`@("`@
M("`@("`@("`@("!R971U<FX@7R@B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"XB*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]714%42$527T52
M4D]27T1"7TY/5%]#3TY.14-4140Z"B`@("`@("`@("`@("`@("!R971U<FX@
M7R@B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(I.PH@("`@("`@("`@("!C
M87-E(%-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E]%4E)/4CH*("`@
M("`@("`@("`@("`@(')E='5R;B!?*")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?
M15)23U)?3D]?3$]#051)3TXZ"B`@("`@("`@("`@("`@("!R971U<FX@7R@B
M3F\@;&]C871I;VX@<')O=FED960N(BD["B`@("`@("`@("`@(&-A<V4@4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424]..@H@("`@("`@
M("`@("`@("`@<F5T=7)N(%\H(DEN=F%L:60@;&]C871I;VX@<')O=FED960N
M(BD["B`@("`@("`@("`@(&-A<V4@4T525DE#15-?5T5!5$A%4E]%4E)/4E])
M3E9!3$E$7U!!4E1.15)?240Z"B`@("`@("`@("`@("`@("!R971U<FX@7R@B
M26YV86QI9"!P87)T;F5R(&ED+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)
M0T537U=%051(15)?15)23U)?24Y604Q)1%]04D]$54-47T-/1$4Z"B`@("`@
M("`@("`@("`@("!R971U<FX@7R@B26YV86QI9"!P<F]D=6-T(&-O9&4N(BD[
M"B`@("`@("`@("`@(&-A<V4@4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!
M3$E$7TQ)0T5.4T5?2T59.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DEN
M=F%L:60@;&EC96YS92!K97DN(BD["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("!R971U<FX@)'-E87)C:"T^9V5T;65S<V%G92@I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:'1M;"`]("<G.PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D<V5A<F-H*2D@>PH@("`@("`@("`@("`O
M+R!3979E<F%L(&QO8V%T:6]N<R!R971U<FYE9"!D=64@=&\@:6UP<F5C:7-E
M(&QO8V%T:6]N"B`@("`@("`@("`@("\O('!A<F%M971E<BX*("`@("`@("`@
M("`@)&AT;6P@/2!?*")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z("(I("X*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=L;V-A=&EO;B==("X*("`@("`@("`@("`@("`@("<\8G(@+SX\
M=6P^)SL*("`@("`@("`@("`@9F]R96%C:"`H)'-E87)C:"!A<R`D:61?=V5A
M=&AE<CT^)')E86Q?;&]C871I;VXI('L*("`@("`@("`@("`@("`@("1H=&UL
M("X]("(\;&D^)')E86Q?;&]C871I;VX@*"1I9%]W96%T:&5R*3PO;&D^7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<\+W5L/B<[
M"B`@("`@("`@("`@(')E='5R;B`D:'1M;#L*("`@("`@("!]"@H@("`@("`@
M("1L;V-A=&EO;B`]("1W96%T:&5R1&]T0V]M+3YG971,;V-A=&EO;B@D<V5A
M<F-H*3L*("`@("`@("!I9B`H:7-?82@D;&]C871I;VXL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L;V-A=&EO;BT^9V5T;65S<V%G
M92@I.PH@("`@("`@('T*("`@("`@("`D=V5A=&AE<B`]("1W96%T:&5R1&]T
M0V]M+3YG971796%T:&5R*"1S96%R8V@I.PH@("`@("`@(&EF("AI<U]A*"1W
M96%T:&5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=V5A=&AE<BT^9V5T;65S<V%G92@I.PH@("`@("`@('T*("`@("`@("`D9F]R
M96-A<W0@/2`D=V5A=&AE<D1O=$-O;2T^9V5T1F]R96-A<W0H)'-E87)C:"P@
M)'1H:7,M/E]P87)A;7-;)V1A>7,G72D["B`@("`@("`@:68@*&ES7V$H)&9O
M<F5C87-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M9F]R96-A<W0M/F=E=&UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@("\O
M($QO8V%T:6]N(&%N9"!L;V-A;"!T:6UE+@H@("`@("`@("1H=&UL("X]("<\
M9&EV(&-L87-S/2)C;VYT<F]L(CXG("X*("`@("`@("`@("`@)SQS=')O;F<^
M)R`N("1L;V-A=&EO;ELG;F%M92==("X@)SPO<W1R;VYG/B`G("X@7R@B3&]C
M86P@=&EM93H@(BD@+B`D;&]C871I;VY;)W1I;64G72`N"B`@("`@("`@("`@
M("<\+V1I=CXG.PH*("`@("`@("`O+R!3=6YR:7-E+W-U;G-E="X*("`@("`@
M("`D:'1M;"`N/2`G/'-T<F]N9SXG("X@7R@B4W5N<FES93H@(BD@+B`G/"]S
M=')O;F<^)R`N"B`@("`@("`@("`@($AO<F1E.CII;6<H)V)L;V-K+W-U;G)I
M<V4O<W5N<FES92YP;F<G+"!?*")3=6YR:7-E(BDI("X*("`@("`@("`@("`@
M)&QO8V%T:6]N6R=S=6YR:7-E)UT["B`@("`@("`@)&AT;6P@+CT@)R`\<W1R
M;VYG/B<@+B!?*")3=6YS970Z("(I("X@)SPO<W1R;VYG/B<@+@H@("`@("`@
M("`@("!(;W)D93HZ:6UG*"=B;&]C:R]S=6YR:7-E+W-U;G-E="YP;F<G+"!?
M*")3=6YS970B*2D@+@H@("`@("`@("`@("`D;&]C871I;VY;)W-U;G-E="==
M.PH*("`@("`@("`O+R!496UP97)A='5R92X*("`@("`@("`D:'1M;"`N/2`G
M/&)R("\^/'-T<F]N9SXG("X@7R@B5&5M<&5R871U<F4Z("(I("X@)SPO<W1R
M;VYG/B<@+@H@("`@("`@("`@("!R;W5N9"@D=V5A=&AE<ELG=&5M<&5R871U
M<F4G72D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G
M72D["@H@("`@("`@("\O($1E=R!P;VEN="X*("`@("`@("`D:'1M;"`N/2`G
M(#QS=')O;F<^)R`N(%\H(D1E=R!P;VEN=#H@(BD@+B`G/"]S=')O;F<^)R`N
M"B`@("`@("`@("`@(')O=6YD*"1W96%T:&5R6R=D97=0;VEN="==*2`N("<F
M9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*"B`@("`@
M("`@+R\@1F5E;',@;&EK92!T96UP97)A='5R92X*("`@("`@("`D:'1M;"`N
M/2`G(#QS=')O;F<^)R`N(%\H(D9E96QS(&QI:V4Z("(I("X@)SPO<W1R;VYG
M/B<@+@H@("`@("`@("`@("!R;W5N9"@D=V5A=&AE<ELG9F5L=%1E;7!E<F%T
M=7)E)UTI("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP
M)UTI.PH*("`@("`@("`O+R!0<F5S<W5R92!A;F0@=')E;F0N"B`@("`@("`@
M)&AT;6P@+CT@)SQB<B`O/CQS=')O;F<^)R`N(%\H(E!R97-S=7)E.B`B*2`N
M("<\+W-T<F]N9SXG.PH@("`@("`@("1T<F5N9"`]("1W96%T:&5R6R=P<F5S
M<W5R951R96YD)UT["B`@("`@("`@)&AT;6P@+CT@<W!R:6YT9BA?*"(E9"`E
M<R!A;F0@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1W
M96%T:&5R6R=P<F5S<W5R92==*2P@)'5N:71S6R=P<F5S)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("!?*"1T<F5N9"DI.PH*("`@("`@("`O+R!7:6YD
M+@H@("`@("`@("1H=&UL("X]("<\8G(@+SX\<W1R;VYG/B<@+B!?*")7:6YD
M.B`B*2`N("<\+W-T<F]N9SXG.PH@("`@("`@(&EF("@D=V5A=&AE<ELG=VEN
M9$1I<F5C=&EO;B==(#T]("=605(G*2!["B`@("`@("`@("`@("1H=&UL("X]
M(%\H(E9A<FEA8FQE(BD["B`@("`@("`@?2!E;'-E:68@*"1W96%T:&5R6R=W
M:6YD1&ER96-T:6]N)UT@/3T@)T-!3$TG*2!["B`@("`@("`@("`@("1H=&UL
M("X](%\H(D-A;&TB*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:'1M;"`N/2!?*")&<F]M('1H92`B*2`N("1W96%T:&5R6R=W:6YD1&ER96-T
M:6]N)UT["B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R6R=W:6YD1W5S="==
M*2`F)B`D=V5A=&AE<ELG=VEN9$=U<W0G72`^(#`I('L*("`@("`@("`@("`@
M)&AT;6P@+CT@)RP@)R`N(%\H(F=U<W1I;F<B*2`N("<@)R`N("1W96%T:&5R
M6R=W:6YD1W5S="==("X*("`@("`@("`@("`@("`@("<@)R`N("1U;FET<ULG
M=VEN9"==.PH@("`@("`@('T*"B`@("`@("`@("`@("1H=&UL("X]("<@*"<@
M+B`D=V5A=&AE<ELG=VEN9$1E9W)E97,G72`N("<I)SL*("`@("`@("!]"B`@
M("`@("`@)&AT;6P@+CT@7R@B(&%T("(I("X@<F]U;F0H)'=E871H97);)W=I
M;F0G72D@+B`G("<@+B`D=6YI='-;)W=I;F0G73L*"B`@("`@("`@+R\@2'5M
M:61I='DN"B`@("`@("`@)&AT;6P@+CT@)SQB<B`O/CQS=')O;F<^)R`N(%\H
M(DAU;6ED:71Y.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@)'=E
M871H97);)VAU;6ED:71Y)UT@+B`G)2<["@H@("`@("`@("\O(%9I<VEB:6QI
M='DN"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@+B!?*")6:7-I8FEL
M:71Y.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@*&ES7VYU;65R
M:6,H)'=E871H97);)W9I<VEB:6QI='DG72D*("`@("`@("`@("`@(#\@<F]U
M;F0H)'=E871H97);)W9I<VEB:6QI='DG72D@+B`G("<@+B`D=6YI='-;)W9I
M<R=="B`@("`@("`@("`@("`Z("1W96%T:&5R6R=V:7-I8FEL:71Y)UTI.PH*
M("`@("`@("`O+R!55B!I;F1E>"X*("`@("`@("`D:'1M;"`N/2`G(#QS=')O
M;F<^)R`N(%\H(E4N5BX@:6YD97@Z("(I("X@)SPO<W1R;VYG/B<["B`@("`@
M("`@)'5V(#T@)'=E871H97);)W5V5&5X="==.PH@("`@("`@("1H=&UL("X]
M("1W96%T:&5R6R=U=DEN9&5X)UT@+B`G("T@)R`N(%\H)'5V*3L*"B`@("`@
M("`@+R\@0W5R<F5N="!C;VYD:71I;VXN"B`@("`@("`@)&-O;F1I=&EO;B`]
M(&EM<&QO9&4H)R`O("<L(&%R<F%Y7VUA<"@G7R<L(&5X<&QO9&4H)R`O("<L
M("1W96%T:&5R6R=C;VYD:71I;VXG72DI*3L*("`@("`@("`D:'1M;"`N/2`G
M/&)R("\^/'-T<F]N9SXG("X@7R@B0W5R<F5N="!C;VYD:71I;VXZ("(I("X@
M)SPO<W1R;VYG/B<@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+R<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("@D=V5A=&AE<ELG8V]N9&ET:6]N26-O;B==(#T]("<M)R`_("=N82<@.B`D
M=V5A=&AE<ELG8V]N9&ET:6]N26-O;B==*2`N("<N<&YG)RP*("`@("`@("`@
M("`@("`@("`@("`@("`D8V]N9&ET:6]N+`H@("`@("`@("`@("`@("`@("`@
M("`@("=A;&EG;CTB;6ED9&QE(B<I.PH@("`@("`@("1H=&UL("X]("<@)R`N
M("1C;VYD:71I;VX["@H@("`@("`@("\O($1O('1H92!F;W)E8V%S="!N;W<@
M*&EF(')E<75E<W1E9"DN"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=D
M87ES)UT@/B`P*2!["B`@("`@("`@("`@("1H=&UL("X]("<\9&EV(&-L87-S
M/2)C;VYT<F]L(B!S='EL93TB=&5X="UA;&EG;CIC96YT97(B/CQS=')O;F<^
M)R`N"B`@("`@("`@("`@("`@("!S<')I;G1F*%\H(B5D+61A>2!F;W)E8V%S
M="(I+"`D=&AI<RT^7W!A<F%M<ULG9&%Y<R==*2`N"B`@("`@("`@("`@("`@
M("`G/"]S=')O;F<^/"]D:78^)SL*"B`@("`@("`@("`@("1F=71U<F5$87ES
M(#T@,#L*("`@("`@("`@("`@)&AT;6P@+CT@)SQT86)L92!W:61T:#TB,3`P
M)2(@8V5L;'-P86-I;F<](C,B/B<["B`@("`@("`@("`@("\O($AE861E<G,N
M"B`@("`@("`@("`@("1H=&UL("X]("<\='(^)SL*("`@("`@("`@("`@)&AT
M;6P@+CT@)SQT:#XG("X@7R@B1&%Y(BD@+B`G/"]T:#X\=&@^)FYB<W`[/"]T
M:#X\=&@^)R`N"B`@("`@("`@("`@("`@("!S<')I;G1F*%\H(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)SQS<&%N('-T>6QE/2)C;VQO<CIR960B/B<L("<\
M+W-P86X^)RP*("`@("`@("`@("`@("`@("`@("`@("`@)SQS<&%N('-T>6QE
M/2)C;VQO<CIB;'5E(CXG+"`G/"]S<&%N/B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI*2`N"B`@("`@
M("`@("`@("`@("`G/"]T:#X\=&@^)R`N(%\H(D-O;F1I=&EO;B(I("X@)SPO
M=&@^)R`N"B`@("`@("`@("`@("`@("`G/'1H/B<@+B!?*")0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E(BD@+B`G/"]T:#XG.PH@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P87)A;7-;)V1E=&%I;&5D1F]R96-A<W0G72DI('L*
M("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&@^)R`N(%\H(DAU;6ED:71Y
M(BD@+B`G/"]T:#X\=&@^)R`N(%\H(E=I;F0B*2`N("<\+W1H/B<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SPO='(^)SL*"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1F;W)E8V%S=%LG9&%Y<R==(&%S("1W:&EC:"`]
M/B`D9&%Y*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1R(&-L87-S
M/2)I=&5M,"(^)SL*"B`@("`@("`@("`@("`@("`O+R!$87D@;F%M92X*("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<F]W<W!A;CTB,B(@<W1Y;&4]
M(F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`G/'-T<F]N9SXG.PH@("`@("`@
M("`@("`@("`@:68@*"1W:&EC:"`]/2`P*2!["B`@("`@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@7R@B5&]D87DB*3L*("`@("`@("`@("`@("`@('T@96QS
M96EF("@D=VAI8V@@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL
M("X](%\H(E1O;6]R<F]W(BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1H=&UL("X]('-T<F9T:6UE*"<E02<L(&UK
M=&EM92@P+"`P+"`P+"!D871E*"=M)RDL(&1A=&4H)V0G*2`K("1F=71U<F5$
M87ES+"!D871E*"=9)RDI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1H=&UL("X]("<\+W-T<F]N9SX\8G(@+SXG("X*("`@("`@("`@
M("`@("`@("`@("!S=')F=&EM92@G)6(@)60G+"!M:W1I;64H,"P@,"P@,"P@
M9&%T92@G;2<I+"!D871E*"=D)RD@*R`D9G5T=7)E1&%Y<RP@9&%T92@G62<I
M*2D@+@H@("`@("`@("`@("`@("`@("`@("<\+W1D/B<@+@H@("`@("`@("`@
M("`@("`@("`@("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@
M=&5X="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@("`@("`@("`@("<\
M<W!A;B!S='EL93TB8V]L;W(Z;W)A;F=E(CXG("X*("`@("`@("`@("`@("`@
M("`@("!?*")$87DB*2`N("<\+W-P86X^/"]T9#XG.PH*("`@("`@("`@("`@
M("`@("\O(%1H92!D87D@<&]R=&EO;B!O9B!T:&4@9F]R96-A<W0@:7,@;F\@
M;&]N9V5R(&%V86EL86)L92!A9G1E<B`R.C`P('`N;2X@;&]C86P@=&]D87DN
M"B`@("`@("`@("`@("`@("!I9B`H)'=H:6-H(#T](#`@)B8@*'-T<G1O=&EM
M92@D;&]C871I;VY;)W1I;64G72D@/CT@<W1R=&]T:6UE*"<Q-#HP,"<I*2D@
M>PH@("`@("`@("`@("`@("`@("`@("\O($)A;&%N8V4@=&AE(&=R:60N"B`@
M("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!C;VQS<&%N/2(G("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("@H:7-S970H)'1H:7,M/E]P
M87)A;7-;)V1E=&%I;&5D1F]R96-A<W0G72D@/R`G-2<@.B`G,R<I("X@)R(G
M*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G('-T>6QE/2)B;W)D
M97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<F;F)S<#L\8G(@+SXG("X@7R@B
M26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB*2`N("<\8G(@+SXF
M;F)S<#LG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\+W1D/B<[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("\O($9O<F5C87-T(&-O;F1I=&EO;BX*("`@("`@("`@("`@("`@("`@("`D
M8V]N9&ET:6]N(#T@:6UP;&]D92@G("\@)RP@87)R87E?;6%P*"=?)RP@97AP
M;&]D92@G("\@)RP@)&1A>5LG9&%Y)UU;)V-O;F1I=&EO;B==*2DI.PH*("`@
M("`@("`@("`@("`@("`@("`O+R!(:6=H('1E;7!E<F%T=7)E+@H@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@
M<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`G/'-P86X@<W1Y;&4](F-O;&]R.G)E9"(^)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1D87E;)W1E;7!E<F%T=7)E
M2&EG:"==*2`N("<\+W-P86X^/"]T9#XG.PH*("`@("`@("`@("`@("`@("`@
M("`O+R!#;VYD:71I;VXN"B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M)SQT9"!S='EL93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N
M.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E.CII
M;6<H)V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O)R`N("@D9&%Y6R=D87DG
M75LG8V]N9&ET:6]N26-O;B==(#T]("<M)R`_("=N82<@.B`D9&%Y6R=D87DG
M75LG8V]N9&ET:6]N26-O;B==*2`N("<N<&YG)RP@)&-O;F1I=&EO;BD@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`G/&)R("\^)R`N("1C;VYD:71I;VX@
M+B`G/"]T9#XG.PH*("`@("`@("`@("`@("`@("`@("`O+R!0<F5C:7!I=&%T
M:6]N(&-H86YC92X*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D
M('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N
M=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`@("`@)&1A>5LG9&%Y)UU;
M)W!R96-I<&ET871I;VXG72`N("<E)R`N("<\+W1D/B<["@H@("`@("`@("`@
M("`@("`@("`@("\O($EF(&$@9&5T86EL960@9F]R96-A<W0@=V%S(')E<75E
M<W1E9"P@<VAO=R!H=6UI9&ET>2!A;F0*("`@("`@("`@("`@("`@("`@("`O
M+R!W:6YD<RX*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P87)A;7-;)V1E=&%I;&5D1F]R96-A<W0G72DI('L*"B`@("`@("`@("`@
M("`@("`@("`@("`@("\O($AU;6ED:71Y+@H@("`@("`@("`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D
M9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D87E;)V1A>2==6R=H=6UI9&ET>2==("X@)R4\+W1D/B<[
M"@H@("`@("`@("`@("`@("`@("`@("`@("`O+R!7:6YD<RX*("`@("`@("`@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!S='EL93TB8F]R9&5R.C%P
M>"!S;VQI9"`C9&1D(CXG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%\H(D9R;VT@=&AE("(I("X@)&1A>5LG9&%Y)UU;)W=I;F1$:7)E8W1I;VXG
M72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*"(@870@(BD@+B`D
M9&%Y6R=D87DG75LG=VEN9"==("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<@)R`N("1U;FET<ULG=VEN9"==.PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1A>5LG9&%Y)UU;)W=I;F1'=7-T)UTI("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%Y6R=D87DG75LG=VEN9$=U
M<W0G72`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL
M("X](%\H(BP@9W5S=&EN9R`B*2`N("1D87E;)V1A>2==6R=W:6YD1W5S="==
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G("<@+B`D=6YI
M='-;)W=I;F0G73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M)SPO='(^)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M+R!.:6=H="!F;W)E8V%S=`H@("`@("`@("`@("`@("`@)&YI9VAT(#T@:6UP
M;&]D92@G("\@)RP@87)R87E?;6%P*"=?)RP@97AP;&]D92@G("\@)RP@)&1A
M>5LG;FEG:'0G75LG8V]N9&ET:6]N)UTI*2D["@H@("`@("`@("`@("`@("`@
M+R\@4VAA9&4@:70@9F]R('9I<W5A;"!S97!A<F%T:6]N+@H@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@)SQT<B!C;&%S<STB:71E;3$B/B<["@H@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@)SQT9"!S='EL93TB8F]R9&5R.C%P>"!S;VQI
M9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@
M("`@("`@7R@B3FEG:'0B*2`N("<\+W1D/B<["@H@("`@("`@("`@("`@("`@
M+R\@3&]W('1E;7!E<F%T=7)E+@H@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M)SQT9"!S='EL93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N
M.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@("`@("`@)SQS<&%N('-T>6QE
M/2)C;VQO<CIB;'5E(CXG("X*("`@("`@("`@("`@("`@("`@("!R;W5N9"@D
M9&%Y6R=T96UP97)A='5R94QO=R==*2`N("<\+W-P86X^/"]T9#XG.PH*("`@
M("`@("`@("`@("`@("\O($-O;F1I=&EO;BX*("`@("`@("`@("`@("`@("1H
M=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X
M="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@("`@("`@("`@($AO<F1E
M.CII;6<H)V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O)R`N("@D9&%Y6R=N
M:6=H="==6R=C;VYD:71I;VY)8V]N)UT@/3T@)RTG(#\@)VYA)R`Z("1D87E;
M)VYI9VAT)UU;)V-O;F1I=&EO;DEC;VXG72D@+B`G+G!N9R<L("1N:6=H="D@
M+@H@("`@("`@("`@("`@("`@("`@("<\8G(@+SXG("X@)&YI9VAT("X@)SPO
M=&0^)SL*"B`@("`@("`@("`@("`@("`O+R!0<F5C:7!I=&%T:6]N(&-H86YC
M92X*("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E
M<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@+@H@("`@
M("`@("`@("`@("`@("`@("1D87E;)VYI9VAT)UU;)W!R96-I<&ET871I;VXG
M72`N("<E/"]T9#XG.PH*("`@("`@("`@("`@("`@("\O($EF(&$@9&5T86EL
M960@9F]R96-A<W0@=V%S(')E<75E<W1E9"P@9&ES<&QA>2!H=6UI9&ET>2!A
M;F0*("`@("`@("`@("`@("`@("\O('=I;F1S+@H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D971A:6QE9$9O<F5C87-T)UTI
M*2!["@H@("`@("`@("`@("`@("`@("`@("\O($AU;6ED:71Y+@H@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@
M<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%Y6R=N:6=H="==6R=H=6UI9&ET>2==("X@)R4\
M+W1D/B<["@H@("`@("`@("`@("`@("`@("`@("\O(%=I;F1S+@H@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@
M<V]L:60@(V1D9"(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@(%\H(D9R
M;VT@=&AE("(I("X@)&1A>5LG;FEG:'0G75LG=VEN9$1I<F5C=&EO;B==("X*
M("`@("`@("`@("`@("`@("`@("`@("`@7R@B(&%T("(I("X@)&1A>5LG;FEG
M:'0G75LG=VEN9"==("X*("`@("`@("`@("`@("`@("`@("`@("`@)R`G("X@
M)'5N:71S6R=W:6YD)UT["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D87E;)VYI9VAT)UU;)W=I;F1'=7-T)UTI("8F("1D87E;)VYI9VAT)UU;
M)W=I;F1'=7-T)UT@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H
M=&UL("X](%\H(BP@9W5S=&EN9R`B*2`N("1D87E;)VYI9VAT)UU;)W=I;F1'
M=7-T)UT@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R`G("X@)'5N
M:71S6R=W:6YD)UT["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W1R/B<["@H@
M("`@("`@("`@("`@("`@+R\@4')E<&%R92!F;W(@;F5X="!D87DN"B`@("`@
M("`@("`@("`@("`D9G5T=7)E1&%Y<RLK.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1H=&UL("X]("<\+W1A8FQE/B<["B`@("`@("`@?0H*("`@("`@
M("`O+R!$:7-P;&%Y(&$@8F%R(&%T('1H92!B;W1T;VT@;V8@=&AE(&)L;V-K
M('=I=&@@=&AE(')E<75I<F5D"B`@("`@("`@+R\@871T<FEB=71I;VX@=&\@
M=V5A=&AE<BYC;VT@86YD('1H92!L;V=O+"!B;W1H(&QI;FME9"!T;PH@("`@
M("`@("\O('=E871H97(N8V]M('=I=&@@=&AE('!A<G1N97(@240N"B`@("`@
M("`@<F5T=7)N("1H=&UL("X@)SQD:78@8VQA<W,](G)I9VAT06QI9VX@;&EN
M9612;W<B/B<@+@H@("`@("`@("`@("!?*")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB*2`N("<@)R`N"B`@("`@("`@("`@($AO<F1E.CIL:6YK*$AO<F1E
M.CIE>'1E<FYA;%5R;"@G:'1T<#HO+W=W=RYW96%T:&5R+F-O;2\_<')O9#UX
M;V%P)F%M<#MP87(])R`N"B`@("`@("`@("`@("`@("`@("`@("`@("1W96%T
M:&5R1&]T0V]M+3Y?<&%R=&YE<DE$*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)W=E871H97(N8V]M)RP@)R<L("=?8FQA;FLG+"`G)RP@)W=E871H97(N
M8V]M)RD@+@H@("`@("`@("`@("`G/&5M/G=E871H97(N8V]M/"]E;3XF<F5G
M.R`G("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B]45T-L;V=O7S,R<'@N<&YG)RP@)W=E871H97(N8V]M(&QO
M9V\G*2`N"B`@("`@("`@("`@("<\+V$^/"]D:78^)SL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O0FQO8VLO86-C;W5N="YP:'``````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0S-S$U`#$P-3$U-#,Q
M,#8P`#`R,#,V,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*)&)L;V-K7VYA;64@/2!?*")!8V-O=6YT($EN9F]R
M;6%T:6]N(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO86-C
M;W5N="YP:'`L=B`Q+C<N,BXT(#(P,#8O,#,O,3`@,3<Z,C@Z-#0@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@17)I8R!2;W-T971T97(@
M/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K
M86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]A
M8V-O=6YT(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]
M("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@
M=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H
M92!T:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B!?*")->2!!8V-O=6YT($EN9F]R;6%T:6]N
M(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1C;VYF.PH*("`@("`@
M("!S=VET8V@@*"1C;VYF6R=A8V-O=6YT<R==6R=D<FEV97(G72D@>PH@("`@
M("`@(&-A<V4@)VYU;&PG.@H@("`@("`@("`@("`D;7ED<FEV97(@/2`F;F5W
M($%C8V]U;G1S7T1R:79E<B@I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!C87-E("=L;V-A;&AO<W0G.@H@("`@("`@(&-A<V4@)VQD87`G.@H@("`@
M("`@("`@("`D8VQA<W,@/2`G06-C;W5N='-?1')I=F5R7R<@+B`D8V]N9ELG
M86-C;W5N=',G75LG9')I=F5R)UT["B`@("`@("`@("`@("1M>61R:79E<B`]
M("9N97<@)&-L87-S*"1C;VYF6R=A8V-O=6YT<R==6R=P87)A;7,G72D["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!P
M87-S=V]R9"!S=&%T=7,N"B`@("`@("`@:68@*&ES7V$H)'-T871U<R`]("1M
M>61R:79E<BT^8VAE8VM087-S=V]R9%-T871U<R@I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1S=&%T=7,@/2`D<W1A='5S+3YG971-97-S86=E
M*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D=7-E<FYA;64@/2`D
M;7ED<FEV97(M/F=E=%5S97)N86UE*"DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1U<V5R;F%M92T^9V5T365S<V%G92@I.PH@("`@
M("`@('T*("`@("`@("`D=&%B;&4@/2!A<G)A>2A?*"),;V=I;B(I(#T^("1U
M<V5R;F%M92D["B`@("`@("`@:68@*&ES7V$H)&9U;&QN86UE(#T@)&UY9')I
M=F5R+3YG971&=6QL;F%M92@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D9G5L;&YA;64M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]
M(&5L<V5I9B`H)&9U;&QN86UE*2!["B`@("`@("`@("`@("1T86)L95M?*")&
M=6QL($YA;64B*5T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<U]A*"1H;VUE(#T@)&UY9')I=F5R+3YG971(;VUE*"DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1H;VUE+3YG971-97-S86=E
M*"D["B`@("`@("`@?2!E;'-E:68@*"1H;VUE*2!["B`@("`@("`@("`@("1T
M86)L95M?*")(;VUE($1I<F5C=&]R>2(I72`]("1H;VUE.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-?82@D<VAE;&P@/2`D;7ED<FEV97(M/F=E=%-H96QL
M*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S:&5L
M;"T^9V5T365S<V%G92@I.PH@("`@("`@('T@96QS96EF("@D<VAE;&PI('L*
M("`@("`@("`@("`@)'1A8FQE6U\H(D1E9F%U;'0@4VAE;&PB*5T@/2`D<VAE
M;&P["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1Q=6]T82`]("1M>61R
M:79E<BT^9V5T475O=&$H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'%U;W1A+3YG971-97-S86=E*"D["B`@("`@("`@?2!E;'-E
M:68@*"1Q=6]T82D@>PH@("`@("`@("`@("`D=&%B;&5;7R@B475O=&$B*5T@
M/2!S<')I;G1F*%\H(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E
M+C)F)24I(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'%U;W1A6R=U<V5D)UT@+R`H(#$P,C0@*B`Q,#(T+C`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Q=6]T85LG
M;&EM:70G72`O("@@,3`R-"`J(#$P,C0N,"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*"1Q=6]T85LG=7-E9"==("H@,3`P
M+C`I("\@)'%U;W1A6R=L:6UI="==*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES7V$H)&QA<W1C:&%N9V4@/2`D;7ED<FEV97(M/F=E=%!A<W-W;W)D0VAA
M;F=E*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L
M87-T8VAA;F=E+3YG971-97-S86=E*"D["B`@("`@("`@?2!E;'-E:68@*"1L
M87-T8VAA;F=E*2!["B`@("`@("`@("`@("1T86)L95M?*"),87-T(%!A<W-W
M;W)D($-H86YG92(I72`]("1L87-T8VAA;F=E.PH@("`@("`@('T*"B`@("`@
M("`@)&]U='!U="`]("<\=&%B;&4@8VQA<W,](FET96TB('=I9'1H/2(Q,#`E
M(B!C96QL<W!A8VEN9STB,2(^)SL*"B`@("`@("`@:68@*"%E;7!T>2@D<W1A
M='5S*2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]("<\='(^/'1D(&-O;'-P
M86X](C(B/CQP(&-L87-S/2)N;W1I8V4B/B<@+@H@("`@("`@("`@("`@("`@
M2&]R9&4Z.FEM9R@G86QE<G1S+W=A<FYI;F<N<&YG)RP@7R@B5V%R;FEN9R(I
M*2`N"B`@("`@("`@("`@("`@("`G)FYB<W`[)FYB<W`[)R`N("1S=&%T=7,@
M+B`G/"]P/CPO=&0^/"]T<CXG.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)'1A8FQE(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1O
M=71P=70@+CT@(CQT<B!C;&%S<SU<(G1E>'1<(CX\=&0^)&ME>3PO=&0^/'1D
M/B1V86QU93PO=&0^/"]T<CY<;B(["B`@("`@("`@?0H@("`@("`@("1O=71P
M=70@+CT@(CPO=&%B;&4^7&XB.PH*("`@("`@("!I9B`H)')E9VES=')Y+3YG
M970H)W-T871U<R<L("=F;W)W87)D<R<I("$]("=I;F%C=&EV92<@)B8*("`@
M("`@("`@("`@)')E9VES=')Y+3YH87--971H;V0H)W-U;6UA<GDG+"`G9F]R
M=V%R9',G*2D@>PH@("`@("`@("`@("`D<W5M;6%R>2`]("1R96=I<W1R>2T^
M8V%L;$)Y4&%C:V%G92@G9F]R=V%R9',G+"`G<W5M;6%R>2<I.PH@("`@("`@
M("`@("!I9B`H(6ES7V$H)'-U;6UA<GDL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@)SQB<B`O/B<@+B`D<W5M;6%R>2`N
M(")<;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1R
M96=I<W1R>2T^9V5T*"=S=&%T=7,G+"`G=F%C871I;VXG*2`A/2`G:6YA8W1I
M=F4G("8F"B`@("`@("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D*"=S=6UM
M87)Y)RP@)W9A8V%T:6]N)RDI('L*("`@("`@("`@("`@)'-U;6UA<GD@/2`D
M<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)W9A8V%T:6]N)RP@)W-U;6UA<GDG
M*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1S=6UM87)Y+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("<\8G(@+SXG("X@
M)'-U;6UA<GD@+B`B7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"GT*"B\J*@H@*B!!8V-O=6YT
M<U]$<FEV97(Z.B!D969I;F5S(&%N($%022!F;W(@9V5T=&EN9R]D:7-P;&%Y
M:6YG(&%C8V]U;G0@:6YF;W)M871I;VX*("H@9F]R(&$@=7-E<B!F;W(@=&AE
M(&%C8V]U;G1S(&UO9'5L92X*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!%
M<FEC(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N
M961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@17)I8R!2;W-T971T
M97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@0'-I
M;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC
M;&%S<R!!8V-O=6YT<U]$<FEV97(@>PH*("`@("\J*@H@("`@("H@17)R;W(@
M<W1R:6YG(')E='5R;F5D('1O('5S97(@:68@86X@97)R;W(@;V-C=7)S+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D97)R
M7W-T<CL*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97)N86UE+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]W97)C87-E9"!U
M<V5R;F%M92X*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5S97)N
M86UE*"D*("`@('L*("`@("`@("`D875T:"`](&5X<&QO9&4H)T`G+"!!=71H
M.CIG971!=71H*"DI.PH@("`@("`@(')E='5R;B!3=')I;F<Z.FQO=V5R*"1A
M=71H6S!=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S
M97(@<F5A;&TN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U
M<V5R(')E86QM+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971296%L;2@I"B`@
M("!["B`@("`@("`@)&%U=&@@/2!E>'!L;V1E*"=`)RP@075T:#HZ9V5T075T
M:"@I*3L*("`@("`@("!R971U<FX@:7-S970H)&%U=&A;,5TI(#\@)&%U=&A;
M,5T@.B`G)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S
M97(G<R!Q=6]T82!I9B!A=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@02!Q=6]T82!A<G)A>2P@96QE;65N=',@87)E('5S960@8GET
M97,@86YD(&QI;6ET(&)Y=&5S(&]N"B`@("`@*B`@("`@("`@("`@("`@("!S
M=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9711=6]T82@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S(&9U;&P@;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S(&9U
M;&P@;F%M92`H<W1R:6YG*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1G5L;&YA;64H*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S
M97(G<R!H;VUE("AL;V=I;BD@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!U<V5R)W,@9&ER96-T;W)Y("AS=')I;F<I+"!O
M<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(;VUE
M*"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@9&5F875L="!S:&5L;"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S('-H96QL("AS
M=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9713:&5L;"@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&%T92!O9B!T:&4@=7-E
M<B=S(&QA<W0@<&%S<W=O<F0@8VAA;F=E+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($1A=&4@<W1R:6YG("AS=')I;F<I(&]R(&9A;'-E("AE<G)O
M<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<W-W;W)D0VAA;F=E*"D*
M("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!S=&%T=7,@;V8@=&AE(&-U<G)E;G0@<&%S<W=O
M<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!S=')I;F<@=VET
M:"!A('=A<FYI;F<@;65S<V%G92!I9B!T:&4@<&%S<W=O<F0@:7,@86)O=70*
M("`@("`J("`@("`@("`@("`@("`@('1O(&5X<&ER92P@4$5!4E]%<G)O<B!O
M;B!E<G)O<B!A;F0@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C:&5C:U!A<W-W;W)D4W1A='5S*"D*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@I]"@HO*BH*("H@26UP;&5M96YT<R!T:&4@06-C
M;W5N=',@05!)(&9O<B!S97)V97)S('=I=&@@=6YI>"!A8V-O=6YT<R!O;B!T
M:&4@;&]C86QH;W-T"B`J(&UA8VAI;F4@*'-A;64@;6%C:&EN92!A<R!T:&4@
M=V5B('-E<G9E<BDN("!3:&]U;&0@=V]R:R!F;W(@;&]C86P@=6YI>`H@*B!A
M8V-O=6YT<RP@;FES+VYI<RL@86-C;W5N=',L(&]R(&%N>2!004T@;W)I96YT
M960@86-C;W5N=',@=&AA="!A<'!E87(@87,*("H@;&]C86P@86-C;W5N=',@
M;VX@=&AE(&QO8V%L(&UA8VAI;F4N("!4:&4@97AC97!T:6]N(&ES('1H92!Q
M=6]T82!S=7!P;W)T+@H@*B!3964@=&AA="!R;W5T:6YE(&9O<B!A9&1I=&EO
M;F%L(&-O;6UE;G1S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($5R:6,@
M2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N
M961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@17)I8R!2;W-T971T
M97(@/&5R:6,N<F]S='1T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C$*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L
M87-S($%C8V]U;G1S7T1R:79E<E]L;V-A;&AO<W0@97AT96YD<R!!8V-O=6YT
M<U]$<FEV97(@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!8V-O=6YT<U]$<FEV97)?;&]C
M86QH;W-T*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3YP87)A;7,@/2`D<&%R86US.PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/G!A<F%M<ULG<75O=&%?<&%T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<&%R86US6R=Q=6]T85]P871H)UT@/2`G<75O=&$G.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3YP87)A;7-;)V=R97!?<&%T:"==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<&%R86US6R=G<F5P7W!A=&@G72`]("=G
M<F5P)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!U<V5R(&%C8V]U;G0@9G)O;2!T:&4@<&]S:7@@:6YF;W)M871I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@8V]M
M<&QE=&4@86-C;W5N="!D971A:6QS+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T06-C;W5N="@I"B`@("!["B`@("`@("`@<W1A=&EC("1I;F9O<FUA=&EO
M;CL*"B`@("`@("`@:68@*"%I<W-E="@D:6YF;W)M871I;VXI*2!["B`@("`@
M("`@("`@("\O('1H:7,@=V]N)W0@=V]R:R!I9B!W92!D;VXG="!H879E('!O
M<VEX(&5X=&5N<VEO;G,*("`@("`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I
M;VY%>&ES=',H)W!O<VEX)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=7-E<B`](%-T<FEN
M9SHZ;&]W97(H)'1H:7,M/F=E=%5S97)N86UE*"DI.PH@("`@("`@("`@("`D
M:6YF;W)M871I;VX@/2!P;W-I>%]G971P=VYA;2@D=7-E<BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@?0H*("`@("\J
M*@H@("`@("H@26UP;&5M96YT('1H92!1=6]T82!!4$D@9F]R($E-05`@<V5R
M=F5R<R!W:71H(&$@=6YI>"!Q=6]T82!C;VUM86YD+@H@("`@("H@5&AI<R!M
M87D@<F5Q=6ER92!A(&UO9&EF:65D(")Q=6]T82(@8V]M;6%N9"!T:&%T(&%L
M;&]W<R!T:&4@:'1T<&0*("`@("`J('-E<G9E<B!A8V-O=6YT('1O(&=E="!Q
M=6]T87,@9F]R(&]T:&5R('5S97)S+BXN("!)="!R97%U:7)E<R!T:&%T('EO
M=7(*("`@("`J('=E8B!S97)V97(@86YD('5S97(@<V5R=F5R(&)E('1H92!S
M86UE('-E<G9E<B!O<B!A="!L96%S="!H879E('-H87)E9`H@("`@("H@875T
M:&5N=&EC871I;VX@86YD(&9I;&4@<V5R=F5R<R`H92YG+B!V:6$@3DE3+TY&
M4RDN("!!;F0@;&%S="P@:70@*&%S"B`@("`@*B!W<FET=&5N*2!R97%U:7)E
M<R!T:&4@<&]S:7@@<&AP(&5X=&5N<VEO;G,N"B`@("`@*@H@("`@("H@268@
M>6]U<B!Q=6]T82!C;VUM86YD('=R87!S('1H92!O=71P=70@;VYT;R!T=V\@
M;&EN97,L('1H96X@=&AI<R!M;V1U;&4*("`@("`J('=I;&P@;VYL>2!W;W)K
M(&EF('EO=2!H879E(&$@9W)E<"!W:&EC:"!S=7!P;W)T<R!T:&4@+4$@<W=I
M=&-H+"!A;F0@>6]U"B`@("`@*B!A<'!E;F0@86X@+4$Q('-W:71C:"!T;R!Y
M;W5R(&=R97!?<&%T:"`H92YG+B`G+V)I;B]G<F5P("U!,2<I+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!Q=6]T82!H87-H("AB>71E<R!U
M<V5D+"!L:6UI="D@;W(@9F%L<V4@9F]R(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9711=6]T82@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T:6]N
M(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H)&EN
M9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*("`@("`@("`D:&]M961I<B`]
M("1I;F9O<FUA=&EO;ELG9&ER)UT["@H@("`@("`@("\O($EF('=E('=A;G0@
M;6]U;G0@<&]I;G0@=')A;G-L871I;VYS+"!T:&5N('1R86YS;&%T92!T:&4@
M;&]G:6X@9&ER"B`@("`@("`@+R\@;F%M92!T;R!A(&UO=6YT('!O:6YT+B`@
M268@;F]T+"!T:&5N('-I;7!L>2!P87)S92!O=70@=&AE(&1E=FEC90H@("`@
M("`@("\O(&YA;64@9G)O;2!T:&4@;&]G:6X@9&ER96-T;W)Y+"!A;F0@=7-E
M('1H870@:6YS=&5A9"X*("`@("`@("!I9B`H)'1H:7,M/G!A<F%M<ULG=')A
M;G-L871E36]U;G10;VEN="==("8F"B`@("`@("`@("`@(&9I;&5?97AI<W1S
M*"1T:&ES+3YP87)A;7-;)W1R86YS;&%T:6]N5&%B;&4G72DI"B`@("`@("`@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)T9I;&4O1G-T86(N<&AP)SL*
M("`@("`@("`@("`@)'-Y<U1A8B`]($9I;&5?1G-T86(Z.G-I;F=L971O;B@D
M=&AI<RT^<&%R86US6R=T<F%N<VQA=&EO;E1A8FQE)UTI.PH@("`@("`@("`@
M("!D;R!["B`@("`@("`@("`@("`@("1E;G1R>2`]("8D<WES5&%B+3YG971%
M;G1R>49O<E!A=&@H)&AO;65D:7(I.PH@("`@("`@("`@("`@("`D:&]M961I
M<B`](&1I<FYA;64H)&AO;65D:7(I.PH@("`@("`@("`@("`@("!I9B`H)&AO
M;65D:7(@/3T@)RXG('Q\(&5M<'1Y*"1H;VUE9&ER*2D@>PH@("`@("`@("`@
M("`@("`@("`@)&AO;65D:7(@/2`G+R<["B`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!W:&EL92`H:7-?82@D96YT<GDL("=014%27T5R<F]R)RDI
M.PH@("`@("`@("`@("`D;6]U;G10;VEN="`]("1E;G1R>2T^9&5V:6-E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@)&AO;65D:7(@/2!E>'!L;V1E
M*"<O)RP@)&AO;65D:7(I.PH@("`@("`@("`@("1M;W5N=%!O:6YT(#T@)R\G
M("X@)&AO;65D:7);,5T["B`@("`@("`@?0H*("`@("`@("`D8VUD;&EN92`]
M('-P<FEN=&8H)R5S("UU("5S(#(^)C$@?"`E<R`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YP87)A;7-;)W%U;W1A7W!A=&@G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%5S97).86UE
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP87)A;7-;
M)V=R97!?<&%T:"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6]U
M;G10;VEN="D["B`@("`@("`@)&IU;FL@/2!E>&5C*"1C;61L:6YE+"`D<75O
M=&%?9&%T82P@)')E='5R;E]C;V1E*3L*("`@("`@("!I9B`H)')E='5R;E]C
M;V1E(#T](#`@)B8@(65M<'1Y*"1Q=6]T85]D871A6S!=*2D@>PH@("`@("`@
M("`@("\O($EN(&-A<V4@;V8@<75O=&$@;W5T<'5T('=R87!P:6YG(&]N('1W
M;R!L:6YE<RP@=V4@8V]N8V%T('1H90H@("`@("`@("`@("\O('-E8V]N9"!L
M:6YE(&]F(')E<W5L=',L(&EF(&%N>2P@:&5R92X*("`@("`@("`@("!I9B`H
M(65M<'1Y*"1Q=6]T85]D871A6S%=*2D@>PH@("`@("`@("`@("`@("`D<75O
M=&%?9&%T85LP72`N/2`D<75O=&%?9&%T85LQ73L*("`@("`@("`@("!]"B`@
M("`@("`@("`@+R\@3F]W('!A<G-E(&]U="!T:&4@<75O=&$@:6YF;R!A;F0@
M<F5T=7)N(&ET+@H@("`@("`@("`@("1Q=6]T82`]('!R96=?<W!L:70H)R]<
M<RLO)RP@=')I;2@D<75O=&%?9&%T85LP72DI.PH@("`@("`@("`@(')E='5R
M;B!A<G)A>2@G=7-E9"<@/3X@)'%U;W1A6S%=("H@,3`R-"P@)VQI;6ET)R`]
M/B`D<75O=&%;,ET@*B`Q,#(T*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E
M<B=S(&9U;&P@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@=7-E<B=S(&9U;&P@;F%M92`H<W1R:6YG*2P@;W(@9F%L<V4@*&5R<F]R
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G5L;&YA;64H*0H@("`@>PH@
M("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@
M("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*
M("`@("`@("`D9V5C;W-?87)R87D@/2!E>'!L;V1E*"<L)RP@)&EN9F]R;6%T
M:6]N6R=G96-O<R==*3L*("`@("`@("!R971U<FX@)&=E8V]S7V%R<F%Y6S!=
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S(&AO
M;64@*&QO9VEN*2!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5&AE('5S97(G<R!D:7)E8W1O<GD@*'-T<FEN9RDL(&]R(&9A;'-E
M("AE<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$AO;64H*0H@("`@
M>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I
M.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N6R=D:7(G73L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97(G<R!D969A=6QT('-H
M96QL+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@
M<VAE;&P@*'-T<FEN9RDL(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-H96QL*"D*("`@('L*("`@("`@("`D:6YF;W)M871I
M;VX@/2`D=&AI<RT^7V=E=$%C8V]U;G0H*3L*("`@("`@("!I9B`H:7-?82@D
M:6YF;W)M871I;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1I;F9O<FUA=&EO;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1I
M;F9O<FUA=&EO;ELG<VAE;&PG73L*("`@('T*"GT*"B\J*@H@*B!4:&4@;&1A
M<"!C;&%S<R!A='1E;7!T<R!T;R!R971U<FX@=7-E<B!I;F9O<FUA=&EO;B!S
M=&]R960@:6X@86X@;&1A<`H@*B!D:7)E8W1O<GD@<V5R=FEC92X*("H*("H@
M0V]P>7)I9VAT(#(P,#$M,C`P-B!%<FEC(%)O<W1E='1E<B`\97)I8RYR;W-T
M971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@17)I8R!*;VX@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P
M:'ES:6-S+G5T97AA<RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`
M<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@06-C;W5N='-?1')I=F5R
M7VQD87`@97AT96YD<R!!8V-O=6YT<U]$<FEV97(@>PH*("`@("\J*@H@("`@
M("H@4&]I;G1E<B!T;R!T:&4@;&1A<"!C;VYN96-T:6]N+@H@("`@("H*("`@
M("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?9',["@H@("`@
M+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?<&%R86US.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!!
M8V-O=6YT<U]$<FEV97)?;&1A<"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@06-C;W5N='-?
M1')I=F5R7VQD87`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M97)G92@*("`@("`@("`@("`@87)R
M87DH)VAO<W0G(#T^("=L;V-A;&AO<W0G+`H@("`@("`@("`@("`@("`@("`G
M<&]R="<@/3X@,S@Y+`H@("`@("`@("`@("`@("`@("`G8F%S961N)R`]/B`G
M)RP*("`@("`@("`@("`@("`@("`@)V%T='(G(#T^("=U:60G+`H@("`@("`@
M("`@("`@("`@("`G=F5R<VEO;B<@/3X@)S,G*2P*("`@("`@("`@("`@)'!A
M<F%M<RD["B`@("!]"@H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E
M<B!A8V-O=6YT(&9R;VT@=&AE(&QD87`@<V]U<F-E+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($$@:&%S:"!W:71H(&-O;7!L971E(&%C8V]U;G0@
M9&5T86EL<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$%C8V]U;G0H*0H@
M("`@>PH@("`@("`@('-T871I8R`D:6YF;W)M871I;VX["@H@("`@("`@(&EF
M("@A:7-S970H)&EN9F]R;6%T:6]N*2D@>PH@("`@("`@("`@("`D=7-E<FYA
M;64@(#T@)'1H:7,M/F=E=%5S97)N86UE*"D["@H@("`@("`@("`@("`O+R!C
M;VYN96-T('1O('1H92!L9&%P('-E<G9E<@H@("`@("`@("`@("`D=&AI<RT^
M7V1S(#T@;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!O<G0G72D["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]D<RD@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(BDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=F5R<VEO;B==*2D@>PH@("`@("`@("`@("`@("`@:68@*"%L9&%P7W-E=%]O
M<'1I;VXH)'1H:7,M/E]D<RP@3$1!4%]/4%1?4%)/5$]#3TQ?5D524TE/3BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4V5T($Q$05`@<')O=&]C;VP@=F5R
M<VEO;B!T;R`E9"!F86EL960Z(%LE9%T@)7,G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W9E<G-I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&QD87!?97)R;F\H)&-O;FXI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D
M8V]N;BDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@8FEN9"!A<R!A;F]N
M>6UO=7,*("`@("`@("`@("`@)')E<W5L="`]($!L9&%P7V)I;F0H)'1H:7,M
M/E]D<RD["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!'970@=&AE(&9U;&QN86UE"B`@("`@("`@("`@("1S96%R8VA2
M97-U;'0@/2!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D=&AI<RT^7W!A<F%M
M<ULG8F%S961N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T<B==("X@)STG("X@)'5S97)N
M86UE*3L*("`@("`@("`@("`@)&EN9F]R;6%T:6]N(#T@;&1A<%]G971?96YT
M<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H4F5S=6QT*3L*"B`@("`@("`@("`@
M("\O(&1I<V-O;FYE8W0@9G)O;2!T:&4@;&1A<"!S97)V97(*("`@("`@("`@
M("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@("`@("`@("!I9B`H
M)&EN9F]R;6%T:6]N6R=C;W5N="==(#T](#`I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:6YF;W)M871I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!U<V5R)W,@9G5L;"!N86UE+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!U<V5R)W,@9G5L;"!N86UE("AS=')I;F<I+"!O<B!F
M86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&=6QL;F%M
M92@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!
M8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=
M6R=C;CML86YG+65S)UU;,%TI("8F"B`@("`@("`@("`@("1I;F9O<FUA=&EO
M;ELP75LG8VX[;&%N9RUE<R==6S!=("$]("<G*2!["B`@("`@("`@("`@("1N
M86UE(#T@)&EN9F]R;6%T:6]N6S!=6R=C;CML86YG+65S)UU;,%T["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA;64@/2`D:6YF;W)M871I;VY;
M,%U;)V-N)UU;,%T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&5M<'1Y
M*"1N86UE*2`_(&9A;'-E(#H@)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=7-E<B=S(&AO;64@*&QO9VEN*2!D:7)E8W1O<GDN
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!D:7)E
M8W1O<GD@*'-T<FEN9RDL(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$AO;64H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO
M;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I
M;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*("`@("`@("`D:&]M961I<B`]
M("1I;F9O<FUA=&EO;ELP75LG:&]M961I<F5C=&]R>2==6S!=.PH@("`@("`@
M(')E='5R;B`H96UP='DH)&AO;65D:7(I(#\@9F%L<V4@.B`D:&]M961I<BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@9&5F
M875L="!S:&5L;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M=7-E<B=S('-H96QL("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9713:&5L;"@I"B`@("!["B`@("`@("`@)&EN
M9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@
M*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H@("`@("`@("1S
M:&5L;"`]("1I;F9O<FUA=&EO;ELP75LG;&]G:6YS:&5L;"==6S!=.PH@("`@
M("`@(')E='5R;B`H96UP='DH)'-H96QL*2`_(&9A;'-E(#H@)'-H96QL*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1A=&4@;V8@=&AE
M('5S97(G<R!L87-T('!A<W-W;W)D(&-H86YG92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!$871E('-T<FEN9R`H<W1R:6YG*2!O<B!F86QS92`H
M97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087-S=V]R9$-H86YG
M92@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!
M8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=
M6R=S:&%D;W=L87-T8VAA;F=E)UU;,%TI*2!["B`@("`@("`@("`@("1L87-T
M8VAA;F=E(#T@<W1R9G1I;64H)R5X)RP@)&EN9F]R;6%T:6]N6S!=6R=S:&%D
M;W=L87-T8VAA;F=E)UU;,%T@*B`X-C0P,"D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@*&5M<'1Y*"1L87-T8VAA;F=E*2`_(&9A;'-E(#H@)&QA<W1C
M:&%N9V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<W1A
M='5S(&]F('1H92!C=7)R96YT('!A<W-W;W)D+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($$@<W1R:6YG('=I=&@@82!W87)N:6YG(&UE<W-A9V4@
M:68@=&AE('!A<W-W;W)D(&ES(&%B;W5T"B`@("`@*B`@("`@("`@("`@("`@
M("!T;R!E>'!I<F4L(%!%05)?17)R;W(@;VX@97)R;W(@86YD(&9A;'-E(&]T
M:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM087-S=V]R9%-T
M871U<R@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G
M971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I
M;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N
M6S!=6R=S:&%D;W=M87@G75LP72D@)B8*("`@("`@("`@("`@:7-S970H)&EN
M9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%TI("8F"B`@("`@
M("`@("`@(&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W=V%R;FEN9R==
M6S!=*2D@>PH@("`@("`@("`@("`D=&]D87D@/2!F;&]O<BAT:6UE*"D@+R`X
M-C0P,"D["B`@("`@("`@("`@("1W87)N9&%Y(#T@)&EN9F]R;6%T:6]N6S!=
M6R=S:&%D;W=L87-T8VAA;F=E)UU;,%T@*PH@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;6%X)UU;,%T@+2`D:6YF;W)M
M871I;VY;,%U;)W-H861O=W=A<FYI;F<G75LP73L*("`@("`@("`@("`@)'1O
M97AP:7)E(#T@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;
M,%T@*R`D:6YF;W)M871I;VY;,%U;)W-H861O=VUA>"==6S!=("T@)'1O9&%Y
M.PH*("`@("`@("`@("`@:68@*"1T;V1A>2`^/2`D=V%R;F1A>2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H7R@B)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N(BDL("1T;V5X<&ER92D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]G;V]G;&4N<&AP````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,V,3,`,3`U,34T,S$P
M-C``,#(P,3<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@HD8FQO8VM?;F%M92`](%\H(D=O;V=L92!396%R8V@B
M*3L*"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C:R]G;V]G;&4N<&AP
M+'8@,2XQ,"XQ,"XQ(#(P,#4O,3`O,3@@,3$Z,S,Z,SD@:F%N($5X<"`D"B`J
M"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C
M:U](;W)D95]G;V]G;&4@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R
M("1?87!P(#T@)VAO<F1E)SL*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T
M;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("`@5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T
M:71L92@I"B`@("!["B`@("`@("`@<F5T=7)N(%\H(D=O;V=L92!396%R8V@B
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN
M('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4
M:&4@8V]N=&5N=`H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@
M("!["B`@("`@("`@)&AT;6P@(#T@)SQF;W)M(&YA;64](F=O;V=L92(@;VYS
M=6)M:70](F]P96Y?9V]O9VQE7W=I;B@I.R!R971U<FX@9F%L<V4[(CXG.PH@
M("`@("`@("1H=&UL("X]("<\=&%B;&4@=VED=&@](C$P,"4B(&AE:6=H=#TB
M,3`P)2(^)SL*("`@("`@("`D:'1M;"`N/2`G/'1R/CQS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(B!S<F,](B<@+B`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VIA=F%S
M8W)I<'0N<&AP/V9I;&4];W!E;E]G;V]G;&5?=VEN+FIS)F%M<#MA<'`]:&]R
M9&4B/CPO<V-R:7!T/B<["B`@("`@("`@)&AT;6P@+CT@)SQT9#XG("X@2&]R
M9&4Z.FEM9R@G9V]O9VQE+G!N9R<L("=';V]G;&4G*2`N("<\+W1D/CPO='(^
M)SL*("`@("`@("`D:'1M;"`N/2`G/'1R/CQT9#X\:6YP=70@;6%X3&5N9W1H
M/2(R-38B('-I>F4](C0P(B!N86UE/2)Q(B!W:61T:#TB,3`P)2(@+SX\+W1D
M/CPO='(^)SL*("`@("`@("`D:'1M;"`N/2`G/'1R/CQT9#X\=&%B;&4@=VED
M=&@](C$P,"4B/CQT<CX\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4]
M(G)A9&EO(B!N86UE/2)A<F5A(B!V86QU93TB=V5B(B!W:61T:#TB,C`E(B!C
M:&5C:V5D/2)C:&5C:V5D(B`O/B<@+B!?*")796(B*2`N("<\+W1D/B<["B`@
M("`@("`@)&AT;6P@+CT@)SQT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP
M93TB<F%D:6\B(&YA;64](F%R96$B('9A;'5E/2)I;6%G97,B('=I9'1H/2(R
M,"4B("\^)R`N(%\H(DEM86=E<R(I("X@)SPO=&0^)SL*("`@("`@("`D:'1M
M;"`N/2`G/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)R861I;R(@
M;F%M93TB87)E82(@=F%L=64](F=R;W5P<R(@=VED=&@](C(P)2(@+SXG("X@
M7R@B1W)O=7!S(BD@+B`G/"]T9#XG.PH@("`@("`@("1H=&UL("X]("<\=&0@
M86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE/2)A<F5A
M(B!V86QU93TB9&ER96-T;W)Y(B!W:61T:#TB,C`E(B`O/B<@+B!?*")$:7)E
M8W1O<GDB*2`N("<\+W1D/B<["B`@("`@("`@)&AT;6P@+CT@)SQT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB<F%D:6\B(&YA;64](F%R96$B('9A
M;'5E/2)N97=S(B!W:61T:#TB,C`E(B`O/B<@+B!?*").97=S(BD@+B`G/"]T
M9#X\+W1R/CPO=&%B;&4^/"]T9#X\+W1R/B<["B`@("`@("`@)&AT;6P@+CT@
M)SQT<CX\=&0^/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@
M=F%L=64](B<@+B!?*")';V]G;&4@4V5A<F-H(BD@+B`G(B`O/CPO=&0^/"]T
M<CXG.PH@("`@("`@("1H=&UL("X]("<\+W1A8FQE/B<["B`@("`@("`@)&AT
M;6P@+CT@)SPO9F]R;3XG.PH@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O0FQO8VLO<W5N<FES92YP:'``````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-C4U`#$P-3$U-#,Q,#8P`#`R
M,#0Q-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*)&)L;V-K7VYA;64@/2!?*")3=6YR:7-E+U-U;G-E="(I.PH*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+W-U;G)I<V4N<&AP+'8@
M,2XQ-"XQ,"XS(#(P,#4O,3`O,3@@,3$Z,S,Z,SD@:F%N($5X<"`D"B`J"B`J
M($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](
M;W)D95]S=6YR:7-E(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D
M7V%P<"`]("=H;W)D92<["@H@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*
M("`@("`@("!R971U<FX@7R@B4W5N<FES92]3=6YS970B*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@
M87)R87DH)VQO8V%T:6]N)R`]/B!A<G)A>2@G='EP92<@/3X@)VUL96YU;2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VYA;64G(#T^(%\H(DQO8V%T:6]N(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<U,2XU,3<Z
M+3`N,3$W)RDI.PH*("`@("`@("!G;&]B86P@)&-O;W)D:6YA=&5S.PH@("`@
M("`@(&EF("@A:7-?87)R87DH)&-O;W)D:6YA=&5S*2D@>PH@("`@("`@("`@
M("!`:6YC;'5D92`G2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<"<["B`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)&-O;W)D:6YA=&5S*2D@>PH@("`@("`@
M("`@("`@("`@)&-O;W)D:6YA=&5S(#T@87)R87DH*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`D<&%R86US6R=L;V-A=&EO;B==6R=V86QU
M97,G72`]("1C;V]R9&EN871E<SL*"B`@("`@("`@<F5T=7)N("1P87)A;7,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72DI('L*("`@
M("`@("`@("`@<F5T=7)N(%\H(DYO(&QO8V%T:6]N(&ES('-E="XB*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%-E="!T:&4@=&EM97IO;F4@=F%R:6%B;&4L
M(&EF(&%V86EL86)L92X*("`@("`@("!.3%,Z.G-E=%1I;65:;VYE*"D["@H@
M("`@("`@(&QI<W0H)&QA="P@)&QO;F<I(#T@97AP;&]D92@G.B<L("1T:&ES
M+3Y?<&%R86US6R=L;V-A=&EO;B==*3L*("`@("`@("`D<FES92`]("1T:&ES
M+3Y?8V%L8W5L871E4W5N<V5T*'1I;64H*2P@)&QA="P@)&QO;F<L(&9A;'-E
M+"!F;&]O<BAD871E*"=:)RD@+R`S-C`P*2D["B`@("`@("`@)'-E="`]("1T
M:&ES+3Y?8V%L8W5L871E4W5N<V5T*'1I;64H*2P@)&QA="P@)&QO;F<L('1R
M=64L(&9L;V]R*&1A=&4H)UHG*2`O(#,V,#`I*3L*"B`@("`@("`@)&QO8V%T
M:6]N(#T@)R<["B`@("`@("`@9VQO8F%L("1C;V]R9&EN871E<SL*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1C;V]R9&EN871E<RDI('L*("`@("`@("`@("`@
M<F5Q=6ER92`G2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<"<["B`@("`@("`@
M?0H@("`@("`@(&9O<F5A8V@@*"1C;V]R9&EN871E<R!A<R`D8V]U;G1R>2D@
M>PH@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D=&AI<RT^7W!A
M<F%M<ULG;&]C871I;VXG72P@)&-O=6YT<GDI*2!["B`@("`@("`@("`@("`@
M("`D;&]C871I;VX@/2`D8V]U;G1R>5LD=&AI<RT^7W!A<F%M<ULG;&]C871I
M;VXG75T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("<\=&%B;&4@=VED=&@](C$P,"4B
M(&AE:6=H=#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/CQT<CXG("X*("`@("`@
M("`@("`@)SQT9"!C;VQS<&%N/2(R(B!C;&%S<STB8V]N=')O;"(^/'-T<F]N
M9SXG("X@)&QO8V%T:6]N("X@)SPO<W1R;VYG/CPO=&0^/"]T<CX\='(@:&5I
M9VAT/2(Q,#`E(CXG("X*("`@("`@("`@("`@)SQT9"!W:61T:#TB-3`E(B!A
M;&EG;CTB8V5N=&5R(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO
M8VLO<W5N<FES92]S=6YR:7-E+G!N9R<L(%\H(E-U;B!2:7-E(BDI("X*("`@
M("`@("`@("`@)SQB<B`O/B<@+B`D<FES92`N("<\+W1D/B<@+@H@("`@("`@
M("`@("`G/'1D('=I9'1H/2(U,"4B(&%L:6=N/2)C96YT97(B/B<@+@H@("`@
M("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]S=6YR:7-E+W-U;G-E="YP;F<G
M+"!?*")3=6X@4V5T(BDI("X*("`@("`@("`@("`@)SQB<B`O/B<@+B`D<V5T
M("X@)SPO=&0^)R`N("<\+W1R/CPO=&%B;&4^)SL*("`@('T*"B`@("`O*BH*
M("`@("`J(&AT='`Z+R]W=W<N>F5N9"YC;VTO8V]D97@N<&AP/VED/3$S-29S
M:6YG;&4],0H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L8W5L871E4W5N<V5T
M*"1D871E+"`D;&%T:71U9&4L("1L;VYG:71U9&4L("1S=6YS970@/2!T<G5E
M+"`D=&EM97IO;F4I"B`@("!["B`@("`@("`@)'ED87D@/2!D871E*"=Z)RP@
M)&1A=&4I.PH@("`@("`@("1M;VX@/2!D871E*"=N)RP@)&1A=&4I.PH@("`@
M("`@("1M9&%Y(#T@9&%T92@G:B<L("1D871E*3L*("`@("`@("`D>65A<B`]
M(&1A=&4H)UDG+"`D9&%T92D["@H@("`@("`@(&EF("@D=&EM97IO;F4@/3T@
M)S$S)RD@>PH@("`@("`@("`@("`D=&EM97IO;F4@/2`G+3$Q)SL*("`@("`@
M("`@("`@)&UD87DK*SL*("`@("`@("`@("`@)'ED87DK*SL*("`@("`@("!]
M"@H@("`@("`@("1!(#T@,2XU-S`X.PH@("`@("`@("1"(#T@,RXQ-#$U.3L*
M("`@("`@("`D0R`](#0N-S$R,SD["B`@("`@("`@)$0@/2`V+C(X,S$Y.PH@
M("`@("`@("1%(#T@,"XP,3<T-3,S("H@)&QA=&ET=61E.PH@("`@("`@("1&
M(#T@,"XP,3<T-3,S("H@)&QO;F=I='5D93L*("`@("`@("`D1R`](#`N,C8Q
M-SDY("`J("1T:6UE>F]N93L*"B`@("`@("`@+R\@1F]R(&%S=')O;F]M:6-A
M;"!T=VEL:6=H="P@=7-E(%(@/2`M+C,P.3`Q-PH@("`@("`@("\O($9O<B!N
M875T:6-A;"!T=VEL:6=H="P@=7-E(%(@/2`M+C(P-SDQ,@H@("`@("`@("\O
M($9O<B!C:79I;"!T=VEL:6=H="P@=7-E(%(@/2`M+C$P-#4R.`H@("`@("`@
M("\O($9O<B!S=6YR:7-E(&]R('-U;G-E="P@=7-E(%(@/2`M+C`Q-#4T,SD*
M("`@("`@("`D4B`]("TN,#$T-30S.3L*"B`@("`@("`@:68@*"1S=6YS970I
M('L*("`@("`@("`@("`@)$H@/2`D0SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D2B`]("1!.PH@("`@("`@('T*"B`@("`@("`@)$L@/2`D>61A
M>2`K("@H)$H@+2`D1BD@+R`D1"D["B`@("`@("`@)$P@/2`H)$L@*B`N,#$W
M,C`R*2`M("XP-3<T,#,Y.R`@("`@("`@("`@("`@+R\@4V]L87(@365A;B!!
M;F]M;VQY"B`@("`@("`@)$T@/2`D3"`K("XP,S,T-#`U("H@<VEN*"1,*3L@
M("`@("`@("`@("`@("`@+R\@4V]L87(@5')U92!,;VYG:71U9&4*("`@("`@
M("`D32`K/2`T+CDS,C@Y("L@*#,N-#DP-C9%+3`T*2`J('-I;B@R("H@)$PI
M.R`O+R!1=6%D<F%N="!$971E<FUI;F%T:6]N"B`@("`@("`@=VAI;&4@*"1-
M(#P@,"D@>PH@("`@("`@("`@("`D32`]("@D32`K("1$*3L*("`@("`@("!]
M"B`@("`@("`@=VAI;&4@*"1-(#X]("1$*2!["B`@("`@("`@("`@("1-(#T@
M*"1-("T@)$0I.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D32`O("1!*2`M
M(&EN='9A;"@D32`O("1!*2`]/2`P*2!["B`@("`@("`@("`@("1-("L](#0N
M.#0X,31%+3`V.PH@("`@("`@('T*"B`@("`@("`@)%`@/2!S:6XH)$TI("\@
M8V]S*"1-*3L@("`@("`@("`@("`@("`@("`@+R\@4V]L87(@4FEG:'0@07-C
M96YS:6]N"B`@("`@("`@)%`@/2!A=&%N,B@N.3$W-#8@*B`D4"P@,2D["@H@
M("`@("`@("\O(%%U861R86YT($%D:G5S=&UE;G0*("`@("`@("!I9B`H)$T@
M/B`D0RD@>PH@("`@("`@("`@("`D4"`K/2`D1#L*("`@("`@("!](&5L<V5I
M9B`H)$T@/B`D02D@>PH@("`@("`@("`@("`D4"`K/2`D0CL*("`@("`@("!]
M"@H@("`@("`@("11(#T@+C,Y-S@R("H@<VEN*"1-*3L@("`@("`@("`@("`O
M+R!3;VQA<B!$96-L:6YA=&EO;@H@("`@("`@("11(#T@)%$@+R!S<7)T*"TD
M42`J("11("L@,2D[("`@("`O+R!4:&ES(&ES(&AO=R!T:&4@;W)I9VEN86P@
M875T:&]R('=R;W1E(&ET(0H@("`@("`@("11(#T@871A;C(H)%$L(#$I.PH*
M("`@("`@("`D4R`]("12("T@*'-I;B@D42D@*B!S:6XH)$4I*3L*("`@("`@
M("`D4R`]("13("\@*&-O<R@D42D@*B!C;W,H)$4I*3L*"B`@("`@("`@:68@
M*&%B<R@D4RD@/B`Q*2!["B`@("`@("`@("`@(')E='5R;B`G;F]N92<[("`@
M("`@("`@("`@("`@("\O($YU;&P@<&AE;F]M96YO;@H@("`@("`@('T*"B`@
M("`@("`@)%,@/2`D4R`O('-Q<G0H+213("H@)%,@*R`Q*3L*("`@("`@("`D
M4R`]("1!("T@871A;C(H)%,L(#$I.PH*("`@("`@("!I9B`H(21S=6YS970I
M('L*("`@("`@("`@("`@)%,@/2`D1"`M("13(#L*("`@("`@("!]"@H@("`@
M("`@("14(#T@)%,@*R`D4"`M(#`N,#$W,C`R."`J("1+("T@,2XW,S,V-#L@
M+R\@3&]C86P@87!P87)E;G0@=&EM90H@("`@("`@("15(#T@)%0@+2`D1CL@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@56YI=F5R<V%L('1I;65R
M"B`@("`@("`@)%8@/2`D52`K("1'.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!786QL(&-L;V-K('1I;64*"B`@("`@("`@+R\@475A9')A;G0@
M1&5T97)M:6YA=&EO;@H@("`@("`@('=H:6QE("@D5B`\(#`I('L*("`@("`@
M("`@("`@)%8@/2`H)%8@*R`D1"D["B`@("`@("`@?0H@("`@("`@('=H:6QE
M("@D5B`^/2`D1"D@>PH@("`@("`@("`@("`D5B`]("@D5B`M("1$*3L*("`@
M("`@("!]"B`@("`@("`@)%8@/2`D5B`J(#,N.#$Y-S(["@H@("`@("`@("1H
M;W5R(#T@:6YT=F%L*"16*3L*("`@("`@("`D5B`@("T]("1H;W5R.PH@("`@
M("`@("1M:6X@(#T@:6YT=F%L*"16("H@-C`I.PH@("`@("`@("16("`@+3T@
M)&UI;B`O(#8P.PH@("`@("`@("1S96,@(#T@:6YT=F%L*"16("H@,S8P,"D[
M"@H@("`@("`@(')E='5R;B!S=')F=&EM92@G)5@G+"!M:W1I;64H)&AO=7(L
M("1M:6XL("1S96,L("1M;VXL("1M9&%Y+"`D>65A<BDI.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+VUO;VXN<&AP````````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S`R-0`Q,#4Q-30S
M,3`V,``P,3<V-S(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B36]O;B!0:&%S97,B
M*3L*"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C:R]M;V]N+G!H<"QV
M(#$N,38N,3`N-"`R,#`U+S$P+S$X(#$Q.C,S.C,Y(&IA;B!%>'`@)`H@*@H@
M*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?
M2&]R9&5?;6]O;B!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A
M<'`@/2`G:&]R9&4G.PH*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@
M("`@("`@<F5T=7)N(%\H(DUO;VX@4&AA<V5S(BD["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@
M("`@("`@("`@("`G<&AA<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M)VYA;64G(#T^(%\H(E=H:6-H('!H87-E<R(I+`H@("`@("`@("`@("`@("`@
M)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B`G8W5R<F5N="<L"B`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A
M>2@G8W5R<F5N="<@/3X@7R@B0W5R<F5N="`T(%!H87-E<R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYE>'0G(#T^(%\H(DYE>'0@
M-"!0:&%S97,B*2DI+`H@("`@("`@("`@("`G:&5M:7-P:&5R92<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B2&5M:7-P:&5R92(I
M+`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`G;F]R=&AE<FXG+`H@("`@("`@("`@("`@
M("`@)W9A;'5E<R<@/3X@87)R87DH)VYO<G1H97)N)R`]/B!?*").;W)T:&5R
M;B!(96UI<W!H97)E(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<V]U=&AE<FXG(#T^(%\H(E-O=71H97)N($AE;6ES<&AE<F4B*2DI
M+`H@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C;VYT96YT
M*"D*("`@('L*("`@("`@("`D<&AA<V5S(#T@)'1H:7,M/E]C86QC=6QA=&5-
M;V]N4&AA<V5S*&1A=&4H)UDG*2D["B`@("`@("`@)&YO=R`]('1I;64H*3L*
M"B`@("`@("`@)&QA<W1.97<@/2`P.PH@("`@("`@("1L87-T3F5W4W1A;7`@
M/2`P.PH@("`@("`@("1O9F9S970@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1P
M:&%S97,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF("@D:V5Y
M(#P@)&YO=R`F)B`D:V5Y(#X@)&QA<W1.97=3=&%M<"`F)B`D=F%L(#T](%\H
M(DYE=R!-;V]N(BDI('L*("`@("`@("`@("`@("`@("1L87-T3F5W(#T@)&]F
M9G-E=#L*("`@("`@("`@("`@("`@("1L87-T3F5W4W1A;7`@/2`D:V5Y.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1O9F9S970K*SL*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG<&AA<V4G72D@
M)B8@)'1H:7,M/E]P87)A;7-;)W!H87-E)UT@/3T@)VYE>'0G*2!["B`@("`@
M("`@("`@("1D871E<R`](&%R<F%Y7W-L:6-E*&%R<F%Y7VME>7,H)'!H87-E
M<RDL("1L87-T3F5W("L@-"P@-"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&1A=&5S(#T@87)R87E?<VQI8V4H87)R87E?:V5Y<R@D<&AA<V5S
M*2P@)&QA<W1.97<L(#0I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=H96UI<W!H97)E)UTI("8F("1T:&ES+3Y?<&%R
M86US6R=H96UI<W!H97)E)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@("`@("`@
M("`D;&]C871I;VX@/2!?*").;W)T:&5R;B!(96UI<W!H97)E(BD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&QO8V%T:6]N(#T@7R@B4V]U=&AE
M<FX@2&5M:7-P:&5R92(I.PH@("`@("`@('T*"B`@("`@("`@)&AT;6P@/2`G
M/'1A8FQE('=I9'1H/2(Q,#`E(B!H96EG:'0](C$P,"4B(&-E;&QS<&%C:6YG
M/2(P(CXG("X*("`@("`@("`@("`@)SQT<CX\=&0@8V]L<W!A;CTB-"(@8VQA
M<W,](F-O;G1R;VPB/CQS=')O;F<^)R`N("1L;V-A=&EO;B`N("<\+W-T<F]N
M9SX\+W1D/CPO='(^)R`N"B`@("`@("`@("`@("<\='(@:&5I9VAT/2(Q,#`E
M(CX\=&0@=VED=&@](C(U)2(@86QI9VX](F-E;G1E<B(^)R`N"B`@("`@("`@
M("`@($AO<F1E.CII;6<H)V)L;V-K+VUO;VXO;F5W;6]O;BYP;F<G+"!?*").
M97<@36]O;B(I*2`N"B`@("`@("`@("`@("<\8G(@+SXG("X@<W1R9G1I;64H
M)R5D("5B)RP@)&1A=&5S6S!=*2`N"B`@("`@("`@("`@("<\+W1D/B<["@H@
M("`@("`@("1H=&UL("X]("<\=&0@=VED=&@](C(U)2(@86QI9VX](F-E;G1E
M<B(^)SL*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)VAE;6ES
M<&AE<F4G72D@)B8@)'1H:7,M/E]P87)A;7-;)VAE;6ES<&AE<F4G72`]/2`G
M;F]R=&AE<FXG*2!["B`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CII;6<H
M)V)L;V-K+VUO;VXO;&%S='%U87)T97(N<&YG)RP@7R@B1FER<W0@475A<G1E
M<B(I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:'1M;"`N/2!(
M;W)D93HZ:6UG*"=B;&]C:R]M;V]N+V9I<G-T<75A<G1E<BYP;F<G+"!?*")&
M:7)S="!1=6%R=&5R(BDI.PH@("`@("`@('T*("`@("`@("`D:'1M;"`N/2`G
M/&)R("\^)R`N('-T<F9T:6UE*"<E9"`E8B<L("1D871E<ULQ72D@+B`G/"]T
M9#XG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D('=I9'1H/2(R-24B(&%L:6=N
M/2)C96YT97(B/B<@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]M
M;V]N+V9U;&QM;V]N+G!N9R<L(%\H(D9U;&P@36]O;B(I*2`N"B`@("`@("`@
M("`@("<\8G(@+SXG("X@<W1R9G1I;64H)R5D("5B)RP@)&1A=&5S6S)=*2`N
M("<\+W1D/B<["@H@("`@("`@("1H=&UL("X]("<\=&0@=VED=&@](C(U)2(@
M86QI9VX](F-E;G1E<B(^)SL*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M87)A;7-;)VAE;6ES<&AE<F4G72D@)B8@)'1H:7,M/E]P87)A;7-;)VAE;6ES
M<&AE<F4G72`]/2`G;F]R=&AE<FXG*2!["B`@("`@("`@("`@("1H=&UL("X]
M($AO<F1E.CII;6<H)V)L;V-K+VUO;VXO9FER<W1Q=6%R=&5R+G!N9R<L(%\H
M(DQA<W0@475A<G1E<B(I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D:'1M;"`N/2!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VQA<W1Q=6%R=&5R
M+G!N9R<L(%\H(DQA<W0@475A<G1E<B(I*3L*("`@("`@("!]"B`@("`@("`@
M)&AT;6P@+CT@)SQB<B`O/B<@+B!S=')F=&EM92@G)60@)6(G+"`D9&%T97-;
M,UTI("X@)SPO=&0^/"]T<CX\+W1A8FQE/B<["@H@("`@("`@(')E='5R;B`D
M:'1M;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@
M=VET:"!A;&P@=&AE('!H87-E<R!O9B!T:&4@;6]O;B!F;W(@82!W:&]L90H@
M("`@("H@>65A<BX*("`@("`J"B`@("`@*B!"87-E9"!O;B!C;V1E(&9R;VT*
M("`@("`J(&AT='`Z+R]W=W<N>F5N9"YC;VTO8V]D97@N<&AP/VED/3@S,"9S
M:6YG;&4],2!B>2!!<F4@4&5D97)S96XN"B`@("`@*@H@("`@("H@0V]N=F5R
M=&5D(&9R;VT@0F%S:6,@8GD@4F]G97(@5RX@4VEN;F]T+"!3:WD@)B!496QE
M<V-O<&4L($UA<F-H(#$Y.#4N"B`@("`@*B!#;VYV97)T960@9G)O;2!J879A
M<V-R:7!T(&)Y($%R92!0961E<G-E;B`R,#`R"B`@("`@*B!*879A<V-R:7!T
M(&9O=6YD(&%T(&AT='`Z+R]W=W<N<W1E;&QA9F%N92YC;VTO;6]O;E]P:&%S
M92]M;V]N7W!H87-E+FAT;0H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("`@)'EE87(@("!4:&4@9F]U<B!D:6=I="!Y96%R('1O(')E='5R;B!T:&4@
M;6]O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('!H87-E<R!F
M;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@("!4:&4@;6]O;B!P
M:&%S97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C86QC=6QA=&5-;V]N4&AA
M<V5S*"19*0H@("`@>PH@("`@("`@("12,2`](#,N,30Q-3DR-C4@+R`Q.#`[
M"B`@("`@("`@)%4@(#T@9F%L<V4["B`@("`@("`@)$LP(#T@:6YT=F%L*"@D
M62`M(#$Y,#`I("H@,3(N,S8X-2D["B`@("`@("`@)%0@(#T@*"19("T@,3@Y
M.2XU*2`O(#$P,#L*("`@("`@("`D5#(@/2`D5"`J("14.PH@("`@("`@("14
M,R`]("14("H@)%0@*B`D5#L*("`@("`@("`D2C`@/2`R-#$U,#(P("L@,CD@
M*B`D2S`["B`@("`@("`@)$8P(#T@,"XP,#`Q,3<X("H@)%0R("T@,"XP,#`P
M,#`Q-34@*B`D5#,["B`@("`@("`@)$8P("L]("@P+C<U.3,S("L@,"XU,S`U
M.#@V."HD2S`I.PH@("`@("`@("1&,"`M/2`H,"XP,#`X,S<@*B`D5"`K(#`N
M,#`P,S,U("H@)%0R*3L*("`@("`@("`D33`@(#T@)$LP("H@,"XP.#`X-#@R
M,3$S,SL*("`@("`@("`D33`@(#T@,S8P("H@*"1-,"`M(&EN='9A;"@D33`I
M*2`K(#,U.2XR,C0R.PH@("`@("`@("1-,"`M/2`P+C`P,#`S,S,@*B`D5#([
M"B`@("`@("`@)$TP("T](#`N,#`P,#`S-#<@*B`D5#,["B`@("`@("`@)$TQ
M("`]("1+,"`J(#`N,#<Q-S$S-C8Q,C@["B`@("`@("`@)$TQ("`](#,V,"`J
M("@D33$@+2!I;G1V86PH)$TQ*2D@*R`S,#8N,#(U,SL*("`@("`@("`D33$@
M*ST@,"XP,3`W,S`V("H@)%0R.PH@("`@("`@("1-,2`K/2`P+C`P,#`Q,C,V
M("H@)%0S.PH@("`@("`@("1",2`@/2`D2S`@*B`P+C`X-3$Y-3@U,3(X.PH@
M("`@("`@("1",2`@/2`S-C`@*B`H)$(Q("T@:6YT=F%L*"1",2DI("L@,C$N
M,CDV-#L*("`@("`@("`D0C$@+3T@,"XP,#$V-3(X("H@)%0R.PH@("`@("`@
M("1",2`M/2`P+C`P,#`P,C,Y("H@)%0S.PH@("`@("`@(&9O<B`H)$LY(#T@
M,#L@)$LY(#P](#(X.R`D2SD@/2`D2SD@*R`P+C4I('L*("`@("`@("`@("`@
M)$H@/2`D2C`@*R`Q-"`J("1+.3L*("`@("`@("`@("`@)$8@/2`D1C`@*R`P
M+C<V-3(Y-"`J("1+.3L*("`@("`@("`@("`@)$L@/2`D2SD@+R`R.PH@("`@
M("`@("`@("`D334@/2`H)$TP("L@)$L@*B`R.2XQ,#4S-38P."D@*B`D4C$[
M"B`@("`@("`@("`@("1--B`]("@D33$@*R`D2R`J(#,X-2XX,38Y,3@P-BD@
M*B`D4C$["B`@("`@("`@("`@("1"-B`]("@D0C$@*R`D2R`J(#,Y,"XV-S`U
M,#8T-BD@*B`D4C$["B`@("`@("`@("`@("1&("T](#`N-#`V."`J('-I;B@D
M338I.PH@("`@("`@("`@("`D1B`K/2`H,"XQ-S,T("T@,"XP,#`S.3,@*B`D
M5"D@*B!S:6XH)$TU*3L*("`@("`@("`@("`@)$8@*ST@,"XP,38Q("H@<VEN
M*#(@*B`D338I.PH@("`@("`@("`@("`D1B`K/2`P+C`Q,#0@*B!S:6XH,B`J
M("1"-BD["B`@("`@("`@("`@("1&("T](#`N,#`W-"`J('-I;B@D334@+2`D
M338I.PH@("`@("`@("`@("`D1B`M/2`P+C`P-3$@*B!S:6XH)$TU("L@)$TV
M*3L*("`@("`@("`@("`@)$8@*ST@,"XP,#(Q("H@<VEN*#(@*B`D334I.PH@
M("`@("`@("`@("`D1B`K/2`P+C`P,3`@*B!S:6XH,B`J("1"-B`M("1--BD[
M"@H@("`@("`@("`@("`O*B!!9&0@,2\R(&UI;G5T92!F;W(@<')O<&5R(')O
M=6YD:6YG('1O(&UI;G5T97,@<&5R(%-K>2`F"B`@("`@("`@("`@("`J(%1E
M;"!A<G1I8VQE+B`J+PH@("`@("`@("`@("`D1B`K/2`P+C4@+R`Q-#0P.PH@
M("`@("`@("`@("`D2B`K/2!I;G1V86PH)$8I.PH@("`@("`@("`@("`D1B`M
M/2!I;G1V86PH)$8I.PH*("`@("`@("`@("`@+RH@0V]N=F5R="!F<F]M($I$
M('1O($-A;&5N9&%R($1A=&4N("HO"B`@("`@("`@("`@("1J=6QI86X@/2`D
M2B`K(')O=6YD*"1&*3L*("`@("`@("`@("`@)'!A<G1S("`](&5X<&QO9&4H
M)R\G+"`D=&AI<RT^7VID=&]G<F5G;W)I86XH)&IU;&EA;BDI.PH@("`@("`@
M("`@("`D<W1A;7`@(#T@9VUM:W1I;64H,"P@,"P@,"P@)'!A<G1S6S!=+"`D
M<&%R='-;,5TL("1P87)T<ULR72D["@H@("`@("`@("`@("`O*B!H86QF($LN
M("HO"B`@("`@("`@("`@(&EF("@H)$LY("T@9FQO;W(H)$LY*2D@/B`P*2![
M"B`@("`@("`@("`@("`@("!I9B`H)%4I('L*("`@("`@("`@("`@("`@("`@
M("`O*B!.97<@:&%L9BX@*B\*("`@("`@("`@("`@("`@("`@("`D<&AA<V5S
M6R1S=&%M<%T@/2!?*")&:7)S="!(86QF(BD["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($9U;&P@:&%L9BX@*B\*
M("`@("`@("`@("`@("`@("`@("`D<&AA<V5S6R1S=&%M<%T@/2!?*"),87-T
M($AA;&8B*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("\J(&9U;&P@2RX@*B\*("`@("`@("`@("`@
M("`@(&EF("@A)%4I('L*("`@("`@("`@("`@("`@("`@("`D<&AA<V5S6R1S
M=&%M<%T@/2!?*").97<@36]O;B(I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D<&AA<V5S6R1S=&%M<%T@/2!?*")&
M=6QL($UO;VXB*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("15(#T@(215.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'!H87-E<SL*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I
M9B!T:&4@:F1T;V=R96=O<FEA;B!F=6YC=&EO;B!E>&ES=',L(&%N9"!I9B!N
M;W0*("`@("`J(&-A;&-U;&%T97,@=&AE(&=R96=O<FEA;B!D871E(&UA;G5A
M;&QY+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&IU;&EA;B!4:&4@:G5L
M:6%N(&1A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!M+V0O60H@
M("`@("HO"B`@("!F=6YC=&EO;B!?:F1T;V=R96=O<FEA;B@D:G5L:6%N*0H@
M("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)VID=&]G<F5G;W)I
M86XG*2D@>PH@("`@("`@("`@("!R971U<FX@:F1T;V=R96=O<FEA;B@D:G5L
M:6%N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!&<F]M(&AT
M='`Z+R]P:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYJ9'1O9W)E9V]R:6%N
M+G!H<`H@("`@("`@("`@("`D:G5L:6%N(#T@)&IU;&EA;B`M(#$W,C$Q,3D[
M"B`@("`@("`@("`@("1C86QC,2`](#0@*B`D:G5L:6%N("T@,3L*("`@("`@
M("`@("`@)'EE87(@/2!F;&]O<B@D8V%L8S$@+R`Q-#8P.3<I.PH@("`@("`@
M("`@("`D:G5L:6%N(#T@9FQO;W(H)&-A;&,Q("T@,30V,#DW("H@)'EE87(I
M.PH@("`@("`@("`@("`D9&%Y(#T@9FQO;W(H)&IU;&EA;B`O(#0I.PH@("`@
M("`@("`@("`D8V%L8S(@/2`T("H@)&1A>2`K(#,["B`@("`@("`@("`@("1J
M=6QI86X@/2!F;&]O<B@D8V%L8S(@+R`Q-#8Q*3L*("`@("`@("`@("`@)&1A
M>2`]("1C86QC,B`M(#$T-C$@*B`D:G5L:6%N.PH@("`@("`@("`@("`D9&%Y
M(#T@9FQO;W(H*"1D87D@*R`T*2`O(#0I.PH@("`@("`@("`@("`D8V%L8S,@
M/2`U("H@)&1A>2`M(#,["B`@("`@("`@("`@("1M;VYT:"`](&9L;V]R*"1C
M86QC,R`O(#$U,RD["B`@("`@("`@("`@("1D87D@/2`D8V%L8S,@+2`Q-3,@
M*B`D;6]N=&@["B`@("`@("`@("`@("1D87D@/2!F;&]O<B@H)&1A>2`K(#4I
M("\@-2D["B`@("`@("`@("`@("1Y96%R(#T@,3`P("H@)'EE87(@*R`D:G5L
M:6%N.PH*("`@("`@("`@("`@:68@*"1M;VYT:"`\(#$P*2!["B`@("`@("`@
M("`@("`@("`D;6]N=&@@/2`D;6]N=&@@*R`S.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&UO;G1H(#T@)&UO;G1H("T@.3L*("`@
M("`@("`@("`@("`@("1Y96%R(#T@)'EE87(@*R`Q.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B`B)&UO;G1H+R1D87DO)'EE87(B.PH@("`@
M("`@('T*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C
M:R]F;W)T=6YE+G!H<```````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3$Q,3<`,3`U,34T,S$P-C``,#(P-#`P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@HD8FQO8VM?;F%M
M92`](%\H(E)A;F1O;2!&;W)T=6YE(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D
M92]L:6(O0FQO8VLO9F]R='5N92YP:'`L=B`Q+C$T+C$P+C(@,C`P-2\Q,"\Q
M."`Q,3HS,SHS.2!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO
M8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7V9O<G1U;F4@97AT96YD
M<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*"B`@
M("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE('1I=&QE('1E>'0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@("`@
M<F5T=7)N(%\H(D9O<G1U;F4B*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R
M86US*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("1D
M97-C<FEP=&EO;G,@/2!A<G)A>2@G87)T)R`]/B!?*")!<G0B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V%S8VEI+6%R="<@/3X@7R@B07-C
M:6D@07)T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B;V9H
M+65X8W5S97,G(#T^(%\H(D)/1D@@17AC=7-E<R(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8V]M<'5T97)S)R`]/B!?*")#;VUP=71E<G,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;VMI92<@/3X@
M7R@B0V]O:VEE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M969I;FET:6]N<R<@/3X@7R@B1&5F:6YI=&EO;G,B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1R=6=S)R`]/B!?*")$<G5G<R(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G961U8V%T:6]N)R`]/B!?*")%
M9'5C871I;VXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5T
M:&YI8R<@/3X@7R@B171H;FEC(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=F;V]D)R`]/B!?*")&;V]D(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=F;W)T=6YE<R<@/3X@7R@B1F]R='5N97,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<G1U;F5S,B<@/3X@7R@B
M1F]R='5N97,@,B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9V]E9&5L)R`]/B!?*")';V5D96PB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAU;6]R:7-T<R<@/3X@7R@B2'5M;W)I<W1S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=K97)N96QN97=B:65S)R`]/B!?
M*")+97)N96P@3F5W8FEE<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:VED<R<@/3X@7R@B2VED<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;&%W)R`]/B!?*"),87<B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VQI;65R:6-K)R`]/B!?*"),:6UE<FEC:R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&EN=7AC;V]K:64G(#T^
M(%\H(DQI;G5X($-O;VMI92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;&ET97)A='5R92<@/3X@7R@B3&ET97)A='5R92(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;&]V92<@/3X@7R@B3&]V92(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6%G:6,G(#T^(%\H(DUA
M9VEC(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M961I8VEN
M92<@/3X@7R@B365D:6-I;F4B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VUI<V-E;&QA;F5O=7,G(#T^(%\H(DUI<V-E;&QA;F5O=7,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYE=W,G(#T^(%\H(DYE
M=W,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]S9F]R='5N
M92<@/3X@7R@B3W!E<F%T:6YG(%-Y<W1E;2(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<&5O<&QE)R`]/B!?*")096]P;&4B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W!E=',G(#T^(%\H(E!E=',B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!L871I='5D97,G(#T^
M(%\H(E!L871I='5D97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W!O;&ET:6-S)R`]/B!?*")0;VQI=&EC<R(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<FED9&QE<R<@/3X@7R@B4FED9&QE<R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V-I96YC92<@/3X@7R@B
M4V-I96YC92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V]N
M9W,M<&]E;7,G(#T^(%\H(E-O;F=S("8@4&]E;7,B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-P;W)T<R<@/3X@7R@B4W!O<G1S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%R=')E:R<@/3X@7R@B
M4W1A<B!4<F5K(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M<F%N<VQA=&4M;64G(#T^(%\H(E1R86YS;&%T:6]N<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=VES9&]M)R`]/B!?*")7:7-D;VTB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=O<FLG(#T^(%\H(E=O
M<FLB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WII<'!Y)R`]
M/B!?*")::7!P>2(I*3L*"B`@("`@("`@)'9A;'5E<R`](&YU;&P["B`@("`@
M("`@:68@*&ES<V5T*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T:"==*2`F
M)@H@("`@("`@("`@("!I<U]E>&5C=71A8FQE*"1C;VYF6R=F;W)T=6YE)UU;
M)V5X96-?<&%T:"==*2D@>PH@("`@("`@("`@("!E>&5C*"1C;VYF6R=F;W)T
M=6YE)UU;)V5X96-?<&%T:"==("X@)R`M9B`R/B8Q)RP@)&]U='!U="P@)'-T
M871U<RD["B`@("`@("`@("`@(&EF("@A)'-T871U<RD@>PH@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#$[("1I(#P@8V]U;G0H)&]U='!U="D[("1I*RLI
M('L*("`@("`@("`@("`@("`@("`@("`D9F]R='5N92`]('-U8G-T<B@D;W5T
M<'5T6R1I72P@<W1R<G!O<R@D;W5T<'5T6R1I72P@)R`G*2`K(#$I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5S8W)I<'1I;VYS6R1F;W)T
M=6YE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<ULD9F]R
M='5N95T@/2`D9&5S8W)I<'1I;VYS6R1F;W)T=6YE73L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L
M=65S6R1F;W)T=6YE72`]("1F;W)T=6YE.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!I9B`H:7-?;G5L;"@D=F%L=65S*2D@>PH@("`@("`@("`@("`D
M=F%L=65S(#T@)&1E<V-R:7!T:6]N<SL*("`@("`@("!]"B`@("`@("`@87-O
M<G0H)'9A;'5E<RD["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E*&%R
M<F%Y*"<G(#T^(%\H(D%L;"(I*2P@)'9A;'5E<RD["@H@("`@("`@(')E='5R
M;B!A<G)A>2@*("`@("`@("`@("`@)V]F9F5N9"<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@
M)VYA;64G(#T^(%\H(D]F9F5N<V4@9FEL=&5R(BDL"B`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@)R<L"B`@("`@("`@("`@("`@("`G=F%L=65S)R`]
M/B!A<G)A>2@G)R`]/B!?*").;R!O9F9E;G-I=F4@9F]R='5N97,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R`M;R<@/3X@7R@B3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R`M82<@/3X@7R@B0F]T:"(I*2DL"B`@("`@("`@("`@
M("=F;W)T=6YE)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=T>7!E)R`]
M/B`G;75L=&EE;G5M)RP*("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")&
M;W)T=6YE('1Y<&4B*2P*("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B!A
M<G)A>2@G)RDL"B`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B`D=F%L=65S
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*&ES<V5T
M*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T:"==*2`F)@H@("`@("`@("`@
M("!I<U]E>&5C=71A8FQE*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T:"==
M*2D@>PH@("`@("`@("`@("`D8VUD3&EN92`]("1C;VYF6R=F;W)T=6YE)UU;
M)V5X96-?<&%T:"==.PH@("`@("`@("`@("`D8VUD3&EN92`N/2`D=&AI<RT^
M7W!A<F%M<ULG;V9F96YD)UT["B`@("`@("`@("`@("1C;61,:6YE("X]("<@
M)R`N(&EM<&QO9&4H)R`G+"`D=&AI<RT^7W!A<F%M<ULG9F]R='5N92==*3L*
M("`@("`@("`@("`@<F5T=7)N(&YL,F)R*&AT;6QS<&5C:6%L8VAA<G,H<VAE
M;&Q?97AE8R@D8VUD3&EN92DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<```````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-C4T`#$P-3$U-#,Q,#8P`#`R,S,T,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@4&]S<VEB;&4@<W1R:6YG<R!F<F]M('=E871H97(N8V]M+"!J=7-T('1O
M(&AA=F4@=&AE;2!I;B!T:&4@<V]U<F-E(&9O<@H@*B!L;V-A;&EZ871I;VX@
M<F5A<V]N<RX*("H*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<"QV(#$N,2XR+C8@,C`P-B\P-2\P,R`Q-SHP
M-SHR-R!J86X@17AP("0*("HO"@I?*")!32!#;&]U9',B*3L*7R@B04T@3&EG
M:'0@4F%I;B(I.PI?*")!32!,:6=H="!3;F]W(BD["E\H(D%-(%)A:6XB*3L*
M7R@B04T@4VAO=V5R<R(I.PI?*")!32!3;F]W(%-H;W=E<G,B*3L*7R@B0VQE
M87(B*3L*7R@B0VQE87)I;F<@3&%T92(I.PI?*")#;&]U9',@16%R;'DB*3L*
M7R@B0VQO=61Y(BD["E\H(D9A:7(B*3L*7R@B1F5W(%-H;W=E<G,B*3L*7R@B
M1F5W(%-N;W<@4VAO=V5R<R(I.PI?*")&;V<B*3L*7R@B1G)E97II;F<@1')I
M>GIL92(I.PI?*")(87IE(BD["E\H(DAE879Y(%0M4W1O<FTB*3L*7R@B27-O
M;&%T960@5"U3=&]R;7,B*3L*7R@B3&EG:'0@1')I>GIL92(I.PI?*"),:6=H
M="!286EN(BD["E\H(DQI9VAT(%)A:6X@16%R;'DB*3L*7R@B3&EG:'0@4F%I
M;B!,871E(BD["E\H(DQI9VAT(%)A:6X@4VAO=V5R(BD["E\H(DQI9VAT(%)A
M:6X@=VET:"!4:'5N9&5R(BD["E\H(DQI9VAT(%-N;W<B*3L*7R@B3&EG:'0@
M4VYO=R!3:&]W97(B*3L*7R@B36]S=&QY($-L96%R(BD["E\H(DUO<W1L>2!#
M;&]U9'DB*3L*7R@B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB*3L*7R@B36]S
M=&QY(%-U;FYY(BD["E\H(E!A<G1L>2!#;&]U9'DB*3L*7R@B4$T@3&EG:'0@
M4F%I;B(I.PI?*")032!286EN(BD["E\H(E!-(%-H;W=E<G,B*3L*7R@B4$T@
M4VYO=R(I.PI?*")032!3;F]W(%-H;W=E<G,B*3L*7R@B4$T@4W5N(BD["E\H
M(E!-(%0M4W1O<FUS(BD["E\H(E)A:6XB*3L*7R@B4F%I;B!%87)L>2(I.PI?
M*")286EN($QA=&4B*3L*7R@B4F%I;B!3:&]W97(B*3L*7R@B4F%I;B!A;F0@
M4VYO=R(I.PI?*")286EN('1O(%-N;W<B*3L*7R@B4V-A='1E<F5D(%0M4W1O
M<FUS(BD["E\H(E-H;W=E<G,B*3L*7R@B4VAO=V5R<R!%87)L>2(I.PI?*")3
M:&]W97)S($QA=&4B*3L*7R@B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB*3L*
M7R@B4VYO=R(I.PI?*")3;F]W(%-H;W=E<B(I.PI?*")3;F]W(%-H;W=E<G,B
M*3L*7R@B4VYO=R!3:&]W97)S($5A<FQY(BD["E\H(E-N;W<@4VAO=V5R<R!,
M871E(BD["E\H(E-U;FYY(BD["E\H(E0M4W1O<FTB*3L*7R@B5"U3=&]R;2!A
M;F0@5VEN9'DB*3L*7R@B5"U3=&]R;7,B*3L*7R@B5"U3=&]R;7,@16%R;'DB
M*3L*7R@B5&AU;F1E<B(I.PI?*")7:6YD(BD["E\H(E=I;F0@16%R;'DB*3L*
M7R@B3&]W(BD["E\H(DUO9&5R871E(BD["E\H(DAI9V@B*3L*7R@B5F5R>2!(
M:6=H(BD["E\H(F9A;&QI;F<B*3L*7R@B<W1E861Y(BD["E\H(G)I<VEN9R(I
M.PH`````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]I9G)A;64N<&AP````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0Q,3``,3`U
M,34T,S$P-C``,#(P,34T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@HD8FQO8VM?;F%M92`](%\H(E9I97<@86X@
M97AT97)N86P@=V5B('!A9V4B*3L*"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+VQI
M8B]";&]C:R]I9G)A;64N<&AP+'8@,2XQ."XX+C0@,C`P-B\P,B\R,2`Q,#HU
M,SHT-2!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO
M"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7VEF<F%M92!E>'1E;F1S($AO<F1E
M7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:&]R9&4G.PH*("`@(&9U;F-T
M:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G:69R
M86UE)R`]/B!A<G)A>2@G='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B55),(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A
M=6QT)R`]/B`G)RDL"B`@("`@("`@("`@("`@("`@("`@("=T:71L92<@(#T^
M(&%R<F%Y*"=T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")4:71L92(I*2P*("`@
M("`@("`@("`@("`@("`@("`@)VAE:6=H="<@/3X@87)R87DH)W1Y<&4G(#T^
M("=I;G0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F%M92<@/3X@7R@B2&5I9VAT(BDI*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("`@5&AE('1I=&QE('1E>'0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@("`@9VQO8F%L("1R
M96=I<W1R>3L*"B`@("`@("`@)'1I=&QE(#T@:7-S970H)'1H:7,M/E]P87)A
M;7-;)W1I=&QE)UTI"B`@("`@("`@("`@(#\@)'1H:7,M/E]P87)A;7-;)W1I
M=&QE)UT*("`@("`@("`@("`@.B`D=&AI<RT^7W!A<F%M<ULG:69R86UE)UT[
M"@H@("`@("`@("1H=&UL(#T@2&]R9&4Z.FQI;FLH)'1H:7,M/E]P87)A;7-;
M)VEF<F%M92==*2`N("1T:71L92`N"B`@("`@("`@("`@("<\+V$^(#HZ(#QS
M;6%L;#XG("X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH)'1H:7,M/E]P87)A
M;7-;)VEF<F%M92==+"`G)RP@)R<L("=?8FQA;FLG*2`N"B`@("`@("`@("`@
M($AO<F1E.CII;6<H)W=E8G-I=&4N<&YG)RP@7R@B3W!E;B!I;B!A(&YE=R!W
M:6YD;W<B*2D@+B`G("<@+@H@("`@("`@("`@("!?*")/<&5N(&EN(&$@;F5W
M('=I;F1O=R(I("X@)SPO83X\+W-M86QL/B<["@H@("`@("`@(')E='5R;B`D
M:'1M;#L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O
M(&EN('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M("!4:&4@8V]N=&5N=`H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1B<F]W<V5R.PH*("`@("`@("!I9B`H
M(21B<F]W<V5R+3YH87-&96%T=7)E*"=I9G)A;65S)RDI('L*("`@("`@("`@
M("`@<F5T=7)N(%\H(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92XB*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG:&5I9VAT)UTI*2!["B`@("`@("`@("`@(&EF("@D
M8G)O=W-E<BT^:7-"<F]W<V5R*"=M<VEE)RD@?'P@)&)R;W=S97(M/FES0G)O
M=W-E<B@G:V]N<75E<F]R)RDI('L*("`@("`@("`@("`@("`@("1H96EG:'0@
M/2`G)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H
M96EG:'0@/2`G(&AE:6=H=#TB,3`P)2(G.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&AE:6=H="`]("<@:&5I9VAT/2(G
M("X@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7W!A<F%M<ULG:&5I9VAT)UTI
M("X@)R(G.PH@("`@("`@('T*("`@("`@("!R971U<FX@)SQI9G)A;64@<W)C
M/2(G("X@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7W!A<F%M<ULG:69R86UE
M)UTI("X@)R(@=VED=&@](C$P,"4B)R`N("1H96EG:'0@+B`G(&UA<F=I;FAE
M:6=H=#TB,"(@<V-R;VQL:6YG/2)A=71O(B!F<F%M96)O<F1E<CTB,"(^/"]I
M9G)A;64^)SL*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]M
M971A<BYP:'``````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-#<Q,S<`,3`U,34T,S$P-C``,#(P,#0Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HD8FQO8VM?;F%M92`]
M(%\H(DUE=&%R(%=E871H97(B*3L*"B\J*@H@*B!4:&4@2&]R9&5?0FQO8VM?
M;65T87(@8VQA<W,@<')O=FED97,@86X@87!P;&5T(&9O<B!T:&4@<&]R=&%L
M"B`J('-C<F5E;B!T;R!D:7-P;&%Y($U%5$%2('=E871H97(@9&%T82!F;W(@
M82!S<&5C:69I960@;&]C871I;VX*("H@*&-U<G)E;G1L>2!A:7)P;W)T<RDN
M"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+VUE=&%R+G!H<"QV(#$N
M,C(N,3`N-B`R,#`V+S`V+S(S(#$Y.C,Q.C(X(&IA;B!%>'`@)`H@*@H@*B!`
M<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R
M9&5?;65T87(@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P
M(#T@)VAO<F1E)SL*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I
M"B`@("!["B`@("`@("`@<F5T=7)N(%\H(D-U<G)E;G0@5V5A=&AE<B(I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@(&EF
M("@A0&EN8VQU9&5?;VYC92`G4V5R=FEC97,O5V5A=&AE<BYP:'`G*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=4:&4@;65T87(@8FQO8VL@
M=VEL;"!N;W0@=V]R:R!W:71H;W5T(%-E<G9I8V5S7U=E871H97(@9G)O;2!0
M14%2+B!2=6X@<&5A<B!I;G-T86QL(%-E<G9I8V5S7U=E871H97(N)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@87)R87DH"B`@
M("`@("`@("`@("`@("`G97)R;W(G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`]/B`G97)R;W(G+`H@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`]/B!?*")%<G)O<B(I+`H@("`@("`@("`@("`@("`@("`@("=D
M969A=6QT)R`]/B!?*")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(I"B`@
M("`@("`@("`@("`@("`I"B`@("`@("`@("`@("D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`@("`@+R\@
M1V5T(&QO8V%T:6]N<R!F<F]M('1H92!D871A8F%S92X*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("`@("`@("`D9&(@/2`F1$(Z
M.F-O;FYE8W0H)&-O;F9;)W-Q;"==*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&1B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&1B.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3970@1$(@<&]R
M=&%B:6QI='D@;W!T:6]N<RX*("`@("`@("`@("`@<W=I=&-H("@D9&(M/G!H
M<'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G;7-S<6PG.@H@("`@("`@("`@
M("`@("`@)&1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"
M24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3('P@1$)?
M4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D9&(M/G-E=$]P
M=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@
M?"!$0E]03U)404))3$E465]%4E)/4E,I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D<F5S=6QT(#T@)&1B+3YQ=65R>2@G4T5,14-4(&EC86\L(&YA
M;64L(&-O=6YT<GD@1E)/32!M971A<D%I<G!O<G1S($]21$52($)9(&-O=6YT
M<GDG*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1L;V-A=&EO;G,@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!W:&EL92`H)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"
M7T9%5$-(34]$15]!4U-/0RDI('L*("`@("`@("`@("`@("`@("1L;V-A=&EO
M;G-;)')O=ULG8V]U;G1R>2==75LD<F]W6R=I8V%O)UU=(#T@)')O=ULG;F%M
M92==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@87)R87DH
M"B`@("`@("`@("`@("`@("`G;&]C871I;VXG(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G;6QE;G5M)RP*("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@/3X@7R@B3&]C871I;VXB*2P*("`@("`@("`@("`@
M("`@("`@("`G9&5F875L="<@/3X@)TM31D(G+`H@("`@("`@("`@("`@("`@
M("`@("=V86QU97,G(#T^("1L;V-A=&EO;G,L"B`@("`@("`@("`@("`@("`I
M+`H@("`@("`@("`@("`@("`@)W5N:71S)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@
M("`@("=N86UE)R`]/B!?*")5;FET<R(I+`H@("`@("`@("`@("`@("`@("`@
M("=D969A=6QT)R`]/B`G<R<L"B`@("`@("`@("`@("`@("`@("`@)W9A;'5E
M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=S)R`]/B!?
M*")3=&%N9&%R9"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G;2<@/3X@
M7R@B365T<FEC(BD*("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`@("`@)VMN;W1S)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("`@
M("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B5VEN9"!S<&5E9"!I;B!K;F]T
M<R(I+`H@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`P"B`@("`@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@)W1A9B<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(D1I<W!L87D@9F]R96-A
M<W0@*%1!1BDB*2P*("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@
M,`H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F]W*"1L86)E;"P@)&-O;G1E;G0I"B`@
M("!["B`@("`@("`@<F5T=7)N("<\8G(@+SX\<W1R;VYG/B<@+B`D;&%B96P@
M+B`G.CPO<W1R;VYG/B`G("X@)&-O;G1E;G0["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W-A;652;W<H)&QA8F5L+"`D8V]N=&5N="D*("`@('L*("`@("`@("!R
M971U<FX@)R`\<W1R;VYG/B<@+B`D;&%B96P@+B`G.CPO<W1R;VYG/B`G("X@
M)&-O;G1E;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T
M;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E
M;G0H*0H@("`@>PH@("`@("`@(&EF("@A0&EN8VQU9&5?;VYC92`G4V5R=FEC
M97,O5V5A=&AE<BYP:'`G*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=4:&4@;65T87(@8FQO8VL@=VEL;"!N;W0@=V]R:R!W:71H;W5T(%-E
M<G9I8V5S7U=E871H97(@9G)O;2!014%2+B!2=6X@<&5A<B!I;G-T86QL(%-E
M<G9I8V5S7U=E871H97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("!R971U<FX@7R@B365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB
M*3L*("`@("`@("!]"@H@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@("!S
M=&%T:6,@)&UE=&%R3&]C<SL*"B`@("`@("`@:68@*"%I<W-E="@D8V]N9ELG
M<W%L)UTI*2!["B`@("`@("`@("`@(')E='5R;B!?*")!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(BD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N
M)UTI*2!["B`@("`@("`@("`@(')E='5R;B!?*").;R!L;V-A=&EO;B!I<R!S
M970N(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1M971A
M<DQO8W,I*2!["B`@("`@("`@("`@("1M971A<DQO8W,@/2`D=&AI<RT^9V5T
M4&%R86US*"D["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)U-E
M<G9I8V5S+U=E871H97(N<&AP)SL*("`@("`@("`D;65T87(@/2`F4V5R=FEC
M97-?5V5A=&AE<CHZ<V5R=FEC92@G345405(G+"!A<G)A>2@G9&5B=6<G(#T^
M(#`I*3L*("`@("`@("`D;65T87(M/G-E=$UE=&%R1$(H)&-O;F9;)W-Q;"==
M*3L*("`@("`@("`D;65T87(M/G-E=%5N:71S1F]R;6%T*"1T:&ES+3Y?<&%R
M86US6R=U;FET<R==*3L*("`@("`@("`D;65T87(M/G-E=$1A=&54:6UE1F]R
M;6%T*"=-(&HL(%DG+"`G2#II)RD["B`@("`@("`@)&UE=&%R+3YS971-971A
M<E-O=7)C92@G:'1T<"<I.PH*("`@("`@("`D=6YI=',@/2`D;65T87(M/F=E
M=%5N:71S1F]R;6%T*"1T:&ES+3Y?<&%R86US6R=U;FET<R==*3L*("`@("`@
M("`D=V5A=&AE<B`]("1M971A<BT^9V5T5V5A=&AE<B@D=&AI<RT^7W!A<F%M
M<ULG;&]C871I;VXG72D["@H@("`@("`@("1H=&UL(#T@)SQT86)L92!W:61T
M:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/B<@+@H@("`@("`@("`@("`G/'1R
M/CQT9"!C;&%S<STB8V]N=')O;"(^/'-T<F]N9SXG("X*("`@("`@("`@("`@
M<W!R:6YT9B@G)7,L("5S("@E<RDG+`H@("`@("`@("`@("`@("`@("`@("1M
M971A<DQO8W-;)VQO8V%T:6]N)UU;)W9A;'5E<R==6R1T:&ES+3Y?<&%R86US
M6R=?7VQO8V%T:6]N)UU=6R1T:&ES+3Y?<&%R86US6R=L;V-A=&EO;B==72P*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG7U]L;V-A=&EO
M;B==+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=L;V-A
M=&EO;B==*2`N"B`@("`@("`@("`@("<\+W-T<F]N9SX\+W1D/CPO='(^/"]T
M86)L93X\<W1R;VYG/B<@+B!?*"),87-T(%5P9&%T960Z(BD@+B`G/"]S=')O
M;F<^("<@+@H@("`@("`@("`@("`D=V5A=&AE<ELG=7!D871E)UT@+B`G/&)R
M("\^/&)R("\^)SL*"B`@("`@("`@+R\@5VEN9"X*("`@("`@("!I9B`H:7-S
M970H)'=E871H97);)W=I;F0G72DI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQS=')O;F<^)R`N(%\H(E=I;F0Z(BD@+B`G/"]S=')O;F<^("<["B`@("`@
M("`@("`@(&EF("@D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==(#T]("=687)I
M86)L92<I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P
M87)A;7-;)VMN;W1S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@<W!R:6YT9BA?*"(E<R!A="`E<R`E<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("!R;W5N9"@D;65T87(M/F-O;G9E<G13<&5E9"@D=V5A
M=&AE<ELG=VEN9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5N
M:71S6R=W:6YD)UTL("=K="<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)VMT)RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B)7,@870@)7,@)7,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)'=E871H97);)W=I;F1$:7)E8W1I;VXG
M72P*("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)'=E871H97);)W=I
M;F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("1U;FET<ULG=VEN9"==
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"@D
M=V5A=&AE<ELG=VEN9$1E9W)E97,G72`]/2`G,#`P)RD@)B8*("`@("`@("`@
M("`@("`@("`@("`@("`@*"1W96%T:&5R6R=W:6YD)UT@/3T@)S`G*2D@>PH@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9BA?*")C86QM(BDI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M<W!R:6YT9BA?*")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R6R=W:6YD1&ER
M96-T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M96%T:&5R6R=W:6YD1&5G<F5E<R==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G72D@/PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D=V5A=&AE
M<ELG=VEN9"==*2`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')O=6YD*"1M971A<BT^8V]N=F5R=%-P965D*"1W96%T:&5R6R=W:6YD)UTL
M("1U;FET<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=K;F]T<R==*2`_
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;FET<ULG=VEN
M9"==(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VMT)RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1W
M96%T:&5R6R=W:6YD1W5S="==*2D@>PH@("`@("`@("`@("!I9B`H)'=E871H
M97);)W=I;F1'=7-T)UTI('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]P87)A;7-;)VMN;W1S)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@<W!R:6YT9BA?*"(L(&=U<W1I;F<@)7,@)7,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&UE=&%R+3YC;VYV97)T4W!E
M960H)'=E871H97);)W=I;F1'=7-T)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("1U;FET<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("=K="<I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*%\H(BP@9W5S=&EN9R`E
M<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D=V5A=&AE
M<ELG=VEN9$=U<W0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("1U;FET
M<ULG=VEN9"==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'=E871H97);)W=I;F1687)I
M86)I;&ET>2==*2D@>PH@("`@("`@("`@("!I9B`H)'=E871H97);)W=I;F16
M87)I86)I;&ET>2==6R=F<F]M)UTI('L*("`@("`@("`@("`@("`@("1H=&UL
M("X]('-P<FEN=&8H7R@B+"!V87)I86)L92!F<F]M("5S('1O("5S(BDL"B`@
M("`@("`@("`@("`@("`@("`@)'=E871H97);)W=I;F1687)I86)I;&ET>2==
M6R=F<F]M)UTL"B`@("`@("`@("`@("`@("`@("`@)'=E871H97);)W=I;F16
M87)I86)I;&ET>2==6R=T;R==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@5FES:6)I;&ET>2X*("`@("`@("!I9B`H:7-S970H)'=E
M871H97);)W9I<VEB:6QI='DG72DI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)'1H:7,M/E]S86UE4F]W*%\H(E9I<VEB:6QI='DB*2P@)'=E871H97);)W9I
M<VEB:6QI='DG72`N("<@)R`N("1U;FET<ULG=FES)UTI.PH@("`@("`@('T*
M"B`@("`@("`@+R\@5&5M<&5R871U<F4O1&5W4&]I;G0N"B`@("`@("`@:68@
M*&ES<V5T*"1W96%T:&5R6R=T96UP97)A='5R92==*2D@>PH@("`@("`@("`@
M("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")496UP97)A='5R92(I+"!R;W5N
M9"@D=V5A=&AE<ELG=&5M<&5R871U<F4G72D@+B`G)F1E9SLG("X@4W1R:6YG
M.CIU<'!E<B@D=6YI='-;)W1E;7`G72DI.PH@("`@("`@('T*("`@("`@("!I
M9B`H:7-S970H)'=E871H97);)V1E=U!O:6YT)UTI*2!["B`@("`@("`@("`@
M("1H=&UL("X]("1T:&ES+3Y?<V%M95)O=RA?*")$97<@4&]I;G0B*2P@<F]U
M;F0H)'=E871H97);)V1E=U!O:6YT)UTI("X@)R9D96<[)R`N(%-T<FEN9SHZ
M=7!P97(H)'5N:71S6R=T96UP)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES<V5T*"1W96%T:&5R6R=F96QT5&5M<&5R871U<F4G72DI('L*("`@("`@
M("`@("`@)&AT;6P@+CT@)'1H:7,M/E]S86UE4F]W*%\H(D9E96QS($QI:V4B
M*2P@<F]U;F0H)'=E871H97);)V9E;'1496UP97)A='5R92==*2`N("<F9&5G
M.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*2D["B`@("`@("`@
M?0H*("`@("`@("`O+R!0<F5S<W5R92X*("`@("`@("!I9B`H:7-S970H)'=E
M871H97);)W!R97-S=7)E)UTI*2!["B`@("`@("`@("`@("1H=&UL("X]("1T
M:&ES+3Y?<F]W*%\H(E!R97-S=7)E(BDL("1W96%T:&5R6R=P<F5S<W5R92==
M("X@)R`G("X@)'5N:71S6R=P<F5S)UTI.PH@("`@("`@('T*"B`@("`@("`@
M+R\@2'5M:61I='DN"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R6R=H=6UI
M9&ET>2==*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W-A;652
M;W<H7R@B2'5M:61I='DB*2P@<F]U;F0H)'=E871H97);)VAU;6ED:71Y)UTI
M("X@)R4G*3L*("`@("`@("!]"@H@("`@("`@("\O($-L;W5D<RX*("`@("`@
M("!I9B`H:7-S970H)'=E871H97);)V-L;W5D<R==*2D@>PH@("`@("`@("`@
M("`D8VQO=61S(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1W96%T:&5R
M6R=C;&]U9',G72!A<R`D8VQO=60I('L*("`@("`@("`@("`@("`@("1C;&]U
M9',@+CT@)SQB<B`O/B<["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-L
M;W5D6R=H96EG:'0G72DI('L*("`@("`@("`@("`@("`@("`@("`D8VQO=61S
M("X]('-P<FEN=&8H7R@B)7,@870@)7,@)7,B*2P@)&-L;W5D6R=A;6]U;G0G
M72P@)&-L;W5D6R=H96EG:'0G72P@)'5N:71S6R=H96EG:'0G72D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1C;&]U
M9',@+CT@)&-L;W5D6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?
M*")#;&]U9',B*2P@)&-L;W5D<RD["B`@("`@("`@?0H*("`@("`@("`O+R!#
M;VYD:71I;VYS+@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG8V]N9&ET
M:6]N)UTI*2!["B`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H
M(D-O;F1I=&EO;G,B*2P@)'=E871H97);)V-O;F1I=&EO;B==*3L*("`@("`@
M("!]"@H@("`@("`@("\O(%)E;6%R:W,N"B`@("`@("`@:68@*&ES<V5T*"1W
M96%T:&5R6R=R96UA<FLG72DI('L*("`@("`@("`@("`@)')E;6%R:W,@/2`G
M)SL*("`@("`@("`@("`@)&]T:&5R(#T@)R<["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1W96%T:&5R6R=R96UA<FLG72!A<R`D<F5M87)K(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D<F5M87)K*2!["B`@("`@("`@
M("`@("`@("!C87-E("=S96%P<F5S<W5R92<Z"B`@("`@("`@("`@("`@("`@
M("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+B!?*")0<F5S<W5R92!A="!S96$@
M;&5V96PZ("(I("X@)'9A;'5E("X@)R`G("X@)'5N:71S6R=P<F5S)UT["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`G<')E8VEP:71A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'9A;'5E(&%S("1P<F5C:7`I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;65R:6,H)'!R96-I<%LG86UO=6YT)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R96-I<%LG:&]U
M<G,G72D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5C
M:7!;)V%M;W5N="==("X@)R`G("X@)'5N:71S6R=R86EN)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ("(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!R96-I<%LG:&]U<G,G72D@+B`D<')E8VEP
M6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=S;F]W9&5P=&@G.@H@("`@("`@("`@("`@
M("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B4VYO=R!D97!T:#H@
M(BD@+B`D=F%L=64@+B`G("<@+B`D=6YI='-;)W)A:6XG73L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=S;F]W
M97%U:78G.@H@("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@
M+SXG("X@7R@B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B*2`N("1V86QU
M92`N("<@)R`N("1U;FET<ULG<F%I;B==.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W-U;F1U<F%T:6]N)SH*
M("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N('-P
M<FEN=&8H7R@B)7,@;6EN=71E<R(I+"`D=F%L=64I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)S%H=&5M<"<Z
M"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+B!?
M*")496UP(&9O<B!L87-T(&AO=7(Z("(I("X@<F]U;F0H)'9A;'5E*2`N("<F
M9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("<Q
M:&1E=R<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O
M/B<@+B!?*")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(BD@+B!R;W5N9"@D
M=F%L=64I("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP
M)UTI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&-A<V4@)S9H;6%X=&5M<"<Z"B`@("`@("`@("`@("`@("`@("`@)')E
M;6%R:W,@+CT@)SQB<B`O/B<@+B!?*")-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M("(I("X@<F]U;F0H)'9A;'5E*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R
M*"1U;FET<ULG=&5M<"==*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("<V:&UI;G1E;7`G.@H@("`@("`@("`@
M("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B36EN('1E;7`@
M;&%S="`V(&AO=7)S.B`B*2`N(')O=6YD*"1V86QU92D@+B`G)F1E9SLG("X@
M4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G,C1H;6%X=&5M
M<"<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@
M+B!?*")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B*2`N(')O=6YD*"1V86QU
M92D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G,C1H;6EN=&5M<"<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R
M:W,@+CT@)SQB<B`O/B<@+B!?*")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M*2`N(')O=6YD*"1V86QU92D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D
M=6YI='-;)W1E;7`G72D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G<V5N<V]R<R<Z"B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1S96YS;W(I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7R@B4V5N<V]R.B`B*2`N("1S96YS;W([
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("`@("`@)&]T:&5R("X]("<\8G(@+SXG("X@)'9A;'5E.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")296UA
M<FMS(BDL("1R96UA<FMS("X@)&]T:&5R*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%1!1@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W1A
M9B==*2D@>PH@("`@("`@("`@("`D=&%F(#T@)&UE=&%R+3YG971&;W)E8V%S
M="@D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72D["B`@("`@("`@("`@(&EF
M("@A:7-?82@D=&%F+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`D9F]R96-A<W0@/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN
M9STB,"(^)SL*("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1R/CQT
M9"!C;&%S<STB8V]N=')O;"(@8V]L<W!A;CTB,B(^/&-E;G1E<CX\<W1R;VYG
M/B<@+B!?*")&;W)E8V%S="`H5$%&*2(I("X@)SPO<W1R;VYG/CPO=&0^/"]T
M<CX\+W1A8FQE/B<["B`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS
M=')O;F<^5F%L:60Z(#PO<W1R;VYG/B<@+B`D=&%F6R=V86QI9$9R;VTG72`N
M("<@+2`G("X@)'1A9ELG=F%L:614;R==("X@)SQB<B`O/CQB<B`O/B<["B`@
M("`@("`@("`@("`@("`D:71E;2`](#`["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=&%F6R=T:6UE)UT@87,@)'1I;64@/3X@)&5N=')Y*2!["B`@("`@
M("`@("`@("`@("`@("`@)&ET96TK*SL*("`@("`@("`@("`@("`@("`@("`D
M9F]R96-A<W0@+CT@)SQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<]
M(C`B/B<["B`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\='(@
M8VQA<W,](FET96TG("X@*"1I=&5M("4@,BD@+B`G(CXG.PH@("`@("`@("`@
M("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1D(&%L:6=N/2)C96YT97(B('=I
M9'1H/2(U,"(^)R`N("1T:6UE("X@)SPO=&0^/'1D/CQS=')O;F<^5VEN9#H\
M+W-T<F]N9SX@)SL*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N
M=')Y6R=W:6YD)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M96YT<GE;)W=I;F1$:7)E8W1I;VXG72`]/2`G5F%R:6%B;&4G*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=K;F]T<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2!S<')I;G1F*%\H(B5S(&%T("5S("5S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<G1O;&]W97(H
M)&5N=')Y6R=W:6YD1&ER96-T:6]N)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R;W5N9"@D;65T87(M/F-O;G9E<G13<&5E9"@D
M96YT<GE;)W=I;F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1U;FET<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=K="<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F]R96-A<W0@+CT@<W!R:6YT9BA?*"(E<R!A="`E<R`E
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT
M<GE;)W=I;F1$:7)E8W1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F]U;F0H)&5N=')Y6R=W:6YD)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G72D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@H)&5N=')Y6R=W:6YD1&5G<F5E<R==(#T]("<P
M,#`G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H
M)&5N=')Y6R=W:6YD)UT@/3T@)S`G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<F5C87-T("X]('-P<FEN=&8H7R@B8V%L;2(I*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)E8V%S="`N/2!S<')I;G1F*%\H(F9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R=W:6YD1&ER96-T:6]N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E;G1R>5LG=VEN9$1E9W)E97,G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P87)A;7-;
M)VMN;W1S)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F]U;F0H)&5N=')Y6R=W:6YD)UTI(#H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&UE
M=&%R+3YC;VYV97)T4W!E960H)&5N=')Y6R=W:6YD)UTL("1U;FET<ULG=VEN
M9"==+"`G:W0G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=K;F]T<R==*2`_
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U;FET<ULG=VEN9"==(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VMT)RD["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\
M8G(@+SXG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&5N=')Y6R=T96UP97)A='5R94QO=R==*2!\?"!I
M<W-E="@D96YT<GE;)W1E;7!E<F%T=7)E2&EG:"==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O;F<^5&5M<&5R871U
M<F4\+W-T<F]N9SXG.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&5N=')Y6R=T96UP97)A='5R94QO=R==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG/B!,;W<Z/"]S
M=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S
M="`N/2`D96YT<GE;)W1E;7!E<F%T=7)E3&]W)UT["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1E;G1R>5LG=&5M<&5R871U<F5(:6=H)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O;F<^($AI9V@Z/"]S
M=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S
M="`N/2`D96YT<GE;)W1E;7!E<F%T=7)E2&EG:"==.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S
M="`N/2`G/&)R("\^)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG=VEN9'-H96%R)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'-T<F]N
M9SY7:6YD<VAE87(Z/"]S=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O<F5C87-T("X]('-P<FEN=&8H7R@B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5N=')Y6R=W:6YD<VAE87)$:7)E8W1I;VXG72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5LG=VEN9'-H
M96%R1&5G<F5E<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N=')Y6R=W:6YD<VAE87)(96EG:'0G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;FET<ULG:&5I9VAT
M)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQB
M<B`O/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D96YT<GE;)W9I<VEB:6QI='DG72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG/E9I<VEB
M:6QI='DZ/"]S=')O;F<^("<["B`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2!S=')T;VQO=V5R*"1E;G1R>5LG=FES475A;&EF:65R)UTI
M("X@)R`G("X@)&5N=')Y6R=V:7-I8FEL:71Y)UT@+B`G("<@+B`D=6YI='-;
M)W9I<R==.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)SQB<B`O/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D96YT<GE;)V-O;F1I=&EO;B==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O;F<^0V]N
M9&ET:6]N<SH\+W-T<F]N9SX@)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<F5C87-T("X]("1E;G1R>5LG8V]N9&ET:6]N)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/&)R("\^)SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M("<\<W1R;VYG/D-L;W5D<SH\+W-T<F]N9SX@)SL*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D96YT<GE;)V-L;W5D<R==(&%S("1C;&]U9',I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;&]U9'-;)W1Y
M<&4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S
M="`N/2`G("<@+B`D8VQO=61S6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M("<@)R`N("1C;&]U9'-;)V%M;W5N="==.PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&-L;W5D<ULG:&5I9VAT)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)R!A="`G("X@)&-L
M;W5D<ULG:&5I9VAT)UT@+B`G("<@+B`D=6YI='-;)VAE:6=H="==.PH@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<F5C87-T("X]("<@)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)SPO=&0^/"]T<CXG.PH@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)V9M8R==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:71E;2LK.PH@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D96YT<GE;)V9M8R==(&%S("1F;6-%;G1R>2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\='(@
M8VQA<W,](FET96TG("X@*"1I=&5M("4@,BD@+B`G(CXG.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\=&0@86QI9VX](F-E
M;G1E<B(@=VED=&@](C4P(CXG.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O<F5C87-T("X]("<J("<@+B`D9FUC16YT<GE;)V9R;VTG72`N("<\
M8G(@+SX@+2`G("X@)&9M8T5N=')Y6R=T;R==("X@)SPO=&0^)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1D/B<["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O
M;F<^5'EP93H@/"]S=')O;F<^)R`N("1F;6-%;G1R>5LG='EP92==.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F;6-%;G1R>5LG
M<')O8F%B:6QI='DG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W0@+CT@)R`\<W1R;VYG/B!0<F]B.B`\+W-T<F]N9SXG
M("X@)&9M8T5N=')Y6R=P<F]B86)I;&ET>2==("X@)R4G.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1F;6-%;G1R>5LG8V]N9&ET:6]N)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@/'-T
M<F]N9SX@0V]N9&ET:6]N<SH@/"]S=')O;F<^)R`N("1F;6-%;G1R>5LG8V]N
M9&ET:6]N)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M8T5N=')Y6R=C
M;&]U9',G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R96-A<W0@+CT@)R`\<W1R;VYG/D-L;W5D<SH\+W-T<F]N9SXG.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F;6-%;G1R
M>5LG8VQO=61S)UT@87,@)&9M8T-L;W5D<RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M8T-L;W5D<ULG='EP
M92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O<F5C87-T("X]("<@)R`N("1F;6-#;&]U9'-;)W1Y<&4G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M8T-L;W5D
M<ULG:&5I9VAT)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F]R96-A<W0@+CT@)R`G("X@)&9M8T-L;W5D<ULG86UO
M=6YT)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F]R96-A<W0@+CT@)R`G("X@)&9M8T-L;W5D<ULG:&5I9VAT)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@)R`G("X@)'5N:71S6R=H96EG:'0G73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G("<@+B`D
M9FUC0VQO=61S6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FUC16YT<GE;)W9I<U%U86QI
M9FEE<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G(#QS=')O;F<^5FES:6)I;&ET>3H\+W-T<F]N9SX@)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M<W1R=&]L;W=E<B@D9FUC16YT<GE;)W9I<U%U86QI9FEE<B==*2`N("<@)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)&9M8T5N=')Y6R=V:7-I8FEL:71Y)UT@+B`G("<@+B`D=6YI='-;)W9I<R==
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\+W1D/CPO='(^)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9F]R96-A<W0@
M+CT@)SPO=&%B;&4^)SL*"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D9F]R
M96-A<W0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:'1M;#L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O0FQO8VLO8V]L;W(N<&AP````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C8U`#$P-3$U-#,Q,#8P`#`R
M,#`T,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+R\@5&AI<R!B;&]C:R!I<R!A;B!E>&%M<&QE(&%N9"!P<F]B
M86)L>2!N;W0@=7-E9G5L('1O('5S97)S+@HO+R`D8FQO8VM?;F%M92`](%\H
M(D-O;&]R(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO8V]L
M;W(N<&AP+'8@,2XQ,B`R,#`T+S`V+S`Q(#$P.C`U.C,Q(&IA;B!%>'`@)`H@
M*@H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO
M8VM?2&]R9&5?8V]L;W(@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R
M("1?87!P(#T@)VAO<F1E)SL*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@
M('L*("`@("`@("!R971U<FX@87)R87DH)W1Y<&4G(#T^("=T97AT)RP*("`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(D-O;&]R(BDL"B`@("`@
M("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G(V9F,#`P,"<I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&AE('1I=&QE('1O(&=O(&EN('1H:7,@8FQO
M8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@=&ET;&4@
M=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@
M("`@("!R971U<FX@7R@B0V]L;W(B*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@)&AT;6P@(#T@)SQT
M86)L92!W:61T:#TB,3`P(B!H96EG:'0](C$P,"(@8F=C;VQO<CTB)7,B/B<[
M"B`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/B<[
M"B`@("`@("`@)&AT;6P@+CT@)SPO=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N
M('-P<FEN=&8H)&AT;6PL("1T:&ES+3Y?<&%R86US6R=C;VQO<B==*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O````````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q
M,#8Q`#`Q-C(Q-P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M;V)I;&4O````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-C``,#$W-#(U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TUO8FEL92]296YD97)E<B\`````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,C$Q-S,`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O36]B:6QE+U)E;F1E
M<F5R+VAT;6PN<&AP````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-#<P`#$P
M-3$U-#,Q,#8P`#`R,C8U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@2&]R9&5?36]B:6QE7U)E;F1E
M<F5R.CH@;W5T<'5T(&UO9'5L92!F;W(@<VEM<&QE($A434P@86YD"B`J($EM
M;V1E+T%V86YT9V\O<VEM:6QA<B!D979I8V5S+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]-;V)I;&4O36]B:6QE+U)E;F1E<F5R+VAT;6PN<&AP+'8@,2XR
M."XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,C8@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B
M:6QE7U)E;F1E<F5R7VAT;6P@97AT96YD<R!(;W)D95]-;V)I;&5?4F5N9&5R
M97(@>PH*("`@("\J*@H@("`@("H@4')O<&5R;'D@96YC;V1E(&-H87)A8W1E
M<G,@9F]R(&]U='!U="!T;R!A;B!(5$U,(&)R;W=S97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:6YP=70@($-H87)A8W1E<G,@=&\@96YC;V1E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC;V1E9"!T
M97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&4H)&EN<'5T*0H@("`@
M>PH@("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R<R@D:6YP=70L($5.
M5%]#3TU0050L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T97,@=&AE('!A9V4@:6X@=&AE(&%P<')O<')I871E(&UA
M<FMU<"X@1&5P96YD:6YG(&]N('1H90H@("`@("H@8VQI96YT<R!B<F]W<V5R
M('1Y<&4@<'5R92!(5$U,+"!H86YD:&5L9&9R:65N9&QY($%V86YT1V\@2%1-
M3"P*("`@("`J(&DM;6]D92!C2%1-3"P@;W(@34U,(&ES(&-R96%T960N"B`@
M("`@*@H@("`@("H@0'!A<F%M($AO<F1E7TUO8FEL92`D9&5C:R`@5&AE(&1E
M8VL@=&\@<F5N9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)B1D
M96-K*0H@("`@>PH@("`@("`@(&EF("@D9&5C:RT^7V1E8G5G*2!["B`@("`@
M("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z('1E>'0O:'1M;#L@
M8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T*("`@
M("`@("!H96%D97(H)U9A<GDZ($%C8V5P="U,86YG=6%G92<I.PH*("`@("`@
M("!I9B`H(21T:&ES+3YI<T)R;W=S97(H)VUM;"<I*2!["B`@("`@("`@("`@
M(&5C:&\@(CPA1$]#5%E012!H=&UL(%!50DQ)0R!<(BTO+U<S0R\O1%1$($A4
M34P@-"XP(%1R86YS:71I;VYA;"\O14Y<(CY<;B(["B`@("`@("`@?0H*("`@
M("`@("!E8VAO("%E;7!T>2@D1TQ/0D%,4ULG;&%N9W5A9V4G72D@/R`G/&AT
M;6P@;&%N9STB)R`N('-T<G1R*"1'3$]"04Q36R=L86YG=6%G92==+"`G7R<L
M("<M)RD@+B`G(CXG(#H@)SQH=&UL/B<["B`@("`@("`@96-H;R`G/&AE860^
M)SL*"B`@("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)V%V86YT9V\G*2D@
M>PH@("`@("`@("`@("!E8VAO("<\;65T82!N86UE/2)(86YD:&5L9$9R:65N
M9&QY(B!C;VYT96YT/2)4<G5E(CXG.PH@("`@("`@('T*"B`@("`@("`@<')I
M;G1F*"(\=&ET;&4^)7,\+W1I=&QE/EQN(BP@)'1H:7,M/F5S8V%P92@D9&5C
M:RT^9V5T*"=T:71L92<I*2D["@H@("`@("`@(&EF("@D9&5C:RT^7W-I;75L
M871O<BD@>PH@("`@("`@("`@("`O+R!5<V4@<VEM=6QA=&]R("AM;V)I;&4@
M=&AE;64I('-T>6QE<VAE970N"B`@("`@("`@("`@(&5C:&\@2&]R9&4Z.G-T
M>6QE<VAE971,:6YK*"=H;W)D92<L("=M;V)I;&4G*3L*("`@("`@("!]"@H@
M("`@("`@(&5C:&\@)SPO:&5A9#X\8F]D>3XG.PH*("`@("`@("!I9B`H)&1E
M8VLM/E]S:6UU;&%T;W(I('L*("`@("`@("`@("`@96-H;R`B/&-E;G1E<CX\
M8G(@+SY<;B(["B`@("`@("`@("`@("\O($-R96%T92!D969A=6QT(&1E=FEC
M92!S:6UU;&%T;W(@=&%B;&4@;&%Y;W5T('=I=&@*("`@("`@("`@("`@+R\@
M8V5N=')A;"!#4U,@;&%Y;W5T+@H@("`@("`@("`@("!E8VAO("(\=&%B;&4@
M8F]R9&5R/5PB,%PB(&-E;&QP861D:6YG/5PB,%PB(&-E;&QS<&%C:6YG/5PB
M,%PB/EQN(CL*("`@("`@("`@("`@96-H;R`B/'1R/CQT9"!C;VQS<&%N/5PB
M,UPB(&-L87-S/5PB=&]P7"(^)FYB<W`[/"]T9#X\+W1R/EQN(CL*("`@("`@
M("`@("`@96-H;R`B/'1R/CQT9"!V86QI9VX]7")T;W!<(B!C;&%S<SU<(FQE
M9G1<(CXF;F)S<#L\+W1D/EQN(CL*("`@("`@("`@("`@96-H;R`B/'1D('9A
M;&EG;CU<(G1O<%PB(&-L87-S/5PB9&ES<&QA>5PB/EQN(CL*("`@("`@("!]
M"@H@("`@("`@("1D:79S='EL92`]("<G.PH@("`@("`@(&EF("@D=&AI<RT^
M:&%S475I<FLH)W-C<F]L;%]T9',G*2`F)B`D9&5C:RT^7W-I;75L871O<BD@
M>PH@("`@("`@("`@("`O+R!-86ME(&-O;G1E;G0@;V8@=&%B;&4@96QE;65N
M="!S8W)O;&QA8FQE("A(;W)D95]-;V)I;&4*("`@("`@("`@("`@+R\@<VEM
M=6QA=&]R*2X*("`@("`@("`@("`@)&1I=G-T>6QE(#T@)R!C;&%S<STB<VEM
M9&5V(B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SQD:78G("X@)&1I=G-T
M>6QE("X@)SXG.PH*("`@("`@("!I9B`H*"1C;G0@/2!C;W5N="@D9&5C:RT^
M7V-A<F1S*2D@(3T](#`I('L*("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@
M("`@("!F;W)E86-H("@D9&5C:RT^7V-A<F1S(&%S("1C87)D*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&D@(3T@,"D@>PH@("`@("`@("`@("`@("`@("`@
M(&5C:&\@)SQH<B`O/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)E;F1E<D-A<F0H)&-A<F0I.PH@("`@("`@("`@("`@
M("`@)&DK*SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1D96-K+3Y?96QE;65N=',@87,@)'!A9V5?96QE
M;65N="D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H
M)'!A9V5?96QE;65N="D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&5C:&\@)SPO9&EV/B<["@H@("`@("`@(&EF("@D9&5C:RT^7W-I;75L
M871O<BD@>PH@("`@("`@("`@("`O+R!$:7-P;&%Y(&QO=V5R('!A<G0@;V8@
M2&]R9&5?36]B:6QE(&1E9F%U;'0@9&5V:6-E"B`@("`@("`@("`@("\O('-I
M;75L871O<BX*("`@("`@("`@("`@96-H;R`G/"]T9#X\=&0@=F%L:6=N/2)T
M;W`B(&-L87-S/2)R:6=H="(^)FYB<W`[/"]T9#X\+W1R/CQT<CX\=&0@8V]L
M<W!A;CTB,R(@8VQA<W,](F)O='1O;2(^)FYB<W`[/"]T9#X\+W1R/CPO=&%B
M;&4^/"]C96YT97(^)SL*("`@("`@("!]"@H@("`@("`@(&5C:&\@)SPO8F]D
M>3X\+VAT;6P^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R0V%R9"@F
M)&-A<F0I"B`@("!["B`@("`@("`@)&YA;64@/2`D8V%R9"T^9V5T*"=N86UE
M)RD@/R`G(&YA;64](B<@+B`D=&AI<RT^97-C87!E*"1C87)D+3YG970H)VYA
M;64G*2D@+B`G(B<@.B`G)SL*("`@("`@("!P<FEN=&8H)SQA)7,^)7,\+V$^
M)RP@)&YA;64L("1C87)D+3YG970H)W1I=&QE)RDI.PH*("`@("`@("!I9B`H
M8V]U;G0H)&-A<F0M/E]S;V9T:V5Y<RDI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)&-A<F0M/E]S;V9T:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@
M("!E8VAO("<@?"`\82!H<F5F/2(G("X@)&ME>5LG=7)L)UT@+B`G(CXG("X@
M("1T:&ES+3YE<V-A<&4H)&ME>5LG;&%B96PG72D@+B`G/"]A/B<["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%)E;F1E<B!A;&P@=&%G
M<RX*("`@("`@("!F;W)E86-H("@D8V%R9"T^7V5L96UE;G1S(&%S("1P86=E
M7V5L96UE;G0I('L*("`@("`@("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H
M)'!A9V5?96QE;65N="D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97),:6YK*"8D;&EN:RD*("`@('L*("`@("`@("!I9B`H)&QI;FLM
M/F=E="@G=&ET;&4G*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES0G)O=W-E
M<B@G879A;G1G;R<I("8F"B`@("`@("`@("`@("$D=&AI<RT^:7-"<F]W<V5R
M*"=I;6]D92<I("8F"B`@("`@("`@("`@("$D=&AI<RT^:7-"<F]W<V5R*"=M
M;6PG*2D@>PH@("`@("`@("`@("`D=&ET;&5?;W!T:6]N(#T@<W!R:6YT9B@G
M(&]N;6]U<V5O=F5R/2)S96QF+G-T871U<SU<)R5S7"<[<F5T=7)N('1R=64[
M(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YE<V-A<&4H)&QI;FLM/F=E="@G=&ET;&4G*2DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:71L95]O<'1I;VX@/2`G)SL*("`@("`@("!]
M"@H@("`@("`@("1A8V-E<W-K97E?;W!T:6]N(#T@)R<["B`@("`@("`@:68@
M*"1L:6YK+3YG970H)V%C8V5S<VME>2<I*2!["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I*2!["B`@("`@("`@("`@("`@("`D
M86-C97-S:V5Y7V]P=&EO;B`]('-P<FEN=&8H)R!A8V-E<W-K97D](B5D(B<L
M("1L:6YK+3YG970H)V%C8V5S<VME>2<I*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1T:&ES+3YI<T)R;W=S97(H)VUM;"<I*2!["B`@("`@("`@("`@("`@
M("`D86-C97-S:V5Y7V]P=&EO;B`]('-P<FEN=&8H)R!D:7)E8W1K97D](B5D
M(B<L("1L:6YK+3YG970H)V%C8V5S<VME>2<I*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<')I;G1F*"<\82!H<F5F/2(E<R(E<R5S/B5S
M/"]A/B<L"B`@("`@("`@("`@("`@('-T<E]R97!L86-E*"<F86UP.V%M<#LG
M+"`G)F%M<#LG+"`D=&AI<RT^97-C87!E*"1L:6YK+3YG970H)W5R;"<I*2DL
M"B`@("`@("`@("`@("`@("1T:71L95]O<'1I;VXL("1A8V-E<W-K97E?;W!T
M:6]N+`H@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E*"1L:6YK+3YG970H
M)VQA8F5L)RDI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R3&EN:W-E
M="@F)&QI;FMS970I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1L:6YK<V5T
M+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@(&5C:&\@)SQO;#XG.PH@("`@
M("`@("`@("!F;W)E86-H("@D;&EN:W-E="T^7V5L96UE;G1S(&%S("1V86PI
M('L*("`@("`@("`@("`@("`@(&5C:&\@)SQL:3XG.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96YD97),:6YK*"1V86PI.PH@("`@("`@("`@("`@("`@
M96-H;R`G/"]L:3XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@
M)SPO;VP^)SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E1E>'0H)B1E;&5M96YT*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1E;&5M
M96YT+3Y?871T<FEB=71E<R!A<R`D871T<FEB=71E*2!["B`@("`@("`@("`@
M(&5C:&\@)SPG("X@)&%T=')I8G5T92`N("<^)SL*("`@("`@("!]"@H@("`@
M("`@(&EF("@D96QE;65N="T^9V5T*"=L:6YE8G)E86MS)RDI('L*("`@("`@
M("`@("`@96-H;R!N;#)B<B@D=&AI<RT^97-C87!E*"1E;&5M96YT+3YG970H
M)W1E>'0G*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@
M)'1H:7,M/F5S8V%P92@D96QE;65N="T^9V5T*"=T97AT)RDI.PH@("`@("`@
M('T*"B`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>5]R979E<G-E*"1E;&5M
M96YT+3Y?871T<FEB=71E<RD["B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T
M97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!E8VAO("<\+R<@+B`D
M871T<FEB=71E("X@)SXG.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5N9&5R26UA9V4H)B1I;6%G92D*("`@('L*("`@("`@("`D871T<FEB
M=71E<R`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1I;6%G92T^7V%T=')I8G5T
M97,@87,@)&%T=')I8G5T92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&%T
M=')I8G5T97,@+CT@<W!R:6YT9B@G("5S/2(E<R(G+"`D871T<FEB=71E+"`D
M=F%L=64I.PH@("`@("`@('T*("`@("`@("!P<FEN=&8H)SQI;6<@<W)C/2(E
M<RYP;F<B)7,@+SXG+"`D:6UA9V4M/E]S<F,L("1A='1R:6)U=&5S*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R1F]R;2@F)&9O<FTI"B`@("!["B`@
M("`@("`@<')I;G1F*"<\9F]R;2!A8W1I;VX](B5S(B!M971H;V0](B5S(CXG
M+"`D9F]R;2T^9V5T*"=U<FPG*2P@)&9O<FTM/F=E="@G;65T:&]D)RDI.PH@
M("`@("`@('!A<F5N=#HZ7W)E;F1E<D9O<FTH)&9O<FTI.PH@("`@("`@(&5C
M:&\@)SPO9F]R;3XG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97));G!U
M="@F)&EN<'5T*0H@("`@>PH@("`@("`@("1T>7!E(#T@)W1Y<&4](B<@+B`D
M:6YP=70M/F=E="@G='EP92<I("X@)R(G.PH@("`@("`@("1S:7IE(#T@)&EN
M<'5T+3YG970H)W-I>F4G*2`_('-P<FEN=&8H)W-I>F4](B5D(B<L("1I;G!U
M="T^9V5T*"=S:7IE)RDI(#H@)R<["B`@("`@("`@)&UA>&QE;F=T:"`]("1I
M;G!U="T^9V5T*"=M87AL96YG=&@G*2`_('-P<FEN=&8H)VUA>&QE;F=T:#TB
M)60B)RP@)&EN<'5T+3YG970H)VUA>&QE;F=T:"<I*2`Z("<G.PH*("`@("`@
M("!I9B`H)'1H:7,M/FES0G)O=W-E<B@G:6UO9&4G*2D@>PH@("`@("`@("`@
M("`D;6]D92`]('-P<FEN=&8H)R!I<W1Y;&4](B5D(B<L("1I;G!U="T^9V5T
M*"=M;V1E)RDI.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R
M*"=M;6PG*2D@>PH@("`@("`@("`@("`D;6]D92`]("1T:&ES+3Y?9V5T36]D
M92@D:6YP=70M/F=E="@G;6]D92<I*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;6]D92`]("<G.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E
M871E($A434P@:6YP=70N"B`@("`@("`@<')I;G1F*"<E<R`\:6YP=70@)7,@
M;F%M93TB)7,B('9A;'5E/2(E<R(E<R5S)7,O/B<L"B`@("`@("`@("`@("`@
M("1T:&ES+3YE<V-A<&4H)&EN<'5T+3YG970H)VQA8F5L)RDI+"`D='EP92P*
M("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D:6YP=70M/F=E="@G;F%M
M92<I*2P@)'1H:7,M/F5S8V%P92@D:6YP=70M/F=E="@G=F%L=64G*2DL("1S
M:7IE+"`D;6%X;&5N9W1H+"`D;6]D92D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E1E>'1A<F5A*"8D=&5X=&%R96$I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YI<T)R;W=S97(H)VEM;V1E)RDI('L*("`@("`@("`@("`@)&UO
M9&4@/2!S<')I;G1F*"<@:7-T>6QE/2(E9"(G+"`D=&AI<RT^;6]D92D["B`@
M("`@("`@?2!E;'-E:68@*"1T:&ES+3YI<T)R;W=S97(H)VUM;"<I*2!["B`@
M("`@("`@("`@("1M;V1E(#T@)'1H:7,M/E]G971-;V1E*"1T:&ES+3YM;V1E
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]D92`]("<G.PH@
M("`@("`@('T*"B`@("`@("`@)'=R87`@/2`G)SL*("`@("`@("!I9B`H(21T
M:&ES+3YI<T)R;W=S97(H)VEM;V1E)RD@)B8@(21T:&ES+3YI<T)R;W=S97(H
M)VUM;"<I*2!["B`@("`@("`@("`@("1W<F%P(#T@)R!W<F%P/2)V:7)T=6%L
M(B<["B`@("`@("`@?0H*("`@("`@("!P<FEN=&8H)R5S/&)R("\^/'1E>'1A
M<F5A(&YA;64](B5S(B!R;W=S/2(E<R(@8V]L<STB)7,B)7,E<SXE<SPO=&5X
M=&%R96$^)RP*("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D=&5X=&%R
M96$M/F=E="@G;&%B96PG*2DL("1T97AT87)E82T^9V5T*"=N86UE)RDL("1T
M97AT87)E82T^9V5T*"=R;W=S)RDL"B`@("`@("`@("`@("`@("1T97AT87)E
M82T^9V5T*"=C;VQS)RDL("1M;V1E+"`D=W)A<"P@)'1E>'1A<F5A+3YG970H
M)W9A;'5E)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)396QE8W0H
M)B1S96QE8W0I"B`@("!["B`@("`@("`@96-H;R`G/'-E;&5C="!N86UE/2(G
M("X@)'-E;&5C="T^9V5T*"=N86UE)RD@+B`G(B!S:7IE/2(Q(CXG.PH@("`@
M("`@(&9O<F5A8V@@*"1S96QE8W0M/E]O<'1I;VYS(&%S("1V86PI('L*("`@
M("`@("`@("`@:68@*"1V86Q;)W9A;'5E)UT@/3T@)'-E;&5C="T^7W9A;'5E
M*2!["B`@("`@("`@("`@("`@("`D<V5L(#T@)R!S96QE8W1E9#TB<V5L96-T
M960B)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S
M96P@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\;W!T
M:6]N)R`N("1S96P@+B`G('9A;'5E/2(G("X@)'9A;%LG=F%L=64G72`N("<B
M/B<@+B`D=&AI<RT^97-C87!E*"1V86Q;)VQA8F5L)UTI("X@)SPO;W!T:6]N
M/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO<V5L96-T/B<["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E)A9&EO*"8D<F%D:6\I"B`@("!["B`@
M("`@("`@9F]R96%C:"`H)')A9&EO+3Y?8G5T=&]N<R!A<R`D=F%L*2!["B`@
M("`@("`@("`@("1S96P@/2`H)'9A;%LG=F%L=64G72`]/2`D<F%D:6\M/E]V
M86QU92D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G.PH@("`@("`@("`@
M("!P<FEN=&8H)SQI;G!U="!T>7!E/2)R861I;R(@;F%M93TB)7,B)7,@=F%L
M=64](B5S(B`O/B`E<SQB<B`O/B<L"B`@("`@("`@("`@("`@("`@("`D<F%D
M:6\M/F=E="@G;F%M92<I+"`D<V5L+"`D=F%L6R=V86QU92==+`H@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D=F%L6R=L86)E;"==*2D["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)#:&5C:V)O>"@F
M)&-H96-K8F]X*0H@("`@>PH@("`@("`@("1S=&%T92`]("1C:&5C:V)O>"T^
M:7-#:&5C:V5D*"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G.PH@("`@
M("`@('!R:6YT9B@G/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2(E<R(E
M<R!V86QU93TB)7,B("\^("5S/&)R("\^)RP*("`@("`@("`@("`@("`@)&-H
M96-K8F]X+3YG970H)VYA;64G*2P@)'-T871E+"`D8VAE8VMB;W@M/F=E="@G
M=F%L=64G*2P*("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D8VAE8VMB
M;W@M/F=E="@G;&%B96PG*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)3=6)M:70H)B1S=6)M:70I"B`@("!["B`@("`@("`@)&YA;64@/2`A96UP
M='DH)'-U8FUI="T^7VYA;64I(#\@)R!N86UE/2(G("X@)'-U8FUI="T^7VYA
M;64@+B`G(B<@.B`G)SL*("`@("`@("!P<FEN=&8H)SQI;G!U="!T>7!E/2)S
M=6)M:70B)7,@=F%L=64](B5S(B`O/CQB<B`O/B<L"B`@("`@("`@("`@("`@
M("1N86UE+"`D=&AI<RT^97-C87!E*"1S=6)M:70M/E]L86)E;"DI.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)(:61D96XH)B1H:61D96XI"B`@("![
M"B`@("`@("`@<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E
M<R(@=F%L=64](B5S(B`O/B<L"B`@("`@("`@("`@("`@("1H:61D96XM/F=E
M="@G;F%M92<I+"`D:&ED9&5N+3YG970H)W9A;'5E)RDI.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)486)L92@F)'1A8FQE*0H@("`@>PH@("`@("`@
M("1B;W)D97(@/2`D=&%B;&4M/F=E="@G8F]R9&5R)RD["B`@("`@("`@)'!A
M9&1I;F<@/2`D=&%B;&4M/F=E="@G<&%D9&EN9R<I.PH@("`@("`@("1S<&%C
M:6YG(#T@)'1A8FQE+3YG970H)W-P86-I;F<G*3L*"B`@("`@("`@96-H;R`G
M/'1A8FQE)SL*("`@("`@("!I9B`H(6ES7VYU;&PH)&)O<F1E<BDI('L*("`@
M("`@("`@("`@96-H;R`G(&)O<F1E<CTB)R`N("1B;W)D97(@+B`G(B<["B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D<&%D9&EN9RDI('L*("`@
M("`@("`@("`@96-H;R`G(&-E;&QP861D:6YG/2(G("X@)'!A9&1I;F<@+B`G
M(B<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D<W!A8VEN9RDI
M('L*("`@("`@("`@("`@96-H;R`G(&-E;&QS<&%C:6YG/2(G("X@)'-P86-I
M;F<@+B`G(B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SXG.PH*("`@("`@
M("!P87)E;G0Z.E]R96YD97)486)L92@D=&%B;&4I.PH*("`@("`@("`O+R!4
M97)M:6YA=&4@=&%B;&4N"B`@("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H
M)VUM;"<I*2!["B`@("`@("`@("`@(&5C:&\@)SPO=&%B;&4^/&)R("\^)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!-34P@:&%S('!R;V)L
M96US('=I=&@@=&AE(&-L96%R(&%T=')I8G5T92X*("`@("`@("`@("`@96-H
M;R`G/"]T86)L93X\8G(@8VQE87(](F%L;"(^)SL*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E!H;VYE*"8D<&AO;F4I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)VEM;V1E)RDI('L*("`@("`@
M("`@("`@+R\@0W)E871E('!H;VYE=&\Z(&QI;FL@9F]R(&DM36]D92X*("`@
M("`@("`@("`@<')I;G1F*"<\<#X\82!H<F5F/2)P:&]N971O.B5S(CXE<SPO
M83X\+W`^)RP*("`@("`@("`@("`@("`@("`@("1P:&]N92T^9V5T*"=N=6UB
M97(G*2P@)'!H;VYE+3YG970H)VQA8F5L)RDI.PH@("`@("`@('T@96QS96EF
M("@D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@("`O+R!#
M<F5A=&4@=&5L.B!L:6YK(&9O<B!-34PN"B`@("`@("`@("`@('!R:6YT9B@G
M/'`^/&$@:')E9CTB=&5L.B5S(CXE<SPO83X\+W`^)RP*("`@("`@("`@("`@
M("`@("`@("1P:&]N92T^9V5T*"=N=6UB97(G*2P@)'!H;VYE+3YG970H)VQA
M8F5L)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($1I<W!L
M87D@<&AO;F4@;G5M8F5R(&%S('!L86EN('1E>'0N"B`@("`@("`@("`@('!R
M:6YT9B@G/'`^/&)I9SXE<SPO8FEG/CPO<#XG+"`D<&AO;F4M/F=E="@G;&%B
M96PG*2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)2
M=6QE*"8D<G5L92D*("`@('L*("`@("`@("`D=VED=&@@/2`D<G5L92T^9V5T
M*"=W:61T:"<I.PH@("`@("`@("1S:7IE(#T@)')U;&4M/F=E="@G<VEZ92<I
M.PH*("`@("`@("!E8VAO("<\:'(G("X@*"1W:61T:"`_("<@=VED=&@](B<@
M+B`D=VED=&@@+B`G(B<@.B`G)RD@+B`H)'-I>F4@/R`G('-I>F4](B<@+B`D
M<VEZ92`N("<B)R`Z("<G*2`N("(@+SY<;B(["B`@("!]"@H@("`@9G5N8W1I
M;VX@7V=E=$UO9&4H)&UO9&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D;6]D
M92D@>PH@("`@("`@(&-A<V4@)VMA=&%K86YA)SH*("`@("`@("`@("`@<F5T
M=7)N("<@;6]D93TB:V%T86MA;F$B)SL*"B`@("`@("`@8V%S92`G:&ER86=A
M;F$G.@H@("`@("`@("`@("!R971U<FX@)R!M;V1E/2)H:7)A9V%N82(G.PH*
M("`@("`@("!C87-E("=N=6UE<FEC)SH*("`@("`@("`@("`@<F5T=7)N("<@
M;6]D93TB;G5M97)I8R(G.PH*("`@("`@("!C87-E("=A;'!H82<Z"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("<@;6]D93TB86QP:&%B
M970B)SL*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O36]B:6QE+U)E
M;F1E<F5R+W=M;"YP:'``````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-3(S
M`#$P-3$U-#,Q,#8P`#`R,C4Q,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@2&]R9&5?36]B:6QE7U)E
M;F1E<F5R.CH@;W5T<'5T(&UO9'5L92!F;W(@5TU,("A7:7)E;&5S<R!-87)K
M=7`@3&%N9W5A9V4I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-;V)I;&4O
M36]B:6QE+U)E;F1E<F5R+W=M;"YP:'`L=B`Q+C,R+C$P+C<@,C`P-B\P,B\R
M-"`R,#HT,#HS."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]296YD97)E<E]W
M;6P@97AT96YD<R!(;W)D95]-;V)I;&5?4F5N9&5R97(@>PH*("`@("\J*@H@
M("`@("H@4')O<&5R;'D@96YC;V1E(&-H87)A8W1E<G,@9F]R(&]U='!U="!T
M;R!A(%=-3"!D979I8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:6YP=70@($-H87)A8W1E<G,@=&\@96YC;V1E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@96YC;V1E9"!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!E<V-A<&4H)&EN<'5T*0H@("`@>PH@("`@("`@("\O($5N8V]D
M92!E;G1I=&EE<RX*("`@("`@("`D;W5T<'5T(#T@0&AT;6QS<&5C:6%L8VAA
M<G,H)&EN<'5T+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["@H@
M("`@("`@("\O($5S8V%P92`D(&-H87)A8W1E<B!I;B!734PN"B`@("`@("`@
M)&]U='!U="`]('-T<E]R97!L86-E*"<D)RP@)R0D)RP@)&]U='!U="D["@H@
M("`@("`@("\O($=E;F5R871E(%541BTX+@H@("`@("`@("1O=71P=70@/2!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1O=71P=70L($Y,4SHZ9V5T0VAA<G-E
M="@I+"`G=71F+3@G*3L*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S('1H92!P86=E(&EN(%=-3"P@86QL
M;W=I;F<@9F]R(&1I9F9E<F5N="!734P@8G)O=W-E<B!Q=6ER:W,N"B`@("`@
M*@H@("`@("H@0'!A<F%M($AO<F1E7TUO8FEL92`D9&5C:R`@5&AE(&1E8VL@
M=&\@<F5N9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)B1D96-K
M*0H@("`@>PH@("`@("`@(&EF("@D9&5C:RT^7V1E8G5G*2!["B`@("`@("`@
M("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/75T9BTX)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:&5A9&5R
M*"=#;VYT96YT+51Y<&4Z('1E>'0O=FYD+G=A<"YW;6P[(&-H87)S970]=71F
M+3@G*3L*("`@("`@("!]"@H@("`@("`@(&5C:&\@(CP_>&UL('9E<G-I;VX]
M7"(Q+C!<(C\^7&XB.PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V]W
M7V=U:5\Q+C,G*2D@>PH@("`@("`@("`@("!E8VAO("<\(41/0U194$4@=VUL
M(%!50DQ)0R`B+2\O4$A/3D4N0T]-+R]$5$0@5TU,(#$N,R\O14XB(")H='1P
M.B\O=W=W+F]P96YW879E+F-O;2]D=&0O=VUL,3,N9'1D(CXG.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&5C:&\@)SPA1$]#5%E012!W;6P@4%5"
M3$E#("(M+R]705!&3U)532\O1%1$(%=-3"`Q+C$O+T5.(B`B:'1T<#HO+W=W
M=RYW87!F;W)U;2YO<F<O1%1$+W=M;%\Q+C$N>&UL(CXG.PH@("`@("`@('T*
M("`@("`@("!E8VAO("<\=VUL/B<["@H@("`@("`@(&EF("AC;W5N="@D9&5C
M:RT^7V-A<F1S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D9&5C:RT^7V-A
M<F1S(&%S("1C87)D*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E;F1E
M<D-A<F0H)&-A<F0I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1I=&QE(#T@)&1E8VLM/F=E="@G=&ET;&4G*2`_("<@
M=&ET;&4](B<@+B`D=&AI<RT^97-C87!E*"1D96-K+3YG970H)W1I=&QE)RDI
M("X@)R(G(#H@)R<["B`@("`@("`@("`@('!R:6YT9B@G/&-A<F0E<SXG+"`D
M=&ET;&4I.PH*("`@("`@("`@("`@+R\@4F5N9&5R(&%L;"!T86=S+@H@("`@
M("`@("`@("!F;W)E86-H("@D9&5C:RT^7V5L96UE;G1S(&%S("1P86=E7V5L
M96UE;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT
M*"1P86=E7V5L96UE;G0I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!E
M8VAO("<\+V-A<F0^)SL*("`@("`@("!]"@H@("`@("`@("\O($5N9"!T:&4@
M5TU,('!A9V4N"B`@("`@("`@96-H;R`G/"]W;6P^)SL*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R0V%R9"@F)&-A<F0I"B`@("!["B`@("`@("`@)&YA
M;64@/2`D8V%R9"T^9V5T*"=N86UE)RD@/R`G(&ED/2(G("X@)'1H:7,M/F5S
M8V%P92@D8V%R9"T^9V5T*"=N86UE)RDI("X@)R(G(#H@)R<["B`@("`@("`@
M)'1I=&QE(#T@)&-A<F0M/F=E="@G=&ET;&4G*2`_("<@=&ET;&4](B<@+B`D
M=&AI<RT^97-C87!E*"1C87)D+3YG970H)W1I=&QE)RDI("X@)R(G(#H@)R<[
M"B`@("`@("`@<')I;G1F*"<\8V%R9"5S)7,^)RP@)&YA;64L("1T:71L92D[
M"@H@("`@("`@("\O($EN:71I86QI>F4@5TU,('9A<FEA8FQE<R!W:71H('1H
M96ER(&1E9F%U;'0@=F%L=65S+@H@("`@("`@(&EF("@A:7-?;G5L;"@D8V%R
M9"T^7V9O<FTI*2!["B`@("`@("`@("`@(&5C:&\@)SQO;F5V96YT('1Y<&4]
M(F]N96YT97)F;W)W87)D(CX\<F5F<F5S:#XG.PH@("`@("`@("`@("`D9&5F
M875L=',@/2`D8V%R9"T^7V9O<FTM/F=E=$1E9F%U;'1S*"D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1D969A=6QT<R!A<R`D9"D@>PH@("`@("`@("`@("`@
M("`@<')I;G1F*"<\<V5T=F%R(&YA;64](E\E<R(@=F%L=64](B5S(B\^)RP@
M)&1;)VYA;64G72P@)'1H:7,M/F5S8V%P92@D9%LG=F%L=64G72DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@)SPO<F5F<F5S:#X\+V]N979E
M;G0^)SL*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D8V%R9"T^7W-O
M9G1K97ES*2D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)&-A<F0M/E]S;V9T
M:V5Y<RD@/3T@,2D@>PH@("`@("`@("`@("`@("`@+R\@268@=&AE<F4@:7,@
M;VYL>2!O;F4@<V]F=&ME>2P@;6%K92!I="!O9B!T>7!E"B`@("`@("`@("`@
M("`@("`O+R`G;W!T:6]N<R<@<V\@=&AA="!I="!A;'=A>7,@<VAO=W,@=7`@
M;VX@=&AE(')I9VAT+`H@("`@("`@("`@("`@("`@+R\@:6YS=&5A9"!O9B!H
M879I;F<@=&\@<VAA<F4@=&AE(&QE9G0@<V]F=&ME>2!W:71H"B`@("`@("`@
M("`@("`@("`O+R!A8W1I=F4@;&EN:W,L(&UA:VEN9R!I="!M=6-H(&AA<F1E
M<B!T;R!G970@=&\N"B`@("`@("`@("`@("`@("`D='EP92`]("=O<'1I;VYS
M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T>7!E
M(#T@)V%C8V5P="<["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C
M:"`H)&-A<F0M/E]S;V9T:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@
M("!E8VAO("<\9&\@='EP93TB)R`N("1T>7!E("X@)R(@;&%B96P](B<@+B`D
M=&AI<RT^97-C87!E*"1K97E;)VQA8F5L)UTI("X@)R(^/&=O(&AR968](B<@
M+B`D:V5Y6R=U<FPG72`N("<B+SX\+V1O/B<["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\O(%)E;F1E<B!A;&P@=&%G<RX*("`@("`@("!F
M;W)E86-H("@D8V%R9"T^7V5L96UE;G1S(&%S("1P86=E7V5L96UE;G0I('L*
M("`@("`@("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H)'!A9V5?96QE;65N
M="D["B`@("`@("`@?0H*("`@("`@("!E8VAO("<\+V-A<F0^)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R3&EN:R@F)&QI;FLI"B`@("!["B`@("`@
M("`@)'1I=&QE7V]P=&EO;B`]("1L:6YK+3YG970H)W1I=&QE)RD@/R!S<')I
M;G1F*"<@=&ET;&4](B5S(B<L("1T:&ES+3YE<V-A<&4H)&QI;FLM/F=E="@G
M=&ET;&4G*2DI(#H@)R<["@H@("`@("`@('!R:6YT9B@G/&$E<R!H<F5F/2(E
M<R(^)7,\+V$^)RP*("`@("`@("`@("`@("`@)'1I=&QE7V]P=&EO;BP@<W1R
M7W)E<&QA8V4H)R9A;7`[86UP.R<L("<F86UP.R<L("1T:&ES+3YE<V-A<&4H
M)&QI;FLM/F=E="@G=7)L)RDI*2P*("`@("`@("`@("`@("`@)'1H:7,M/F5S
M8V%P92@D;&EN:RT^9V5T*"=L86)E;"<I*2D["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<DQI;FMS970H)B1L:6YK<V5T*0H@("`@>PH@("`@("`@(&EF
M("AC;W5N="@D;&EN:W-E="T^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/FES0G)O=W-E<B@G=7`G*2D@>PH@("`@("`@("`@("`@("`@
M96-H;R`G/'-E;&5C=#XG.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI
M;FMS970M/E]E;&5M96YT<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1I=&QE(#T@)'9A;"T^9V5T*"=T:71L92<I(#\@)R!T:71L93TB)R`N
M("1T:&ES+3YE<V-A<&4H)'9A;"T^9V5T*"=T:71L92<I*2`N("<B)R`Z("<G
M.PH@("`@("`@("`@("`@("`@("`@('!R:6YT9B@G/&]P=&EO;B!O;G!I8VL]
M(B5S(B5S/B5S/"]O<'1I;VX^)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1R7W)E<&QA8V4H)R9A;7`[86UP.R<L("<F86UP.R<L("1T:&ES+3YE
M<V-A<&4H)'9A;"T^9V5T*"=U<FPG*2DI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&ET;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YE<V-A<&4H)'9A;"T^9V5T*"=L86)E;"<I*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!E8VAO("<\+W-E;&5C=#XG.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI
M;FMS970M/E]E;&5M96YT<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96YD97),:6YK*"1V86PI.PH@("`@("`@("`@("`@("`@
M("`@(&5C:&\@)SQB<B`O/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E1E
M>'0H)B1E;&5M96YT*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1E;&5M96YT
M+3Y?871T<FEB=71E<R!A<R`D871T<FEB=71E*2!["B`@("`@("`@("`@(&5C
M:&\@)SPG("X@)&%T=')I8G5T92`N("<^)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D96QE;65N="T^9V5T*"=L:6YE8G)E86MS)RDI('L*("`@("`@("`@
M("`@96-H;R!N;#)B<B@D=&AI<RT^97-C87!E*"1E;&5M96YT+3YG970H)W1E
M>'0G*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@)'1H
M:7,M/F5S8V%P92@D96QE;65N="T^9V5T*"=T97AT)RDI.PH@("`@("`@('T*
M"B`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>5]R979E<G-E*"1E;&5M96YT
M+3Y?871T<FEB=71E<RD["B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@
M87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!E8VAO("<\+R<@+B`D871T
M<FEB=71E("X@)SXG.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R26UA9V4H)B1I;6%G92D*("`@('L*("`@("`@("`D871T<FEB=71E
M<R`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1I;6%G92T^7V%T=')I8G5T97,@
M87,@)&%T=')I8G5T92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&%T=')I
M8G5T97,@+CT@<W!R:6YT9B@G("5S/2(E<R(G+"`D871T<FEB=71E+"`D=F%L
M=64I.PH@("`@("`@('T*("`@("`@("!P<FEN=&8H)SQI;6<@<W)C/2(E<RYW
M8FUP(B5S+SXG+"`D:6UA9V4M/E]S<F,L("1A='1R:6)U=&5S*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R26YP=70H)B1I;G!U="D*("`@('L*("`@
M("`@("`D='EP92`]("<@='EP93TB)R`N("1I;G!U="T^9V5T*"=T>7!E)RD@
M+B`G(B<["B`@("`@("`@)'-I>F4@/2`D:6YP=70M/F=E="@G<VEZ92<I(#\@
M<W!R:6YT9B@G('-I>F4](B5D(B<L("1I;G!U="T^9V5T*"=S:7IE)RDI(#H@
M)R<["B`@("`@("`@)&UA>&QE;F=T:"`]("1I;G!U="T^9V5T*"=M87AL96YG
M=&@G*2`_('-P<FEN=&8H)R!M87AL96YG=&@](B5D(B<L("1I;G!U="T^9V5T
M*"=M87AL96YG=&@G*2D@.B`G)SL*"B`@("`@("`@<')I;G1F*"<E<SQI;G!U
M="!E;7!T>6]K/2)T<G5E(B!F;W)M870](B5S(B5S(&YA;64](E\E<R(@=F%L
M=64](B5S(B5S)7,O/B<L"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H
M)&EN<'5T+3YG970H)VQA8F5L)RDI+"`D:6YP=70M/F=E="@G9F]R;6%T)RDL
M"B`@("`@("`@("`@("`@("1T>7!E+"`D=&AI<RT^97-C87!E*"1I;G!U="T^
M9V5T*"=N86UE)RDI+"`D=&AI<RT^97-C87!E*"1I;G!U="T^9V5T*"=V86QU
M92<I*2P@)'-I>F4L("1M87AL96YG=&@I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)497AT87)E82@F)'1E>'1A<F5A*0H@("`@>PH@("`@("`@('!R
M:6YT9B@G)7,\:6YP=70@96UP='EO:STB=')U92(@;F%M93TB7R5S(B!V86QU
M93TB)7,B+SXG+`H@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E*"1T97AT
M87)E82T^9V5T*"=L86)E;"<I*2P*("`@("`@("`@("`@("`@)'1E>'1A<F5A
M+3YG970H)VYA;64G*2P@)'1E>'1A<F5A+3YG970H)W9A;'5E)RDI.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)396QE8W0H)B1S96QE8W0I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G;W=?9W5I7S$N,R<I*2![
M"B`@("`@("`@("`@('-W:71C:"`H)'-E;&5C="T^9V5T*"=T>7!E)RDI('L*
M("`@("`@("`@("`@8V%S92`G<W!I;B<Z"B`@("`@("`@("`@("`@("`D='EP
M95]O<'1I;VX@/2`G='EP93TB<W!I;B(G.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=P;W!U<"<Z"B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`D='EP95]O<'1I;VX@/2`G='EP93TB
M<&]P=7`B)SL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!E8VAO("<\<V5L96-T("<@+B`D='EP95]O<'1I;VX@
M+B`G(&YA;64](E\G("X@)'-E;&5C="T^9V5T*"=N86UE)RD@+B`G(CXG.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@)SQS96QE8W0@;F%M
M93TB7R<@+B`D<V5L96-T+3YG970H)VYA;64G*2`N("<B/B<["B`@("`@("`@
M?0H*("`@("`@("!F;W)E86-H("@D<V5L96-T+3Y?;W!T:6]N<R!A<R`D=F%L
M*2!["B`@("`@("`@("`@(&5C:&\@)SQO<'1I;VX@=F%L=64](B<@+B`D=F%L
M6R=V86QU92==("X@)R(^)R`N("1T:&ES+3YE<V-A<&4H)'9A;%LG;&%B96PG
M72D@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"B`@("`@("`@96-H;R`G/"]S
M96QE8W0^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4F%D:6\H)B1R
M861I;RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FAA<U%U:7)K*"=O=U]G
M=6E?,2XS)RDI('L*("`@("`@("`@("`@+R\@3W!E;G=A=F4@1U5)(&5X=&5N
M<VEO;G,@9F]R(%=-3"`Q+C,*("`@("`@("`@("`@<')I;G1F*"<\<V5L96-T
M('1Y<&4](G)A9&EO(B!N86UE/2)?)7,B/B<L("1R861I;RT^9V5T*"=N86UE
M)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($-O;G9E;G1I
M;VYA;"!734P@*'-I;6EL87(@=&\@2&]R9&5?36]B:6QE7W-E;&5C="DN"B`@
M("`@("`@("`@('!R:6YT9B@G/'-E;&5C="!N86UE/2)?)7,B/B<L("1R861I
M;RT^9V5T*"=N86UE)RDI.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)')A9&EO+3Y?8G5T=&]N<R!A<R`D=F%L*2!["B`@("`@("`@("`@('!R:6YT
M9B@G/&]P=&EO;B!V86QU93TB)7,B/B5S/"]O<'1I;VX^)RP*("`@("`@("`@
M("`@("`@("`@("1V86Q;)W9A;'5E)UTL("1T:&ES+3YE<V-A<&4H)'9A;%LG
M;&%B96PG72DI.PH@("`@("`@('T*"B`@("`@("`@96-H;R`G/"]S96QE8W0^
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R0VAE8VMB;W@H)B1C:&5C
M:V)O>"D*("`@('L*("`@("`@("!P<FEN=&8H)SQS96QE8W0@;F%M93TB7R5S
M(B!M=6QT:7!L93TB=')U92(^)RP@)&-H96-K8F]X+3YG970H)VYA;64G*2D[
M"B`@("`@("`@<')I;G1F*"<\;W!T:6]N('9A;'5E/2(E<R(^)7,\+V]P=&EO
M;CX\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`D8VAE8VMB;W@M/F=E="@G
M=F%L=64G*2P@)'1H:7,M/F5S8V%P92@D8VAE8VMB;W@M/F=E="@G;&%B96PG
M*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)3=6)M:70H)B1S=6)M
M:70I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G;W=?9W5I
M7S$N,R<I*2!["B`@("`@("`@("`@("\O($-R96%T92`\9&\@='EP93TB8G5T
M=&]N(CX@<V5Q=65N8V4@9F]R($]P96YW879E($=520H@("`@("`@("`@("`O
M+R!E>'1E;G-I;VYS(%=-3"`Q+C,N"B`@("`@("`@("`@('!R:6YT9B@G/&1O
M('1Y<&4](F)U='1O;B(@;&%B96P](B5S(CXG+`H@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3YG970H)VQA8F5L)RDI*3L*("`@
M("`@("`@("`@)'1A9R`]("=D;R<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@0W)E871E(#QA;F-H;W(^('-E<75E;F-E(&EN(&YO<FUA;"!7
M34PN"B`@("`@("`@("`@('!R:6YT9B@G/&%N8VAO<B!T:71L93TB)7,B/B5S
M)RP*("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'-U8FUI="T^
M9V5T*"=L86)E;"<I*2P*("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<V-A
M<&4H)'-U8FUI="T^9V5T*"=L86)E;"<I*2D["B`@("`@("`@("`@("1T86<@
M/2`G86YC:&]R)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D<W5B;6ET+3Y?
M9F]R;2T^9V5T*"=M971H;V0G*2`]/2`G<&]S="<I('L*("`@("`@("`@("`@
M<')I;G1F*"<\9V\@:')E9CTB)7,B(&UE=&AO9#TB<&]S="(^)RP@2&]R9&4Z
M.G5R;"@D<W5B;6ET+3Y?9F]R;2T^9V5T*"=U<FPG*2DI.PH*("`@("`@("`@
M("`@+R\@5F%L=64@9F]R('1H:7,@<W5B;6ET(&5L96UE;G0L(&]N;'D@:68@
M;F]N+65M<'1Y(&YA;64N"B`@("`@("`@("`@(&EF("@D<W5B;6ET+3YG970H
M)VYA;64G*2D@>PH@("`@("`@("`@("`@("`@<')I;G1F*"<\<&]S=&9I96QD
M(&YA;64](B5S(B!V86QU93TB)7,B+SXG+"`D<W5B;6ET+3YG970H)VYA;64G
M*2P@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3YG970H)VQA8F5L)RDI*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&1E9F%U;'1S(#T@)'-U8FUI="T^
M7V9O<FTM/F=E=$1E9F%U;'1S*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M969A=6QT<R!A<R`D9"D@>PH@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME
M>5]E>&ES=',H)VAI9&1E;B<L("1D*2D@>PH@("`@("`@("`@("`@("`@("`@
M('!R:6YT9B@G/'!O<W1F:65L9"!N86UE/2(E<R(@=F%L=64](B5S(B\^)RP@
M)&1;)VYA;64G72P@)'1H:7,M/F5S8V%P92@D9%LG=F%L=64G72DI.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!P<FEN
M=&8H)SQP;W-T9FEE;&0@;F%M93TB)7,B('9A;'5E/2(D*%\E<RDB+SXG+"`D
M9%LG;F%M92==+"`D9%LG;F%M92==*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%-T
M87)T('=I=&@@=&AE('9A;'5E(&9O<B!T:&ES('-U8FUI="!E;&5M96YT+@H@
M("`@("`@("`@("`D<75E<GE?<W1R:6YG(#T@)'-U8FUI="T^9V5T*"=N86UE
M)RD@+B`G/2<@+B`D=&AI<RT^97-C87!E*"1S=6)M:70M/F=E="@G;&%B96PG
M*2D@+B`G)F%M<#LG.PH*("`@("`@("`@("`@)&=E='9A<G,@/2`D<W5B;6ET
M+3Y?9F]R;2T^9V5T1V5T5F%R<R@I.PH@("`@("`@("`@("!F;W)E86-H("@D
M9V5T=F%R<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D<75E<GE?<W1R
M:6YG("X]("1V86P@+B`G/20H7R<@+B`D=F%L("X@)RDF86UP.R<["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("AS=6)S='(H)'%U97)Y7W-T<FEN
M9RP@+34I(#T]("<F86UP.R<I('L*("`@("`@("`@("`@("`@("1Q=65R>5]S
M=')I;F<@/2!S=6)S='(H)'%U97)Y7W-T<FEN9RP@,"P@<W1R;&5N*"1Q=65R
M>5]S=')I;F<I("T@-2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('!R
M:6YT9B@G/&=O(&AR968](B5S/R5S(CXG+"`D<W5B;6ET+3Y?9F]R;2T^9V5T
M*"=U<FPG*2P@)'%U97)Y7W-T<FEN9RD["B`@("`@("`@?0H*("`@("`@("!E
M8VAO("(\+V=O/CPO)'1A9SXB.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)486)L92@F)'1A8FQE*0H@("`@>PH@("`@("`@("\O($-O=6YT(&UA>&EM
M=6T@;G5M8F5R(&]F(&-O;'5M;G,@:6X@=&%B;&4N"B`@("`@("`@)&UA>"`]
M(#`["B`@("`@("`@9F]R96%C:"`H)'1A8FQE+3Y?<F]W<R!A<R`D<F]W*2![
M"B`@("`@("`@("`@("1M87@@/2!M87@H)&UA>"P@)')O=RT^9V5T0V]L=6UN
M0V]U;G0H*2D["B`@("`@("`@?0H@("`@("`@('!R:6YT9B@G/'1A8FQE(&-O
M;'5M;G,](B5D(CXG+"`D;6%X*3L*"B`@("`@("`@<&%R96YT.CI?<F5N9&5R
M5&%B;&4H)'1A8FQE*3L*"B`@("`@("`@+R\@5&5R;6EN871E('1A8FQE+@H@
M("`@("`@(&5C:&\@)SPO=&%B;&4^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R4&AO;F4H)B1P:&]N92D*("`@('L*("`@("`@("`D=&ET;&4@/2`D
M<&AO;F4M/F=E="@G=&ET;&4G*3L*("`@("`@("`D=&ET;&5?;W!T:6]N(#T@
M*"1T:71L92`_('-P<FEN=&8H)R!T:71L93TB)7,B)RP@)'1H:7,M/F5S8V%P
M92@D=&ET;&4I*2`Z("<G*3L*"B`@("`@("`@<')I;G1F*"<\825S(&AR968]
M(G=T86DZ+R]W<"]M8SLE<R(^)7,\+V$^)RP@)'1I=&QE7V]P=&EO;BP*("`@
M("`@("`@("`@("`@<W1R7W)E<&QA8V4H)RLG+"`G)3)")RP@)'!H;VYE+3YG
M970H)VYU;6)E<B<I*2P@)'!H;VYE+3YG970H)VQA8F5L)RDI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)2=6QE*"8D<G5L92D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/FAA<U%U:7)K*"=O=U]G=6E?,2XS)RDI('L*("`@("`@
M("`@("`@+R\@5T%0(&1E=FEC92!A8V-E<'1S($]P96YW879E($=522!E>'1E
M;G-I;VYS(&9O<B!734P@,2XS"B`@("`@("`@("`@("1W:61T:"`]("1R=6QE
M+3YG970H)W=I9'1H)RD["B`@("`@("`@("`@("1S:7IE(#T@)')U;&4M/F=E
M="@G<VEZ92<I.PH*("`@("`@("`@("`@96-H;R`G/&AR)R`N("@D=VED=&@@
M/R`G('=I9'1H/2(G("X@)'=I9'1H("X@)R(G(#H@)R<I("X@*"1S:7IE(#\@
M)R!S:7IE/2(G("X@)'-I>F4@+B`G(B<@.B`G)RD@+B`G("\^)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!705`@9&5V:6-E(&1O97,@;F]T
M('5N9&5R<W1A;F0@/&AR("\^('1A9W,N"B`@("`@("`@("`@("\O(#T]/B!D
M<F%W('-O;64@;G5M8F5R(&]F(&AY<&AE;G,@=&\@8W)E871E(&$@<G5L90H@
M("`@("`@("`@("!E8VAO("<M+2TM+2TM+2TM/&)R("\^)SL*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O36]B:6QE
M+U)E;F1E<F5R+G!H<```````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q
M,C`V`#$P-3$U-#,Q,#8P`#`R,3<P,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@2&]R9&5?36]B:6QE
M7U)E;F1E<F5R.CH@9G)A;65W;W)K(&9O<B!M;V)I;&4@9&5V:6-E(&UA<FMU
M<`H@*B!R96YD97)E<G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TUO8FEL
M92]-;V)I;&4O4F5N9&5R97(N<&AP+'8@,2XQ-2XQ,"XX(#(P,#8O,#$O,#$@
M,C$Z,C@Z,C8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7U)E;F1E<F5R(&5X=&5N
M9',@2&]R9&5?36]B:6QE('L*"B`@("!V87(@)%]B<F]W<V5R.PH*("`@(&9U
M;F-T:6]N($AO<F1E7TUO8FEL95]296YD97)E<B@D8G)O=W-E<B`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&)R;W=S97(I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8G)O=W-E<B`]("9N97<@0G)O=W-E<B@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8G)O=W-E<B`]("1B
M<F]W<V5R.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<T)R;W=S
M97(H)&%G96YT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)R;W=S
M97(M/FES0G)O=W-E<B@D86=E;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&AA
M<U%U:7)K*"1Q=6ER:RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B
M<F]W<V5R+3YH87-1=6ER:R@D<75I<FLI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5N9&5R(&%N>2!(;W)D95]-;V)I;&5?96QE;65N="!O8FIE8W0N($QO
M;VMS(&9O<B!T:&4*("`@("`J(&%P<')O<')I871E(')E;F1E<FEN9R!F=6YC
M=&EO;B!I;B!T:&4@<F5N9&5R97([(&EF('1H97)E(&ES;B=T"B`@("`@*B!O
M;F4L('=E(&EG;F]R92!T:&ES(&5L96UE;G0N"B`@("`@*@H@("`@("H@0'!A
M<F%M($AO<F1E7TUO8FEL95]E;&5M96YT("1E;&5M96YT("!4:&4@96QE;65N
M="!T;R!R96YD97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D5L96UE
M;G0H)B1E;&5M96YT*0H@("`@>PH@("`@("`@("1F=6YC(#T@)U]R96YD97(G
M("X@=6-F:7)S="AS=')?<F5P;&%C92@G:&]R9&5?;6]B:6QE7R<L("<G+"!S
M=')T;VQO=V5R*&=E=%]C;&%S<R@D96QE;65N="DI*2D["B`@("`@("`@:68@
M*&UE=&AO9%]E>&ES=',H)'1H:7,L("1F=6YC*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^)&9U;F,H)&5L96UE;G0I.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R0FQO8VLH)B1B;&]C:RD*("`@('L*("`@("`@("!I
M9B`H8V]U;G0H)&)L;V-K+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@(&5C
M:&\@)SQP/B<["B`@("`@("`@("`@(&9O<F5A8V@@*"1B;&]C:RT^7V5L96UE
M;G1S(&%S("1B;&]C:T5L96UE;G0I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YR96YD97)%;&5M96YT*"1B;&]C:T5L96UE;G0I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5C:&\@(CPO<#Y<;B(["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)&;W)M*"8D9F]R;2D*("`@('L*("`@("`@
M("!F;W)E86-H("@D9F]R;2T^7V5L96UE;G1S(&%S("1F;W)M16QE;65N="D@
M>PH@("`@("`@("`@("`D=&AI<RT^<F5N9&5R16QE;65N="@D9F]R;45L96UE
M;G0I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5&%B
M;&4H)B1T86)L92D*("`@('L*("`@("`@("!F;W)E86-H("@D=&%B;&4M/E]R
M;W=S(&%S("1R;W<I('L*("`@("`@("`@("`@)'1H:7,M/E]R96YD97)2;W<H
M)')O=RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)2
M;W<H)B1R;W<I"B`@("!["B`@("`@("`@96-H;R`G/'1R/B<["B`@("`@("`@
M9F]R96%C:"`H)')O=RT^7V-O;'5M;G,@87,@)&-O;'5M;BD@>PH@("`@("`@
M("`@("!E8VAO("<\=&0^)SL*("`@("`@("`@("`@+R\@0V%L;"!C<F5A=&4@
M9G5N8W1I;VX@9F]R(&5A8V@@8V5L;&5L96UE;G0@=&AA="!I<R!A"B`@("`@
M("`@("`@("\O($AO<F1E7TUO8FEL92!O8FIE8W0N"B`@("`@("`@("`@(&EF
M("@A:7-?;G5L;"@D8V]L=6UN*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G)E;F1E<D5L96UE;G0H)&-O;'5M;BD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96-H;R`G/"]T9#XG.PH@("`@("`@('T*("`@("`@("!E8VAO("(\
M+W1R/EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M='5R;B!A(&-O;F-R971E($AO<F1E7TUO8FEL95]296YD97)E<B!I;G-T86YC
M90H@("`@("H@8F%S960@;VX@)'1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D='EP92`@("`@(%1H92!K:6YD(&]F(&UA<FMU<"`H:'1M;"P@
M:&1M;"P@=VUL*2!W92!W86YT('1O"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@9V5N97)A=&4N"B`@("`@*B!`<&%R86T@0G)O=W-E<B`D8G)O
M=W-E<B`@5&AE($)R;W=S97(@;V)J96-T('1O('5S92X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;W!T
M:6]N<R!F;W(@=&AE(')E;F1E<F5R+@H@("`@("H*("`@("`J($!R971U<FX@
M2&]R9&5?36]B:6QE7U)E;F1E<F5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC
M<F5T90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO
M<F1E7TUO8FEL95]296YD97)E<B!I;G-T86YC92P@;W(@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T
M(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D
M='EP92P@)&)R;W=S97(@/2!N=6QL+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D='EP92`](&)A<V5N86UE*"1T>7!E*3L*"B`@("`@("`@
M:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O4F5N9&5R
M97(O)R`N("1T>7!E("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!I;F-L=61E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E;F1E<F5R+R<@+B`D='EP
M92`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC
M;'5D95]O;F-E("=(;W)D92]-;V)I;&4O4F5N9&5R97(O)R`N("1T>7!E("X@
M)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7TUO
M8FEL95]296YD97)E<E\G("X@)'1Y<&4["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1R96YD97)E<B`]("9N97<@
M)&-L87-S*"1B<F]W<V5R+"`D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<F5N9&5R97(@/2!014%2.CIR86ES945R<F]R*"=#;&%S
M<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5N9&5R97(["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(
M;W)D95]-;V)I;&5?4F5N9&5R97(@:6YS=&%N8V4*("`@("`J(&)A<V5D(&]N
M("1T>7!E+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF
M(&YO"B`@("`@*B!R96YD97)E<B!W:71H('1H92!S86UE('!A<F%M971E<G,@
M8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T>7!E("`@("`@5&AE(&MI;F0@;V8@;6%R:W5P("AH=&UL+"!H9&UL+"!W
M;6PI('=E('=A;G0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!G96YE<F%T92X*("`@("`J($!P87)A;2!"<F]W<V5R("1B<F]W<V5R("!4
M:&4@0G)O=W-E<B!O8FIE8W0@=&\@=7-E+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!O<'1I;VYS(&9O
M<B!T:&4@<F5N9&5R97(N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]-
M;V)I;&5?4F5N9&5R97(@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?36]B
M:6QE7U)E;F1E<F5R(&EN<W1A;F-E+"!O<B!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@86X@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)'1Y<&4L
M("1B<F]W<V5R(#T@;G5L;"P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D
M<VEG;F%T=7)E(#T@;60U*'-E<FEA;&EZ92AA<G)A>2@D='EP92P@)&)R;W=S
M97(L("1P87)A;7,I*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S
M6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N
M871U<F5=(#T@)DAO<F1E7TUO8FEL95]296YD97)E<CHZ9F%C=&]R>2@D='EP
M92P@)&)R;W=S97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T1A=&$O````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,3<P-C<`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1&%T82]O=71L;V]K8W-V+G!H<```````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#(S`#$P-3$U-#,Q,#8P`#`R,C`P
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]$871A+V-S=BYP:'`G.PH*+RHJ
M"B`J($AO<F1E7T1A=&$@:6UP;&5M96YT871I;VX@9F]R($]U=&QO;VL@8V]M
M;6$M<V5P87)A=&5D(&1A=&$@*$-35BDN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T1A=&$O1&%T82]O=71L;V]K8W-V+G!H<"QV(#$N,RXQ,"XS(#(P,#4O
M,3`O,3@@,3$Z,#$Z,#0@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E
M7T1A=&$*("HO"F-L87-S($AO<F1E7T1A=&%?;W5T;&]O:V-S=B!E>'1E;F1S
M($AO<F1E7T1A=&%?8W-V('L*"B`@("`O*BH*("`@("`J($)U:6QD<R!A($-3
M5B!F:6QE(&9R;VT@82!G:79E;B!D871A('-T<G5C='5R92!A;F0@<F5T=7)N
M<R!I="!A<R!A"B`@("`@*B!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`@)&1A=&$@("`@("`@02!T=V\M9&EM96YS:6]N86P@87)R87D@
M8V]N=&%I;FEN9R!T:&4@9&%T80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<V5T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&AE861E<B`@
M("`@268@=')U92P@=&AE(')O=W,@;V8@)&1A=&$@87)E(&%S<V]C:6%T:79E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>7,@=VET
M:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@0U-6(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(@/2!F86QS92P@)&5X<&]R
M=%]M87!P:6YG(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1D871A*2!\?"!C;W5N="@D9&%T82D@/3T@,"D@>PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D97AP;W)T(#T@)R<[
M"B`@("`@("`@)&5O;"`](")<<EQN(CL*("`@("`@("`D:&5A9"`](&%R<F%Y
M7VME>7,H8W5R<F5N="@D9&%T82DI.PH@("`@("`@(&EF("@D:&5A9&5R*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1H96%D(&%S("1K97DI('L*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&ME>2DI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&5X<&]R=%]M87!P:6YG6R1K97E=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@)&5X<&]R=%]M87!P:6YG6R1K
M97E=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`D97AP;W)T("X]("<B)R`N("1K97D@+B`G(B<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D97AP;W)T("X]("<L)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D97AP;W)T(#T@<W5B<W1R*"1E>'!O<G0L(#`L
M("TQ*2`N("1E;VP["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9&%T
M82!A<R`D<F]W*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1H96%D(&%S("1K
M97DI('L*("`@("`@("`@("`@("`@("1C96QL(#T@)')O=ULD:V5Y73L*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&-E;&PI('Q\("1C96QL(#T]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2!P<F5G7W)E<&QA8V4H
M(B]<(B\B+"`B7")<(B(L("1C96QL*3L*("`@("`@("`@("`@("`@("`@("`D
M97AP;W)T("X]("<B)R`N("1C96QL("X@)R(G.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G+"<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&5X<&]R="`]('-U8G-T<B@D97AP;W)T+"`P+"`M
M,2D@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E>'!O<G0[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T1A=&$O=F-A<F0N<&AP````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C$T,P`Q,#4Q-30S,3`V,``P,C`V-S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O:6UC+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H<"<["@HO*BH*("H@
M26UP;&5M96YT('1H92!(;W)D95]$871A.CH@05!)(&9O<B!V0V%R9"!D871A
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A+T1A=&$O=F-A<F0N<&AP
M+'8@,2XS,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]$871A"B`J+PIC;&%S<R!(;W)D95]$871A7W9C
M87)D(&5X=&5N9',@2&]R9&5?1&%T85]I;6,@>PH*("`@("\J*@H@("`@("H@
M17AP;W)T<R!V8V%L96YD87(@9&%T82!A<R!A('-T<FEN9RX@56YL:6ME('9%
M=F5N="P@=D-A<F0@9&%T80H@("`@("H@:7,@;F]T(&5N8VQO<V5D(&EN($)%
M1TE.?$5.1#IV0V%L96YD87(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1D871A("`@("!!;B!A<G)A>2!C;VYT86EN:6YG($AO<F1E7VE#86QE;F1A
M<E]V8V%R9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W1S
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@:51I<"!M971H
M;V0@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M:4-A;&5N9&%R(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R=$1A
M=&$H)&1A=&$L("1M971H;V0@/2`G4D5154535"<I"B`@("!["B`@("`@("`@
M)',@/2`G)SL*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D=F-A<F0I('L*
M("`@("`@("`@("`@)',N/2`D=F-A<F0M/F5X<&]R='9#86QE;F1A<B@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)',["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]V=&]D
M;RYP:'``````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C(Q
M`#$P-3$U-#,Q,#8P`#`R,#<R-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RHJ(%=E(')E;'D@;VX@=&AE($AO
M<F1E7T1A=&%?:6UC.CH@86)S=')A8W0@8VQA<W,N("HO"G)E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O:6UC+G!H<"<["@HO*BH*("H@26UP
M;&5M96YT('1H92!(;W)D95]$871A.CH@05!)(&9O<B!V5&]D;R!D871A+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A+T1A=&$O=G1O9&\N<&AP+'8@
M,2XX+C$P+C,@,C`P-B\P,2\P,2`R,3HR.#HQ,R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E
M($AO<F1E7T1A=&$*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!(
M;W)D95]$871A7W9T;V1O(&5X=&5N9',@2&]R9&5?1&%T85]I;6,@>PH*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T
M82]T<W8N<&AP````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(Q,#,S`#$P-3$U-#,Q,#8P`#`R,#0Q,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@2&]R9&5?1&%T
M82!I;7!L96UE;G1A=&EO;B!F;W(@=&%B+7-E<&%R871E9"!D871A("A44U8I
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<"QV
M(#$N,C,N,3`N,3`@,C`P-B\P."\P,R`P,CHU,#HT,"!S96QS:WD@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N
M,PH@*B!`<&%C:V%G92!(;W)D95]$871A"B`J+PIC;&%S<R!(;W)D95]$871A
M7W1S=B!E>'1E;F1S($AO<F1E7T1A=&$@>PH*("`@('9A<B`D7V5X=&5N<VEO
M;B`]("=T<W8G.PH@("`@=F%R("1?8V]N=&5N=%1Y<&4@/2`G=&5X="]T86(M
M<V5P87)A=&5D+79A;'5E<R<["@H@("`@9G5N8W1I;VX@:6UP;W)T1&%T82@D
M8V]N=&5N=',L("1H96%D97(@/2!F86QS92P@)&1E;&EM:71E<B`](")<="(I
M"B`@("!["B`@("`@("`@)&-O;G1E;G1S(#T@97AP;&]D92@B7&XB+"`D8V]N
M=&5N=',I.PH@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@("!I9B`H
M)&AE861E<BD@>PH@("`@("`@("`@("`D:&5A9"`](&5X<&QO9&4H)&1E;&EM
M:71E<BP@87)R87E?<VAI9G0H)&-O;G1E;G1S*2D["B`@("`@("`@?0H@("`@
M("`@(&9O<F5A8V@@*"1C;VYT96YT<R!A<R`D;&EN92D@>PH@("`@("`@("`@
M("!I9B`H=')I;2@D;&EN92D@/3T@)R<I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L:6YE(#T@97AP
M;&]D92@D9&5L:6UI=&5R+"`D;&EN92D["B`@("`@("`@("`@(&EF("@A:7-S
M970H)&AE860I*2!["B`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&QI;F4[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;F5W;&EN
M92`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!C;W5N="@D:&5A9"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D
M;F5W;&EN95LD:&5A9%LD:5U=(#T@96UP='DH)&QI;F5;)&E=*2`_("<G(#H@
M)&QI;F5;)&E=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&1A=&%;72`]("1N97=L:6YE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J($)U
M:6QD<R!A(%135B!F:6QE(&9R;VT@82!G:79E;B!D871A('-T<G5C='5R92!A
M;F0@<F5T=7)N<R!I="!A<R!A"B`@("`@*B!S=')I;F<N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1D871A("`@("`@02!T=V\M9&EM96YS:6]N86P@
M87)R87D@8V]N=&%I;FEN9R!T:&4@9&%T82!S970N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D:&5A9&5R("!)9B!T<G5E+"!T:&4@<F]W<R!O9B`D9&%T82!A
M<F4@87-S;V-I871I=F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y<R!W:71H(&9I96QD(&YA;65S(&%S('1H96ER(&ME>7,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!44U8@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@97AP;W)T1&%T82@D9&%T82P@)&AE861E<B`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&$I('Q\(&-O
M=6YT*"1D871A*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("!]"B`@("`@("`@)&5X<&]R="`]("<G.PH@("`@("`@("1H96%D(#T@
M87)R87E?:V5Y<RAC=7)R96YT*"1D871A*2D["B`@("`@("`@:68@*"1H96%D
M97(I('L*("`@("`@("`@("`@)&5X<&]R="`](&EM<&QO9&4H(EQT(BP@)&AE
M860I("X@(EQN(CL*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&1A=&$@
M87,@)')O=RD@>PH@("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y
M*2!["B`@("`@("`@("`@("`@("`D8V5L;"`]("1R;W=;)&ME>5T["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1C96QL*2!\?"`D8V5L;"`]/3T@,"D@
M>PH@("`@("`@("`@("`@("`@("`@("1E>'!O<G0@+CT@)&-E;&P["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D97AP;W)T("X](")<="([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5X<&]R="`]('-U8G-T<B@D
M97AP;W)T+"`P+"`M,2D@+B`B7&XB.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&5X<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A(%13
M5B!F:6QE(&9R;VT@82!G:79E;B!D871A('-T<G5C='5R92!A;F0@=')I9V=E
M<G,@:71S(&1O=VYL;V%D+@H@("`@("H@270@1$]%4R!.3U0@97AI="!T:&4@
M8W5R<F5N="!S8W)I<'0@8G5T(&]N;'D@;W5T<'5T<R!T:&4@8V]R<F5C="!H
M96%D97)S"B`@("`@*B!A;F0@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F:6QE;F%M92`@5&AE(&YA;64@;V8@=&AE(&9I;&4@=&\@8F4@
M9&]W;FQO861E9"X*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("`@("!!
M('1W;RUD:6UE;G-I;VYA;"!A<G)A>2!C;VYT86EN:6YG('1H92!D871A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@<V5T+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&AE861E<B`@($EF('1R=64L('1H92!R;W=S(&]F("1D
M871A(&%R92!A<W-O8VEA=&EV90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y<R!W:71H(&9I96QD(&YA;65S(&%S('1H96ER(&ME>7,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R=$9I;&4H)&9I;&5N86UE+"`D
M9&%T82P@)&AE861E<B`](&9A;'-E*0H@("`@>PH@("`@("`@("1E>'!O<G0@
M/2`D=&AI<RT^97AP;W)T1&%T82@D9&%T82P@)&AE861E<BD["B`@("`@("`@
M)$=,3T)!3%-;)V)R;W=S97(G72T^9&]W;FQO861(96%D97)S*"1F:6QE;F%M
M92P@)W1E>'0O=&%B+7-E<&%R871E9"UV86QU97,G+"!F86QS92P@<W1R;&5N
M*"1E>'!O<G0I*3L*("`@("`@("!E8VAO("1E>'!O<G0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!486ME<R!A;&P@;F5C97-S87)Y(&%C=&EO;G,@9F]R('1H
M92!G:79E;B!I;7!O<G0@<W1E<"P@<&%R86UE=&5R<R!A;F0*("`@("`J(&9O
M<FT@=F%L=65S(&%N9"!R971U<FYS('1H92!N97AT(&YE8V5S<V%R>2!S=&5P
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VX@(%1H92!C
M=7)R96YT('-T97`N($]N92!O9B!T:&4@24U03U)47RH@8V]N<W1A;G1S+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;2`@("`@06X@87-S;V-I871I=F4@
M87)R87D@8V]N=&%I;FEN9R!N965D960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('!A<F%M971E<G,@9F]R('1H92!C=7)R96YT('-T97`N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R('1H92!N97AT('-T
M97`@87,@86X@:6YT96=E<B!C;VYS=&%N="!O<B!I;7!O<G1E9`H@("`@("H@
M("`@("`@("`@("`@("`@9&%T82!S970@869T97(@=&AE(&9I;F%L('-T97`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'13=&5P*"1A8W1I;VXL("1P87)A
M;2`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W=I=&-H("@D86-T:6]N*2![
M"B`@("`@("`@8V%S92!)35!/4E1?1DE,13H*("`@("`@("`@("`@)&YE>'1?
M<W1E<"`]('!A<F5N=#HZ;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&YE>'1?<W1E<"P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1N97AT7W-T97`["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D7U-%4U-)3TY;)VEM<&]R=%]D871A
M)UU;)V9O<FUA="==(#T]("=M=6QB97)R>2<@?'P*("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9F]R;6%T)UT@/3T@)W!I;F4G
M*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;
M)V1A=&$G72`]("1T:&ES+3YI;7!O<G1&:6QE*"1?1DE,15-;)VEM<&]R=%]F
M:6QE)UU;)W1M<%]N86UE)UTI.PH@("`@("`@("`@("`@("`@)&9O<FUA="`]
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9F]R;6%T)UT["B`@("`@("`@
M("`@("`@("!I9B`H)&9O<FUA="`]/2`G;75L8F5R<GDG*2!["B`@("`@("`@
M("`@("`@("`@("`@)&%P<$ME>7,@(#T@87)R87DH)V%L:6%S)RP@)VYA;64G
M+"`G96UA:6PG+"`G8V]M<&%N>2<L("=W;W)K061D<F5S<R<L("=W;W)K4&AO
M;F4G+"`G:&]M95!H;VYE)RP@)V9A>"<L("=N;W1E<R<I.PH@("`@("`@("`@
M("`@("`@("`@("1D871A2V5Y<R`](&%R<F%Y*#`L(#$L(#(L(#,L(#0L(#4L
M(#8L(#<L(#DI.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1F;W)M870@
M/3T@)W!I;F4G*2!["B`@("`@("`@("`@("`@("`@("`@)&%P<$ME>7,@/2!A
M<G)A>2@G86QI87,G+"`G;F%M92<L("=E;6%I;"<L("=N;W1E<R<I.PH@("`@
M("`@("`@("`@("`@("`@("1D871A2V5Y<R`](&%R<F%Y*#`L(#$L(#(L(#0I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&%P<$ME>7,@87,@)&ME>2`]/B`D87!P*2!["B`@("`@("`@("`@("`@("`@
M("`@)&UA<%LD9&%T84ME>7-;)&ME>5U=(#T@)&%P<#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG
M9&%T82==(&%S("1R;W<I('L*("`@("`@("`@("`@("`@("`@("`D:&%S:"`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1F;W)M870@/3T@
M)VUU;&)E<G)Y)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@B+UY'<G`Z+R(L("1R;W=;,%TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D<F]W6S%=(#T@<')E9U]R
M97!L86-E*"<O7BA;7BPB72LI+%QS*B@N*BDD+R<L("<D,B`D,2<L("1R;W=;
M,5TI.PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&%T84ME
M>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&%R<F%Y7VME>5]E>&ES=',H)&ME>2P@)')O=RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:&%S:%LD:V5Y72`]('-T<FEP<VQA<VAE
M<RAP<F5G7W)E<&QA8V4H)R]<7%Q<<B\G+"`B7&XB+"`D<F]W6R1K97E=*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&9O
M<FUA="`]/2`G<&EN92<I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&-O=6YT*"1R;W<I(#P@,R!\?"!P<F5G7VUA=&-H*"(O7B-$14Q%5$5$+R(L
M("1R;W=;,%TI('Q\('!R96=?;6%T8V@H(B];*"E=+R(L("1R;W=;,ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<F]W6S%=(#T@<')E9U]R97!L86-E*"<O7BA;7BPB72LI+%QS*B@N*BDD+R<L
M("<D,B`D,2<L("1R;W=;,5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`O
M*B!!9&1R97-S(&-A;B!B92!A(&9U;&P@4D9#.#(R(&%D9')E<W,@*B\*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+U)&0S@R
M,BYP:'`G.PH@("`@("`@("`@("`@("`@("`@("`@("`D861D<E]A<G(@/2!-
M86EL7U)&0S@R,CHZ<&%R<V5!9&1R97-S3&ES="@D<F]W6S)=*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1A9&1R7V%R<ELP72T^;6%I
M;&)O>"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("1R;W=;,ET@/2`D861D<E]A<G);,%TM/FUA:6QB;W@@+B`G0"<@
M+B`D861D<E]A<G);,%TM/FAO<W0["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D<F]W6S%=*2`F)B`A96UP='DH)&%D9')?87)R6S!=+3YP
M97)S;VYA;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;W=;
M,5T@/2`D861D<E]A<G);,%TM/G!E<G-O;F%L.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D
M871A2V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D:V5Y+"`D<F]W*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1K97E=(#T@)')O=ULD
M:V5Y73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D9&%T85M=(#T@)&AA<V@["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;
M)V1A=&$G72`]("1D871A.PH@("`@("`@("`@("`@("`@)%]315-324].6R=I
M;7!O<G1?9&%T82==6R=M87`G72`]("1M87`["B`@("`@("`@("`@("`@("`D
M<F5T(#T@)'1H:7,M/FYE>'13=&5P*$E-4$]25%]$051!+"`D<&%R86TI.PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($UO=F4@=7!L;V%D960@9FEL92!S;R!T:&%T('=E(&-A
M;B!R96%D(&ET(&%G86EN(&EN('1H92!N97AT('-T97`*("`@("`@("`@("`@
M("`@869T97(@=&AE('5S97(@9V%V92!S;VUE(&9O<FUA="!D971A:6QS+B`J
M+PH@("`@("`@("`@("`D=7!L;V%D960@/2!"<F]W<V5R.CIW87-&:6QE57!L
M;V%D960H)VEM<&]R=%]F:6QE)RP@7R@B5%-6(&9I;&4B*2D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1U<&QO861E9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'5P;&]A9&5D
M+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F
M:6QE7VYA;64@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)VEM<&]R="<L(&9A;'-E
M*3L*("`@("`@("`@("`@:68@*"%M;W9E7W5P;&]A9&5D7V9I;&4H)%]&24Q%
M4ULG:6UP;W)T7V9I;&4G75LG=&UP7VYA;64G72P@)&9I;&5?;F%M92DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H
M92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=F:6QE7VYA;64G72`]("1F:6QE7VYA;64["@H@("`@("`@("`@("`O*B!2
M96%D('1H92!F:6QE)W,@9FER<W0@='=O(&QI;F5S('1O('-H;W<@=&AE;2!T
M;R!T:&4@=7-E<BX@*B\*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=F:7)S=%]L:6YE<R==(#T@)R<["B`@("`@("`@("`@("1F<"`]
M($!F;W!E;B@D9FEL95]N86UE+"`G<B<I.PH@("`@("`@("`@("!I9B`H)&9P
M*2!["B`@("`@("`@("`@("`@("`D;&EN95]N;R`](#$["B`@("`@("`@("`@
M("`@("!W:&EL92`H)&QI;F5?;F\@/"`S("8F("1L:6YE(#T@9F=E=',H)&9P
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1N97=L:6YE(#T@4W1R:6YG.CIL
M96YG=&@H)&QI;F4I(#X@,3`P(#\@(EQN(B`Z("<G.PH@("`@("`@("`@("`@
M("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G
M72`N/2!S=6)S='(H)&QI;F4L(#`L(#$P,"D@+B`D;F5W;&EN93L*("`@("`@
M("`@("`@("`@("`@("`D;&EN95]N;RLK.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!)35!/4E1?5%-6.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)35!/4E1?5%-6.@H@
M("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VAE861E<B==
M(#T@571I;#HZ9V5T1F]R;41A=&$H)VAE861E<B<I.PH@("`@("`@("`@("`D
M:6UP;W)T7V1A=&$@/2`D=&AI<RT^:6UP;W)T1FEL92@D7U-%4U-)3TY;)VEM
M<&]R=%]D871A)UU;)V9I;&5?;F%M92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D
M871A)UU;)VAE861E<B==*3L*("`@("`@("`@("`@)%]315-324].6R=I;7!O
M<G1?9&%T82==6R=D871A)UT@/2`D:6UP;W)T7V1A=&$["B`@("`@("`@("`@
M('5N<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P)UTI.PH@("`@
M("`@("`@("!R971U<FX@24U03U)47TU!4%!%1#L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!P87)E
M;G0Z.FYE>'13=&5P*"1A8W1I;VXL("1P87)A;2D["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]$871A+VEC86QE;F1A<BYP:'``````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$R,#<`,3`U,34T,S$P-C``,#(Q-3$W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@HO*BH@5V4@
M<F5L>2!O;B!T:&4@2&]R9&5?1&%T85]I;6,Z.B!A8G-T<F%C="!C;&%S<RX@
M*B\*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]I;6,N<&AP
M)SL*"B\J*@H@*B!4:&ES(&ES(&E#86QE;F1A<B`H=D-A;&5N9&%R*2X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+VEC86QE;F1A<BYP:'`L
M=B`Q+C,Q+C$P+C,@,C`P-B\P,2\P,2`R,3HR.#HQ,R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!+87)S
M=&5N($9O=7)M;VYT(#QF;W5R;6]N=$!H;W)D92YO<F<^"B`J($!P86-K86=E
M($AO<F1E7T1A=&$*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!(
M;W)D95]$871A7VEC86QE;F1A<B!E>'1E;F1S($AO<F1E7T1A=&%?:6UC('L*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]$871A+W9N;W1E+G!H<```````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(S-S(`,3`U,34T,S$P-C``,#(P-S,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+VEM8RYP:'`G.PH*
M+RHJ"B`J($EM<&QE;65N="!T:&4@2&]R9&5?1&%T83HZ($%022!F;W(@=DYO
M=&4@9&%T82X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+W9N
M;W1E+G!H<"QV(#$N."XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<&%C:V%G92!(;W)D95]$871A"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B\*8VQA<W,@2&]R9&5?1&%T85]V;F]T92!E>'1E;F1S($AO<F1E7T1A=&%?
M:6UC('L*"B`@("`O*BH*("`@("`J($5X<&]R=',@=F-A;&5N9&%R(&1A=&$@
M87,@82!S=')I;F<N(%5N;&EK92!V179E;G0L('9.;W1E(&1A=&$*("`@("`J
M(&ES(&YO="!E;F-L;W-E9"!I;B!"14=)3GQ%3D0Z=D-A;&5N9&%R+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("`@06X@87)R87D@8V]N
M=&%I;FEN9R!(;W)D95]I0V%L96YD87)?=FYO=&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@;V)J96-T<RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&UE=&AO9"`@5&AE(&E4:7`@;65T:&]D('1O('5S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&E#86QE;F1A<B!D871A+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>'!O<G1$871A*"1D871A+"`D;65T:&]D(#T@)U)%
M455%4U0G*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@
M("1T:&ES+3Y?:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["@H@("`@
M("`@("1T:&ES+3Y?:4-A;"T^<V5T071T<FEB=71E*"=-151(3T0G+"`D;65T
M:&]D*3L*("`@("`@("`D<R`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1D871A
M(&%S("1E=F5N="D@>PH@("`@("`@("`@("`D<RX]("1E=F5N="T^97AP;W)T
M=D-A;&5N9&%R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<SL*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O:6UC+G!H
M<```````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C0R-P`Q
M,#4Q-30S,3`V,``P,C`S-38`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O:4-A
M;&5N9&%R+G!H<"<["@HO*BH*("H@06)S=')A8W0@:6UP;&5M96YT871I;VX@
M;V8@=&AE($AO<F1E7T1A=&$Z.B!!4$D@9F]R($E-0R!D871A("T*("H@=D-A
M<F1S(&%N9"!I0V%L96YD87(@9&%T82P@971C+B!0<F]V:61E<R!A(&YU;6)E
M<B!O9B!U=&EL:71Y"B`J(&UE=&AO9',@=&AA="!V0V%R9"!A;F0@:4-A;&5N
M9&%R(&EM<&QE;65N=&%T:6]N(&-A;B!S:&%R92!A;F0@<F5L>0H@*B!O;BX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`L=B`Q
M+C,R+C$P+C@@,C`P-B\P-2\P.2`R,SHP-CHP.2!C:'5C:R!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]$871A"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?1&%T85]I;6,@
M97AT96YD<R!(;W)D95]$871A('L*"B`@("!V87(@)%]I0V%L(#T@9F%L<V4[
M"@H@("`@9G5N8W1I;VX@:6UP;W)T1&%T82@D=&5X="D*("`@('L*("`@("`@
M("`D=&AI<RT^7VE#86P@/2!N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@("`@
M("`@:68@*"$D=&AI<RT^7VE#86PM/G!A<G-E=D-A;&5N9&%R*"1T97AT*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]I0V%L+3YG
M971#;VUP;VYE;G1S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@
M86X@:4-A;&5N9&%R(&9I;&4@9G)O;2!A(&=I=F5N(&1A=&$@<W1R=6-T=7)E
M(&%N9`H@("`@("H@<F5T=7)N<R!I="!A<R!A('-T<FEN9RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@($%N(&%R<F%Y(&-O;G1A:6YI
M;F<@2&]R9&5?:4-A;&5N9&%R7W9E=F5N=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!O8FIE8W1S"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H
M;V0@(%1H92!I5&EP(&UE=&AO9"!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!I0V%L96YD87(@9&%T82X*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AP;W)T1&%T82@D9&%T82P@)&UE=&AO9"`]("=215%515-4
M)RD*("`@('L*("`@("`@("`D=&AI<RT^7VE#86P@/2!N97<@2&]R9&5?:4-A
M;&5N9&%R*"D["B`@("`@("`@)'1H:7,M/E]I0V%L+3YS971!='1R:6)U=&4H
M)TU%5$A/1"<L("1M971H;V0I.PH*("`@("`@("!F;W)E86-H("@D9&%T82!A
M<R`D979E;G0I('L*("`@("`@("`@("`@)'1H:7,M/E]I0V%L+3YA9&1#;VUP
M;VYE;G0H)&5V96YT*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7VE#86PM/F5X<&]R='9#86QE;F1A<B@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0G5I;&1S(&%N(&E#86QE;F1A<B!F:6QE(&9R;VT@82!G:79E;B!D
M871A('-T<G5C='5R92!A;F0*("`@("`J('1R:6=G97)S(&ET<R!D;W=N;&]A
M9"X@($ET($1/15,@3D]4(&5X:70@=&AE(&-U<G)E;G0@<V-R:7!T(&)U=`H@
M("`@("H@;VYL>2!O=71P=71S('1H92!C;W)R96-T(&AE861E<G,@86YD(&1A
M=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@("!4
M:&4@;F%M92!O9B!T:&4@9FEL92!T;R!B92!D;W=N;&]A9&5D+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1D871A("`@("`@("!!;B!A<G)A>2!C;VYT86EN:6YG
M($AO<F1E7VE#86QE;F1A<E]V979E;G1S"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5X<&]R=$9I;&4H)&9I;&5N86UE+"`D9&%T82D*("`@('L*("`@("`@("`D
M97AP;W)T(#T@)'1H:7,M/F5X<&]R=$1A=&$H)&1A=&$I.PH@("`@("`@("1'
M3$]"04Q36R=B<F]W<V5R)UTM/F1O=VYL;V%D2&5A9&5R<R@D9FEL96YA;64L
M("=T97AT+V-A;&5N9&%R)RP@9F%L<V4L('-T<FQE;B@D97AP;W)T*2D["B`@
M("`@("`@96-H;R`D97AP;W)T.PH@("`@?0H*("`@("\J*@H@("`@("H@5&%K
M97,@86QL(&YE8V5S<V%R>2!A8W1I;VYS(&9O<B!T:&4@9VEV96X@:6UP;W)T
M('-T97`L"B`@("`@*B!P87)A;65T97)S(&%N9"!F;W)M('9A;'5E<R!A;F0@
M<F5T=7)N<R!T:&4@;F5X="!N96-E<W-A<GD@<W1E<"X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D86-T:6]N("!4:&4@8W5R<F5N="!S=&5P+B!/
M;F4@;V8@=&AE($E-4$]25%\J(&-O;G-T86YT<RX*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86T@("`@($%N(&%S<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI
M;F<@;F5E9&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A
M;65T97)S(&9O<B!T:&4@8W5R<F5N="!S=&5P+@H@("`@("H@0')E='5R;B!M
M:7AE9"`@16ET:&5R('1H92!N97AT('-T97`@87,@86X@:6YT96=E<B!C;VYS
M=&%N="!O<B!I;7!O<G1E9`H@("`@("H@("`@("`@("`@("`@("`@9&%T82!S
M970@869T97(@=&AE(&9I;F%L('-T97`N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YE>'13=&5P*"1A8W1I;VXL("1P87)A;2`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@<W=I=&-H("@D86-T:6]N*2!["B`@("`@("`@8V%S92!)35!/4E1?
M1DE,13H*("`@("`@("`@("`@)&YE>'1?<W1E<"`]('!A<F5N=#HZ;F5X=%-T
M97`H)&%C=&EO;BP@)'!A<F%M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&YE
M>'1?<W1E<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1N97AT7W-T97`["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1I
M;7!O<G1?9&%T82`]("1T:&ES+3YI;7!O<G1&:6QE*"1?1DE,15-;)VEM<&]R
M=%]F:6QE)UU;)W1M<%]N86UE)UTI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M:6UP;W)T7V1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D:6UP;W)T7V1A=&$["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VE#86PM/F=E=$-O;7!O;F5N=',H*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M(')E='5R;B!P87)E;G0Z.FYE>'13=&5P*"1A8W1I;VXL("1P87)A;2D["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A+V-S=BYP
M:'``````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8W-#<`
M,3`U,34T,S$P-C``,#(P-#$P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!(;W)D95]$871A(&EM<&QE
M;65N=&%T:6]N(&9O<B!C;VUM82US97!A<F%T960@9&%T82`H0U-6*2X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`L=B`Q+C,P
M+C$P+C@@,C`P-B\P,2\R."`Q-CHR,3HU."!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P
M86-K86=E($AO<F1E7T1A=&$*("HO"F-L87-S($AO<F1E7T1A=&%?8W-V(&5X
M=&5N9',@2&]R9&5?1&%T82!["@H@("`@=F%R("1?97AT96YS:6]N(#T@)V-S
M=B<["B`@("!V87(@)%]C;VYT96YT5'EP92`]("=T97AT+V-O;6UA+7-E<&%R
M871E9"UV86QU97,G.PH*("`@("\J*@H@("`@("H@5')I97,@=&\@9&ES8V]V
M97(@=&AE($-35B!F:6QE)W,@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&YA;64@;V8@=&AE(&9I;&4@
M=&\@:6YV97-T:6=A=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M06X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG('!O<W-I
M8FQE(&ME>7,Z"B`@("`@*B`\<')E/@H@("`@("H@)W-E<"<Z("`@(%1H92!F
M:65L9"!S97!A<F%T;W(*("`@("`J("=Q=6]T92<Z("!4:&4@<75O=&EN9R!C
M:&%R86-T97(*("`@("`J("=F:65L9',G.B!4:&4@;G5M8F5R(&]F(&9I96QD
M<R`H8V]L=6UN<RD*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D:7-C;W9E<D9O<FUA="@D9FEL96YA;64I"B`@("!["B`@("`@("`@0&EN
M8VQU9&5?;VYC92@G1FEL92]#4U8N<&AP)RD["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@G1FEL95]#4U8G*2D@>PH@("`@("`@("`@("!R971U<FX@1FEL
M95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"1F:6QE;F%M92D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=S97`G(#T^("<L)RD[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@26UP;W)T<R!A;F0@
M<&%R<V5S(&$@0U-6(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9FEL96YA;64@(%1H92!N86UE(&]F('1H92!F:6QE('1O('!A<G-E+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&AE861E<B`@($1O97,@=&AE(&9I<G-T
M(&QI;F4@8V]N=&%I;B!T:&4@9FEE;&0O8V]L=6UN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@;F%M97,_"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S97`@("`@("`@5&AE(&9I96QD+V-O;'5M;B!S97!A<F%T;W(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1Q=6]T92`@("`@5&AE('%U;W1I;F<@8VAA<F%C
M=&5R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9I96QD<R`@(%1H92!N=6UB
M97(@;W(@9FEE;&1S+V-O;'5M;G,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M:&%R<V5T("`@5&AE(&9I;&4G<R!C:&%R<V5T+B!`<VEN8V4@2&]R9&4@,RXQ
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W)L9B`@("`@(%1H92!F:6QE)W,@
M;&EN969E960@8VAA<F%C=&5R<RX@0'-I;F-E($AO<F1E(#,N,2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!('1W;RUD:6UE;G-I;VYA;"!A<G)A
M>2!O9B!A;&P@:6UP;W)T960@9&%T82!R;W=S+B`@268*("`@("`J("`@("`@
M("`@("`@("`@("1H96%D97(@=V%S('1R=64@=&AE(')O=W,@87)E(&%S<V]C
M:6%T:79E(&%R<F%Y<R!W:71H('1H90H@("`@("H@("`@("`@("`@("`@("`@
M9FEE;&0O8V]L=6UN(&YA;65S(&%S('1H92!K97ES+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I;7!O<G1&:6QE*"1F:6QE;F%M92P@)&AE861E<B`](&9A;'-E
M+"`D<V5P(#T@)R<L("1Q=6]T92`]("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEE;&1S(#T@;G5L;"P@)&EM<&]R=%]M87!P:6YG(#T@87)R87DH
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)&-H87)S970@/2!N=6QL+"`D
M8W)L9B`](&YU;&PI"B`@("!["B`@("`@("`@0&EN8VQU9&5?;VYC92@G1FEL
M92]#4U8N<&AP)RD["@H@("`@("`@("1D871A(#T@87)R87DH*3L*"B`@("`@
M("`@+RH@1FEL95]#4U8@:7,@<')E<V5N="X@*B\*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"=&:6QE7T-35B<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M=V%R;FEN9W,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@+RH@1FEL95]#4U8@
M:7,@82!B:70@<&EC:WD@870@=VAA="!P87)A;65T97(@:70@97AP96-T<RX@
M*B\*("`@("`@("`@("`@)&-O;F8@/2!A<G)A>2@I.PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1Q=6]T92DI('L*("`@("`@("`@("`@("`@("1C;VYF6R=Q
M=6]T92==(#T@)'%U;W1E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D<V5P*2D@>PH@("`@("`@("`@("`@("`@)&-O;F9;)W-E<"==
M(#T@)RPG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&-O;F9;)W-E<"==(#T@)'-E<#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&9I96QD<RD@>PH@("`@("`@("`@("`@("`@)&-O;F9;)V9I96QD
M<R==(#T@)&9I96QD<SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1C<FQF*2D@>PH@("`@("`@("`@("`@("`@)&-O;F9;
M)V-R;&8G72`]("1C<FQF.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!3=')I<"!A;F0@:V5E<"!T:&4@9FER<W0@;&EN92!I9B!I="!C;VYT86EN
M<R!T:&4@9FEE;&0*("`@("`@("`@("`@("H@;F%M97,N("HO"B`@("`@("`@
M("`@(&EF("@D:&5A9&5R*2!["B`@("`@("`@("`@("`@("`D:&5A9"`]($9I
M;&5?0U-6.CIR96%D*"1F:6QE;F%M92P@)&-O;F8I.PH@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)&AE860L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)&AE860["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1H96%D(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M:&5A9"P@)&-H87)S970L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@=VAI;&4@*"1L
M:6YE(#T@1FEL95]#4U8Z.G)E860H)&9I;&5N86UE+"`D8V]N9BDI('L*("`@
M("`@("`@("`@("`@(&EF("AI<U]A*"1L:6YE+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1L:6YE.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI
M('L*("`@("`@("`@("`@("`@("`@("`D;&EN92`](%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)&QI;F4L("1C:&%R<V5T+"!.3%,Z.F=E=$-H87)S970H*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1H96%D*2D@>PH@("`@("`@("`@("`@("`@("`@("1D871A6UT@/2`D;&EN
M93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&YE=VQI;F4@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1H96%D*3L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EM<&]R=%]M87!P:6YG6R1H
M96%D6R1I75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:&5A
M9%LD:5T@/2`D:6UP;W)T7VUA<'!I;F=;)&AE861;)&E=73L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D8V5L
M;"`]("1L:6YE6R1I73L*("`@("`@("`@("`@("`@("`@("`@("`@)&-E;&P@
M/2!P<F5G7W)E<&QA8V4H(B]<(EPB+R(L(")<(B(L("1C96QL*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE=VQI;F5;)&AE861;)&E=72`](&5M<'1Y
M*"1C96QL*2`_("<G(#H@)&-E;&P["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1D871A6UT@/2`D;F5W;&EN93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9P(#T@
M1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I;&5N86UE+"`D8V]N9BD["B`@("`@
M("`@("`@(&EF("@D9G`@)B8@(6ES7V$H)&9P+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R97=I;F0H)&9P*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG<R`]($9I;&5?0U-6.CIW87)N
M:6YG*"D["@H@("`@("`@("\J($9A;&P@8F%C:R!T;R!F9V5T8W-V*"DN("HO
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)&9I
M;&5N86UE+"`G<B<I.PH@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!3=')I<"!A;F0@:V5E<"!T:&4@9FER<W0@;&EN92!I9B!I="!C
M;VYT86EN<R!T:&4@9FEE;&0*("`@("`@("`@("`@("`@;F%M97,N("HO"B`@
M("`@("`@("`@(&EF("@D:&5A9&5R*2!["B`@("`@("`@("`@("`@("`D:&5A
M9"`](&9G971C<W8H)&9P+"`Q,#(T+"`D<V5P*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@>PH@("`@("`@("`@
M("`@("`@)&AE860@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1H96%D+"`D
M8VAA<G-E="P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@('=H:6QE("@D;&EN92`](&9G971C<W8H)&9P+"`Q,#(T+"`D
M<V5P*2D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI
M('L*("`@("`@("`@("`@("`@("`@("`D;&EN92`](%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)&QI;F4L("1C:&%R<V5T+"!.3%,Z.F=E=$-H87)S970H*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1H96%D*2D@>PH@("`@("`@("`@("`@("`@("`@("1D871A6UT@/2`D;&EN
M93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&YE=VQI;F4@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1H96%D*3L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EM<&]R=%]M87!P:6YG6R1H
M96%D6R1I75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:&5A
M9%LD:5T@/2`D:6UP;W)T7VUA<'!I;F=;)&AE861;)&E=73L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D8V5L
M;"`]("1L:6YE6R1I73L*("`@("`@("`@("`@("`@("`@("`@("`@)&-E;&P@
M/2!P<F5G7W)E<&QA8V4H(B]<(B\B+"`B7")<(B(L("1C96QL*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE=VQI;F5;)&AE861;)&E=72`](&5M<'1Y
M*"1C96QL*2`_("<G(#H@)&-E;&P["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1D871A6UT@/2`D;F5W;&EN93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F-L;W-E
M*"1F<"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*
M"B`@("`O*BH*("`@("`J($)U:6QD<R!A($-35B!F:6QE(&9R;VT@82!G:79E
M;B!D871A('-T<G5C='5R92!A;F0@<F5T=7)N<R!I="!A<R!A"B`@("`@*B!S
M=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D871A("`@("`@
M02!T=V\M9&EM96YS:6]N86P@87)R87D@8V]N=&%I;FEN9R!T:&4@9&%T82!S
M970N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R("!)9B!T<G5E+"!T
M:&4@<F]W<R!O9B`D9&%T82!A<F4@87-S;V-I871I=F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y<R!W:71H(&9I96QD(&YA;65S(&%S
M('1H96ER(&ME>7,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!#4U8@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T1&%T82@D
M9&%T82P@)&AE861E<B`](&9A;'-E+"`D97AP;W)T7VUA<'!I;F<@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&$I('Q\(&-O
M=6YT*"1D871A*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("!]"@H@("`@("`@("1E>'!O<G0@/2`G)SL*("`@("`@("`D96]L(#T@
M(EQN(CL*("`@("`@("`D:&5A9"`](&%R<F%Y7VME>7,H8W5R<F5N="@D9&%T
M82DI.PH@("`@("`@(&EF("@D:&5A9&5R*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1H96%D(&%S("1K97DI('L*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&ME>2DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5X
M<&]R=%]M87!P:6YG6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D:V5Y(#T@)&5X<&]R=%]M87!P:6YG6R1K97E=.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D97AP;W)T("X]("<B)R`N
M("1K97D@+B`G(B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D97AP;W)T("X]("<L)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M97AP;W)T(#T@<W5B<W1R*"1E>'!O<G0L(#`L("TQ*2`N("1E;VP["B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D<F]W*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1H96%D(&%S("1K97DI('L*("`@("`@("`@("`@
M("`@("1C96QL(#T@)')O=ULD:V5Y73L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)&-E;&PI('Q\("1C96QL(#T]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)&5X<&]R="`N/2`G(B<@+B`D8V5L;"`N("<B)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1E>'!O<G0@+CT@)RPG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1E>'!O<G0@/2!S=6)S='(H)&5X<&]R
M="P@,"P@+3$I("X@)&5O;#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M97AP;W)T.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&$@0U-6(&9I
M;&4@9G)O;2!A(&=I=F5N(&1A=&$@<W1R=6-T=7)E(&%N9"!T<FEG9V5R<R!I
M=',*("`@("`J(&1O=VYL;V%D+B`@270@1$]%4R!.3U0@97AI="!T:&4@8W5R
M<F5N="!S8W)I<'0@8G5T(&]N;'D@;W5T<'5T<R!T:&4*("`@("`J(&-O<G)E
M8W0@:&5A9&5R<R!A;F0@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QE;F%M92`@5&AE(&YA;64@;V8@=&AE(&9I;&4@=&\@8F4@9&]W
M;FQO861E9"X*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("`@("!!('1W
M;RUD:6UE;G-I;VYA;"!A<G)A>2!C;VYT86EN:6YG('1H92!D871A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@<V5T+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&AE861E<B`@($EF('1R=64L('1H92!R;W=S(&]F("1D871A
M(&%R92!A<W-O8VEA=&EV90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y<R!W:71H(&9I96QD(&YA;65S(&%S('1H96ER(&ME>7,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R=$9I;&4H)&9I;&5N86UE+"`D9&%T
M82P@)&AE861E<B`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`D
M97AP;W)T7VUA<'!I;F<@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1E>'!O
M<G0@/2`D=&AI<RT^97AP;W)T1&%T82@D9&%T82P@)&AE861E<BP@)&5X<&]R
M=%]M87!P:6YG*3L*("`@("`@("`D1TQ/0D%,4ULG8G)O=W-E<B==+3YD;W=N
M;&]A9$AE861E<G,H)&9I;&5N86UE+"`G87!P;&EC871I;VXO8W-V)RP@9F%L
M<V4L('-T<FQE;B@D97AP;W)T*2D["B`@("`@("`@96-H;R`D97AP;W)T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&%K97,@86QL(&YE8V5S<V%R>2!A8W1I
M;VYS(&9O<B!T:&4@9VEV96X@:6UP;W)T('-T97`L('!A<F%M971E<G,@86YD
M"B`@("`@*B!F;W)M('9A;'5E<R!A;F0@<F5T=7)N<R!T:&4@;F5X="!N96-E
M<W-A<GD@<W1E<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D86-T
M:6]N("!4:&4@8W5R<F5N="!S=&5P+B!/;F4@;V8@=&AE($E-4$]25%\J(&-O
M;G-T86YT<RX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86T@("`@($%N(&%S
M<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@;F5E9&5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&9O<B!T:&4@8W5R<F5N
M="!S=&5P+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!T
M:&4@;F5X="!S=&5P(&%S(&%N(&EN=&5G97(@8V]N<W1A;G0@;W(@:6UP;W)T
M960*("`@("`J("`@("`@("`@("`@("`@(&1A=&$@<V5T(&%F=&5R('1H92!F
M:6YA;"!S=&5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT4W1E<"@D86-T
M:6]N+"`D<&%R86T@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)&%C=&EO;BD@>PH@("`@("`@(&-A<V4@24U03U)47T9)3$4Z"B`@("`@("`@
M("`@("1N97AT7W-T97`@/2!P87)E;G0Z.FYE>'13=&5P*"1A8W1I;VXL("1P
M87)A;2D["B`@("`@("`@("`@(&EF("AI<U]A*"1N97AT7W-T97`L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;F5X=%]S=&5P
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!-;W9E('5P;&]A9&5D
M(&9I;&4@<V\@=&AA="!W92!C86X@<F5A9"!I="!A9V%I;B!I;B!T:&4@;F5X
M=`H@("`@("`@("`@("`@("!S=&5P(&%F=&5R('1H92!U<V5R(&=A=F4@<V]M
M92!F;W)M870@9&5T86EL<RX@*B\*("`@("`@("`@("`@)&9I;&5?;F%M92`]
M($AO<F1E.CIG971496UP1FEL92@G:6UP;W)T)RP@9F%L<V4I.PH@("`@("`@
M("`@("!I9B`H(6UO=F5?=7!L;V%D961?9FEL92@D7T9)3$536R=I;7!O<G1?
M9FEL92==6R=T;7!?;F%M92==+"`D9FEL95]N86UE*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(I*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I;&5?;F%M
M92==(#T@)&9I;&5?;F%M93L*"B`@("`@("`@("`@("\J(%1R>2!T;R!D:7-C
M;W9E<B!T:&4@9FEL92!F;W)M870@;W5R<V5L=F5S+B`J+PH@("`@("`@("`@
M("`D8V]N9B`]("1T:&ES+3YD:7-C;W9E<D9O<FUA="@D9FEL95]N86UE*3L*
M("`@("`@("`@("`@:68@*"$D8V]N9BD@>PH@("`@("`@("`@("`@("`@)&-O
M;F8@/2!A<G)A>2@G<V5P)R`]/B`G+"<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G72`](&%R<F%Y7VUE<F=E
M*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G72P@)&-O;F8I.PH*("`@("`@("`@
M("`@+RH@0VAE8VL@:68@8VAA<G-E="!W87,@<W!E8VEF:65D+B`J+PH@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V-H87)S970G72`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=C:&%R<V5T)RD["@H@("`@("`@("`@("`O
M*B!296%D('1H92!F:6QE)W,@9FER<W0@='=O(&QI;F5S('1O('-H;W<@=&AE
M;2!T;R!T:&4@=7-E<BX@*B\*("`@("`@("`@("`@)%]315-324].6R=I;7!O
M<G1?9&%T82==6R=F:7)S=%]L:6YE<R==(#T@)R<["B`@("`@("`@("`@("1F
M<"`]($!F;W!E;B@D9FEL95]N86UE+"`G<B<I.PH@("`@("`@("`@("!I9B`H
M)&9P*2!["B`@("`@("`@("`@("`@("`D;&EN95]N;R`](#$["B`@("`@("`@
M("`@("`@("!W:&EL92`H)&QI;F5?;F\@/"`S("8F("1L:6YE(#T@9F=E=',H
M)&9P*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)%]315-3
M24].6R=I;7!O<G1?9&%T82==6R=C:&%R<V5T)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1L:6YE(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M;&EN92P@)%]315-324].6R=I;7!O<G1?9&%T82==6R=C:&%R<V5T)UTL($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)&YE=VQI;F4@/2!3=')I;F<Z.FQE;F=T:"@D;&EN
M92D@/B`Q,#`@/R`B7&XB(#H@)R<["B`@("`@("`@("`@("`@("`@("`@)%]3
M15-324].6R=I;7!O<G1?9&%T82==6R=F:7)S=%]L:6YE<R==("X]('-U8G-T
M<B@D;&EN92P@,"P@,3`P*2`N("1N97=L:6YE.PH@("`@("`@("`@("`@("`@
M("`@("1L:6YE7VYO*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N($E-4$]25%]#4U8["@H@("`@("`@(&-A
M<V4@24U03U)47T-35CH*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=H96%D97(G72`](%5T:6PZ.F=E=$9O<FU$871A*"=H96%D97(G
M*3L*("`@("`@("`@("`@)&EM<&]R=%]M87!P:6YG(#T@87)R87DH*3L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1P87)A;5LG:6UP;W)T7VUA<'!I;F<G72DI
M('L*("`@("`@("`@("`@("`@("1I;7!O<G1?;6%P<&EN9R`]("1P87)A;5LG
M:6UP;W)T7VUA<'!I;F<G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M:6UP;W)T7V1A=&$@/2`D=&AI<RT^:6UP;W)T1FEL92@D7U-%4U-)3TY;)VEM
M<&]R=%]D871A)UU;)V9I;&5?;F%M92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D
M871A)UU;)VAE861E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M1&%T82@G<V5P)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%5T
M:6PZ.F=E=$9O<FU$871A*"=Q=6]T92<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M1&%T82@G
M9FEE;&1S)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;7!O<G1?;6%P<&EN9RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=C:&%R<V5T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG
M8W)L9B==*3L*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=D871A)UT@/2`D:6UP;W)T7V1A=&$["B`@("`@("`@("`@('5N<V5T*"1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P)UTI.PH@("`@("`@("`@("!R
M971U<FX@24U03U)47TU!4%!%1#L*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N('!A<F5N=#HZ;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M
M*3L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"\`
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C``,#$W,C4W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T=R87!H+U!L;W0O````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,C`Q-S4`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O4&QO="]B87)G<F]U
M<&5D+G!H<```````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-3<R`#$P-3$U-#,Q
M,#8P`#`R,S`T,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]'<F%P:"]0;&]T
M+V)A<BYP:'`G.PH*+RHJ"B`J($=R;W5P960@8F%R(&=R87!H(&EM<&QE;65N
M=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A<&@@<&%C:V%G92X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A<&@O4&QO="]B87)G<F]U<&5D+G!H
M<"QV(#$N,2XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,3@@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T=R87!H"B`J+PIC;&%S<R!(;W)D
M95]'<F%P:%]0;&]T7V)A<F=R;W5P960@97AT96YD<R!(;W)D95]'<F%P:%]0
M;&]T7V)A<B!["@H@("`@=F%R("1?<W1E<"`]("XU.PH@("`@=F%R("1?8V]L
M;W)S(#T@87)R87DH*3L*("`@('9A<B`D7V1A=&%S971S(#T@87)R87DH*3L*
M"B`@("!F=6YC=&EO;B!D<F%W*"D*("`@('L*("`@("`@("`O+R!#86QC=6QA
M=&4@=&AE('-T87)T:6YG(&]F9G-E="!F;W(@96%C:"!B87(L(&9R;VT@=VAI
M8V@@=V4*("`@("`@("`O+R!M;W9E(&ET(&]V97(@8GD@)'1H:7,M/E]S=&5P
M+@H@("`@("`@("1D871A<V5T<R`](&-O=6YT*"1T:&ES+3Y?9&%T87-E=',I
M.PH@("`@("`@("1G;&]B86Q/9F9S970@/2`D=&AI<RT^7V]F9G-E="`M("@H
M)'1H:7,M/E]S=&5P("H@*"1D871A<V5T<R`M(#$I*2`O(#(I.PH*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D9&%T87-E=',[("1I*RLI('L*("`@("`@
M("`@("`@+R\@0V%L8W5L871E('1H92!O9F9S970@;V8@=&AI<R!S970@;V8@
M8F%R<RX*("`@("`@("`@("`@)'1H:7,M/E]O9F9S970@/2`D9VQO8F%L3V9F
M<V5T("L@*"1T:&ES+3Y?<W1E<"`J("1I*3L*"B`@("`@("`@("`@("\O(%-E
M="!B87(@<&%R86UE=&5R<R!T:&%T(&-H86YG92!P97(M9W)O=7`N"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-O;&]R<ULD:5TI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-O;&]R(#T@)'1H:7,M/E]C;VQO<G-;)&E=
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9&%T87-E="`]
M("1T:&ES+3Y?9&%T87-E='-;)&E=.PH*("`@("`@("`@("`@+R\@1')A=R!T
M:&ES(&1A=&%S970N"B`@("`@("`@("`@('!A<F5N=#HZ9')A=R@I.PH@("`@
M("`@('T*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]'<F%P:"]0;&]T+V)A<BYP:'``````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,P,C,`,3`U,34T,S$P-C``,#(Q-#0U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!"
M87(@9W)A<&@@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P:"!P
M86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P:"]0
M;&]T+V)A<BYP:'`L=B`Q+C4N,3(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$X(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@*B\*
M8VQA<W,@2&]R9&5?1W)A<&A?4&QO=%]B87(@>PH*("`@('9A<B`D9W)A<&@[
M"@H@("`@=F%R("1?8V]L;W(@/2`G8FQU92<["B`@("!V87(@)%]O=71L:6YE
M(#T@)V)L86-K)SL*("`@('9A<B`D7W=I9'1H(#T@,3`["B`@("!V87(@)%]O
M9F9S970@/2`P.PH@("`@=F%R("1?9&%T87-E=#L*"B`@("!F=6YC=&EO;B!(
M;W)D95]'<F%P:%]0;&]T7V)A<B@F)&=R87!H+"`D<&%R86US*0H@("`@>PH@
M("`@("`@("1T:&ES+3YG<F%P:"`]("8D9W)A<&@["@H@("`@("`@(&9O<F5A
M8V@@*"1P87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("`D=&AI<RT^)&ME
M>2`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9')A
M=R@D;6EN62`](&9A;'-E*0H@("`@>PH@("`@("`@("1D871A(#T@)'1H:7,M
M/F=R87!H+3Y?9&%T85LG>2==6R1T:&ES+3Y?9&%T87-E=%T["@H@("`@("`@
M("1B87)7:61T:"`]("1T:&ES+3Y?=VED=&@["B`@("`@("`@)&)A<D]F9G-E
M="`]("1T:&ES+3Y?;V9F<V5T("H@)&)A<E=I9'1H.PH@("`@("`@("1U(#T@
M,#L*("`@("`@("`D=B`](#`["B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&1A
M=&$I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@
M>PH@("`@("`@("`@("`D>"`]("1I.PH@("`@("`@("`@("!I9B`H)&UI;ED@
M/3T](&9A;'-E('Q\("1D871A6R1I72`^/2`D;6EN62D@>PH@("`@("`@("`@
M("`@("`@)'D@/2`D9&%T85LD:5T["B`@("`@("`@("`@("`@("`D=&AI<RT^
M9W)A<&@M/G1R86YS;&%T92@D>"P@)'DI.PH@("`@("`@("`@("`@("`@)'@@
M/2`D>"`M("@D8F%R5VED=&@@+R`R*2`K("1B87)/9F9S970["B`@("`@("`@
M("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=R87!H+3Y?9W)A<&A";W1T;VT@
M+2`D>3L*"B`@("`@("`@("`@("`@("`D=&AI<RT^9W)A<&@M/FEM9RT^<F5C
M=&%N9VQE*"1X+"`D>2P@)&)A<E=I9'1H+"`D:&5I9VAT+"`D=&AI<RT^7V]U
M=&QI;F4L("1T:&ES+3Y?8V]L;W(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M1W)A<&@O4&QO="]B87)S=&%C:V5D+G!H<```````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-C(U`#$P-3$U-#,Q,#8P`#`R,S`Q,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@4W1A8VME
M9"!B87(@9W)A<&@@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P
M:"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P
M:"]0;&]T+V)A<G-T86-K960N<&AP+'8@,2XQ+C$P+C0@,C`P-B\P,2\P,2`R
M,3HR.#HQ."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M1W)A<&@*("HO"F-L87-S($AO<F1E7T=R87!H7U!L;W1?8F%R<W1A8VME9"![
M"@H@("`@=F%R("1G<F%P:#L*"B`@("!V87(@)%]C;VQO<B`]("=B;'5E)SL*
M("`@('9A<B`D7V]U=&QI;F4@/2`G8FQA8VLG.PH@("`@=F%R("1?=VED=&@@
M/2`Q,#L*("`@('9A<B`D7V]F9G-E="`](#`["B`@("!V87(@)%]D871A<V5T
M.PH*("`@(&9U;F-T:6]N($AO<F1E7T=R87!H7U!L;W1?8F%R<W1A8VME9"@F
M)&=R87!H+"`D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3YG<F%P:"`]
M("8D9W)A<&@["@H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M
M.PH@("`@("`@("`@("`D=&AI<RT^)&ME>2`]("1V86QU93L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@9')A=R@I"B`@("!["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O1W)A<&@O4&QO="]L:6YE+G!H<```````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,C4W`#$P-3$U-#,Q,#8P`#`R,38T,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M3&EN92!G<F%P:"!I;7!L96UE;G1A=&EO;B!F;W(@=&AE($AO<F1E7T=R87!H
M('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T=R87!H+T=R87!H
M+U!L;W0O;&EN92YP:'`L=B`Q+C0N,3(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@
M*B\*8VQA<W,@2&]R9&5?1W)A<&A?4&QO=%]L:6YE('L*"B`@("!V87(@)%]G
M<F%P:#L*("`@('9A<B`D7V-O;&]R(#T@)V)L=64G.PH@("`@=F%R("1?=VED
M=&@@/2`Q.PH@("`@=F%R("1?9&%T87-E=#L*"B`@("!F=6YC=&EO;B!(;W)D
M95]'<F%P:%]0;&]T7VQI;F4H)B1G<F%P:"P@)'!A<F%M<RD*("`@('L*("`@
M("`@("`D=&AI<RT^7V=R87!H(#T@)B1G<F%P:#L*"B`@("`@("`@9F]R96%C
M:"`H)'!A<F%M<R!A<R`D<&%R86T@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("1K97D@/2`G7R<@+B`D<&%R86T["B`@("`@("`@("`@("1T:&ES+3XD:V5Y
M(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D<F%W
M*"1M:6Y9(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^
M7V=R87!H+3Y?9&%T85LG>2==6R1T:&ES+3Y?9&%T87-E=%T["@H@("`@("`@
M("1C;W5N="`](&-O=6YT*"1D871A*3L*("`@("`@("`D=F5R=',@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@
M>PH@("`@("`@("`@("`D>"`]("1I.PH@("`@("`@("`@("!I9B`H)&UI;ED@
M(3T](&9A;'-E("8F("1D871A6R1I72`\("1M:6Y9*2!["B`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)'9E<G1S*2`]/2`Q*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G<F%P:"T^:6UG+3YC:7)C;&4H)'9E<G1S6S!=6R=X
M)UTL("1V97)T<ULP75LG>2==+"`D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7V-O
M;&]R+"`D=&AI<RT^7V-O;&]R*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9W)A<&@M/FEM9RT^<&]L>6QI;F4H)'9E<G1S+"`D=&AI<RT^7V-O;&]R+"`D
M=&AI<RT^7W=I9'1H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1V97)T<R`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("`D>2`]("1D871A6R1I73L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9W)A<&@M/G1R86YS;&%T92@D>"P@)'DI
M.PH@("`@("`@("`@("`@("`@)'9E<G1S6UT@/2!A<G)A>2@G>"<@/3X@)'@L
M("=Y)R`]/B`D>2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?9W)A<&@M/FEM9RT^<&]L>6QI;F4H)'9E<G1S+"`D=&AI<RT^
M7V-O;&]R+"`D=&AI<RT^7W=I9'1H*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T=R87!H+U!L;W0O<V-A='1E<BYP:'``````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C0R,0`Q,#4Q-30S,3`V,``P,C(S-#<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%-C871T
M97(@<&QO="!I;7!L96UE;G1A=&EO;B!F;W(@=&AE($AO<F1E7T=R87!H('!A
M8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T=R87!H+T=R87!H+U!L
M;W0O<V-A='1E<BYP:'`L=B`Q+C,N,3(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@
M*B\*8VQA<W,@2&]R9&5?1W)A<&A?4&QO=%]S8V%T=&5R('L*"B`@("!V87(@
M)%]G<F%P:#L*("`@('9A<B`D7V-O;&]R(#T@)V)L=64G.PH@("`@=F%R("1?
M<VAA<&4@/2`G<W%U87)E)SL*("`@('9A<B`D7V1A=&%S970["@H@("`@9G5N
M8W1I;VX@2&]R9&5?1W)A<&A?4&QO=%]S8V%T=&5R*"8D9W)A<&@L("1P87)A
M;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]G<F%P:"`]("8D9W)A<&@["@H@
M("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@
M("`D=&AI<RT^)&ME>2`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@9')A=R@D;6EN62`](&9A;'-E*0H@("`@>PH@("`@("`@("1D
M871A(#T@)'1H:7,M/E]G<F%P:"T^7V1A=&%;)WDG75LD=&AI<RT^7V1A=&%S
M971=.PH*("`@("`@("`D8V]U;G0@/2!C;W5N="@D9&%T82D["B`@("`@("`@
M)'9E<G1S(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)'@@/2`D:3L*("`@("`@("`@
M("`@:68@*"1M:6Y9(#T]/2!F86QS92!\?"`D9&%T85LD:5T@/CT@)&UI;EDI
M('L*("`@("`@("`@("`@("`@("1Y(#T@)&1A=&%;)&E=.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G<F%P:"T^=')A;G-L871E*"1X+"`D>2D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=R87!H+3YI;6<M/F)R=7-H*"1X+"`D>2P@
M)'1H:7,M/E]C;VQO<BP@)'1H:7,M/E]S:&%P92D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O0VAA<G0O````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P
M`#`R,#,R,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P
M:"]#:&%R="]P:64S9"YP:'``````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(S-C<`,3`U,34T,S$P-C``,#(R,#0R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`S1"!0:64@9W)A
M<&@@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P:"!P86-K86=E
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P:"]#:&%R="]P
M:64S9"YP:'`L=B`Q+C$N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$X(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@*B\*8VQA
M<W,@2&]R9&5?1W)A<&A?0VAA<G1?<&EE,V0@>PH*("`@('9A<B`D9W)A<&@[
M"@H@("`@=F%R("1?9&%T87-E=#L*("`@('9A<B`D7W!A9&1I;F<@/2`R,#L*
M("`@('9A<B`D7V]U=&QI;F4@/2!T<G5E.PH@("`@=F%R("1?8V]L;W)S(#T@
M87)R87DH)W1A;B<L("=P86QE9V]L9&5N<F]D)RP@)V]L:79E9')A8B<L("=B
M;'5E)RP@)W)E9"<L("=G<F5E;B<L("=Y96QL;W<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)V]R86YG92<L("=G<F%Y)RP@)W!U<G!L92<I.PH@("`@
M+RHJ"B`@("`@("(R-34L,34S+#`B+`H@("`@("`B,"PR,#0L,34S(BP*("`@
M("`@(C(P-"PR-34L,3`R(BP*("`@("`@(C(U-2PQ,#(L,3`R(BP*("`@("`@
M(C$P,BPR,#0L,C4U(BP*("`@("`@(C(P-"PQ-3,L,C4U(BP*("`@("`@(C(U
M-2PP+#`B+`H@("`@("`B-3$L,"PR-34B+`H@("`@("`B,C4U+#4Q+#$U,R(L
M"B`@("`@("(R,#0L,"PR-34B+`H@("`@("`B,C4U+#(U-2PU,2(L"B`@("`@
M("(U,2PR-34L-3$B+`H@("`@("`B,C4U+#$P,BPP(BD["B`@("`J+PH*("`@
M(&9U;F-T:6]N($AO<F1E7T=R87!H7T-H87)T7W!I93-D*"8D9W)A<&@L("1P
M87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/F=R87!H(#T@)B1G<F%P:#L*
M"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86T@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("1K97D@/2`G7R<@+B`D<&%R86T["B`@("`@("`@
M("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!D<F%W*"D*("`@('L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+T-H87)T+W!I92YP:'``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#<Q-P`Q,#4Q-30S,3`V,``P,C$V
M,3$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%!I92!G<F%P:"!I;7!L96UE;G1A=&EO;B!F;W(@=&AE
M($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T=R87!H+T=R87!H+T-H87)T+W!I92YP:'`L=B`Q+C$P+C$P+C0@,C`P-B\P
M,2\P,2`R,3HR.#HQ."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?1W)A<&@*("HO"F-L87-S($AO<F1E7T=R87!H7T-H87)T7W!I92![
M"@H@("`@=F%R("1G<F%P:#L*"B`@("!V87(@)%]D871A<V5T.PH@("`@=F%R
M("1?<&%D9&EN9R`](#(P.PH@("`@=F%R("1?;W5T;&EN92`]('1R=64["B`@
M("!V87(@)%]C;VQO<G,@/2!A<G)A>2@G=&%N)RP@)W!A;&5G;VQD96YR;V0G
M+"`G;VQI=F5D<F%B)RP@)V)L=64G+"`G<F5D)RP@)V=R965N)RP@)WEE;&QO
M=R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G;W)A;F=E)RP@)V=R87DG
M+"`G<'5R<&QE)RD["B`@("`O*BH*("`@("`@(C(U-2PQ-3,L,"(L"B`@("`@
M("(P+#(P-"PQ-3,B+`H@("`@("`B,C`T+#(U-2PQ,#(B+`H@("`@("`B,C4U
M+#$P,BPQ,#(B+`H@("`@("`B,3`R+#(P-"PR-34B+`H@("`@("`B,C`T+#$U
M,RPR-34B+`H@("`@("`B,C4U+#`L,"(L"B`@("`@("(U,2PP+#(U-2(L"B`@
M("`@("(R-34L-3$L,34S(BP*("`@("`@(C(P-"PP+#(U-2(L"B`@("`@("(R
M-34L,C4U+#4Q(BP*("`@("`@(C4Q+#(U-2PU,2(L"B`@("`@("(R-34L,3`R
M+#`B*3L*("`@("HO"@H@("`@9G5N8W1I;VX@2&]R9&5?1W)A<&A?0VAA<G1?
M<&EE*"8D9W)A<&@L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/F=R
M87!H(#T@)B1G<F%P:#L*"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D
M<&%R86T@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1K97D@/2`G7R<@+B`D
M<&%R86T["B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D<F%W*"D*("`@('L*("`@("`@
M("`D9&%T82`]("1T:&ES+3YG<F%P:"T^7V1A=&%;)WDG75LD=&AI<RT^7V1A
M=&%S971=.PH*("`@("`@("`O+R!);FET:6%L:7IE('-O;64@=F%R:6%B;&5S
M+@H@("`@("`@("1D:6%M971E<B`](&UI;B@D=&AI<RT^9W)A<&@M/E]G<F%P
M:%=I9'1H+"`D=&AI<RT^9W)A<&@M/E]G<F%P:$AE:6=H="D@+2`H)'1H:7,M
M/E]P861D:6YG("H@,BD["B`@("`@("`@)')A9&EU<R`]("1D:6%M971E<B`O
M(#(["B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&1A=&$I.PH@("`@("`@("1X
M8V5N=&5R(#T@)'1H:7,M/F=R87!H+3Y?9W)A<&A,969T("L@)'1H:7,M/E]P
M861D:6YG("L@*"1T:&ES+3YG<F%P:"T^7V=R87!H5VED=&@@+R`R*3L*("`@
M("`@("`D>6-E;G1E<B`]("1T:&ES+3YG<F%P:"T^7V=R87!H5&]P("L@)'1H
M:7,M/E]P861D:6YG("L@*"1T:&ES+3YG<F%P:"T^7V=R87!H2&5I9VAT("\@
M,BD["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@<W5M(&]F(&%L;"!S;&EC
M97,N"B`@("`@("`@)'-U;2`](#`["B`@("`@("`@9F]R96%C:"`H)&1A=&$@
M87,@)'@I('L*("`@("`@("`@("`@)'-U;2`K/2`D>#L*("`@("`@("!]"@H@
M("`@("`@("\O($-O;G9E<G0@96%C:"!S;&EC92!I;G1O('1H92!C;W)R97-P
M;VYD:6YG('!E<F-E;G1A9V4@;V8@80H@("`@("`@("\O(#,V,"UD96=R964@
M8VER8VQE+@H@("`@("`@("1D96=#;W5N="`](#`["B`@("`@("`@)'-L:6-E
M<R`](&%R<F%Y*"D["B`@("`@("`@)&1E9W)E97,@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<F5A8V@@*"1D871A(&%S("1I(#T^("1Y*2!["B`@("`@("`@("`@
M(&EF("@H*"1Y("\@)'-U;2D@*B`S-C`I(#X@,"D@>PH@("`@("`@("`@("`@
M("`@)&1E9W)E97-;)&1E9T-O=6YT72`]("@D>2`O("1S=6TI("H@,S8P.PH@
M("`@("`@("`@("`@("`@)'-L:6-E<ULD9&5G0V]U;G1=(#T@)'D["B`@("`@
M("`@("`@("`@("`D;F%M97-;)&1E9T-O=6YT72`](&ES<V5T*"1T:&ES+3YG
M<F%P:"T^7V1A=&%;)W@G75LD:5TI(#\@)'1H:7,M/F=R87!H+3Y?9&%T85LG
M>"==6R1I72`Z("<G.PH@("`@("`@("`@("`@("`@)&1E9T-O=6YT*RL["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($1R87<@=&AE(&)A
M<V5L:6YE+@H@("`@("`@(&EF("@D8V]U;G0@/B`Q*2!["B`@("`@("`@("`@
M("1L87-T7V%N9VQE(#T@,#L*("`@("`@("`@("`@)&-O=6YT(#T@8V]U;G0H
M)&1E9W)E97,I.PH@("`@("`@("`@("!F;W(@*"1Z(#T@,#L@)'H@/"`D8V]U
M;G0[("1Z*RLI('L*("`@("`@("`@("`@("`@("\O($-A;&-U;&%T92!A;F0@
M9')A=R!A<F-S(&-O<G)E<W!O;F1I;F<@=&\@96%C:`H@("`@("`@("`@("`@
M("`@+R\@<VQI8V4N"B`@("`@("`@("`@("`@("`D8WH@/2`D>B`E(&-O=6YT
M*"1T:&ES+3Y?8V]L;W)S*3L*("`@("`@("`@("`@("`@("1T:&ES+3YG<F%P
M:"T^:6UG+3YA<F,H)'AC96YT97(L("1Y8V5N=&5R+"`D<F%D:75S+"`D;&%S
M=%]A;F=L92P@*"1L87-T7V%N9VQE("L@)&1E9W)E97-;)'I=*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71L
M:6YE(#\@)V)L86-K)R`Z("1T:&ES+3Y?8V]L;W)S6R1C>ETL("1T:&ES+3Y?
M8V]L;W)S6R1C>ETI.PH@("`@("`@("`@("`@("`@)&QA<W1?86YG;&4@/2`D
M;&%S=%]A;F=L92`K("1D96=R965S6R1Z73L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG+3YC
M:7)C;&4H)'AC96YT97(L("1Y8V5N=&5R+"`D<F%D:75S+"`G8FQA8VLG+"`D
M=&AI<RT^7V-O;&]R<ULP72D["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A
M=&4@=&AE(&-O;&]R(&ME>2!A;F0@<VQI8V4@;&%B96QS+@H@("`@("`@("1Y
M0F%S92`]("1T:&ES+3YG<F%P:"T^7V=R87!H5&]P.PH@("`@("`@("1X0F%S
M92`](#4["B`@("`@("`@)&UA>"`]('-T<FQE;B@H<W1R:6YG*6UA>"@D9&%T
M82DI.PH@("`@("`@(&9O<B`H)'H@/2`P.R`D>B`\("1D96=#;W5N=#L@)'HK
M*RD@>PH@("`@("`@("`@("`D8WH@/2`D>B`E(&-O=6YT*"1T:&ES+3Y?8V]L
M;W)S*3L*("`@("`@("`@("`@)'!E<F-E;G0@/2`H)&1E9W)E97-;)'I=("\@
M,S8P*2`J(#$P,#L*("`@("`@("`@("`@)'!E<F-E;G0@/2!R;W5N9"@D<&5R
M8V5N="P@,BD["B`@("`@("`@("`@("1Y0F%S92`K/2`Q-3L*"B`@("`@("`@
M("`@("1T:&ES+3YG<F%P:"T^:6UG+3YR96-T86YG;&4H)'A"87-E+"`D>4)A
M<V4L(#$R+"`Q,BP@)V)L86-K)RP@)'1H:7,M/E]C;VQO<G-;)&-Z72D["B`@
M("`@("`@("`@(&EF("@D<VQI8V5S6R1Z72`^/2`Q,#`P("8F("1S;&EC97-;
M)'I=(#P@,3`P,#`P,"D@>PH@("`@("`@("`@("`@("`@)'-L:6-E<ULD>ET@
M/2`D<VQI8V5S6R1Z72`O(#$P,#`["B`@("`@("`@("`@("`@("`D<VQI8V5S
M6R1Z72`]("1S;&EC97-;)'I=("X@)VLG.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R97!E870@/2`D;6%X("T@<W1R;&5N*"1S;&EC97-;)'I=*3L*
M("`@("`@("`@("`@:68@*"1R97!E870@/"`P*2!["B`@("`@("`@("`@("`@
M("`D<F5P96%T(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<VQI
M8V5S6R1Z72`]('-T<E]R97!E870H)R`G+"`D<F5P96%T*2`N("1S;&EC97-;
M)'I=.PH*("`@("`@("`@("`@)'1H:7,M/F=R87!H+3YI;6<M/G1E>'0H)'-L
M:6-E<ULD>ETL("1X0F%S92`K(#(P+"`H)'E"87-E("L@,2DI.PH*("`@("`@
M("`@("`@)&QA8F5L(#T@)&YA;65S6R1Z72`N("<@*"<@+B`D<&5R8V5N="`N
M("<E*2<["B`@("`@("`@("`@(&EF("AS=')L96XH)&QA8F5L*2`^(#(P*2![
M"B`@("`@("`@("`@("`@("`D;&%B96QS(#T@97AP;&]D92@B7&XB+"!W;W)D
M=W)A<"@D;&%B96PL(#(P*2D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M;&%B96QS(&%S("1I(#T^("1L86)E;"D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'E"87-E
M("L](#$U.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9W)A<&@M/FEM9RT^=&5X="@D;&%B96PL("1X0F%S92`K
M(#,U("L@*"1M87@@*B`T*2P@*"1Y0F%S92`K(#$I*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YG<F%P:"T^:6UG+3YT97AT*"1L86)E;"P@)'A"87-E("L@,S4@*R`H
M)&UA>"`J(#0I+"`H)'E"87-E("L@,2DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O1W)O=7`O````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q-S,Q,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F]U<"]L9&%P+G!H<```````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C,Q-34`,3`U,34T,S$P
M-C``,#(P-S4R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@1W)O=7!?;&1A<"!C;&%S<R!P<F]V
M:61E<R!A;B!,1$%0(&)A8VME;F0@9F]R('1H92!(;W)D92!G<F]U<',*("H@
M<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<"QV(#$N,3@N,BXR(#(P,#8O,#$O,#$@,C$Z,C@Z,3D@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@0F5N($-H879E="`\8F5N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($)E;B!#
M:&%V970@/&)E;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@
M*B!`<&%C:V%G92!(;W)D95]'<F]U<`H@*B\*8VQA<W,@1W)O=7!?;&1A<"!E
M>'1E;F1S($=R;W5P('L*"B`@("`O*BH*("`@("`J($Q$05`@8V]N;F5C=&EO
M;B!H86YD;&4*("`@("`J+PH@("`@=F%R("1?9',["@H@("`@+RHJ"B`@("`@
M*B!,;V-A;"!C;W!Y(&]F('1H92!G;&]B86P@)&-O;F9;)V=R;W5P)UU;)W!A
M<F%M<R==(&%R<F%Y+B`@4VEM<&QY"B`@("`@*B!F;W(@8V]D:6YG(&-O;G9E
M;FEE;F-E+@H@("`@("HO"B`@("!V87(@)%]P87)A;7,["@H@("`@+RHJ"B`@
M("`@*B!'96YE<F%T960@3$1!4"!F:6QT97(@8F%S960@;VX@=&AE(&-O;F9I
M9R!P87)A;65T97)S"B`@("`@*B\*("`@('9A<B`D7V9I;'1E<CL*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!'
M<F]U<%]L9&%P*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@
M("`@)'1H:7,M/E]P87)A;7,@/2`D8V]N9ELG9W)O=7`G75LG<&%R86US)UT[
M"@H@("`@("`@("1T:&ES+3Y?<&%R86US6R=G:60G72`]('-T<G1O;&]W97(H
M)'1H:7,M/E]P87)A;7-;)V=I9"==*3L*("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG;65M8F5R=6ED)UT@/2!S=')T;VQO=V5R*"1T:&ES+3Y?<&%R86US6R=M
M96UB97)U:60G72D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;
M)VYE=V=R;W5P7V]B:F5C=&-L87-S)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=N97=G<F]U<%]O8FIE8W1C;&%S
M<R==6R1K97E=(#T@<W1R=&]L;W=E<B@D=F%L*3L*("`@("`@("!]"@H@("`@
M("`@("\J($=E;F5R871E($Q$05`@<V5A<F-H(&9I;'1E<BX@*B\*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=F:6QT97(G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]F:6QT97(@/2`D=&AI<RT^7W!A<F%M<ULG9FEL
M=&5R)UT["B`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A
M<F%M<ULG;V)J96-T8VQA<W,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]F
M:6QT97(@/2`G;V)J96-T8VQA<W,])R`N("1T:&ES+3Y?<&%R86US6R=O8FIE
M8W1C;&%S<R==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?9FEL=&5R(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M<&%R86US6R=O8FIE8W1C;&%S<R==(&%S("1O8FIE8W1C;&%S<RD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]F:6QT97(@/2`G*"8G("X@)'1H:7,M/E]F
M:6QT97(["B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I;'1E<B`N/2`G*&]B
M:F5C=&-L87-S/2<@+B`D;V)J96-T8VQA<W,@+B`G*2DG.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9I;'1E<B`]('-T<G1O
M;&]W97(H)'1H:7,M/E]F:6QT97(I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]N;F5C=',@=&\@=&AE($Q$05`@<V5R=F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O<B!&86QS92!B87-E9"!O;B!S=6-C97-S
M(&]F(&-O;FYE8W0@86YD(&)I;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M;VYN96-T*"D*("`@('L*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0
M('-E<G9E<BX@*B\*("`@("`@("`D=&AI<RT^7V1S(#T@0&QD87!?8V]N;F5C
M="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72D["B`@("`@("`@:68@*"$D
M=&AI<RT^7V1S*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(I*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A;&1A<%]S971?;W!T:6]N*"1T:&ES
M+3Y?9',L($Q$05!?3U!47U!23U1/0T],7U9%4E-)3TXL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72DI
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H"B`@("`@("`@("`@
M("`@("!S<')I;G1F*"=3970@3$1!4"!P<F]T;V-O;"!V97)S:6]N('1O("5D
M(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=V97)S:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@(&QD87!?97)R;F\H)&-O;FXI+`H@("`@("`@("`@("`@("`@("`@("`@
M("!L9&%P7V5R<F]R*"1C;VYN*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P87)A;7-;)V)I;F1D;B==*2D@>PH@("`@("`@("`@
M("`D8FEN9"`]($!L9&%P7V)I;F0H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A
M;7-;)V)I;F1D;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A)&)I;F0I('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-I=F5L>2!D96QE=&5S
M("1D;BX@)'1H:7,M/E]D<R!-55-4(&%L<F5A9'D@8F4@8V]N;F5C=&5D+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@:68@9&5L971E('=A
M<R!S=6-C97-S9G5L+"!014%27T5R<F]R(&]T:&5R=VES92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W)E8W5R<VEV95]D96QE=&4H)&1N*0H@("`@>PH@("`@
M("`@("1S96%R8V@@/2!`;&1A<%]L:7-T*"1T:&ES+3Y?9',L("1D;BP@)V]B
M:F5C=&-L87-S/2HG+"!A<G)A>2@G)RDI.PH@("`@("`@(&EF("@A)'-E87)C
M:"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("!]
M"@H@("`@("`@("1C:&EL9')E;B`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES
M+3Y?9',L("1S96%R8V@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C
M:&EL9')E;ELG8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]R96-U<G-I=F5?9&5L971E*"1C:&EL9')E;ELD:5U;)V1N
M)UTI.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(I+"`D=&AI<RT^9V5T
M3F%M92@D8VAI;&1R96Y;)&E=6R=D;B==*2DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@0&QD87!?9&5L971E*"1T:&ES
M+3Y?9',L("1D;BD["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(I+"`D9&XI*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5A<F-H97,@97AI<W1I;F<@9W)O=7!S(&9O<B!T:&4@:&EG
M:&5S="!G:61N=6UB97(L(&%N9"!R971U<FYS"B`@("`@*B!O;F4@:&EG:&5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;F5X=$=I9"@I"B`@("!["B`@("`@
M("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@
M)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?
M82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I*3L*
M("`@("`@("!]"@H@("`@("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H
M:7,M/E]D<RP@)&1N+"`D=&AI<RT^7V9I;'1E<BD["B`@("`@("`@:68@*"$D
M<V5A<F-H*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@0&QD87!?<V]R="@D=&AI<RT^7V1S+"`D<V5A<F-H
M+"`G9VED;G5M8F5R)RD["B`@("`@("`@)')E<W5L="`]($!L9&%P7V=E=%]E
M;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@("`@($!L9&%P7V-L
M;W-E*"1T:&ES+3Y?9',I.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R97-U
M;'0I('Q\("AC;W5N="@D<F5S=6QT*2`\/2`Q*2D@>PH@("`@("`@("`@("!R
M971U<FX@,#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT6R1R
M97-U;'1;)V-O=6YT)UT@+2`Q75LG9VED;G5M8F5R)UU;,%T@*R`Q.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@;F5W(&=R;W5P(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@(%1H92!G<F]U
M<"=S(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)E;G0@(%1H92!G
M<F]U<"=S('!A<F5N="=S(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!,
M1$%07T=R;W5P("!!(&YE=R!G<F]U<"!O8FIE8W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9N97='<F]U<"@D;F%M92P@)'!A<F5N="`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(I*3L*("`@("`@("!]"@H@("`@("`@(&=L;V)A;"`D8V]N9CL*
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=G<F]U<&QD87`G
M72DI('L*("`@("`@("`@("`@0&EN8VQU9&4@2$]21$5?0D%312`N("<O8V]N
M9FEG+VAO;VMS+G!H<"<["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)U]H;W)D95]H;V]K7V=R;W5P;&1A<"<I*2!["B`@("`@("`@("`@("`@
M("`D96YT<GD@/2!C86QL7W5S97)?9G5N8R@G7VAO<F1E7VAO;VM?9W)O=7!L
M9&%P)RP@)&YA;64L("1P87)E;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@5')Y('1H:7,@<VEM<&QE(&1E9F%U
M;'0@86YD(&AO<&4@:70@=V]R:W,N"B`@("`@("`@("`@("1E;G1R>5LD=&AI
M<RT^7W!A<F%M<ULG9VED)UU=(#T@)&YA;64["B`@("`@("`@("`@("1E;G1R
M>5LG;V)J96-T8VQA<W,G72`]("1T:&ES+3Y?<&%R86US6R=N97=G<F]U<%]O
M8FIE8W1C;&%S<R==.PH@("`@("`@("`@("`D96YT<GE;)V=I9&YU;6)E<B==
M(#T@)'1H:7,M/E]N97AT1VED*"D["B`@("`@("`@?0H*("`@("`@("`D9W)O
M=7`@/2`F;F5W($Q$05!?1W)O=7`H)&YA;64L("1P87)E;G0I.PH@("`@("`@
M("1G<F]U<"T^7V9R;VU!='1R:6)U=&5S*"1E;G1R>2D["B`@("`@("`@)&=R
M;W5P+3YS971'<F]U<$]B*"1T:&ES*3L*("`@("`@("!R971U<FX@)&=R;W5P
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&%N($Q$05!?1W)O=7`@
M;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&YA;65D(&=R;W5P+"!W:71H
M('1H90H@("`@("H@=7-E<G,@86YD(&]T:&5R(&1A=&$@<F5T<FEE=F5D(&%P
M<')O<')I871E;'DN"B`@("`@*@H@("`@("H@3D]413H@9V5T1W)O=7!">4ED
M*"D@<VAO=6QD(&)E('5S960@=VAE<F4@<&]S<VEB;&4@:6YS=&5A9"!O9@H@
M("`@("H@9V5T1W)O=7`H*2!B96-A=7-E(&=R;W5P(&YA;65S(&%R92!P;W1E
M;G1I86QL>2!N;VXM=6YI<75E('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@9W)O=7`@=&\@<F5T
M<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!,1$%07T=R;W5P("!4:&4@
M<F5Q=65S=&5D(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1W)O
M=7`H)&YA;64I"B`@("!["B`@("`@("`@)&1N(#T@)'1H:7,M/F=E=$=R;W5P
M260H)&YA;64I.PH@("`@("`@(&EF("AI<U]A*"1D;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D9&XM
M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H@("`@("`@("1G<F]U<"`]("8D
M=&AI<RT^9V5T1W)O=7!">4ED*"1D;BD["B`@("`@("`@<F5T=7)N("1G<F]U
M<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A;B!,1$%07T]B:F5C
M="!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV96X@9&XL('=I=&@@
M=&AE"B`@("`@*B!U<V5R<R!A;F0@;W1H97(@9&%T82!R971R:65V960@87!P
M<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@
M5&AE(&1N(&]F('1H92!G<F]U<"!T;R!R971R:65V92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($Q$05!?3V)J96-T("!4:&4@<F5Q=65S=&5D(&=R;W5P+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1W)O=7!">4ED*"1D;BD*("`@('L*
M("`@("`@("!S=&%T:6,@)&-A8VAE.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1C86-H92DI('L*("`@("`@("`@("`@)&-A8VAE(#T@87)R87DH*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&-A8VAE6R1D;ETI*2!["B`@
M("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@
M("`@("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E
M<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)&1N+"`D=&AI
M<RT^7V9I;'1E<BD["B`@("`@("`@("`@(&EF("@A)'-E87)C:"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@
M;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI
M<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H
M:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')E<W5L="D@
M?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")%;7!T>2!R97-U;'0N(BDI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y
M*"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R97-U;'1;,%U;
M)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT
M6S!=6R1R97-U;'1;,%U;)&E=75LG8V]U;G0G72`^(#$I('L*("`@("`@("`@
M("`@("`@("`@("`D871T<FEB=71E<ULD<F5S=6QT6S!=6R1I75T@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1R
M97-U;'1;,%U;)')E<W5L=%LP75LD:5U=6R=C;W5N="==.R`D:BLK*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R1R97-U;'1;,%U;
M)&E=75M=(#T@)')E<W5L=%LP75LD<F5S=6QT6S!=6R1I75U;)&I=.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)')E<W5L=%LP75LD:5U=
M(#T@)')E<W5L=%LP75LD<F5S=6QT6S!=6R1I75U;,%T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&%T=')I8G5T97-;
M)V1N)UT@/2`D<F5S=6QT6S!=6R=D;B==.PH*("`@("`@("`@("`@)&=R;W5P
M(#T@;F5W($Q$05!?1W)O=7`H)'1H:7,M/F=E=$=R;W5P3F%M92@D9&XI*3L*
M("`@("`@("`@("`@)&=R;W5P+3Y?9G)O;4%T=')I8G5T97,H)&%T=')I8G5T
M97,I.PH@("`@("`@("`@("`D9W)O=7`M/G-E=$=R;W5P3V(H)'1H:7,I.PH@
M("`@("`@("`@("`D8V%C:&5;)&1N72`]("1G<F]U<#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1C86-H95LD9&Y=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T(&$@9VQO8F%L;'D@=6YI<75E($E$(&9O<B!A(&=R;W5P+B`@5&AI
M<R!R96%L;'D@:G5S="!R971U<FYS('1H92!D;@H@("`@("H@9F]R('1H92!G
M<F]U<"P@8G5T(&ES(&EN8VQU9&5D(&9O<B!C;VUP871I8FEL:71Y('=I=&@@
M=&AE($=R;W5P(&-L87-S+@H@("`@("H*("`@("`J($!P87)A;2!,1$%07T]B
M:F5C="`D9W)O=7`@(%1H92!G<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@82!'54E$(')E9F5R<FEN9R!T;R`D9W)O=7`N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$=5240H)&=R;W5P*0H@("`@>PH@("`@("`@(')E
M='5R;B`D9W)O=7`M/F=E="@G9&XG*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9"!A(&=R;W5P('1O('1H92!G<F]U<',@<WES=&5M+B`@5&AE(&=R;W5P
M(&UU<W0@9FER<W0@8F4@8W)E871E9"!W:71H"B`@("`@*B!'<F]U<%]L9&%P
M.CIN97='<F]U<"@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<R!A9&1E
M9"!T;R!I="P@8F5F;W)E"B`@("`@*B!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@3$1!4%]'<F]U<"`D9W)O=7`@(%1H
M92!N97<@9W)O=7`@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@:68@<W5C8V5S<V9U;"P@4$5!4E]%<G)O<B!O=&AE<G=I<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$=R;W5P*"1G<F]U<"D*("`@('L*
M("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G1&%T851R965/8FIE8W1?1W)O
M=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE8W1?1W)O=7`@;V)J96-T<R!O
M<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@("\J
M($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U
M8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@?0H*("`@("`@("`D9&X@/2`D9W)O=7`M/F=E="@G9&XG*3L*"B`@("`@
M("`@)&5N=')Y(#T@)&=R;W5P+3Y?=&]!='1R:6)U=&5S*"D["B`@("`@("`@
M)'-U8V-E<W,@/2!`;&1A<%]A9&0H)'1H:7,M/E]D<RP@)&1N+"`D96YT<GDI
M.PH*("`@("`@("!I9B`H(21S=6-C97-S*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(BDL("1G<F]U<"T^9V5T3F%M92@I*2`N($!L9&%P7V5R<F]R*"1T
M:&ES+3Y?9',I*3L*("`@("`@("!]"@H@("`@("`@($!L9&%P7V-L;W-E*"1T
M:&ES+3Y?9',I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-T;W)E('5P9&%T960@9&%T82`M('5S97)S+"!E=&,N("T@
M;V8@82!G<F]U<"!T;R!T:&4@8F%C:V5N9"!S>7-T96TN"B`@("`@*@H@("`@
M("H@0'!A<F%M($Q$05!?3V)J96-T("1G<F]U<"`@5&AE(&=R;W5P('1O('5P
M9&%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<RP@4$5!4E]%<G)O<B!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('5P9&%T94=R;W5P*"1G<F]U<"D*("`@('L*("`@("`@("!I9B`H(6ES
M7V$H)&=R;W5P+"`G1&%T851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1W)O=7!S(&UU<W0@8F4@
M1&%T851R965/8FIE8W1?1W)O=7`@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C
M;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@("1E;G1R>2`]("1G<F]U<"T^
M7W1O071T<FEB=71E<R@I.PH*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,
M1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S
M=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@)')E
M<W5L="`]($!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S+"`D9W)O=7`M/F=E=$ED
M*"DL("1E;G1R>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1W)O=7!?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(I+"`D9W)O=7`M/F=E
M=$YA;64H*2DI.PH@("`@("`@('T*"B`@("`@("`@0&QD87!?8VQO<V4H)'1H
M:7,M/E]D<RD["@H@("`@("`@("\J($QO9R!T:&4@=7!D871E(&]F('1H92!G
M<F]U<"!U<V5R<R!O;B!T:&4@:&ES=&]R>2!L;V<N("HO"B`@("`@("`@)&AI
M<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@
M)&=U:60@/2`D=&AI<RT^9V5T1U5)1"@D9W)O=7`I.PH@("`@("`@(&9O<F5A
M8V@@*"1G<F]U<"T^9V5T075D:71,;V<H*2!A<R`D=7-E<DED(#T^("1A8W1I
M;VXI('L*("`@("`@("`@("`@)&AI<W1O<GDM/FQO9R@D9W5I9"P@87)R87DH
M)V%C=&EO;B<@/3X@)&%C=&EO;BP@)W5S97(G(#T^("1U<V5R260I+"!T<G5E
M*3L*("`@("`@("!]"B`@("`@("`@)&=R;W5P+3YC;&5A<D%U9&ET3&]G*"D[
M"@H@("`@("`@("\J($QO9R!T:&4@9W)O=7`@;6]D:69I8V%T:6]N+B`J+PH@
M("`@("`@("1H:7-T;W)Y+3YL;V<H)&=U:60L(&%R<F%Y*"=A8W1I;VXG(#T^
M("=M;V1I9GDG*2P@=')U92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE(&YA;64@;V8@82!G<F]U
M<"X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?1W)O=7`@
M)&=R;W5P("!4:&4@9W)O=7`@=&\@<F5N86UE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F5W3F%M92`@("`@("`@("`@("`@5&AE(&=R;W5P)W,@;F5W(&YA
M;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M94=R;W5P*"1G<F]U<"P@
M)&YE=TYA;64I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A
M=&%4<F5E3V)J96-T7T=R;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T=R;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T
M7T=R;W5P(&]B:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@
M("`@?0H*("`@("`@("`D9W)O=7`M/G-E="@D=&AI<RT^7W!A<F%M<ULG9VED
M)UTL("1N97=.86UE*3L*("`@("`@("`D96YT<GD@/2`D9W)O=7`M/E]T;T%T
M=')I8G5T97,H*3L*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S
M97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S
M<RT^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@
M/2!`;&1A<%]M;V1I9GDH)'1H:7,M/E]D<RP@)&=R;W5P+3YG971)9"@I+"`D
M96YT<GDI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B*2P@)&=R;W5P+3YG971.86UE
M*"DI*3L*("`@("`@("!]"@H@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?
M9',I.PH*("`@("`@("`O*B!(:7-T;W)Y($QO9R!T:&4@;F%M92!C:&%N9V4@
M;V8@=&AE(&=R;W5P+B`J+PH@("`@("`@("1H:7-T;W)Y(#T@)DAO<F1E7TAI
M<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@("`@("1H:7-T;W)Y+3YL;V<H)&=R
M;W5P+3YG970H)V1N)RDL(&%R<F%Y*"=A8W1I;VXG(#T^("=R96YA;64G*2P@
M=')U92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["@H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5M;W9E(&$@9W)O=7`@9G)O;2!T:&4@9W)O=7!S('-Y<W1E
M;2!P97)M86YE;G1L>2X*("`@("`J"B`@("`@*B!`<&%R86T@3$1!4%]'<F]U
M<"`D9W)O=7`@(%1H92!G<F]U<"!T;R!R96UO=F4N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D9F]R8V4@("`@(%)E8W5R<VEV96QY(&1E;&5T92!C:&EL9')E
M;B!G<F]U<',@:68@=')U92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;W1H97)W:7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96UO=F5'<F]U<"@D9W)O=7`L("1F;W)C92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=$871A
M5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A5')E94]B:F5C=%]'
M<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@
M('T*"B`@("`@("`@)&1N(#T@)&=R;W5P+3YG971)9"@I.PH*("`@("`@("`O
M*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C
M8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S
M=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1F;W)C92D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]R96-U<G-I=F5?9&5L971E*"1D;BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<W5L="`]($!L9&%P7V1E;&5T92@D=&AI
M<RT^7V1S+"`D9&XI.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H
M7R@B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(I+"`D
M9&XI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E('1H92!N86UE(&]F(&$@9W)O=7`N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D;B!O9B!T:&4@9W)O=7`@
M=&\@<F5T<FEE=F4@=&AE(&YA;64@9F]R+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@9W)O=7`G<R!N86UE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971'<F]U<$YA;64H)&1N*0H@("`@>PH@("`@("`@("1R97-U;'0@
M/2!L9&%P7V5X<&QO9&5?9&XH)&1N+"`Q*3L*("`@("`@("!R971U<FX@)')E
M<W5L=%LP73L*("`@('T*"B`@("`O*BH*("`@("`J($1A=&%4<F5E3V)J96-T
M(&9U;&P@;F%M97,@:6YC;'5D92!R969E<F5N8V5S('1O('!A<F5N=',L(&)U
M="!,1$%0(&1O97,*("`@("`J(&YO="!H879E('1H:7,@8V]N8V5P="X@(%1H
M:7,@9G5N8W1I;VX@<VEM<&QY(')E='5R;G,@=&AE("1G<F]U<`H@("`@("H@
M<&%R86UE=&5R(&%N9"!I<R!I;F-L=61E9"!F;W(@8V]M<&%T:6)I;&ET>2!W
M:71H('1H92!'<F]U<"!C;&%S<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1G<F]U<"`@1W)O=7`@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@)&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U
M<%-H;W)T3F%M92@D9W)O=7`I"B`@("!["B`@("`@("`@<F5T=7)N("1G<F]U
M<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!)1"!O9B!T
M:&4@9VEV96X@9W)O=7`N"B`@("`@*@H@("`@("H@3D]413H@268@9VEV96X@
M82!G<F]U<"!N86UE+"!T:&ES(&9U;F-T:6]N(&-A;B!B92!U;G)E;&EA8FQE
M(&EF(&UO<F4*("`@("`J('1H86X@;VYE(&=R;W5P(&5X:7-T<R!W:71H('1H
M92!S86UE(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1G<F]U
M<"`@($Q$05!?1W)O=7`@;V)J96-T+"!O<B!A(&=R;W5P(&YA;64@*'-T<FEN
M9RD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&=R;W5P)W,@
M240N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P260H)&=R;W5P*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A*"1G<F]U<"P@)TQ$05!?1W)O=7`G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&=R;W5P+3YG970H)V1N)RD["B`@("`@
M("`@?0H*("`@("`@("!S=&%T:6,@)&-A8VAE.PH*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1C86-H92DI('L*("`@("`@("`@("`@)&-A8VAE(#T@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&-A8VAE6R1G<F]U
M<%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M("`@("`D<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T:&ES
M+3Y?<&%R86US6R=B87-E9&XG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9VED)UT@+B`G/2<@+B`D9W)O
M=7`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)'1H:7,M/E]P87)A;7-;)V=I9"==*2D["B`@("`@("`@("`@(&EF("@A)'-E
M87)C:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?
M96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@("`@0&QD
M87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)')E<W5L="D@?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")%;7!T>2!R
M97-U;'0N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C86-H95LD
M9W)O=7!=(#T@)')E<W5L=%LP75LG9&XG73L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D8V%C:&5;)&=R;W5P73L*("`@('T*"B`@("`O*BH*("`@("`J
M($-H96-K(&EF(&$@9W)O=7`@97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@(%1H92!G<F]U<"!N86UE
M('1O(&-H96-K(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE(&=R;W5P(&5X:7-T<RP@1F%L<V4@;W1H97)W:7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)&=R;W5P*0H@("`@>PH@("`@
M("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("@A:7-?87)R87DH)&-A
M8VAE*2D@>PH@("`@("`@("`@("`D8V%C:&4@/2!A<G)A>2@I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&=R;W5P72DI('L*("`@
M("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@
M("`@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S
M<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D9&XL("<H)B<@
M+B`D=&AI<RT^7V9I;'1E<B`N("<H)R`N("1T:&ES+3Y?<&%R86US6R=G:60G
M72`N("<])R`N("1G<F]U<"`N("<I*2<I.PH@("`@("`@("`@("!I9B`H(21S
M96%R8V@I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@0&QD87!?9V5T
M7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@("`@("`@($!L
M9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("`D8V%C:&5;)&=R
M;W5P72`]("AI<U]A<G)A>2@D<F5S=6QT*2`F)B`H8V]U;G0H)')E<W5L="`^
M(#$I*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1G<F]U
M<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H92!P
M87)E;G1S(&]F(&$@8VAI;&0@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&X@(%1H92!D;B!O9B!T:&4@8VAI;&0@9W)O=7`N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&1N(&%N9"!N86UE(&]F('1H
M92!P87)E;G0@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P
M4&%R96YT<R@D9&XI"B`@("!["B`@("`@("`@)'!A<F5N="`]("1T:&ES+3YG
M971'<F]U<%!A<F5N="@D9&XI.PH@("`@("`@(')E='5R;B!A<G)A>2@D<&%R
M96YT(#T^("1T:&ES+3YG971'<F]U<$YA;64H)'!A<F5N="DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!P87)E;G0@;V8@=&AE(&=I=F5N(&=R
M;W5P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1N("!4:&4@9&X@
M;V8@=&AE(&-H:6QD(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@9&X@;V8@=&AE('!A<F5N="!G<F]U<"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1W)O=7!087)E;G0H)&1N*0H@("`@>PH@("`@("`@("1R
M97-U;'0@/2!L9&%P7V5X<&QO9&5?9&XH)&1N+"`P*3L*("`@("`@("!U;G-E
M="@D<F5S=6QT6R=C;W5N="==*3L*("`@("`@("!U;G-E="@D<F5S=6QT6S!=
M*3L*("`@("`@("`D<&%R96YT7V1N(#T@:6UP;&]D92@G+"<L("1R97-U;'0I
M.PH*("`@("`@("!I9B`H)'!A<F5N=%]D;B`]/2`D1TQ/0D%,4ULG8V]N9B==
M6R=G<F]U<"==6R=P87)A;7,G75LG8F%S961N)UTI('L*("`@("`@("`@("`@
M<F5T=7)N($1!5$%44D5%7U)/3U0["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("1P87)E;G1?9&X["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!P87)E;G1S(&%L;"!T:&4@=V%Y
M('5P('1O('1H92!R;V]T(&]B:F5C="!F;W(@=&AE(&=I=F5N"B`@("`@*B!G
M<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE(&1N
M(&]F('1H92!G<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!
M(&9L870@;&ES="!O9B!A;&P@;V8@=&AE('!A<F5N=',@;V8@=&AE(&=I=F5N
M(&=R;W5P+`H@("`@("H@("`@("`@("`@("`@("`@:&%S:&5D(&EN("1D;B`]
M/B`D;F%M92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P
M4&%R96YT3&ES="@D9&XI"B`@("!["B`@("`@("`@)')E<W5L="`](&QD87!?
M97AP;&]D95]D;B@D9&XL(#`I.PH@("`@("`@("1N=6T@/2`D<F5S=6QT6R=C
M;W5N="==.PH*("`@("`@("!U;G-E="@D<F5S=6QT6R=C;W5N="==*3L*("`@
M("`@("!U;G-E="@D<F5S=6QT6S!=*3L*"B`@("`@("`@)&-O=6YT(#T@,#L*
M("`@("`@("`D<&%R96YT<R`](&%R<F%Y*"D["B`@("`@("`@)'!A<F5N=%]D
M;B`](&EM<&QO9&4H)RPG+"`D<F5S=6QT*3L*("`@("`@("!W:&EL92`H)'!A
M<F5N=%]D;B`A/2`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UT@)B8@)&-O=6YT
M*RL@(3T@)&YU;2D@>PH@("`@("`@("`@("`D<&%R96YT<ULD<&%R96YT7V1N
M72`]("1T:&ES+3YG971'<F]U<$YA;64H)'!A<F5N=%]D;BD["B`@("`@("`@
M("`@('5N<V5T*"1R97-U;'1;)&-O=6YT72D["B`@("`@("`@("`@("1P87)E
M;G1?9&X@/2!I;7!L;V1E*"<L)RP@)')E<W5L="D["B`@("`@("`@?0H@("`@
M("`@("1P87)E;G1S6T1!5$%44D5%7U)/3U1=(#T@1$%40512145?4D]/5#L*
M"B`@("`@("`@<F5T=7)N("1P87)E;G1S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T(&$@;&ES="!O9B!E=F5R>2!G<F]U<"P@:6X@=&AE(&9O<FUA="!D
M;B`]/B!G<F]U<&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)')E9G)E<V@@($EF('1R=64L('1H92!C86-H960@=F%L=64@:7,@:6=N;W)E
M9"!A;F0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9W)O
M=7`@;&ES="!I<R!R969R97-H960@9G)O;2!T:&4@9W)O=7`@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!D;B`]/B!G<F]U<&YA;64@
M:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$=R;W5P<R@D<F5F<F5S
M:"`](&9A;'-E*0H@("`@>PH@("`@("`@('-T871I8R`D9W)O=7!S.PH*("`@
M("`@("!I9B`H)')E9G)E<V@@?'P@:7-?;G5L;"@D9W)O=7!S*2D@>PH@("`@
M("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@
M("`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S
M+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R
M86US6R=B87-E9&XG72P@)'1H:7,M/E]F:6QT97(L(&%R<F%Y*"1T:&ES+3Y?
M<&%R86US6R=G:60G72DI.PH@("`@("`@("`@("!I9B`H(21S96%R8V@I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!`;&1A<%]S;W)T*"1T:&ES+3Y?9',L("1S96%R
M8V@L("1T:&ES+3Y?<&%R86US6R=G:60G72D["@H@("`@("`@("`@("`D<F5S
M=6QT(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D[
M"B`@("`@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1R97-U;'0I('Q\("AC;W5N="@D<F5S=6QT
M*2`\/2`Q*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1G<F]U<',@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<F5S=6QT6R=C;W5N="==
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D9W)O=7!S6R1R97-U;'1;)&E=
M6R=D;B==72`]("1R97-U;'1;)&E=6R1T:&ES+3Y?<&%R86US6R=G:60G75U;
M,%T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9W)O=7!S.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E
M=F5R>2!U<V5R('1H870@:7,@<&%R="!O9B!T:&4@<W!E8VEF:65D(&=R;W5P
M(&%N9"!A;GD*("`@("`J(&]F(&ET<R!S=6)G<F]U<',N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D;B!O9B!T:&4@<&%R96YT(&=R
M;W5P+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!C;VUP;&5T
M92!U<V5R(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!;&Q5<V5R
M<R@D9&XI"B`@("!["B`@("`@("`@<W1A=&EC("1C86-H93L*"B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D8V%C:&4I*2!["B`@("`@("`@("`@("1C86-H92`]
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C86-H
M95LD9&Y=*2D@>PH@("`@("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D
M<RP@)'1H:7,M/F=E=$=R;W5P4&%R96YT*"1D;BDL("1T:&ES+3Y?9FEL97(I
M.PH@("`@("`@("`@("!I9B`H(21S96%R8V@I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D<F5S=6QT(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E
M87)C:"D["B`@("`@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R97-U;'0I('Q\("AC;W5N="@D
M<F5S=6QT*2`\/2`Q*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B16UP='D@<F5S=6QT+B(I*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'5S97)S(#T@87)R87DH*3L*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)')E<W5L=%LG8V]U;G0G73L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)')E<W5L=%LD:5U;
M)'1H:7,M/E]P87)A;7-;)VUE;6)E<G5I9"==75LG8V]U;G0G73L@)&HK*RD@
M>PH@("`@("`@("`@("`@("`@("`@("1U<V5R<UM=(#T@)')E<W5L=%LD:5U;
M)'1H:7,M/E]P87)A;7-;)VUE;6)E<G5I9"==75LD:ET["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C86-H95LD9&Y=
M(#T@87)R87E?=6YI<75E*"1U<V5R<RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&-A8VAE6R1D;ET["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M82!L:7-T(&]F(&5V97)Y(&=R;W5P('1H870@=&AE(&=I=F5N('5S97(@:7,@
M82!M96UB97(@;V8N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5S
M97(@("`@("`@("`@5&AE('5S97(@=&\@9V5T(&=R;W5P<R!F;W(N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<&%R96YT1W)O=7!S("!!;'-O(')E='5R;B!T
M:&4@<&%R96YT<R!O9B!A;GD@9W)O=7!S/PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%N(&%R<F%Y(&]F(&%L;"!G<F]U<',@=&AE('5S97(@:7,@
M:6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P365M8F5R<VAI<',H
M)'5S97(L("1P87)E;G1'<F]U<',@/2!F86QS92D*("`@('L*("`@("`@("!S
M=&%T:6,@)&-A8VAE.PH*("`@("`@("!I9B`H96UP='DH)&-A8VAE6R1U<V5R
M72DI('L*("`@("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V
M97(N("HO"B`@("`@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T
M*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@D<W5C8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D
M=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL("<H)R`N("1T:&ES+3Y?<&%R86US
M6R=M96UB97)U:60G72`N("<])R`N("1U<V5R("X@)RDG*3L*("`@("`@("`@
M("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R
M=F5R+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<W5L="`]
M($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@
M("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\?"`H8V]U;G0H)')E<W5L="D@/#T@
M,2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D5M<'1Y(')E<W5L="XB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1G<F]U<',@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D<F5S=6QT6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`D9W)O=7!S6R1R97-U;'1;)&E=6R=D;B==72`]("1R97-U;'1;)&E=
M6R1T:&ES+3Y?<&%R86US6R=G:60G75U;,%T["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1C86-H95LD=7-E<ET@/2`D9W)O=7!S.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1C86-H95LD=7-E<ET["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!T<F5E(&1E<'1H(&]F('1H92!G:79E;B!G
M<F]U<"P@<F5L871I=F4@=&\@=&AE(&)A<V4@9&XN"B`@("`@*B`P(&ES(')E
M='5R;F5D(&9O<B!A;GD@;V)J96-T(&1I<F5C=&QY(&)E;&]W('1H92!B87-E
M(&1N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1N("!4:&4@9&X@
M;V8@=&AE(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5N9V5R
M("!4:&4@=')E(&1E<'1H(&]F('1H92!G<F]U<"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T3&5V96PH)&1N*0H@("`@>PH@("`@("`@("1B87-E(#T@0&QD
M87!?97AP;&]D95]D;B@D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL(#`I.PH@
M("`@("`@("1G<F]U<"`]($!L9&%P7V5X<&QO9&5?9&XH)&1N+"`P*3L*("`@
M("`@("!R971U<FX@)&=R;W5P6R=C;W5N="==("T@)&)A<V5;)V-O=6YT)UT@
M+2`Q.PH@("`@?0H*?0H*+RHJ"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R
M965/8FIE8W1?1W)O=7`@8VQA<W,@9F]R('-T;W)I;F<@9W)O=7`@:6YF;W)M
M871I;VX*("H@:6X@86X@3$1!4"!D:7)E8W1O<GDN"B`J"B`J($!A=71H;W(@
M($)E;B!#:&%V970@/&)E;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#,N,0H@*B!`<&%C:V%G92!(;W)D95]'<F]U<`H@*B\*8VQA<W,@3$1!4%]'
M<F]U<"!E>'1E;F1S($1A=&%4<F5E3V)J96-T7T=R;W5P('L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@("`@5&AE(&YA;64@;V8@=&AI<R!G<F]U<"X*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A<F5N="`@5&AE(&1N(&]F('1H92!P87)E;G0@;V8@
M=&AI<R!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@3$1!4%]'<F]U<"@D
M;F%M92P@)'!A<F5N="`](&YU;&PI"B`@("!["B`@("`@("`@<&%R96YT.CI$
M871A5')E94]B:F5C=%]'<F]U<"@D;F%M92D["B`@("`@("`@:68@*"1P87)E
M;G0I('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V1N)UT@/2!S=')T;VQO
M=V5R*"1'3$]"04Q36R=C;VYF)UU;)V=R;W5P)UU;)W!A<F%M<R==6R=G:60G
M72D@+B`G/2<@+B`D;F%M92`N("<L)R`N("1P87)E;G0["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V1N)UT@/2!S=')T;VQO
M=V5R*"1'3$]"04Q36R=C;VYF)UU;)V=R;W5P)UU;)W!A<F%M<R==6R=G:60G
M72D@+B`G/2<@+B`D;F%M92`N"B`@("`@("`@("`@("`@("`G+"<@+B!S=')T
M;VQO=V5R*"1'3$]"04Q36R=C;VYF)UU;)V=R;W5P)UU;)W!A<F%M<R==6R=B
M87-E9&XG72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&$@;&ES="!O9B!E=F5R>2!U<V5R('1H870@:7,@<&%R="!O9B!T:&ES(&=R
M;W5P("AA;F0@;VYL>0H@("`@("H@=&AI<R!G<F]U<"DN"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE('5S97(@;&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]G<F]U<$]B+3YL:7-T57-E<G,H)'1H:7,M/F1A=&%;)V1N)UTI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!U<V5R
M('1H870@:7,@82!M96UB97(@;V8@=&AI<R!G<F]U<"!A;F0@86YY(&]F"B`@
M("`@*B!I="=S('-U8F=R;W5P<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@8V]M<&QE=&4@=7-E<B!L:7-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!L:7-T06QL57-E<G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V=R;W5P3V(M/FQI<W1!;&Q5<V5R<R@D=&AI<RT^9&%T85LG9&XG72D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&EN(&$@;&ES="!O9B!A='1R
M:6)U=&5S(&9R;VT@=&AE(&)A8VME;F0@86YD(&UA<"!I="!T;R!O=7(*("`@
M("`J(&EN=&5R;F%L(&1A=&$@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1A='1R:6)U=&5S("!4:&4@;&ES="!O9B!A='1R:6)U=&5S(&9R
M;VT@=&AE(&)A8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F<F]M071T
M<FEB=71E<R@D871T<FEB=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/F1A=&%;)W5S97)S)UT@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@@*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@(&EF("@D:V5Y(#T]('-T<G1O;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG
M9W)O=7`G75LG<&%R86US)UU;)VUE;6)E<G5I9"==*2D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D=F%L=64@87,@)'5S97(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S97)=(#T@)S$G
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;
M)'9A;'5E72`]("<Q)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E:68@*"1K97D@/3T@)VUA:6PG*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^9&%T85LG96UA:6PG72`]("1V86QU93L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1K97E=(#T@)'9A
M;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@36%P('1H:7,@;V)J96-T)W,@871T<FEB=71E<R!F<F]M('1H92!D
M871A(&%R<F%Y(&EN=&\@82!F;W)M870@=&AA=`H@("`@("H@8V%N(&)E('-T
M;W)E9"!I;B!A;B!,1$%0(&5N=')Y+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!E;G1R>2!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W1O071T<FEB=71E<R@I"B`@("!["B`@("`@("`@)&%T=')I8G5T97,@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD871A(&%S("1K97D@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=U<V5R<R<I
M('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D=7-E<B`]
M/B`D;65M8F5R<VAI<"D@>PH@("`@("`@("`@("`@("`@("`@("1A='1R:6)U
M=&5S6W-T<G1O;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G75LG<&%R
M86US)UU;)VUE;6)E<G5I9"==*5U;72`]("1U<V5R.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&ME>2`]/2`G96UA:6PG*2![
M"B`@("`@("`@("`@("`@("`D871T<FEB=71E<ULG;6%I;"==(#T@(65M<'1Y
M*"1V86QU92D@/R`D=F%L=64@.B`G("<["B`@("`@("`@("`@('T@96QS96EF
M("@D:V5Y("$]("=D;B<@)B8@)&ME>2`A/2!S=')T;VQO=V5R*"1'3$]"04Q3
M6R=C;VYF)UU;)V=R;W5P)UU;)W!A<F%M<R==6R=M96UB97)U:60G72DI('L*
M("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R1K97E=(#T@(65M<'1Y*"1V
M86QU92D@/R`D=F%L=64@.B`G("<["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D871T<FEB=71E<SL*("`@('T*"GT`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)O=7`O:&]O:W,N<&AP````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-30T`#$P-3$U-#,Q
M,#8P`#`R,3$U-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($=R;W5P7VAO;VMS.CH@8VQA<W,@
M<')O=FED97,@=&AE($AO<F1E(&=R;W5P<R!S>7-T96T@=VET:"!T:&4*("H@
M861D:71I;VX@;V8@861D:6YG('-U<'!O<G0@9F]R(&AO;VL@9G5N8W1I;VYS
M('1O(&1E9FEN92!I9B!A('5S97(*("H@:7,@:6X@82!G<F]U<"X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O:&]O:W,N<&AP+'8@,2XW
M+C(N,3`@,C`P-B\P,2\P,2`R,3HR.#HQ.2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!2=7-T(#QJ<G5S=$!R=7-T>7!A<G1S
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N(%)U<W0@
M/&IR=7-T0')U<W1Y<&%R=',N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?1W)O=7`*("HO"F-L87-S($=R;W5P7VAO;VMS
M(&5X=&5N9',@1W)O=7`@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($=R;W5P7VAO;VMS*"D*("`@('L*("`@
M("`@("!P87)E;G0Z.D=R;W5P*"D["B`@("`@("`@<F5Q=6ER92`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]C
M;VYF:6<O:&]O:W,N<&AP)SL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M(&QI<W0@;V8@979E<GD@9W)O=7`@=&AA="`D=7-E<B!I<R!I;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7-E<B`@("`@("`@("!4:&4@=7-E
M<B!T;R!G970@9W)O=7!S(&9O<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P
M87)E;G1'<F]U<',@($%L<V\@<F5T=7)N('1H92!P87)E;G1S(&]F(&%N>2!G
M<F]U<',_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M;V8@86QL(&=R;W5P<R!T:&4@=7-E<B!I<R!I;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1W)O=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P
M<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1M96UB97)S:&EP<R`]('!A<F5N
M=#HZ9V5T1W)O=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<RD[
M"B`@("`@("`@)&=R;W5P<R`]("1T:&ES+3YL:7-T1W)O=7!S*"D["B`@("`@
M("`@9F]R96%C:"`H)&=R;W5P<R!A<R`D9VED(#T^("1G<F]U<"D@>PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/FAA<TAO;VLH)&=R;W5P*2`F)@H@("`@("`@
M("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/E]G971'<F]U<$AO;VM.
M86UE*"1G<F]U<"DL("1U<V5R*2D@>PH@("`@("`@("`@("`@("`@)&UE;6)E
M<G-H:7!S("L](&%R<F%Y*"1G:60@/3X@)&=R;W5P*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H)'!A<F5N=$=R;W5P<RD@>PH@("`@("`@("`@
M("`@("`@)'!A<F5N=',@/2`D=&AI<RT^9V5T1W)O=7!087)E;G1,:7-T*"1G
M:60I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F5N=',@87,@)'!I
M9"`]/B`D<&%R96YT*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YH87-(;V]K*"1P87)E;G0I("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?9V5T1W)O=7!(;V]K3F%M92@D9W)O
M=7`I+"`D=7-E<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UE;6)E
M<G-H:7!S("L](&%R<F%Y*"1P:60@/3X@)'!A<F5N="D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&UE;6)E<G-H:7!S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V%Y(&EF(&$@=7-E<B!I<R!A(&UE;6)E<B!O9B!A
M(&=R;W5P(&]R(&YO="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M=7-E<B`@("`@("!4:&4@;F%M92!O9B!T:&4@=7-E<BX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1G:60@("`@("`@(%1H92!)1"!O9B!T:&4@9W)O=7`N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D<W5B9W)O=7!S("!2971U<FX@=')U92!I
M9B!T:&4@=7-E<B!I<R!I;B!A;GD@<W5B9W)O=7!S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!O9B`D9W)O=7`L(&%L<V\N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*B\*("`@(&9U;F-T:6]N('5S
M97))<TEN1W)O=7`H)'5S97(L("1G:60L("1S=6)G<F]U<',@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1G<F]U<"`]("1T:&ES+3YG971'<F]U<$YA;64H)&=I
M9"D["B`@("`@("`@:68@*"1T:&ES+3YH87-(;V]K*"1G<F]U<"DI('L*("`@
M("`@("`@("`@:68@*&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?9V5T1W)O=7!(
M;V]K3F%M92@D9W)O=7`I+"`D=7-E<BDI('L*("`@("`@("`@("`@("`@("1I
M;D=R;W5P(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1I;D=R;W5P(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D:6Y'<F]U<"`](&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1I;D=R;W5P('Q\('!A<F5N=#HZ=7-E<DES
M26Y'<F]U<"@D=7-E<BP@)&=I9"P@)'-U8F=R;W5P<RDI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($1E=&5R;6EN97,@:68@82!G<F]U<"!H87,@82!H;V]K(&%S<V]C:6%T960@
M=VET:"!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@9W)O=7`@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE(&=R;W5P(&AA<R!A(&AO;VLL(&9A;'-E(&]T:&5R=VES
M90H@("`@("HO"B`@("!F=6YC=&EO;B!H87-(;V]K*"1N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B!F=6YC=&EO;E]E>&ES=',H)'1H:7,M/E]G971'<F]U
M<$AO;VM.86UE*"1N86UE*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!N86UE(&]F('1H92!H;V]K(&9U;F-T:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!G<F]U<"!N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5N8W1I;VX@;F%M92!F
M;W(@=&AE(&AO;VL@9F]R('1H:7,@9W)O=7`*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$=R;W5P2&]O:TYA;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T
M=7)N("=?9W)O=7!?:&]O:U\G("X@<W1R7W)E<&QA8V4H)SHG+"`G7U\G+"`D
M;F%M92D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+P``````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`V,``P,3<R-#``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M26UA9V4O<F=B+G!H<```````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#0R-C<Q`#$P-3$U-#,Q,#8P`#`R,#4S,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@4D="(&-O
M;&]R(&YA;65S+W9A;'5E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO26UA
M9V4O26UA9V4O<F=B+G!H<"QV(#$N,BXQ,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z
M,3,@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J+PHD
M1TQ/0D%,4ULG:&]R9&5?:6UA9V5?<F=B7V-O;&]R<R==(#T@87)R87DH"B`@
M("`G87%U82<@/3X@87)R87DH,"P@,C4U+"`R-34I+"`)"0H@("`@)VQI;64G
M(#T^(&%R<F%Y*#`L(#(U-2P@,"DL(`D)"B`@("`G=&5A;"<@/3X@87)R87DH
M,"P@,3(X+"`Q,C@I+`H@("`@)W=H:71E<VUO:V4G(#T^(&%R<F%Y*#(T-2P@
M,C0U+"`R-#4I+`H@("`@)V=A:6YS8F]R;R<@/3X@87)R87DH,C(P+"`R,C`L
M(#(R,"DL"B`@("`G;VQD;&%C92<@/3X@87)R87DH,C4S+"`R-#4L(#(S,"DL
M"B`@("`G;&EN96XG(#T^(&%R<F%Y*#(U,"P@,C0P+"`R,S`I+`H@("`@)V%N
M=&EQ=65W:&ET92<@/3X@87)R87DH,C4P+"`R,S4L(#(Q-2DL"B`@("`G<&%P
M87EA=VAI<"<@/3X@87)R87DH,C4U+"`R,SDL(#(Q,RDL"B`@("`G8FQA;F-H
M961A;&UO;F0G(#T^(&%R<F%Y*#(U-2P@,C,U+"`R,#4I+`H@("`@)V)I<W%U
M92<@/3X@87)R87DH,C4U+"`R,C@L(#$Y-BDL"B`@("`G<&5A8VAP=69F)R`]
M/B!A<G)A>2@R-34L(#(Q."P@,3@U*2P*("`@("=N879A:F]W:&ET92<@/3X@
M87)R87DH,C4U+"`R,C(L(#$W,RDL"B`@("`G;6]C8V%S:6XG(#T^(&%R<F%Y
M*#(U-2P@,C(X+"`Q.#$I+`H@("`@)V-O<FYS:6QK)R`]/B!A<G)A>2@R-34L
M(#(T."P@,C(P*2P*("`@("=I=F]R>2<@/3X@87)R87DH,C4U+"`R-34L(#(T
M,"DL"B`@("`G;&5M;VYC:&EF9F]N)R`]/B!A<G)A>2@R-34L(#(U,"P@,C`U
M*2P*("`@("=S96%S:&5L;"<@/3X@87)R87DH,C4U+"`R-#4L(#(S."DL"B`@
M("`G;6EN=&-R96%M)R`]/B!A<G)A>2@R-#4L(#(U-2P@,C4P*2P*("`@("=A
M>G5R92<@/3X@87)R87DH,C0P+"`R-34L(#(U-2DL"B`@("`G86QI8V5B;'5E
M)R`]/B!A<G)A>2@R-#`L(#(T."P@,C4U*2P*("`@("=L879E;F1E<B<@/3X@
M87)R87DH,C,P+"`R,S`L(#(U,"DL"B`@("`G;&%V96YD97)B;'5S:"<@/3X@
M87)R87DH,C4U+"`R-#`L(#(T-2DL"B`@("`G;6ES='ER;W-E)R`]/B!A<G)A
M>2@R-34L(#(R."P@,C(U*2P*("`@("=W:&ET92<@/3X@87)R87DH,C4U+"`R
M-34L(#(U-2DL"B`@("`G8FQA8VLG(#T^(&%R<F%Y*#`L(#`L(#`I+`H@("`@
M)V1A<FMS;&%T96=R87DG(#T^(&%R<F%Y*#0W+"`W.2P@-SDI+`H@("`@)V1I
M;6=R87DG(#T^(&%R<F%Y*#$P-2P@,3`U+"`Q,#4I+`H@("`@)W-L871E9W)A
M>2<@/3X@87)R87DH,3$R+"`Q,C@L(#$T-"DL"B`@("`G;&EG:'1S;&%T96=R
M87DG(#T^(&%R<F%Y*#$Q.2P@,3,V+"`Q-3,I+`H@("`@)V=R87DG(#T^(&%R
M<F%Y*#$Y,"P@,3DP+"`Q.3`I+`H@("`@)VQI9VAT9W)A>2<@/3X@87)R87DH
M,C$Q+"`R,3$L(#(Q,2DL"B`@("`G;6ED;FEG:'1B;'5E)R`]/B!A<G)A>2@R
M-2P@,C4L(#$Q,BDL"B`@("`G;F%V>2<@/3X@87)R87DH,"P@,"P@,3(X*2P*
M("`@("=C;W)N9FQO=V5R8FQU92<@/3X@87)R87DH,3`P+"`Q-#DL(#(S-RDL
M"B`@("`G9&%R:W-L871E8FQU92<@/3X@87)R87DH-S(L(#8Q+"`Q,SDI+`H@
M("`@)W-L871E8FQU92<@/3X@87)R87DH,3`V+"`Y,"P@,C`U*2P*("`@("=M
M961I=6US;&%T96)L=64G(#T^(&%R<F%Y*#$R,RP@,3`T+"`R,S@I+`H@("`@
M)VQI9VAT<VQA=&5B;'5E)R`]/B!A<G)A>2@Q,S(L(#$Q,BP@,C4U*2P*("`@
M("=M961I=6UB;'5E)R`]/B!A<G)A>2@P+"`P+"`R,#4I+`H@("`@)W)O>6%L
M8FQU92<@/3X@87)R87DH-C4L(#$P-2P@,C(U*2P*("`@("=B;'5E)R`]/B!A
M<G)A>2@P+"`P+"`R-34I+`H@("`@)V1O9&=E<F)L=64G(#T^(&%R<F%Y*#,P
M+"`Q-#0L(#(U-2DL"B`@("`G9&5E<'-K>6)L=64G(#T^(&%R<F%Y*#`L(#$Y
M,2P@,C4U*2P*("`@("=S:WEB;'5E)R`]/B!A<G)A>2@Q,S4L(#(P-BP@,C,U
M*2P*("`@("=L:6=H='-K>6)L=64G(#T^(&%R<F%Y*#$S-2P@,C`V+"`R-3`I
M+`H@("`@)W-T965L8FQU92<@/3X@87)R87DH-S`L(#$S,"P@,3@P*2P*("`@
M("=L:6=H=')E9"<@/3X@87)R87DH,C$Q+"`Q-C<L(#$V."DL"B`@("`G;&EG
M:'1S=&5E;&)L=64G(#T^(&%R<F%Y*#$W-BP@,3DV+"`R,C(I+`H@("`@)VQI
M9VAT8FQU92<@/3X@87)R87DH,3<S+"`R,38L(#(S,"DL"B`@("`G<&]W9&5R
M8FQU92<@/3X@87)R87DH,3<V+"`R,C0L(#(S,"DL"B`@("`G<&%L971U<G%U
M;VES92<@/3X@87)R87DH,3<U+"`R,S@L(#(S."DL"B`@("`G9&%R:W1U<G%U
M;VES92<@/3X@87)R87DH,"P@,C`V+"`R,#DI+`H@("`@)VUE9&EU;71U<G%U
M;VES92<@/3X@87)R87DH-S(L(#(P.2P@,C`T*2P*("`@("=T=7)Q=6]I<V4G
M(#T^(&%R<F%Y*#8T+"`R,C0L(#(P."DL"B`@("`G8WEA;B<@/3X@87)R87DH
M,"P@,C4U+"`R-34I+`H@("`@)VQI9VAT8WEA;B<@/3X@87)R87DH,C(T+"`R
M-34L(#(U-2DL"B`@("`G8V%D971B;'5E)R`]/B!A<G)A>2@Y-2P@,34X+"`Q
M-C`I+`H@("`@)VUE9&EU;6%Q=6%M87)I;F4G(#T^(&%R<F%Y*#$P,BP@,C`U
M+"`Q-S`I+`H@("`@)V%Q=6%M87)I;F4G(#T^(&%R<F%Y*#$R-RP@,C4U+"`R
M,3(I+`H@("`@)V1A<FMG<F5E;B<@/3X@87)R87DH,"P@,3`P+"`P*2P*("`@
M("=D87)K;VQI=F5G<F5E;B<@/3X@87)R87DH.#4L(#$P-RP@-#<I+`H@("`@
M)V1A<FMS96%G<F5E;B<@/3X@87)R87DH,30S+"`Q.#@L(#$T,RDL"B`@("`G
M<V5A9W)E96XG(#T^(&%R<F%Y*#0V+"`Q,SDL(#@W*2P*("`@("=M961I=6US
M96%G<F5E;B<@/3X@87)R87DH-C`L(#$W.2P@,3$S*2P*("`@("=L:6=H='-E
M86=R965N)R`]/B!A<G)A>2@S,BP@,3<X+"`Q-S`I+`H@("`@)W!A;&5G<F5E
M;B<@/3X@87)R87DH,34R+"`R-3$L(#$U,BDL"B`@("`G<W!R:6YG9W)E96XG
M(#T^(&%R<F%Y*#`L(#(U-2P@,3(W*2P*("`@("=L87=N9W)E96XG(#T^(&%R
M<F%Y*#$R-"P@,C4R+"`P*2P*("`@("=G<F5E;B<@/3X@87)R87DH,"P@,C4U
M+"`P*2P*("`@("=C:&%R=')E=7-E)R`]/B!A<G)A>2@Q,C<L(#(U-2P@,"DL
M"B`@("`G;65D:75M<W!R:6YG9W)E96XG(#T^(&%R<F%Y*#`L(#(U,"P@,34T
M*2P*("`@("=G<F5E;GEE;&QO=R<@/3X@87)R87DH,3<S+"`R-34L(#0W*2P*
M("`@("=L:6UE9W)E96XG(#T^(&%R<F%Y*#4P+"`R,#4L(#4P*2P*("`@("=Y
M96QL;W=G<F5E;B<@/3X@87)R87DH,34T+"`R,#4L(#4P*2P*("`@("=F;W)E
M<W1G<F5E;B<@/3X@87)R87DH,S0L(#$S.2P@,S0I+`H@("`@)V]L:79E9')A
M8B<@/3X@87)R87DH,3`W+"`Q-#(L(#,U*2P*("`@("=D87)K:VAA:VDG(#T^
M(&%R<F%Y*#$X.2P@,3@S+"`Q,#<I+`H@("`@)VMH86MI)R`]/B!A<G)A>2@R
M-#`L(#(S,"P@,30P*2P*("`@("=P86QE9V]L9&5N<F]D)R`]/B!A<G)A>2@R
M,S@L(#(S,BP@,3<P*2P*("`@("=L:6=H=&=O;&1E;G)O9'EE;&QO=R<@/3X@
M87)R87DH,C4P+"`R-3`L(#(Q,"DL"B`@("`G;&EG:'1Y96QL;W<G(#T^(&%R
M<F%Y*#(U-2P@,C4U+"`R,#`I+`H@("`@)WEE;&QO=R<@/3X@87)R87DH,C4U
M+"`R-34L(#`I+`H@("`@)V=O;&0G(#T^(&%R<F%Y*#(U-2P@,C$U+"`P*2P*
M("`@("=L:6=H=&=O;&1E;G)O9"<@/3X@87)R87DH,C,X+"`R,C$L(#$S,"DL
M"B`@("`G9V]L9&5N<F]D)R`]/B!A<G)A>2@R,3@L(#$V-2P@,S(I+`H@("`@
M)V1A<FMG;VQD96YR;V0G(#T^(&%R<F%Y*#$X-"P@,3,T+"`Q,2DL"B`@("`G
M<F]S>6)R;W=N)R`]/B!A<G)A>2@Q.#@L(#$T,RP@,30S*2P*("`@("=I;F1I
M86YR960G(#T^(&%R<F%Y*#(P-2P@.3(L(#DR*2P*("`@("=S861D;&5B<F]W
M;B<@/3X@87)R87DH,3,Y+"`V.2P@,3DI+`H@("`@)W-I96YN82<@/3X@87)R
M87DH,38P+"`X,BP@-#4I+`H@("`@)W!E<G4G(#T^(&%R<F%Y*#(P-2P@,3,S
M+"`V,RDL"B`@("`G8G5R;'EW;V]D)R`]/B!A<G)A>2@R,C(L(#$X-"P@,3,U
M*2P*("`@("=B96EG92<@/3X@87)R87DH,C0U+"`R-#4L(#(R,"DL"B`@("`G
M=VAE870G(#T^(&%R<F%Y*#(T-2P@,C(R+"`Q-SDI+`H@("`@)W-A;F1Y8G)O
M=VXG(#T^(&%R<F%Y*#(T-"P@,38T+"`Y-BDL"B`@("`G=&%N)R`]/B!A<G)A
M>2@R,3`L(#$X,"P@,30P*2P*("`@("=C:&]C;VQA=&4G(#T^(&%R<F%Y*#(Q
M,"P@,3`U+"`S,"DL"B`@("`G9FER96)R:6-K)R`]/B!A<G)A>2@Q-S@L(#,T
M+"`S-"DL"B`@("`G8G)O=VXG(#T^(&%R<F%Y*#$V-2P@-#(L(#0R*2P*("`@
M("=D87)K<V%L;6]N)R`]/B!A<G)A>2@R,S,L(#$U,"P@,3(R*2P*("`@("=S
M86QM;VXG(#T^(&%R<F%Y*#(U,"P@,3(X+"`Q,30I+`H@("`@)VQI9VAT<V%L
M;6]N)R`]/B!A<G)A>2@R-34L(#$V,"P@,3(R*2P*("`@("=O<F%N9V4G(#T^
M(&%R<F%Y*#(U-2P@,38U+"`P*2P*("`@("=D87)K;W)A;F=E)R`]/B!A<G)A
M>2@R-34L(#$T,"P@,"DL"B`@("`G8V]R86PG(#T^(&%R<F%Y*#(U-2P@,3(W
M+"`X,"DL"B`@("`G;&EG:'1C;W)A;"<@/3X@87)R87DH,C0P+"`Q,C@L(#$R
M."DL"B`@("`G=&]M871O)R`]/B!A<G)A>2@R-34L(#DY+"`W,2DL"B`@("`G
M;W)A;F=E<F5D)R`]/B!A<G)A>2@R-34L(#8Y+"`P*2P*("`@("=R960G(#T^
M(&%R<F%Y*#(U-2P@,"P@,"DL"B`@("`G:&]T<&EN:R<@/3X@87)R87DH,C4U
M+"`Q,#4L(#$X,"DL"B`@("`G9&5E<'!I;FLG(#T^(&%R<F%Y*#(U-2P@,C`L
M(#$T-RDL"B`@("`G<&EN:R<@/3X@87)R87DH,C4U+"`Q.3(L(#(P,RDL"B`@
M("`G;&EG:'1P:6YK)R`]/B!A<G)A>2@R-34L(#$X,BP@,3DS*2P*("`@("=P
M86QE=FEO;&5T<F5D)R`]/B!A<G)A>2@R,3DL(#$Q,BP@,30W*2P*("`@("=M
M87)O;VXG(#T^(&%R<F%Y*#$W-BP@-#@L(#DV*2P*("`@("=M961I=6UV:6]L
M971R960G(#T^(&%R<F%Y*#$Y.2P@,C$L(#$S,RDL"B`@("`G=FEO;&5T<F5D
M)R`]/B!A<G)A>2@R,#@L(#,R+"`Q-#0I+`H@("`@)VUA9V5N=&$G(#T^(&%R
M<F%Y*#(U-2P@,"P@,C4U*2P*("`@("=V:6]L970G(#T^(&%R<F%Y*#(S."P@
M,3,P+"`R,S@I+`H@("`@)W!L=6TG(#T^(&%R<F%Y*#(R,2P@,38P+"`R,C$I
M+`H@("`@)V]R8VAI9"<@/3X@87)R87DH,C$X+"`Q,3(L(#(Q-"DL"B`@("`G
M;65D:75M;W)C:&ED)R`]/B!A<G)A>2@Q.#8L(#@U+"`R,3$I+`H@("`@)V1A
M<FMO<F-H:60G(#T^(&%R<F%Y*#$U,RP@-3`L(#(P-"DL"B`@("`G9&%R:W9I
M;VQE="<@/3X@87)R87DH,30X+"`P+"`R,3$I+`H@("`@)V)L=65V:6]L970G
M(#T^(&%R<F%Y*#$S."P@-#,L(#(R-BDL"B`@("`G<'5R<&QE)R`]/B!A<G)A
M>2@Q-C`L(#,R+"`R-#`I+`H@("`@)VUE9&EU;7!U<G!L92<@/3X@87)R87DH
M,30W+"`Q,3(L(#(Q.2DL"B`@("`G=&AI<W1L92<@/3X@87)R87DH,C$V+"`Q
M.3$L(#(Q-BDL"B`@("`G<VYO=S$G(#T^(&%R<F%Y*#(U-2P@,C4P+"`R-3`I
M+`H@("`@)W-N;W<R)R`]/B!A<G)A>2@R,S@L(#(S,RP@,C,S*2P*("`@("=S
M;F]W,R<@/3X@87)R87DH,C`U+"`R,#$L(#(P,2DL"B`@("`G<VYO=S0G(#T^
M(&%R<F%Y*#$S.2P@,3,W+"`Q,S<I+`H@("`@)W-E87-H96QL,2<@/3X@87)R
M87DH,C4U+"`R-#4L(#(S."DL"B`@("`G<V5A<VAE;&PR)R`]/B!A<G)A>2@R
M,S@L(#(R.2P@,C(R*2P*("`@("=S96%S:&5L;#,G(#T^(&%R<F%Y*#(P-2P@
M,3DW+"`Q.3$I+`H@("`@)W-E87-H96QL-"<@/3X@87)R87DH,3,Y+"`Q,S0L
M(#$S,"DL"B`@("`G06YT:7%U95=H:71E,2<@/3X@87)R87DH,C4U+"`R,SDL
M(#(Q.2DL"B`@("`G06YT:7%U95=H:71E,B<@/3X@87)R87DH,C,X+"`R,C,L
M(#(P-"DL"B`@("`G06YT:7%U95=H:71E,R<@/3X@87)R87DH,C`U+"`Q.3(L
M(#$W-BDL"B`@("`G06YT:7%U95=H:71E-"<@/3X@87)R87DH,3,Y+"`Q,S$L
M(#$R,"DL"B`@("`G8FES<75E,2<@/3X@87)R87DH,C4U+"`R,C@L(#$Y-BDL
M"B`@("`G8FES<75E,B<@/3X@87)R87DH,C,X+"`R,3,L(#$X,RDL"B`@("`G
M8FES<75E,R<@/3X@87)R87DH,C`U+"`Q.#,L(#$U."DL"B`@("`G8FES<75E
M-"<@/3X@87)R87DH,3,Y+"`Q,C4L(#$P-RDL"B`@("`G<&5A8VA0=69F,2<@
M/3X@87)R87DH,C4U+"`R,3@L(#$X-2DL"B`@("`G<&5A8VAP=69F,B<@/3X@
M87)R87DH,C,X+"`R,#,L(#$W,RDL"B`@("`G<&5A8VAP=69F,R<@/3X@87)R
M87DH,C`U+"`Q-S4L(#$T.2DL"B`@("`G<&5A8VAP=69F-"<@/3X@87)R87DH
M,3,Y+"`Q,3DL(#$P,2DL"B`@("`G;F%V86IO=VAI=&4Q)R`]/B!A<G)A>2@R
M-34L(#(R,BP@,3<S*2P*("`@("=N879A:F]W:&ET93(G(#T^(&%R<F%Y*#(S
M."P@,C`W+"`Q-C$I+`H@("`@)VYA=F%J;W=H:71E,R<@/3X@87)R87DH,C`U
M+"`Q-SDL(#$S.2DL"B`@("`G;F%V86IO=VAI=&4T)R`]/B!A<G)A>2@Q,SDL
M(#$R,2P@.30I+`H@("`@)VQE;6]N8VAI9F9O;C$G(#T^(&%R<F%Y*#(U-2P@
M,C4P+"`R,#4I+`H@("`@)VQE;6]N8VAI9F9O;C(G(#T^(&%R<F%Y*#(S."P@
M,C,S+"`Q.3$I+`H@("`@)VQE;6]N8VAI9F9O;C,G(#T^(&%R<F%Y*#(P-2P@
M,C`Q+"`Q-C4I+`H@("`@)VQE;6]N8VAI9F9O;C0G(#T^(&%R<F%Y*#$S.2P@
M,3,W+"`Q,3(I+`H@("`@)VEV;W)Y,2<@/3X@87)R87DH,C4U+"`R-34L(#(T
M,"DL"B`@("`G:79O<GDR)R`]/B!A<G)A>2@R,S@L(#(S."P@,C(T*2P*("`@
M("=I=F]R>3,G(#T^(&%R<F%Y*#(P-2P@,C`U+"`Q.3,I+`H@("`@)VEV;W)Y
M-"<@/3X@87)R87DH,3,Y+"`Q,SDL(#$S,2DL"B`@("`G:&]N97ED97<G(#T^
M(&%R<F%Y*#$Y,RP@,C`U+"`Q.3,I+`H@("`@)VQA=F5N9&5R8FQU<V@Q)R`]
M/B!A<G)A>2@R-34L(#(T,"P@,C0U*2P*("`@("=L879E;F1E<F)L=7-H,B<@
M/3X@87)R87DH,C,X+"`R,C0L(#(R.2DL"B`@("`G;&%V96YD97)B;'5S:#,G
M(#T^(&%R<F%Y*#(P-2P@,3DS+"`Q.3<I+`H@("`@)VQA=F5N9&5R8FQU<V@T
M)R`]/B!A<G)A>2@Q,SDL(#$S,2P@,3,T*2P*("`@("=M:7-T>7)O<V4Q)R`]
M/B!A<G)A>2@R-34L(#(R."P@,C(U*2P*("`@("=M:7-T>7)O<V4R)R`]/B!A
M<G)A>2@R,S@L(#(Q,RP@,C$P*2P*("`@("=M:7-T>7)O<V4S)R`]/B!A<G)A
M>2@R,#4L(#$X,RP@,3@Q*2P*("`@("=M:7-T>7)O<V4T)R`]/B!A<G)A>2@Q
M,SDL(#$R-2P@,3(S*2P*("`@("=A>G5R93$G(#T^(&%R<F%Y*#(T,"P@,C4U
M+"`R-34I+`H@("`@)V%Z=7)E,B<@/3X@87)R87DH,C(T+"`R,S@L(#(S."DL
M"B`@("`G87IU<F4S)R`]/B!A<G)A>2@Q.3,L(#(P-2P@,C`U*2P*("`@("=A
M>G5R930G(#T^(&%R<F%Y*#$S,2P@,3,Y+"`Q,SDI+`H@("`@)W-L871E8FQU
M93$G(#T^(&%R<F%Y*#$S,2P@,3$Q+"`R-34I+`H@("`@)W-L871E8FQU93(G
M(#T^(&%R<F%Y*#$R,BP@,3`S+"`R,S@I+`H@("`@)W-L871E8FQU93,G(#T^
M(&%R<F%Y*#$P-2P@.#DL(#(P-2DL"B`@("`G<VQA=&5B;'5E-"<@/3X@87)R
M87DH-S$L(#8P+"`Q,SDI+`H@("`@)W)O>6%L8FQU93$G(#T^(&%R<F%Y*#<R
M+"`Q,3@L(#(U-2DL"B`@("`G<F]Y86QB;'5E,B<@/3X@87)R87DH-C<L(#$Q
M,"P@,C,X*2P*("`@("=R;WEA;&)L=64S)R`]/B!A<G)A>2@U."P@.34L(#(P
M-2DL"B`@("`G<F]Y86QB;'5E-"<@/3X@87)R87DH,SDL(#8T+"`Q,SDI+`H@
M("`@)V1O9&=E<F)L=64Q)R`]/B!A<G)A>2@S,"P@,30T+"`R-34I+`H@("`@
M)V1O9&=E<F)L=64R)R`]/B!A<G)A>2@R."P@,3,T+"`R,S@I+`H@("`@)V1O
M9&=E<F)L=64S)R`]/B!A<G)A>2@R-"P@,3$V+"`R,#4I+`H@("`@)V1O9&=E
M<F)L=64T)R`]/B!A<G)A>2@Q-BP@-S@L(#$S.2DL"B`@("`G<W1E96QB;'5E
M,2<@/3X@87)R87DH.3DL(#$X-"P@,C4U*2P*("`@("=S=&5E;&)L=64R)R`]
M/B!A<G)A>2@Y,BP@,3<R+"`R,S@I+`H@("`@)W-T965L8FQU93,G(#T^(&%R
M<F%Y*#<Y+"`Q-#@L(#(P-2DL"B`@("`G<W1E96QB;'5E-"<@/3X@87)R87DH
M-30L(#$P,"P@,3,Y*2P*("`@("=D965P<VMY8FQU93$G(#T^(&%R<F%Y*#`L
M(#$Y,2P@,C4U*2P*("`@("=D965P<VMY8FQU93(G(#T^(&%R<F%Y*#`L(#$W
M."P@,C,X*2P*("`@("=D965P<VMY8FQU93,G(#T^(&%R<F%Y*#`L(#$U-"P@
M,C`U*2P*("`@("=D965P<VMY8FQU930G(#T^(&%R<F%Y*#`L(#$P-"P@,3,Y
M*2P*("`@("=S:WEB;'5E,2<@/3X@87)R87DH,3,U+"`R,#8L(#(U-2DL"B`@
M("`G<VMY8FQU93(G(#T^(&%R<F%Y*#$R-BP@,3DR+"`R,S@I+`H@("`@)W-K
M>6)L=64S)R`]/B!A<G)A>2@Q,#@L(#$V-BP@,C`U*2P*("`@("=S:WEB;'5E
M-"<@/3X@87)R87DH-S0L(#$Q,BP@,3,Y*2P*("`@("=L:6=H='-K>6)L=64Q
M)R`]/B!A<G)A>2@Q-S8L(#(R-BP@,C4U*2P*("`@("=L:6=H='-K>6)L=64R
M)R`]/B!A<G)A>2@Q-C0L(#(Q,2P@,C,X*2P*("`@("=L:6=H='-K>6)L=64S
M)R`]/B!A<G)A>2@Q-#$L(#$X,BP@,C`U*2P*("`@("=L:6=H='-K>6)L=64T
M)R`]/B!A<G)A>2@Y-BP@,3(S+"`Q,SDI+`H@("`@)W-L871E9W)A>3$G(#T^
M(&%R<F%Y*#$Y."P@,C(V+"`R-34I+`H@("`@)W-L871E9W)A>3(G(#T^(&%R
M<F%Y*#$X-2P@,C$Q+"`R,S@I+`H@("`@)W-L871E9W)A>3,G(#T^(&%R<F%Y
M*#$U.2P@,3@R+"`R,#4I+`H@("`@)W-L871E9W)A>30G(#T^(&%R<F%Y*#$P
M."P@,3(S+"`Q,SDI+`H@("`@)VQI9VAT<W1E96QB;'5E,2<@/3X@87)R87DH
M,C`R+"`R,C4L(#(U-2DL"B`@("`G;&EG:'1S=&5E;&)L=64R)R`]/B!A<G)A
M>2@Q.#@L(#(Q,"P@,C,X*2P*("`@("=L:6=H='-T965L8FQU93,G(#T^(&%R
M<F%Y*#$V,BP@,3@Q+"`R,#4I+`H@("`@)VQI9VAT<W1E96QB;'5E-"<@/3X@
M87)R87DH,3$P+"`Q,C,L(#$S.2DL"B`@("`G;&EG:'1B;'5E,2<@/3X@87)R
M87DH,3DQ+"`R,SDL(#(U-2DL"B`@("`G;&EG:'1B;'5E,B<@/3X@87)R87DH
M,3<X+"`R,C,L(#(S."DL"B`@("`G;&EG:'1B;'5E,R<@/3X@87)R87DH,34T
M+"`Q.3(L(#(P-2DL"B`@("`G;&EG:'1B;'5E-"<@/3X@87)R87DH,3`T+"`Q
M,S$L(#$S.2DL"B`@("`G;&EG:'1C>6%N,2<@/3X@87)R87DH,C(T+"`R-34L
M(#(U-2DL"B`@("`G;&EG:'1C>6%N,B<@/3X@87)R87DH,C`Y+"`R,S@L(#(S
M."DL"B`@("`G;&EG:'1C>6%N,R<@/3X@87)R87DH,3@P+"`R,#4L(#(P-2DL
M"B`@("`G;&EG:'1C>6%N-"<@/3X@87)R87DH,3(R+"`Q,SDL(#$S.2DL"B`@
M("`G<&%L971U<G%U;VES93$G(#T^(&%R<F%Y*#$X-RP@,C4U+"`R-34I+`H@
M("`@)W!A;&5T=7)Q=6]I<V4R)R`]/B!A<G)A>2@Q-S0L(#(S."P@,C,X*2P*
M("`@("=P86QE='5R<75O:7-E,R<@/3X@87)R87DH,34P+"`R,#4L(#(P-2DL
M"B`@("`G<&%L971U<G%U;VES930G(#T^(&%R<F%Y*#$P,BP@,3,Y+"`Q,SDI
M+`H@("`@)V-A9&5T8FQU93$G(#T^(&%R<F%Y*#$U,BP@,C0U+"`R-34I+`H@
M("`@)V-A9&5T8FQU93(G(#T^(&%R<F%Y*#$T,BP@,C(Y+"`R,S@I+`H@("`@
M)V-A9&5T8FQU93,G(#T^(&%R<F%Y*#$R,BP@,3DW+"`R,#4I+`H@("`@)V-A
M9&5T8FQU930G(#T^(&%R<F%Y*#@S+"`Q,S0L(#$S.2DL"B`@("`G='5R<75O
M:7-E,2<@/3X@87)R87DH,"P@,C0U+"`R-34I+`H@("`@)W1U<G%U;VES93(G
M(#T^(&%R<F%Y*#`L(#(R.2P@,C,X*2P*("`@("=T=7)Q=6]I<V4S)R`]/B!A
M<G)A>2@P+"`Q.3<L(#(P-2DL"B`@("`G='5R<75O:7-E-"<@/3X@87)R87DH
M,"P@,3,T+"`Q,SDI+`H@("`@)V-Y86XQ)R`]/B!A<G)A>2@P+"`R-34L(#(U
M-2DL"B`@("`G8WEA;C(G(#T^(&%R<F%Y*#`L(#(S."P@,C,X*2P*("`@("=C
M>6%N,R<@/3X@87)R87DH,"P@,C`U+"`R,#4I+`H@("`@)V-Y86XT)R`]/B!A
M<G)A>2@P+"`Q,SDL(#$S.2DL"B`@("`G9&%R:W-L871E9W)A>3$G(#T^(&%R
M<F%Y*#$U,2P@,C4U+"`R-34I+`H@("`@)V1A<FMS;&%T96=R87DR)R`]/B!A
M<G)A>2@Q-#$L(#(S."P@,C,X*2P*("`@("=D87)K<VQA=&5G<F%Y,R<@/3X@
M87)R87DH,3(Q+"`R,#4L(#(P-2DL"B`@("`G9&%R:W-L871E9W)A>30G(#T^
M(&%R<F%Y*#@R+"`Q,SDL(#$S.2DL"B`@("`G87%U86UA<FEN93$G(#T^(&%R
M<F%Y*#$R-RP@,C4U+"`R,3(I+`H@("`@)V%Q=6%M87)I;F4R)R`]/B!A<G)A
M>2@Q,3@L(#(S."P@,3DX*2P*("`@("=A<75A;6%R:6YE,R<@/3X@87)R87DH
M,3`R+"`R,#4L(#$W,"DL"B`@("`G87%U86UA<FEN930G(#T^(&%R<F%Y*#8Y
M+"`Q,SDL(#$Q-BDL"B`@("`G9&%R:W-E86=R965N,2<@/3X@87)R87DH,3DS
M+"`R-34L(#$Y,RDL"B`@("`G9&%R:W-E86=R965N,B<@/3X@87)R87DH,3@P
M+"`R,S@L(#$X,"DL"B`@("`G9&%R:W-E86=R965N,R<@/3X@87)R87DH,34U
M+"`R,#4L(#$U-2DL"B`@("`G9&%R:W-E86=R965N-"<@/3X@87)R87DH,3`U
M+"`Q,SDL(#$P-2DL"B`@("`G<V5A9W)E96XQ)R`]/B!A<G)A>2@X-"P@,C4U
M+"`Q-3DI+`H@("`@)W-E86=R965N,B<@/3X@87)R87DH-S@L(#(S."P@,30X
M*2P*("`@("=S96%G<F5E;C,G(#T^(&%R<F%Y*#8W+"`R,#4L(#$R."DL"B`@
M("`G<V5A9W)E96XT)R`]/B!A<G)A>2@T-BP@,3,Y+"`X-RDL"B`@("`G<&%L
M96=R965N,2<@/3X@87)R87DH,34T+"`R-34L(#$U-"DL"B`@("`G<&%L96=R
M965N,B<@/3X@87)R87DH,30T+"`R,S@L(#$T-"DL"B`@("`G<&%L96=R965N
M,R<@/3X@87)R87DH,3(T+"`R,#4L(#$R-"DL"B`@("`G<&%L96=R965N-"<@
M/3X@87)R87DH.#0L(#$S.2P@.#0I+`H@("`@)W-P<FEN9V=R965N,2<@/3X@
M87)R87DH,"P@,C4U+"`Q,C<I+`H@("`@)W-P<FEN9V=R965N,B<@/3X@87)R
M87DH,"P@,C,X+"`Q,3@I+`H@("`@)W-P<FEN9V=R965N,R<@/3X@87)R87DH
M,"P@,C`U+"`Q,#(I+`H@("`@)W-P<FEN9V=R965N-"<@/3X@87)R87DH,"P@
M,3,Y+"`V.2DL"B`@("`G8VAA<G1R975S93$G(#T^(&%R<F%Y*#$R-RP@,C4U
M+"`P*2P*("`@("=C:&%R=')E=7-E,B<@/3X@87)R87DH,3$X+"`R,S@L(#`I
M+`H@("`@)V-H87)T<F5U<V4S)R`]/B!A<G)A>2@Q,#(L(#(P-2P@,"DL"B`@
M("`G8VAA<G1R975S930G(#T^(&%R<F%Y*#8Y+"`Q,SDL(#`I+`H@("`@)V]L
M:79E9')A8C$G(#T^(&%R<F%Y*#$Y,BP@,C4U+"`V,BDL"B`@("`G;VQI=F5D
M<F%B,B<@/3X@87)R87DH,3<Y+"`R,S@L(#4X*2P*("`@("=O;&EV961R86(S
M)R`]/B!A<G)A>2@Q-30L(#(P-2P@-3`I+`H@("`@)V]L:79E9')A8C0G(#T^
M(&%R<F%Y*#$P-2P@,3,Y+"`S-"DL"B`@("`G9&%R:V]L:79E9W)E96XQ)R`]
M/B!A<G)A>2@R,#(L(#(U-2P@,3$R*2P*("`@("=D87)K;VQI=F5G<F5E;C(G
M(#T^(&%R<F%Y*#$X."P@,C,X+"`Q,#0I+`H@("`@)V1A<FMO;&EV96=R965N
M,R<@/3X@87)R87DH,38R+"`R,#4L(#DP*2P*("`@("=D87)K;VQI=F5G<F5E
M;C0G(#T^(&%R<F%Y*#$Q,"P@,3,Y+"`V,2DL"B`@("`G:VAA:VDQ)R`]/B!A
M<G)A>2@R-34L(#(T-BP@,30S*2P*("`@("=K:&%K:3(G(#T^(&%R<F%Y*#(S
M."P@,C,P+"`Q,S,I+`H@("`@)VMH86MI,R<@/3X@87)R87DH,C`U+"`Q.3@L
M(#$Q-2DL"B`@("`G:VAA:VDT)R`]/B!A<G)A>2@Q,SDL(#$S-"P@-S@I+`H@
M("`@)VQI9VAT9V]L9&5N<F]D,2<@/3X@87)R87DH,C4U+"`R,S8L(#$S.2DL
M"B`@("`G;&EG:'1G;VQD96YR;V0R)R`]/B!A<G)A>2@R,S@L(#(R,"P@,3,P
M*2P*("`@("=L:6=H=&=O;&1E;G)O9#,G(#T^(&%R<F%Y*#(P-2P@,3DP+"`Q
M,3(I+`H@("`@)VQI9VAT9V]L9&5N<F]D-"<@/3X@87)R87DH,3,Y+"`Q,CDL
M(#<V*2P*("`@("=Y96QL;W<Q)R`]/B!A<G)A>2@R-34L(#(U-2P@,"DL"B`@
M("`G>65L;&]W,B<@/3X@87)R87DH,C,X+"`R,S@L(#`I+`H@("`@)WEE;&QO
M=S,G(#T^(&%R<F%Y*#(P-2P@,C`U+"`P*2P*("`@("=Y96QL;W<T)R`]/B!A
M<G)A>2@Q,SDL(#$S.2P@,"DL"B`@("`G9V]L9#$G(#T^(&%R<F%Y*#(U-2P@
M,C$U+"`P*2P*("`@("=G;VQD,B<@/3X@87)R87DH,C,X+"`R,#$L(#`I+`H@
M("`@)V=O;&0S)R`]/B!A<G)A>2@R,#4L(#$W,RP@,"DL"B`@("`G9V]L9#0G
M(#T^(&%R<F%Y*#$S.2P@,3$W+"`P*2P*("`@("=G;VQD96YR;V0Q)R`]/B!A
M<G)A>2@R-34L(#$Y,RP@,S<I+`H@("`@)V=O;&1E;G)O9#(G(#T^(&%R<F%Y
M*#(S."P@,3@P+"`S-"DL"B`@("`G9V]L9&5N<F]D,R<@/3X@87)R87DH,C`U
M+"`Q-34L(#(Y*2P*("`@("=G;VQD96YR;V0T)R`]/B!A<G)A>2@Q,SDL(#$P
M-2P@,C`I+`H@("`@)V1A<FMG;VQD96YR;V0Q)R`]/B!A<G)A>2@R-34L(#$X
M-2P@,34I+`H@("`@)V1A<FMG;VQD96YR;V0R)R`]/B!A<G)A>2@R,S@L(#$W
M,RP@,30I+`H@("`@)V1A<FMG;VQD96YR;V0S)R`]/B!A<G)A>2@R,#4L(#$T
M.2P@,3(I+`H@("`@)V1A<FMG;VQD96YR;V0T)R`]/B!A<G)A>2@Q,SDL(#$P
M,2P@."DL"B`@("`G<F]S>6)R;W=N,2<@/3X@87)R87DH,C4U+"`Q.3,L(#$Y
M,RDL"B`@("`G<F]S>6)R;W=N,B<@/3X@87)R87DH,C,X+"`Q.#`L(#$X,"DL
M"B`@("`G<F]S>6)R;W=N,R<@/3X@87)R87DH,C`U+"`Q-34L(#$U-2DL"B`@
M("`G<F]S>6)R;W=N-"<@/3X@87)R87DH,3,Y+"`Q,#4L(#$P-2DL"B`@("`G
M:6YD:6%N<F5D,2<@/3X@87)R87DH,C4U+"`Q,#8L(#$P-BDL"B`@("`G:6YD
M:6%N<F5D,B<@/3X@87)R87DH,C,X+"`Y.2P@.3DI+`H@("`@)VEN9&EA;G)E
M9#,G(#T^(&%R<F%Y*#(P-2P@.#4L(#@U*2P*("`@("=I;F1I86YR960T)R`]
M/B!A<G)A>2@Q,SDL(#4X+"`U."DL"B`@("`G<VEE;FYA,2<@/3X@87)R87DH
M,C4U+"`Q,S`L(#<Q*2P*("`@("=S:65N;F$R)R`]/B!A<G)A>2@R,S@L(#$R
M,2P@-C8I+`H@("`@)W-I96YN83,G(#T^(&%R<F%Y*#(P-2P@,3`T+"`U-RDL
M"B`@("`G<VEE;FYA-"<@/3X@87)R87DH,3,Y+"`W,2P@,S@I+`H@("`@)V)U
M<FQY=V]O9#$G(#T^(&%R<F%Y*#(U-2P@,C$Q+"`Q-34I+`H@("`@)V)U<FQY
M=V]O9#(G(#T^(&%R<F%Y*#(S."P@,3DW+"`Q-#4I+`H@("`@)V)U<FQY=V]O
M9#,G(#T^(&%R<F%Y*#(P-2P@,3<P+"`Q,C4I+`H@("`@)V)U<FQY=V]O9#0G
M(#T^(&%R<F%Y*#$S.2P@,3$U+"`X-2DL"B`@("`G=VAE870Q)R`]/B!A<G)A
M>2@R-34L(#(S,2P@,3@V*2P*("`@("=W:&5A=#(G(#T^(&%R<F%Y*#(S."P@
M,C$V+"`Q-S0I+`H@("`@)W=H96%T,R<@/3X@87)R87DH,C`U+"`Q.#8L(#$U
M,"DL"B`@("`G=VAE870T)R`]/B!A<G)A>2@Q,SDL(#$R-BP@,3`R*2P*("`@
M("=T86XQ)R`]/B!A<G)A>2@R-34L(#$V-2P@-SDI+`H@("`@)W1A;C(G(#T^
M(&%R<F%Y*#(S."P@,34T+"`W,RDL"B`@("`G=&%N,R<@/3X@87)R87DH,C`U
M+"`Q,S,L(#8S*2P*("`@("=T86XT)R`]/B!A<G)A>2@Q,SDL(#DP+"`T,RDL
M"B`@("`G8VAO8V]L871E,2<@/3X@87)R87DH,C4U+"`Q,C<L(#,V*2P*("`@
M("=C:&]C;VQA=&4R)R`]/B!A<G)A>2@R,S@L(#$Q."P@,S,I+`H@("`@)V-H
M;V-O;&%T93,G(#T^(&%R<F%Y*#(P-2P@,3`R+"`R.2DL"B`@("`G8VAO8V]L
M871E-"<@/3X@87)R87DH,3,Y+"`V.2P@,3DI+`H@("`@)V9I<F5B<FEC:S$G
M(#T^(&%R<F%Y*#(U-2P@-#@L(#0X*2P*("`@("=F:7)E8G)I8VLR)R`]/B!A
M<G)A>2@R,S@L(#0T+"`T-"DL"B`@("`G9FER96)R:6-K,R<@/3X@87)R87DH
M,C`U+"`S."P@,S@I+`H@("`@)V9I<F5B<FEC:S0G(#T^(&%R<F%Y*#$S.2P@
M,C8L(#(V*2P*("`@("=B<F]W;C$G(#T^(&%R<F%Y*#(U-2P@-C0L(#8T*2P*
M("`@("=B<F]W;C(G(#T^(&%R<F%Y*#(S."P@-3DL(#4Y*2P*("`@("=B<F]W
M;C,G(#T^(&%R<F%Y*#(P-2P@-3$L(#4Q*2P*("`@("=B<F]W;C0G(#T^(&%R
M<F%Y*#$S.2P@,S4L(#,U*2P*("`@("=S86QM;VXQ)R`]/B!A<G)A>2@R-34L
M(#$T,"P@,3`U*2P*("`@("=S86QM;VXR)R`]/B!A<G)A>2@R,S@L(#$S,"P@
M.3@I+`H@("`@)W-A;&UO;C,G(#T^(&%R<F%Y*#(P-2P@,3$R+"`X-"DL"B`@
M("`G<V%L;6]N-"<@/3X@87)R87DH,3,Y+"`W-BP@-3<I+`H@("`@)VQI9VAT
M<V%L;6]N,2<@/3X@87)R87DH,C4U+"`Q-C`L(#$R,BDL"B`@("`G;&EG:'1S
M86QM;VXR)R`]/B!A<G)A>2@R,S@L(#$T.2P@,3$T*2P*("`@("=L:6=H='-A
M;&UO;C,G(#T^(&%R<F%Y*#(P-2P@,3(Y+"`Y."DL"B`@("`G;&EG:'1S86QM
M;VXT)R`]/B!A<G)A>2@Q,SDL(#@W+"`V-BDL"B`@("`G;W)A;F=E,2<@/3X@
M87)R87DH,C4U+"`Q-C4L(#`I+`H@("`@)V]R86YG93(G(#T^(&%R<F%Y*#(S
M."P@,34T+"`P*2P*("`@("=O<F%N9V4S)R`]/B!A<G)A>2@R,#4L(#$S,RP@
M,"DL"B`@("`G;W)A;F=E-"<@/3X@87)R87DH,3,Y+"`Y,"P@,"DL"B`@("`G
M9&%R:V]R86YG93$G(#T^(&%R<F%Y*#(U-2P@,3(W+"`P*2P*("`@("=D87)K
M;W)A;F=E,B<@/3X@87)R87DH,C,X+"`Q,3@L(#`I+`H@("`@)V1A<FMO<F%N
M9V4S)R`]/B!A<G)A>2@R,#4L(#$P,BP@,"DL"B`@("`G9&%R:V]R86YG930G
M(#T^(&%R<F%Y*#$S.2P@-CDL(#`I+`H@("`@)V-O<F%L,2<@/3X@87)R87DH
M,C4U+"`Q,30L(#@V*2P*("`@("=C;W)A;#(G(#T^(&%R<F%Y*#(S."P@,3`V
M+"`X,"DL"B`@("`G8V]R86PS)R`]/B!A<G)A>2@R,#4L(#DQ+"`V.2DL"B`@
M("`G8V]R86PT)R`]/B!A<G)A>2@Q,SDL(#8R+"`T-RDL"B`@("`G=&]M871O
M,2<@/3X@87)R87DH,C4U+"`Y.2P@-S$I+`H@("`@)W1O;6%T;S(G(#T^(&%R
M<F%Y*#(S."P@.3(L(#8V*2P*("`@("=T;VUA=&\S)R`]/B!A<G)A>2@R,#4L
M(#<Y+"`U-RDL"B`@("`G=&]M871O-"<@/3X@87)R87DH,3,Y+"`U-"P@,S@I
M+`H@("`@)V]R86YG97)E9#$G(#T^(&%R<F%Y*#(U-2P@-CDL(#`I+`H@("`@
M)V]R86YG97)E9#(G(#T^(&%R<F%Y*#(S."P@-C0L(#`I+`H@("`@)V]R86YG
M97)E9#,G(#T^(&%R<F%Y*#(P-2P@-34L(#`I+`H@("`@)V]R86YG97)E9#0G
M(#T^(&%R<F%Y*#$S.2P@,S<L(#`I+`H@("`@)V1E97!P:6YK,2<@/3X@87)R
M87DH,C4U+"`R,"P@,30W*2P*("`@("=D965P<&EN:S(G(#T^(&%R<F%Y*#(S
M."P@,3@L(#$S-RDL"B`@("`G9&5E<'!I;FLS)R`]/B!A<G)A>2@R,#4L(#$V
M+"`Q,3@I+`H@("`@)V1E97!P:6YK-"<@/3X@87)R87DH,3,Y+"`Q,"P@.#`I
M+`H@("`@)VAO='!I;FLQ)R`]/B!A<G)A>2@R-34L(#$Q,"P@,3@P*2P*("`@
M("=H;W1P:6YK,B<@/3X@87)R87DH,C,X+"`Q,#8L(#$V-RDL"B`@("`G:&]T
M<&EN:S,G(#T^(&%R<F%Y*#(P-2P@.38L(#$T-"DL"B`@("`G:&]T<&EN:S0G
M(#T^(&%R<F%Y*#$S.2P@-3@L(#DX*2P*("`@("=P:6YK,2<@/3X@87)R87DH
M,C4U+"`Q.#$L(#$Y-RDL"B`@("`G<&EN:S(G(#T^(&%R<F%Y*#(S."P@,38Y
M+"`Q.#0I+`H@("`@)W!I;FLS)R`]/B!A<G)A>2@R,#4L(#$T-2P@,34X*2P*
M("`@("=P:6YK-"<@/3X@87)R87DH,3,Y+"`Y.2P@,3`X*2P*("`@("=L:6=H
M='!I;FLQ)R`]/B!A<G)A>2@R-34L(#$W-"P@,3@U*2P*("`@("=L:6=H='!I
M;FLR)R`]/B!A<G)A>2@R,S@L(#$V,BP@,3<S*2P*("`@("=L:6=H='!I;FLS
M)R`]/B!A<G)A>2@R,#4L(#$T,"P@,30Y*2P*("`@("=L:6=H='!I;FLT)R`]
M/B!A<G)A>2@Q,SDL(#DU+"`Q,#$I+`H@("`@)W!A;&5V:6]L971R960Q)R`]
M/B!A<G)A>2@R-34L(#$S,"P@,3<Q*2P*("`@("=P86QE=FEO;&5T<F5D,B<@
M/3X@87)R87DH,C,X+"`Q,C$L(#$U.2DL"B`@("`G<&%L979I;VQE=')E9#,G
M(#T^(&%R<F%Y*#(P-2P@,3`T+"`Q,S<I+`H@("`@)W!A;&5V:6]L971R960T
M)R`]/B!A<G)A>2@Q,SDL(#<Q+"`Y,RDL"B`@("`G;6%R;V]N,2<@/3X@87)R
M87DH,C4U+"`U,BP@,3<Y*2P*("`@("=M87)O;VXR)R`]/B!A<G)A>2@R,S@L
M(#0X+"`Q-C<I+`H@("`@)VUA<F]O;C,G(#T^(&%R<F%Y*#(P-2P@-#$L(#$T
M-"DL"B`@("`G;6%R;V]N-"<@/3X@87)R87DH,3,Y+"`R."P@.3@I+`H@("`@
M)W9I;VQE=')E9#$G(#T^(&%R<F%Y*#(U-2P@-C(L(#$U,"DL"B`@("`G=FEO
M;&5T<F5D,B<@/3X@87)R87DH,C,X+"`U."P@,30P*2P*("`@("=V:6]L971R
M960S)R`]/B!A<G)A>2@R,#4L(#4P+"`Q,C`I+`H@("`@)W9I;VQE=')E9#0G
M(#T^(&%R<F%Y*#$S.2P@,S0L(#@R*2P*("`@("=M86=E;G1A,2<@/3X@87)R
M87DH,C4U+"`P+"`R-34I+`H@("`@)VUA9V5N=&$R)R`]/B!A<G)A>2@R,S@L
M(#`L(#(S."DL"B`@("`G;6%G96YT83,G(#T^(&%R<F%Y*#(P-2P@,"P@,C`U
M*2P*("`@("=M86=E;G1A-"<@/3X@87)R87DH,3,Y+"`P+"`Q,SDI+`H@("`@
M)VUE9&EU;7)E9"<@/3X@87)R87DH,30P+"`S-"P@,S0I+`H@("`@)V]R8VAI
M9#$G(#T^(&%R<F%Y*#(U-2P@,3,Q+"`R-3`I+`H@("`@)V]R8VAI9#(G(#T^
M(&%R<F%Y*#(S."P@,3(R+"`R,S,I+`H@("`@)V]R8VAI9#,G(#T^(&%R<F%Y
M*#(P-2P@,3`U+"`R,#$I+`H@("`@)V]R8VAI9#0G(#T^(&%R<F%Y*#$S.2P@
M-S$L(#$S-RDL"B`@("`G<&QU;3$G(#T^(&%R<F%Y*#(U-2P@,3@W+"`R-34I
M+`H@("`@)W!L=6TR)R`]/B!A<G)A>2@R,S@L(#$W-"P@,C,X*2P*("`@("=P
M;'5M,R<@/3X@87)R87DH,C`U+"`Q-3`L(#(P-2DL"B`@("`G<&QU;30G(#T^
M(&%R<F%Y*#$S.2P@,3`R+"`Q,SDI+`H@("`@)VUE9&EU;6]R8VAI9#$G(#T^
M(&%R<F%Y*#(R-"P@,3`R+"`R-34I+`H@("`@)VUE9&EU;6]R8VAI9#(G(#T^
M(&%R<F%Y*#(P.2P@.34L(#(S."DL"B`@("`G;65D:75M;W)C:&ED,R<@/3X@
M87)R87DH,3@P+"`X,BP@,C`U*2P*("`@("=M961I=6UO<F-H:60T)R`]/B!A
M<G)A>2@Q,C(L(#4U+"`Q,SDI+`H@("`@)V1A<FMO<F-H:60Q)R`]/B!A<G)A
M>2@Q.3$L(#8R+"`R-34I+`H@("`@)V1A<FMO<F-H:60R)R`]/B!A<G)A>2@Q
M-S@L(#4X+"`R,S@I+`H@("`@)V1A<FMO<F-H:60S)R`]/B!A<G)A>2@Q-30L
M(#4P+"`R,#4I+`H@("`@)V1A<FMO<F-H:60T)R`]/B!A<G)A>2@Q,#0L(#,T
M+"`Q,SDI+`H@("`@)W!U<G!L93$G(#T^(&%R<F%Y*#$U-2P@-#@L(#(U-2DL
M"B`@("`G<'5R<&QE,B<@/3X@87)R87DH,30U+"`T-"P@,C,X*2P*("`@("=P
M=7)P;&4S)R`]/B!A<G)A>2@Q,C4L(#,X+"`R,#4I+`H@("`@)W!U<G!L930G
M(#T^(&%R<F%Y*#@U+"`R-BP@,3,Y*2P*("`@("=M961I=6UP=7)P;&4Q)R`]
M/B!A<G)A>2@Q-S$L(#$S,"P@,C4U*2P*("`@("=M961I=6UP=7)P;&4R)R`]
M/B!A<G)A>2@Q-3DL(#$R,2P@,C,X*2P*("`@("=M961I=6UP=7)P;&4S)R`]
M/B!A<G)A>2@Q,S<L(#$P-"P@,C`U*2P*("`@("=M961I=6UP=7)P;&4T)R`]
M/B!A<G)A>2@Y,RP@-S$L(#$S.2DL"B`@("`G=&AI<W1L93$G(#T^(&%R<F%Y
M*#(U-2P@,C(U+"`R-34I+`H@("`@)W1H:7-T;&4R)R`]/B!A<G)A>2@R,S@L
M(#(Q,"P@,C,X*2P*("`@("=T:&ES=&QE,R<@/3X@87)R87DH,C`U+"`Q.#$L
M(#(P-2DL"B`@("`G=&AI<W1L930G(#T^(&%R<F%Y*#$S.2P@,3(S+"`Q,SDI
M+`H@("`@)V=R87DQ)R`]/B!A<G)A>2@Q,"P@,3`L(#$P*2P*("`@("=G<F%Y
M,B<@/3X@87)R87DH-#`L(#0P+"`S,"DL"B`@("`G9W)A>3,G(#T^(&%R<F%Y
M*#<P+"`W,"P@-S`I+`H@("`@)V=R87DT)R`]/B!A<G)A>2@Q,#`L(#$P,"P@
M,3`P*2P*("`@("=G<F%Y-2<@/3X@87)R87DH,3,P+"`Q,S`L(#$S,"DL"B`@
M("`G9W)A>38G(#T^(&%R<F%Y*#$V,"P@,38P+"`Q-C`I+`H@("`@)V=R87DW
M)R`]/B!A<G)A>2@Q.3`L(#$Y,"P@,3DP*2P*("`@("=G<F%Y."<@/3X@87)R
M87DH,C$P+"`R,3`L(#(Q,"DL"B`@("`G9W)A>3DG(#T^(&%R<F%Y*#(T,"P@
M,C0P+"`R-#`I+`H@("`@)V1A<FMG<F%Y)R`]/B!A<G)A>2@Q,#`L(#$P,"P@
M,3`P*2P*("`@("=D87)K8FQU92<@/3X@87)R87DH,"P@,"P@,3,Y*2P*("`@
M("=D87)K8WEA;B<@/3X@87)R87DH,"P@,3,Y+"`Q,SDI+`H@("`@)V1A<FMM
M86=E;G1A)R`]/B!A<G)A>2@Q,SDL(#`L(#$S.2DL"B`@("`G9&%R:W)E9"<@
M/3X@87)R87DH,3,Y+"`P+"`P*2P*("`@("=S:6QV97(G(#T^(&%R<F%Y*#$Y
M,BP@(#$Y,BP@(#$Y,BDL"B`@("`G96=G<&QA;G0G(#T^(&%R<F%Y*#$T-"P@
M,3<V+"`Q-C@I+`H@("`@)VQI9VAT9W)E96XG(#T^(&%R<F%Y*#$T-"P@,C,X
M+"`Q-#0I"BD["@``````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O<W9G+G!H<```````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,Q-C`Q`#$P-3$U-#,Q
M,#8P`#`R,#4T-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B]);6%G92YP:'`G.PIR97%U:7)E7V]N8V4@)UA-3"]35D<N<&AP
M)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E7TEM
M86=E.CH@05!)(&9O<B!35D<N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TEM
M86=E+TEM86=E+W-V9RYP:'`L=B`Q+C,Q+C$P+C8@,C`P-B\P,2\P,2`R,3HR
M.#HR,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?26UA
M9V4*("HO"F-L87-S($AO<F1E7TEM86=E7W-V9R!E>'1E;F1S($AO<F1E7TEM
M86=E('L*"B`@("!V87(@)%]S=F<["@H@("`@+RHJ"B`@("`@*B!#87!A8FEL
M:71E<R!O9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V-A<&%B:6QI=&EE<R`](&%R<F%Y*"=C86YV
M87,G*3L*"B`@("!F=6YC=&EO;B!(;W)D95]);6%G95]S=F<H)'!A<F%M<RD*
M("`@('L*("`@("`@("!P87)E;G0Z.DAO<F1E7TEM86=E*"1P87)A;7,I.PH@
M("`@("`@("1T:&ES+3Y?<W9G(#T@)FYE=R!834Q?4U9'7T1O8W5M96YT*&%R
M<F%Y*"=W:61T:"<@/3X@)'1H:7,M/E]W:61T:"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&5I9VAT)R`]
M/B`D=&AI<RT^7VAE:6=H="DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O
M;G1E;G14>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)VEM86=E+W-V9RMX
M;6PG.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$QI;FLH)'5R;"P@)'1I=&QE
M(#T@)R<I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@9&ES<&QA>2@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S=F<M/G!R:6YT16QE;65N="@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!R87<@9&%T82!F;W(@=&AI
M<R!I;6%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')A
M=R!I;6%G92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R87<H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-V9RT^8G5F9F5R3V)J96-T*"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1F]N="@D9F]N="D*("`@('L*("`@
M("`@("!R971U<FX@)&9O;G0["B`@("!]"@H@("`@9G5N8W1I;VX@7V-R96%T
M95-Y;6)O;"@D<RP@)&ED*0H@("`@>PH@("`@("`@("1S+3YS971087)A;2@G
M:60G+"`D:60I.PH@("`@("`@("1D969S(#T@)FYE=R!834Q?4U9'7T1E9G,H
M*3L*("`@("`@("`D9&5F<RT^861D0VAI;&0H)',I.PH@("`@("`@("1T:&ES
M+3Y?<W9G+3YA9&1#:&EL9"@D9&5F<RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V-R96%T941R;W!3:&%D;W<H)&ED(#T@)V1R;W!3:&%D;W<G*0H@("`@>PH@
M("`@("`@("1D969S(#T@)FYE=R!834Q?4U9'7T1E9G,H*3L*("`@("`@("`D
M9FEL=&5R(#T@)FYE=R!834Q?4U9'7T9I;'1E<BAA<G)A>2@G:60G(#T^("1I
M9"DI.PH@("`@("`@("1F:6QT97(M/F%D9%!R:6UI=&EV92@G1V%U<W-I86Y"
M;'5R)RP@87)R87DH)VEN)R`]/B`G4V]U<F-E06QP:&$G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T
M9$1E=FEA=&EO;B<@/3X@,BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R97-U;'0G(#T^("=B;'5R)RDI
M.PH@("`@("`@("1F:6QT97(M/F%D9%!R:6UI=&EV92@G3V9F<V5T)RP@87)R
M87DH)VEN)R`]/B`G8FQU<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9'@G(#T^(#0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9'DG(#T^(#0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5S=6QT)R`]/B`G;V9F<V5T0FQU<B<I*3L*("`@("`@("`D;65R9V4@/2`F
M;F5W(%A-3%]35D=?1FEL=&5R4')I;6ET:79E*"=-97)G92<I.PH@("`@("`@
M("1M97)G92T^861D365R9V5.;V1E*"=O9F9S971";'5R)RD["B`@("`@("`@
M)&UE<F=E+3YA9&1-97)G94YO9&4H)U-O=7)C94=R87!H:6,G*3L*"B`@("`@
M("`@)&9I;'1E<BT^861D0VAI;&0H)&UE<F=E*3L*("`@("`@("`D9&5F<RT^
M861D0VAI;&0H)&9I;'1E<BD["B`@("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H
M:6QD*"1D969S*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87=S(&$@=&5X
M="!S=')I;F<@;VX@=&AE(&EM86=E(&EN(&$@<W!E8VEF:65D(&QO8V%T:6]N
M+"!W:71H"B`@("`@*B!T:&4@<W!E8VEF:65D('-T>6QE(&EN9F]R;6%T:6]N
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1T97AT("`@("`@(%1H
M92!T97AT('1O(&1R87<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@
M("`@("!4:&4@;&5F="!X(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T(&]F('1H
M92!T97AT('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@
M("`@(%1H92!T;W`@>2!C;V]R9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4@
M=&5X="!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9F]N="`@("`@
M("!4:&4@9F]N="!I9&5N=&EF:65R('EO=2!W86YT('1O('5S92!F;W(@=&AE
M('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("`@("!4:&4@
M8V]L;W(@=&AA="!Y;W4@=V%N="!T:&4@=&5X="!D:7-P;&%Y960@:6XN"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("!!;B!I;G1E9V5R('1H
M870@<W!E8VEF:65S('1H92!O<FEE;G1A=&EO;B!O9B!T:&4@=&5X="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&5X="@D<W1R:6YG+"`D>"P@)'DL("1F;VYT
M(#T@)VUO;F]S<&%C92<L("1C;VQO<B`]("=B;&%C:R<L("1D:7)E8W1I;VX@
M/2`P*0H@("`@>PH@("`@("`@("1H96EG:'0@/2`Q,CL*("`@("`@("`D<W1Y
M;&4@/2`G9F]N="UF86UI;'DZ)R`N("1F;VYT("X@)SMF;VYT+6AE:6=H=#HG
M("X@)&AE:6=H="`N("=P>#MF:6QL.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H
M)&-O;&]R*2`N("<[=&5X="UA;F-H;W(Z<W1A<G0[)SL*("`@("`@("`D=')A
M;G-F;W)M(#T@)W)O=&%T92@G("X@)&1I<F5C=&EO;B`N("<L)R`N("1X("X@
M)RPG("X@)'D@+B`G*2<["B`@("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H:6QD
M*&YE=R!834Q?4U9'7U1E>'0H87)R87DH)W1E>'0G(#T^("1S=')I;F<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W@G(#T^("AI;G0I)'@L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WDG(#T^("AI;G0I)'D@
M*R`D:&5I9VAT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T<F%N<V9O<FTG(#T^("1T<F%N<V9O<FTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W-T>6QE)R`]/B`D<W1Y;&4I*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$<F%W(&$@8VER8VQE+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1X("`@("`@5&AE('@@8V]O<F1I;F%T92!O9B!T:&4@8V5N=')E
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("!4:&4@>2!C;V]R9&EN
M871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<B`@
M("`@(%1H92!R861I=7,@;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A;2!S
M=')I;F<@("1C;VQO<B`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&-I<F-L92X*
M("`@("`J($!P87)A;2!S=')I;F<@("1F:6QL("`@5&AE(&-O;&]R('1O(&9I
M;&P@=&AE(&-I<F-L92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VER8VQE*"1X
M+"`D>2P@)'(L("1C;VQO<BP@)&9I;&P@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A96UP='DH)&9I;&PI*2!["B`@("`@("`@("`@("1S='EL92`]("=F
M:6QL.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&9I;&PI("X@)SL@)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#IN;VYE
M.R<["B`@("`@("`@?0H@("`@("`@("1S='EL92`N/2`G<W1R;VME.B<@+B`D
M=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R*2`N("<[('-T<F]K92UW:61T:#HQ
M)SL*"B`@("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'
M7T-I<F-L92AA<G)A>2@G8W@G(#T^("1X+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-Y)R`]/B`D
M>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R)R`]/B`D<BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@
M)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A('!O;'EG
M;VX@8F%S960@;VX@82!S970@;V8@=F5R=&EC97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@>"!A;F0@>2!L
M86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL("XN
M+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@8V]L;W(@
M>6]U('=A;G0@=&\@9')A=R!T:&4@<&]L>6=O;B!W:71H+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE('!O
M;'EG;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EG;VXH)'9E<G1S+"`D
M8V]L;W(L("1F:6QL(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1F:6QL*2D@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#HG("X@)'1H
M:7,M/F=E=$AE>$-O;&]R*"1F:6QL*2`N("<[("<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ;F]N93LG.PH@("`@("`@
M('T*("`@("`@("`D<W1Y;&4@+CT@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE
M>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z,2<["@H@("`@("`@
M("1P;VEN=',@/2`G)SL*("`@("`@("!F;W)E86-H("@D=F5R=',@87,@)'8I
M('L*("`@("`@("`@("`@)'!O:6YT<R`N/2`D=ELG>"==("X@)RPG("X@)'9;
M)WDG72`N("<@)SL*("`@("`@("!]"B`@("`@("`@)'!O:6YT<R`]('1R:6TH
M)'!O:6YT<RD["@H@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@
M6$U,7U-61U]0;VQY9V]N*&%R<F%Y*"=P;VEN=',G(#T^("1P;VEN=',L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W-T>6QE)R`]/B`D<W1Y;&4I*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$<F%W(&$@<F5C=&%N9VQE+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1X("`@("`@(%1H92!L969T('@M8V]O<F1I;F%T92!O9B!T
M:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("`@
M5&AE('1O<"!Y+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C
M=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE(&AE
M:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]L;W(@("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL
M('1H92!R96-T86YG;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8W1A;F=L
M92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R+"`D9FEL;"`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@("`@
M("`@("`@)'-T>6QE(#T@)V9I;&PZ)R`N("1T:&ES+3YG971(97A#;VQO<B@D
M9FEL;"D@+B`G.R`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S
M='EL92`]("=F:6QL.FYO;F4[)SL*("`@("`@("!]"B`@("`@("`@)'-T>6QE
M("X]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D8V]L;W(I("X@
M)SL@<W1R;VME+7=I9'1H.C$G.PH*("`@("`@("`D=&AI<RT^7W-V9RT^861D
M0VAI;&0H;F5W(%A-3%]35D=?4F5C="AA<G)A>2@G>"<@/3X@)'@L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)WDG(#T^("1Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=W:61T:"<@/3X@)'=I9'1H+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H96EG:'0G(#T^("1H96EG:'0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`D
M<W1Y;&4I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<F5C=&%N
M9VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@(%1H
M92!L969T('@M8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'D@("`@("`@5&AE('1O<"!Y+6-O;W)D:6YA=&4@
M;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1W:61T
M:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&AE:6=H="`@5&AE(&AE:6=H="!O9B!T:&4@<F5C=&%N9VQE
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=6YD("`@5&AE('=I9'1H(&]F
M('1H92!C;W)N97(@<F]U;F1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M8V]L;W(@("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("`@5&AE(&-O;&]R('1O(&9I;&P@
M=&AE(')E8W1A;F=L92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]U;F1E9%)E
M8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)')O=6YD+"`D8V]L
M;W(L("1F:6QL*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)&9I;&PI*2![
M"B`@("`@("`@("`@("1S='EL92`]("=F:6QL.B<@+B`D=&AI<RT^9V5T2&5X
M0V]L;W(H)&9I;&PI("X@)SL@)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<W1Y;&4@/2`G9FEL;#IN;VYE.R<["B`@("`@("`@?0H@("`@("`@
M("1S='EL92`N/2`G<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&-O
M;&]R*2`N("<[('-T<F]K92UW:61T:#HQ)SL*"B`@("`@("`@)'1H:7,M/E]S
M=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'7U)E8W0H87)R87DH)W@G(#T^("1X
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=Y)R`]/B`D>2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<G@G(#T^("1R;W5N9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<GDG(#T^("1R;W5N9"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@G(#T^("1W
M:61T:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G:&5I9VAT)R`]/B`D:&5I9VAT+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S
M='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A
M=R!A(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@P("`@
M("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1Y,"`@("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@<W1A
M<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#$@("`@(%1H92!X(&-O;W)D
M:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@
M("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A
M;2!S=')I;F<@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@)'DQ+"`D>#(L("1Y,BP@)&-O
M;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@("`D<W1Y
M;&4@/2`G<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R*2`N
M("<[('-T<F]K92UW:61T:#HG("X@*&EN="DD=VED=&@["B`@("`@("`@)'1H
M:7,M/E]S=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'7TQI;F4H87)R87DH)W@Q
M)R`]/B`D>#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)WDQ)R`]/B`D>3$L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W@R)R`]
M/B`D>#(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)WDR)R`]/B`D>3(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]
M/B`D<W1Y;&4I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@9&%S
M:&5D(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@P("`@
M("`@("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1Y,"`@("`@("`@("`@5&AE('D@8V]O<F1I;F%T
M92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#$@("`@
M("`@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1Y,2`@("`@("`@("`@5&AE('D@8V]O<F1I;F%T92!O
M9B!T:&4@96YD+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("`@("`@
M("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A;2!S=')I;F<@("1W:61T
M:"`@("`@("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&1A<VA?;&5N9W1H("!4:&4@;&5N9W1H(&]F(&$@9&%S:"!O
M;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J($!P87)A;2!I;G1E9V5R("1D87-H
M7W-P86-E("`@5&AE(&QE;F=T:"!O9B!A('-P86-E(&EN('1H92!D87-H960@
M;&EN90H@("`@("HO"B`@("!F=6YC=&EO;B!D87-H961,:6YE*"1X,2P@)'DQ
M+"`D>#(L("1Y,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2P@)&1A
M<VA?;&5N9W1H(#T@,BP@)&1A<VA?<W!A8V4@/2`R*0H@("`@>PH@("`@("`@
M("1S='EL92`]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D8V]L
M;W(I("X@)SL@<W1R;VME+7=I9'1H.B<@+B`H:6YT*21W:61T:"`N("<[('-T
M<F]K92UD87-H87)R87DZ)R`N("1D87-H7VQE;F=T:"`N("<L)R`N("1D87-H
M7W-P86-E("X@)SLG.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN
M97<@6$U,7U-61U],:6YE*&%R<F%Y*"=X,2<@/3X@)'@Q+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y
M,2<@/3X@)'DQ+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=X,B<@/3X@)'@R+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y,B<@
M/3X@)'DR+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1')A=R!A('!O;'EL:6YE("AA(&YO;BUC;&]S960L
M(&YO;BUF:6QL960@<&]L>6=O;BD@8F%S960@;VX@80H@("`@("H@<V5T(&]F
M('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=F5R=&EC
M97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E<G1I8V5S6S!=6R=X
M)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@=&AE
M(&QI;F4@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)'=I9'1H("`@(%1H
M92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]L
M>6QI;F4H)'9E<G1S+"`D8V]L;W(L("1W:61T:"`](#$I"B`@("!["B`@("`@
M("`@)'-T>6QE(#T@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C
M;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z)R`N("1W:61T:"`N("<[9FEL;#IN
M;VYE.R<["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@<&%T:"!E;G1R>2X*
M("`@("`@("`D<&%T:"`]("<G.PH*("`@("`@("`D9FER<W0@/2!T<G5E.PH@
M("`@("`@(&9O<F5A8V@@*"1V97)T<R!A<R`D=F5R="D@>PH@("`@("`@("`@
M("!I9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@("`D9FER<W0@/2!F86QS
M93L*("`@("`@("`@("`@("`@("1P871H("X]("=-("<@+B`D=F5R=%LG>"==
M("X@)RPG("X@)'9E<G1;)WDG73L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1P871H("X]("<@3"`G("X@)'9E<G1;)W@G72`N("<L
M)R`N("1V97)T6R=Y)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U]0871H*&%R
M<F%Y*"=D)R`]/B`D<&%T:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL92DI
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@86X@87)C+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@5&AE('@@8V]O<F1I;F%T
M92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@
M("!4:&4@>2!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE(&%R8RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@5&AE('-T87)T(&%N9VQE(&]F
M('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96YD("`@(%1H92!E
M;F0@86YG;&4@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!S=')I;F<@("1C
M;VQO<B`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&%R8RX*("`@("`J($!P87)A
M;2!S=')I;F<@("1F:6QL("`@5&AE(&9I;&P@8V]L;W(@;V8@=&AE(&%R8R`H
M9&5F875L=',@=&\@;F]N92DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%R8R@D
M>"P@)'DL("1R+"`D<W1A<G0L("1E;F0L("1C;VQO<B`]("=B;&%C:R<L("1F
M:6QL(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1F:6QL*2D@
M>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#HG("X@)'1H:7,M/F=E=$AE
M>$-O;&]R*"1F:6QL*2`N("<[("<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'-T>6QE(#T@)V9I;&PZ;F]N93LG.PH@("`@("`@('T*("`@("`@
M("`D<W1Y;&4@+CT@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C
M;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z,2<["@H@("`@("`@("1M:60@/2!R
M;W5N9"@H)'-T87)T("L@)&5N9"D@+R`R*3L*"B`@("`@("`@+R\@0V%L8W5L
M871E('1H92!P871H(&5N=')Y+@H@("`@("`@("1P871H(#T@)R<["@H@("`@
M("`@("\O($EF(&9I;&QE9"P@9')A=R!T:&4@;W5T;&EN92X*("`@("`@("!I
M9B`H(65M<'1Y*"1F:6QL*2D@>PH@("`@("`@("`@("`O+R!3=&%R="!A="!T
M:&4@8V5N=&5R(&]F('1H92!E;&QI<'-E('1H92!A<F,@:7,@;VXN"B`@("`@
M("`@("`@("1P871H("X](")-("1X+"1Y("(["@H@("`@("`@("`@("`O+R!$
M<F%W(&]U="!T;R!E;&QI<'-E(&5D9V4N"B`@("`@("`@("`@(&QI<W0H)&%R
M8U@L("1A<F-9*2`]("1T:&ES+3Y?8VER8VQE4&]I;G0H)'-T87)T+"`D<B`J
M(#(I.PH@("`@("`@("`@("`D<&%T:"`N/2`G3"`G("X@<F]U;F0H)'@@*R`D
M87)C6"D@+B`G+"<@+@H@("`@("`@("`@("`@("`@<F]U;F0H)'D@*R`D87)C
M62D@+B`G("<["B`@("`@("`@?0H*("`@("`@("`O+R!$<F%W(&%R8W,N"B`@
M("`@("`@;&ES="@D87)C6"P@)&%R8UDI(#T@)'1H:7,M/E]C:7)C;&50;VEN
M="@D;6ED+"`D<B`J(#(I.PH@("`@("`@("1P871H("X](")!("1R+"1R(#`@
M,"`Q("(@+@H@("`@("`@("`@("!R;W5N9"@D>"`K("1A<F-8*2`N("<L)R`N
M"B`@("`@("`@("`@(')O=6YD*"1Y("L@)&%R8UDI("X@)R`G.PH*("`@("`@
M("!L:7-T*"1A<F-8+"`D87)C62D@/2`D=&AI<RT^7V-I<F-L95!O:6YT*"1E
M;F0L("1R("H@,BD["B`@("`@("`@)'!A=&@@+CT@(D$@)'(L)'(@,"`P(#$@
M(B`N"B`@("`@("`@("`@(')O=6YD*"1X("L@)&%R8U@I("X@)RPG("X*("`@
M("`@("`@("`@<F]U;F0H)'D@*R`D87)C62D@+B`G("<["@H@("`@("`@("\O
M($EF(&9I;&QE9"P@8VQO<V4@=&AE(&]U=&QI;F4N"B`@("`@("`@:68@*"%E
M;7!T>2@D9FEL;"DI('L*("`@("`@("`@("`@)'!A=&@@+CT@)UHG.PH@("`@
M("`@('T*"B`@("`@("`@)'!A=&@@/2!T<FEM*"1P871H*3L*"B`@("`@("`@
M)'1H:7,M/E]S=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'7U!A=&@H87)R87DH
M)V0G(#T^("1P871H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O<W=F
M+G!H<```````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0T-S`T
M`#$P-3$U-#,Q,#8P`#`R,#4U-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B]);6%G92YP:'`G.PH*+RHJ"B`J(%1H:7,@8VQA
M<W,@:6UP;&5M96YT<R!T:&4@2&]R9&5?26UA9V4Z.B!!4$D@9F]R(%-71BP@
M=7-I;F<@=&AE(%!(4`H@*B!-:6YG(&5X=&5N<VEO;BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO26UA9V4O26UA9V4O<W=F+G!H<"QV(#$N,C0N,3`N-B`R
M,#`V+S`Q+S`Q(#(Q.C(X.C(R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]);6%G90H@*B\*8VQA<W,@2&]R9&5?26UA9V5?<W=F(&5X
M=&5N9',@2&]R9&5?26UA9V4@>PH*("`@("\J*@H@("`@("H@0V%P86)I;&ET
M97,@;V8@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]C87!A8FEL:71I97,@/2!A<G)A>2@G8V%N=F%S
M)RD["@H@("`@+RHJ"B`@("`@*B!35T8@<F]O="!M;W9I92X*("`@("`J"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7VUO=FEE.PH*
M("`@(&9U;F-T:6]N($AO<F1E7TEM86=E7W-W9B@D<&%R86US*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ2&]R9&5?26UA9V4H)'!A<F%M<RD["@H@("`@("`@
M("1T:&ES+3Y?;6]V:64@/2`F;F5W(%-71DUO=FEE*"D["B`@("`@("`@)'1H
M:7,M/E]M;W9I92T^<V5T1&EM96YS:6]N*"1T:&ES+3Y?=VED=&@L("1T:&ES
M+3Y?:&5I9VAT*3L*"B`@("`@("`@+R\@1DE8344Z(&AO;F]R('1H92`G8F%C
M:V=R;W5N9"<@<&%R86UE=&5R(&AE<F4N"B`@("`@("`@)'1H:7,M/E]M;W9I
M92T^<V5T0F%C:V=R;W5N9"@P>&9F+"`P>&9F+"`P>&9F*3L*("`@("`@("`D
M=&AI<RT^7VUO=FEE+3YS9712871E*#,P*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=A<'!L
M:6-A=&EO;B]X+7-H;V-K=V%V92UF;&%S:"<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$:7-P;&%Y('1H92!M;W9I92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&ES<&QA>2@I"B`@("!["B`@("`@("`@)'1H:7,M/FAE861E<G,H*3L*("`@
M("`@("`D=&AI<RT^7VUO=FEE+3YO=71P=70H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@<F%W(&1A=&$@9F]R('1H:7,@:6UA9V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R87<@:6UA9V4@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F%W*"D*("`@('L*("`@("`@("!O
M8E]S=&%R="@I.PH@("`@("`@("1T:&ES+3Y?;6]V:64M/F]U='!U="@I.PH@
M("`@("`@("1D871A(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@;V)?
M96YD7V-L96%N*"D["@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!C;VQO<B!T:&%T(&-A;B!B92!A8V-E
M<W-E9"!I;B!T:&ES(&]B:F5C="X@5VAE;B!A"B`@("`@*B!C;VQO<B!I<R!S
M970L('1H92!R9V)A('9A;'5E<R!A<F4@<F5T=7)N960@:6X@86X@87)R87DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@
M;V8@=&AE(&-O;&]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H
M92!R960L(&=R965N+"!B;'5E+"!A;'!H82!V86QU97,@;V8@=&AE(&-O;&]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A;&QO8V%T94-O;&]R*"1N86UE*0H@
M("`@>PH@("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D=&AI<RT^9V5T4D="
M*"1N86UE*3L*("`@("`@("!R971U<FX@87)R87DH)W)E9"<@/3X@)'(L"B`@
M("`@("`@("`@("`@("`@("`@("=G<F5E;B<@/3X@)&<L"B`@("`@("`@("`@
M("`@("`@("`@("=B;'5E)R`]/B`D8BP*("`@("`@("`@("`@("`@("`@("`@
M)V%L<&AA)R`]/B`R-34I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$9O;G0H
M)&9O;G0I"B`@("!["B`@("`@("`@<W=I=&-H("@D9F]N="D@>PH@("`@("`@
M(&-A<V4@)W-A;G,M<V5R:68G.@H@("`@("`@("`@("!R971U<FX@)U]S86YS
M)SL*"B`@("`@("`@8V%S92`G<V5R:68G.@H@("`@("`@("`@("!R971U<FX@
M)U]S97)I9B<["@H@("`@("`@(&-A<V4@)VUO;F]S<&%C92<Z"B`@("`@("`@
M("`@(')E='5R;B`G7W1Y<&5W<FET97(G.PH*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("!R971U<FX@)&9O;G0["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1')A=W,@82!T97AT('-T<FEN9R!O;B!T:&4@:6UA9V4@
M:6X@82!S<&5C:69I960@;&]C871I;VXL('=I=&@*("`@("`J('1H92!S<&5C
M:69I960@<W1Y;&4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'1E>'0@("`@("`@5&AE('1E>'0@=&\@9')A=RX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1X("`@("`@("`@(%1H92!L969T('@@8V]O<F1I
M;F%T92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E>'0@<W1R:6YG+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'D@("`@("`@("`@5&AE('1O<"!Y(&-O;W)D:6YA
M=&4@;V8@=&AE('-T87)T(&]F('1H92!T97AT('-T<FEN9RX*("`@("`J($!P
M87)A;2!S=')I;F<@("1F;VYT("`@("`@(%1H92!F;VYT(&ED96YT:69I97(@
M>6]U('=A;G0@=&\@=7-E(&9O<B!T:&4@=&5X="X*("`@("`J($!P87)A;2!S
M=')I;F<@("1C;VQO<B`@("`@(%1H92!C;VQO<B!T:&%T('EO=2!W86YT('1H
M92!T97AT(&1I<W!L87EE9"!I;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1D
M:7)E8W1I;VX@($%N(&EN=&5G97(@=&AA="!S<&5C:69I97,@=&AE(&]R:65N
M=&%T:6]N(&]F('1H92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!T97AT
M*"1S=')I;F<L("1X+"`D>2P@)&9O;G0@/2`G;6]N;W-P86-E)RP@)&-O;&]R
M(#T@)V)L86-K)RP@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@)&-O
M;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*"B`@("`@("`@
M:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2!["B`@("`@("`@
M("`@("1T97AT(#T@)FYE=R!35T9497AT1FEE;&0H4U=&5$585$9)14Q$7TY/
M141)5"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1E>'0@/2`F
M;F5W(%-71E1E>'0H*3L*("`@("`@("!]"B`@("`@("`@)'1E>'0M/G-E=$-O
M;&]R*"1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B
M;'5E)UTL("1C;VQO<ELG86QP:&$G72D["B`@("`@("`@)'1E>'0M/F%D9%-T
M<FEN9R@D<W1R:6YG*3L*("`@("`@("`D=&5X="T^<V5T1F]N="AN97<@4U=&
M1F]N="@D=&AI<RT^9V5T1F]N="@D9F]N="DI*3L*"B`@("`@("`@)'0@/2`D
M=&AI<RT^7VUO=FEE+3YA9&0H)'1E>'0I.PH@("`@("`@("1T+3YM;W9E5&\H
M)'@L("1Y*3L*("`@("`@("`D="T^<F]T871E*"1D:7)E8W1I;VXI.PH*("`@
M("`@("!R971U<FX@)'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@
M8VER8VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@
M5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1Y("`@("`@5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE(&-E
M;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1R("`@("`@5&AE(')A9&EU
M<R!O9B!T:&4@8VER8VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R
M("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@8VER8VQE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&9I;&P@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@8VER8VQE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:7)C;&4H)'@L("1Y+"`D<BP@)&-O
M;&]R+"`D9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("`D<R`]("9N97<@
M4U=&4VAA<&4H*3L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#
M;VQO<B@D8V]L;W(I.PH@("`@("`@("1S+3YS971,:6YE*#$L("1C;VQO<ELG
M<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO
M<ELG86QP:&$G72D["@H@("`@("`@(&EF("@D9FEL;"`A/2`G;F]N92<I('L*
M("`@("`@("`@("`@)&9I;&Q#;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R
M*"1F:6QL*3L*("`@("`@("`@("`@)&8@/2`D<RT^861D1FEL;"@D9FEL;$-O
M;&]R6R=R960G72P@)&9I;&Q#;VQO<ELG9W)E96XG72P@)&9I;&Q#;VQO<ELG
M8FQU92==+"`D9FEL;$-O;&]R6R=A;'!H82==*3L*("`@("`@("`@("`@)',M
M/G-E=%)I9VAT1FEL;"@D9BD["B`@("`@("`@?0H*("`@("`@("`D82`]("1R
M("H@,"XT,30R,3,U-C([("\O(#T@=&%N*#(R+C4@9&5G*0H@("`@("`@("1B
M(#T@)'(@*B`P+C<P-S$P-C<X,3L@+R\@/2!S<7)T*#(I+S(@/2!S:6XH-#4@
M9&5G*0H*("`@("`@("`D<RT^;6]V95!E;E1O*"1X("L@)'(L("1Y*3L*"B`@
M("`@("`@)',M/F1R87=#=7)V951O*"1X("L@)'(L("1Y("T@)&$L("1X("L@
M)&(L("1Y("T@)&(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`K("1A
M+"`D>2`M("1R+"`D>"P@)'D@+2`D<BD["B`@("`@("`@)',M/F1R87=#=7)V
M951O*"1X("T@)&$L("1Y("T@)'(L("1X("T@)&(L("1Y("T@)&(I.PH@("`@
M("`@("1S+3YD<F%W0W5R=F54;R@D>"`M("1R+"`D>2`M("1A+"`D>"`M("1R
M+"`D>2D["B`@("`@("`@)',M/F1R87=#=7)V951O*"1X("T@)'(L("1Y("L@
M)&$L("1X("T@)&(L("1Y("L@)&(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54
M;R@D>"`M("1A+"`D>2`K("1R+"`D>"P@)'D@*R`D<BD["B`@("`@("`@)',M
M/F1R87=#=7)V951O*"1X("L@)&$L("1Y("L@)'(L("1X("L@)&(L("1Y("L@
M)&(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`K("1R+"`D>2`K("1A
M+"`D>"`K("1R+"`D>2D["@H@("`@("`@(')E='5R;B`D=&AI<RT^7VUO=FEE
M+3YA9&0H)',I.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A('!O;'EG
M;VX@8F%S960@;VX@82!S970@;V8@=F5R=&EC97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@>"!A;F0@>2!L
M86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL("XN
M+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@8V]L;W(@
M>6]U('=A;G0@=&\@9')A=R!T:&4@<&]L>6=O;B!W:71H+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE('!O
M;'EG;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EG;VXH)'9E<G1S+"`D
M8V]L;W(L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@("1C;VQO<B`]
M("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["@H@("`@("`@(&EF("AI
M<U]A<G)A>2@D8V]L;W(I("8F(&ES7V%R<F%Y*"1V97)T<RD@)B8@*'-I>F5O
M9B@D=F5R=',I(#X@,BDI('L*("`@("`@("`@("`@)'-H87!E(#T@)FYE=R!3
M5T93:&%P92@I.PH@("`@("`@("`@("`D<VAA<&4M/G-E=$QI;F4H,2P@)&-O
M;&]R6R=R960G72P@)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);)V)L=64G72P@
M)&-O;&]R6R=A;'!H82==*3L*"B`@("`@("`@("`@(&EF("@D9FEL;"`A/2`G
M;F]N92<I('L*("`@("`@("`@("`@("`@("1F:6QL0V]L;W(@/2`D=&AI<RT^
M86QL;V-A=&5#;VQO<B@D9FEL;"D["B`@("`@("`@("`@("`@("`D9B`]("1S
M:&%P92T^861D1FEL;"@D9FEL;$-O;&]R6R=R960G72P@)&9I;&Q#;VQO<ELG
M9W)E96XG72P@)&9I;&Q#;VQO<ELG8FQU92==+"`D9FEL;$-O;&]R6R=A;'!H
M82==*3L*("`@("`@("`@("`@("`@("1S:&%P92T^<V5T4FEG:'1&:6QL*"1F
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I<G-T7V1O;F4@/2!F
M86QS93L*("`@("`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@:68@*"$D9FER<W1?9&]N92D@>PH@("`@("`@
M("`@("`@("`@("`@("1S:&%P92T^;6]V95!E;E1O*"1V86QU95LG>"==+"`D
M=F%L=65;)WDG72D["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T7V1O;F4@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("1F:7)S=%]X(#T@)'9A;'5E
M6R=X)UT["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T7WD@/2`D=F%L=65;
M)WDG73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S:&%P
M92T^9')A=TQI;F54;R@D=F%L=65;)W@G72P@)'9A;'5E6R=Y)UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1S:&%P92T^9')A=TQI;F54;R@D9FER
M<W1?>"P@)&9I<G-T7WDI.PH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;6]V:64M/F%D9"@D<VAA<&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O($EF('1H92!C;VQO<B!I<R!A;B!A<G)A>2!A;F0@=&AE('9E<G1I
M8V5S(&ES(&$@86X@87)R87D*("`@("`@("`@("`@+R\@;V8@;6]R92!T:&%N
M(#(@<&]I;G1S+@H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X
M+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R
M96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@
M=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J
M($!P87)A;2!S=')I;F<@("1C;VQO<B`@(%1H92!L:6YE(&-O;&]R(&]F('1H
M92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL;"`@("!4
M:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1C
M;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@)'9E<G1S6S!=
M(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@)'DI.PH@("`@("`@("1V97)T
M<ULQ72`](&%R<F%Y*"=X)R`]/B`D>"`K("1W:61T:"P@)WDG(#T^("1Y*3L*
M("`@("`@("`D=F5R='-;,ET@/2!A<G)A>2@G>"<@/3X@)'@@*R`D=VED=&@L
M("=Y)R`]/B`D>2`K("1H96EG:'0I.PH@("`@("`@("1V97)T<ULS72`](&%R
M<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y("L@)&AE:6=H="D["@H@("`@("`@
M(')E='5R;B`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1C;VQO<BP@)&9I;&PI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X
M+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R
M96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@
M=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1R;W5N9"`@(%1H92!W:61T:"!O9B!T:&4@8V]R
M;F5R(')O=6YD:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@
M5&AE(&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!R96-T
M86YG;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=6YD961296-T86YG;&4H
M)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1R;W5N9"P@)&-O;&]R(#T@)V)L
M86-K)RP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@:68@*"1R;W5N
M9"`\/2`P*2!["B`@("`@("`@("`@("\O($]P=&EM:7IE(&]U="!A;GD@8V%L
M;',@=VET:"!N;R!C;W)N97(@<F]U;F1I;F<N"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D
M8V]L;W(L("1F:6QL*3L*("`@("`@("!]"@H@("`@("`@("1S(#T@)FYE=R!3
M5T93:&%P92@I.PH@("`@("`@("1C;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O
M;&]R*"1C;VQO<BD["B`@("`@("`@)',M/G-E=$QI;F4H,2P@)&-O;&]R6R=R
M960G72P@)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);)V)L=64G72P@)&-O;&]R
M6R=A;'!H82==*3L*"B`@("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@
M("`@("`@("`@("`D9FEL;$-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H
M)&9I;&PI.PH@("`@("`@("`@("`D9B`]("1S+3YA9&1&:6QL*"1F:6QL0V]L
M;W);)W)E9"==+"`D9FEL;$-O;&]R6R=G<F5E;B==+"`D9FEL;$-O;&]R6R=B
M;'5E)UTL("1F:6QL0V]L;W);)V%L<&AA)UTI.PH@("`@("`@("`@("`D<RT^
M<V5T4FEG:'1&:6QL*"1F*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E="!C
M;W)N97(@<&]I;G1S('1O(&%V;VED(&QO=',@;V8@<F5D=6YD86YT(&UA=&@N
M"B`@("`@("`@)'@Q(#T@)'@@*R`D<F]U;F0["B`@("`@("`@)'DQ(#T@)'D@
M*R`D<F]U;F0["@H@("`@("`@("1X,B`]("1X("L@)'=I9'1H("T@)')O=6YD
M.PH@("`@("`@("1Y,B`]("1Y("L@)')O=6YD.PH*("`@("`@("`D>#,@/2`D
M>"`K("1W:61T:"`M("1R;W5N9#L*("`@("`@("`D>3,@/2`D>2`K("1H96EG
M:'0@+2`D<F]U;F0["@H@("`@("`@("1X-"`]("1X("L@)')O=6YD.PH@("`@
M("`@("1Y-"`]("1Y("L@)&AE:6=H="`M("1R;W5N9#L*"B`@("`@("`@+R\@
M4W1A<G0@:6X@=&AE('5P<&5R(&QE9G0N"B`@("`@("`@)'`Q(#T@)'1H:7,M
M/E]A<F-0;VEN=',H)')O=6YD+"`Q.#`L(#(R-2D["B`@("`@("`@)'`R(#T@
M)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`R,C4L(#(W,"D["@H@("`@("`@
M("\O(%-T87)T(&%T('1H92!L;W=E<B!L969T(&-O<FYE<B!O9B!T:&4@=&]P
M(&QE9G0@8W5R=F4N"B`@("`@("`@)',M/FUO=F5096Y4;R@D>#$@*R`D<#%;
M)W@Q)UTL("1Y,2`K("1P,5LG>3$G72D["@H@("`@("`@("\O($1R87<@=&AE
M('5P<&5R(&QE9G0@8V]R;F5R+@H@("`@("`@("1S+3YD<F%W0W5R=F54;R@D
M>#$@*R`D<#%;)W@S)UTL("1Y,2`K("1P,5LG>3,G72P@)'@Q("L@)'`Q6R=X
M,B==+"`D>3$@*R`D<#%;)WDR)UTI.PH@("`@("`@("1S+3YD<F%W0W5R=F54
M;R@D>#$@*R`D<#);)W@S)UTL("1Y,2`K("1P,ELG>3,G72P@)'@Q("L@)'`R
M6R=X,B==+"`D>3$@*R`D<#);)WDR)UTI.PH*("`@("`@("`O+R!#86QC=6QA
M=&4@=&AE('5P<&5R(')I9VAT('!O:6YT<RX*("`@("`@("`D<#,@/2`D=&AI
M<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#(W,"P@,S$U*3L*("`@("`@("`D<#0@
M/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#,Q-2P@,S8P*3L*"B`@("`@
M("`@+R\@0V]N;F5C="!T:&4@=&]P(&QE9G0@86YD(')I9VAT(&-U<G9E<RX*
M("`@("`@("`D<RT^9')A=TQI;F54;R@D>#(@*R`D<#-;)W@Q)UTL("1Y,B`K
M("1P,ULG>3$G72D["@H@("`@("`@("\O($1R87<@=&AE('5P<&5R(')I9VAT
M(&-O<FYE<BX*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@R("L@)'`S6R=X
M,R==+"`D>3(@*R`D<#-;)WDS)UTL("1X,B`K("1P,ULG>#(G72P@)'DR("L@
M)'`S6R=Y,B==*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@R("L@)'`T
M6R=X,R==+"`D>3(@*R`D<#1;)WDS)UTL("1X,B`K("1P-%LG>#(G72P@)'DR
M("L@)'`T6R=Y,B==*3L*"B`@("`@("`@+R\@0V%L8W5L871E('1H92!L;W=E
M<B!R:6=H="!P;VEN=',N"B`@("`@("`@)'`U(#T@)'1H:7,M/E]A<F-0;VEN
M=',H)')O=6YD+"`P+"`T-2D["B`@("`@("`@)'`V(#T@)'1H:7,M/E]A<F-0
M;VEN=',H)')O=6YD+"`T-2P@.3`I.PH*("`@("`@("`O+R!#;VYN96-T('1H
M92!T;W`@<FEG:'0@86YD(&QO=V5R(')I9VAT(&-U<G9E<RX*("`@("`@("`D
M<RT^9')A=TQI;F54;R@D>#,@*R`D<#5;)W@Q)UTL("1Y,R`K("1P-5LG>3$G
M72D["@H@("`@("`@("\O($1R87<@=&AE(&QO=V5R(')I9VAT(&-O<FYE<BX*
M("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@S("L@)'`U6R=X,R==+"`D>3,@
M*R`D<#5;)WDS)UTL("1X,R`K("1P-5LG>#(G72P@)'DS("L@)'`U6R=Y,B==
M*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@S("L@)'`V6R=X,R==+"`D
M>3,@*R`D<#9;)WDS)UTL("1X,R`K("1P-ELG>#(G72P@)'DS("L@)'`V6R=Y
M,B==*3L*"B`@("`@("`@+R\@0V%L8W5L871E('1H92!L;W=E<B!L969T('!O
M:6YT<RX*("`@("`@("`D<#<@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L
M(#DP+"`Q,S4I.PH@("`@("`@("1P."`]("1T:&ES+3Y?87)C4&]I;G1S*"1R
M;W5N9"P@,3,U+"`Q.#`I.PH*("`@("`@("`O+R!#;VYN96-T('1H92!B;W1T
M;VT@<FEG:'0@86YD(&)O='1O;2!L969T(&-U<G9E<RX*("`@("`@("`D<RT^
M9')A=TQI;F54;R@D>#0@*R`D<#=;)W@Q)UTL("1Y-"`K("1P-ULG>3$G72D[
M"@H@("`@("`@("\O($1R87<@=&AE(&QO=V5R(&QE9G0@8V]R;F5R+@H@("`@
M("`@("1S+3YD<F%W0W5R=F54;R@D>#0@*R`D<#=;)W@S)UTL("1Y-"`K("1P
M-ULG>3,G72P@)'@T("L@)'`W6R=X,B==+"`D>30@*R`D<#=;)WDR)UTI.PH@
M("`@("`@("1S+3YD<F%W0W5R=F54;R@D>#0@*R`D<#A;)W@S)UTL("1Y-"`K
M("1P.%LG>3,G72P@)'@T("L@)'`X6R=X,B==+"`D>30@*R`D<#A;)WDR)UTI
M.PH*("`@("`@("`O+R!#;&]S92!T:&4@<VAA<&4N"B`@("`@("`@)',M/F1R
M87=,:6YE5&\H)'@Q("L@)'`Q6R=X,2==+"`D>3$@*R`D<#%;)WDQ)UTI.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/E]M;W9I92T^861D*"1S*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87<@82!L:6YE+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1X,"`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE
M('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DP("`@("!4:&4@>2!C
M;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>#$@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>3$@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F
M('1H92!E;F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@(%1H92!L
M:6YE(&-O;&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'=I9'1H("!4:&4@
M=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;F4H
M)'@Q+"`D>3$L("1X,BP@)'DR+"`D8V]L;W(@/2`G8FQA8VLG+"`D=VED=&@@
M/2`Q*0H@("`@>PH@("`@("`@("1C;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O
M;&]R*"1C;VQO<BD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D8V]L;W(I*2![
M"B`@("`@("`@("`@("1S:&%P92`]("9N97<@4U=&4VAA<&4H*3L*("`@("`@
M("`@("`@)'-H87!E+3YS971,:6YE*"1W:61T:"P@)&-O;&]R6R=R960G72P@
M)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);)V)L=64G72P@)&-O;&]R6R=A;'!H
M82==*3L*("`@("`@("`@("`@)'-H87!E+3YM;W9E4&5N5&\H)'@Q+"`D>3$I
M.PH@("`@("`@("`@("`D<VAA<&4M/F1R87=,:6YE5&\H)'@R+"`D>3(I.PH*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<VAA<&4I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@9&%S:&5D
M(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@P("`@("`@
M("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>3`@("`@("`@("`@(%1H92!Y(&-O+6]R9&EN871E
M(&]F('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1X,2`@("`@
M("`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1Y,2`@("`@("`@("`@5&AE('D@8V\M;W)D:6YA=&4@
M;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@("`@
M("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=VED
M=&@@("`@("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1D87-H7VQE;F=T:"`@5&AE(&QE;F=T:"!O9B!A(&1A<V@@
M;VX@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&%S
M:%]S<&%C92`@(%1H92!L96YG=&@@;V8@82!S<&%C92!I;B!T:&4@9&%S:&5D
M(&QI;F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&%S:&5D3&EN92@D>#`L("1Y
M,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B;&%C:R<L("1W:61T:"`](#$L("1D
M87-H7VQE;F=T:"`](#(L("1D87-H7W-P86-E(#T@,BD*("`@('L*("`@("`@
M("`O+R!'970@=&AE(&QE;F=T:"!O9B!T:&4@;&EN92!I;B!P:7AE;',N"B`@
M("`@("`@)&QI;F5?;&5N9W1H(#T@;6%X*&-E:6PH<W%R="AP;W<H*"1X,2`M
M("1X,"DL(#(I("L@<&]W*"@D>3$@+2`D>3`I+"`R*2DI+"`R*3L*"B`@("`@
M("`@)&-O<U1H971A(#T@*"1X,2`M("1X,"D@+R`D;&EN95]L96YG=&@["B`@
M("`@("`@)'-I;E1H971A(#T@*"1Y,2`M("1Y,"D@+R`D;&EN95]L96YG=&@[
M"B`@("`@("`@)&QA<W1X(#T@)'@P.PH@("`@("`@("1L87-T>2`]("1Y,#L*
M"B`@("`@("`@+R\@1')A=R!T:&4@9&%S:&5D(&QI;F4N"B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&QI;F5?;&5N9W1H.R`D:2`K/2`H)&1A<VA?;&5N
M9W1H("L@)&1A<VA?<W!A8V4I*2!["B`@("`@("`@("`@("1X(#T@*"1D87-H
M7VQE;F=T:"`J("1C;W-4:&5T82D@*R`D;&%S='@["B`@("`@("`@("`@("1Y
M(#T@*"1D87-H7VQE;F=T:"`J("1S:6Y4:&5T82D@*R`D;&%S='D["@H@("`@
M("`@("`@("`D=&AI<RT^;&EN92@D;&%S='@L("1L87-T>2P@)'@L("1Y+"`D
M8V]L;W(I.PH*("`@("`@("`@("`@)&QA<W1X(#T@)'@@*R`H)&1A<VA?<W!A
M8V4@*B`D8V]S5&AE=&$I.PH@("`@("`@("`@("`D;&%S='D@/2`D>2`K("@D
M9&%S:%]S<&%C92`J("1S:6Y4:&5T82D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1')A=R!A('!O;'EL:6YE("AA(&YO;BUC;&]S960L(&YO
M;BUF:6QL960@<&]L>6=O;BD@8F%S960@;VX@80H@("`@("H@<V5T(&]F('9E
M<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1V97)T:6-E
M<R`@06X@87)R87D@;V8@>"!A;F0@>2!L86)E;&5D(&%R<F%Y<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H96<N("1V97)T:6-E<ULP75LG
M>"==+"`D=F5R=&EC97-;,%U;)WDG72P@+BXN*2X*("`@("`J($!P87)A;2!S
M=')I;F<@("1C;VQO<B`@("`@5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@
M=&AE(&QI;F4@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@("1W:61T:"`@
M("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!P;VQY;&EN92@D=F5R=',L("1C;VQO<BP@)'=I9'1H(#T@,2D*("`@('L*
M("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I
M.PH*("`@("`@("`D<VAA<&4@/2`F;F5W(%-71E-H87!E*"D["B`@("`@("`@
M)'-H87!E+3YS971,:6YE*"1W:61T:"P@)&-O;&]R6R=R960G72P@)&-O;&]R
M6R=G<F5E;B==+"`D8V]L;W);)V)L=64G72P@)&-O;&]R6R=A;'!H82==*3L*
M"B`@("`@("`@)&9I<G-T7V1O;F4@/2!F86QS93L*("`@("`@("!F;W)E86-H
M("@D=F5R=',@87,@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@A)&9I<G-T
M7V1O;F4I('L*("`@("`@("`@("`@("`@("1S:&%P92T^;6]V95!E;E1O*"1V
M86QU95LG>"==+"`D=F%L=65;)WDG72D["B`@("`@("`@("`@("`@("`D9FER
M<W1?9&]N92`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-H
M87!E+3YD<F%W3&EN951O*"1V86QU95LG>"==+"`D=F%L=65;)WDG72D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]M;W9I92T^861D*"1S
M:&%P92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&%N(&%R8RX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H92!X(&-O+6]R
M9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>2`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE(&%R
M8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@5&AE('-T87)T(&%N
M9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96YD("`@
M(%1H92!E;F0@86YG;&4@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;&]R("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&%R8RX*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I;&P@("`@5&AE(&9I;&P@8V]L;W(@;V8@=&AE
M(&%R8RX*("`@("`J+PH@("`@9G5N8W1I;VX@87)C*"1X+"`D>2P@)'(L("1S
M=&%R="P@)&5N9"P@)&-O;&]R(#T@)V)L86-K)RP@)&9I;&P@/2`G;F]N92<I
M"B`@("!["B`@("`@("`@)',@/2`F;F5W(%-71E-H87!E*"D["B`@("`@("`@
M)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@("`@
M("`D<RT^<V5T3&EN92@Q+"`D8V]L;W);)W)E9"==+"`D8V]L;W);)V=R965N
M)UTL("1C;VQO<ELG8FQU92==+"`D8V]L;W);)V%L<&AA)UTI.PH*("`@("`@
M("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@("`@("1F:6QL0V]L
M;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL;"D["B`@("`@("`@("`@
M("1F(#T@)',M/F%D9$9I;&PH)&9I;&Q#;VQO<ELG<F5D)UTL("1F:6QL0V]L
M;W);)V=R965N)UTL("1F:6QL0V]L;W);)V)L=64G72P@)&9I;&Q#;VQO<ELG
M86QP:&$G72D["B`@("`@("`@("`@("1S+3YS9712:6=H=$9I;&PH)&8I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1E;F0@+2`D<W1A<G0@/#T@-#4I('L*
M("`@("`@("`@("`@)'!T<R`]("1T:&ES+3Y?87)C4&]I;G1S*"1R+"`D<W1A
M<G0L("1E;F0I.PH@("`@("`@("`@("`D<RT^;6]V95!E;E1O*"1X+"`D>2D[
M"B`@("`@("`@("`@("1S+3YD<F%W3&EN951O*"1P='-;)W@Q)UT@*R`D>"P@
M)'!T<ULG>3$G72`K("1Y*3L*("`@("`@("`@("`@)',M/F1R87=#=7)V951O
M*"1P='-;)W@S)UT@*R`D>"P@)'!T<ULG>3,G72`K("1Y+"`D<'1S6R=X,B==
M("L@)'@L("1P='-;)WDR)UT@*R`D>2D["B`@("`@("`@("`@("1S+3YD<F%W
M3&EN951O*"1X+"`D>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'-E8W1I;VYS(#T@8V5I;"@H)&5N9"`M("1S=&%R="D@+R`T-2D["B`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1S96-T:6]N<SL@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)'!T<R`]("1T:&ES+3Y?87)C4&]I;G1S*"1R+"`D
M<W1A<G0@*R`H)&D@*B`T-2DL("@D<W1A<G0@*R`H*"1I("L@,2D@*B`T-2D@
M/B`D96YD*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#\@)&5N9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@*"1S=&%R="`K("@H)&D@*R`Q*2`J(#0U*2DI.PH*("`@("`@
M("`@("`@("`@("\O($EF('=E(&%R92!O;B!T:&4@9FER<W0@<V5C=&EO;BP@
M;6]V92!T:&4@<&5N('1O('1H90H@("`@("`@("`@("`@("`@+R\@8V5N=')E
M(&%N9"!D<F%W(&]U="!T;R!T:&4@961G92X*("`@("`@("`@("`@("`@(&EF
M("@D:2`]/2`P("8F("1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1S+3YM;W9E4&5N5&\H)'@L("1Y*3L*("`@("`@("`@("`@("`@
M("`@("`D<RT^9')A=TQI;F54;R@D<'1S6R=X,2==("L@)'@L("1P='-;)WDQ
M)UT@*R`D>2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1S+3YM;W9E4&5N5&\H)'!T<ULG>#$G72`K("1X+"`D<'1S
M6R=Y,2==("L@)'DI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\O($1R87<@=&AE(&%R8RX*("`@("`@("`@("`@("`@("1S+3YD<F%W
M0W5R=F54;R@D<'1S6R=X,R==("L@)'@L("1P='-;)WDS)UT@*R`D>2P@)'!T
M<ULG>#(G72`K("1X+"`D<'1S6R=Y,B==("L@)'DI.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@
M("`@("`@("`O+R!$<F%W(&$@;&EN92!F<F]M('1H92!E9&=E(&)A8VL@=&\@
M=&AE(&-E;G1R92!T;R!C;&]S90H@("`@("`@("`@("`@("`@+R\@;V9F('1H
M92!S96=M96YT+@H@("`@("`@("`@("`@("`@)',M/F1R87=,:6YE5&\H)'@L
M("1Y*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?;6]V:64M/F%D9"@D<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$<F%W(&$@<F5C=&%N9VQE(&9I;&QE9"!W:71H(&$@9W)A9&EE;G0@9G)O
M;2`D8V]L;W(Q('1O"B`@("`@*B`D8V]L;W(R+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1X("`@("`@(%1H92!L969T('@M8V]O<F1I;F%T92!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@
M("`@5&AE('1O<"!Y+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@
M<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE
M(&AE:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&-O;&]R("`@5&AE(&]U=&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!S=')I;F<@("1F:6QL,2`@(%1H92!N86UE(&]F
M('1H92!S=&%R="!C;VQO<B!F;W(@=&AE(&=R861I96YT+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&9I;&PR("`@5&AE(&YA;64@;V8@=&AE(&5N9"!C;VQO
M<B!F;W(@=&AE(&=R861I96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G<F%D
M:65N=%)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R
M(#T@)V)L86-K)RP@)&9I;&PQ(#T@)V)L86-K)RP@)&9I;&PR(#T@)W=H:71E
M)RD*("`@('L*("`@("`@("`D<R`]("9N97<@4U=&4VAA<&4H*3L*"B`@("`@
M("`@:68@*"1C;VQO<B`A/2`G;F]N92<I('L*("`@("`@("`@("`@)&-O;&]R
M(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@("`@("`@("`@
M)',M/G-E=$QI;F4H,2P@)&-O;&]R6R=R960G72P@)&-O;&]R6R=G<F5E;B==
M+"`D8V]L;W);)V)L=64G72P@)&-O;&]R6R=A;'!H82==*3L*("`@("`@("!]
M"@H@("`@("`@("1F:6QL,2`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL
M,2D["B`@("`@("`@)&9I;&PR(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I
M;&PR*3L*("`@("`@("`D9W)A9&EE;G0@/2`F;F5W(%-71D=R861I96YT*"D[
M"B`@("`@("`@)&=R861I96YT+3YA9&1%;G1R>2@P+C`L("1F:6QL,5LG<F5D
M)UTL("1F:6QL,5LG9W)E96XG72P@)&9I;&PQ6R=B;'5E)UTL("1F:6QL,5LG
M86QP:&$G72D["B`@("`@("`@)&=R861I96YT+3YA9&1%;G1R>2@Q+C`L("1F
M:6QL,ELG<F5D)UTL("1F:6QL,ELG9W)E96XG72P@)&9I;&PR6R=B;'5E)UTL
M("1F:6QL,ELG86QP:&$G72D["@H@("`@("`@("1F(#T@)',M/F%D9$9I;&PH
M)&=R861I96YT+"!35T9&24Q,7TQ)3D5!4E]'4D%$245.5"D["B`@("`@("`@
M)&8M/G-C86QE5&\H)'=I9'1H("\@)'1H:7,M/E]W:61T:"D["B`@("`@("`@
M)&8M/FUO=F54;R@D>"P@)'DI.PH@("`@("`@("1S+3YS9712:6=H=$9I;&PH
M)&8I.PH*("`@("`@("`D=F5R='-;,%T@/2!A<G)A>2@G>"<@/3X@)'@L("=Y
M)R`]/B`D>2D["B`@("`@("`@)'9E<G1S6S%=(#T@87)R87DH)W@G(#T^("1X
M("L@)'=I9'1H+"`G>2<@/3X@)'DI.PH@("`@("`@("1V97)T<ULR72`](&%R
M<F%Y*"=X)R`]/B`D>"`K("1W:61T:"P@)WDG(#T^("1Y("L@)&AE:6=H="D[
M"B`@("`@("`@)'9E<G1S6S-=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@
M)'D@*R`D:&5I9VAT*3L*"B`@("`@("`@)&9I<G-T7V1O;F4@/2!F86QS93L*
M("`@("`@("!F;W)E86-H("@D=F5R=',@87,@)'9E<G0I('L*("`@("`@("`@
M("`@:68@*"$D9FER<W1?9&]N92D@>PH@("`@("`@("`@("`@("`@)',M/FUO
M=F5096Y4;R@D=F5R=%LG>"==+"`D=F5R=%LG>2==*3L*("`@("`@("`@("`@
M("`@("1F:7)S=%]D;VYE(#T@=')U93L*("`@("`@("`@("`@("`@("1F:7)S
M=%]X(#T@)'9E<G1;)W@G73L*("`@("`@("`@("`@("`@("1F:7)S=%]Y(#T@
M)'9E<G1;)WDG73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<RT^9')A
M=TQI;F54;R@D=F5R=%LG>"==+"`D=F5R=%LG>2==*3L*("`@("`@("!]"B`@
M("`@("`@)',M/F1R87=,:6YE5&\H)&9I<G-T7W@L("1F:7)S=%]Y*3L*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<RD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TEM86=E+V=D+G!H<```````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$P-S8T-@`Q,#4Q-30S,3`V,``P,C`S-38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO26UA9V4N<&AP)SL*
M"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E7TEM86=E
M.CH@05!)(&9O<B!T:&4@4$A0($=$"B`J(&5X=&5N<VEO;BX@270@;6%I;FQY
M('!R;W9I9&5S('-O;64@=71I;&ET>2!F=6YC=&EO;G,L('-U8V@@87,@=&AE
M"B`J(&%B:6QI='D@=&\@;6%K92!P:7AE;',L(&9O<B!N;W<N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TEM86=E+TEM86=E+V=D+G!H<"QV(#$N-#@N,3`N
M,30@,C`P-B\P,2\P,2`R,3HR.#HR,B!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?26UA9V4*("HO"F-L87-S($AO<F1E7TEM86=E7V=D
M(&5X=&5N9',@2&]R9&5?26UA9V4@>PH*("`@("\J*@H@("`@("H@0V%P86)I
M;&ET97,@;V8@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]C87!A8FEL:71I97,@/2!A<G)A>2@G<F5S
M:7IE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C<F]P)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R;W1A=&4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9L:7`G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VUI<G)O<B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9W)A>7-C86QE)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S97!I82<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G>65L;&]W:7IE)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=W871E<FUA<FLG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V-A;G9A<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`I
M.PH*("`@("\J*@H@("`@("H@5VAA="!K:6YD(&]F(&EM86=E<R!S:&]U;&0@
M1T0@9V5N97)A=&4_($1E9F%U;'1S('1O("=P;F<G+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1Y<&4@/2`G<&YG)SL*
M"B`@("`O*BH*("`@("`J($=$($EM86=E(')E<V]U<F-E(&9O<B!T:&4@8W5R
M<F5N="!I;6%G92!D871A+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*
M("`@("`J+PH@("`@=F%R("1?:6T["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@
M:61E;G1I9FEE<B!O9B!T:&4@8W5R<F5N="!I;6%G92X@3F5W(&EM86=E(&1A
M=&$@=VEL;"!N;W0@8F4*("`@("`J(&QO861E9"!I9B!T:&4@<V%M92!I9"!I
M<R!A;')E861Y(&QO861E9"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]I9"`]("<G.PH*("`@(&9U;F-T:6]N($AO<F1E
M7TEM86=E7V=D*"1P87)A;7,I"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D
M95]);6%G92@D<&%R86US*3L*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;
M)W1Y<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'!A<F%M
M<ULG='EP92==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D<&%R
M86US6R=W:61T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VEM(#T@)B1T
M:&ES+3Y?8W)E871E*"1T:&ES+3Y?=VED=&@L("1T:&ES+3Y?:&5I9VAT*3L*
M("`@("`@("`@("`@)'1H:7,M/E]C86QL*"=I;6%G949I;&PG+"!A<G)A>2@D
M=&AI<RT^7VEM+"`P+"`P+"`D=&AI<RT^86QL;V-A=&5#;VQO<B@D=&AI<RT^
M7V)A8VMG<F]U;F0I*2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)VEM86=E
M+R<@+B`D=&AI<RT^7W1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-P
M;&%Y('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M:7-P;&%Y*"D*("`@('L*("`@("`@("`D=&AI<RT^:&5A9&5R<R@I.PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-A;&PH)VEM86=E)R`N("1T:&ES+3Y?='EP
M92P@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@<F%W(&1A=&$@9F]R('1H:7,@:6UA9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&-O;G9E<G0@($EF('1R=64L('1H92!I
M;6%G92!D871A('=I;&P@8F4@<F5T=7)N960@:6X@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&%R9V5T(&9O<FUA="P@:6YD97!E;F1E
M;G1L>2!F<F]M(&%N>2!I;6%G90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&]P97)A=&EO;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!R87<@:6UA9V4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F%W*"1C;VYV97)T(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T=7)N(%5T
M:6PZ.F)U9F9E<D]U='!U="@G:6UA9V4G("X@)'1H:7,M/E]T>7!E+"`D=&AI
M<RT^7VEM*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G
M92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@
M("`@("`@<&%R96YT.CIR97-E="@I.PH@("`@("`@(&EF("AI<U]R97-O=7)C
M92@D=&AI<RT^7VEM*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C
M86QL*"=I;6%G941E<W1R;WDG+"!A<G)A>2@D=&AI<RT^7VEM*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!H96EG:'0@86YD('=I9'1H(&]F('1H92!C=7)R96YT(&EM
M86=E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&AA<V@@=VET
M:"`G=VED=&@G(&-O;G1A:6YI;F<@=&AE('=I9'1H+`H@("`@("H@("`@("`@
M("`@("`@("`@)VAE:6=H="<@8V]N=&%I;FEN9R!T:&4@:&5I9VAT(&]F('1H
M92!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&EM96YS:6]N<R@I
M"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]I;2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@
M("!](&5L<V5I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]I;2DI('L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=W:61T:"<@/3X@)'1H:7,M/E]C86QL*"=I
M;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAE:6=H="<@/3X@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@
M87)R87DH)'1H:7,M/E]I;2DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH)W=I9'1H)R`]/B`P+"`G:&5I9VAT)R`]/B`P
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M8V]L;W(@=&AA="!C86X@8F4@86-C97-S960@:6X@=&AI<R!O8FIE8W0N(%=H
M96X@80H@("`@("H@8V]L;W(@:7,@<V5T+"!T:&4@:6YT96=E<B!R97-O=7)C
M92!O9B!I="!I<R!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@8V]L;W(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!4:&4@<F5S;W5R8V4@;V8@=&AE(&-O;&]R
M('1H870@8V%N(&)E('!A<W-E9"!T;R!'1"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86QL;V-A=&5#;VQO<B@D;F%M92D*("`@('L*("`@("`@("!S=&%T:6,@
M)&-O;&]R<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AE;7!T>2@D8V]L;W)S
M6R1N86UE72DI('L*("`@("`@("`@("`@;&ES="@D<BP@)&<L("1B*2`]("1T
M:&ES+3YG97121T(H)&YA;64I.PH@("`@("`@("`@("`D8V]L;W)S6R1N86UE
M72`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<D%L;&]C871E)RP@87)R87DH
M)'1H:7,M/E]I;2P@)'(L("1G+"`D8BDI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1C;VQO<G-;)&YA;65=.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=$9O;G0H)&9O;G0I"B`@("!["B`@("`@("`@<W=I=&-H("@D9F]N="D@>PH@
M("`@("`@(&-A<V4@)W1I;GDG.@H@("`@("`@("`@("!R971U<FX@,3L*"B`@
M("`@("`@8V%S92`G;65D:75M)SH*("`@("`@("`@("`@<F5T=7)N(#,["@H@
M("`@("`@(&-A<V4@)VQA<F=E)SH*("`@("`@("`@("`@<F5T=7)N(#0["@H@
M("`@("`@(&-A<V4@)V=I86YT)SH*("`@("`@("`@("`@<F5T=7)N(#4["@H@
M("`@("`@(&-A<V4@)W-M86QL)SH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!R971U<FX@,CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!,;V%D('1H92!I;6%G92!D871A(&9R;VT@82!S=')I;F<N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@06X@87)B:71R87)Y
M(&ED(&9O<B!T:&4@:6UA9V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;6%G
M95]D871A("!4:&4@9&%T82!T;R!U<V4@9F]R('1H92!I;6%G92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&]A9%-T<FEN9R@D:60L("1I;6%G95]D871A*0H@
M("`@>PH@("`@("`@(&EF("@D:60@(3T@)'1H:7,M/E]I9"D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]I;2D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="`]("1T:&ES+3YR97-E="@I+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]I
M;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E0W)E871E1G)O;5-T<FEN9R<L(&%R
M<F%Y*"1I;6%G95]D871A*2D["B`@("`@("`@("`@("1T:&ES+3Y?:60@/2`D
M:60["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M3&]A9"!T:&4@:6UA9V4@9&%T82!F<F]M(&$@9FEL92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9U;&P@<&%T:"!A;F0@
M9FEL96YA;64@=&\@=&AE(&9I;&4@=&\@;&]A9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!I;6%G92!D871A(&9R;VTN(%1H92!F:6QE
M;F%M92!W:6QL(&%L<V\@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!U<V5D(&9O<B!T:&4@:6UA9V4@:60N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@4$5!4B!%<G)O<B!I9B!F:6QE(&1O97,@;F]T(&5X:7-T
M(&]R(&-O=6QD(&YO="!B92!L;V%D960*("`@("`J("`@("`@("`@("`@("`@
M(&]T:&5R=VES92!.54Q,(&EF('-U8V-E<W-F=6P@;W(@86QR96%D>2!L;V%D
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO861&:6QE*"1F:6QE;F%M92D*
M("`@('L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/G)E<V5T
M*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D:6YF;R`]("1T:&ES
M+3Y?8V%L;"@G9V5T:6UA9V5S:7IE)RP@87)R87DH)&9I;&5N86UE*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1I;F9O*2D@>PH@("`@("`@
M("`@("!S=VET8V@@*"1I;F9O6S)=*2!["B`@("`@("`@("`@(&-A<V4@,3H*
M("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)VEM86=E8W)E
M871E9G)O;6=I9B<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E8W)E871E9G)O;6=I9B<L(&%R<F%Y
M*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUJ
M<&5G)RP@87)R87DH)&9I;&5N86UE*2D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`S.@H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E8W)E871E9G)O;7!N9R<L(&%R
M<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@,34Z"B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?
M97AI<W1S*"=I;6%G96-R96%T969R;VUG=V)M<"<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E8W)E
M871E9G)O;6=W8FUP)RP@87)R87DH)&9I;&5N86UE*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`Q-CH*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F)'1H:7,M/E]C
M86QL*"=I;6%G96-R96%T969R;VUX8FTG+"!A<G)A>2@D9FEL96YA;64I*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?:6TI*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!P
M87)E;G0Z.FQO861&:6QE*"1F:6QE;F%M92D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6T@
M/2`F)'1H:7,M/E]C86QL*"=I;6%G94-R96%T949R;VU3=')I;F<G+"!A<G)A
M>2@D=&AI<RT^7V1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<VEZ
M92!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D=VED=&@@("`@("!4:&4@;F5W('=I9'1H+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&AE:6=H="`@("`@5&AE(&YE=R!H96EG:'0N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<F%T:6\@("`@("!-86EN=&%I;B!O<FEG:6YA;"!A
M<W!E8W0@<F%T:6\N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<VEZ92@D=VED
M=&@L("1H96EG:'0L("1R871I;R`]('1R=64I"B`@("!["B`@("`@("`@+RH@
M06)O<G0@:68@=V4G<F4@87-K960@=&\@9&EV:61E(&)Y('IE<F\L(&]R('1R
M=6YC871E('1H90H@("`@("`@("`J(&EM86=E(&-O;7!L971E;'D@:6X@96ET
M:&5R(&1I<F5C=&EO;BX@*B\*("`@("`@("!I9B`H(21W:61T:"!\?"`A)&AE
M:6=H="D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)')A=&EO*2!["B`@("`@("`@("`@(&EF("@D=VED=&@@+R`D:&5I
M9VAT(#X@)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I
M;2DI("\@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I
M;2DI*2!["B`@("`@("`@("`@("`@("`D=VED=&@@/2`D:&5I9VAT("H@)'1H
M:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI("\@)'1H
M:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&AE:6=H="`]("1W
M:61T:"`J("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?
M:6TI*2`O("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?
M:6TI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&EM(#T@
M)'1H:7,M/E]I;3L*("`@("`@("`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8W)E
M871E*"1W:61T:"P@)&AE:6=H="D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/E]I;2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]I;3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]
M("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL)RP@87)R87DH)'1H:7,M/E]I;2P@
M,"P@,"P@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R06QL;V-A=&4G+"!A<G)A
M>2@D=&AI<RT^7VEM+"`R-34L(#(U-2P@,C4U*2DI*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@
M("`@("`@:68@*&ES7V$H)'1H:7,M/E]C86QL*"=I;6%G94-O<'E297-A;7!L
M960G+"!A<G)A>2@D=&AI<RT^7VEM+"`D:6TL(#`L(#`L(#`L(#`L("1W:61T
M:"P@)&AE:6=H="P@)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)&EM
M*2DL("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1I;2DI*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%L
M;"@G:6UA9V5#;W!Y4F5S:7IE9"<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1I;2P@
M,"P@,"P@,"P@,"P@)'=I9'1H+"`D:&5I9VAT+"`D=&AI<RT^7V-A;&PH)VEM
M86=E4U@G+"!A<G)A>2@D:6TI*2P@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@
M87)R87DH)&EM*2DI*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F]P('1H92!C=7)R96YT(&EM86=E+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1X,2`@5&AE('1O<"!L969T(&-O<FYE<B!O9B!T:&4@8W)O
M<'!E9"!I;6%G92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@5&AE('1O
M<"!R:6=H="!C;W)N97(@;V8@=&AE(&-R;W!P960@:6UA9V4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>#(@(%1H92!B;W1T;VT@;&5F="!C;W)N97(@;V8@
M=&AE(&-R;W!P960@:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3(@
M(%1H92!B;W1T;VT@<FEG:'0@8V]R;F5R(&]F('1H92!C<F]P<&5D(&EM86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F]P*"1X,2P@)'DQ+"`D>#(L("1Y
M,BD*("`@('L*("`@("`@("`D:6T@/2`D=&AI<RT^7VEM.PH@("`@("`@("1T
M:&ES+3Y?:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'@R("T@)'@Q+"`D>3(@+2`D
M>3$I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6T["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^7V-A;&PH)VEM86=E0V]P>2<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1I;2P@,"P@,"P@)'@Q+"`D>3$L("1X,B`M("1X
M,2P@)'DR("T@)'DQ*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2;W1A=&4@
M=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&%N9VQE("`@("`@(%1H92!A;F=L92!T;R!R;W1A=&4@=&AE(&EM86=E
M(&)Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN('1H
M92!C;&]C:W=I<V4@9&ER96-T:6]N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8F%C:V=R;W5N9"`@5&AE(&)A8VMG<F]U;F0@8V]L;W(@=&\@9FEL;"!A;GD@
M=')I86YG;&5S"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=&%T92@D86YG;&4L
M("1B86-K9W)O=6YD(#T@)W=H:71E)RD*("`@('L*("`@("`@("!I9B`H(69U
M;F-T:6]N7V5X:7-T<R@G:6UA9V5R;W1A=&4G*2D@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("`D8F%C:V=R;W5N9"`]("1T:&ES
M+3YA;&QO8V%T94-O;&]R*"1B86-K9W)O=6YD*3L*("`@("`@("!I9B`H:7-?
M82@D8F%C:V=R;W5N9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&)A8VMG<F]U;F0["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@
M*"1A;F=L92D@>PH@("`@("`@(&-A<V4@)SDP)SH*("`@("`@("`@("`@)'@@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D[
M"B`@("`@("`@("`@("1Y(#T@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R
M87DH)'1H:7,M/E]I;2DI.PH@("`@("`@("`@("`D>'EM87@@/2!M87@H)'@L
M("1Y*3L*"B`@("`@("`@("`@("1I;2`]("8D=&AI<RT^7V-R96%T92@D>'EM
M87@L("1X>6UA>"D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I;3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M
M/E]C86QL*"=I;6%G94-O<'DG+"!A<G)A>2@D:6TL("1T:&ES+3Y?:6TL(#`L
M(#`L(#`L(#`L("1X+"`D>2DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G95)O=&%T92<L(&%R<F%Y
M*"1I;2P@,C<P+"`D8F%C:V=R;W5N9"DI.PH@("`@("`@("`@("!I9B`H:7-?
M82@D:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D:6T["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]I;2`]
M("1I;3L*("`@("`@("`@("`@)&EM(#T@)B1T:&ES+3Y?8W)E871E*"1Y+"`D
M>"D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I;3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'@@/"`D>2D@>PH@("`@("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R
M87DH)&EM+"`D=&AI<RT^7VEM+"`P+"`P+"`P+"`P+"`D>'EM87@L("1X>6UA
M>"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS96EF("@D>"`^("1Y*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O<'DG+"!A<G)A>2@D:6TL
M("1T:&ES+3Y?:6TL(#`L(#`L("1X>6UA>"`M("1Y+"`D>'EM87@@+2`D>"P@
M)'AY;6%X+"`D>'EM87@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`D:6T["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V52;W1A=&4G+"!A
M<G)A>2@D=&AI<RT^7VEM+"`S-C`@+2`D86YG;&4L("1B86-K9W)O=6YD*2D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($9L:7`@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9L:7`H*0H@("`@>PH@("`@("`@("1X(#T@)'1H
M:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@
M("`@("1Y(#T@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M
M/E]I;2DI.PH*("`@("`@("`D:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'@L("1Y
M*3L*("`@("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1I;3L*("`@("`@("!]"B`@("`@("`@9F]R("@D
M8W5R62`](#`[("1C=7)9(#P@)'D[("1C=7)9*RLI('L*("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@
M87)R87DH)&EM+"`D=&AI<RT^7VEM+"`P+"`D>2`M("@D8W5R62`K(#$I+"`P
M+"`D8W5R62P@)'@L(#$I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?:6T@/2`D:6T["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-:7)R;W(@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&UI<G)O<B@I"B`@("!["B`@("`@("`@)'@@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D["B`@("`@("`@)'D@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D=&AI<RT^7VEM*2D[
M"@H@("`@("`@("1I;2`]("8D=&AI<RT^7V-R96%T92@D>"P@)'DI.PH@("`@
M("`@(&EF("AI<U]A*"1I;2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&EM.PH@("`@("`@('T*("`@("`@("!F;W(@*"1C=7)8(#T@
M,#L@)&-U<E@@/"`D>#L@)&-U<E@K*RD@>PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O<'DG+"!A<G)A>2@D
M:6TL("1T:&ES+3Y?:6TL("1X("T@*"1C=7)8("L@,2DL(#`L("1C=7)8+"`P
M+"`Q+"`D>2DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]I;2`]("1I;3L*("`@('T*"B`@("`O*BH*("`@("`J($-O
M;G9E<G0@=&AE(&-U<G)E;G0@:6UA9V4@=&\@9W)A>7-C86QE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G<F%Y<V-A;&4H*0H@("`@>PH@("`@("`@("1R871E
M4B`]("XR,CD["B`@("`@("`@)')A=&5'(#T@+C4X-SL*("`@("`@("`D<F%T
M94(@/2`N,3$T.PH@("`@("`@("1W:&ET96YE<W,@/2`S.PH*("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%G96ES=')U96-O;&]R)RD@)B8@)'1H
M:7,M/E]C86QL*"=I;6%G94ES5')U94-O;&]R)RP@87)R87DH)'1H:7,M/E]I
M;2DI(#T]/2!T<G5E*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E5')U94-O;&]R5&]086QE='1E)RP@87)R
M87DH)'1H:7,M/E]I;2P@=')U92P@,C4V*2DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D8V]L;W)S(#T@;6EN*#(U-BP@)'1H:7,M
M/E]C86QL*"=I;6%G94-O;&]R<U1O=&%L)RP@87)R87DH)'1H:7,M/E]I;2DI
M*3L*("`@("`@("!F;W(@*"1X(#T@,#L@)'@@/"`D8V]L;W)S.R`D>"LK*2![
M"B`@("`@("`@("`@("1S<F,@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)S
M1F]R26YD97@G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"DI.PH@("`@("`@("`@
M("!I9B`H:7-?82@D<W)C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'-R8SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;F5W(#T@;6EN*#(U-2P@86)S*"1S<F-;)W)E9"==("H@)')A=&52("L@)'-R
M8ULG9W)E96XG72`J("1R871E1R`K("1S<F-;)V)L=64G72`J("1R871E0BD@
M*R`D=VAI=&5N97-S*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]
M("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<E-E="<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL("1X+"`D;F5W+"`D;F5W+"`D;F5W*2DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5P:6$@9FEL=&5R
M+@H@("`@("H*("`@("`J($)A<VEC86QL>2!T=7)N<R!T:&4@:6UA9V4@=&\@
M9W)A>7-C86QE(&%N9"!T:&5N(&%D9',@<V]M90H@("`@("H@9&5F:6YE9"!T
M:6YT(&]N(&ET("A2("L](#,P+"!'("L](#0S+"!"("L]("TR,RD@<V\@:70@
M=VEL;`H@("`@("H@87!P96%R('1O(&)E(&$@=F5R>2!O;&0@<&EC='5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5P:6$H*0H@("`@>PH@("`@("`@("1T
M:6YT4B`](#@P.PH@("`@("`@("1T:6YT1R`](#0S.PH@("`@("`@("1T:6YT
M0B`]("TR,SL*("`@("`@("`D<F%T95(@/2`N,C(Y.PH@("`@("`@("1R871E
M1R`]("XU.#<["B`@("`@("`@)')A=&5"(#T@+C$Q-#L*("`@("`@("`D=VAI
M=&5N97-S(#T@,SL*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%L;"@G:6UA9V5)
M<U1R=65#;VQO<B<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`]/3T@=')U92D@>PH@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I
M;6%G951R=65#;VQO<E1O4&%L971T92<L(&%R<F%Y*"1T:&ES+3Y?:6TL('1R
M=64L(#(U-BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&-O;&]R<R`](&UA>"@R-38L("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO
M<G-4;W1A;"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2D["B`@("`@("`@9F]R("@D
M>"`](#`[("1X(#P@)&-O;&]R<SL@)'@K*RD@>PH@("`@("`@("`@("`D<W)C
M(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R<T9O<DEN9&5X)RP@87)R87DH
M)'1H:7,M/E]I;2P@)'@I*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-R8RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S<F,[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YE=R`](&UI;B@R-34L(&%B
M<R@D<W)C6R=R960G72`J("1R871E4B`K("1S<F-;)V=R965N)UT@*B`D<F%T
M94<@*R`D<W)C6R=B;'5E)UT@*B`D<F%T94(I("L@)'=H:71E;F5S<RD["B`@
M("`@("`@("`@("1R(#T@;6EN*#(U-2P@)&YE=R`K("1T:6YT4BD["B`@("`@
M("`@("`@("1G(#T@;6EN*#(U-2P@)&YE=R`K("1T:6YT1RD["B`@("`@("`@
M("`@("1B(#T@;6EN*#(U-2P@)&YE=R`K("1T:6YT0BD["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)3
M970G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'(L("1G+"`D8BDI+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%EE;&QO=VEZ92!F:6QT97(N"B`@("`@*@H@("`@("H@061D<R!A(&QA>65R
M(&]F('EE;&QO=R!T:&%T(&-A;B!B92!T<F%N<W!A<F5N="!O<B!S;VQI9"X@
M268*("`@("`J("1I;G1E;G-I='E!(&ES(#(U-2!T:&4@:6UA9V4@=VEL;"!B
M92`P)2!T<F%N<W!A<F5N="`H<V]L:60I+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I;G1E;G-I='E9("!(;W<@<W1R;VYG('-H;W5L9"!T:&4@
M>65L;&]W("AR960@86YD(&=R965N*2!B93\@*#`M,C4U*0H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&EN=&5N<VET>4(@($AO=R!W96%K('-H;W5L9"!T:&4@
M8FQU92!B93\@*#X](#(L(&EN('1H92!P;W-I=&EV92!L:6UI="!I="!W:6QL
M(&)E(&UA:V4@0DQ512`P*0H@("`@("HO"B`@("!F=6YC=&EO;B!Y96QL;W=I
M>F4H)&EN=&5N<VET>5D@/2`U,"P@)&EN=&5N<VET>4(@/2`S*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^7V-A;&PH)VEM86=E27-4<G5E0V]L;W(G+"!A
M<G)A>2@D=&AI<RT^7VEM*2D@/3T]('1R=64I('L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V54<G5E0V]L;W)4
M;U!A;&5T=&4G+"!A<G)A>2@D=&AI<RT^7VEM+"!T<G5E+"`R-38I*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C;VQO<G,@/2!M
M87@H,C4V+"`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)S5&]T86PG+"!A<G)A
M>2@D=&AI<RT^7VEM*2DI.PH@("`@("`@(&9O<B`H)'@@/2`P.R`D>"`\("1C
M;VQO<G,[("1X*RLI('L*("`@("`@("`@("`@)'-R8R`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5#;VQO<G-&;W));F1E>"<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X
M*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1S<F,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W)C.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1R(#T@;6EN*"1S<F-;)W)E9"==("L@)&EN=&5N<VET
M>5DL(#(U-2D["B`@("`@("`@("`@("1G(#T@;6EN*"1S<F-;)V=R965N)UT@
M*R`D:6YT96YS:71Y62P@,C4U*3L*("`@("`@("`@("`@)&(@/2!M87@H*"1R
M("L@)&<I("\@;6%X*"1I;G1E;G-I='E"+"`R*2P@,"D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)3
M970G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'(L("1G+"`D8BDI+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!W
M871E<FUA<FLH)'1E>'0L("1H86QI9VX@/2`G<FEG:'0G+"`D=F%L:6=N(#T@
M)V)O='1O;2<L("1F;VYT(#T@)W-M86QL)RD*("`@('L*("`@("`@("`D8V]L
M;W(@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)#;&]S97-T)RP@87)R87DH
M)'1H:7,M/E]I;2P@,C4U+"`R-34L(#(U-2DI.PH@("`@("`@(&EF("AI<U]A
M*"1C;VQO<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&-O;&]R.PH@("`@("`@('T*("`@("`@("`D<VAA9&]W(#T@)'1H:7,M/E]C
M86QL*"=I;6%G94-O;&]R0VQO<V5S="<L(&%R<F%Y*"1T:&ES+3Y?:6TL(#`L
M(#`L(#`I*3L*("`@("`@("!I9B`H:7-?82@D<VAA9&]W+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<VAA9&]W.PH@("`@("`@('T*
M"B`@("`@("`@+R\@4VAA9&]W(&]F9G-E="!I;B!P:7AE;',N"B`@("`@("`@
M)&1R;W`@/2`Q.PH*("`@("`@("`O+R!-87AI;75M('1E>'0@=VED=&@N"B`@
M("`@("`@)&UA>'=I9'1H(#T@,C`P.PH*("`@("`@("`O+R!!;6]U;G0@;V8@
M<W!A8V4@=&\@;&5A=F4@8F5T=V5E;B!T:&4@=&5X="!A;F0@=&AE(&EM86=E
M"B`@("`@("`@+R\@8F]R9&5R+@H@("`@("`@("1P861D:6YG(#T@,3`["@H@
M("`@("`@("1F(#T@)'1H:7,M/F=E=$9O;G0H)&9O;G0I.PH@("`@("`@("1F
M;VYT=VED=&@@/2`D=&AI<RT^7V-A;&PH)VEM86=E1F]N=%=I9'1H)RP@87)R
M87DH)&8I*3L*("`@("`@("!I9B`H:7-?82@D9F]N='=I9'1H+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9F]N='=I9'1H.PH@("`@
M("`@('T*("`@("`@("`D9F]N=&AE:6=H="`]("1T:&ES+3Y?8V%L;"@G:6UA
M9V5&;VYT2&5I9VAT)RP@87)R87DH)&8I*3L*("`@("`@("!I9B`H:7-?82@D
M9F]N=&AE:6=H="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&9O;G1H96EG:'0["B`@("`@("`@?0H*("`@("`@("`O+R!3;R!T:&%T
M('-H861O=R!I<R!N;W0@;V9F('1H92!I;6%G92!W:71H(')I9VAT(&%L:6=N
M(&%N9`H@("`@("`@("\O(&)O='1O;2!V86QI9VXN"B`@("`@("`@)&UA<F=I
M;B`](&9L;V]R*"1P861D:6YG("L@)&1R;W`I("\@,CL*"B`@("`@("`@:68@
M*"1M87AW:61T:"D@>PH@("`@("`@("`@("`D;6%X8VAA<G-P97)L:6YE(#T@
M9FQO;W(H*"1M87AW:61T:"`M("@D;6%R9VEN("H@,BDI("\@)&9O;G1W:61T
M:"D["B`@("`@("`@("`@("1T97AT(#T@=V]R9'=R87`H)'1E>'0L("1M87AC
M:&%R<W!E<FQI;F4L(")<;B(L(#$I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4W!L:70@)'1E>'0@:6YT;R!I;F1I=FED=6%L(&QI;F5S+@H@("`@("`@("1L
M:6YE<R`](&5X<&QO9&4H(EQN(BP@)'1E>'0I.PH*("`@("`@("!S=VET8V@@
M*"1V86QI9VXI('L*("`@("`@("!C87-E("=C96YT97(G.@H@("`@("`@("`@
M("`D>2`]("@D=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D=&AI<RT^
M7VEM*2D@+2`H)&9O;G1H96EG:'0@*B!C;W5N="@D;&EN97,I*2D@+R`R.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G8F]T=&]M)SH*("`@
M("`@("`@("`@)'D@/2`D=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D
M=&AI<RT^7VEM*2D@+2`H*"1F;VYT:&5I9VAT("H@8V]U;G0H)&QI;F5S*2D@
M*R`D;6%R9VEN*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("1Y(#T@)&UA<F=I;CL*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1H86QI9VXI('L*("`@
M("`@("!C87-E("=R:6=H="<Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE
M<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="`]("1T:&ES+3Y?8V%L;"@G:6UA9V53=')I;F<G+"!A<G)A>2@D=&AI<RT^
M7VEM+"`D9BP@*"1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES
M+3Y?:6TI*2`M("1F;VYT=VED=&@@*B!S=')L96XH)&QI;F4I*2`M("1M87)G
M:6X@*R`D9')O<"P@*"1Y("L@)&1R;W`I+"`D;&EN92P@)'-H861O=RDI+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1F+"`H)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H
M:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J('-T<FQE;B@D;&EN92DI("T@)&UA
M<F=I;BP@)'DL("1L:6YE+"`D8V]L;W(I*3L*("`@("`@("`@("`@("`@("1Y
M("L]("1F;VYT:&5I9VAT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=C96YT97(G.@H@("`@("`@("`@("!F;W)E
M86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R:6YG)RP@87)R
M87DH)'1H:7,M/E]I;2P@)&8L(&9L;V]R*"@D=&AI<RT^7V-A;&PH)VEM86=E
M4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D@+2`D9F]N='=I9'1H("H@<W1R;&5N
M*"1L:6YE*2D@+R`R*2`K("1D<F]P+"`H)'D@*R`D9')O<"DL("1L:6YE+"`D
M<VAA9&]W*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R:6YG)RP@
M87)R87DH)'1H:7,M/E]I;2P@)&8L(&9L;V]R*"@D=&AI<RT^7V-A;&PH)VEM
M86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D@+2`D9F]N='=I9'1H("H@<W1R
M;&5N*"1L:6YE*2D@+R`R*2P@)'DL("1L:6YE+"`D8V]L;W(I*3L*("`@("`@
M("`@("`@("`@("1Y("L]("1F;VYT:&5I9VAT.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R:6YG
M)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L("1M87)G:6X@*R`D9')O<"P@*"1Y
M("L@)&1R;W`I+"`D;&EN92P@)'-H861O=RDI+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1F+"`D;6%R
M9VEN+"`D>2P@)&QI;F4L("1C;VQO<BDI.PH@("`@("`@("`@("`@("`@)'D@
M*ST@)&9O;G1H96EG:'0["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87=S(&$@=&5X="!S=')I
M;F<@;VX@=&AE(&EM86=E(&EN(&$@<W!E8VEF:65D(&QO8V%T:6]N+"!W:71H
M"B`@("`@*B!T:&4@<W!E8VEF:65D('-T>6QE(&EN9F]R;6%T:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1T97AT("`@("`@(%1H92!T97AT
M('1O(&1R87<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("`@("!4
M:&4@;&5F="!X(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T(&]F('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&5X="!S=')I;F<N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("`@("!4:&4@=&]P('D@8V]O
M<F1I;F%T92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E>'0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-T<FEN9RX*("`@("`J($!P87)A;2!S
M=')I;F<@("1F;VYT("`@("`@(%1H92!F;VYT(&ED96YT:69I97(@>6]U('=A
M;G0@=&\@=7-E(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("`@
M("!4:&4@8V]L;W(@=&AA="!Y;W4@=V%N="!T:&4@=&5X="!D:7-P;&%Y960@
M:6XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("!!;B!I;G1E
M9V5R('1H870@<W!E8VEF:65S('1H92!O<FEE;G1A=&EO;B!O9@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1E>'0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1E>'0H)'-T<FEN9RP@)'@L("1Y+"`D9F]N="`]("=M
M;VYO<W!A8V4G+"`D8V]L;W(@/2`G8FQA8VLG+"`D9&ER96-T:6]N(#T@,"D*
M("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO
M<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@("`D9B`]("1T
M:&ES+3YG971&;VYT*"1F;VYT*3L*("`@("`@("!S=VET8V@@*"1D:7)E8W1I
M;VXI('L*("`@("`@("!C87-E("TY,#H*("`@("`@("!C87-E(#(W,#H*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V53=')I;F=5
M<"<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1F+"`D>"P@)'DL("1S=')I;F<L("1C
M*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#`Z"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V53=')I;F<G+"!A<G)A>2@D=&AI<RT^7VEM+"`D9BP@)'@L("1Y
M+"`D<W1R:6YG+"`D8RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@8VER8VQE+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("!4:&4@>"!C;RUO
M<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'D@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<B`@("`@5&AE(')A9&EU<R!O9B!T:&4@8VER
M8VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@(%1H92!L:6YE(&-O
M;&]R(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL
M("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(&-I<F-L92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VER8VQE*"1X+"`D>2P@)'(L("1C;VQO<BP@)&9I;&P@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H
M)&-O;&]R*3L*("`@("`@("!I9B`H:7-?82@D8RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&,["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<U]N=6QL*"1F:6QL*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]C86QL*"=I;6%G945L;&EP<V4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D
M>"P@)'DL("1R("H@,BP@)'(@*B`R+"`D8RDI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("@D9FEL;"`A/3T@)&-O;&]R*2!["B`@("`@("`@
M("`@("`@("`D9FEL;$-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I
M;&PI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&9I;&Q#;VQO<BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D9FEL
M;$-O;&]R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL961%;&QI
M<'-E)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J(#(L("1R("H@
M,BP@)&9I;&Q#;VQO<BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G945L
M;&EP<V4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'DL("1R("H@,BP@)'(@
M*B`R+"`D8RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL961%;&QI<'-E
M)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J(#(L("1R("H@,BP@
M)&,I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R
M87<@82!P;VQY9V]N(&)A<V5D(&]N(&$@<V5T(&]F('9E<G1I8V5S+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D=F5R=&EC97,@($%N(&%R<F%Y(&]F
M('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("AE9RX@)'9E<G1I8V5S6S!=6R=X)UTL("1V97)T:6-E<ULP
M75LG>2==+"`N+BXI+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@
M5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@=&AE('!O;'EG;VX@=VET:"X*
M("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F
M:6QL('1H92!P;VQY9V]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY9V]N
M*"1V97)T<RP@)&-O;&]R+"`D9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@
M("`D=F5R=&EC97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1V97)T
M<R!A<R`D=F5R="D@>PH@("`@("`@("`@("`D=F5R=&EC97-;72`]("1V97)T
M6R=X)UT["B`@("`@("`@("`@("1V97)T:6-E<UM=(#T@)'9E<G1;)WDG73L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D9FEL;"`A/2`G;F]N92<I('L*("`@
M("`@("`@("`@)&8@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL;"D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1F+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&8["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL
M9610;VQY9V]N)RP@87)R87DH)'1H:7,M/E]I;2P@)'9E<G1I8V5S+"!C;W5N
M="@D=F5R=',I+"`D9BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*"1F:6QL(#T]("=N;VYE)R!\?"`D9FEL;"`A/2`D8V]L
M;W(I('L*("`@("`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D
M8V]L;W(I.PH@("`@("`@("`@("!I9B`H:7-?82@D8RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH
M)VEM86=E4&]L>6=O;B<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1V97)T:6-E<RP@
M8V]U;G0H)'9E<G1S*2P@)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<F5C=&%N9VQE+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@(%1H92!L969T
M('@M8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'D@("`@("`@5&AE('1O<"!Y+6-O;W)D:6YA=&4@;V8@=&AE
M(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H
M92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&AE:6=H="`@5&AE(&AE:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&QI;F4@8V]L;W(@;V8@
M=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@
M(%1H92!C;VQO<B!T;R!F:6QL('1H92!R96-T86YG;&4@=VET:"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H+"`D:&5I
M9VAT+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`]("=N;VYE)RD*("`@('L*
M("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@("`@("1F
M(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("!I
M9B`H:7-?82@D9BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D4F5C=&%N9VQE
M)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D>"`K("1W:61T:"P@)'D@
M*R`D:&5I9VAT+"`D9BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*"1F:6QL(#T]("=N;VYE)R!\?"`D9FEL;"`A/2`D8V]L
M;W(I('L*("`@("`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D
M8V]L;W(I.PH@("`@("`@("`@("!I9B`H:7-?82@D8RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH
M)VEM86=E4F5C=&%N9VQE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D
M>"`K("1W:61T:"P@)'D@*R`D:&5I9VAT+"`D8RDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!R
M;W5N9&5D(')E8W1A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A
M;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@
M>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@
M=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W5N9"`@
M(%1H92!W:61T:"!O9B!T:&4@8V]R;F5R(')O=6YD:6YG+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(')E
M8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H92!C
M;VQO<B!T;R!F:6QL('1H92!R;W5N9&5D(')E8W1A;F=L92!W:71H+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R;W5N9&5D4F5C=&%N9VQE*"1X+"`D>2P@)'=I
M9'1H+"`D:&5I9VAT+"`D<F]U;F0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL
M(#T@)VYO;F4G*0H@("`@>PH@("`@("`@(&EF("@D<F]U;F0@/#T@,"D@>PH@
M("`@("`@("`@("`O+R!/<'1I;6EZ92!O=70@86YY(&-A;&QS('=I=&@@;F\@
M8V]R;F5R(')O=6YD:6YG+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)E
M8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R+"`D9FEL
M;"D["B`@("`@("`@?0H*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O
M;&]R*"1C;VQO<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*"B`@("`@
M("`@+R\@4V5T(&-O<FYE<B!P;VEN=',@=&\@879O:60@;&]T<R!O9B!R961U
M;F1A;G0@;6%T:"X*("`@("`@("`D>#$@/2`D>"`K("1R;W5N9#L*("`@("`@
M("`D>3$@/2`D>2`K("1R;W5N9#L*"B`@("`@("`@)'@R(#T@)'@@*R`D=VED
M=&@@+2`D<F]U;F0["B`@("`@("`@)'DR(#T@)'D@*R`D<F]U;F0["@H@("`@
M("`@("1X,R`]("1X("L@)'=I9'1H("T@)')O=6YD.PH@("`@("`@("1Y,R`]
M("1Y("L@)&AE:6=H="`M("1R;W5N9#L*"B`@("`@("`@)'@T(#T@)'@@*R`D
M<F]U;F0["B`@("`@("`@)'DT(#T@)'D@*R`D:&5I9VAT("T@)')O=6YD.PH*
M("`@("`@("`D<B`]("1R;W5N9"`J(#(["@H@("`@("`@("\O($-A;&-U;&%T
M92!T:&4@=7!P97(@;&5F="!A<F,N"B`@("`@("`@)'`Q(#T@)'1H:7,M/E]A
M<F-0;VEN=',H)')O=6YD+"`Q.#`L(#(R-2D["B`@("`@("`@)'`R(#T@)'1H
M:7,M/E]A<F-0;VEN=',H)')O=6YD+"`R,C4L(#(W,"D["@H@("`@("`@("\O
M($-A;&-U;&%T92!T:&4@=7!P97(@<FEG:'0@87)C+@H@("`@("`@("1P,R`]
M("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@,C<P+"`S,34I.PH@("`@("`@
M("1P-"`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@,S$U+"`S-C`I.PH*
M("`@("`@("`O+R!#86QC=6QA=&4@=&AE(&QO=V5R(')I9VAT(&%R8RX*("`@
M("`@("`D<#4@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#`L(#0U*3L*
M("`@("`@("`D<#8@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#0U+"`Y
M,"D["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@;&]W97(@;&5F="!A<F,N
M"B`@("`@("`@)'`W(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`Y,"P@
M,3,U*3L*("`@("`@("`D<#@@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L
M(#$S-2P@,3@P*3L*"B`@("`@("`@+R\@1')A=R!T:&4@8V]R;F5R<R`M('5P
M<&5R(&QE9G0L('5P<&5R(')I9VAT+"!L;W=E<B!R:6=H="P*("`@("`@("`O
M+R!L;W=E<B!L969T+@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI
M<RT^7V-A;&PH)VEM86=E07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@Q+"`D
M>3$L("1R+"`D<BP@,3@P+"`R-S`L("1C*2DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E07)C)RP@
M87)R87DH)'1H:7,M/E]I;2P@)'@R+"`D>3(L("1R+"`D<BP@,C<P+"`S-C`L
M("1C*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D
M=&AI<RT^7V-A;&PH)VEM86=E07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@S
M+"`D>3,L("1R+"`D<BP@,"P@.3`L("1C*2DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E07)C)RP@
M87)R87DH)'1H:7,M/E]I;2P@)'@T+"`D>30L("1R+"`D<BP@.3`L(#$X,"P@
M)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("\O($1R87<@=&AE(&-O;FYE8W1I
M;F<@<VED97,@+2!T;W`L(')I9VAT+"!B;W1T;VTL(&QE9G0N"B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5,:6YE)RP@
M87)R87DH)'1H:7,M/E]I;2P@)'@Q("L@)'`R6R=X,B==+"`D>3$@*R`D<#);
M)WDR)UTL("1X,B`K("1P,ULG>#$G72P@)'DR("L@)'`S6R=Y,2==+"`D8RDI
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M
M/E]C86QL*"=I;6%G94QI;F4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>#(@*R`D
M<#1;)W@R)UTL("1Y,B`K("1P-%LG>3(G72P@)'@S("L@)'`U6R=X,2==+"`D
M>3,@*R`D<#5;)WDQ)UTL("1C*2DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E3&EN92<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1X,R`K("1P-ELG>#(G72P@)'DS("L@)'`V6R=Y,B==
M+"`D>#0@*R`D<#=;)W@Q)UTL("1Y-"`K("1P-ULG>3$G72P@)&,I*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@T("L@)'`X6R=X
M,B==+"`D>30@*R`D<#A;)WDR)UTL("1X,2`K("1P,5LG>#$G72P@)'DQ("L@
M)'`Q6R=Y,2==+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F:6QL
M("$]("=N;VYE)RD@>PH@("`@("`@("`@("`D9B`]("1T:&ES+3YA;&QO8V%T
M94-O;&]R*"1F:6QL*3L*("`@("`@("`@("`@:68@*&ES7V$H)&8L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M
M/E]C86QL*"=I;6%G949I;&Q4;T)O<F1E<B<L(&%R<F%Y*"1T:&ES+3Y?:6TL
M("1X("L@*"1W:61T:"`O(#(I+"`D>2`K("@D:&5I9VAT("\@,BDL("1C+"`D
M9BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($1R87<@82!L:6YE+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1X,"`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@5&AE('D@8V\M;W)D:6YA
M=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("`@
M(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>3$@("`@5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE(&5N9"X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!4:&4@;&EN92!C;VQO<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)'=I9'1H("!4:&4@=VED=&@@;V8@=&AE
M(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;F4H)'@Q+"`D>3$L("1X
M,BP@)'DR+"`D8V]L;W(@/2`G8FQA8VLG+"`D=VED=&@@/2`Q*0H@("`@>PH@
M("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@
M("`@("!I9B`H:7-?82@D8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&,["B`@("`@("`@?0H*("`@("`@("`O+R!$;VXG="!N965D
M('1O(&1O(&%N>71H:6YG('-P96-I86P@9F]R('-I;F=L92UW:61T:"!L:6YE
M<RX*("`@("`@("!I9B`H)'=I9'1H(#T](#$I('L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M
M/E]I;2P@)'@Q+"`D>3$L("1X,BP@)'DR+"`D8RDI.PH@("`@("`@('T@96QS
M96EF("@D>#$@/3T@)'@R*2!["B`@("`@("`@("`@("\O($9O<B!V97)T:6-A
M;"!L:6YE<RP@=V4@8V%N(&IU<W0@9')A=R!A('9E<G1I8V%L"B`@("`@("`@
M("`@("\O(')E8W1A;F=L92X*("`@("`@("`@("`@)&QE9G0@/2`D>#$@+2!F
M;&]O<B@H)'=I9'1H("T@,2D@+R`R*3L*("`@("`@("`@("`@)')I9VAT(#T@
M)'@Q("L@9FQO;W(H)'=I9'1H("\@,BD["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D4F5C=&%N9VQE)RP@87)R87DH
M)'1H:7,M/E]I;2P@)&QE9G0L("1Y,2P@)')I9VAT+"`D>3(L("1C*2D["B`@
M("`@("`@?2!E;'-E:68@*"1Y,2`]/2`D>3(I('L*("`@("`@("`@("`@+R\@
M1F]R(&AO<FEZ;VYT86P@;&EN97,L('=E(&-A;B!J=7-T(&1R87<@82!H;W)I
M>F]N=&%L"B`@("`@("`@("`@("\O(&9I;&QE9"!R96-T86YG;&4N"B`@("`@
M("`@("`@("1T;W`@/2`D>3$@+2!F;&]O<B@D=VED=&@@+R`R*3L*("`@("`@
M("`@("`@)&)O='1O;2`]("1Y,2`K(&9L;V]R*"@D=VED=&@@+2`Q*2`O(#(I
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I
M;&QE9%)E8W1A;F=L92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,2P@)'1O<"P@
M)'@R+"`D8F]T=&]M+"`D8RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O($%N9VQE9"!L:6YE<RX*"B`@("`@("`@("`@("\O($UA:V4@<W5R
M92!T:&%T('1H92!E;F0@<&]I;G1S(&]F('1H92!L:6YE(&%R90H@("`@("`@
M("`@("`O+R!P97)P96YD:6-U;&%R('1O('1H92!L:6YE(&ET<V5L9BX*("`@
M("`@("`@("`@)&$@/2!A=&%N,B@D>3$@+2`D>3(L("1X,B`M("1X,2D["B`@
M("`@("`@("`@("1D>"`]("AS:6XH)&$I("H@)'=I9'1H("\@,BD["B`@("`@
M("`@("`@("1D>2`]("AC;W,H)&$I("H@)'=I9'1H("\@,BD["@H@("`@("`@
M("`@("`D=F5R=',@/2!A<G)A>2@D>#(@*R`D9'@L("1Y,B`K("1D>2P@)'@R
M("T@)&1X+"`D>3(@+2`D9'DL("1X,2`M("1D>"P@)'DQ("T@)&1Y+"`D>#$@
M*R`D9'@L("1Y,2`K("1D>2D["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V-A;&PH)VEM86=E1FEL;&5D4&]L>6=O;B<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL("1V97)T<RP@8V]U;G0H)'9E<G1S*2`O(#(L("1C*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($1R87<@82!D87-H960@;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>#`@("`@("`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H
M92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@("`@("`@
M5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@Q("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T
M:&4@96YD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DQ("`@("`@("`@("!4
M:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]L;W(@("`@("`@("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P
M87)A;2!S=')I;F<@)'=I9'1H("`@("`@("`@5&AE('=I9'1H(&]F('1H92!L
M:6YE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1A<VA?;&5N9W1H("!4:&4@
M;&5N9W1H(&]F(&$@9&%S:"!O;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J($!P
M87)A;2!I;G1E9V5R("1D87-H7W-P86-E("`@5&AE(&QE;F=T:"!O9B!A('-P
M86-E(&EN('1H92!D87-H960@;&EN90H@("`@("HO"B`@("!F=6YC=&EO;B!D
M87-H961,:6YE*"1X,"P@)'DP+"`D>#$L("1Y,2P@)&-O;&]R(#T@)V)L86-K
M)RP@)'=I9'1H(#T@,2P@)&1A<VA?;&5N9W1H(#T@,BP@)&1A<VA?<W!A8V4@
M/2`R*0H@("`@>PH@("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H
M)&-O;&]R*3L*("`@("`@("!I9B`H:7-?82@D8RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&,["B`@("`@("`@?0H@("`@("`@("1W
M(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)W=H:71E)RD["B`@("`@("`@:68@
M*&ES7V$H)'<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1W.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T('5P('1H92!S='EL92!A
M<G)A>2!A8V-O<F1I;F<@=&\@=&AE("1D87-H7RH@<&%R86UE=&5R<RX*("`@
M("`@("`D<W1Y;&4@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1D87-H7VQE;F=T:#L@)&DK*RD@>PH@("`@("`@("`@("`D<W1Y;&5;
M72`]("1C.PH@("`@("`@('T*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M9&%S:%]S<&%C93L@)&DK*RD@>PH@("`@("`@("`@("`D<W1Y;&5;72`]("1W
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES
M+3Y?8V%L;"@G:6UA9V539713='EL92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1S
M='EL92DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@
M)'1H:7,M/E]C86QL*"=I;6%G95-E=%1H:6-K;F5S<R<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1W:61T:"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/E]C86QL*"=I;6%G94QI;F4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>#`L
M("1Y,"P@)'@Q+"`D>3$L($E-1U]#3TQ/4E]35%E,140I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1R87<@82!P;VQY;&EN92`H82!N;VXM8VQO<V5D+"!N
M;VXM9FEL;&5D('!O;'EG;VXI(&)A<V5D(&]N(&$*("`@("`J('-E="!O9B!V
M97)T:6-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'9E<G1I8V5S
M("!!;B!A<G)A>2!O9B!X(&%N9"!Y(&QA8F5L960@87)R87ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`H96<N("1V97)T:6-E<ULP75LG>"==
M+"`D=F5R=&EC97-;,%U;)WDG72P@+BXN*2X*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;&]R("`@(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!L
M:6YE('=I=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@("!4:&4@
M=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EL
M:6YE*"1V97)T<RP@)&-O;&]R+"`D=VED=&@@/2`Q*0H@("`@>PH@("`@("`@
M("1F:7)S="`]('1R=64["B`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S("1V
M97)T*2!["B`@("`@("`@("`@(&EF("@A)&9I<G-T*2!["B`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/FQI;F4H)&QA<W18+"`D
M;&%S=%DL("1V97)T6R=X)UTL("1V97)T6R=Y)UTL("1C;VQO<BP@)'=I9'1H
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&QA<W18(#T@)'9E<G1;)W@G73L*("`@("`@
M("`@("`@)&QA<W19(#T@)'9E<G1;)WDG73L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$<F%W(&%N(&%R8RX*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>"`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!C
M96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@(%1H92!Y(&-O
M+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE(&%R8RX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1S=&%R="`@5&AE('-T87)T(&%N9VQE(&]F('1H92!A<F,N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96YD("`@(%1H92!E;F0@86YG;&4@
M;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@5&AE
M(&QI;F4@8V]L;W(@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!S=')I;F<@
M("1F:6QL("`@5&AE(&9I;&P@8V]L;W(@;V8@=&AE(&%R8R`H9&5F875L=',@
M=&\@;F]N92DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%R8R@D>"P@)'DL("1R
M+"`D<W1A<G0L("1E;F0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL(#T@;G5L
M;"D*("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C
M;VQO<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?;G5L;"@D9FEL;"DI('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?8V%L;"@G:6UA9V5!<F,G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'DL
M("1R("H@,BP@)'(@*B`R+"`D<W1A<G0L("1E;F0L("1C*2D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*"1F:6QL("$]/2`D8V]L;W(I('L*
M("`@("`@("`@("`@("`@("1F(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I
M;&PI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&8L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&8["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@
M)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9$%R8R<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1S=&%R="P@)&5N9"P@)&8L
M($E-1U]!4D-?4$E%*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL
M;&5D07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J(#(L("1R
M("H@,BP@)'-T87)T+"`D96YD+"`D8RP@24U'7T%20U]%1$=%1"!\($E-1U]!
M4D-?3D]&24Q,*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9$%R8R<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1S
M=&%R="P@)&5N9"P@)&,L($E-1U]!4D-?4$E%*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#<F5A=&5S(&%N(&EM86=E(&]F('1H92!G:79E;B!S:7IE
M+@H@("`@("H@268@<&]S<VEB;&4@=&AE(&9U;F-T:6]N(')E='5R;G,@82!T
M<G5E(&-O;&]R(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1W:61T:"`@(%1H92!I;6%G92!W:61T:"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1H96EG:'0@(%1H92!I;6%G92!H96EG:'0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!R97-O=7)C97QO8FIE8W0@4$5!4B!%<G)O<B`@5&AE(&EM86=E
M(&AA;F1L97(@;W(@82!014%27T5R<F]R(&]N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)E]C<F5A=&4H)'=I9'1H+"`D:&5I9VAT*0H@("`@>PH@("`@
M("`@("1R97-U;'0@/2`F)'1H:7,M/E]C86QL*"=I;6%G94-R96%T951R=65#
M;VQO<B<L(&%R<F%Y*"1W:61T:"P@)&AE:6=H="DI.PH@("`@("`@(&EF("@A
M:7-?<F5S;W5R8V4H)')E<W5L="DI('L*("`@("`@("`@("`@)')E<W5L="`]
M("8D=&AI<RT^7V-A;&PH)VEM86=E0W)E871E)RP@87)R87DH)'=I9'1H+"`D
M:&5I9VAT*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5W)A<',@82!C86QL('1O(&$@9G5N8W1I
M;VX@;V8@=&AE(&=D(&5X=&5N<VEO;BX*("`@("`J($EF('1H92!C86QL('!R
M;V1U8V5S(&%N(&5R<F]R+"!A(%!%05)?17)R;W(@:7,@<F5T=7)N960L('1H
M92!F=6YC=&EO;@H@("`@("H@<F5S=6QT(&]T:&5R=VES92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F=6YC=&EO;B`@5&AE(&YA;64@;V8@=&AE
M(&9U;F-T:6]N('1O('=R87`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@("`@06X@87)R87D@=VET:"!A;&P@<&%R86UE=&5R<R!F;W(@=&AA="!F
M=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@
M=&AE(&9U;F-T:6]N(')E<W5L="!O<B!A(%!%05)?17)R;W(@:68@86X@97)R
M;W(*("`@("`J("`@("`@("`@("`@("`@(&]C8W5R960@=VAE;B!E>&5C=71I
M;F<@=&AE(&9U;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7V-A;&PH
M)&9U;F-T:6]N+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!U;G-E
M="@D<&AP7V5R<F]R;7-G*3L*("`@("`@("`D=')A8VL@/2!I;FE?<V5T*"=T
M<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("`D<F5S=6QT(#T@0&-A;&Q?=7-E
M<E]F=6YC7V%R<F%Y*"1F=6YC=&EO;BP@)'!A<F%M<RD["B`@("`@("`@:68@
M*"1T<F%C:R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:6YI7W-E="@G=')A
M8VM?97)R;W)S)RP@)'1R86-K*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D<&AP7V5R<F]R;7-G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@)')E<W5L="`](%!%05(Z.G)A
M:7-E17)R;W(H)&9U;F-T:6]N("X@)SH@)R`N("1P:'!?97)R;W)M<V<I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O:6TN<&AP
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,W,S0V`#$P
M-3$U-#,Q,#8P`#`R,#,W,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]);6%G
M92YP:'`G.PH*+RHJ"B`J(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4@2&]R
M9&5?26UA9V4Z.B!!4$D@9F]R($EM86=E36%G:6-K+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]);6%G92]);6%G92]I;2YP:'`L=B`Q+C,T+C$P+C$Q(#(P
M,#8O,#$O,#$@,C$Z,C@Z,C(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?26UA9V4*("HO"F-L
M87-S($AO<F1E7TEM86=E7VEM(&5X=&5N9',@2&]R9&5?26UA9V4@>PH*("`@
M("\J*@H@("`@("H@0V%P86)I;&ET97,@;V8@=&AI<R!D<FEV97(N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C87!A8FEL
M:71I97,@/2!A<G)A>2@G<F5S:7IE)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=C<F]P)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R;W1A=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V=R87ES8V%L92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9FQI<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6ER<F]R
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S97!I82<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V%N=F%S)PH@("`@("`@
M("`@("`@("`@("`@("`@("`@*3L*"B`@("`O*BH*("`@("`J(%=H870@:VEN
M9"!O9B!I;6%G97,@<VAO=6QD($EM86=E36%G:6-K(&=E;F5R871E/R!$969A
M=6QT<R!T;R`G<&YG)RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]T>7!E(#T@)W!N9R<["@H@("`@+RHJ"B`@("`@*B!/
M<&5R871I;VYS('1O(&)E('!E<F9O<FUE9"X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]P97)A=&EO;G,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!S=')O:V4@8V]L;W([(&-A8VAE
M9"!S;R!W92!D;VXG="!I<W-U92!M;W)E("US=')O:V4@8V]M;6%N9',*("`@
M("`J('1H86X@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7W-T<F]K94-O;&]R(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J($-U<G)E;G0@<W1R;VME('=I9'1H.R!C86-H960@<V\@=V4@
M9&]N)W0@:7-S=64@;6]R92`M<W1R;VME=VED=&@*("`@("`J(&-O;6UA;F1S
M('1H86X@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W-T<F]K95=I9'1H(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($-U<G)E;G0@9FEL;"!C;VQO<CL@8V%C:&5D('-O('=E(&1O;B=T
M(&ES<W5E(&UO<F4@+69I;&P@8V]M;6%N9',@=&AA;@H@("`@("H@;F5C97-S
M87)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V9I;&Q#;VQO<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?26UA9V5?:6TH)'!A
M<F%M<RD*("`@('L*("`@("`@("!P87)E;G0Z.DAO<F1E7TEM86=E*"1P87)A
M;7,I.PH*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)W1Y<&4G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'!A<F%M<ULG='EP92==.PH@
M("`@("`@('T*"B`@("`@("`@+R\@36%K92!S=7)E('=E('-T87)T('=I=&@@
M82!W:&ET92!B86-K9W)O=6YD('1O(&)E(&-O;G-I<W1E;G0*("`@("`@("`O
M+R!W:71H(&]T:&5R(&1R:79E<G,N"B`@("`@("`@:68@*"%E;7!T>2@D<&%R
M86US6R=B86-K9W)O=6YD)UTI*2!["B`@("`@("`@("`@("1B9R`]("1P87)A
M;7-;)V)A8VMG<F]U;F0G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D8F<@/2`G=VAI=&4G.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^<F5C
M=&%N9VQE*#`L(#`L("1T:&ES+3Y?=VED=&@L("1T:&ES+3Y?:&5I9VAT+"`D
M8F<L("1B9RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&-O
M;G1E;G0@='EP92!F;W(@=&AI<R!I;6%G92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!F;W(@=&AI<R!I;6%G92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]N=&5N=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G:6UA9V4O)R`N("1T:&ES+3Y?='EP93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')A=R!D871A(&9O<B!T:&ES
M(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1C;VYV97)T
M("!)9B!T<G5E+"!T:&4@:6UA9V4@9&%T82!W:6QL(&)E(')E='5R;F5D(&EN
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1A<F=E="!F
M;W)M870L(&EN9&5P96YD96YT;'D@9G)O;2!A;GD@:6UA9V4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!O<&5R871I;VYS+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&EM86=E(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')A=R@D8V]N=F5R="`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7V1A=&$I*2!["B`@("`@("`@("`@("\O($EF('1H97)E(&%R92!N;R!O
M<&5R871I;VYS+"!A;F0@=V4@86QR96%D>2!H879E(&1A=&$L"B`@("`@("`@
M("`@("\O(&1O;B=T(&)O=&AE<B!W<FET:6YG(&]U="!F:6QE<RP@:G5S="!R
M971U<FX@=&AE(&-U<G)E;G0*("`@("`@("`@("`@+R\@9&%T82X*("`@("`@
M("`@("`@:68@*"$D8V]N=F5R="`F)B`A8V]U;G0H)'1H:7,M/E]O<&5R871I
M;VYS*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T83L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1M<&EN(#T@)'1H:7,M/G1O
M1FEL92@D=&AI<RT^7V1A=&$I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O($-R96%T92!A;B!E;7!T>2!04$T@9FEL92!T;R!L;V%D+@H@("`@
M("`@("`@("`D=&UP:6X@/2!5=&EL.CIG971496UP1FEL92@G:6UG)RP@9F%L
M<V4L("1T:&ES+3Y?=&UP9&ER*3L*("`@("`@("`@("`@)&9P(#T@9F]P96XH
M)'1M<&EN+"`G=V(G*3L*("`@("`@("`@("`@9G=R:71E*"1F<"P@<W!R:6YT
M9B@B4#-<;B5D("5D7&XR-35<;B`B+"`D=&AI<RT^7W=I9'1H+"`D=&AI<RT^
M7VAE:6=H="DI.PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]
M"@H@("`@("`@("1T;7!O=70@/2!5=&EL.CIG971496UP1FEL92@G:6UG)RP@
M9F%L<V4L("1T:&ES+3Y?=&UP9&ER*3L*"B`@("`@("`@)&-O;6UA;F0@(#T@
M)&-O;F9;)VEM86=E)UU;)V-O;G9E<G0G73L*("`@("`@("`D8V]M;6%N9"`N
M/2`G("<@+B!I;7!L;V1E*"<@)RP@)'1H:7,M/E]O<&5R871I;VYS*3L*("`@
M("`@("`D8V]M;6%N9"`N/2`G("(G("X@)'1M<&EN("X@)R(@*W!R;V9I;&4@
M(BHB("<@+B`D=&AI<RT^7W1Y<&4@+B`G.B(G("X@)'1M<&]U="`N("<B(#(^
M)C$G.PH*("`@("`@("!E>&5C*"1C;VUM86YD+"`D;W5T<'5T+"`D<F5T=F%L
M*3L*"B`@("`@("`@)'1H:7,M/E]D871A(#T@9FEL95]G971?8V]N=&5N=',H
M)'1M<&]U="D["@H@("`@("`@($!U;FQI;FLH)'1M<&EN*3L*("`@("`@("!`
M=6YL:6YK*"1T;7!O=70I.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5S970@=&AE(&EM86=E(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T*"D*("`@('L*("`@("`@("!P
M87)E;G0Z.G)E<V5T*"D["B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS(#T@
M87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<VEZ92!T:&4@8W5R
M<F5N="!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED
M=&@@("!4:&4@;F5W('=I9'1H+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE
M:6=H="`@5&AE(&YE=R!H96EG:'0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F%T:6\@("!-86EN=&%I;B!O<FEG:6YA;"!A<W!E8W0@<F%T:6\N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E<VEZ92@D=VED=&@L("1H96EG:'0L("1R871I
M;R`]('1R=64I"B`@("!["B`@("`@("`@:68@*"1R871I;RD@>PH@("`@("`@
M("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M<VEZ92![)'=I9'1H?7A[
M)&AE:6=H='T@+7)E<VEZ92![)'=I9'1H?7A[)&AE:6=H='TB.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@
M(BUS:7IE('LD=VED=&A]>'LD:&5I9VAT?2`M<F5S:7IE('LD=VED=&A]>'LD
M:&5I9VAT?2$B.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R
M;W`@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'@Q("!4:&4@=&]P(&QE9G0@8V]R;F5R(&]F('1H92!C<F]P<&5D
M(&EM86=E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DQ("!4:&4@=&]P(')I
M9VAT(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1X,B`@5&AE(&)O='1O;2!L969T(&-O<FYE<B!O9B!T:&4@
M8W)O<'!E9"!I;6%G92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,B`@5&AE
M(&)O='1O;2!R:6=H="!C;W)N97(@;V8@=&AE(&-R;W!P960@:6UA9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-R;W`H)'@Q+"`D>3$L("1X,BP@)'DR*0H@
M("`@>PH@("`@("`@("1L:6YE(#T@*"1X,B`M("1X,2D@+B`G>"<@+B`H)'DR
M("T@)'DQ*2`N("<K)R`N("1X,2`N("<K)R`N("1Y,CL*("`@("`@("`D=&AI
M<RT^7V]P97)A=&EO;G-;72`]("<M8W)O<"`G("X@)&QI;F4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2;W1A=&4@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%N9VQE("`@("`@(%1H92!A;F=L
M92!T;R!R;W1A=&4@=&AE(&EM86=E(&)Y+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EN('1H92!C;&]C:W=I<V4@9&ER96-T:6]N+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&)A8VMG<F]U;F0@(%1H92!B86-K9W)O
M=6YD(&-O;&]R('1O(&9I;&P@86YY('1R:6%N9VQE<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F]T871E*"1A;F=L92P@)&)A8VMG<F]U;F0@/2`G=VAI=&4G
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUR;W1A
M=&4@>R1A;F=L97T@+6)A8VMG<F]U;F0@)&)A8VMG<F]U;F0B.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1FQI<"!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9FQI<"@I"B`@("!["B`@("`@("`@)'1H:7,M/E]O
M<&5R871I;VYS6UT@/2`G+69L:7`G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M36ER<F]R('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!M:7)R;W(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=
M(#T@)RUF;&]P)SL*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE
M(&-U<G)E;G0@:6UA9V4@=&\@9W)A>7-C86QE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G<F%Y<V-A;&4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T
M:6]N<UM=(#T@)RUC;VQO<G-P86-E($=205D@+6-O;&]R<R`R-38G.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5P:6$@9FEL=&5R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S97!I82@I"B`@("!["B`@("`@("`@)'1H:7,M/E]O<&5R871I
M;VYS6UT@/2`G+6UO9'5L871E(#$Q,"`M8V]L;W)S<&%C92!'4D%9("UC;VQO
M<G,@,C4V("UG86UM82`Q+C(U+S$O,"XV-B<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$<F%W<R!A('1E>'0@<W1R:6YG(&]N('1H92!I;6%G92!I;B!A('-P
M96-I9FEE9"!L;V-A=&EO;BP@=VET:`H@("`@("H@=&AE('-P96-I9FEE9"!S
M='EL92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D=&5X="`@("`@("!4:&4@=&5X="!T;R!D<F%W+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@@("`@("`@("`@5&AE(&QE9G0@>"!C;V]R9&EN871E(&]F
M('1H92!S=&%R="!O9B!T:&4@=&5X="!S=')I;F<N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>2`@("`@("`@("!4:&4@=&]P('D@8V]O<F1I;F%T92!O9B!T
M:&4@<W1A<G0@;V8@=&AE('1E>'0@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&9O;G0@("`@("`@5&AE(&9O;G0@:61E;G1I9FEE<B!Y;W4@=V%N
M="!T;R!U<V4@9F]R('1H92!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&-O;&]R("`@("`@5&AE(&-O;&]R('1H870@>6]U('=A;G0@=&AE('1E>'0@
M9&ES<&QA>65D(&EN+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO
M;B`@06X@:6YT96=E<B!T:&%T('-P96-I9FEE<R!T:&4@;W)I96YT871I;VX@
M;V8@=&AE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('1E>'0H)'-T<FEN
M9RP@)'@L("1Y+"`D9F]N="`]("=?<V%N<R<L("1C;VQO<B`]("=B;&%C:R<L
M("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("1T:&ES+3YS9713=')O
M:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1T:&ES+3YS9713=')O:V57:61T
M:"@Q*3L*"B`@("`@("`@)'-T<FEN9R`](&%D9'-L87-H97,H)R(G("X@)'-T
M<FEN9R`N("<B)RD["B`@("`@("`@)'D@/2`D>2`K(#$R.PH@("`@("`@("1T
M:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB=&5X="`D>"PD>2`D<W1R
M:6YG7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&-I<F-L92X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@5&AE('@@8V]O
M<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'D@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1R("`@("!4:&4@<F%D:75S(&]F('1H92!C:7)C
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@5&AE(&QI;F4@8V]L
M;W(@;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@
M("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@8VER8VQE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C:7)C;&4H)'@L("1Y+"`D<BP@)&-O;&]R+"`D9FEL;"`]("=N
M;VYE)RD*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O
M;&]R*3L*("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F:6QL*3L*"B`@
M("`@("`@)'A-87@@/2`D>"`K("1R.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T
M:6]N<UM=(#T@(BUD<F%W(%PB8VER8VQE("1X+"1Y("1X36%X+"1Y7"(B.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A('!O;'EG;VX@8F%S960@;VX@
M82!S970@;V8@=F5R=&EC97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1V97)T:6-E<R`@06X@87)R87D@;V8@>"!A;F0@>2!L86)E;&5D(&%R<F%Y
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@*&5G+B`D=F5R=&EC
M97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL("XN+BDN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@8V]L;W(@>6]U('=A;G0@=&\@
M9')A=R!T:&4@<&]L>6=O;B!W:71H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE('!O;'EG;VXN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!O;'EG;VXH)'9E<G1S+"`D8V]L;W(L("1F:6QL
M(#T@)VYO;F4G*0H@("`@>PH@("`@("`@("1T:&ES+3YS9713=')O:V5#;VQO
M<B@D8V]L;W(I.PH@("`@("`@("1T:&ES+3YS971&:6QL0V]L;W(H)&9I;&PI
M.PH*("`@("`@("`D8V]M;6%N9"`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1V
M97)T<R!A<R`D=F5R="D@>PH@("`@("`@("`@("`D8V]M;6%N9"`N/2!S<')I
M;G1F*"<@)60L)60G+"`D=F5R=%LG>"==+"`D=F5R=%LG>2==*3L*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")P
M;VQY9V]N("1C;VUM86YD7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A
M=R!A(')E8W1A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC
M;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE
M(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H
M92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N
M9VQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96-T86YG;&4H)'@L("1Y+"`D
M=VED=&@L("1H96EG:'0L("1C;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("![
M"B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R*"1C;VQO<BD["B`@("`@
M("`@)'1H:7,M/G-E=$9I;&Q#;VQO<B@D9FEL;"D["@H@("`@("`@("1X36%X
M(#T@)'@@*R`D=VED=&@["B`@("`@("`@)'E-87@@/2`D>2`K("1H96EG:'0[
M"B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")R96-T
M86YG;&4@)'@L)'D@)'A-87@L)'E-87A<(B(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$<F%W(&$@<F]U;F1E9"!R96-T86YG;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE9G0@>"UC;V]R9&EN871E
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@
M("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H
M92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4
M:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<F]U;F0@("!4:&4@=VED=&@@;V8@=&AE(&-O<FYE<B!R;W5N9&EN
M9RX*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@(%1H92!L:6YE(&-O
M;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M9FEL;"`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F]U;F1E9"!R96-T86YG
M;&4@=VET:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]U;F1E9%)E8W1A;F=L
M92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)')O=6YD+"`D8V]L;W(L("1F
M:6QL*0H@("`@>PH@("`@("`@("1T:&ES+3YS9713=')O:V5#;VQO<B@D8V]L
M;W(I.PH@("`@("`@("1T:&ES+3YS971&:6QL0V]L;W(H)&9I;&PI.PH*("`@
M("`@("`D>#$@/2`D>"`K("1W:61T:#L*("`@("`@("`D>3$@/2`D>2`K("1H
M96EG:'0["B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@
M7")R;W5N9%)E8W1A;F=L92`D>"PD>2`D>#$L)'DQ+"`D<F]U;F0L)')O=6YD
M7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&QI;F4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@P("`@("!4:&4@>"!C;V]R9&EN
M871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,"`@
M("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>#$@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&5N
M9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@("`@5&AE('D@8V]O<F1I
M;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@
M("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A;2!S=')I;F<@)'=I9'1H
M("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L:6YE*"1X,"P@)'DP+"`D>#$L("1Y,2P@)&-O;&]R(#T@)V)L86-K)RP@
M)'=I9'1H(#T@,2D*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L
M;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME5VED=&@H)'=I
M9'1H*3L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<
M(FQI;F4@)'@P+"1Y,"`D>#$L)'DQ7"(B.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1')A=R!A(&1A<VAE9"!L:6YE+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1X,"`@("`@("`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE
M('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DP("`@("`@("`@("!4
M:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>#$@("`@("`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H
M92!E;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@("`@("`@("`@(%1H
M92!Y(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;VQO<B`@("`@("`@(%1H92!L:6YE(&-O;&]R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=VED=&@@("`@("`@("!4:&4@=VED=&@@;V8@=&AE(&QI
M;F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&%S:%]L96YG=&@@(%1H92!L
M96YG=&@@;V8@82!D87-H(&]N('1H92!D87-H960@;&EN90H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&1A<VA?<W!A8V4@("!4:&4@;&5N9W1H(&]F(&$@<W!A
M8V4@:6X@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A
M<VAE9$QI;F4H)'@P+"`D>3`L("1X,2P@)'DQ+"`D8V]L;W(@/2`G8FQA8VLG
M+"`D=VED=&@@/2`Q+"`D9&%S:%]L96YG=&@@/2`R+"`D9&%S:%]S<&%C92`]
M(#(I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R*"1C;VQO
M<BD["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K95=I9'1H*"1W:61T:"D["B`@
M("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")L:6YE("1X
M,"PD>3`@)'@Q+"1Y,5PB(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@
M82!P;VQY;&EN92`H82!N;VXM8VQO<V5D+"!N;VXM9FEL;&5D('!O;'EG;VXI
M(&)A<V5D(&]N(&$*("`@("`J('-E="!O9B!V97)T:6-E<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'9E<G1I8V5S("!!;B!A<G)A>2!O9B!X(&%N
M9"!Y(&QA8F5L960@87)R87ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`H96<N("1V97)T:6-E<ULP75LG>"==+"`D=F5R=&EC97-;,%U;)WDG
M72P@+BXN*2X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!C
M;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!L:6YE('=I=&@N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1W:61T:"`@("!4:&4@=VED=&@@;V8@=&AE(&QI;F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EL:6YE*"1V97)T<RP@)&-O;&]R
M+"`D=VED=&@@/2`Q*0H@("`@>PH@("`@("`@("1T:&ES+3YS9713=')O:V5#
M;VQO<B@D8V]L;W(I.PH@("`@("`@("1T:&ES+3YS9713=')O:V57:61T:"@D
M=VED=&@I.PH@("`@("`@("1T:&ES+3YS971&:6QL0V]L;W(H)VYO;F4G*3L*
M"B`@("`@("`@)&-O;6UA;F0@/2`G)SL*("`@("`@("!F;W)E86-H("@D=F5R
M=',@87,@)'9E<G0I('L*("`@("`@("`@("`@)&-O;6UA;F0@+CT@<W!R:6YT
M9B@G("5D+"5D)RP@)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB<&]L
M>6QI;F4@)&-O;6UA;F1<(B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W
M(&%N(&%R8RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@
M(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1Y("`@("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@8V5N
M=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'(@("`@("!4:&4@<F%D:75S
M(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H
M92!S=&%R="!A;F=L92!O9B!T:&4@87)C+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&5N9"`@("!4:&4@96YD(&%N9VQE(&]F('1H92!A<F,N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D8V]L;W(@(%1H92!L:6YE(&-O;&]R(&]F('1H92!A
M<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL;"`@(%1H92!F:6QL(&-O
M;&]R(&]F('1H92!A<F,@*&1E9F%U;'1S('1O(&YO;F4I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A<F,H)'@L("1Y+"`D<BP@)'-T87)T+"`D96YD+"`D8V]L
M;W(@/2`G8FQA8VLG+"`D9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("`D
M=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^
M<V5T1FEL;$-O;&]R*"1F:6QL*3L*"B`@("`@("`@+R\@4W!L:70@=7`@87)C
M<R!G<F5A=&5R('1H86X@,3@P(&1E9W)E97,@:6YT;R!T=V\@<&EE8V5S+@H@
M("`@("`@("1M:60@/2!R;W5N9"@H)'-T87)T("L@)&5N9"D@+R`R*3L*("`@
M("`@("`D>"`](')O=6YD*"1X*3L*("`@("`@("`D>2`](')O=6YD*"1Y*3L*
M("`@("`@("`D<B`](')O=6YD*"1R*3L*("`@("`@("!I9B`H)&UI9"`^(#DP
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W
M(%PB96QL:7!S92`D>"PD>2`D<BPD<B`D<W1A<G0L)&UI9%PB(CL*("`@("`@
M("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")E;&QI<'-E
M("1X+"1Y("1R+"1R("1M:60L)&5N9%PB(CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<(F5L
M;&EP<V4@)'@L)'D@)'(L)'(@)'-T87)T+"1E;F1<(B(["B`@("`@("`@?0H*
M("`@("`@("`O+R!)9B!F:6QL960L(&1R87<@=&AE(&]U=&QI;F4N"B`@("`@
M("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@("`@("`@("`@;&ES="@D>#$L
M("1Y,2D@/2`D=&AI<RT^7V-I<F-L95!O:6YT*"1S=&%R="P@)'(@*B`R*3L*
M("`@("`@("`@("`@;&ES="@D>#(L("1Y,BD@/2`D=&AI<RT^7V-I<F-L95!O
M:6YT*"1M:60L("1R("H@,BD["B`@("`@("`@("`@(&QI<W0H)'@S+"`D>3,I
M(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D96YD+"`D<B`J(#(I.PH*("`@("`@
M("`@("`@+R\@5&AI<R!S965M<R!T;R!R97-U;'0@:6X@<VQI9VAT;'D@8F5T
M=&5R('!L86-E;65N="!O9@H@("`@("`@("`@("`O+R!P:64@<VQI8V5S+@H@
M("`@("`@("`@("`D>"LK.PH@("`@("`@("`@("`D>2LK.PH*("`@("`@("`@
M("`@)'9E<G1S(#T@87)R87DH87)R87DH)W@G(#T^("1X("L@)'@S+"`G>2<@
M/3X@)'D@*R`D>3,I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=X)R`]/B`D>"`K("1X,2P@)WDG(#T^("1Y("L@)'DQ
M*2D["@H@("`@("`@("`@("!I9B`H)&UI9"`^(#DP*2!["B`@("`@("`@("`@
M("`@("`D=F5R=',Q(#T@87)R87DH87)R87DH)W@G(#T^("1X("L@)'@R+"`G
M>2<@/3X@)'D@*R`D>3(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G>"<@/3X@)'@@*R`D>#$L("=Y
M)R`]/B`D>2`K("1Y,2DI.PH@("`@("`@("`@("`@("`@)'9E<G1S,B`](&%R
M<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X,RP@)WDG(#T^("1Y("L@)'DS*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G>"<@/3X@
M)'@L("=Y)R`]/B`D>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W@G(#T^("1X("L@)'@R+"`G>2<@/3X@)'D@*R`D>3(I*3L*
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]L>6=O;B@D=F5R=',Q+"`D9FEL
M;"P@)&9I;&PI.PH@("`@("`@("`@("`@("`@)'1H:7,M/G!O;'EG;VXH)'9E
M<G1S,BP@)&9I;&PL("1F:6QL*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YP;VQY9V]N*"1V97)T<RP@)&9I;&PL("1F
M:6QL*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/G!O;'EL
M:6YE*"1V97)T<RP@)&-O;&]R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&%N9V4@=&AE(&-U<G)E;G0@<W1R;VME(&-O;&]R+B!7:6QL
M(&]N;'D@869F96-T('1H92!C;VUM86YD"B`@("`@*B!S=')I;F<@:68@)'-T
M<F]K92!I<R!D:69F97)E;G0@9G)O;2!T:&4@<')E=FEO=7,@<W1R;VME(&-O
M;&]R"B`@("`@*B`H<W1O<F5D(&EN("1T:&ES+3Y?<W1R;VME0V]L;W(I+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-E92`D7W-T
M<F]K94-O;&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@
M(%1H92!N97<@<W1R;VME(&-O;&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M9713=')O:V5#;VQO<B@D8V]L;W(I"B`@("!["B`@("`@("`@:68@*"1C;VQO
M<B`A/2`D=&AI<RT^7W-T<F]K94-O;&]R*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W!E<F%T:6]N<UM=(#T@(BUS=')O:V4@)&-O;&]R(CL*("`@("`@("`@
M("`@)'1H:7,M/E]S=')O:V5#;VQO<B`]("1C;VQO<CL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE(&-U<G)E;G0@<W1R;VME
M('=I9'1H+B!7:6QL(&]N;'D@869F96-T('1H92!C;VUM86YD"B`@("`@*B!S
M=')I;F<@:68@)'=I9'1H(&ES(&1I9F9E<F5N="!F<F]M('1H92!P<F5V:6]U
M<R!S=')O:V4@=VED=&@*("`@("`J("AS=&]R960@:6X@)'1H:7,M/E]S=')O
M:V57:61T:"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`<V5E("1?<W1R;VME"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=VED=&@@(%1H92!N97<@<W1R;VME('=I9'1H+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S9713=')O:V57:61T:"@D=VED=&@I"B`@("!["B`@("`@("`@:68@
M*"1W:61T:"`A/2`D=&AI<RT^7W-T<F]K95=I9'1H*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUS=')O:V5W:61T:"`D=VED=&@B
M.PH@("`@("`@("`@("`D=&AI<RT^7W-T<F]K95=I9'1H(#T@)'=I9'1H.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG92!T:&4@8W5R
M<F5N="!F:6QL(&-O;&]R+B!7:6QL(&]N;'D@869F96-T('1H92!C;VUM86YD
M"B`@("`@*B!S=')I;F<@:68@)&-O;&]R(&ES(&1I9F9E<F5N="!F<F]M('1H
M92!P<F5V:6]U<R!F:6QL(&-O;&]R"B`@("`@*B`H<W1O<F5D(&EN("1T:&ES
M+3Y?9FEL;$-O;&]R*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!S964@)%]F:6QL"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]L;W(@(%1H92!N97<@9FEL;"!C;VQO<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T1FEL;$-O;&]R*"1C;VQO<BD*("`@('L*("`@("`@("!I9B`H
M)&-O;&]R("$]("1T:&ES+3Y?9FEL;$-O;&]R*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUF:6QL("1C;VQO<B(["B`@("`@("`@
M("`@("1T:&ES+3Y?9FEL;$-O;&]R(#T@)&-O;&]R.PH@("`@("`@('T*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O26UA9V4O<&YG+G!H<```````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$U-3,R`#$P-3$U-#,Q,#8P`#`R,#4T,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]);6%G92YP:'`G
M.PH*+RHJ"B`J(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4@2&]R9&5?26UA
M9V4Z.B!!4$D@9F]R(%!.1R!I;6%G97,N($ET"B`J(&UA:6YL>2!P<F]V:61E
M<R!S;VUE('5T:6QI='D@9G5N8W1I;VYS+"!S=6-H(&%S('1H92!A8FEL:71Y
M('1O(&UA:V4*("H@<&EX96QS(&]R('-O;&ED(&EM86=E<R!F;W(@;F]W+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92]);6%G92]P;F<N<&AP+'8@
M,2XQ.2XQ,"XX(#(P,#8O,#4O,S$@,3<Z,#8Z,S8@<V5L<VMY($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]);6%G90H@*B\*
M8VQA<W,@2&]R9&5?26UA9V5?<&YG(&5X=&5N9',@2&]R9&5?26UA9V4@>PH*
M("`@("\J*@H@("`@("H@5&AE(&%R<F%Y(&]F('!I>&5L(&1A=&$N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]I;6<@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]L;W(@9&5P=&@@*&]N;'D@."!A
M;F0@,38@:6UP;&5M96YT960I+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]C;VQO<D1E<'1H(#T@.#L*"B`@("`O*BH*
M("`@("`J($-O;&]R('1Y<&4@*&]N;'D@,B`H=')U92!C;VQO<BD@:6UP;&5M
M96YT960I+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]C;VQO<E1Y<&4@/2`R.PH*("`@("\J*@H@("`@("H@0V]M<')E
M<W-I;VX@;65T:&]D("@P(&ES('1H92!O;FQY(&-U<G)E;G0@=F%L:60@=F%L
M=64I+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V
M87(@)%]C;VUP<F5S<VEO;DUE=&AO9"`](#`["@H@("`@+RHJ"B`@("`@*B!&
M:6QT97(@;65T:&]D("@P(&ES('1H92!O;FQY(&-U<G)E;G0@=F%L:60@=F%L
M=64I+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V
M87(@)%]F:6QT97)-971H;V0@/2`P.PH*("`@("\J*@H@("`@("H@26YT97)L
M86-E(&UE=&AO9"`H;VYL>2`P("AN;R!I;G1E<FQA8V4I(&EM<&QE;65N=&5D
M*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1?:6YT97)L86-E365T:&]D(#T@,#L*"B`@("`O*BH*("`@("`J(%!.1R!I
M;6%G92!C;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?
M26UA9V5?<&YG*"1P87)A;7,I"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D
M95]);6%G92@D<&%R86US*3L*"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US
M6R=W:61T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F5C=&%N9VQE*#`L
M(#`L("1P87)A;7-;)W=I9'1H)UTL("1P87)A;7-;)VAE:6=H="==+"`D=&AI
M<RT^7V)A8VMG<F]U;F0L("1T:&ES+3Y?8F%C:V=R;W5N9"D["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14>7!E*"D*("`@('L*
M("`@("`@("!R971U<FX@)VEM86=E+W!N9R<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE(')A=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&EM86=E(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')A=R@I"B`@("!["B`@("`@("`@<F5T
M=7)N"B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R*"D@+@H@("`@("`@("`@
M("`D=&AI<RT^7TE(1%(H*2`N"@H@("`@("`@("`@("`O*B!387D@=VAA="!C
M<F5A=&5D('1H92!I;6%G92!F:6QE+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M7W1%6'0H)U-O9G1W87)E)RP@)TAO<F1E($9R86UE=V]R:R!);6%G95]P;F<@
M0VQA<W,G*2`N"@H@("`@("`@("`@("`O*B!3970@=&AE(&QA<W0@;6]D:69I
M960@9&%T92]T:6UE+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W1)344H*2`N
M"@H@("`@("`@("`@("`D=&AI<RT^7TE$050H*2`N"B`@("`@("`@("`@("1T
M:&ES+3Y?245.1"@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5S970@=&AE
M(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T*"D*("`@
M('L*("`@("`@("!P87)E;G0Z.G)E<V5T*"D["B`@("`@("`@)'1H:7,M/E]I
M;6<@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E
M8W1A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@
M("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN
M871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A
M;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!L:6YE
M(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE('=I
M=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8W1A;F=L92@D>"P@)'DL("1W
M:61T:"P@)&AE:6=H="P@)&-O;&]R(#T@)V)L86-K)RP@)&9I;&P@/2`G;F]N
M92<I"B`@("!["B`@("`@("`@;&ES="@D<BP@)&<L("1B*2`]("1T:&ES+3YG
M97121T(H)&-O;&]R*3L*("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2![
M"B`@("`@("`@("`@(&QI<W0H)&92+"`D9D<L("1F0BD@/2`D=&AI<RT^9V5T
M4D="*"1F:6QL*3L*("`@("`@("!]"@H@("`@("`@("1X,B`]("1X("L@)'=I
M9'1H.PH@("`@("`@("1Y,B`]("1Y("L@)&AE:6=H=#L*"B`@("`@("`@9F]R
M("@D:"`]("1Y.R`D:"`\/2`D>3([("1H*RLI('L*("`@("`@("`@("`@9F]R
M("@D=R`]("1X.R`D=R`\/2`D>#([("1W*RLI('L*("`@("`@("`@("`@("`@
M("\O(%-E92!I9B!W92=R92!O;B!A;B!E9&=E+@H@("`@("`@("`@("`@("`@
M:68@*"1W(#T]("1X('Q\("1H(#T]("1Y('Q\("1W(#T]("1X,B!\?"`D:"`]
M/2`D>3(I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM9ULD:%U;
M)'==(#T@87)R87DH)W(G(#T^("1R+"`G9R<@/3X@)&<L("=B)R`]/B`D8BD[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&9I;&P@(3T@)VYO;F4G*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;6=;)&A=6R1W72`](&%R
M<F%Y*"=R)R`]/B`D9E(L("=G)R`]/B`D9D<L("=B)R`]/B`D9D(I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E('1H92!03D<@9FEL92!H96%D97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]H96%D97(H*0H@("`@>PH@("`@("`@(')E
M='5R;B!P86-K*"=#0T-#0T-#0R<L(#$S-RP@.#`L(#<X+"`W,2P@,3,L(#$P
M+"`R-BP@,3`I.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E($EM86=E
M($AE861E<B!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7TE(1%(H*0H@
M("`@>PH@("`@("`@("1D871A(#T@<&%C:R@G831.3D-#0T-#)RP@)TE(1%(G
M+"`D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H="P@)'1H:7,M/E]C;VQO
M<D1E<'1H+"`D=&AI<RT^7V-O;&]R5'EP92P@)'1H:7,M/E]C;VUP<F5S<VEO
M;DUE=&AO9"P@)'1H:7,M/E]F:6QT97)-971H;V0L("1T:&ES+3Y?:6YT97)L
M86-E365T:&]D*3L*("`@("`@("!R971U<FX@<&%C:R@G3F$G("X@<W1R;&5N
M*"1D871A*2`N("=.)RP@<W1R;&5N*"1D871A*2`M(#0L("1D871A+"!C<F,S
M,B@D9&%T82DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E($E%3D0@
M8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%])14Y$*"D*("`@('L*("`@
M("`@("`D9&%T82`]("=)14Y$)SL*("`@("`@("!R971U<FX@<&%C:R@G3F$G
M("X@<W1R;&5N*"1D871A*2`N("=.)RP@<W1R;&5N*"1D871A*2`M(#0L("1D
M871A+"!C<F,S,B@D9&%T82DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E($EM86=E($1A=&$@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%])
M1$%4*"D*("`@('L*("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("1P<F5V
M<V-A;FQI;F4@/2!N=6QL.PH@("`@("`@("1F:6QT97(@/2`P.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1T:&ES+3Y?:&5I9VAT.R`D:2LK*2!["B`@
M("`@("`@("`@("1S8V%N;&EN92`](&%R<F%Y*"D["B`@("`@("`@("`@("1D
M871A("X](&-H<B@D9FEL=&5R*3L*("`@("`@("`@("`@9F]R("@D:B`](#`[
M("1J(#P@)'1H:7,M/E]W:61T:#L@)&HK*RD@>PH@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8V]L;W)$97!T:"`]/2`X*2!["B`@("`@("`@("`@("`@
M("`@("`@)'-C86YL:6YE6R1J72`]('!A8VLH)T-#0R<L("1T:&ES+3Y?:6UG
M6R1I75LD:EU;)W(G72P@)'1H:7,M/E]I;6=;)&E=6R1J75LG9R==+"`D=&AI
M<RT^7VEM9ULD:5U;)&I=6R=B)UTI.PH@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1T:&ES+3Y?8V]L;W)$97!T:"`]/2`Q-BD@>PH@("`@("`@("`@("`@
M("`@("`@("1S8V%N;&EN95LD:ET@/2!P86-K*"=N;FXG+"`D=&AI<RT^7VEM
M9ULD:5U;)&I=6R=R)UT@/#P@."P@)'1H:7,M/E]I;6=;)&E=6R1J75LG9R==
M(#P\(#@L("1T:&ES+3Y?:6UG6R1I75LD:EU;)V(G72`\/"`X*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)&9I;'1E<B`]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@+RH@3F\@1FEL=&5R+B`J+PH@("`@
M("`@("`@("`@("`@("`@("1D871A("X]("1S8V%N;&EN95LD:ET["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)&9I;'1E<B`]/2`R*2!["B`@("`@("`@
M("`@("`@("`@("`@+RH@57`@1FEL=&5R+B`J+PH@("`@("`@("`@("`@("`@
M("`@("1P:7AE;"`]("1S8V%N;&EN95LD:ET@+2`D<')E=G-C86YL:6YE6R1J
M73L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VQO<D1E<'1H
M(#T](#@I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$@+CT@<&%C
M:R@G0T-#)RP@)'!I>&5L(#X^(#$V+"`H)'!I>&5L(#X^(#@I("8@,'A&1BP@
M)'!I>&5L("8@,'A&1BD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1T:&ES+3Y?8V]L;W)$97!T:"`]/2`Q-BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%T82`N/2!P86-K*"=N;FXG+"`H)'!I>&5L(#X^(#,R*2P@
M*"1P:7AE;"`^/B`Q-BD@)B`P>$9&1D8L("1P:7AE;"`F(#!X1D9&1BD["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1P<F5V<V-A;FQI;F4@/2`D<V-A;FQI;F4[
M"B`@("`@("`@?0H@("`@("`@("1C;VUP<F5S<V5D(#T@9WID969L871E*"1D
M871A+"`Y*3L*"B`@("`@("`@)&1A=&$@/2`G241!5"<@+B!P86-K*"=#0V$G
M("X@<W1R;&5N*"1C;VUP<F5S<V5D*2`N("=A-"<L(#!X-S@L(#!X,#$L("1C
M;VUP<F5S<V5D+"`D=&AI<RT^7T%D;&5R,S(H)&1A=&$I*3L*("`@("`@("!R
M971U<FX@<&%C:R@G3F$G("X@<W1R;&5N*"1D871A*2`N("=.)RP@<W1R;&5N
M*"1D871A*2`M(#0L("1D871A+"!C<F,S,B@D9&%T82DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E('1%6'0@8FQO8VLN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]T15AT*"1K97EW;W)D+"`D=&5X="D*("`@('L*("`@("`@("`D
M9&%T82`]("=T15AT)R`N("1K97EW;W)D("X@(EPP(B`N("1T97AT.PH@("`@
M("`@(')E='5R;B!P86-K*"=.82<@+B!S=')L96XH)&1A=&$I("X@)TXG+"!S
M=')L96XH)&1A=&$I("T@-"P@)&1A=&$L(&-R8S,R*"1D871A*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@;&%S="!M;V1I9FEE9"!T:6UE(&)L
M;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=$E-12@D9&%T92`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&1A=&4I*2!["B`@("`@("`@
M("`@("1D871E(#T@=&EM92@I.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@
M/2`G=$E-12<@+B!P86-K*"=N0T-#0T,G+"!I;G1V86PH9&%T92@G62<L("1D
M871E*2DL(&EN='9A;"AD871E*"=M)RP@)&1A=&4I*2P@:6YT=F%L*&1A=&4H
M)VHG+"`D9&%T92DI+"!I;G1V86PH9&%T92@G1R<L("1D871E*2DL(&EN='9A
M;"AD871E*"=I)RP@)&1A=&4I*2P@:6YT=F%L*&1A=&4H)W,G+"`D9&%T92DI
M*3L*("`@("`@("!R971U<FX@<&%C:R@G3F$G("X@<W1R;&5N*"1D871A*2`N
M("=.)RP@<W1R;&5N*"1D871A*2`M(#0L("1D871A+"!C<F,S,B@D9&%T82DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L8W5L871E(&%N($%D;&5R,S(@
M8VAE8VMS=6T@9F]R(&$@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M061L97(S,B@D:6YP=70I"B`@("!["B`@("`@("`@)',Q(#T@,3L*("`@("`@
M("`D<S(@/2`P.PH@("`@("`@("1I36%X(#T@<W1R;&5N*"1I;G!U="D["B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&E-87@[("1I*RLI('L*("`@("`@
M("`@("`@)',Q(#T@*"1S,2`K(&]R9"@D:6YP=71;)&E=*2D@)2`P>$9&1C$[
M"B`@("`@("`@("`@("1S,B`]("@D<S(@*R`D<S$I("4@,'A&1D8Q.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@<&%C:R@G3B<L("@H)',R(#P\(#$V*2!\
M("1S,2DI.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4&5R;7,O
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#8P`#`Q-S,P-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]097)M<R]522YP:'``````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-#4R-#,`,3`U,34T,S$P-C``,#(P,S,W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@4&5R;7-?54DZ.B!C;&%S<R!P<F]V:61E<R!522!M971H;V1S
M(&9O<B!T:&4@2&]R9&4@<&5R;6ES<VEO;G,*("H@<WES=&5M+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`L=B`Q+C(W+C(N
M."`R,#`V+S`Q+S`Q(#(Q.C(X.C,Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`
M<&%C:V%G92!(;W)D95]097)M<PH@*B\*8VQA<W,@4&5R;7-?54D@>PH*("`@
M("\J*@H@("`@("H@5&AE(%!E<FUS(&]B:F5C="!W92=R92!D:7-P;&%Y:6YG
M(%5)('-T=69F(&9O<BX*("`@("`J"B`@("`@*B!`=F%R(%!E<FUS"B`@("`@
M*B\*("`@('9A<B`D7W!E<FUS.PH*("`@("\J*@H@("`@("H@5&AE($AO<F1E
M7T9O<FT@;V)J96-T('1H870@=VEL;"!B92!U<V5D(&9O<B!D:7-P;&%Y:6YG
M('1H92!E9&ET(&9O<FTN"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]&;W)M
M"B`@("`@*B\*("`@('9A<B`D7V9O<FT@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@5&AE(%9A<FEA8FQE<R!O8FIE8W0@=7-E9"!I;B!(;W)D95]&;W)M+@H@
M("`@("H*("`@("`J($!V87(@5F%R:6%B;&5S"B`@("`@*B\*("`@('9A<B`D
M7W9A<G,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE('!E<FUI<W-I;VX@
M='EP92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]T>7!E(#T@)VUA=')I>"<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@4&5R;7,@)'!E<FUS("!4:&4@
M4&5R;7,@;V)J96-T('1O(&1I<W!L87D@54D@<W1U9F8@9F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!097)M<U]522@F)'!E<FUS*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<&5R;7,@/2`F)'!E<FUS.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@2&]R9&5?5')E92!R97!R97-E;G1A=&EO;B!O9B!T:&4@
M<&5R;6ES<VEO;G,@=')E92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&AT;6P@<VAO=VEN9R!T:&4@<&5R;6ES<VEO;G,@87,@82!(;W)D
M95]4<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)4<F5E*"1C=7)R
M96YT(#T@1$%40512145?4D]/5"D*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1R964N<&AP
M)SL*"B`@("`@("`@+RH@1V5T('1H92!P97)M<R!T<F5E+B`J+PH@("`@("`@
M("1N;V1E<R`]("8D=&AI<RT^7W!E<FUS+3YG9714<F5E*"D["@H@("`@("`@
M("1I8V]N9&ER(#T@87)R87DH)VEC;VYD:7(G(#T^("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG971);6%G941I<B@I*3L*("`@("`@("`D<&5R;7-?;F]D92`]
M("1I8V]N9&ER("L@87)R87DH)VEC;VXG(#T^("=P97)M<RYP;F<G*3L*("`@
M("`@("`D861D(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`G*3L*("`@("`@("`D961I="`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O961I="YP:'`G*3L*("`@("`@("`D
M9&5L971E(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]D
M96QE=&4N<&AP)RD["B`@("`@("`@)&5D:71?:6UG(#T@2&]R9&4Z.FEM9R@G
M961I="YP;F<G+"!?*")%9&ET(%!E<FUI<W-I;VXB*2D["B`@("`@("`@)&1E
M;&5T95]I;6<@/2!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@7R@B1&5L971E
M(%!E<FUI<W-I;VXB*2D["@H@("`@("`@("\J(%-E="!U<"!T:&4@=')E92X@
M*B\*("`@("`@("`D=')E92`]("9(;W)D95]4<F5E.CIS:6YG;&5T;VXH)W!E
M<FUS7W5I)RP@)VIA=F%S8W)I<'0G*3L*("`@("`@("`D=')E92T^<V5T3W!T
M:6]N*&%R<F%Y*"=A;'1E<FYA=&4G(#T^('1R=64L("=H:61E2&5A9&5R<R<@
M/3X@=')U92DI.PH@("`@("`@("1T<F5E+3YS971(96%D97(H87)R87DH87)R
M87DH)W=I9'1H)R`]/B`G-3`E)RDI*3L*"B`@("`@("`@9F]R96%C:"`H)&YO
M9&5S(&%S("1P97)M7VED(#T^("1N;V1E*2!["B`@("`@("`@("`@("1N;V1E
M7V-L87-S(#T@*"1C=7)R96YT(#T]("1P97)M7VED*2`_(&%R<F%Y*"=C;&%S
M<R<@/3X@)W-E;&5C=&5D)RD@.B!A<G)A>2@I.PH@("`@("`@("`@("!I9B`H
M)'!E<FU?:60@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`@("`@
M)&%D9%]I;6<@/2!(;W)D93HZ:6UG*"=P97)M<RYP;F<G+"!?*")!9&0@3F5W
M(%!E<FUI<W-I;VXB*2D["B`@("`@("`@("`@("`@("`D861D7VQI;FL@/2!(
M;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)&%D9"P@)W!E<FU?:60G
M+"`D<&5R;5]I9"DL(%\H(D%D9"!.97<@4&5R;6ES<VEO;B(I*2`N("1A9&1?
M:6UG("X@)SPO83XG.PH@("`@("`@("`@("`@("`@)&)A<V5?;F]D95]P87)A
M;7,@/2`D:6-O;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G861M:6YI<W1R871I
M;VXN<&YG)RD["@H@("`@("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H)'!E
M<FU?:60L(&YU;&PL(%\H(D%L;"!097)M:7-S:6]N<R(I+"`P+"!T<G5E+"`D
M8F%S95]N;V1E7W!A<F%M<R`K("1N;V1E7V-L87-S+"!A<G)A>2@D861D7VQI
M;FLI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P
M87)E;G1?:60@/2`D=&AI<RT^7W!E<FUS+3Y?9&%T871R964M/F=E=%!A<F5N
M="@D;F]D92D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<&%R96YT7VED
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@2&]R9&4Z
M.F9A=&%L*"1P87)E;G1?:60L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%D9%]I;6<@/2!(;W)D
M93HZ:6UG*"=P97)M<RYP;F<G+"!?*")!9&0@0VAI;&0@4&5R;6ES<VEO;B(I
M*3L*("`@("`@("`@("`@("`@("1A9&1?;&EN:R`]($AO<F1E.CIL:6YK*%5T
M:6PZ.F%D9%!A<F%M971E<B@D861D+"`G<&5R;5]I9"<L("1P97)M7VED*2P@
M7R@B061D($-H:6QD(%!E<FUI<W-I;VXB*2D@+B`D861D7VEM9R`N("<\+V$^
M)SL*("`@("`@("`@("`@("`@("1E9&ET7VQI;FL@/2!(;W)D93HZ;&EN:RA5
M=&EL.CIA9&1087)A;65T97(H)&5D:70L("=P97)M7VED)RP@)'!E<FU?:60I
M+"!?*")%9&ET(%!E<FUI<W-I;VXB*2D@+B`D961I=%]I;6<@+B`G/"]A/B<[
M"B`@("`@("`@("`@("`@("`D9&5L971E7VQI;FL@/2!(;W)D93HZ;&EN:RA5
M=&EL.CIA9&1087)A;65T97(H)&1E;&5T92P@)W!E<FU?:60G+"`D<&5R;5]I
M9"DL(%\H(D1E;&5T92!097)M:7-S:6]N(BDI("X@)&1E;&5T95]I;6<@+B`G
M/"]A/B<["B`@("`@("`@("`@("`@("`D<&5R;7-?97AT<F$@/2!A<G)A>2@D
M861D7VQI;FLL("1E9&ET7VQI;FLL("1D96QE=&5?;&EN:RD["B`@("`@("`@
M("`@("`@("`D;F%M92`]("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1N;V1E
M*3L*"B`@("`@("`@("`@("`@("`D=')E92T^861D3F]D92@D<&5R;5]I9"P@
M)'!A<F5N=%]I9"P@)&YA;64L('-U8G-T<E]C;W5N="@D;F]D92P@)SHG*2`K
M(#$L(&9A;'-E+"`D<&5R;7-?;F]D92`K("1N;V1E7V-L87-S+"`D<&5R;7-?
M97AT<F$I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=')E
M92T^<V]R="@G;&%B96PG*3L*"B`@("`@("`@<F5T=7)N("1T<F5E+3YR96YD
M97)4<F5E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@86X@97AI<W1I
M;F<@9F]R;2!O8FIE8W0@=&\@=7-E(&9O<B!T:&4@961I="!F;W)M+@H@("`@
M("H*("`@("`J($!P87)A;2!(;W)D95]&;W)M("1F;W)M("!!;B!E>&ES=&EN
M9R!(;W)D95]&;W)M(&]B:F5C="!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$9O<FTH)B1F;W)M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9F]R
M;2`]("8D9F]R;3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!A;B!E>&ES
M=&EN9R!V87)S(&]B:F5C="!T;R!U<V4@9F]R('1H92!E9&ET(&9O<FTN"B`@
M("`@*@H@("`@("H@0'!A<F%M(%9A<FEA8FQE<R`D=F%R<R`@06X@97AI<W1I
M;F<@5F%R:6%B;&5S(&]B:F5C="!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%9A<G,H)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R
M<R`]("8D=F%R<SL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A(&9O
M<FT@=&\@861D(&$@<&5R;6ES<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M4&5R;7,@)'!E<FUI<W-I;VX*("`@("`J($!P87)A;2!S=')I;F<@)&9O<F-E
M7V-H;VEC92`@268@=&AE('!E<FUI<W-I;VX@=&\@8F4@861D960@8V%N(&)E
M(&]N92!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!M
M86YY+"!S971T:6YG('1H:7,@=VEL;"!F;W)C92!T:&4@8VAO:6-E('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]N92!P87)T:6-U
M;&%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971U<$%D9$9O<FTH)'!E<FUI
M<W-I;VXL("1F;W)C95]C:&]I8V4@/2!N=6QL*0H@("`@>PH@("`@("`@("\J
M($EN:71I86QI<V4@9F]R;2!I9B!R97%U:7)E9"X@*B\*("`@("`@("`D=&AI
M<RT^7V9O<FU);FET*"D["@H@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T5&ET
M;&4H<W!R:6YT9BA?*")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<
M(B(I+"`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T
M3F%M92@I*2DI.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T0G5T=&]N<RA?
M*")!9&0B*2P@=')U92D["B`@("`@("`@)'1H:7,M/E]V87)S+3YS970H)W!E
M<FU?:60G+"`D=&AI<RT^7W!E<FUS+3YG971097)M:7-S:6]N260H)'!E<FUI
M<W-I;VXI*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9$AI9&1E;B@G)RP@
M)W!E<FU?:60G+"`G=&5X="<L(&9A;'-E*3L*"B`@("`@("`@+RH@4V5T('5P
M('1H92!A8W1U86P@8VAI;&0@861D:6YG(&9I96QD+B`J+PH@("`@("`@("1C
M:&EL9%]P97)M<R`]("1T:&ES+3Y?<&5R;7,M/F=E=$%V86EL86)L92@D<&5R
M;6ES<VEO;BT^9V5T3F%M92@I*3L*("`@("`@("!I9B`H)&-H:6QD7W!E<FUS
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`O*B!&86QS92P@<V\@;F\@8VAI
M;&1S(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*%\H(E!E<FUI<W-I
M;VXB*2P@)V-H:6QD)RP@)VEN=F%L:60G+"!T<G5E+"!F86QS92P@;G5L;"P@
M87)R87DH7R@B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R
M;6ES<VEO;BXB*2DI.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D8VAI
M;&1?<&5R;7,I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)&9O<F-E7V-H
M;VEC92DI('L*("`@("`@("`@("`@("`@("\J($-H;VEC92!A<G)A>2!A=F%I
M;&%B;&4L(&)U="!C:&]I8V4@8F5I;F<@9F]R8V5D+B`J+PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V87)S+3YS970H)V-H:6QD)RP@)&9O<F-E7V-H;VEC
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE
M*%\H(E!E<FUI<W-I;VYS(BDL("=C:&EL9"<L("=E;G5M)RP@=')U92P@=')U
M92P@;G5L;"P@87)R87DH)&-H:6QD7W!E<FUS*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O*B!#:&]I8V4@87)R87D@879A:6QA
M8FQE+"!S;R!S970@=7`@96YU;2!F:65L9"X@*B\*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H7R@B4&5R;6ES<VEO;G,B*2P@
M)V-H:6QD)RP@)V5N=6TG+"!T<G5E+"!F86QS92P@;G5L;"P@87)R87DH)&-H
M:6QD7W!E<FUS*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A;GD@861D(&9O
M<FT@:6YP=70N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R
M(&9A;'-E(&EF('1H92!F;W)M(&1O97,@;F]T('9A;&ED871E(&-O<G)E8W1L
M>2!O<@H@("`@("H@("`@("`@("`@("`@("`@86X@87)R87D@=VET:"!A;&P@
M=&AE(&9O<FT@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!V86QI9&%T
M94%D9$9O<FTH)B1I;F9O*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]F
M;W)M+3YV86QI9&%T92@D=&AI<RT^7W9A<G,I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9F]R;2T^
M9V5T26YF;R@D=&AI<RT^7W9A<G,L("1I;F9O*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A('!E<FUI<W-I
M;VX@961I=&EN9R!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E
M94]B:F5C=%]097)M:7-S:6]N("1P97)M:7-S:6]N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E='5P161I=$9O<FTH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@
M("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@26YI=&EA;&ES92!F
M;W)M(&EF(')E<75I<F5D+B`J+PH@("`@("`@("1T:&ES+3Y?9F]R;4EN:70H
M*3L*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971"=71T;VYS*%\H(E5P9&%T
M92(I+"!T<G5E*3L*("`@("`@("`D<&5R;5]I9"`]("1T:&ES+3Y?<&5R;7,M
M/F=E=%!E<FUI<W-I;VY)9"@D<&5R;6ES<VEO;BD["B`@("`@("`@)'1H:7,M
M/E]F;W)M+3YA9&1(:61D96XH)R<L("=P97)M7VED)RP@)W1E>'0G+"!F86QS
M92D["@H@("`@("`@("\J($=E="!P97)M:7-S:6]N(&-O;F9I9W5R871I;VXN
M("HO"B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'!E<FUI<W-I;VXM/F=E="@G
M='EP92<I.PH@("`@("`@("1P87)A;7,@/2`D<&5R;6ES<VEO;BT^9V5T*"=P
M87)A;7,G*3L*"B`@("`@("`@+RH@1&5F875L="!P97)M:7-S:6]N<RX@*B\*
M("`@("`@("`D<&5R;5]V86P@/2`D<&5R;6ES<VEO;BT^9V5T1&5F875L=%!E
M<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971396-T:6]N
M*"=D969A=6QT)RP@7R@B06QL($%U=&AE;G1I8V%T960@57-E<G,B*2P@2&]R
M9&4Z.FEM9R@G<&5R;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2P@9F%L<V4I.PH*("`@("`@("`O*B!792!-55-4
M('5S92`G9&5F;'0G(&9O<B!T:&4@=F%R:6%B;&4@;F%M92!B96-A=7-E("=D
M969A=6QT)R!I<R!A"B`@("`@("`@("H@<F5S97)V960@=V]R9"!I;B!*879A
M4V-R:7!T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA=')I
M>"<I('L*("`@("`@("`@("`@+RH@4V5T('5P('1H92!C;VQU;6YS(&9O<B!T
M:&4@<&5R;6ES<VEO;G,@;6%T<FEX+B`J+PH@("`@("`@("`@("`D8V]L<R`]
M(%!E<FUS.CIG971097)M<T%R<F%Y*"D["@H@("`@("`@("`@("`O*B!$969I
M;F4@82!S:6YG;&4@;6%T<FEX(')O=R!F;W(@9&5F875L="!P97)M<RX@*B\*
M("`@("`@("`@("`@)&UA=')I>"`](&%R<F%Y*"D["B`@("`@("`@("`@("1M
M871R:7A;,%T@/2!097)M<SHZ:6YT96=E<E1O07)R87DH)'!E<FU?=F%L*3L*
M("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G)RP@)V1E
M9FQT)RP@)VUA=')I>"<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O
M;',L(&%R<F%Y*#`@/3X@)R<I+"`D;6%T<FEX*2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA
M8FQE*"<G+"`G9&5F;'0G+"`D=&AI<RT^7W1Y<&4L(&9A;'-E+"!F86QS92P@
M;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@("1V87(M/G-E=$1E9F%U;'0H
M)'!E<FU?=F%L*3L*("`@("`@("!]"@H@("`@("`@("\J($=U97-T('!E<FUI
M<W-I;VYS+B`J+PH@("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG
M971'=65S=%!E<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS
M971396-T:6]N*"=G=65S="<L(%\H(D=U97-T(%!E<FUI<W-I;VYS(BDL("<G
M+"!F86QS92D["@H@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA=')I
M>"<I('L*("`@("`@("`@("`@+RH@1&5F:6YE(&$@<VEN9VQE(&UA=')I>"!R
M;W<@9F]R(&=U97-T('!E<FUS+B`J+PH@("`@("`@("`@("`D;6%T<FEX(#T@
M87)R87DH*3L*("`@("`@("`@("`@)&UA=')I>%LP72`](%!E<FUS.CII;G1E
M9V5R5&]!<G)A>2@D<&5R;5]V86PI.PH@("`@("`@("`@("`D=&AI<RT^7V9O
M<FTM/F%D9%9A<FEA8FQE*"<G+"`G9W5E<W0G+"`G;6%T<FEX)RP@9F%L<V4L
M(&9A;'-E+"!N=6QL+"!A<G)A>2@D8V]L<RP@87)R87DH,"`]/B`G)RDL("1M
M871R:7@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%R(#T@
M)B1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=G=65S="<L("1T:&ES
M+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL+"`D<&%R86US*3L*("`@("`@
M("`@("`@)'9A<BT^<V5T1&5F875L="@D<&5R;5]V86PI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,N("HO"B`@
M("`@("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=$-R96%T;W)097)M
M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO;B@G
M8W)E871O<B<L(%\H(D-R96%T;W(@4&5R;6ES<VEO;G,B*2P@2&]R9&4Z.FEM
M9R@G=7-E<BYP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI+"!F86QS92D["@H@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@
M/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@+RH@1&5F:6YE(&$@<VEN9VQE
M(&UA=')I>"!R;W<@9F]R(&-R96%T;W(@<&5R;7,N("HO"B`@("`@("`@("`@
M("1M871R:7@@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6%T<FEX6S!=(#T@
M4&5R;7,Z.FEN=&5G97)4;T%R<F%Y*"1P97)M7W9A;"D["B`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=C<F5A=&]R)RP@)VUA
M=')I>"<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O;',L(&%R<F%Y
M*#`@/3X@)R<I+"`D;6%T<FEX*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G
M8W)E871O<B<L("1T:&ES+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL+"`D
M<&%R86US*3L*("`@("`@("`@("`@)'9A<BT^<V5T1&5F875L="@D<&5R;5]V
M86PI.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E<G,@<&5R;6ES<VEO;G,N
M("HO"B`@("`@("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=%5S97)0
M97)M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO
M;B@G=7-E<G,G+"!?*"));F1I=FED=6%L(%5S97)S(BDL($AO<F1E.CII;6<H
M)W5S97(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*2P@9F%L<V4I.PH@("`@("`@("1A=71H(#T@)D%U=&@Z.G-I;F=L
M971O;B@D1TQ/0D%,4ULG8V]N9B==6R=A=71H)UU;)V1R:79E<B==*3L*("`@
M("`@("!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH@("`@
M("`@("`@("`O*B!4:&4@875T:"!D<FEV97(@:&%S(&QI<W0@8V%P86)I;&ET
M:65S('-O('-E="!U<"!A;B!A<G)A>2!W:&EC:`H@("`@("`@("`@("`@*B!T
M:&4@;6%T<FEX(&9I96QD('1Y<&4@=VEL;"!R96-O9VYI<V4@=&\@<V5T('5P
M(&%N(&5N=6T@8F]X(&9O<@H@("`@("`@("`@("`@*B!A9&1I;F<@;F5W('5S
M97)S('1O('1H92!P97)M:7-S:6]N<R!M871R:7@N("HO"B`@("`@("`@("`@
M("1N97=?=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=7-E<E]L:7-T
M(#T@)&%U=&@M/FQI<W15<V5R<R@I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M=7-E<E]L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D
M;F5W7W5S97)S(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@('-O<G0H)'5S97)?;&ES="D["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=7-E<E]L:7-T(&%S("1U<V5R*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D<&5R;5]V86Q;)'5S97)=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;F5W7W5S97)S6R1U<V5R72`]("1U<V5R.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO(&QI
M<W0@8V%P86)I;&ET:65S+"!S971T:6YG('1O('1R=64@<V\@=&AA="!T:&4@
M;6%T<FEX(&9I96QD"B`@("`@("`@("`@("`J('1Y<&4@=VEL;"!O9F9E<B!A
M('1E>'0@:6YP=70@8F]X(&9O<B!A9&1I;F<@;F5W('5S97)S+B`J+PH@("`@
M("`@("`@("`D;F5W7W5S97)S(#T@=')U93L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@
M+RH@4V5T('5P('1H92!M871R:7@@87)R87DL(&)R96%K:6YG('5P(&5A8V@@
M<&5R;6ES<VEO;B!I;G1E9V5R"B`@("`@("`@("`@("`J(&EN=&\@86X@87)R
M87DN("!4:&4@:V5Y<R!O9B!T:&ES(&%R<F%Y('=I;&P@8F4@=&AE(')O=PH@
M("`@("`@("`@("`@*B!H96%D97)S+B`J+PH@("`@("`@("`@("`D<F]W<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1M871R:7@@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!F;W)E86-H("@D<&5R;5]V86P@87,@)'5?:60@/3X@)'5?<&5R
M;7,I('L*("`@("`@("`@("`@("`@("1R;W=S6R1U7VED72`]("1U7VED.PH@
M("`@("`@("`@("`@("`@)&UA=')I>%LD=5]I9%T@/2!097)M<SHZ:6YT96=E
M<E1O07)R87DH)'5?<&5R;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=U)RP@)VUA=')I>"<L
M(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O;',L("1R;W=S+"`D;6%T
M<FEX+"`D;F5W7W5S97)S*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"1N97=?=7-E<G,I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D;F5W7W5S97)S*2D@>PH@("`@("`@("`@("`@("`@("`@("1U7VX@
M/2!5=&EL.CIG971&;W)M1&%T82@G=5]N)RD["B`@("`@("`@("`@("`@("`@
M("`@)'5?;B`](&5M<'1Y*"1U7VY;)W4G72D@/R!N=6QL(#H@)'5?;ELG=2==
M.PH@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@/2`G/'-E;&5C="!N
M86UE/2)U7VY;=5TB/CQO<'1I;VX^)R`N(%\H(BTM('-E;&5C="`M+2(I("X@
M)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&YE
M=U]U<V5R<R!A<R`D;F5W7W5S97(I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'5S97)?:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB)R`N("1N97=?=7-E
M<B`N("<B)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`N
M/2`D=5]N(#T]("1N97=?=7-E<B`_("<@<V5L96-T960](G-E;&5C=&5D(B<@
M.B`G)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`N/2`G
M/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1N97=?=7-E<BD@+B`G/"]O<'1I;VX^
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'5S97)?:'1M;"`N/2`G/"]S96QE8W0^)SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`]("<\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB=5]N6W5=(B`O/B<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA
M8FQE*"1U<V5R7VAT;6PL("=U7VY;=ETG+"`D=&AI<RT^7W1Y<&4L(&9A;'-E
M+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@9F]R96%C:"`H)'!E<FU?=F%L(&%S("1U7VED(#T^("1U7W!E<FUS
M*2!["B`@("`@("`@("`@("`@("`D=F%R(#T@)B1T:&ES+3Y?9F]R;2T^861D
M5F%R:6%B;&4H)'5?:60L("=U7W9;)R`N("1U7VED("X@)UTG+"`D=&AI<RT^
M7W1Y<&4L(&9A;'-E+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@
M("`@("`@("`D=F%R+3YS971$969A=6QT*"1U7W!E<FUS*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@1W)O=7!S('!E<FUI<W-I;VYS
M+B`J+PH@("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG971'<F]U
M<%!E<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971396-T
M:6]N*"=G<F]U<',G+"!?*")'<F]U<',B*2P@2&]R9&4Z.FEM9R@G9W)O=7`N
M<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2P@9F%L<V4I.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N
M<&AP)SL*("`@("`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*
M("`@("`@("`D9W)O=7!?;&ES="`]("1G<F]U<',M/FQI<W1'<F]U<',H*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1G<F]U<%]L:7-T*2D@>PH@("`@("`@("`@
M("`O*B!4:&5R92!I<R!A;B!A=F%I;&%B;&4@;&ES="!O9B!G<F]U<',@<V\@
M<V5T('5P(&%N(&%R<F%Y('=H:6-H"B`@("`@("`@("`@("`J('1H92!M871R
M:7@@9FEE;&0@='EP92!W:6QL(')E8V]G;FES92!T;R!S970@=7`@86X@96YU
M;2!B;W@@9F]R"B`@("`@("`@("`@("`J(&%D9&EN9R!N97<@9W)O=7!S('1O
M('1H92!P97)M:7-S:6]N<R!M871R:7@N("HO"B`@("`@("`@("`@("1N97=?
M9W)O=7!S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P
M7VQI<W0@87,@)&=R;W5P260@/3X@)&=R;W5P*2!["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1P97)M7W9A;%LD9W)O=7!)9%TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&YE=U]G<F]U<'-;)&=R;W5P261=(#T@)&=R;W5P.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH@1&\@;F]T(&]F9F5R(&$@=&5X="!B;W@@=&\@
M861D(&YE=R!G<F]U<',N("HO"B`@("`@("`@("`@("1N97=?9W)O=7!S(#T@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]
M("=M871R:7@G*2!["B`@("`@("`@("`@("\J(%-E="!U<"!T:&4@;6%T<FEX
M(&%R<F%Y+"!B<F5A:R!U<"!E86-H('!E<FUI<W-I;VX@:6YT96=E<B!I;G1O
M"B`@("`@("`@("`@("`J(&%N(&%R<F%Y+B!4:&4@:V5Y<R!O9B!T:&ES(&%R
M<F%Y('=I;&P@8F4@=&AE(')O=R!H96%D97)S+B`J+PH@("`@("`@("`@("`D
M<F]W<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1M871R:7@@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V86P@87,@)&=?:60@/3X@
M)&=?<&5R;7,I('L*("`@("`@("`@("`@("`@("1R;W=S6R1G7VED72`](&ES
M<V5T*"1G<F]U<%]L:7-T6R1G7VED72D@/R`D9W)O=7!?;&ES=%LD9U]I9%T@
M.B`D9U]I9#L*("`@("`@("`@("`@("`@("1M871R:7A;)&=?:61=(#T@4&5R
M;7,Z.FEN=&5G97)4;T%R<F%Y*"1G7W!E<FUS*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G9R<L
M("=M871R:7@G+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS+"`D
M<F]W<RP@)&UA=')I>"P@)&YE=U]G<F]U<',I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H)&YE=U]G<F]U<',I('L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D;F5W7V=R;W5P<RDI('L*("`@("`@("`@("`@
M("`@("`@("`D9U]N(#T@571I;#HZ9V5T1F]R;41A=&$H)V=?;B<I.PH@("`@
M("`@("`@("`@("`@("`@("1G7VX@/2!E;7!T>2@D9U]N6R=G)UTI(#\@;G5L
M;"`Z("1G7VY;)V<G73L*("`@("`@("`@("`@("`@("`@("`D9W)O=7!?:'1M
M;"`]("<\<V5L96-T(&YA;64](F=?;EMG72(^/&]P=&EO;CXG("X@7R@B+2T@
M<V5L96-T("TM(BD@+B`G/"]O<'1I;VX^)SL*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D;F5W7V=R;W5P<R!A<R`D9W)O=7!)9"`]/B`D9W)O=7`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)SQO
M<'1I;VX@=F%L=64](B<@+B`D9W)O=7!)9"`N("<B)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)&=?;B`]/2`D9W)O=7!)9"`_
M("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)SXG("X@:'1M;'-P96-I86QC:&%R
M<R@D9W)O=7`I("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1G<F]U<%]H=&UL("X]("<\+W-E;&5C
M=#XG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D9W)O=7!?:'1M;"`]("<\:6YP=70@='EP93TB=&5X="(@;F%M93TB
M9U]N6V==(B`O/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"1G<F]U<%]H=&UL+"`G9U]N
M6W9=)RP@)'1H:7,M/E]T>7!E+"!F86QS92P@9F%L<V4L(&YU;&PL("1P87)A
M;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M
M7W9A;"!A<R`D9U]I9"`]/B`D9U]P97)M<RD@>PH@("`@("`@("`@("`@("`@
M)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*&ES<V5T*"1G<F]U
M<%]L:7-T6R1G7VED72D@/R`D9W)O=7!?;&ES=%LD9U]I9%T@.B`D9U]I9"P@
M)V=?=ELG("X@)&=?:60@+B`G72<L("1T:&ES+3Y?='EP92P@9F%L<V4L(&9A
M;'-E+"!N=6QL+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("1V87(M/G-E
M=$1E9F%U;'0H)&=?<&5R;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!3970@9F]R;2!T:71L92X@*B\*("`@("`@("`D=&AI<RT^
M7V9O<FTM/G-E=%1I=&QE*'-P<FEN=&8H7R@B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(BDL("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1P97)M:7-S
M:6]N+3YG971.86UE*"DI*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T;R!V86QI9&%T92!A;GD@961I="!F;W)M(&EN<'5T+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!F86QS92!I9B!T:&4@9F]R
M;2!D;V5S(&YO="!V86QI9&%T92!C;W)R96-T;'D@;W(*("`@("`J("`@("`@
M("`@("`@("`@(&%N(&%R<F%Y('=I=&@@86QL('1H92!F;W)M('9A;'5E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5%9&ET1F]R;2@F)&EN9F\I
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V9O<FTM/G9A;&ED871E*"1T
M:&ES+3Y?=F%R<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YG971);F9O*"1T:&ES+3Y?
M=F%R<RP@)&EN9F\I.PH*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]("=M
M871R:7@G*2!["B`@("`@("`@("`@("\J($-O;&QA<'-E('1H92!A<G)A>2!F
M;W(@9&5F875L="]G=65S="]C<F5A=&]R+B`J+PH@("`@("`@("`@("`D:6YF
M;ULG9&5F;'0G72`](&ES<V5T*"1I;F9O6R=D969L="==6S!=*2`_("1I;F9O
M6R=D969L="==6S!=(#H@;G5L;#L*("`@("`@("`@("`@)&EN9F];)V=U97-T
M)UT@("`](&ES<V5T*"1I;F9O6R=G=65S="==6S!=*2`_("1I;F9O6R=G=65S
M="==6S!=(#H@;G5L;#L*("`@("`@("`@("`@)&EN9F];)V-R96%T;W(G72`]
M(&ES<V5T*"1I;F9O6R=C<F5A=&]R)UU;,%TI(#\@)&EN9F];)V-R96%T;W(G
M75LP72`Z(&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5?
M;B`]("1T:&ES+3Y?=F%R<RT^9V5T*"=U7VXG*3L*("`@("`@("`@("`@)&EN
M9F];)W4G72`](&%R<F%Y*"1U7VY;)W4G72`]/B`D:6YF;ULG=5]N)UU;)W8G
M72D["B`@("`@("`@("`@('5N<V5T*"1I;F9O6R=U7VXG72D["B`@("`@("`@
M("`@(&EF("AI<W-E="@D:6YF;ULG=5]V)UTI*2!["B`@("`@("`@("`@("`@
M("`D:6YF;ULG=2==(#T@87)R87E?;65R9V4H)&EN9F];)W4G72P@)&EN9F];
M)W5?=B==*3L*("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=U7W8G72D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&=?;B`]("1T:&ES+3Y?=F%R
M<RT^9V5T*"=G7VXG*3L*("`@("`@("`@("`@)&EN9F];)V<G72`](&%R<F%Y
M*"1G7VY;)V<G72`]/B`D:6YF;ULG9U]N)UU;)W8G72D["B`@("`@("`@("`@
M('5N<V5T*"1I;F9O6R=G7VXG72D["B`@("`@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG9U]V)UTI*2!["B`@("`@("`@("`@("`@("`D:6YF;ULG9R==(#T@
M87)R87E?;65R9V4H)&EN9F];)V<G72P@)&EN9F];)V=?=B==*3L*("`@("`@
M("`@("`@("`@('5N<V5T*"1I;F9O6R=G7W8G72D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@)&EN9F];)V1E9F%U;'0G72`]("1I;F9O6R=D
M969L="==.PH@("`@("`@('5N<V5T*"1I;F9O6R=D969L="==*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@
M82!P97)M:7-S:6]N(&1E;&5T:6YG(&9O<FTN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&]B:F5C="`D<&5R;6ES<VEO;@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971U<$1E;&5T949O<FTH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@+RH@
M26YI=&EA;&ES92!F;W)M(&EF(')E<75I<F5D+B`J+PH@("`@("`@("1T:&ES
M+3Y?9F]R;4EN:70H*3L*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YS9714:71L
M92AS<')I;G1F*%\H(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(BDL
M("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1P97)M:7-S:6]N+3YG971.86UE
M*"DI*2D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971"=71T;VYS*&%R<F%Y
M*%\H(D1E;&5T92(I+"!?*")$;R!N;W0@9&5L971E(BDI*3L*("`@("`@("`D
M=&AI<RT^7V9O<FTM/F%D9$AI9&1E;B@G)RP@)W!E<FU?:60G+"`G=&5X="<L
M(&9A;'-E*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*'-P
M<FEN=&8H7R@B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N
M>2!S=6(M<&5R;6ES<VEO;G,_(BDL("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE
M*"1P97)M:7-S:6]N+3YG971.86UE*"DI*2P@)W!R;VUP="<L("=D97-C<FEP
M=&EO;B<L(&9A;'-E*3L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO
M;B!T;R!V86QI9&%T92!A;GD@9&5L971E(&9O<FT@:6YP=70N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@268@=&AE(&1E;&5T92!B=71T;VX@8V]N
M9FER;6%T:6]N(&AA<R!B965N('!R97-S960@<F5T=7)N"B`@("`@*B`@("`@
M("`@("`@("`@("!T<G5E+"!I9B!A;GD@;W1H97(@<W5B;6ET(&)U='1O;B!H
M87,@8F5E;B!P<F5S<V5D(')E='5R;@H@("`@("H@("`@("`@("`@("`@("`@
M9F%L<V4N($EF(&9O<FT@9&ED(&YO="!V86QI9&%T92!R971U<FX@;G5L;"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5$96QE=&5&;W)M*"8D:6YF
M;RD*("`@('L*("`@("`@("`D9F]R;5]S=6)M:70@/2`D=&AI<RT^7W9A<G,M
M/F=E="@G<W5B;6ET8G5T=&]N)RD["@H@("`@("`@(&EF("@D9F]R;5]S=6)M
M:70@/3T@7R@B1&5L971E(BDI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M9F]R;2T^=F%L:61A=&4H)'1H:7,M/E]V87)S*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]F;W)M+3YG971);F9O*"1T:&ES+3Y?=F%R<RP@)&EN9F\I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1F;W)M7W-U8FUI="DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97)S('1H92!E
M9&ET(&9O<FTN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D9O<FTH)&9O
M<FU?<V-R:7!T(#T@)V5D:70N<&AP)RD*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*("`@("`@("`D<F5N
M9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H*3L*("`@("`@("`D
M=&AI<RT^7V9O<FTM/G)E;F1E<D%C=&EV92@D<F5N9&5R97(L("1T:&ES+3Y?
M=F%R<RP@)&9O<FU?<V-R:7!T+"`G<&]S="<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E<R!A;GD@9F]R;2!O8FIE8W1S(&EF('1H97D@:&%V92!N
M;W0@8F5E;B!I;FET:6%L:7-E9"!Y970N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;W)M26YI="@I"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]V87)S*2D@>PH@("`@
M("`@("`@("`O*B!.;R!E>&ES=&EN9R!V87)S('-E="P@9V5T('1H96T@;F]W
M+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE
M<RYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W9A<G,@/2`F5F%R:6%B;&5S
M.CIG971$969A=6QT5F%R:6%B;&5S*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES7V$H)'1H:7,M/E]F;W)M+"`G2&]R9&5?1F]R;2<I*2!["B`@("`@
M("`@("`@("\J($YO(&5X:7-T:6YG('9A;&ED(&9O<FT@;V)J96-T('-E="!S
M;R!S970@=7`@82!N97<@;VYE+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T9O<FTN<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]F;W)M
M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G)RP@)'1H:7,M/E]V87)S*3L*
M("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0
M97)M<R]D871A=')E92YP:'``````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-C8W-S4`,3`U,34T,S$P-C``,#(Q-C,P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)TAO<F1E+T1A=&%4<F5E+G!H<"<["@HO*BH*("H@5&AE(%!E<FUS7V1A=&%T
M<F5E.CH@8VQA<W,@<')O=FED97,@82!$871A5')E92!D<FEV97(@9F]R('1H
M92!(;W)D90H@*B!P97)M:7-S:6]N<R!S>7-T96TN"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<"QV(#$N-BXR+C$R
M(#(P,#8O,#<O,C`@,3@Z-3`Z,#4@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]097)M<PH@*B\*8VQA<W,@4&5R;7-?9&%T
M871R964@97AT96YD<R!097)M<R!["@H@("`@+RHJ"B`@("`@*B!0;VEN=&5R
M('1O(&$@1&%T851R964@:6YS=&%N8V4@=&\@;6%N86=E('1H92!D:69F97)E
M;G0*("`@("`J('!E<FUI<W-I;VYS+@H@("`@("H*("`@("`J($!V87(@1&%T
M851R964*("`@("`J+PH@("`@=F%R("1?9&%T871R964["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@4&5R;7-?
M9&%T871R964H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@
M("`@:68@*&5M<'1Y*"1C;VYF6R=D871A=')E92==6R=D<FEV97(G72DI('L*
M("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!T:&4@4&5R;7,@1&%T851R964@
M9')I=F5R+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`D9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==.PH@
M("`@("`@("1T:&ES+3Y?9&%T871R964@/2`F1&%T851R964Z.G-I;F=L971O
M;B@D9')I=F5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>5]M97)G92A(;W)D93HZ9V5T1')I=F5R0V]N
M9FEG*"=D871A=')E92<L("1D<FEV97(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G9W)O=7`G(#T^("=H;W)D92YP97)M<R<I*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!A=F%I;&%B;&4@<&5R;6ES<VEO;G,@9F]R
M(&$@9VEV96X@;&5V96PN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE('!E<FUI<W-I;VXG<R!N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%V86EL86)L92!P97)M:7-S:6]N
M<R!A;F0@=&AE:7(@=&ET;&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!
M=F%I;&%B;&4H)&YA;64I"B`@("!["B`@("`@("`@:68@*"1N86UE(#T]($1!
M5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@)&YA;64@/2`G)SL*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T079A:6QA8FQE*"1N86UE
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@<&5R;6ES<VEO;B!N
M86UE+"!R971U<FYS('1H92!T:71L92!F;W(@=&AA="!P97)M:7-S:6]N(&)Y
M"B`@("`@*B!L;V]K:6YG(&ET('5P(&EN('1H92!A<'!L:6-A=&EO;G,G<R!P
M97)M:7-S:6]N(&%P:2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@<&5R;6ES<VEO;G,G<R!N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=&ET;&4@9F]R('1H92!P97)M:7-S:6]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714:71L92@D;F%M92D*("`@('L*("`@
M("`@("!I9B`H)&YA;64@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@
M("!R971U<FX@7R@B06QL(%!E<FUI<W-I;VYS(BD["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!P87)E;G0Z.F=E=%1I=&QE*"1N86UE*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!N97<@<&5R;6ES<VEO;G,@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!P97)M
M:7-S:6]N)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E
M3V)J96-T7U!E<FUI<W-I;VYS("!!(&YE=R!P97)M:7-S:6]N<R!O8FIE8W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=097)M:7-S:6]N*"1N86UE*0H@
M("`@>PH@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!E<FUI<W-I;VX@;F%M97,@;75S
M="!B92!N;VXM96UP='DG*3L*("`@("`@("!]"@H@("`@("`@("1T>7!E(#T@
M)VUA=')I>"<["B`@("`@("`@)'!A<F%M<R`](&YU;&P["B`@("`@("`@:68@
M*"1P;W,@/2!S=')P;W,H)&YA;64L("<Z)RDI('L*("`@("`@("`@("`@)&EN
M9F\@/2`D=&AI<RT^9V5T07!P;&EC871I;VY097)M:7-S:6]N<RAS=6)S='(H
M)&YA;64L(#`L("1P;W,I*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1I;F9O
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&EN9F];)W1Y<&4G72D@)B8@:7-S970H)&EN9F];)W1Y<&4G75LD;F%M95TI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D:6YF;ULG='EP92==
M6R1N86UE73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D:6YF;ULG<&%R86US)UTI("8F(&ES<V5T*"1I;F9O6R=P87)A
M;7,G75LD;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`]
M("1I;F9O6R=P87)A;7,G75LD;F%M95T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'!E<FT@/2`F;F5W($1A
M=&%4<F5E3V)J96-T7U!E<FUI<W-I;VXH)&YA;64L("1T>7!E+"`D<&%R86US
M*3L*("`@("`@("`D<&5R;2T^<V5T1&%T851R964H)'1H:7,M/E]D871A=')E
M92D["@H@("`@("`@(')E='5R;B`D<&5R;3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!$871A5')E94]B:F5C=%]097)M:7-S:6]N(&]B:F5C
M="!C;W)R97-P;VYD:6YG('1O('1H90H@("`@("H@;F%M960@<&5R;6ES<VEO
M;BP@=VET:"!T:&4@=7-E<G,@86YD(&]T:&5R(&1A=&$@<F5T<FEE=F5D"B`@
M("`@*B!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!P97)M:7-S:6]N('1O(')E=')I
M979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4&5R;6ES<VEO;B@D;F%M
M92D*("`@('L*("`@("`@("`O*B!#86-H92!O9B!P<F5V:6]U<VQY(')E=')I
M979E9"!P97)M:7-S:6]N<RX@*B\*("`@("`@("!S=&%T:6,@)'!E<FUS0V%C
M:&4@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-S970H)'!E<FUS0V%C:&5;
M)&YA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@)'!E<FUS0V%C:&5;)&YA
M;65=.PH@("`@("`@('T*"B`@("`@("`@)'!E<FUS0V%C:&5;)&YA;65=(#T@
M)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T*"1N86UE+"`G1&%T851R965/
M8FIE8W1?4&5R;6ES<VEO;B<I.PH@("`@("`@(')E='5R;B`D<&5R;7-#86-H
M95LD;F%M95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@1&%T
M851R965/8FIE8W1?4&5R;6ES<VEO;B!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T
M;R!T:&4@9VEV96X*("`@("`J('5N:7%U92!)1"P@=VET:"!T:&4@=7-E<G,@
M86YD(&]T:&5R(&1A=&$@<F5T<FEE=F5D(&%P<')O<')I871E;'DN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE('5N:7%U92!)1"!O
M9B!T:&4@<&5R;6ES<VEO;B!T;R!R971R:65V92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F=E=%!E<FUI<W-I;VY">4ED*"1C:60I"B`@("!["B`@("`@("`@
M:68@*"1C:60@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D;V)J
M96-T(#T@)B1T:&ES+3YN97=097)M:7-S:6]N*$1!5$%44D5%7U)/3U0I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O8FIE8W0@/2`F)'1H:7,M
M/E]D871A=')E92T^9V5T3V)J96-T0GE)9"@D8VED+"`G1&%T851R965/8FIE
M8W1?4&5R;6ES<VEO;B<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&]B
M:F5C=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!P97)M:7-S:6]N
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(%1H92!P97)M:7-S:6]N(&UU
M<W0@9FER<W0*("`@("`J(&)E(&-R96%T960@=VET:"!097)M.CIN97=097)M
M:7-S:6]N*"DL(&%N9"!H879E(&%N>2!I;FET:6%L('5S97)S"B`@("`@*B!A
M9&1E9"!T;R!I="P@8F5F;W)E('1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D+@H@
M("`@("H*("`@("`J($!P87)A;2!$871A5')E94]B:F5C=%]097)M:7-S:6]N
M("1P97)M("!4:&4@;F5W('!E<FT@;V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1097)M:7-S:6]N*"8D<&5R;2D*("`@('L*("`@("`@("!I9B`H
M(6ES7V$H)'!E<FTL("=$871A5')E94]B:F5C=%]097)M:7-S:6]N)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!E<FUI<W-I
M;VYS(&UU<W0@8F4@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!O8FIE8W1S
M(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F%D9"@D<&5R;2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F5S(&$@<&5R;6ES<VEO;B!F<F]M('1H92!P
M97)M:7-S:6]N<R!S>7-T96T@<&5R;6%N96YT;'DN"B`@("`@*@H@("`@("H@
M0'!A<F%M($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@)'!E<FT@(%1H92!P
M97)M:7-S:6]N('1O(')E;6]V92X*("`@("`J($!P87)A;2!B;V]L96%N("1F
M;W)C92`@("`@("`@("`@("`@("`@("!&;W)C92!T;R!R96UO=F4@979E<GD@
M8VAI;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V95!E<FUI<W-I;VXH
M)B1P97)M+"`D9F]R8V4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(6ES
M7V$H)'!E<FTL("=$871A5')E94]B:F5C=%]097)M:7-S:6]N)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!E<FUI<W-I;VYS
M(&UU<W0@8F4@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!O8FIE8W1S(&]R
M(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&%T871R964M/G)E;6]V92@D<&5R;2T^9V5T3F%M92@I
M+"`D9F]R8V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9',@;W5T('=H
M870@<FEG:'1S('1H92!G:79E;B!U<V5R(&AA<R!T;R!T:&ES(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!E<FUI<W-I;VX@(%1H92!F
M=6QL('!E<FUI<W-I;VX@;F%M92!O9B!T:&4@;V)J96-T('1O"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-H96-K('1H92!P97)M:7-S:6]N
M<R!O9BP@;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@;V)J96-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<B`@("`@("!4:&4@=7-E<B!T;R!C:&5C:R!F;W(N
M($1E9F%U;'1S('1O('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('5S97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<F5A
M=&]R("`@(%1H92!U<V5R('=H;R!C<F5A=&5D('1H92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!B:71M87-K(&]F('!E<FUI<W-I
M;VYS+"!A('!E<FUI<W-I;VX@=F%L=64L(&]R(&%N(&%R<F%Y"B`@("`@*B`@
M("`@("`@("`@("`@("!O9B!P97)M:7-S:6]N('9A;'5E<R!T:&4@=7-E<B!H
M87,L(&1E<&5N9&EN9R!O;B!T:&4*("`@("`J("`@("`@("`@("`@("`@('!E
M<FUI<W-I;VX@='EP92!A;F0@=VAE=&AE<B!T:&4@<&5R;6ES<VEO;B!V86QU
M92!I<PH@("`@("H@("`@("`@("`@("`@("`@86UB:6=U;W5S+B!&86QS92!I
M9B!T:&5R92!I<R!N;R!S=6-H('!E<FUS:7-S:6]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971097)M:7-S:6]N<R@D<&5R;6ES<VEO;BP@)'5S97(@/2!N
M=6QL+"`D8W)E871O<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]A
M*"1P97)M:7-S:6]N+"`G1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B<I*2![
M"B`@("`@("`@("`@("1P97)M:7-S:6]N(#T@)B1T:&ES+3YG971097)M:7-S
M:6]N*"1P97)M:7-S:6]N*3L*("`@("`@("`@("`@:68@*&ES7V$H)'!E<FUI
M<W-I;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"1P97)M:7-S:6]N+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1U<V5R
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T
M:"@I.PH@("`@("`@('T*"B`@("`@("`@+R\@268@=&AI<R!I<R!A(&=U97-T
M('5S97(L(&]N;'D@8VAE8VL@9W5E<W0@<&5R;6ES<VEO;G,N"B`@("`@("`@
M:68@*&5M<'1Y*"1U<V5R*2D@>PH@("`@("`@("`@("!R971U<FX@)'!E<FUI
M<W-I;VXM/F=E=$=U97-T4&5R;6ES<VEO;G,H*3L*("`@("`@("!]"@H@("`@
M("`@("\O($EF("1C<F5A=&]R('=A<R!S<&5C:69I960L(&-H96-K(&-R96%T
M;W(@<&5R;6ES<VEO;G,N"B`@("`@("`@:68@*"1C<F5A=&]R("$]/2!N=6QL
M*2!["B`@("`@("`@("`@("\O($EF('1H92!U<V5R(&ES('1H92!C<F5A=&]R
M(&]F('1H92!E=F5N="!S964@:68@=&AE<F4*("`@("`@("`@("`@+R\@87)E
M(&-R96%T;W(@<&5R;6ES<VEO;G,N"B`@("`@("`@("`@(&EF("AS=')L96XH
M)'5S97(I("8F("1U<V5R(#T]/2`D8W)E871O<B`F)@H@("`@("`@("`@("`@
M("`@*"1P97)M<R`]("1P97)M:7-S:6]N+3YG971#<F5A=&]R4&5R;6ES<VEO
M;G,H*2D@(3T](&YU;&PI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<&5R
M;7,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-H96-K
M('5S97(M;&5V96P@<&5R;6ES<VEO;G,N"B`@("`@("`@)'5S97)P97)M<R`]
M("1P97)M:7-S:6]N+3YG9715<V5R4&5R;6ES<VEO;G,H*3L*("`@("`@("!I
M9B`H:7-S970H)'5S97)P97)M<ULD=7-E<ETI*2!["B`@("`@("`@("`@(')E
M='5R;B`D=7-E<G!E<FUS6R1U<V5R73L*("`@("`@("!]"@H@("`@("`@("\O
M($EF(&YO('5S97(@<&5R;6ES<VEO;G,@87)E(&9O=6YD+"!T<GD@9W)O=7`@
M<&5R;6ES<VEO;G,N"B`@("`@("`@:68@*&ES<V5T*"1P97)M:7-S:6]N+3YD
M871A6R=G<F]U<',G72D@)B8*("`@("`@("`@("`@:7-?87)R87DH)'!E<FUI
M<W-I;VXM/F1A=&%;)V=R;W5P<R==*2`F)@H@("`@("`@("`@("!C;W5N="@D
M<&5R;6ES<VEO;BT^9&%T85LG9W)O=7!S)UTI*2!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*("`@("`@("`@("`@)&=R
M;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["@H@("`@("`@("`@("`D8V]M
M<&]S:71E7W!E<FT@/2!N=6QL.PH@("`@("`@("`@("`D='EP92`]("1P97)M
M:7-S:6]N+3YG970H)W1Y<&4G*3L*("`@("`@("`@("`@9F]R96%C:"`H)'!E
M<FUI<W-I;VXM/F1A=&%;)V=R;W5P<R==(&%S("1G<F]U<"`]/B`D<&5R;2D@
M>PH@("`@("`@("`@("`@("`@:68@*"1G<F]U<',M/G5S97))<TEN1W)O=7`H
M)'5S97(L("1G<F]U<"DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-O
M;7!O<VET95]P97)M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VUP;W-I=&5?<&5R;2`]("1T>7!E(#T]("=M871R:7@G(#\@,"`Z
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D='EP92`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]M<&]S:71E7W!E<FT@?#T@)'!E<FT["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;7!O<VET95]P97)M6UT@/2`D<&5R;3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@D8V]M<&]S:71E7W!E<FT@(3T](&YU;&PI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D8V]M<&]S:71E7W!E<FT["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\O($EF('1H97)E(&%R92!D969A=6QT('!E
M<FUI<W-I;VYS+"!R971U<FX@=&AE;2X*("`@("`@("!I9B`H*"1P97)M<R`]
M("1P97)M:7-S:6]N+3YG971$969A=6QT4&5R;6ES<VEO;G,H*2D@(3T](&YU
M;&PI('L*("`@("`@("`@("`@<F5T=7)N("1P97)M<SL*("`@("`@("!]"@H@
M("`@("`@("\O($]T:&5R=VES92P@9&5N>2!A;&P@<&5R;6ES<VEO;G,@=&\@
M=&AE(&]B:F5C="X*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!U;FEQ=64@:61E;G1I9FEE<B!O9B!T
M:&ES('!E<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E
M3V)J96-T7U!E<FUI<W-I;VX@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N
M(&]B:F5C="!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&=E="!T:&4@240@;V8N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!4:&4@=6YI<75E(&ED+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971097)M:7-S:6]N260H)'!E<FUI<W-I;VXI"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$ED*"1P97)M
M:7-S:6]N+3YG971.86UE*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN
M9',@;W5T(&EF('1H92!U<V5R(&AA<R!T:&4@<W!E8VEF:65D(')I9VAT<R!T
M;R!T:&4@9VEV96X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@("`@5&AE('5S97(@=&\@8VAE
M8VL@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FT@("`@("`@5&AE
M('!E<FUI<W-I;VX@;&5V96P@=&AA="!N965D<R!T;R!B92!C:&5C:V5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C<F5A=&]R("`@("!4:&4@8W)E871O<B!O9B!T:&4@
M979E;G0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U
M<V5R+"`D<&5R;2P@)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(')E
M='5R;B`H)'1H:7,M/F=E=%!E<FUI<W-I;VYS*"1P97)M:7-S:6]N+"`D=7-E
M<BP@)&-R96%T;W(I("8@)'!E<FTI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&EF(&$@<&5R;6ES<VEO;B!E>&ES=',@:6X@=&AE('-Y<W1E;2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P97)M:7-S:6]N("!4:&4@
M<&5R;6ES<VEO;B!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AE('!E<FUI<W-I;VX@97AI<W1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>&ES=',H)'!E<FUI<W-I;VXI"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F5X:7-T<R@D<&5R;6ES<VEO
M;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!P
M87)E;G0@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8VAI;&0@(%1H92!N86UE(&]F('1H92!C:&EL9"!T;R!R971R:65V92!P
M87)E;G1S(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA
M<V@@=VET:"!A;&P@<&%R96YT<R!I;B!A('1R964@9F]R;6%T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971087)E;G1S*"1C:&EL9"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT<R@D8VAI;&0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@<&5R;6ES<VEO
M;G,@;V8@=&AE('-Y<W1E;2!I;B!A('1R964@9F]R;6%T+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($$@:&%S:"!W:71H(&%L;"!P97)M:7-S:6]N
M<R!I;B!A('1R964@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T
M5')E92@I"B`@("!["B`@("`@("`@)'1R964@/2`D=&AI<RT^7V1A=&%T<F5E
M+3YG970H1$%40512145?1D]234%47T9,050L($1!5$%44D5%7U)/3U0L('1R
M=64I.PH@("`@("`@(')E='5R;B`D=')E93L*("`@('T*"GT*"B\J*@H@*B!%
M>'1E;G-I;VX@;V8@=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O<B!S=&]R
M:6YG(%!E<FUI<W-I;VX@:6YF;W)M871I;VX@:6X*("H@=&AE($1A=&%4<F5E
M(&1R:79E<BX@268@>6]U('=A;G0@=&\@<W1O<F4@<W!E8VEA;&EZ960@4&5R
M;6ES<VEO;@H@*B!I;F9O<FUA=&EO;BP@>6]U('-H;W5L9"!E>'1E;F0@=&AI
M<R!C;&%S<R!I;G-T96%D(&]F(&5X=&5N9&EN9PH@*B!$871A5')E94]B:F5C
M="!D:7)E8W1L>2X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G
M92!(;W)D95]097)M<PH@*B\*8VQA<W,@1&%T851R965/8FIE8W1?4&5R;6ES
M<VEO;B!E>'1E;F1S($1A=&%4<F5E3V)J96-T('L*"B`@("`O*BH*("`@("`J
M(%1H92!$871A5')E94]B:F5C=%]097)M:7-S:6]N(&-O;G-T<G5C=&]R+B!*
M=7-T(&UA:V5S('-U<F4@=&\@8V%L;"!T:&4*("`@("`J('!A<F5N="!C;VYS
M=')U8W1O<B!S;R!T:&%T('1H92!P97)M)W,@;F%M92!I<R!S970@<')O<&5R
M;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@(%1H92!N
M86UE(&]F('1H92!P97)M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M(%1H92!P97)M:7-S:6]N('1Y<&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@02!H87-H('=I=&@@86YY('!A<F%M971E<G,@=&AA="!T:&4@<&5R
M;6ES<VEO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1Y<&4@;F5E
M9',N"B`@("`@*B\*("`@(&9U;F-T:6]N($1A=&%4<F5E3V)J96-T7U!E<FUI
M<W-I;VXH)&YA;64L("1T>7!E(#T@)VUA=')I>"<L("1P87)A;7,@/2!N=6QL
M*0H@("`@>PH@("`@("`@('!A<F5N=#HZ1&%T851R965/8FIE8W0H)&YA;64I
M.PH@("`@("`@("1T:&ES+3YD871A6R=T>7!E)UT@/2`D='EP93L*("`@("`@
M("!I9B`H:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'1H:7,M
M/F1A=&%;)W!A<F%M<R==(#T@)'!A<F%M<SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'971S(&]N92!O9B!T:&4@871T<FEB=71E<R!O9B!T
M:&4@;V)J96-T+"!O<B!N=6QL(&EF(&ET(&ES;B=T(&1E9FEN960N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D871T<FEB=71E("!4:&4@871T<FEB
M=71E('1O(&=E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M=F%L=64@;V8@=&AE(&%T=')I8G5T92P@;W(@;G5L;"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T*"1A='1R:6)U=&4I"B`@("!["B`@("`@("`@)'9A;'5E
M(#T@<&%R96YT.CIG970H)&%T=')I8G5T92D["B`@("`@("`@:68@*"1V86QU
M92`]/3T@;G5L;"`F)B`D871T<FEB=71E(#T]("=T>7!E)RD@>PH@("`@("`@
M("`@("`D=F%L=64@/2`G;6%T<FEX)SL*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@=&AE
M('!E<FUI<W-I;VYS(&)A<V5D(&]N(&1A=&$@<&%S<V5D(&EN('1H92!A<G)A
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!E<FUS("!!;B!A<G)A
M>2!C;VYT86EN:6YG('1H92!P97)M:7-S:6]N<R!W:&EC:"!A<F4@=&\@8F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@('5P9&%T960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('5P9&%T95!E<FUI<W-I;VYS*"1P97)M<RD*("`@('L*
M("`@("`@("`D='EP92`]("1T:&ES+3YG970H)W1Y<&4G*3L*"B`@("`@("`@
M:68@*"1T>7!E(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("\J($%R<F%Y
M(&]F('!E<FUI<W-I;VX@='EP97,@=&\@:71E<F%T92!T:')O=6=H+B`J+PH@
M("`@("`@("`@("`D<&5R;5]T>7!E<R`](%!E<FUS.CIG971097)M<T%R<F%Y
M*"D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D<&5R;7,@87,@)'!E
M<FU?8VQA<W,@/3X@)'!E<FU?=F%L=65S*2!["B`@("`@("`@("`@('-W:71C
M:"`H)'!E<FU?8VQA<W,I('L*("`@("`@("`@("`@8V%S92`G9&5F875L="<Z
M"B`@("`@("`@("`@(&-A<V4@)V=U97-T)SH*("`@("`@("`@("`@8V%S92`G
M8W)E871O<B<Z"B`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)VUA=')I
M>"<I('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]T>7!E
M<R!A<R`D=F%L(#T^("1L86)E;"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1P97)M7W9A;'5E<ULD=F%L72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971097)M*"1P97)M7V-L87-S
M+"`D=F%L+"!F86QS92D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6YS9710
M97)M*"1P97)M7V-L87-S+"`D=F%L+"!F86QS92D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H(65M<'1Y*"1P97)M7W9A;'5E<RDI('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T4&5R;2@D<&5R;5]C;&%S<RP@)'!E
M<FU?=F%L=65S+"!F86QS92D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YU;G-E=%!E<FTH)'!E<FU?8VQA
M<W,L(&YU;&PL(&9A;'-E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G=2<Z"B`@("`@("`@
M("`@(&-A<V4@)V<G.@H@("`@("`@("`@("`@("`@)'!E<FU)9"`](&%R<F%Y
M*"=C;&%S<R<@/3X@)'!E<FU?8VQA<W,@/3T@)W4G(#\@)W5S97)S)R`Z("=G
M<F]U<',G*3L*("`@("`@("`@("`@("`@("\J($9I9W5R92!O=70@=VAA="!N
M86UE<R!T:&%T(&%R92!S=&]R960@:6X@=&AI<R!P97)M:7-S:6]N"B`@("`@
M("`@("`@("`@("`@*B!C;&%S<R!H879E(&YO="!B965N('-U8FUI='1E9"!F
M;W(@86X@=7!D871E+"!I92X@:&%V92!B965N"B`@("`@("`@("`@("`@("`@
M*B!R96UO=F5D(&5N=&ER96QY+B`J+PH@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?;F%M97,@/2!I<W-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==
M72D*("`@("`@("`@("`@("`@("`@("`_(&%R<F%Y7VME>7,H)'1H:7,M/F1A
M=&%;)'!E<FU)9%LG8VQA<W,G75TI"B`@("`@("`@("`@("`@("`@("`@.B!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@)'5P9&%T961?;F%M97,@/2!A<G)A
M>5]K97ES*"1P97)M7W9A;'5E<RD["B`@("`@("`@("`@("`@("`D<F5M;W9E
M9%]N86UE<R`](&%R<F%Y7V1I9F8H)&-U<G)E;G1?;F%M97,L("1U<&1A=&5D
M7VYA;65S*3L*"B`@("`@("`@("`@("`@("`O*B!296UO=F4@86YY(&YA;65S
M('1H870@:&%V92!B965N(&-O;7!L971E;'D@=6YS970N("HO"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D<F5M;W9E9%]N86UE<R!A<R`D;F%M92D@>PH@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R1P97)M261;
M)V-L87-S)UU=6R1N86UE72D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@+RH@268@;F]T:&EN9R!T;R!A8W1U86QL>2!U<&1A=&4@9FEN
M:7-H('=I=&@@=&AI<R!C87-E+B`J+PH@("`@("`@("`@("`@("`@:68@*"1P
M97)M7W9A;'5E<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J
M($QO;W`@=&AR;W5G:"!T:&4@;F%M97,@86YD('5P9&%T92!P97)M:7-S:6]N
M<R!F;W(@96%C:"X@*B\*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M
M7W9A;'5E<R!A<R`D;F%M92`]/B`D;F%M95]V86QU97,I('L*("`@("`@("`@
M("`@("`@("`@("`D<&5R;4ED6R=N86UE)UT@/2`D;F%M93L*"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M871R:7@G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M7W1Y<&5S(&%S("1V86P@
M/3X@)&QA8F5L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1N86UE7W9A;'5E<ULD=F%L72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4&5R;2@D<&5R;4ED+"`D=F%L
M+"!F86QS92D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU;G-E
M=%!E<FTH)'!E<FU)9"P@)'9A;"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D;F%M95]V86QU97,I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971097)M*"1P
M97)M260L("1N86UE7W9A;'5E<RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU
M;G-E=%!E<FTH)'!E<FU)9"P@;G5L;"P@9F%L<V4I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($9)6$U%.B!N965D<R!D;V-S"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=%!E<FTH)'!E<FU)9"P@)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E
M*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D<&5R;4ED*2D@>PH@("`@
M("`@("`@("!I9B`H96UP='DH)'!E<FU)9%LG;F%M92==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<@)B8*("`@("`@("`@
M("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P
M97)M261;)VYA;64G75TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^9&%T
M85LD<&5R;4ED6R=C;&%S<R==75LD<&5R;4ED6R=N86UE)UU=('P]("1P97)M
M:7-S:6]N.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75U;)'!E<FU)9%LG;F%M92==
M72`]("1P97)M:7-S:6]N.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T
M<FEX)R`F)@H@("`@("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)'!E
M<FU)9%TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD<&5R;4ED
M72!\/2`D<&5R;6ES<VEO;CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YD871A6R1P97)M261=(#T@)'!E<FUI<W-I;VX[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D=7!D871E
M*2!["B`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1DE8344Z(&YE961S(&1O8W,*("`@("`J+PH@
M("`@9G5N8W1I;VX@=6YS971097)M*"1P97)M260L("1P97)M:7-S:6]N+"`D
M=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'!E
M<FU)9"DI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1P97)M261;)VYA;64G
M72DI('L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F1A=&%;)'!E
M<FU)9%LG8VQA<W,G75U;)'!E<FU)9%LG;F%M92==72DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD<&5R
M;4ED6R=N86UE)UU=("8]('XD<&5R;6ES<VEO;CL*("`@("`@("`@("`@("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75U;
M)'!E<FU)9%LG;F%M92==72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M=6YS970H)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75U;)'!E<FU)9%LG
M;F%M92==72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS879E*"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@=6YS970H)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75U;)'!E<FU)
M9%LG;F%M92==72D["B`@("`@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G*2!["B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F1A=&%;)'!E<FU)9%TI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'!E<FU)9%T@
M)CT@?B1P97)M:7-S:6]N.PH@("`@("`@("`@("`@("`@("`@(&EF("@D=7!D
M871E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M
M/F1A=&%;)'!E<FU)9%TI.PH@("`@("`@("`@("`@("`@:68@*"1U<&1A=&4I
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1W)A;G1S(&$@=7-E<B!A9&1I=&EO;F%L('!E<FUI<W-I
M;VYS('1O('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97(@("`@("`@("`@5&AE('5S97(@=&\@9W)A;G0@861D:71I;VYA
M;"!P97)M:7-S:6]N<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T;RX*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@
M5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\@861D+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O
M(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@)'!E<FUI<W-I;VXL("1U<&1A
M=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=7-E<BDI('L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@(&ES
M<V5T*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72DI('L*("`@("`@("`@
M("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S97)=('P]("1P97)M:7-S:6]N
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=U
M<V5R<R==6R1U<V5R72`]("1P97)M:7-S:6]N.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'<F%N=',@9W5E<W1S
M(&%D9&ET:6]N86P@<&5R;6ES<VEO;G,@=&\@=&AI<R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S:6]N("!4:&4@<&5R
M;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N*2!T;R!A9&0N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H97(@=&\@875T;VUA
M=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$=U
M97-T4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BP@)'5P9&%T92`]('1R=64I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX
M)R`F)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^9&%T85LG9W5E<W0G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V=U97-T)UT@?#T@)'!E<FUI
M<W-I;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1A
M=&%;)V=U97-T)UT@/2`D<&5R;6ES<VEO;CL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1W)A;G1S(&-R96%T;W)S
M(&%D9&ET:6]N86P@<&5R;6ES<VEO;G,@=&\@=&AI<R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S:6]N("!4:&4@<&5R
M;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N*2!T;R!A9&0N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H97(@=&\@875T;VUA
M=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-R
M96%T;W)097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7!D871E(#T@=')U92D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R
M:7@G("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R=C<F5A=&]R
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=C<F5A=&]R)UT@?#T@
M)'!E<FUI<W-I;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)V-R96%T;W(G72`]("1P97)M:7-S:6]N.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-A
M=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'<F%N=',@
M861D:71I;VYA;"!D969A=6QT('!E<FUI<W-I;VYS('1O('1H:7,@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@
M5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\@861D+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O
M(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1$969A=6QT4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BP@)'5P9&%T92`]
M('1R=64I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]
M/2`G;6%T<FEX)R`F)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^9&%T85LG
M9&5F875L="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9&5F875L
M="==('P]("1P97)M:7-S:6]N.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YD871A6R=D969A=6QT)UT@/2`D<&5R;6ES<VEO;CL*("`@
M("`@("!]"@H@("`@("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("1T
M:&ES+3YS879E*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1W)A;G1S(&$@9W)O=7`@861D:71I;VYA;"!P97)M:7-S:6]N<R!T;R!T:&ES
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9W)O=7!)
M9"`@("`@(%1H92!I9"!O9B!T:&4@9W)O=7`@=&\@9W)A;G0@861D:71I;VYA
M;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P97)M:7-S
M:6]N<R!T;RX*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@
M5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\@861D+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O
M(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1'<F]U<%!E<FUI<W-I;VXH)&=R;W5P260L("1P97)M:7-S:6]N+"`D
M=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&=R;W5P
M260I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<@)B8*("`@("`@
M("`@("`@:7-S970H)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED72DI
M('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED
M72!\/2`D<&5R;6ES<VEO;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=(#T@)'!E<FUI<W-I
M;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@
M("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V97,@82!P97)M:7-S:6]N('1H870@82!U<V5R(&-U<G)E
M;G1L>2!H87,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!R96UO=F4@=&AE
M('!E<FUI<W-I;VX@9G)O;2X*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R
M;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@
M=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5M;W9E
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R
M('1O(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E<BP@)'!E<FUI<W-I;VXL
M("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=7-E
M<BD@?'P@(6ES<V5T*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72DI('L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`D
M=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ET@)CT@?B1P97)M:7-S:6]N.PH@
M("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S
M97)=*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;)W5S
M97)S)UU;)'5S97)=*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R
M72D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@
M("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V97,@82!P97)M:7-S:6]N('1H870@9W5E<W1S(&-U<G)E
M;G1L>2!H879E(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@*%!%4DU3
M7T1%3$5412P@971C+BD@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T
M92`@("`@("!7:&5T:&5R('1O(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B86-K96YD+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5'=65S=%!E<FUI<W-I;VXH)'!E
M<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/F1A=&%;)V=U97-T)UTI*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E
M)RD@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V=U
M97-T)UT@)CT@?B1P97)M:7-S:6]N.PH@("`@("`@("`@("!I9B`H)'5P9&%T
M92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3YD871A6R=G=65S="==*3L*("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@<&5R
M;6ES<VEO;B!T:&%T(&-R96%T;W)S(&-U<G)E;G1L>2!H879E(&]N('1H:7,@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES
M<VEO;B`@5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5M;W9E+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O
M(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96UO=F5#<F5A=&]R4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BP@)'5P9&%T
M92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^9&%T
M85LG8W)E871O<B==*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G
M*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=C<F5A=&]R)UT@)CT@?B1P
M97)M:7-S:6]N.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=C<F5A
M=&]R)UTI.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!D969A=6QT('!E<FUI
M<W-I;VX@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O
M;G-T86YT("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,
M151%+"!E=&,N*2!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@
M("`@(%=H971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V941E9F%U;'1097)M:7-S:6]N*"1P97)M
M:7-S:6]N+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YD871A6R=D969A=6QT)UTI*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E
M)RD@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V1E
M9F%U;'0G72`F/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@(&EF("@D=7!D
M871E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6YS970H)'1H
M:7,M/F1A=&%;)V1E9F%U;'0G72D["B`@("`@("`@("`@(&EF("@D=7!D871E
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A
M('!E<FUI<W-I;VX@=&AA="!A(&=R;W5P(&-U<G)E;G1L>2!H87,@;VX@=&AI
M<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&=R;W5P
M260@("`@("!4:&4@:60@;V8@=&AE(&=R;W5P('1O(')E;6]V92!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<&5R;6ES<VEO;B!F
M<F]M+@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S:6]N("!4:&4@
M<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N*2!T;PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F4N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H97(@=&\@875T;VUA=&EC
M86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94=R
M;W5P4&5R;6ES<VEO;B@D9W)O=7!)9"P@)'!E<FUI<W-I;VXL("1U<&1A=&4@
M/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D9W)O=7!)9"D@?'P@
M(6ES<V5T*"1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)9%TI*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI
M<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED72`F/2!^)'!E<FUI<W-I;VX[
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9&%T85LG9W)O=7!S)UU;
M)&=R;W5P261=*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A
M=&%;)V=R;W5P<R==6R1G<F]U<$ED72D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M879E*"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=*3L*
M("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS879E*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%L;"!U<V5R('!E
M<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1P97)M("!,:7-T(&]N;'D@=7-E<G,@=VET:"!T:&ES('!E
M<FUI<W-I;VX@;&5V96PN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M1&5F875L=',@=&\@86QL('5S97)S+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%L;"!U<V5R('!E<FUI<W-I;VYS(&9O<B!T:&ES(&]B:F5C="P@
M:6YD97AE9"!B>2!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R
M4&5R;6ES<VEO;G,H)'!E<FT@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/F1A=&%;)W5S97)S)UTI('Q\("%I<U]A<G)A>2@D=&AI
M<RT^9&%T85LG=7-E<G,G72DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("`@("`@?2!E;'-E:68@*"$D<&5R;2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F1A=&%;)W5S97)S)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'5S97)S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/F1A=&%;)W5S97)S)UT@87,@)'5S97(@/3X@)'5P97)M
M*2!["B`@("`@("`@("`@("`@("!I9B`H)'5P97)M("8@)'!E<FTI('L*("`@
M("`@("`@("`@("`@("`@("`D=7-E<G-;)'5S97)=(#T@)'5P97)M.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B`D=7-E<G,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@9W5E<W0@<&5R;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@9W5E<W0@<&5R;6ES
M<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$=U97-T4&5R;6ES<VEO;G,H*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP
M='DH)'1H:7,M/F1A=&%;)V=U97-T)UTI(#\*("`@("`@("`@("`@)'1H:7,M
M/F1A=&%;)V=U97-T)UT@.@H@("`@("`@("`@("!N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W)E871O<B!P97)M:7-S:6]N<R!O
M;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%1H92!C<F5A=&]R('!E<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#<F5A=&]R4&5R;6ES<VEO;G,H*0H@("`@
M>PH@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M/F1A=&%;)V-R96%T;W(G
M72D@/PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG8W)E871O<B==(#H*("`@
M("`@("`@("`@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&1E9F%U;'0@<&5R;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@9&5F875L="!P97)M:7-S
M:6]N<R!O;B!T:&ES(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1&5F875L=%!E<FUI<W-I;VYS*"D*("`@('L*("`@("`@("!R971U<FX@(65M
M<'1Y*"1T:&ES+3YD871A6R=D969A=6QT)UTI(#\*("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)V1E9F%U;'0G72`Z"B`@("`@("`@("`@(&YU;&P["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%L;"!G<F]U
M<"!P97)M:7-S:6]N<R!O;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<&5R;2`@3&ES="!O;FQY('5S97)S('=I=&@@=&AI
M<R!P97)M:7-S:6]N(&QE=F5L+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@($1E9F%U;'1S('1O(&%L;"!U<V5R<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;&P@9W)O=7`@<&5R;6ES<VEO;G,@9F]R('1H:7,@;V)J
M96-T+"!I;F1E>&5D(&)Y(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971'<F]U<%!E<FUI<W-I;VYS*"1P97)M(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3YD871A6R=G<F]U<',G72D@?'P*("`@("`@
M("`@("`@(6ES7V%R<F%Y*"1T:&ES+3YD871A6R=G<F]U<',G72DI('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?2!E;'-E:68@*"$D
M<&5R;2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1A=&%;)V=R;W5P
M<R==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1G<F]U<',@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%T85LG9W)O
M=7!S)UT@87,@)&=R;W5P(#T^("1G<&5R;2D@>PH@("`@("`@("`@("`@("`@
M:68@*"1G<&5R;2`F("1P97)M*2!["B`@("`@("`@("`@("`@("`@("`@)&=R
M;W5P<ULD9W)O=7!=(#T@)&=P97)M.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9W)O=7!S.PH@("`@("`@
M('T*("`@('T*"GT*````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(O````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`R,3$S-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]M>7-Q;"YP
M:'``````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C0R-#``,3`U,34T,S$P-C``
M,#(S,#$T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T
M:6]N(&9O<B!->5-13"`H;F%T:79E*2X*("H*("H@4F5Q=6ER960@<&%R86UE
M=&5R<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@("`M(%1H92!H;W-T;F%M92!O
M9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@("`M(%1H
M92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N
M*2X*("H@("`G=7-E<FYA;64G("`@+2!4:&4@=7-E<FYA;64@=VET:"!W:&EC
M:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G
M("`@+2!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N
M"B`J("`@)V1A=&%B87-E)R`@("T@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E
M+@H@*B`@("=T86)L92<@("`@("`M(%1H92!N86UE(&]F('1H92!S97-S:6]N
M9&%T82!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("=R;W=L;V-K:6YG)R`M
M(%=H971H97(@=&\@=7-E(')O=RUL979E;"!L;V-K:6YG(&%N9"!T<F%N<V%C
M=&EO;G,@*$EN;F]$0BD*("H@("`@("`@("`@("`@("`@("!O<B!T86)L92UL
M979E;"!L;V-K:6YG("A->4E304TI+CPO<')E/@H@*@H@*B!297%U:7)E9"!F
M;W(@<V]M92!C;VYF:6=U<F%T:6]N<SH\<')E/@H@*B`@("=P;W)T)R`@5&AE
M('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P
M<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G<&5R
M<VES=&5N="<@(%5S92!P97)S:7-T96YT($1"(&-O;FYE8W1I;VYS/R`H8F]O
M;&5A;BD\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE
M(%-E<W-I;VY(86YD;&5R(&-A;B!B92!F;W5N9"!I;@H@*B!H;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS<6PN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VUY
M<W%L+G!H<"QV(#$N,38N,3(N,30@,C`P-B\P,R\R.2`Q.3HP-CHT-B!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%M92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N
M9&QE<E]M>7-Q;"!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*
M("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C
M=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@
M('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@07)E('=E(&-O;FYE8W1E9"!T
M;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I
M"B`@("!["B`@("`@("`@+RH@1&ES8V]N;F5C="!F<F]M(&1A=&%B87-E+B`J
M+PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U
M<FX@0&UY<W%L7V-L;W-E*"1T:&ES+3Y?9&(I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H
M92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R
M;VT@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF
M:65R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO
M;B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*
M("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E
M(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@
M("`@("`@("\J(%-E<W-I;VX@=&EM96]U="P@9&]N)W0@<F5L>2!O;B!G87)B
M86=E(&-O;&QE8W1I;VXN("HO"B`@("`@("`@)'1I;65O=70@/2!T:6UE*"D@
M+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T:6UE)RD["@H@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E
M<R!72$5212!S97-S:6]N7VED(#T@)7,G("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("<@04Y$('-E<W-I;VY?;&%S=&UO9&EF:65D(#X@)7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W%U;W1E*"1I9"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&EM96]U="D["@H@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W)O=VQO8VMI;F<G72DI('L*
M("`@("`@("`@("`@+RH@4W1A<G0@82!T<F%N<V%C=&EO;BX@*B\*("`@("`@
M("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G4U1!4E0@5%)!3E-!0U1)
M3TXG+"`D=&AI<RT^7V1B*3L*("`@("`@("`@("`@)'%U97)Y("X]("<@1D]2
M(%501$%412<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L
M="`]($!M>7-Q;%]Q=65R>2@G3$]#2R!404),15,@)R`N("1T:&ES+3Y?<&%R
M86US6R=T86)L92==("X@)R!74DE412<L("1T:&ES+3Y?9&(I.PH@("`@("`@
M('T*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A
M($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;7ES<6PZ
M.G)E860H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E<GDL
M("1T:&ES+3Y?9&(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@<F5T<FEE=FEN9R!S97-S
M:6]N(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@0&UY<W%L7W)E<W5L="@D<F5S=6QT+"`P+"`P*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T82!T;R!T:&4@4V5S
M<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N
M(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@("\J
M($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO
M;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@
M0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"=215!,04-%($E.5$\@)7,@*'-E<W-I;VY?:60L('-E<W-I;VY?9&%T
M82P@<V5S<VEO;E]L87-T;6]D:69I960I)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G(%9!3%5%4R`H)7,L("5S+"`E<RDG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W%U;W1E*"1I9"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W%U;W1E*"1S97-S:6]N7V1A=&$I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@=&EM92@I*3L*"B`@("`@("`@
M)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3Y?9&(I.PH@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<F]W;&]C:VEN9R==
M*2D@>PH@("`@("`@("`@("!`;7ES<6Q?<75E<GDH)U5.3$]#2R!404),15,@
M)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^7V1B*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@($!M
M>7-Q;%]Q=65R>2@G4D],3$)!0TLG+"`D=&AI<RT^7V1B*3L*("`@("`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R('=R:71I;F<@<V5S<VEO;B!D
M871A)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!`;7ES
M<6Q?<75E<GDH)T-/34U)5"<L("1T:&ES+3Y?9&(I.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@=&AE(&1A
M=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@:6X@=&AE
M"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S
M+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<W1R
M;WDH)&ED*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@
M=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^
M7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@
M*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!7
M2$5212!S97-S:6]N7VED(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("1T:&ES+3Y?<75O=&4H)&ED
M*2D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@
M;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G
M4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7VUY<W%L.CID97-T<F]Y*"DZ
M('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U
M;'0@/2!`;7ES<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^7V1B*3L*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W)O=VQO8VMI;F<G72DI('L*
M("`@("`@("`@("`@0&UY<W%L7W%U97)Y*"=53DQ/0TL@5$%"3$53("<@+B`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/E]D8BD["B`@("`@("`@
M?0H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!`;7ES<6Q?
M<75E<GDH)U)/3$Q"04-+)RP@)'1H:7,M/E]D8BD["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=&86EL960@=&\@9&5L971E('-E<W-I;VX@*&ED
M(#T@)R`N("1I9"`N("<I)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!`;7ES<6Q?<75E<GDH)T-/34U)5"<L("1T:&ES+3Y?9&(I.PH*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=A
M<F)A9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F<F]M('1H92!397-S:6]N
M2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1M87AL:69E=&EM92`@5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D
M;6%X;&EF971I;64@/2`S,#`I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E
M('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@
M4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$54
M12!&4D]-("5S(%=(15)%('-E<W-I;VY?;&%S=&UO9&EF:65D(#P@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTL("AI;G0I*'1I;64H*2`M("1M87AL:69E=&EM92DI.PH*("`@("`@("`O
M*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!3
M97-S:6]N2&%N9&QE<E]M>7-Q;#HZ9V,H*3H@<75E<GD@/2`B)7,B)RP@)'%U
M97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T
M:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D
M<75E<GDL("1T:&ES+3Y?9&(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@9V%R8F%G92!C
M;VQL96-T:6YG(&]L9"!S97-S:6]N<R<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N($!M>7-Q;%]A9F9E8W1E9%]R;W=S*"1T
M:&ES+3Y?9&(I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O
M9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@=F%L:60@<V5S<VEO;B!I9&5N
M=&EF:65R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5S<VEO;DE$<R@I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D
M871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`O*B!397-S:6]N('1I;65O=70L(&1O;B=T(')E;'D@
M;VX@9V%R8F%G92!C;VQL96-T:6]N("HO"B`@("`@("`@)'1I;65O=70@/2!T
M:6UE*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T:6UE)RD["@H@
M("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7VED($92
M3TT@)7,G("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@5TA%4D4@<V5S
M<VEO;E]L87-T;6]D:69I960@/B`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:6UE;W5T*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R
M>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?
M;7ES<6PZ.F=E=%-E<W-I;VY)1',H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]($!M>7-Q
M;%]Q=65R>2@D<75E<GDL("1T:&ES+3Y?9&(I.PH@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@
M9V5T=&EN9R!S97-S:6]N($E$<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'-E
M<W-I;VYS(#T@87)R87DH*3L*"B`@("`@("`@=VAI;&4@*"1R;W<@/2!M>7-Q
M;%]F971C:%]R;W<H)')E<W5L="DI"B`@("`@("`@("`@("1S97-S:6]N<UM=
M(#T@)')O=ULP73L*"B`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($5S8V%P92!A(&UY<W%L('-T<FEN9RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1V86QU92`@5&AE('-T<FEN9R!T;R!Q=6]T92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('%U;W1E9"!S=')I;F<N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]Q=6]T92@D=F%L=64I"B`@("!["B`@("`@("`@
M<W=I=&-H("AS=')T;VQO=V5R*&=E='1Y<&4H)'9A;'5E*2DI('L*("`@("`@
M("!C87-E("=N=6QL)SH*("`@("`@("`@("`@<F5T=7)N("=.54Q,)SL*"B`@
M("`@("`@8V%S92`G:6YT96=E<B<Z"B`@("`@("`@("`@(')E='5R;B`D=F%L
M=64["@H@("`@("`@(&-A<V4@)W-T<FEN9R<Z"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@<F5T=7)N("(G(B`N($!M>7-Q;%]R96%L7V5S8V%P95]S
M=')I;F<H)'9A;'5E+"`D=&AI<RT^7V1B*2`N("(G(CL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C
M=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I
M=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@
M("`@("`@("`@("!A<G)A>2@G:&]S='-P96,G+"`G=7-E<FYA;64G+"`G9&%T
M86)A<V4G*2P*("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!->5-13"<I
M.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==
M(#T@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==(#T@)VAO<F1E7W-E<W-I;VYH86YD;&5R)SL*("`@("`@("!]
M"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N
M="==*2D@>PH@("`@("`@("`@("`D8V]N;F5C="`]("=M>7-Q;%]C;VYN96-T
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V]N;F5C="`]("=M
M>7-Q;%]P8V]N;F5C="<["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES
M+3Y?9&(@/2!`)&-O;FYE8W0H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD
M(&YO="!C;VYN96-T('1O(&1A=&%B87-E(&9O<B!344P@4V5S<VEO;DAA;F1L
M97(N)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(4!M>7-Q;%]S96QE8W1?9&(H)'1H:7,M/E]P87)A;7-;)V1A=&%B
M87-E)UTL("1T:&ES+3Y?9&(I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"A014%2.CIR86ES945R<F]R*'-P<FEN=&8H)T-O=6QD(&YO="!C;VYN96-T
M('1O('1A8FQE("5S(&9O<B!344P@4V5S<VEO;DAA;F1L97(N)RP@)'1H:7,M
M/E]P87)A;7-;)V1A=&%B87-E)UTI+"!?7T9)3$5?7RP@7U],24Y%7U\I*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+VYO;F4N<&AP````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S4R
M,@`Q,#4Q-30S,3`V,``P,C(V,#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%-E<W-I;VY(86YD;&5R
M(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!B=6EL="UI;B!S97-S:6]N(&AA
M;F1L97(N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("!.
M;VYE+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J
M("`@3F]N92X\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`L=B`Q+C,N,BXT(#(P
M,#8O,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`U+3(P,#8@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-871T(%-E;'-K>2`\<V5L<VMY
M0&-O;'5M8FEA+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K
M86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N
M9&QE<E]N;VYE(&5X=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@
M("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@
M:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E
M<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9"@D:60I"B`@("!["B`@("`@("`@)&9I;&4@/2!S97-S:6]N7W-A=F5?<&%T
M:"@I("X@1$E214-43U)97U-%4$%2051/4B`N("=S97-S7R<@+B`D:60["@H@
M("`@("`@("1S97-S:6]N7V1A=&$@/2!`9FEL95]G971?8V]N=&5N=',H)&9I
M;&4I.PH@("`@("`@(&EF("@D<V5S<VEO;E]D871A(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@
M=&\@<F5A9"!F:6QE.B`B*2`N("1F:6QE*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<V5S<VEO;E]D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@=F%L:60@
M<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4V5S<VEO;DE$<R@I"B`@("!["B`@("`@("`@)'-E<W-I;VYS(#T@87)R87DH
M*3L*"B`@("`@("`@)'!A=&@@/2!S97-S:6]N7W-A=F5?<&%T:"@I.PH@("`@
M("`@("1D(#T@9&ER*&5M<'1Y*"1P871H*2`_(%5T:6PZ.F=E=%1E;7!$:7(H
M*2`Z("1P871H*3L*"B`@("`@("`@=VAI;&4@*&9A;'-E("$]/2`H)&5N=')Y
M(#T@)&0M/G)E860H*2DI('L*("`@("`@("`@("`@+RH@36%K92!S=7)E('=E
M)W)E(&1E86QI;F<@=VET:"!F:6QE<R!T:&%T('-T87)T('=I=&@*("`@("`@
M("`@("`@("H@<V5S<U\N("HO"B`@("`@("`@("`@(&EF("AI<U]F:6QE*"1D
M+3YP871H("X@1$E214-43U)97U-%4$%2051/4B`N("1E;G1R>2D@)B8*("`@
M("`@("`@("`@("`@("%S=')N8VUP*"1E;G1R>2P@)W-E<W-?)RP@<W1R;&5N
M*"=S97-S7R<I*2D@>PH@("`@("`@("`@("`@("`@)'-E<W-I;VYS6UT@/2!S
M=6)S='(H)&5N=')Y+"!S=')L96XH)W-E<W-?)RDI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-E<W-I;VYS.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE
M<B]L9&%P+G!H<```````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`P-C<`,3`U
M,34T,S$P-C``,#(R-3<Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<B!I;7!L
M96UE;G1A=&EO;B!F;W(@3$1!4"!D:7)E8W1O<FEE<RX*("H*("H@4F5Q=6ER
M960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=F;V\G("`@("`@(%1H92!F;V\N
M"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S='-P
M96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&QD87`@<V5R=F5R+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<B]L9&%P+G!H<"QV(#$N,BXR+C(@,C`P-2\Q,"\Q."`Q,3HP,3HR-R!J86X@
M17AP("0*("H*("H@5&AI<R!C;V1E(&ES(&%D87!T960@9G)O;2!T:&4@8V]M
M;65N=',@870*("H@:'1T<#HO+W=W=RYP:'`N;F5T+W-E<W-I;VXM<V5T+7-A
M=F4M:&%N9&QE<BX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!S:6YC92`@($AO<F1E
M(#,N,0H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA
M<W,@4V5S<VEO;DAA;F1L97)?;&1A<"!E>'1E;F1S(%-E<W-I;VY(86YD;&5R
M('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T
M86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E
M"B`@("`@*B\*("`@('9A<B`D7V-O;FX["@H@("`@+RHJ"B`@("`@*B!/<&5N
M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'-A=F5?<&%T:"`@("`@5&AE('!A=&@@=&\@=&AE('-E
M<W-I;VX@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]N
M86UE("!4:&4@;F%M92!O9B!T:&4@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W
M:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"1S879E7W!A=&@L("1S
M97-S:6]N7VYA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN(#T@0&QD
M87!?8V]N;F5C="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P@)'1H:7,M
M/E]P87)A;7-;)W!O<G0G72D["B`@("`@("`@<F5T=7)N($!L9&%P7V)I;F0H
M)'1H:7,M/E]C;VYN+"`D=&AI<RT^7W!A<F%M<ULG9&XG72P@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO
M<V4@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R
M=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@
M("`@(')E='5R;B!`;&1A<%]C;&]S92@D=&AI<RT^7V-O;FXI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R
M('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA
M;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@("`@)'-R(#T@0&QD87!?<V5A
M<F-H*"1T:&ES+3Y?8V]N;BP@)'1H:7,M/E]P87)A;7-;)V1N)UTL("(H8VX]
M)&ED*2(I.PH@("`@("`@("1I;F9O(#T@0&QD87!?9V5T7V5N=')I97,H)'1H
M:7,M/E]C;VYN+"`D<W(I.PH@("`@("`@(&EF("@D:6YF;ULG8V]U;G0G72`^
M(#`I('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O6S!=6R=S97-S:6]N)UU;
M,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@
M9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N
M(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A
M=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@
M("`@>PH@("`@("`@("1U<&1A=&4@/2!A<G)A>2@G;V)J96-T0VQA<W,G(#T^
M(&%R<F%Y*"=P:'!S97-S:6]N)RP@)W1O<"<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G<V5S<VEO;B<@/3X@)'-E<W-I;VY?9&%T82D["B`@("`@("`@
M)&1N(#T@(F-N/21I9"PB("X@)'1H:7,M/E]P87)A;7-;)V1N)UT["B`@("`@
M("`@0&QD87!?9&5L971E*"1T:&ES+3Y?8V]N;BP@)&1N*3L*("`@("`@("!R
M971U<FX@0&QD87!?861D*"1T:&ES+3Y?8V]N;BP@)&1N+"`D=7!D871E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@=&AE(&1A=&$@9F]R(&$@
M<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@:6X@=&AE"B`@("`@*B!3
M97-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<W1R;WDH)&ED*0H@
M("`@>PH@("`@("`@("1D;B`](")C;CTD:60L(B`N("1T:&ES+3Y?<&%R86US
M6R=D;B==.PH@("`@("`@(')E='5R;B!`;&1A<%]D96QE=&4H)'1H:7,M/E]C
M;VYN+"`D9&XI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL
M96-T('-T86QE('-E<W-I;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD;&5R(&)A
M8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QI9F5T
M:6UE("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S97-S:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL:69E=&EM
M92`](#,P,"D*("`@('L*("`@("`@("`D<W(@/2!`;&1A<%]S96%R8V@H)'1H
M:7,M/E]C;VYN+"`D=&AI<RT^7W!A<F%M<ULG9&XG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)RAO8FIE8W1#;&%S<SUP:'!S97-S:6]N*2<L(&%R
M<F%Y*"<K)RP@)V-N)RDI.PH@("`@("`@("1I;F9O(#T@0&QD87!?9V5T7V5N
M=')I97,H)'1H:7,M/E]C;VYN+"`D<W(I.PH@("`@("`@(&EF("@D:6YF;ULG
M8V]U;G0G72`^(#`I('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&EN9F];)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("1I9"`]
M("1I;F9O6R1I75LG8VXG75LP73L*("`@("`@("`@("`@("`@("1D;B`](")C
M;CTD:60L(B`N("1T:&ES+3Y?<&%R86US6R=D;B==.PH@("`@("`@("`@("`@
M("`@)&QD87!S=&%M<"`]("1I;F9O6R1I75LG;6]D:69Y=&EM97-T86UP)UU;
M,%T["B`@("`@("`@("`@("`@("`D>65A<B`]('-U8G-T<B@D;&1A<'-T86UP
M+"`P+"`T*3L*("`@("`@("`@("`@("`@("1M;VYT:"`]('-U8G-T<B@D;&1A
M<'-T86UP+"`T+"`R*3L*("`@("`@("`@("`@("`@("1D87D@/2!S=6)S='(H
M)&QD87!S=&%M<"P@-BP@,BD["B`@("`@("`@("`@("`@("`D:&]U<B`]('-U
M8G-T<B@D;&1A<'-T86UP+"`X+"`R*3L*("`@("`@("`@("`@("`@("1M:6YU
M=&4@/2!S=6)S='(H)&QD87!S=&%M<"P@,3`L(#(I.PH@("`@("`@("`@("`@
M("`@)&UO9&EF:65D(#T@9VUM:W1I;64H)&AO=7(L("1M:6YU=&4L(#`L("1M
M;VYT:"P@)&1A>2P@)'EE87(I.PH@("`@("`@("`@("`@("`@:68@*'1I;64H
M*2`M("1M;V1I9FEE9"`^/2`D;6%X;&EF971I;64I('L*("`@("`@("`@("`@
M("`@("`@("!`;&1A<%]D96QE=&4H)'1H:7,M/E]C;VYN+"`D9&XI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+W-A<&1B+G!H
M<``````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C,P-P`Q,#4Q-30S,3`V,``P
M,C(W-#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M<W%L+G!H<"<["@HO*BH*("H@4V5S<VEO;DAA;F1L97(@:6UP;&5M96YT871I
M;VX@9F]R(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX@;&%Y97(N
M"B`J"B`J($EF('EO=2!A8V-E<W,@>6]U<B!D871A8F%S92!T:')O=6=H($]$
M0D,L('EO=2!W:6QL(&%L;6]S="!C97)T86EN;'D@;F5E9`H@*B!T;R!C:&%N
M9V4@4$A0)W,@9&5F875L="!V86QU92!F;W(@;V1B8RYD969A=6QT;')L("AT
M:&ES(&ES(&$@<&AP+FEN:0H@*B!S971T:6YG*2X@5&AE(&1E9F%U;'0@:7,@
M-#`Y-BP@=VAI8V@@:7,@=&]O('-M86QL("AY;W5R('-E<W-I;VX@9&%T82!W
M:6QL"B`J(&)E(&-H;W!P960@;V9F*2P@86YD('-E='1I;F<@:70@=&\@,"!$
M3T53($Y/5"!W;W)K("T@=&AA="!D;V5S;B=T(&UE86X@;F\*("H@;&EM:70L
M(&9O<B!S;VUE(')E87-O;BX@;V1B8RYD969A=6QT;')L(#T@,S(W-C@@<V5E
M;7,@=&\@=V]R:R!P<F5T='D@=V5L;`H@*B`H=7-I;F<@35-344PM,C`P,"DN
M"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S='-P
M96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@
M("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C
M<"<L("=U;FEX)RP@971C+BDN"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N
M86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J
M("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G
M=7-E<FYA;64G+@H@*B`@("=D871A8F%S92<@(%1H92!N86UE(&]F('1H92!D
M871A8F%S92X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E
M/@H@*B`@("=T86)L92<@("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T
M82!T86)L92!I;B`G9&%T86)A<V4G+B`@1&5F875L="!I<PH@*B`@("`@("`@
M("`@("`@("=H;W)D95]S97-S:6]N:&%N9&QE<B<N/"]P<F4^"B`J"B`J(%1H
M92!T86)L92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N2&%N9&QE<B!C86X@
M8F4@9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO
M;FAA;F1L97(N<V%P9&(N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]S87!D8BYP:'`L=B`Q+C$S
M+C$R+C@@,C`P-B\P,2\P,2`R,3HR.#HS-"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J
M+PIC;&%S<R!397-S:6]N2&%N9&QE<E]S87!D8B!E>'1E;F1S(%-E<W-I;VY(
M86YD;&5R7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M(%-13"!397-S:6]N2&%N9&QE<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4V5S<VEO;DAA
M;F1L97)?<V%P9&(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'!A<F%M<ULG<&AP='EP92==(#T@)V]D8F,G.PH@("`@("`@('!A<F5N=#HZ
M4V5S<VEO;DAA;F1L97)?<W%L*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@
M:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E
M<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9"@D:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V
M86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?
M8V]N;F5C="@I.PH*("`@("`@("`O*B!"96=I;B!A('1R86YS86-T:6]N+B`J
M+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YA=71O8V]M;6ET*&9A
M;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-1
M3"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@
M<V5S<VEO;E]D871A($923TT@)7,@5TA%4D4@<V5S<VEO;E]I9"`]("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O
M=&4H)&ED*2D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)5
M1R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R
M:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W-Q;#HZ<F5A9"@I
M.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2`J+PH@("`@("`@("1R97-U
M;'0@/2!O9&)C7V5X96,H)'1H:7,M/E]D8BT^8V]N;F5C=&EO;BP@)'%U97)Y
M*3L*("`@("`@("!O9&)C7VQO;F=R96%D;&5N*"1R97-U;'0L(#$P-#@U-S8I
M.PH*("`@("`@("`O*B!&971C:"!T:&4@=F%L=64@*B\*("`@("`@("!O9&)C
M7V9E=&-H7W)O=R@D<F5S=6QT+"`P*3L*("`@("`@("`D9&%T82`](&]D8F-?
M<F5S=6QT*"1R97-U;'0L("=S97-S:6]N7V1A=&$G*3L*"B`@("`@("`@+RH@
M0VQE86X@=7`@*B\*("`@("`@("!O9&)C7V9R965?<F5S=6QT*"1R97-U;'0I
M.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]S<6PN<&AP
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,W,#$`,3`U,34T,S$P-C``
M,#(R-#0W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<B!I;7!L96UE;G1A=&EO
M;B!F;W(@4$A0)W,@4$5!4B!D871A8F%S92!A8G-T<F%C=&EO;B!L87EE<BX*
M("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P:'!T>7!E
M)R`@(%1H92!D871A8F%S92!T>7!E("AE+F<N("=P9W-Q;"<L("=M>7-Q;"<L
M(&5T8RXI+CPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B87-E
M(&EM<&QE;65N=&%T:6]N<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H
M;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O
M;"<@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G
M+"!E=&,N*2X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T
M86)A<V4N"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@=VAI
M8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D
M)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@
M*B`@("=O<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O
M('1H92!D871A8F%S92X*("H@("`G='1Y)R`@("`@("!4:&4@5%19(&]N('=H
M:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T)R`@
M("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B
M87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J
M("`@)W!E<G-I<W1E;G0G("!5<V4@<&5R<VES=&5N="!$0B!C;VYN96-T:6]N
M<S\@*&)O;VQE86XI"B`J("`@)W1A8FQE)R`@("`@("!4:&4@;F%M92!O9B!T
M:&4@<V5S<VEO;F1A=&$@=&%B;&4@:6X@)V1A=&%B87-E)RX@($1E9F%U;'0*
M("H@("`@("`@("`@("`@("`@(&ES("=H;W)D95]S97-S:6]N:&%N9&QE<B<N
M/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!397-S
M:6]N2&%N9&QE<B!C86X@8F4@9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S
M<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]S<6PN<&AP
M+'8@,2XR,BXQ,"XQ,R`R,#`V+S`Q+S`Q(#(Q.C(X.C,T(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4V5S<VEO;DAA
M;F1L97(*("HO"F-L87-S(%-E<W-I;VY(86YD;&5R7W-Q;"!E>'1E;F1S(%-E
M<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE
M(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`
M=F%R($1""B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@
M0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE
M8W1E9"!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@
M("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&]S92@I"B`@("!["B`@("`@("`@+RH@1&ES8V]N;F5C="!F<F]M(&1A=&%B
M87-E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@
M("`@("`@("`O*B!#;&]S92!A;GD@;W!E;B!T<F%N<V%C=&EO;G,N("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?9&(M/F-O;6UI="@I.PH@("`@("`@("`@("`D
M=&AI<RT^7V1B+3YA=71O0V]M;6ET*'1R=64I.PH*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T
M82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H
M90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@
M("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN
M96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@
M("`O*B!"96=I;B!A('1R86YS86-T:6]N+B`J+PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YA=71O8V]M;6ET*&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M('T*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]344PN<&AP)SL*("`@("`@("`D<F5S=6QT
M(#T@2&]R9&5?4U%,.CIR96%D0FQO8B@D=&AI<RT^7V1B+"`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72P@)W-E<W-I;VY?9&%T82<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-E<W-I;VY?:60G(#T^
M("1I9"DI.PH*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A=&$@
M=&\@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I9&5N
M=&EF:65R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4
M:&4@<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@('L*
M("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E
M(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@
M("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G4T5,14-4('-E<W-I;VY?:60@1E)/32`E<R!72$52
M12!S97-S:6]N7VED(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@)'9A;'5E<R`](&%R
M<F%Y*"1I9"D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)5
M1R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R
M:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W-Q;#HZ=W)I=&4H
M*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&(M/F=E=$]N92@D<75E<GDL("1V86QU97,I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+U-13"YP:'`G.PH@("`@("`@(&EF("@D<F5S=6QT*2!["B`@("`@("`@("`@
M("1R97-U;'0@/2!(;W)D95]344PZ.G5P9&%T94)L;V(H)'1H:7,M/E]D8BP@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("=S97-S:6]N7V1A=&$G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S97-S
M:6]N7V1A=&$L(&%R<F%Y*"=S97-S:6]N7VED)R`]/B`D:60I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S
M97-S:6]N7VQA<W1M;V1I9FEE9"<@/3X@=&EM92@I*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<W5L="`]($AO<F1E7U-13#HZ:6YS97)T
M0FQO8B@D=&AI<RT^7V1B+"`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)W-E
M<W-I;VY?9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-E<W-I;VY?9&%T82P@87)R87DH)W-E<W-I;VY?:60G
M(#T^("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5S<VEO;E]L87-T;6]D
M:69I960G(#T^('1I;64H*2DI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V1B+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YA
M=71O0V]M;6ET*'1R=64I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V1B+3YC;VUM:70H*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E*3L*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R
M;WD@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I
M97(@:6X@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N
M=&EF:65R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E<W1R;WDH)&ED*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W
M92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@
M("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-1
M3"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@
M1E)/32`E<R!72$5212!S97-S:6]N7VED(#T@/R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"1I9"D["@H@("`@("`@("\J($QO9R!T:&4@<75E
M<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R
M7W-Q;#HZ9&5S=')O>2@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@
M*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y
M+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U
M;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/F-O;6UI="@I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=A
M<F)A9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F<F]M('1H92!397-S:6]N
M2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1M87AL:69E=&EM92`@5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D
M;6%X;&EF971I;64@/2`S,#`I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E
M('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@
M4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$54
M12!&4D]-("5S(%=(15)%('-E<W-I;VY?;&%S=&UO9&EF:65D(#P@/R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*'1I;64H*2`M("1M87AL:69E
M=&EM92D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L
M;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT
M9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W-Q;#HZ9V,H*3H@<75E
M<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N
M=&EF:65R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@
M;V8@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4V5S<VEO;DE$<R@I"B`@("!["B`@("`@("`@+RH@36%K92!S
M=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@
M("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D=&EM96]U="`]
M('1I;64H*2`M(&EN:5]G970H)W-E<W-I;VXN9V-?;6%X;&EF971I;64G*3L*
M"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D
M<75E<GD@/2`G4T5,14-4('-E<W-I;VY?:60@1E)/32`G("X@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@<V5S
M<VEO;E]L87-T;6]D:69I960@/B`_)SL*("`@("`@("`D=F%L=65S(#T@87)R
M87DH)'1I;65O=70I.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@
M1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]S<6PZ.F=E
M=%-E<W-I;VY)1',H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDL
M(#`L("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E
M<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(&]P96X@82!C;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S.R!E>&ET
M<R`H2&]R9&4Z.F9A=&%L*"DI(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-O
M;FYE8W1E9"D@>PH@("`@("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N
M9FEG*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@
M("`@("`@("`@87)R87DH)W!H<'1Y<&4G*2P*("`@("`@("`@("`@("`@("=S
M97-S:6]N(&AA;F1L97(@4U%,)RD["@H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U
M<V5R;F%M92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W5S97)N86UE)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72`]("=H;W)D95]S97-S:6]N:&%N9&QE<B<["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S
M97)V97(@=7-I;F<@=&AE('-U<'!L:65D"B`@("`@("`@("`@("`J('!A<F%M
M971E<G,N("HO"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G1$(N<&AP)SL*
M("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^
M7W!A<F%M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES
M+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E
M.CIF871A;"@D=&AI<RT^7V1B+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH
M)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?
M4$]25$%"24Q)5%E?15)23U)3*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]M96UC86-H92YP
M:'``````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38R,38`,3`U,34T,S$P-C``,#(S
M-#$U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N
M(&9O<B!M96UC86-H92X*("H@;65M8V%C:&4@=V5B<VET93H@:'1T<#HO+W=W
M=RYD86YG82YC;VTO;65M8V%C:&5D+PH@*@H@*B!297%U:7)E9"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H
M92!M96UC86-H92!S97)V97(N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@
M;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@;65M8V%C:&4@<V5R=F5R+CPO
M<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!E
M<G-I<W1E;G0G("!5<V4@<&5R<VES=&5N="!$0B!C;VYN96-T:6]N<S\@*&)O
M;VQE86XI"B`J("`@)V-O;7!R97-S:6]N)R!5<V4@8V]M<')E<W-I;VX@=VAE
M;B!S=&]R:6YG('-E<W-I;VYS+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]M96UC86-H92YP
M:'`L=B`Q+C$N,BXQ(#(P,#8O,#4O,#(@,3<Z,C<Z-#D@8VAU8VL@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!2;VYG+45N($9A;B`\<F%F86Y`
M:6YF;W(N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]N9RU%
M;B!&86X@/')A9F%N0&EN9F]R+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ
M"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!3
M97-S:6]N2&%N9&QE<E]M96UC86-H92!E>'1E;F1S(%-E<W-I;VY(86YD;&5R
M('L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@;65M8V%C:&4@8V]N;F5C=&EO
M;BX*("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@
M)%]D8CL*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T
M:&5R(&]R(&YO="!W92=R92!C;VYN96-T960@=&\@=&AE"B`@("`@*B!M96UC
M86-H92!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@3&]C:R!H86YD;&4N"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@
M("`@("HO"B`@("!V87(@)%]F<#L*"B`@("`O*BH*("`@("`J($-L;W-E('1H
M92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@0&UE;6-A8VAE7V-L;W-E
M*"1T:&ES+3Y?9&(I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]U;FQO
M8VM397-S:6]N*"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S
M<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE
M<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4
M:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96%D*"1I9"D*("`@('L*("`@("`@("`O*B!/8G1A:6X@<V5S<VEO;B!L
M;V-K+B`J+PH@("`@("`@("1T:&ES+3Y?;&]C:U-E<W-I;VXH)&ED*3L*"B`@
M("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!M96UC86-H92!C
M;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@
M("`@("`D<F5S=6QT(#T@0&UE;6-A8VAE7V=E="@D=&AI<RT^7V1B+"`D:60I
M.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G17)R;W(@<F5T<FEE=FEN9R!S97-S:6]N(&1A=&$@*&ED
M(#T@)R`N("1I9"`N("<I)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("`D=&AI<RT^7W5N;&]C:U-E<W-I;VXH*3L*
M("`@("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7W!A<F%M<ULG;&]C:U]D:7(G
M72`N("<O;&]C:U\G("X@)&ED*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U)E860@
M<V5S<VEO;B!D871A("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A
M('1O('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E
M;G1I9FEE<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@
M5&AE('-E<W-I;VX@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!W<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("![
M"B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!M96UC86-H
M92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*
M("`@("`@("`D;&EF971I;64@/2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI
M9F5T:6UE)RD["B`@("`@("`@)&9L86=S(#T@)'1H:7,M/E]P87)A;7-;)V-O
M;7!R97-S:6]N)UT@/R!-14U#04-(15]#3TU04D534T5$(#H@,#L*("`@("`@
M("`D<F5S=6QT(#T@0&UE;6-A8VAE7W-E="@D=&AI<RT^7V1B+"`D:60L("1S
M97-S:6]N7V1A=&$L("1F;&%G<RP@)&QI9F5T:6UE*3L*"B`@("`@("`@:68@
M*"$D<F5S=6QT*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%
M<G)O<B!W<FET:6YG('-E<W-I;VX@9&%T82`H:60@/2`G("X@)&ED("X@)RDG
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U=R;W1E('-E<W-I;VX@9&%T82`H:60@/2`G("X@)&ED("X@
M)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T
M<F]Y('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF
M:65R(&EN('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E
M;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D97-T<F]Y*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@
M=V4@:&%V92!A('9A;&ED(&UE;6-A8VAE(&-O;FYE8W1I;VXN("HO"B`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("1R97-U;'0@/2!`;65M
M8V%C:&5?9&5L971E*"1T:&ES+3Y?9&(L("1I9"D["@H@("`@("`@(&EF("@A
M)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G1F%I
M;&5D('1O(&1E;&5T92!S97-S:6]N("AI9"`]("<@+B`D:60@+B`G*2<L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G1&5L971E9"!S97-S:6]N(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I
M)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("1T:&ES+3Y?=6YL;V-K4V5S<VEO;B@I.PH@("`@("`@($!U;FQI;FLH
M)'1H:7,M/E]P87)A;7-;)VQO8VM?9&ER)UT@+B`G+VQO8VM?)R`N("1I9"D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H
M)&UA>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O
M;FYE8W1I;VX@=&\@=&AE(&UE;6-A8VAE('-E<G9E<BAS*2X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O
M;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@
M>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G06QR96%D>2!C;VYN
M96-T960@=&\@82!M96UC86-H92!S97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I
M;VY(86YD;&5R)R`L(%]?1DE,15]?+"!?7TQ)3D5?7RQ014%27TQ/1U]$14)5
M1RD["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@($AO
M<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=S97-S
M:6]N:&%N9&QE<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G:&]S='-P96,G+"`G<&]R="<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!M96UC86-H92<I
M.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E
M;G0G72DI('L*("`@("`@("`@("`@)&-O;FYE8W1?<&5R<VES=&5N="`](&9A
M;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYN96-T7W!E
M<G-I<W1E;G0@/2!T<G5E.PH@("`@("`@('T*("`@("`@("`D8V]N(#T@;F5W
M($UE;6-A8VAE.PH*("`@("`@("!F;W(@*"1I(#T@,"P@)&X@/2!C;W5N="@D
M=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72D[("1I(#P@)&X[("LK)&DI('L*
M("`@("`@("`@("`@:68@*"%`)&-O;BT^861D4V5R=F5R*"1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==6R1I72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UU;)&E=+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;FYE8W1?<&5R<VES=&5N
M="DI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=#;W5L
M9"!N;W0@861D(%LG("X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UU;)&E=
M("X@)SHG("X@)'1H:7,M/E]P87)A;7-;)W!O<G0G75LD:5T@+B`G72!A<R!M
M96UC86-H92!S97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(86YD;&5R)R`L
M(%]?1DE,15]?+"!?7TQ)3D5?7RQ014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)T%D9&5D(%LG("X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UU;)&E=("X@
M)SHG("X@)'1H:7,M/E]P87)A;7-;)W!O<G0G75LD:5T@+B`G72!A<R!M96UC
M86-H92!S97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(86YD;&5R)RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&EF(&%N>2!O9B!T:&4@<&]O
M;&5D(&-O;FYE8W1I;VYS('=O<FMS+B`J+PH@("`@("`@(&EF("@D8V]N+3YG
M971697)S:6]N*"DI('L*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("1C;VX[
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T-O;FYE8W1E9"!T;R!A(&UE;6-A
M8VAE('-E<G9E<B!F;W(@;65M8V%C:&4@4V5S<VEO;DAA;F1L97(G("P@7U]&
M24Q%7U\L(%]?3$E.15]?+%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@86YY(&UE;6-A8VAE('-E<G9E<B!F;W(@;65M8V%C:&4@4V5S<VEO
M;DAA;F1L97(G("P@7U]&24Q%7U\L(%]?3$E.15]?+%!%05)?3$]'7T524BD[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L;V-K4V5S<VEO;B@D:60I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]F<"`]($!F;W!E;B@D=&AI<RT^7W!A<F%M
M<ULG;&]C:U]D:7(G72`N("<O;&]C:U\G("X@)&ED+"`G=RLG*3L*("`@("`@
M("!I9B`H(21T:&ES+3Y?9G`I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)T-O=6QD(&YO="!O<&5N('-E<W-I;VX@;&]C:R!F;W(@)R`N("1I
M9"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@A0&9L
M;V-K*"1T:&ES+3Y?9G`L($Q/0TM?15@I*2!["B`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"=#;W5L9"!N;W0@;&]C:R!S97-S:6]N("<@+B`D:60L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W5N;&]C:U-E<W-I;VXH*0H@("`@>PH@("`@
M("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7V9P*2D@>PH@("`@("`@("`@
M("!I9B`H(4!F;&]C:R@D=&AI<RT^7V9P+"!,3T-+7U5.*2D@>PH@("`@("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T-O=6QD(&YO="!U;FQO8VL@
M<V5S<VEO;B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!`9F-L;W-E*"1T:&ES+3Y?9G`I
M.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+V]C:3@N<&AP
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-#`S,@`Q,#4Q-30S,3`V,``P
M,C(U,3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%-E<W-I;VY(86YD;&5R.CH@:6UP;&5M96YT871I
M;VX@9F]R($]R86-L92`X:2`H;F%T:79E*2X*("H*("H@4F5Q=6ER960@<&%R
M86UE=&5R<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O
M9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C
M;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*
M("H@("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C
M;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@
M<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V1A
M=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=T86)L
M92<@("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T82!T86)L92!I;B`G
M9&%T86)A<V4G+CPO<')E/@H@*@H@*B!297%U:7)E9"!F;W(@<V]M92!C;VYF
M:6=U<F%T:6]N<SH\<')E/@H@*B`@("=P;W)T)R`@5&AE('!O<G0@;VX@=VAI
M8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P
M=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G<&5R<VES=&5N="<@(%5S
M92!P97)S:7-T96YT($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A;BD\+W!R93X*
M("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE(%-E<W-I;VY(86YD
M;&5R(&-A;B!B92!F;W5N9"!I;@H@*B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D
M95]S97-S:6]N:&%N9&QE<BYO8VDX+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;V-I."YP:'`L
M=B`Q+C@N-"XQ,2`R,#`V+S`R+S$P(#$X.C0V.C4S(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($QI86T@2&]E:V5N9V$@/&QI86UR0'5M
M:6-H+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($QI86T@2&]E
M:V5N9V$@/&QI86UR0'5M:6-H+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,BXR
M"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!3
M97-S:6]N2&%N9&QE<E]O8VDX(&5X=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*
M("`@("\J*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S
M92!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@
M("`J+PH@("`@=F%R("1?9&(["@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@8V]N
M;F5C=&5D('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T960@/2!F86QS93L*
M"B`@("`O*BH*("`@("`J($-L;W-E('1H92!397-S:6]N2&%N9&QE<B!B86-K
M96YD+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I
M('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@
M("`@("`@("`@<F5T=7)N($]#24QO9T]F9B@D=&AI<RT^7V1B*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E
M;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I
M;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D
M:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI
M9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`D<V5L96-T7W%U97)Y(#T@<W!R:6YT9B@G4T5,
M14-4('-E<W-I;VY?9&%T82!&4D]-("5S(%=(15)%('-E<W-I;VY?:60@/2`E
M<R!&3U(@55!$051%)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/E]Q=6]T92@D:60I
M*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L
M979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=3
M44P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ<F5A9"@I.B!Q=65R
M>2`]("(E<R(G+"`D<V5L96-T7W%U97)Y*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@+RH@17AE8W5T92!Q=65R>2`J+PH@("`@("`@("1S96QE8W1?
M<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)'-E;&5C=%]Q=65R
M>2D["B`@("`@("`@3T-)17AE8W5T92@D<V5L96-T7W-T871E;65N="D["B`@
M("`@("`@:68@*"%/0TE&971C:$EN=&\H)'-E;&5C=%]S=&%T96UE;G0L("1R
M97-U;'0I*2!["B`@("`@("`@("`@("1I;G-E<G1?<75E<GD@/2!S<')I;G1F
M*"=)3E-%4E0@24Y43R`E<R`H<V5S<VEO;E]I9"P@<V5S<VEO;E]L87-T;6]D
M:69I960L('-E<W-I;VY?9&%T82D@5D%,5453("@E<RP@)7,L($5-4%197T),
M3T(H*2D@4D5455).24Y'('-E<W-I;VY?9&%T82!)3E1/(#IB;&]B)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<75O=&4H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92AT:6UE*"DI*3L*("`@("`@
M("`@("`@)&EN<V5R=%]S=&%T96UE;G0@/2!/0TE087)S92@D=&AI<RT^7V1B
M+"`D:6YS97)T7W%U97)Y*3L*("`@("`@("`@("`@)&QO8B`]($]#24YE=T1E
M<V-R:7!T;W(H)'1H:7,M/E]D8BD["B`@("`@("`@("`@($]#24)I;F1">4YA
M;64H)&EN<V5R=%]S=&%T96UE;G0L("<Z8FQO8B<L("1L;V(L("TQ+"!344Q4
M7T),3T(I.PH@("`@("`@("`@("!/0TE%>&5C=71E*"1I;G-E<G1?<W1A=&5M
M96YT+"!/0TE?1$5&055,5"D["B`@("`@("`@("`@(&EF("@D<V5S<VEO;E]D
M871A*2!["B`@("`@("`@("`@("`@("`D;&]B+3YS879E*"1S97-S:6]N7V1A
M=&$I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!/0TE#
M;VUM:70H)'1H:7,M/E]D8BD["B`@("`@("`@("`@($]#249R9653=&%T96UE
M;G0H)&EN<V5R=%]S=&%T96UE;G0I.PH@("`@("`@("`@("!/0TE%>&5C=71E
M*"1S96QE8W1?<W1A=&5M96YT*3L*("`@("`@("`@("`@3T-)1F5T8VA);G1O
M*"1S96QE8W1?<W1A=&5M96YT+"`D<F5S=6QT*3L*("`@("`@("!]"B`@("`@
M("`@)'9A;'5E(#T@)')E<W5L=%LP72T^;&]A9"@I.PH@("`@("`@($]#249R
M9653=&%T96UE;G0H)'-E;&5C=%]S=&%T96UE;G0I.PH@("`@("`@(')E='5R
M;B@D=F%L=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@<V5S<VEO
M;B!D871A('1O('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@("`@5&AE('-E<W-I
M;VX@:61E;G1I9FEE<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-E<W-I;VY?
M9&%T82`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D:60L("1S97-S:6]N7V1A=&$I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D
M871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@<V5S<VEO;E]L
M87-T;6]D:69I960@/2`E<RP@<V5S<VEO;E]D871A(#T@14U05%E?0DQ/0B@I
M(%=(15)%('-E<W-I;VY?:60@/2`E<R!215154DY)3D<@<V5S<VEO;E]D871A
M($E.5$\@.F)L;V(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W%U;W1E*'1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W%U;W1E*"1I9"DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U
M97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE
M<E]O8VDX.CIW<FET92@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('%U97)Y("HO"B`@
M("`@("`@)'-T871E;65N="`]($]#25!A<G-E*"1T:&ES+3Y?9&(L("1Q=65R
M>2D["B`@("`@("`@)&QO8B`]($]#24YE=T1E<V-R:7!T;W(H)'1H:7,M/E]D
M8BD["B`@("`@("`@3T-)0FEN9$)Y3F%M92@D<W1A=&5M96YT+"`G.F)L;V(G
M+"`D;&]B+"`M,2P@4U%,5%]"3$]"*3L*("`@("`@("!/0TE%>&5C=71E*"1S
M=&%T96UE;G0L($]#25]$149!54Q4*3L*("`@("`@("!I9B`H)'-E<W-I;VY?
M9&%T82D@>PH@("`@("`@("`@("`D;&]B+3YS879E*"1S97-S:6]N7V1A=&$I
M.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1T:&ES
M+3Y?9&(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G17)R;W(@=W)I=&EN9R!S97-S:6]N(&1A=&$G
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F
M;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@
M("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D
M:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI
M9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@
M("`@("`@("1Q=65R>2`]('-P<FEN=&8H("=$14Q%5$4@1E)/32`E<R!72$52
M12!S97-S:6]N7VED(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^7W%U;W1E*"1I9"DI
M.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE
M=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-1
M3"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]O8VDX.CID97-T<F]Y*"DZ('%U
M97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1S=&%T96UE
M;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+"`D<75E<GDI.PH@("`@("`@("1R
M97-U;'0@/2!/0TE%>&5C=71E*"1S=&%T96UE;G0I.PH@("`@("`@(&EF("@A
M)')E<W5L="D@>PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T
M96UE;G0I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G1F%I;&5D
M('1O(&1E;&5T92!S97-S:6]N("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@3T-)1G)E95-T871E;65N
M="@D<W1A=&5M96YT*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F
M<F]M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1M87AL:69E=&EM92`@5&AE(&UA>&EM=6T@86=E
M(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G8R@D;6%X;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@
M("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C
M=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@
M+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!S97-S:6]N7VQA<W1M;V1I
M9FEE9"`\("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+"`D=&AI<RT^7W%U;W1E*'1I;64H*2`M("1M87AL
M:69E=&EM92DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"
M54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]O8VDX.CIG8R@I
M.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<W1A
M=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@
M("`D<F5S=6QT(#T@3T-)17AE8W5T92@D<W1A=&5M96YT*3L*("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D
M<W1A=&5M96YT*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R
M<F]R(&=A<F)A9V4@8V]L;&5C=&EN9R!O;&0@<V5S<VEO;G,G+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@($]#249R9653=&%T96UE;G0H
M)'-T871E;65N="D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H92!V86QI9"!S97-S:6]N(&ED
M96YT:69I97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@;&ES
M="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I97)S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971397-S:6]N241S*"D*("`@('L*("`@("`@("`O*B!-86ME
M('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO
M"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J(%-E<W-I
M;VX@=&EM96]U="P@9&]N)W0@<F5L>2!O;B!G87)B86=E(&-O;&QE8W1I;VX@
M*B\*("`@("`@("`D=&EM96]U="`]('1I;64H*2`M(&EN:5]G970H)W-E<W-I
M;VXN9V-?;6%X;&EF971I;64G*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G4T5,14-4('-E<W-I;VY?:60@1E)/32`E<R<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@)R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE9"`^("5S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1I;65O=70I.PH*
M("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L
M+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1
M=65R>2!B>2!397-S:6]N2&%N9&QE<E]O8VDX.CIG971397-S:6]N241S*"DZ
M('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("\J($5X96-U=&4@<75E<GD@*B\*("`@("`@("`D<W1A=&5M96YT
M(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("!/0TE%
M>&5C=71E*"1S=&%T96UE;G0I.PH*("`@("`@("`D<V5S<VEO;G,@/2!A<G)A
M>2@I.PH@("`@("`@('=H:6QE("A/0TE&971C:$EN=&\H)'-T871E;65N="P@
M)')O=RDI('L*("`@("`@("`@("`@)'-E<W-I;VYS6UT@/2`D<F]W6S!=.PH@
M("`@("`@('T*"B`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT
M*3L*("`@("`@("!R971U<FX@)'-E<W-I;VYS.PH@("`@?0H*("`@("\J*@H@
M("`@("H@17-C87!E(&$@<W1R:6YG(&9O<B!I;G-E<G1I;VXN(%-T;VQE;B!F
M<F]M(%!%05(Z.D1"+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!S=')I;F<@=&\@<75O
M=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!Q=6]T960@
M<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75O=&4H)'9A;'5E*0H@
M("`@>PH@("`@("`@(')E='5R;B`H)'9A;'5E(#T]/2!N=6QL*2`_("=.54Q,
M)R`Z("(G(B`N('-T<E]R97!L86-E*"(G(BP@(B<G(BP@)'9A;'5E*2`N("(G
M(CL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C
M;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIA<W-E
M<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=S97-S:6]N:&%N9&QE
M<B<L"B`@("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=U<V5R;F%M92<L
M("=P87-S=V]R9"<I+`H@("`@("`@("`@("`G<V5S<VEO;B!H86YD;&5R($]R
M86-L92<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T
M86)L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72`]("=H;W)D95]S97-S:6]N:&%N9&QE<B<["B`@("`@("`@?0H*("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=O8VE?8V]N;F5C="<I*2!["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==
M*2D@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W0@/2`G;V-I7V-O;FYE8W0G
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-O;FYE
M8W0@/2`G;V-I7W!C;VYN96-T)SL*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M<&5R<VES=&5N="==*2D@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W0@/2`G
M3T-)3&]G;VXG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&-O;FYE8W0@/2`G3T-)4$QO9V]N)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^7V1B(#T@
M0"1C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO
M<W1S<&5C)UTI*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ
M<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&-O;FYE8W0@=&\@9&%T86)A<V4@9F]R
M(%-13"!397-S:6]N2&%N9&QE<BXG*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(O<&=S<6PN<&AP````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(W-C4Q
M`#$P-3$U-#,Q,#8P`#`R,S`P-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@4&]S=&=R95-13"!397-S
M:6]N($AA;F1L97(@9F]R(%!(4"`H;F%T:79E*2X*("H*("H@0V]P>7)I9VAT
M(#(P,#`M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^+B`@06QL
M(')I9VAT<R!R97-E<G9E9"X*("H*("H@(%)E9&ES=')I8G5T:6]N(&%N9"!U
M<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U
M=`H@*B`@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H
M870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J("!A<F4@;65T.@H@*B`@
M,2X@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN
M('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T
M(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*
M("H@(#(N(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E
M<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(@:6X@=&AE"B`J("`@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE
M<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@
M*@H@*B`@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@05542$]2
M($%.1"!#3TY44DE"551/4E,@8&!!4R!)4R<G($%.1`H@*B`@04Y9($584%)%
M4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@
M3$E-251%1"!43RP@5$A%"B`J("!)35!,245$(%=!4E)!3E1)15,@3T8@3452
M0TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%52
M4$]310H@*B`@05)%($1)4T-,04E-140N("!)3B!.3R!%5D5.5"!32$%,3"!4
M2$4@05542$]2($]2($-/3E1224)55$]24R!"12!,24%"3$4*("H@($9/4B!!
M3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%
M35!,05)9+"!/4B!#3TY315%514Y424%,"B`J("!$04U!1T53("A)3D-,541)
M3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)
M5%5412!'3T]$4PH@*B`@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!
M+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI"B`J("!(
M3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL
M(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5`H@*B`@3$E!0DE,2519+"!/
M4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%2
M25-)3D<@24X@04Y9(%=!60H@*B`@3U54($]&(%1(12!54T4@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/
M1@H@*B`@4U5#2"!$04U!1T4N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z
M/'!R93X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A
M<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@
M=VET:"`G=7-E<FYA;64G+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM=6YI
M8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G*2X*("H@("`G=7-E<FYA
M;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H
M92!D871A8F%S92X*("H*("H@4F5Q=6ER960@9F]R('-O;64@8V]N9FEG=7)A
M=&EO;G,@*&DN92X@)W!R;W1O8V]L)R`]("=T8W`G*3H\<')E/@H@*B`@("=H
M;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R
M+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A
M;65T97)S.CQP<F4^"B`J("`@)W!E<G-I<W1E;G0G("!5<V4@<&5R<VES=&5N
M="!$0B!C;VYN96-T:6]N<S\@*&)O;VQE86XI"B`J("`@("`@("`@("`@("`@
M("!$969A=6QT.B!.3PH@*B`@("=T86)L92<@("`@("`@5&AE(&YA;64@;V8@
M=&AE('-E<W-I;VYD871A('1A8FQE(&EN("=D871A8F%S92<N"B`J("`@("`@
M("`@("`@("`@("!$969A=6QT.B`G:&]R9&5?<V5S<VEO;FAA;F1L97(G/"]P
M<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N
M2&%N9&QE<B!C86X@8F4@9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?<V5S<VEO;FAA;F1L97(N<&=S<6PN<W%L+@H@*@H@*B!#;VYT<FEB
M=71O<G,Z/'!R93X*("H@($IA<V]N($-A<FQS;VX@("`@("`@("`@(%)E='5R
M;B!A;B!E;7!T>2!S=')I;F<@;VX@9F%I;&5D(')E861S"B`J("!P871`<&-P
M<F]G<F%M;65R+F-O;2`@("!097)F;W)M('5P9&%T92!I;B!A('-I;F=L92!T
M<F%N<V%C=&EO;@H@*B`@2F]N871H86X@0W)O;7!T;VX@("`@("`@3&]C:R!R
M;W<@9F]R(&QI9F4@;V8@<V5S<VEO;CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]P9W-Q;"YP
M:'`L=B`Q+C$R+C$P+C$U(#(P,#8O,#,O,C,@,3@Z,#`Z,3<@:F%N($5X<"`D
M"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!C<V@N<FET+F5D=3X*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I
M;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]P9W-Q;"!E>'1E
M;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F
M;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@
M("\J*@H@("`@("H@07)E('=E(&-O;FYE8W1E9"!T;R!T:&4@4U%,('-E<G9E
M<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;&]S92!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@
M+RH@1&ES8V]N;F5C="!F<F]M(&1A=&%B87-E+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE
M8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@0'!G7V-L;W-E*"1T
M:&ES+3Y?9&(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I
M8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S
M:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U
M<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@
M("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@($!P9U]Q=65R>2@D
M=&AI<RT^7V1B+"`G0D5'24X[)RD["@H@("`@("`@("1T:6UE;W5T(#T@=&EM
M92@I("T@:6YI7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/
M32`E<R!72$5212`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S
M:6]N7VED(#T@)7,@04Y$('-E<W-I;VY?;&%S=&UO9&EF:65D(#X]("5S("<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@)T9/4B!54$1!5$4[)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G%U;W1E*"1I9"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&EM96]U="D["@H@("`@("`@
M("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y
M(%-E<W-I;VY(86YD;&5R7W!G<W%L.CHG("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=R96%D*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R
M>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2!`<&=?
M<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D9&%T82`]('!G
M7V9E=&-H7W)E<W5L="@D<F5S=6QT+"`P+"`G<V5S<VEO;E]D871A)RD["B`@
M("`@("`@<&=?9G)E95]R97-U;'0H)')E<W5L="D["@H@("`@("`@(')E='5R
M;B!P86-K*"=(*B<L("1D871A*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=R
M:71E('-E<W-I;VX@9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@("`@
M(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T
M:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D<V5S
M<VEO;E]D871A*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E
M(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI
M<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)'1I;65O=70@/2!T:6UE*"D@+2!I
M;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T:6UE)RD["B`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G4T5,14-4('-E<W-I;VY?9&%T82!&4D]-("5S(%=(
M15)%("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@)W-E<W-I;VY?:60@
M/2`E<R!!3D0@<V5S<VEO;E]L87-T;6]D:69I960@/CT@)7,@)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G1D]2(%501$%412<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92@D:60I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1I;65O=70I.PH@("`@("`@("1R97-U;'0@
M/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D<F]W
M<R`]('!G7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@("`@('!G7V9R965?<F5S
M=6QT*"1R97-U;'0I.PH*("`@("`@("!I9B`H)')O=W,@/3T@,"D@>PH@("`@
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H<V5S
M<VEO;E]I9"P@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-E
M<W-I;VY?;&%S=&UO9&EF:65D+"!S97-S:6]N7V1A=&$I("<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=604Q515,@*"5S+"`E<RP@)7,I.R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G%U;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&EM
M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T
M92AB:6XR:&5X*"1S97-S:6]N7V1A=&$I*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"!S
M97-S:6]N7VQA<W1M;V1I9FEE9"`]("5S+"`G("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<V5S<VEO;E]D871A(#T@)7,@5TA%4D4@<V5S<VEO
M;E]I9"`]("5S.R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YQ=6]T92AB:6XR:&5X*"1S97-S:6]N7V1A=&$I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H)&ED*2D["B`@("`@
M("`@?0H*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G
M(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H
M)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=W)I=&4H*3H@<75E<GD@
M/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@
M)')E<W5L="`]($!P9U]Q=65R>2@D=&AI<RT^7V1B+"`D<75E<GDI.PH@("`@
M("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G17)R;W(@=W)I=&EN9R!S97-S:6]N(&1A=&$Z("<@+B!P9U]L87-T
M7V5R<F]R*"1T:&ES+3Y?9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@)')O=W,@/2!P9U]A9F9E8W1E9%]R;W=S*"1R97-U;'0I.PH@
M("`@("`@('!G7V9R965?<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!`<&=?
M<75E<GDH)'1H:7,M/E]D8BP@)T-/34U)5#LG*3L*"B`@("`@("`@:68@*"1R
M;W=S("$](#$I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R
M<F]R('=R:71I;F<@<V5S<VEO;B!D871A)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@
M=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@
M:6X@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF
M:65R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E<W1R;WDH)&ED*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H
M879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/
M32`E<R!72$5212!S97-S:6]N7VED(#T@)7,[)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^<75O
M=&4H)&ED*2D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)5
M1R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R
M:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W!G<W%L.CHG("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-T<F]Y*"DZ
M('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U
M;'0@/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*"B`@("`@("`@
M0'!G7W%U97)Y*"1T:&ES+3Y?9&(L("=#3TU-250[)RD["@H@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("!P9U]F<F5E7W)E<W5L="@D<F5S
M=6QT*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T
M;R!D96QE=&4@<V5S<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@('!G7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C
M;VQL96-T('-T86QE('-E<W-I;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD;&5R
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QI
M9F5T:6UE("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S97-S:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS
M92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL:69E
M=&EM92`](#,P,"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V
M92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H
M:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E
M<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@
M)7,@5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/"`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92AT:6UE*"D@+2`D
M;6%X;&EF971I;64I*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A
M($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?<&=S<6PZ
M.B<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=C*"DZ
M('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U
M;'0@/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)T5R<F]R(&=A<F)A9V4@8V]L;&5C=&EN9R!O;&0@<V5S<VEO;G,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@?0H*("`@("`@("!P9U]F<F5E7W)E
M<W5L="@D<F5S=6QT*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($5S8V%P92!A('-T<FEN9R!F;W(@:6YS97)T:6]N
M(&EN=&\@=&AE(&1A=&%B87-E+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!S=')I;F<@
M=&\@<75O=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!Q
M=6]T960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T92@D=F%L
M=64I"B`@("!["B`@("`@("`@<F5T=7)N("(G(B`N(&%D9'-L87-H97,H)'9A
M;'5E*2`N("(G(CL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@
M;V8@=&AE('9A;&ED('-E<W-I;VX@:61E;G1I9FEE<G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F('9A;&ED('-E<W-I;VX@:61E
M;G1I9FEE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<W-I;VY)1',H
M*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@
M9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE
M8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@
M("`@("`D<75E<GD@/2`G4T5,14-4('-E<W-I;VY?:60@1E)/32`G("X@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UT["@H@("`@("`@("\J($QO9R!T:&4@<75E
M<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R
M7W!G<W%L.CHG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=G971397-S:6]N241S*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y
M+B`J+PH@("`@("`@("1R97-U;'0@/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@
M)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@
M<&=?9G)E95]R97-U;'0H)')E<W5L="D["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=%<G)O<B!G971T:6YG('-E<W-I;VX@241S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D<V5S<VEO;G,@/2!A<G)A>2@I.PH@("`@("`@('=H
M:6QE("@D<F]W(#T@<&=?9F5T8VA?<F]W*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("1S97-S:6]N<UM=(#T@)')O=ULP73L*("`@("`@("!]"@H@("`@("`@
M('!G7V9R965?<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@)'-E
M<W-I;VYS.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E
M;B!A(&-O;FYE8W1I;VX@=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,[(&5X:71S("A(
M;W)D93HZ9F%T86PH*2D@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C
M=&5D*2!["B`@("`@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H
M)'1H:7,M/E]P87)A;7,L("=S97-S:6]N:&%N9&QE<B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@
M)W5S97)N86UE)RP@)V1A=&%B87-E)RP@)W!A<W-W;W)D)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE
M<B!P9W-Q;"<I.PH*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=T86)L92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@/2`G:&]R9&5?<V5S<VEO;FAA;F1L97(G.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D8V]N;F5C="`](&5M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=P97)S:7-T96YT)UTI(#\*("`@("`@("`@("`@("`@("=P9U]C
M;VYN96-T)R`Z)W!G7W!C;VYN96-T)SL*"B`@("`@("`@("`@("1P87)A;7-T
M<B`]("<G.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;
M)W!R;W1O8V]L)UTI("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG<')O=&]C;VPG72`]/2`G=&-P)RD@>PH@("`@("`@("`@("`@("`@)'!A
M<F%M<W1R("X]("<@:&]S=#TG("X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C
M)UT["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;
M)W!O<G0G72DI('L*("`@("`@("`@("`@("`@("`@("`D<&%R86US='(@+CT@
M)R!P;W)T/2<@+B`D=&AI<RT^7W!A<F%M<ULG<&]R="==.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1P87)A;7-T<B`N
M/2`G(&1B;F%M93TG("X@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@+@H@
M("`@("`@("`@("`@("`@)R!U<V5R/2<@+B`D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;64G72`N"B`@("`@("`@("`@("`@("`G('!A<W-W;W)D/2<@+B`D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F0G73L*"B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/E]D8B`]($`D8V]N;F5C="@D<&%R86US='(I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]D8FTN<&AP````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8T,C,`,3`U,34T,S$P-C``,#(R-#$T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O<B!$0DT@
M9FEL97,N"B`J($Y/5$4Z(%1H92!02%`@1$)-(&9U;F-T:6]N<R!A<F4@9&5P
M<F5C871E9"X*("H*("H@3F\@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N('!A
M<F%M971E<G,@;F5E9&5D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]D8FTN<&AP+'8@,2XY+C$R+C<@
M,C`P-B\P,2\P,2`R,3HR.#HS-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?4V5S<VEO;DAA;F1L97(*("HO"F-L87-S(%-E<W-I;VY(
M86YD;&5R7V1B;2!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*
M("`@("`J($]U<B!P;VEN=&5R('1O('1H92!$0DT@9FEL92P@:68@;W!E;BX*
M("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M7V1B;3L*"B`@("`O*BH*("`@("`J($]P96X@=&AE(%-E<W-I;VY(86YD;&5R
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V%V95]P
M871H("`@("!4:&4@<&%T:"!T;R!T:&4@<V5S<VEO;B!O8FIE8W0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7VYA;64@(%1H92!N86UE(&]F('1H
M92!S97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&]P96XH)'-A=F5?<&%T:"P@)'-E<W-I;VY?;F%M92D*("`@('L*
M("`@("`@("`D=&AI<RT^7V1B;2`]($!D8FUO<&5N*"(D<V%V95]P871H+R1S
M97-S:6]N7VYA;64B+"`G8R<I.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1B
M;3L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E('1H92!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@0&1B;6-L
M;W-E*"1T:&ES+3Y?9&)M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E860@
M=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@
M9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT
M:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97-S
M:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@("`@
M>PH@("`@("`@(&EF("@D9&%T82`](&1B;69E=&-H*"1T:&ES+3Y?9&)M+"`D
M:60I*2!["B`@("`@("`@("`@(')E='5R;B!B87-E-C1?9&5C;V1E*'-U8G-T
M<B@D9&%T82P@<W1R<&]S*"1D871A+"`G?"<I("L@,2DI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A=&$@=&\@=&AE(%-E
M<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4:&4@<V5S<VEO
M;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@('L*("`@("`@("!R
M971U<FX@0&1B;7)E<&QA8V4H)'1H:7,M/E]D8FTL("1I9"P@=&EM92@I("X@
M)WPG("X@8F%S938T7V5N8V]D92@D<V5S<VEO;E]D871A*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A('!A<G1I8W5L
M87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@4V5S<VEO;DAA
M;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I9"D*("`@('L*("`@
M("`@("!I9B`H(2A`9&)M9&5L971E*"1T:&ES+3Y?9&)M+"`D:60I*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G1F%I;&5D('1O(&1E;&5T
M92!S97-S:6]N("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O
M;2!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O
M9B!A('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V,H)&UA>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@
M("1E>'!I<F5D(#T@=&EM92@I("T@)&UA>&QI9F5T:6UE.PH@("`@("`@("1I
M9"`](&1B;69I<G-T:V5Y*"1T:&ES+3Y?9&)M*3L*"B`@("`@("`@=VAI;&4@
M*"1I9"D@>PH@("`@("`@("`@("!I9B`H)&1A=&$@/2!D8FUF971C:"@D=&AI
M<RT^7V1B;2P@)&ED*2D@>PH@("`@("`@("`@("`@("`@)&%G92`]('-U8G-T
M<B@D=&UP+"`P+"!S=')P;W,H)&1A=&$L("=\)RDI.PH@("`@("`@("`@("`@
M("`@:68@*"1E>'!I<F5D(#X@)&%G92D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YD97-T<F]Y*"1I9"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1I9"`](&1B;6YE>'1K97DH)'1H:7,M
M/E]D8FTL("1I9"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+P``````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`R,#8T-``@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-C``,#(R-#,Q`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-30T-0`Q,#4Q-30S,3`V,``P,C0T,38`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`G.PH*
M+RHJ"B`J(%1H92!.;W1I9FEC871I;VY?3&ES=&5N97)?;6]B:6QE.CH@8VQA
M<W,@<')O=FED97,@9G5N8W1I;VYA;&ET>2!F;W(*("H@9&ES<&QA>6EN9R!M
M97-S86=E<R!F<F]M('1H92!M97-S86=E('-T86-K(&]N(&UO8FEL92!D979I
M8V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`L=B`Q+C@N,3`N."`R,#`V
M+S`Q+S`Q(#(Q.C(X.C,P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E],
M:7-T96YE<E]M;V)I;&4@97AT96YD<R!.;W1I9FEC871I;VY?3&ES=&5N97)?
M<W1A='5S('L*"B`@("`O*BH*("`@("`J(%1H92!(;W)D95]-;V)I;&4Z.B!O
M8FIE8W0@=&AA="!S=&%T=7,@;&EN97,@<VAO=6QD(&)E(&%D9&5D('1O+@H@
M("`@("H*("`@("`J($!V87(@2&]R9&5?36]B:6QE"B`@("`@*B\*("`@('9A
M<B`D7VUO8FEL92`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<@H@("`@("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VY?3&ES=&5N97)?
M;6]B:6QE*"D*("`@('L*("`@("`@("`D=&AI<RT^7VAA;F1L97,@/2!A<G)A
M>2@G:&]R9&4N97)R;W(G("`@/3X@7R@B15)2(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G(#T^(%\H(E-50T-%
M4U,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N
M=V%R;FEN9R<@/3X@7R@B5T%23B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H;W)D92YM97-S86=E)R`]/B!?*")-4T<B*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!<W-O8VEA=&4@82!(;W)D95]-;V)I;&4Z.B!O
M8FIE8W0@=VET:"!T:&4@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M($AO<F1E7TUO8FEL92`@5&AE($AO<F1E7TUO8FEL93HZ(&]B:F5C="!T;R!S
M96YD('-T871U<R!L:6YE<R!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M36]B:6QE3V)J96-T*"8D;6]B:6QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;6]B:6QE(#T@)B1M;V)I;&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI<R!L:7-T96YE<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@56YI<75E(&ED+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@("`@("!R971U<FX@
M)VUO8FEL92<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S('1H92!S
M=&%T=7,@;&EN92!I9B!T:&5R92!A<F4@86YY(&UE<W-A9V5S(&]N('1H92`G
M;6]B:6QE)PH@("`@("H@;65S<V%G92!S=&%C:RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)B1M97-S86=E4W1A8VL@(%1H92!S=&%C:R!O9B!M97-S
M86=E<RX*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@("`@("`@06X@
M87)R87D@;V8@;W!T:6]N<RX@3W!T:6]N<SH@)VYO<W!A8V4G"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YO=&EF>2@F)&UE<W-A9V53=&%C:RP@)&]P=&EO;G,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]M;V)I;&4I
M('L*("`@("`@("`@("`@<&%R96YT.CI.;W1I9FEC871I;VY?3&ES=&5N97)?
M<W1A='5S*"D["B`@("`@("`@("`@(')E='5R;B!P87)E;G0Z.FYO=&EF>2@D
M;65S<V%G95-T86-K+"`D;W!T:6]N<RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H8V]U;G0H)&UE<W-A9V53=&%C:RDI('L*("`@("`@("`@("`@=VAI;&4@
M*"1M97-S86=E(#T@87)R87E?<VAI9G0H)&UE<W-A9V53=&%C:RDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YG971-97-S86=E*"1M97-S86=E*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D="`]("8D=&AI<RT^7VUO8FEL92T^
M861D*&YE=R!(;W)D95]-;V)I;&5?=&5X="@B7&XB*2D["B`@("`@("`@("`@
M("1T+3YS970H)VQI;F5B<F5A:W,G+"!T<G5E*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!/=71P=71S(&]N92!M97-S86=E+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@3VYE(&UE<W-A9V4@:&%S
M:"!F<F]M('1H92!S=&%C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T365S
M<V%G92@D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;6]B
M:6QE*2!["B`@("`@("`@("`@('!A<F5N=#HZ3F]T:69I8V%T:6]N7TQI<W1E
M;F5R7W-T871U<R@I.PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIG971-
M97-S86=E*"1M97-S86=E*3L*("`@("`@("!]"@H@("`@("`@("1E=F5N="`]
M("1T:&ES+3YG971%=F5N="@D;65S<V%G92D["B`@("`@("`@)'1H:7,M/E]M
M;V)I;&4M/F%D9"AN97<@2&]R9&5?36]B:6QE7W1E>'0H<W!R:6YT9BA?*"(E
M<SH@)7,B*2P@)'1H:7,M/E]H86YD;&5S6R1M97-S86=E6R=T>7!E)UU=+"!S
M=')I<%]T86=S*"1E=F5N="T^9V5T365S<V%G92@I*2DI*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+V%U9&EO+G!H<```````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#,T`#$P-3$U
M-#,Q,#8P`#`R-#(T-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(N<&AP)SL*"B\J*@H@*B!4:&4@3F]T:69I8V%T:6]N
M7TQI<W1E;F5R7V%U9&EO.CH@8VQA<W,@<')O=FED97,@9G5N8W1I;VYA;&ET
M>2!F;W(*("H@:6YS97)T:6YG(&5M8F5D9&5D(&%U9&EO(&YO=&EF:6-A=&EO
M;G,@9G)O;2!T:&4@<W1A8VL@:6YT;R!T:&4@<&%G92X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]A=61I;RYP:'`L=B`Q+C,N,BXR(#(P,#8O,#$O,#$@,C$Z,C@Z,S`@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@0W)O;F]S>7,L($Q,
M0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES
M+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TYO=&EF:6-A=&EO;@H@*B\*8VQA<W,@3F]T:69I8V%T:6]N7TQI<W1E;F5R
M7V%U9&EO(&5X=&5N9',@3F]T:69I8V%T:6]N7TQI<W1E;F5R('L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($YO
M=&EF:6-A=&EO;E],:7-T96YE<E]A=61I;R@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]H86YD;&5S(#T@87)R87DH)V%U9&EO)R`]/B`G)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@
M=&AI<R!L:7-T96YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M56YI<75E(&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@
M('L*("`@("`@("!R971U<FX@)V%U9&EO)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($]U='!U=',@=&AE(&5M8F5D9&5D(&%U9&EO(&-O9&4@:68@=&AE<F4@
M87)E(&%N>2!M97-S86=E<R!O;B!T:&4*("`@("`J("=A=61I;R<@;65S<V%G
M92!S=&%C:RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1M97-S86=E
M4W1A8VL@("`@(%1H92!S=&%C:R!O9B!M97-S86=E<RX*("`@("`J($!P87)A
M;2!A<G)A>2`D;W!T:6]N<R`@06X@87)R87D@;V8@;W!T:6]N<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@;F]T:69Y*"8D;65S<V%G95-T86-K+"`D;W!T:6]N
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1M97-S86=E
M4W1A8VLI*2!["B`@("`@("`@("`@('=H:6QE("@D;65S<V%G92`](&%R<F%Y
M7W-H:69T*"1M97-S86=E4W1A8VLI*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^9V5T365S<V%G92@D;65S<V%G92D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S(&]N92!M97-S86=E
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@3VYE(&UE
M<W-A9V4@:&%S:"!F<F]M('1H92!S=&%C:RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T365S<V%G92@D;65S<V%G92D*("`@('L*("`@("`@("`D979E;G0@
M/2`D=&AI<RT^9V5T179E;G0H)&UE<W-A9V4I.PH@("`@("`@(&5C:&\@)SQE
M;6)E9"!S<F,](B<L(&AT;6QS<&5C:6%L8VAA<G,H)&5V96YT+3YG971-97-S
M86=E*"DI+`H@("`@("`@("`@("`@)R(@=VED=&@](C`B(&AE:6=H=#TB,"(@
M875T;W-T87)T/2)T<G5E(B`O/B<["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]J879A<V-R:7!T+G!H<``````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#`Q-``Q,#4Q-30S,3`V
M,``P,C4S,#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+G!H<"<["@HO*BH*("H@5&AE($YO=&EF:6-A=&EO;E],:7-T
M96YE<E]J879A<V-R:7!T.CH@8VQA<W,@<')O=FED97,@9G5N8W1I;VYA;&ET
M>2!F;W(*("H@:6YS97)T:6YG(&IA=F%S8W)I<'0@8V]D92!F<F]M('1H92!M
M97-S86=E('-T86-K(&EN=&\@=&AE('!A9V4N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O:F%V
M87-C<FEP="YP:'`L=B`Q+C<N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C,P(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC
M;&%S<R!.;W1I9FEC871I;VY?3&ES=&5N97)?:F%V87-C<FEP="!E>'1E;F1S
M($YO=&EF:6-A=&EO;E],:7-T96YE<B!["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VY?3&ES
M=&5N97)?:F%V87-C<FEP="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]H86YD
M;&5S(#T@87)R87DH)VIA=F%S8W)I<'0G(#T^("<G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!A('5N:7%U92!I9&5N=&EF:65R(&9O<B!T:&ES
M(&QI<W1E;F5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!5;FEQ
M=64@:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G:F%V87-C<FEP="<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!/=71P=71S('1H92!J879A<V-R:7!T(&-O9&4@:68@=&AE<F4@87)E
M(&%N>2!M97-S86=E<R!O;B!T:&4*("`@("`J("=J879A<V-R:7!T)R!M97-S
M86=E('-T86-K(&%N9"!I9B!T:&4@)VYO=&EF>5]J879A<V-R:7!T)R!O<'1I
M;VX@:7,@<V5T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&UE<W-A
M9V53=&%C:R`@("`@5&AE('-T86-K(&]F(&UE<W-A9V5S+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1O<'1I;VYS("!!;B!A<G)A>2!O9B!O<'1I;VYS+B!/<'1I
M;VYS.B`G;F]S8W)I<'0G"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO=&EF>2@F
M)&UE<W-A9V53=&%C:RP@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&EF("AC;W5N="@D;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("!I
M9B`H96UP='DH)&]P=&EO;G-;)VYO<V-R:7!T)UTI*2!["B`@("`@("`@("`@
M("`@("!E8VAO("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^)SL*
M("`@("`@("`@("`@("`@(&5C:&\@(EQN/"$M+5QN(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!W:&EL92`H)&UE<W-A9V4@/2!A<G)A>5]S:&EF="@D
M;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$UE
M<W-A9V4H)&UE<W-A9V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D;W!T:6]N<ULG;F]S8W)I<'0G72DI('L*("`@("`@("`@("`@
M("`@(&5C:&\@(B\O+2T^7&X\+W-C<FEP=#Y<;B(["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S(&]N92!M
M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@
M3VYE(&UE<W-A9V4@:&%S:"!F<F]M('1H92!S=&%C:RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T365S<V%G92@D;65S<V%G92D*("`@('L*("`@("`@("`D
M979E;G0@/2`D=&AI<RT^9V5T179E;G0H)&UE<W-A9V4I.PH@("`@("`@(&5C
M:&\@)&5V96YT+3YG971-97-S86=E*"D@+B`B7&XB.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#4W
M,``Q,#4Q-30S,3`V,``P,C0T-S``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+G!H<"<["@HO*BH*("H@5&AE($YO=&EF
M:6-A=&EO;E],:7-T96YE<E]S=&%T=7,Z.B!C;&%S<R!P<F]V:61E<R!F=6YC
M=&EO;F%L:71Y(&9O<@H@*B!D:7-P;&%Y:6YG(&UE<W-A9V5S(&9R;VT@=&AE
M(&UE<W-A9V4@<W1A8VL@87,@82!S=&%T=7,@;&EN92X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP+'8@,2XR.2XR+C4@,C`P-B\P,2\P,2`R,3HR.#HS,"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7TYO=&EF:6-A=&EO;@H@*B\*
M8VQA<W,@3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T871U<R!E>'1E;F1S($YO
M=&EF:6-A=&EO;E],:7-T96YE<B!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VY?3&ES=&5N
M97)?<W1A='5S*"D*("`@('L*("`@("`@("`D=&AI<RT^7VAA;F1L97,@/2!A
M<G)A>2@G:&]R9&4N97)R;W(G("`@/3X@87)R87DH)V%L97)T<R]E<G)O<BYP
M;F<G+"!?*")%<G)O<B(I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&]R9&4N<W5C8V5S<R<@/3X@87)R87DH)V%L97)T<R]S=6-C97-S
M+G!N9R<L(%\H(E-U8V-E<W,B*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAO<F1E+G=A<FYI;F<G(#T^(&%R<F%Y*"=A;&5R=',O=V%R
M;FEN9RYP;F<G+"!?*")787)N:6YG(BDI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=H;W)D92YM97-S86=E)R`]/B!A<G)A>2@G86QE<G1S
M+VUE<W-A9V4N<&YG)RP@7R@B365S<V%G92(I*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI<R!L
M:7-T96YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@56YI<75E
M(&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@
M("`@("!R971U<FX@)W-T871U<R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M=71P=71S('1H92!S=&%T=7,@;&EN92!I9B!T:&5R92!A<F4@86YY(&UE<W-A
M9V5S(&]N('1H92`G<W1A='5S)PH@("`@("H@;65S<V%G92!S=&%C:RX*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1M97-S86=E4W1A8VL@(%1H92!S
M=&%C:R!O9B!M97-S86=E<RX*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N
M<R`@("`@("`@06X@87)R87D@;V8@;W!T:6]N<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F]T:69Y*"8D;65S<V%G95-T86-K+"`D;W!T:6]N<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1M97-S86=E4W1A8VLI*2![
M"B`@("`@("`@("`@('=H:6QE("@D;65S<V%G92`](&%R<F%Y7W-H:69T*"1M
M97-S86=E4W1A8VLI*2!["B`@("`@("`@("`@("`@("!E8VAO("1T:&ES+3YG
M971-97-S86=E*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E8VAO("<\8G(@8VQA<W,](G-P86-E<B(@+SXG.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($]U='!U=',@;VYE(&UE<W-A9V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E("!/;F4@;65S<V%G92!H
M87-H(&9R;VT@=&AE('-T86-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-
M97-S86=E*"1M97-S86=E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["@H@("`@("`@("1E=F5N="`]("1T:&ES+3YG971%=F5N="@D;65S<V%G
M92D["B`@("`@("`@)'1E>'0@/2`D979E;G0M/F=E=$UE<W-A9V4H*3L*"B`@
M("`@("`@:68@*"%I;E]A<G)A>2@G8V]N=&5N="YR87<G+"`D=&AI<RT^9V5T
M1FQA9W,H)&UE<W-A9V4I*2D@>PH@("`@("`@("`@("`D=&5X="`](&AT;6QS
M<&5C:6%L8VAA<G,H)'1E>'0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("<\<"!C;&%S<STB;F]T:6-E(CXG("X@2&]R9&4Z.FEM9R@D=&AI<RT^7VAA
M;F1L97-;)&UE<W-A9V5;)W1Y<&4G75U;,%TL("1T:&ES+3Y?:&%N9&QE<ULD
M;65S<V%G95LG='EP92==75LQ72P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI("X@)R9N8G-P.R9N8G-P.R<@+B`D=&5X="`N("<\+W`^
M)SL*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B]%=F5N="YP:'``````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C4R-``Q,#4Q-30S,3`V,``P,C(T,S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!.;W1I9FEC871I;VY?179E;G0Z.B!C;&%S<R!P<F]V:61E<R!A(&-O;G1A
M:6YE<B!F;W(@<&%S<VEN9PH@*B!M97-S86=E<R!T;R!.;W1I9FEC871I;VY?
M3&ES=&5N97(@8VQA<W-E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B]%=F5N="YP:'`L=B`Q+C4N,BXU(#(P
M,#8O,#$O,#$@,C$Z,C@Z,CD@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@2&%N<R!,96QL96QI9"`\:&%N<T!V96QU;2YN970^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!(86YS($QE;&QE;&ED(#QH86YS0'9E
M;'5M+FYE=#X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7TYO=&EF:6-A=&EO;@H@*B\*8VQA<W,@3F]T:69I8V%T:6]N7T5V96YT
M('L*"B`@("`O*BH*("`@("`J(%1H92!M97-S86=E(&)E:6YG('!A<W-E9"X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?;65S<V%G92`]("<G.PH*("`@("\J*@H@("`@("H@
M268@<&%S<V5D+"!S971S('1H92!M97-S86=E(&9O<B!T:&ES(&5V96YT+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@(%1H92!T97AT
M(&UE<W-A9V4@9F]R('1H:7,@979E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($YO=&EF:6-A=&EO;E]%=F5N="@D;65S<V%G92`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*"%I<U]N=6QL*"1M97-S86=E*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5T365S<V%G92@D;65S<V%G92D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@=&5X="!M97-S86=E(&9O<B!T:&ES
M(&5V96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@
M(%1H92!T97AT(&UE<W-A9V4@=&\@9&ES<&QA>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T365S<V%G92@D;65S<V%G92D*("`@('L*("`@("`@("`D=&AI
M<RT^7VUE<W-A9V4@/2`D;65S<V%G93L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E=',@=&AE('1E>'0@;65S<V%G92!F;W(@=&AI<R!E=F5N="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@;65S<V%G92!T;R!D
M:7-P;&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S86=E*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M97-S86=E.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+G!H<```````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-C(S`#$P-3$U-#,Q
M,#8P`#`R,S$T-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($YO=&EF:6-A=&EO;E],:7-T96YE
M<CHZ(&-L87-S('!R;W9I9&5S(&9U;F-T:6]N86QI='D@9F]R(&1I<W!L87EI
M;F<*("H@;65S<V%G97,@9G)O;2!T:&4@;65S<V%G92!S=&%C:R!A<R!A('-T
M871U<R!L:6YE+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+G!H<"QV(#$N,38N,BXW(#(P,#8O
M,#$O,#$@,C$Z,C@Z,CD@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E
M($AO<F1E7TYO=&EF:6-A=&EO;@H@*B\*8VQA<W,@3F]T:69I8V%T:6]N7TQI
M<W1E;F5R('L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(&UE<W-A9V4@='EP
M97,@=&AA="!T:&ES(&QI<W1E;F5R(&AA;F1L97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H86YD;&5S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U
M;F-T:6]N($YO=&EF:6-A=&EO;E],:7-T96YE<B@I"B`@("!["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$;V5S('1H:7,@;&ES=&5N97(@:&%N9&QE(&$@8V5R
M=&%I;B!T>7!E(&]F(&UE<W-A9V4_"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@5&AE(&UE<W-A9V4@='EP92!I;B!Q=65S=&EO;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AI<R!L:7-T
M96YE<B!H86YD;&5S('1H92!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!H
M86YD;&5S*"1T>7!E*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI
M<RT^7VAA;F1L97-;)'1Y<&5=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!A('5N:7%U92!I9&5N=&EF:65R(&9O<B!T:&ES(&QI<W1E;F5R+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!5;FEQ=64@:60N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H*0H@("`@>PH@("`@("`@(')E='5R
M;B!G971?8VQA<W,H)'1H:7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T
M<'5T<R!T:&4@<W1A='5S(&QI;F4L('-E;F1S(&5M86EL<RP@<&%G97,L(&5T
M8RXL(&EF('1H97)E"B`@("`@*B!A<F4@86YY(&UE<W-A9V5S(&]N('1H:7,@
M;&ES=&5N97(G<R!M97-S86=E('-T86-K+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`F)&UE<W-A9V53=&%C:R`@5&AE('-T86-K(&]F(&UE<W-A9V5S
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS("`@("`@("!!;B!A<G)A
M>2!O9B!O<'1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!N;W1I9GDH)B1M
M97-S86=E4W1A8VMS+"`D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!0<F]C97-S97,@;VYE(&UE<W-A9V4@9G)O;2!T
M:&4@;65S<V%G92!S=&%C:RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&UE<W-A9V4@($]N92!M97-S86=E(&AA<V@@9G)O;2!T:&4@<W1A8VLN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("![
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G-E<FEA;&EZ92!A;B!E=F5N="!F
M<F]M('1H92!M97-S86=E('-T86-K+"!C:&5C:VEN9R!T;R!S964@:68@=&AE
M"B`@("`@*B!A<'!R;W!R:6%T92!C;&%S<R!E>&ES=',@86YD(&ML=61G:6YG
M(&ET(&EN=&\@82!B87-E($YO=&EF:6-A=&EO;E]%=F5N=`H@("`@("H@;V)J
M96-T(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T179E;G0H)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@)&]B(#T@9F%L<V4["B`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@D;65S<V%G95LG8VQA<W,G72DI('L*("`@("`@("`@
M("`@)&]B(#T@0'5N<V5R:6%L:7IE*"1M97-S86=E6R=E=F5N="==*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+T5V96YT+G!H<"<["B`@("`@("`@("`@("1O8B`]
M($!U;G-E<FEA;&EZ92@D;65S<V%G95LG979E;G0G72D["B`@("`@("`@("`@
M(&EF("@A;65T:&]D7V5X:7-T<R@D;V(L("=G971-97-S86=E)RDI('L*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D;V(M/E]M97-S86=E*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1O8B`]("9N97<@3F]T:69I8V%T:6]N7T5V96YT
M*"1O8BT^7VUE<W-A9V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92=V92!F86EL960@=&\@
M8W)E871E(&$@=F%L:60@3F]T:69I8V%T:6]N7T5V96YT(&]B:F5C=`H@("`@
M("`@("`J("AO<B!S=6)C;&%S<R!O8FIE8W0I('-O(&9A<BP@<F5T=7)N(&$@
M4$5!4E]%<G)O<BX@*B\*("`@("`@("!I9B`H(6UE=&AO9%]E>&ES=',H)&]B
M+"`G9V5T365S<V%G92<I*2!["B`@("`@("`@("`@("1O8B`](%!%05(Z.G)A
M:7-E17)R;W(H)U5N86)L92!T;R!D96-O9&4@;65S<V%G92!E=F5N=#H@)R`N
M("1M97-S86=E6R=E=F5N="==*3L*("`@("`@("!]"@H@("`@("`@("\J(%-P
M96-I86QL>2!H86YD;&4@4$5!4E]%<G)O<B!O8FIE8W1S(&%N9"!A9&0@=7-E
M<FEN9F\@:68*("`@("`@("`@*B!I="=S('1H97)E+B`J+PH@("`@("`@(&EF
M("AM971H;V1?97AI<W1S*"1O8BP@)V=E=%5S97));F9O)RDI('L*("`@("`@
M("`@("`@)'5S97)I;F9O(#T@)&]B+3YG9715<V5R26YF;R@I.PH@("`@("`@
M("`@("!I9B`H)'5S97)I;F9O*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'5S97)I;F9O*2D@>PH@("`@("`@("`@("`@("`@("`@("1U<V5R
M:6YF;R`]($!I;7!L;V1E*"<L("<L("1U<V5R:6YF;RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;V(M/E]M97-S86=E(#T@)&]B+3YG
M971-97-S86=E*"D@+B`G(#H@)R`N("1U<V5R:6YF;SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%5N<V5R:6%L:7IE(&%N(&%R<F%Y(&]F(&5V96YT(&9L86=S
M(&9R;VT@=&AE(&UE<W-A9V4@<W1A8VLN("!)9B!T:&ES"B`@("`@*B!E=F5N
M="!H87,@;F\@9FQA9W,L(&]R('1H92!F;&%G<R!A<G)A>2!C;W5L9"!N;W0@
M8F4@=6YS97)I86QI>F5D+"!A;@H@("`@("H@96UP='D@87)R87D@:7,@<F5T
M=7)N960N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M;V8@9FQA9W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9L86=S*"1M97-S
M86=E*0H@("`@>PH@("`@("`@("\J($EF('1H:7,@;65S<V%G92!D;V5S;B=T
M(&AA=F4@86YY(&9L86=S+"!R971U<FX@86X@96UP='D*("`@("`@("`@*B!A
M<G)A>2X@*B\*("`@("`@("!I9B`H96UP='DH)&UE<W-A9V5;)V9L86=S)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@56YS97)I86QI>F4@=&AE(&9L86=S(&%R<F%Y(&9R;VT@=&AE
M(&UE<W-A9V4N("HO"B`@("`@("`@)&9L86=S(#T@0'5N<V5R:6%L:7IE*"1M
M97-S86=E6R=F;&%G<R==*3L*"B`@("`@("`@+RH@268@=V4@8V]U;&1N)W0@
M=6YS97)I86QI>F4@=&AE(&9L86=S(&%R<F%Y+"!R971U<FX@86X@96UP='D*
M("`@("`@("`@*B!A<G)A>2X@*B\*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F
M;&%G<RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&9L86=S.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M24U!4"\`````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`Q-C<T-``@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92])34%0+T%#3"\`````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C``,#$W,S0S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S0S,30N<&AP````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#(Q-@`Q
M,#4Q-30S,3`V,``P,C$Q-#(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`G.PH*+RHJ"B`J($-O;G1A:6YS(&9U;F-T:6]N
M<R!R96QA=&5D('1O(&UA;F%G:6YG($%C8V5S<R!#;VYT<F]L($QI<W1S(&]N
M(&%N($E-05`*("H@<V5R=F5R('5S:6YG(%)&0R`T,S$T+@H@*@H@*B!297%U
M:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W5S97)N86UE)R`@5&AE('5S
M97)N86UE(&9O<B!T:&4@<V5R=F5R(&-O;FYE8W1I;VX*("H@("`G<&%S<W=O
M<F0G("!4:&4@<&%S<W=O<F0@9F]R('1H92!S97)V97(@8V]N;F5C=&EO;@H@
M*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S(&]F
M('1H92!S97)V97(N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@)VQO8V%L
M:&]S="<*("H@("`G<&]R="<@("`@("!4:&4@<V5R=F5R('!O<G0@=&\@=VAI
M8V@@=V4@=VEL;"!C;VYN96-T+@H@*B`@("`@("`@("`@("`@($E-05`@:7,@
M9V5N97)A;&QY(#$T,RP@=VAI;&4@24U!4"U34TP@:7,@9V5N97)A;&QY(#DY
M,RX*("H@("`@("`@("`@("`@("!$149!54Q4.B`Q-#,*("H@("`G<')O=&]C
M;VPG("!4:&4@8V]N;F5C=&EO;B!P<F]T;V-O;"`H92YG+B`G:6UA<"<L("=P
M;W`S)RP@)VYN='`G*2X*("H@("`@("`@("`@("`@("!0<F]T;V-O;"!I<R!O
M;F4@;V8@)VEM87`O;F]T;',G("AO<B!O;FQY("=I;6%P)R!I9B!Y;W4*("H@
M("`@("`@("`@("`@("!H879E(&$@8RUC;&EE;G0@=F5R<VEO;B`R,#`P8R!O
M<B!O;&1E<BDL("=I;6%P+W-S;"<L(&]R"B`J("`@("`@("`@("`@("`@)VEM
M87`O<W-L+VYO=F%L:61A=&4M8V5R="<@*&9O<B!A('-E;&8M<VEG;F5D(&-E
M<G1I9FEC871E*2X*("H@("`@("`@("`@("`@("!$149!54Q4.B`G:6UA<"<\
M+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<"QV(#$N,BXR+C$@,C`P-B\P,B\P-B`R,SHR,3HQ.2!S96QS
M:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#8@36%T="!396QS:WD@/'-E
M;'-K>4!C;VQU;6)I82YE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO"F-L87-S
M($E-05!?04-,7W)F8S0S,30@97AT96YD<R!)34%07T%#3%]R9F,R,#@V('L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!;GD@861D:71I;VYA;"!P87)A;65T97)S
M('1H:7,@9')I=F5R(&UA>2!N965D+@H@("`@("HO"B`@("!F=6YC=&EO;B!)
M34%07T%#3%]R9F,T,S$T*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@('!A<F5N=#HZ24U!4%]!0TQ?<F9C,C`X-B@D<&%R86US*3L*"B`@("`@
M("`@)'1H:7,M/E]R:6=H='-,:7-T(#T@87)R87DH"B`@("`@("`@("`@("`G
M;"<@/3X@7R@B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(BDL"B`@
M("`@("`@("`@("`G<B<@/3X@7R@B4F5A9"!M97-S86=E<R(I+`H@("`@("`@
M("`@("`@)W,G(#T^(%\H(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(I
M+`H@("`@("`@("`@("`@)W<G(#T^(%\H(DUA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(BDL"B`@("`@("`@("`@("`G
M:2<@/3X@7R@B26YS97)T(&UE<W-A9V5S(BDL"B`@("`@("`@("`@("`G<"<@
M/3X@7R@B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I(BDL"B`@("`@("`@("`@("`G:R<@/3X@7R@B0W)E871E('-U8B!F;VQD
M97)S(BDL"B`@("`@("`@("`@("`G>"<@/3X@7R@B1&5L971E('-U8B!F;VQD
M97)S(BDL"B`@("`@("`@("`@("`G="<@/3X@7R@B1&5L971E(&UE<W-A9V5S
M(BDL"B`@("`@("`@("`@("`G92<@/3X@7R@B4'5R9V4@;65S<V%G97,B*2P*
M("`@("`@("`@("`@("=A)R`]/B!?*")!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(I"B`@("`@("`@*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`T,C0V-P`Q,#4Q-30S,3`V,``P,C$Q-C``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($-O;G1A
M:6YS(&9U;F-T:6]N<R!R96QA=&5D('1O(&UA;F%G:6YG($%C8V5S<R!#;VYT
M<F]L($QI<W1S(&]N(&%N($E-05`*("H@<V5R=F5R('5S:6YG(%)&0R`R,#@V
M+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W5S97)N
M86UE)R`@5&AE('5S97)N86UE(&9O<B!T:&4@<V5R=F5R(&-O;FYE8W1I;VX*
M("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@9F]R('1H92!S97)V97(@
M8V]N;F5C=&EO;@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O<B!)
M4"!A9&1R97-S(&]F('1H92!S97)V97(N"B`J("`@("`@("`@("`@("`@1$5&
M055,5#H@)VQO8V%L:&]S="<*("H@("`G<&]R="<@("`@("!4:&4@<V5R=F5R
M('!O<G0@=&\@=VAI8V@@=V4@=VEL;"!C;VYN96-T+@H@*B`@("`@("`@("`@
M("`@($E-05`@:7,@9V5N97)A;&QY(#$T,RP@=VAI;&4@24U!4"U34TP@:7,@
M9V5N97)A;&QY(#DY,RX*("H@("`@("`@("`@("`@("!$149!54Q4.B`Q-#,*
M("H@("`G<')O=&]C;VPG("!4:&4@8V]N;F5C=&EO;B!P<F]T;V-O;"`H92YG
M+B`G:6UA<"<L("=P;W`S)RP@)VYN='`G*2X*("H@("`@("`@("`@("`@("!0
M<F]T;V-O;"!I<R!O;F4@;V8@)VEM87`O;F]T;',G("AO<B!O;FQY("=I;6%P
M)R!I9B!Y;W4*("H@("`@("`@("`@("`@("!H879E(&$@8RUC;&EE;G0@=F5R
M<VEO;B`R,#`P8R!O<B!O;&1E<BDL("=I;6%P+W-S;"<L(&]R"B`J("`@("`@
M("`@("`@("`@)VEM87`O<W-L+VYO=F%L:61A=&4M8V5R="<@*&9O<B!A('-E
M;&8M<VEG;F5D(&-E<G1I9FEC871E*2X*("H@("`@("`@("`@("`@("!$149!
M54Q4.B`G:6UA<"<\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<"QV(#$N-BXX+C$R(#(P,#8O,#<O,C8@
M,3DZ,S0Z-#4@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P
M-B!#:')I<R!(87-T:64@/&EM<$!O86LM=V]O9"YC;RYU:SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H<FES($AA<W1I92`\:6UP0&]A:RUW;V]D
M+F-O+G5K/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?24U!4`H@*B\*8VQA<W,@24U!4%]!0TQ?<F9C,C`X-B!E>'1E;F1S($E-
M05!?04-,('L*"B`@("`O*BH*("`@("`J($E-05`@<F5S;W5R8V4N"B`@("`@
M*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]I;6%P
M.PH*("`@("\J*@H@("`@("H@3&ES="!O9B!S97)V97(G<R!C87!A8FEL:71I
M97,L(&]U='!U="!O9B!#05!!0DE,2519(&-O;6UA;F0N($9O<FUA=&5D"B`@
M("`@*B!A<R!A(&AA<V@*("`@("`J(#QC;V1E/@H@("`@("H@87)R87DH"B`@
M("`@*B`@("`@*F-A<&%B:6QI='DJ(#T^(#$*("`@("`J("D*("`@("`J(#PO
M8V]D93X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V-A<',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!A
M9&1I=&EO;F%L('!A<F%M971E<G,@=&AI<R!D<FEV97(@;6%Y(&YE960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($E-05!?04-,7W)F8S(P.#8H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A
M>5]M97)G92AA<G)A>2@G:&]S='-P96,G(#T^("=L;V-A;&AO<W0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!O<G0G
M(#T^(#$T,RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P<F]T;V-O;"<@/3X@)VEM87`G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH*("`@("`@("`D=&AI
M<RT^7V-A<',@/2`D=&AI<RT^7V=E=$-A<&%B:6QI='DH*3L*("`@("`@("!I
M9B`H:7-?82@D=&AI<RT^7V-A<',L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B`]("1T:&ES+3Y?8V%P<SL*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*'-U8G-T<B@D=&AI
M<RT^7W!A<F%M<ULG<')O=&]C;VPG72P@,"P@-"D@(3T@)VEM87`G*2!["B`@
M("`@("`@("`@("\J($YO('!O:6YT(&EN(&=O:6YG(&%N>2!F=7)T:&5R(&EF
M(&ET)W,@;F]T(&%N($E-05`@<V5R=F5R+B`J+PH@("`@("`@("`@("`D=&AI
M<RT^7V5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<BA?*")/;FQY($E-05`@<V5R
M=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(I*3L*("`@("`@("`@("`@
M)'1H:7,M/E]S=7!P;W)T960@/2!F86QS93L*("`@("`@("!](&5L<V5I9B`H
M(6ES<V5T*"1T:&ES+3Y?8V%P<ULG86-L)UTI*2!["B`@("`@("`@("`@("\J
M($EF('=E(&-O=6QD;B=T(&=E="!T:&4@<V5R=F5R)W,@8V%P86)I;&ET>2P@
M=V4G;&P@87-S=6UE($%#3"!I<PH@("`@("`@("`@("`@("!N;W0@<W5P<&]R
M=&5D(&9O<B!N;W<N("HO"B`@("`@("`@("`@("1T:&ES+3Y?<W5P<&]R=&5D
M(#T@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]S=7!P;W)T960@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]P<F]T96-T960@/2!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G
M72D["@H@("`@("`@("1T:&ES+3Y?<FEG:'1S3&ES="`](&%R<F%Y*`H@("`@
M("`@("`@("`@)VPG(#T^(%\H(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<B(I+`H@("`@("`@("`@("`@)W(G(#T^(%\H(E)E860@;65S<V%G97,B
M*2P*("`@("`@("`@("`@("=S)R`]/B!?*")-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,B*2P*("`@("`@("`@("`@("=W)R`]/B!?*")-87)K('=I=&@@
M;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(I+`H@("`@
M("`@("`@("`@)VDG(#T^(%\H(DEN<V5R="!M97-S86=E<R(I+`H@("`@("`@
M("`@("`@)W`G(#T^(%\H(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*2(I+`H@("`@("`@("`@("`@)V,G(#T^(%\H(D-R96%T
M92!S=6(@9F]L9&5R<R(I+`H@("`@("`@("`@("`@)V0G(#T^(%\H(D1E;&5T
M92!A;F0@<'5R9V4@;65S<V%G97,B*2P*("`@("`@("`@("`@("=A)R`]/B!?
M*")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<R(I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7VEM87`I('L*("`@("`@("`@
M("`@)'1H:7,M/E]I;6%P(#T@0&EM87!?;W!E;BAS<')I;G1F*"=[)7,Z)60O
M)7-])RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!/4%](04Q&3U!%
M3BD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]I;6%P*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEM87`@/2!014%2.CIR86ES945R<F]R*&EM87!?
M;&%S=%]E<G)O<B@I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@(6ES7V$H)'1H:7,M/E]I;6%P+"`G4$5!4E]%<G)O<B<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@04-,(&]N(&%N($E-05`@
M<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@
M("`@(%1H92!F;VQD97(@;VX@=VAI8V@@=&\@961I="!T:&4@04-,+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<VAA<F5?=7-E<B`@5&AE('5S97(@=&\@9W)A
M;G0@<FEG:'1S('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A8VP@("`@("`@
M("`@06X@87)R87DL('1H92!K97ES(&]F('=H:6-H(&%R92!T:&4@<FEG:'1S
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B92!G<F%N
M=&5D("AS964@4D9#(#(P.#8I+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!F86EL=7)E(&]R
M(&EF('-E<G9E<@H@("`@("H@("`@("`@("`@("`@("`@9&]E<VXG="!S=7!P
M;W)T($%#3',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T94%#3"@D9F]L
M9&5R+"`D<VAA<F5?=7-E<BP@)&%C;"D*("`@('L*("`@("`@("!I9B`H(21T
M:&ES+3Y?8V]N;F5C="@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM87`["B`@("`@("`@?0H*("`@("`@("`D86-L7W-T<B`]("<G.PH@("`@
M("`@(&EF("@A96UP='DH)&%C;"DI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)&%C;"!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("1A8VQ?
M<W1R("X]("1K97D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($-A;B=T(&-A;&P@=&AI<R!A<R!`:6UA<%]S971A8VPH*2!A<R!S=7!P
M<F5S<VEN9R!E<G)O<G,@;&5A9',@=&\*("`@("`@("`@("!I;6%P7V5R<F]R
M<R@I(')E='5R;FEN9R!N;W1H:6YG+B`J+PH@("`@("`@("1R97-U;'0@/2!I
M;6%P7W-E=&%C;"@D=&AI<RT^7VEM87`L("1F;VQD97(L("1S:&%R95]U<V5R
M+"`D86-L7W-T<BD["@H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@
M("`@("`D97)R;W)S(#T@:6UA<%]E<G)O<G,H*3L*("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1E<G)O<G,I*2!["B`@("`@("`@("`@("`@("`D97)R;W)?
M<W1R:6YG(#T@)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R;W)S
M(&%S("1E<G(I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&5R<B`]/2`G
M04-,(&YO="!A=F%I;&%B;&4@;VX@=&AI<R!)34%0('-E<G9E<B<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<B`N/2!?*")4:&ES($E-05`@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D97)R;W)?
M<W1R:6YG("X]("1E<G(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;W)?<W1R:6YG*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(I
M+"`D<VAA<F5?=7-E<BP@)&9O;&1E<BP@)&%C;%]S='(I*3L*("`@("`@("!]
M"@H@("`@("`@("\J($EF(%!(4"`U(&ES;B=T(&%V86EL86)L92!W86ET(&$@
M8FET('1O(&5N<W5R92!!0TP@<')O<&%G871E<R!I;@H@("`@("`@("`J($-Y
M<G5S($UU<F1E<B!C;VYF:6=U<F%T:6]N+B`J+PH@("`@("`@(&EF("@A9G5N
M8W1I;VY?97AI<W1S*"=I;6%P7V=E=&%C;"<I*2!["B`@("`@("`@("`@('-L
M965P*#4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%9&ET<R!A;B!!0TP@;VX@86X@24U!4"!S
M97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L9&5R("`@
M("`@5&AE(&9O;&1E<B!O;B!W:&EC:"!T;R!E9&ET('1H92!!0TPN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S:&%R95]U<V5R("!4:&4@=7-E<B!T;R!G<F%N
M="!R:6=H=',@=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&%C;"`@("`@("`@
M("!!;B!A<G)A>2P@=&AE(&ME>7,@;V8@=VAI8V@@87)E('1H92!R:6=H=',@
M=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)E(&=R86YT
M960@*'-E92!21D,@,C`X-BDN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E('5N;&5S<R!S
M97)V97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@("`@("`@<W5P<&]R="!!
M0TQS+"!R971U<FYS("=N;U]S=7!P;W)T)PH@("`@("HO"B`@("!F=6YC=&EO
M;B!E9&ET04-,*"1F;VQD97(L("1S:&%R95]U<V5R+"`D86-L*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^8W)E871E04-,*"1F;VQD97(L("1S:&%R
M95]U<V5R+"`D86-L*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(&=E="!T:&4@<F5S=6QT(&]F(&$@0T%004))3$E462!C;VUM86YD('1O
M('1H92!C=7)R96YT($E-05`*("`@("`J('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;B!A<G)A>2!C;VYT86EN:6YG('1H92!S97)V97(G<R!C87!A8FEL:71I
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971#87!A8FEL:71Y*"D*("`@
M('L*("`@("`@("`D8V%P86)I;&ET:65S(#T@;G5L;#L*("`@("`@("`D<V5R
M=F5R(#T@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT["B`@("`@("`@)'-U
M8E]P<F]T;R`](&YU;&P["@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7EM>
M+UTK+W-S;'PG+"`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72DI('L*("`@
M("`@("`@("`@)'-E<G9E<B`]("=S<VPZ+R\G("X@)'-E<G9E<CL*("`@("`@
M("!]"@H@("`@("`@("1I;6%P(#T@9G-O8VMO<&5N*"1S97)V97(L("1T:&ES
M+3Y?<&%R86US6R=P;W)T)UTL("1E<G)N;RP@)&5R<G-T<BP@,S`I.PH*("`@
M("`@("!I9B`H(21I;6%P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,B*2`N("<@+2`G("X@*"1E<G)N;R`_(%\H(D-O;FYE8W1I;VX@
M9F%I;&5D.B`B*2`N("1E<G)N;R`N("<@.B`G("X@)&5R<G-T<B`Z(%\H(D-O
M;FYE8W1I;VX@9F%I;&5D+B(I*2D["B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-P;VYS92`](&9G
M971S*"1I;6%P+"`T,#DV*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]>7"I<<RM/2R\G+"`D<F5S<&]N<V4I*2!["B`@("`@("`@("`@("`@("!F
M<'5T<R@D:6UA<"P@(G@@0T%004))3$E465QR7&XB*3L*("`@("`@("`@("`@
M("`@("1R97-P;VYS92`]('1R:6TH9F=E=',H)&EM87`L(#$P,C0I*3L*("`@
M("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EPJ7',K0T%004))3$E4
M62\G+"`D<F5S<&]N<V4I*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W!O
M;G-E7V%R<F%Y(#T@97AP;&]D92@G("<L("1R97-P;VYS92D["B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)')E<W!O;G-E7V%R<F%Y(&%S("1V87(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D=F%R+"`G
M/2<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<C(@/2!E>'!L;V1E*"<])RP@)'9A<BP@,BD["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8V%P86)I;&ET:65S6U-T<FEN9SHZ;&]W97(H)'9A
M<C);,%TI75M3=')I;F<Z.FQO=V5R*"1V87(R6S%=*5T@/2`Q.PH@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-A<&%B:6QI=&EE<UM3=')I;F<Z.FQO=V5R*"1V87(I72`]
M(#$["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!F8VQO<V4@*"1I;6%P*3L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(BD@+B`G("T@)R`N(%\H(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(I("X@)UPG>"!#05!!0DE,
M25197"<@.B`G("X@)')E<W!O;G-E*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9C;&]S92`H)&EM
M87`I.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(I
M("X@)R`M("<@+B!?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ("(I("X@)')E<W!O;G-E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!F8VQO<V4@*"1I;6%P*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8V%P86)I;&ET:65S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T<FEE=F4@=&AE(&5X:7-T:6YG($%#3"!F;W(@
M82!F;VQD97(@9G)O;2!T:&4@8W5R<F5N=`H@("`@("H@24U!4"!S97)V97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!F;VQD97(@(%1H92!F;VQD
M97(@=&\@9V5T('1H92!!0TP@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($$@:&%S:"!C;VYT86EN:6YG(&EN9F]R;6%T:6]N(&]N('1H92!!
M0TPN"B`@("`@*B`\<')E/@H@("`@("H@07)R87D@*`H@("`@("H@("!U<V5R
M(#T^($%R<F%Y("@*("`@("`J("`@("!R:6=H="`]/B`Q"B`@("`@*B`@("D*
M("`@("`J("D*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971!0TPH)&9O;&1E<BD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]C87!S6R=A=71H)UU;)V1I9V5S="UM9#4G72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9V5T04-,*"1F;VQD97(L("=D:6=E<W0M;60U)RD[
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?8V%P<ULG875T:"==
M6R=C<F%M+6UD-2==*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G
M971!0TPH)&9O;&1E<BP@)V-R86TM;60U)RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T04-,*"1F;VQD97(L("=L
M;V=I;B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E=')I979E('1H92!E>&ES=&EN9R!!0TP@9F]R(&$@9F]L9&5R
M(&9R;VT@=&AE(&-U<G)E;G0*("`@("`J($E-05`@<V5R=F5R+@H@("`@("H*
M("`@("`J($Y".B!I9B!!=71H7U-!4TP@:7,@;F]T(&EN<W1A;&QE9"!T:&ES
M(&9U;F-T:6]N('=I;&P@<V5N9"!T:&4@=7-E<G,*("`@("`J('!A<W-W;W)D
M('1O('1H92!)34%0('-E<G9E<B!A<R!P;&%I;B!T97AT(2$*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&9O;&1E<B`@("!4:&4@9F]L9&5R('1O(&=E="!T:&4@04-,(&9O<BX*
M("`@("`J($!P87)A;2!S=')I;F<@875T:$UE8V@@(%1H92!A=71H;W)I<V%T
M:6]N(&UE8VAA;FES;2!T;R!U<V4N($]N92!O9@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@8W)A;2UM9#4L(&1I9V5S="UM9#4@;W(@;&]G:6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H(&-O;G1A:6YI
M;F<@:6YF;W)M871I;VX@;VX@=&AE($%#3`H@("`@("H@/'!R93X*("`@("`J
M($%R<F%Y("@*("`@("`J("`@=7-E<B`]/B!!<G)A>2`H"B`@("`@*B`@("`@
M<FEG:'0@/3X@,0H@("`@("H@("`I"B`@("`@*B`I"B`@("`@*B`\+W!R93X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$%#3"@D9F]L9&5R+"`D875T:$UE
M8V@I"B`@("!["B`@("`@("`@+RH@268@:6UA<%]G971A8VPH*2!I<R!A=F%I
M;&%B;&4L('5S92!I="`J+PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H
M)VEM87!?9V5T86-L)RDI('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V-O
M;FYE8W0H*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6UA
M<#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<W5L="`]($!I;6%P
M7V=E=&%C;"@D=&AI<RT^7VEM87`L("1F;VQD97(I.PH@("`@("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@("1E<G)O<G,@/2!I;6%P
M7V5R<F]R<R@I.PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G)O
M<G,I*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R7W-T<FEN9R`]("<G
M.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E<G)O<G,@87,@)&5R
M<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&5R<B`]/2`G04-,
M(&YO="!A=F%I;&%B;&4@;VX@=&AI<R!)34%0('-E<G9E<B<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G(@+CT@7R@B5&AI<R!)34%0('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R;W)?<W1R:6YG("X]("1E<G(["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1E<G)O<E]S=')I;F<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L
M9"!N;W0@<F5T<FEE=F4@04-,(BDI*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)')E='5R;D%#3"`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1R97-U;'0@87,@)'5S97(@/3X@)')I9VAT<RD@>PH@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#`L("1I36%X(#T@<W1R;&5N*"1R:6=H=',I.R`D
M:2`\("1I36%X.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)')E='5R
M;D%#3%LD=7-E<EU;)')I9VAT<ULD:5U=(#T@,3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("1R971U<FY!
M0TP["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)&YO=&EF:6-A=&EO;CL*
M"B`@("`@("`@)&AA=F5?<V%S;"`](&9A;'-E.PH@("`@("`@("1R971U<FY!
M0TP@/2!A<G)A>2@I.PH@("`@("`@("1S97)V97(@/2`D=&AI<RT^7W!A<F%M
M<ULG:&]S='-P96,G73L*("`@("`@("`D<W5B7W!R;W1O(#T@;G5L;#L*("`@
M("`@("`D='AI9"`](#`["@H@("`@("`@("\J(%-I;&5N8V4@=V%R;FEN9W,@
M9'5R:6YG(&-H96-K(&EF($%U=&A?4T%33"!M;V1U;&4@:7,@:6YS=&%L;&5D
M+B`J+PH@("`@("`@(&EF("A`:6YC;'5D95]O;F-E("=!=71H+U-!4TPN<&AP
M)RD@>PH@("`@("`@("`@("`D:&%V95]S87-L(#T@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1P87-S(#T@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT[
M"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7EM>+UTK+W-S;'PG+"`D=&AI
M<RT^7W!A<F%M<ULG<')O=&]C;VPG72DI('L*("`@("`@("`@("`@)'-E<G9E
M<B`]("=S<VPZ+R\G("X@)'-E<G9E<CL*("`@("`@("!]"@H@("`@("`@("\J
M(%%U;W1E('1H92!F;VQD97(@<W1R:6YG(&EF(&ET(&-O;G1A:6YS(&YO;B!A
M;'!H82UN=6UE<FEC"B`@("`@("`@("`@8VAA<F%C=&5R<RX@*B\*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UQ7+R<L)&9O;&1E<BDI('L*("`@("`@("`@
M("`@)&9O;&1E<B`]("<B)R`N("1F;VQD97(@+B`G(B<["B`@("`@("`@?0H*
M("`@("`@("`D:6UA<"`](&9S;V-K;W!E;B@D<V5R=F5R+"`D=&AI<RT^7W!A
M<F%M<ULG<&]R="==+"`D97)R;F\L("1E<G)S='(L(#,P*3L*"B`@("`@("`@
M:68@*"$D:6UA<"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(BD*("`@("`@("`@("`@
M("`@("X@)R`M("<@+B`H)&5R<FYO(#\@7R@B0V]N;F5C=&EO;B!F86EL960Z
M("(I("X@)&5R<FYO+B<@.B`G("X@)&5R<G-T<B`Z(%\H(D-O;FYE8W1I;VX@
M9F%I;&5D+B(I*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E
M<W!O;G-E(#T@9F=E=',H)&EM87`L(#0P.38I.PH@("`@("`@("`@("!I9B`H
M<')E9U]M871C:"@G+UY<*EQS*T]++R<L("1R97-P;VYS92DI('L*"B`@("`@
M("`@("`@("`@("`O*B!L;V=I;B!U<VEN9R!T:&4@<')E9F5R<F5D(&UE8VAA
M;FES;2!D969A=6QT('1O(&QO9VEN(&EF"B`@("`@("`@("`@("`@("`@("!!
M=71H7U-!4TP@:7,@;F]T(&EN<W1A;&QE9"X@*B\*("`@("`@("`@("`@("`@
M(&EF("@D:&%V95]S87-L("8F("@D875T:$UE8V@@/3T@)V-R86TM;60U)RDI
M('L*("`@("`@("`@("`@("`@("`@("`D;&]G:6X@/2!!=71H7U-!4TPZ.F9A
M8W1O<GDH)V-R86UM9#4G*3L*"B`@("`@("`@("`@("`@("`@("`@9G!U=',H
M)&EM87`L("(D='AI9"!!551(14Y424-!5$4@0U)!32U-1#5<<EQN(BD["B`@
M("`@("`@("`@("`@("`@("`@)&-H86QL96YG92`](&5X<&QO9&4H)R`G+"!T
M<FEM*&9G971S*"1I;6%P+"`Q,#(T*2DI.PH*("`@("`@("`@("`@("`@("`@
M("`D<F5S<&]N<V4@/2`D;&]G:6XM/F=E=%)E<W!O;G-E*"1?4T534TE/3ELG
M:6UP)UU;)W5S97(G72P@)'!A<W,L(&)A<V4V-%]D96-O9&4H)&-H86QL96YG
M95LQ72DI.PH@("`@("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P+"!B87-E
M-C1?96YC;V1E*"1R97-P;VYS92D@+B`B7')<;B(I.PH*("`@("`@("`@("`@
M("`@('T@96QS96EF*"1H879E7W-A<VP@)B8@*"1A=71H365C:"`]/2`G9&EG
M97-T+6UD-2<I*2!["B`@("`@("`@("`@("`@("`@("`@)&QO9VEN(#T@075T
M:%]305-,.CIF86-T;W)Y*"=D:6=E<W1M9#4G*3L*"B`@("`@("`@("`@("`@
M("`@("`@9G!U=',H)&EM87`L("(D='AI9"!!551(14Y424-!5$4@1$E'15-4
M+4U$-5QR7&XB*3L*("`@("`@("`@("`@("`@("`@("`D8VAA;&QE;F=E(#T@
M97AP;&]D92@G("<L('1R:6TH9F=E=',H)&EM87`L(#$P,C0I*2D["@H@("`@
M("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1L;V=I;BT^9V5T4F5S<&]N
M<V4H)%]315-324].6R=I;7`G75LG=7-E<B==+"`D<&%S<RP@8F%S938T7V1E
M8V]D92@D8VAA;&QE;F=E6S%=*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)%]315-324].6R=I;7`G75LG<V5R=F5R)UTL("1?4T534TE/3ELG:6UP)UU;
M)V)A<V5?<')O=&]C;VPG72D["@H@("`@("`@("`@("`@("`@("`@(&9P=71S
M*"1I;6%P+"!B87-E-C1?96YC;V1E*"1R97-P;VYS92D@+B`B7')<;B(I.PH@
M("`@("`@("`@("`@("`@("`@("1R97-P;VYS92`](&5X<&QO9&4H)R`G+"!T
M<FEM*&9G971S*"1I;6%P+"`Q,#(T*2DI.PH@("`@("`@("`@("`@("`@("`@
M("1R97-P;VYS92`](&)A<V4V-%]D96-O9&4H)')E<W!O;G-E6S%=*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1R97-P;VYS92P@)W)S<&%U
M=&@])RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9C
M;&]S92@D:6UA<"D["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R971R:65V92!!0TPB*0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G("T@)R`N(%\H(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(I("X@)T1I9V5S="U-
M1#4@<F5S<&]N<V4G+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!F<'5T<R@D:6UA<"P@(EQR
M7&XB*3L*"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7%<O)RP@)'!A<W,I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1P87-S(#T@861D<VQA<VAE<R@D<&%S<RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P87-S(#T@)R(G("X@)'!A<W,@
M+B`G(B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&9P=71S*"1I;6%P+"`B)'1X:60@3$]'24X@(B`N("1?4T534TE/3ELG
M:6UP)UU;)W5S97(G72`N("<@)R`N("1P87-S("X@(EQR7&XB*3L*"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!T<FEM
M*&9G971S*"1I;6%P+"`Q,#(T*2D["B`@("`@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@B+UXD='AI9%QS3TLO(BP@)')E<W!O;G-E*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T>&ED*RL["B`@("`@("`@("`@("`@("`@("`@9G!U
M=',H)&EM87`L("(D='AI9"!'151!0TP@(B`N("1F;VQD97(@+B`B7')<;B(I
M.PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS92`]('1R:6TH9F=E=',H
M)&EM87`L(#0P.38I*3L*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UY<*EQS*T%#3%QS*R@N*BDO:2<L("1R97-P;VYS92P@)&UA=&-H
M97,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R97-?87)R(#T@)'1H
M:7,M/E]A=&]M:7-E*"1M871C:&5S6S%=*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<U]F;VQD97(@/2!A<G)A>5]S:&EF="@D<F5S7V%R<BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I<U]K97D@/2`Q.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:V5Y(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)')E<U]A<G(@87,@)'9A<BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1I<U]K97DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@)'9A<CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:7-?:V5Y(#T@,#L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!E<FUS(#T@<')E9U]S<&QI="@G+R\G+"`D=F%R+"`M
M,2P@4%)%1U]34$Q)5%].3U]%35!462D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'!E<FUS(&%S("1P7VME>2`]/B`D<%]V
M87(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E
M='5R;D%#3%LD:V5Y75LD<%]V87)=(#T@,3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&ES7VME>2`](#$["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&EM
M87`I.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(BD*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("X@)R`M("<@+B!?*")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B*2`N("(G)'1X:60@1T5404-,)R`Z
M("(@+B1R97-P;VYS92D["@H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@9F-L;W-E
M*"1I;6%P*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(BD*("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G("T@)R`N(%\H(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(I("X@)VQO9VEN(#H@)R`N("1R97-P;VYS
M92D["@H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@9F-L;W-E*"1I;6%P*3L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R971R:65V
M92!!0TPB*0H@("`@("`@("`@("`@("`@("`@("X@)R`M("<@+B!?*")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(I
M("X@)')E<W!O;G-E*3L*"B`@("`@("`@("`@('T*("`@("`@("`@("`@9F-L
M;W-E*"1I;6%P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T=7)N
M04-,.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%N(&$@=7-E<B!E9&ET('1H
M92!!0TP@9F]R('1H:7,@9F]L9&5R/PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!N86UE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<B`@("!!('5S97(@;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@)'5S97(@:&%S('!E<FUI<W-I;VX@
M=&\@961I="!T:&4@04-,(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("1F
M;VQD97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A;D5D:70H)&9O;&1E<BP@
M)'5S97(I"B`@("!["B`@("`@("`@+RH@5V4@8V%N)W0@97-T86)L:7-H(&EF
M('1H92!U<V5R(&ES(&EN(&$@9W)O=7`@=VET:"!T:&4@)V$G"B`@("`@("`@
M("`@<')I=FEL96=E+"!S;R!J=7-T(')E='5R;B!T<G5E(&%N9"!L96%V92!T
M:&4@9&5C:7-I;VX@=&\@=&AE"B`@("`@("`@("`@<V5R=F5R("HO"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<G5D96QY
M('-P;&ET(&$@<W1R:6YG(&EN=&\@)V%T;VUS)RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M;B`@5&AE('-T<FEN9R!T;R!S<&QI="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!;B!A<G)A>2!O9B`G871O;7,G+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?871O;6ES92@D:6XI"B`@("!["B`@("`@("`@)&QE;F=T:"`]('-T
M<FQE;B@D:6XI.PH@("`@("`@("1Q="`](&9A;'-E.PH@("`@("`@("1I9'@@
M/2`P.PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D;&5N9W1H.R`D:2LK*2!["B`@("`@("`@("`@("1C:&%R
M(#T@<W5B<W1R*"1I;BP@)&DL(#$I.PH@("`@("`@("`@("!I9B`H*"1C:&%R
M(#T]("<B)RD@)B8@(21Q="D@>PH@("`@("`@("`@("`@("`@)'%T(#T@=')U
M93L*("`@("`@("`@("`@("`@("1I9'@K*SL*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H*"1C:&%R(#T]("<@)RD@
M)B8@(21Q="D@>PH@("`@("`@("`@("`@("`@)&ED>"LK.PH@("`@("`@("`@
M("!](&5L<V5I9B`H*"1C:&%R(#T]("<B)RD@)B8@)'%T*2!["B`@("`@("`@
M("`@("`@("`D<70@/2!F86QS93L*("`@("`@("`@("`@("`@("1I9'@K*SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AE;7!T
M>2@D;W5T6R1I9'A=*2D@>PH@("`@("`@("`@("`@("`@("`@("1O=71;)&ED
M>%T@/2`D8VAA<CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&]U=%LD:61X72`N/2`D8VAA<CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1O=70["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O061M:6XN<&AP````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S`U,0`Q,#4Q-30S
M,3`V,``P,C`U,#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!)34%07T%D;6EN.CH@8VQA<W,@
M86QL;W<@;6%N86=I;F<@;V8@;6%I;&)O>&5S(&]N($E-05`@<V5R=F5R<RX*
M("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=A9&UI;E]U
M<V5R)R`@("`@(%1H92!N86UE(&]F(&$@=7-E<B!W:71H(&%D;6EN('!R:79I
M;&5G97,N"B`J("`@)V%D;6EN7W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&]F
M('1H92!A9&UI;G-T<F%T;W(N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M
M971E<G,Z/'!R93X*("H@("`G:&]S='-P96,G("`@("`@(%1H92!H;W-T;F%M
M92!O<B!)4"!A9&1R97-S(&]F('1H92!S97)V97(N"B`J("`@("`@("`@("`@
M("`@("`@("!$149!54Q4.B`G;&]C86QH;W-T)PH@*B`@("=P;W)T)R`@("`@
M("`@("`@5&AE('-E<G9E<B!P;W)T('1O('=H:6-H('=E('=I;&P@8V]N;F5C
M="X*("H@("`@("`@("`@("`@("`@("`@($E-05`@:7,@9V5N97)A;&QY(#$T
M,RP@=VAI;&4@24U!4"U34TP@:7,@9V5N97)A;&QY(#DY,RX*("H@("`@("`@
M("`@("`@("`@("`@($1%1D%53%0Z(#$T,PH@*B`@("=P<F]T;V-O;"<@("`@
M("`@5&AE(&-O;FYE8W1I;VX@<')O=&]C;VP@*&4N9RX@)VEM87`G+"`G<&]P
M,R<L("=N;G1P)RDN"B`J("`@("`@("`@("`@("`@("`@("!0<F]T;V-O;"!I
M<R!O;F4@;V8@)VEM87`O;F]T;',G("AO<B!O;FQY("=I;6%P)R!I9B!Y;W4*
M("H@("`@("`@("`@("`@("`@("`@(&AA=F4@82!C+6-L:65N="!V97)S:6]N
M(#(P,#!C(&]R(&]L9&5R*2P@)VEM87`O<W-L)RP*("H@("`@("`@("`@("`@
M("`@("`@(&]R("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G("AF;W(@82!S
M96QF+7-I9VYE9`H@*B`@("`@("`@("`@("`@("`@("`@8V5R=&EF:6-A=&4I
M+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@)VEM87`G"B`J("`@
M)W5S97)H:65R87)C:'DG("!4:&4@:&EE<F%R8VAY('=H97)E('5S97(@;6%I
M;&)O>&5S(&%R92!S=&]R960N"B`J("`@("`@("`@("`@("`@("`@("!$149!
M54Q4.B`G=7-E<BXG"B`J("`@)V1S;B<@("`@("`@("`@("!4:&4@9G5L;"!)
M34%0(&-O;FYE8W1I;VX@<W1R:6YG+@H@*B`@("`@("`@("`@("`@("`@("`@
M268@;F]T('!R97-E;G0L('1H:7,@:7,@8G5I;'0@9G)O;2`G:&]S='-P96,G
M+"`G<&]R="<*("H@("`@("`@("`@("`@("`@("`@(&%N9"`G<')O=&]C;VPG
M('!A<F%M971E<G,N/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-
M05`O24U!4"]!9&UI;BYP:'`L=B`Q+C4N-BXY(#(P,#8O,#4O,S$@,3DZ,SDZ
M-#<@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*
M8VQA<W,@24U!4%]!9&UI;B!["@H@("`@+RHJ"B`@("`@*B!087)A;65T97(@
M:&%S:"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W!A<F%M<SL*"B`@("`O*BH*("`@("`J($E-05`@<F5S;W5R8V4N"B`@
M("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]I
M;6%P.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!W:71H(&%L;"!N96-E
M<W-A<GD@<&%R86UE=&5R<PH@("`@("HO"B`@("!F=6YC=&EO;B!)34%07T%D
M;6EN*"1P87)A;7,I"B`@("!["B`@("`@("`@)&1E9F%U;'1?<&%R86US(#T@
M87)R87DH"B`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)VQO8V%L:&]S="<L
M"B`@("`@("`@("`@("=P;W)T)R`]/B`G,30S)RP*("`@("`@("`@("`@)W!R
M;W1O8V]L)R`]/B`G:6UA<"<L"B`@("`@("`@("`@("=U<V5R:&EE<F%R8VAY
M)R`]/B`G=7-E<BXG"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^7W!A<F%M
M<R`](&%R<F%Y7VUE<F=E*"1D969A=6QT7W!A<F%M<RP@)'!A<F%M<RD["@H@
M("`@("`@("\J($-R96%T92!$4TX@<W1R:6YG+B`J+PH@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P87)A;7-;)V1S;B==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG9'-N)UT@/2!S<')I;G1F*"=[)7,Z)60O)7-])RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R
M="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*3L*("`@("`@("`@("`@
M)'1H:7,M/E]R968@/2`D=&AI<RT^7W!A<F%M<ULG9'-N)UT["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>>RA;7CI=
M*RDZ*%QD*RE<+RA;7GU=*RE]+R<L("1T:&ES+3Y?<&%R86US6R=D<VXG72P@
M)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M:&]S='-P96,G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W!O<G0G72`]("1M871C:&5S6S)=.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UT@/2`D;6%T8VAE<ULS
M73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5F(#T@<W!R:6YT9B@G>R5S
M.B5D+R5S?2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T<R!T;R!T:&4@24U!
M4"!S97)V97(@=VET:"!T:&4@<&%R86UE=&5R<R!P87-S960@=&\@=&AE"B`@
M("`@*B!C;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(')E<V]U
M<F-E?&]B:F5C="`@06X@24U!4"!R97-O=7)C92!O<B!A(%!%05)?17)R;W(@
M;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@
M("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VEM87`I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?:6UA<"`]($!I;6%P7V]P96XH)'1H:7,M/E]R968L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)V%D;6EN7W5S97(G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG861M:6Y?<&%S<W=O
M<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!/
M4%](04Q&3U!%3BD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]I;6%P*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM87`@/2!014%2.CIR86ES945R
M<F]R*%\H(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6UA<#L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9',@82!M86EL8F]X+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&UA:6QB;W@@("`@("!4:&4@;6%I;&)O>"!N86UE('1O(&%D9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1-86EL8F]X*"1M86EL8F]X*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A*"1I;6%P(#T@)'1H:7,M/E]C;VYN96-T*"DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;6%P.PH@("`@("`@('T*("`@
M("`@("!I9B`H(4!I;6%P7V-R96%T96UA:6QB;W@H)&EM87`L("1T:&ES+3Y?
M<F5F("X@)'1H:7,M/E]P87)A;7-;)W5S97)H:65R87)C:'DG72`N("1M86EL
M8F]X*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAI
M;6%P7VQA<W1?97)R;W(H*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V=R86YT061M:6Y097)M<R@D;6%I
M;&)O>"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'<F%N="!T:&4@861M:6X@
M=7-E<B!A;&P@<FEG:'1S(&]N('1H92!M86EL8F]X+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&UA:6QB;W@@("`@("`@=&AE(&YA;64@;V8@=&AE(&UA:6QB;W@@;VX@=VAI
M8V@@=V4@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!G<F%N="!T:&4@<&5R;6ES<VEO;@H@("`@("H@0')E='5R;B!M:7AE9"!4
M<G5E(&EF('-U8V-E<W-F=6PL(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9W)A;G1!9&UI;E!E<FUS*"1M86EL8F]X
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O04-,+G!H<"<["@H@("`@("`@("1P87)A;7,@/2!A<G)A>2@G=7-E
M<FYA;64G(#T^("1T:&ES+3Y?<&%R86US6R=A9&UI;E]U<V5R)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'1H:7,M/E]P87)A
M;7-;)V%D;6EN7W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("=H;W-T<W!E8R<@/3X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("=P;W)T)R`]/B`D=&AI<RT^7W!A<F%M
M<ULG<&]R="==+`H@("`@("`@("`@("`@("`@("`@("`@("`G<')O=&]C;VPG
M(#T^("1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*3L*("`@("`@("`D86-L
M(#T@)DE-05!?04-,.CIF86-T;W)Y*"=R9F,R,#@V)RP@)'!A<F%M<RD["B`@
M("`@("`@)')E<W5L="`]("1A8VPM/F-R96%T94%#3"@D=&AI<RT^7W!A<F%M
M<ULG=7-E<FAI97)A<F-H>2==("X@)&UA:6QB;W@L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG861M:6Y?=7-E
M<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)VPG(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<B<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W<G(#T^('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:2<@/3X@=')U92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P)R`]
M/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V,G(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A)R`]/B!T<G5E*2D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@;6%I;&)O>"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("!4:&4@;6%I;&)O
M>"!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E36%I;&)O>"@D;6%I;&)O
M>"D*("`@('L*("`@("`@("!I9B`H:7-?82@D:6UA<"`]("1T:&ES+3Y?8V]N
M;F5C="@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M:6UA<#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9W)A;G1!9&UI;E!E
M<FUS*"1M86EL8F]X*3L*("`@("`@("!I9B`H(4!I;6%P7V1E;&5T96UA:6QB
M;W@H)&EM87`L("1T:&ES+3Y?<F5F("X@)'1H:7,M/E]P87)A;7-;)W5S97)H
M:65R87)C:'DG72`N("1M86EL8F]X*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAI;6%P7VQA<W1?97)R;W(H*2P@)VAO<F1E+G=A
M<FYI;F<G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!M86EL8F]X97,N"B`@("`@*@H@
M("`@("H@3F]T92!T:&%T('1H:7,@9&]E<R!N;W0@=V]R:R!O;B!A('9I<G1U
M86PM9&]M86EN(&5N86)L960@0WER=7,@*&ET('=I;&P*("`@("`J(&]N;'D@
M<F5T=7)N(&UA:6QB;WAE<R!I;B!T:&4@9&5F875L="!D;VUA:6XI+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!M86EL8F]X
M97,L(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&ES=$UA:6QB;WAE<R@I"B`@("!["B`@("`@("`@
M:68@*&ES7V$H)&EM87`@/2`D=&AI<RT^7V-O;FYE8W0H*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EM87`["B`@("`@("`@?0H*
M("`@("`@("`D;&ES="`]($!I;6%P7VQI<W0H)&EM87`L("1T:&ES+3Y?<F5F
M+"`D=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H>2==("X@)R4G*3L*("`@
M("`@("!I9B`H(21L:7-T*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O+BHG
M("X@<')E9U]Q=6]T92@D=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H>2==
M+"`G+R<I("X@)R@N*BDO)RP@)UQ<,2<L("1L:7-T*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K('=H971H97(@82!M86EL8F]X(&5X:7-T<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("`@5&AE(&UA:6QB
M;W@@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&EF(&UA
M:6QB;W@@97AI<W1S+"!F86QS92!I9B!N;W0L(&]R(&$@4$5!4E]%<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@;6%I;&)O>$5X:7-T<R@D;6%I;&)O>"D*
M("`@('L*("`@("`@("!I9B`H:7-?82@D:6UA<"`]("1T:&ES+3Y?8V]N;F5C
M="@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6UA
M<#L*("`@("`@("!]"@H@("`@("`@("1L:7-T(#T@0&EM87!?;&ES="@D:6UA
M<"P@)'1H:7,M/E]R968L("1T:&ES+3Y?<&%R86US6R=U<V5R:&EE<F%R8VAY
M)UT@+B`D;6%I;&)O>"D["B`@("`@("`@:68@*"1L:7-T(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!C;W5N="@D;&ES="D@/B`P.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92])34%0+T%#3"YP:'``````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3(W,34`,3`U,34T,S$P-C``,#(P,#4W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!#;VYT
M86EN<R!F=6YC=&EO;G,@<F5L871E9"!T;R!M86YA9VEN9PH@*B!!8V-E<W,@
M0V]N=')O;"!,:7-T<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"YP:'`L=B`Q+C(N,3(N,3`@,C`P-B\P,B\P,R`P,SHP-SHU-R!S
M96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:')I<R!(
M87-T:64@/&EM<$!O86LM=V]O9"YC;RYU:SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-H<FES($AA<W1I92`\:6UP0&]A:RUW;V]D+F-O+G5K/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@
M*B\*8VQA<W,@24U!4%]!0TP@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@:68@=&AE(&1R
M:79E<B!I<R!S=7!P;W)T960@8GD@=&AE('-E<G9E<@H@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S=7!P;W)T960@/2!F
M86QS93L*"B`@("`O*BH*("`@("`J($%N>2!014%27T5R<F]R('1H870@;V-C
M=7)E9"!B=70@8V]U;&1N)W0@8F4@<F5T=7)N960@9&ER96-T;'DN"B`@("`@
M*@H@("`@("H@0'9A<B!014%27T5R<F]R"B`@("`@*B\*("`@('9A<B`D7V5R
M<F]R(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!T
M:&4@;&ES="!O9B!P;W-S:6)L92!R:6=H=',@86YD(&$@:'5M86X*("`@("`J
M(')E861A8FQE(&1E<V-R:7!T:6]N(&]F(&5A8V@*("`@("`J"B`@("`@*B!!
M<G)A>2`H"B`@("`@*B`@("`@<FEG:'0M:60@/3X@<FEG:'0M9&5S8W)I<'1I
M;VX*("`@("`J("D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W)I9VAT<TQI<W0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@07)R87D@8V]N=&%I;FEN9R!U<V5R(&YA;65S('1H870@8V%N;F]T(&AA
M=F4@=&AE:7(@86-C97-S"B`@("`@*B!R:6=H=',@8VAA;F=E9"X*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<')O=&5C
M=&5D.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!C;VYN
M96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-05!?
M04-,*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E=')I979E('1H92!E>&ES=&EN9R!!0TP@9F]R(&$@9F]L9&5R
M(&9R;VT*("`@("`J('1H92!C=7)R96YT($E-05`@<V5R=F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@9F]L9&5R("!4:&4@9F]L9&5R('1O(&=E
M="!T:&4@04-,(&9O<@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@
M:&%S:"!C;VYT86EN:6YG(&EN9F]R;6%T:6]N(&]N('1H92!!0TP*("`@("`J
M("`@("`@("`@("`@("`@($%R<F%Y("@*("`@("`J("`@("`@("`@("`@("`@
M("`@("!U<V5R(#T^($%R<F%Y("@*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R:6=H="`]/B`Q"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I"B`@("`@*B`@("`@("`@("`@("`@("`I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$%#3"@D9F]L9&5R*0H@("`@>PH@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE
M($%#3"!O;B!A;B!)34%0('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!O;B!W:&EC:"!T;R!E9&ET('1H
M92!!0TP*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%R95]U<V5R
M("!4:&4@=7-E<B!T;R!G<F%N="!R:6=H=',@=&\*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&%C;"`@06X@87)R87DL('1H92!K97ES(&]F('=H:6-H
M(&%R92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("!R:6=H=',@=&\@
M8F4@9W)A;G1E9"`H<V5E(%)&0R`R,#@V*0H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92!U
M;FQE<W,*("`@("`J("`@("`@("`@("`@("`@('-E<G9E<B!D;V5S;B=T('-U
M<'!O<G0@04-,<RP@<F5T=7)N<R`G;F]?<W5P<&]R="<*("`@("`J+PH@("`@
M9G5N8W1I;VX@8W)E871E04-,*"1F;VQD97(L("1S:&%R95]U<V5R+"`D86-L
M*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*
M("`@("`J($5D:71S(&%N($%#3"!O;B!A;B!)34%0('-E<G9E<@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!O;B!W
M:&EC:"!T;R!E9&ET('1H92!!0TP*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S:&%R95]U<V5R("!4:&4@=7-E<B!T;R!G<F%N="!R:6=H=',@=&\*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%C;"`@06X@87)R87DL('1H
M92!K97ES(&]F('=H:6-H(&%R92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("!R:6=H=',@=&\@8F4@9W)A;G1E9"`H<V5E(%)&0R`R,#@V*0H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;VX@9F%I;'5R92!U;FQE<W,*("`@("`J("`@("`@("`@("`@("`@('-E
M<G9E<B!D;V5S;B=T('-U<'!O<G0@04-,<RP@<F5T=7)N<R`G;F]?<W5P<&]R
M="<*("`@("`J+PH@("`@9G5N8W1I;VX@961I=$%#3"@D9F]L9&5R+"`D<VAA
M<F5?=7-E<BP@)&%C;"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#86X@82!U<V5R(&5D:70@=&AE($%#3"!F
M;W(@=&AI<R!F;VQD97(_(%)E='5R;G,@=')U92!I9B`D=7-E<@H@("`@("H@
M<&5R;6ES<VEO;B!T;R!E9&ET('1H92!!0TP@;VX@)&9O;&1E<@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!N86UE
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@02!U<V5R(&YA
M;64*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@)'5S
M97(@:&%S("=A)R!R:6=H=`H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y%9&ET
M*"1F;VQD97(L("1U<V5R*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=%)I9VAT<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<FEG:'1S3&ES=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!G9710<F]T96-T960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!R;W1E8W1E9#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U-U<'!O<G1E9"@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W5P<&]R=&5D.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$5R<F]R*"D*("`@('L*("`@("`@("`D97)R
M;W(@/2`D=&AI<RT^7V5R<F]R.PH@("`@("`@("1T:&ES+3Y?97)R;W(@/2!N
M=6QL.PH@("`@("`@(')E='5R;B`D97)R;W(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@86X@04-,(&EN<W1A;F-E(&)A<V5D
M(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!!0TP@<W5B8VQA<W,@=&\@<F5T
M=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@04-,(&EN<W1A
M;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@;VX@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M
M92@D9')I=F5R*3L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+T%#3"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D
M8VQA<W,@/2`G24U!4%]!0TQ?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1A8VP@/2`F;F5W
M("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D86-L(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%C
M;#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(')E9F5R96YC92!T;R!A(&-O;F-R971E($%#3"!I;G-T86YC90H@("`@("H@
M8F%S960@;VX@)&1R:79E<BX@($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@
M:6YS=&%N8V4@:68@;F\*("`@("`J($%#3"!I;G-T86YC92!W:71H('1H92!S
M86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F24U!
M4%]!0TPZ.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!!0TP@<W5B8VQA<W,@
M=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA
M<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE(&-R96%T960@8V]N8W)E=&4@04-,(&EN<W1A
M;F-E+"!O<B!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*"%I<W-E
M="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI
M>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S
M970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN
M<W1A;F-E<ULD<VEG;F%T=7)E72`]("9)34%07T%#3#HZ9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])34%0+U-E87)C:"YP:'``````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#$S,#$`,3`U,34T,S$P
M-C``,#(P-C4V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@24U!4%]396%R8V@Z.B!C;&%S<R!P
M97)F;W)M<R!C;VUP;&5X('-E87)C:&EN9R!O9B!A;B!)34%0(&UA:6QB;W@N
M"B`J"B`J($-L87-S97,@=&\@:&5L<"!W:71H(&-O;7!L97@@<V5A<F-H:6YG
M(&]F(&%N($E-05`@;6%I;&)O>"X@(%1H92!B=6EL="UI;@H@*B!02%`@<V5A
M<F-H*"D@9G5N8W1I;VX@;VYL>2!A;&QO=W,@24U!4'8R('-E87)C:"!Q=65R
M:65S("AS964@4D9#(#$Q-S8I+@H@*B!4:&ES(&QI8G)A<GD@86QL;W=S(&UO
M<F4@8V]M<&QE>"!S96%R8VAE<R!T;R!B92!C<F5A=&5D("AE+F<N($]2('-E
M87)C:&5S+`H@*B!S96%R8VAI;F<@<W!E8VEF:6,@:&5A9&5R<RDN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!4"]396%R8V@N<&AP+'8@,2XR
M.2XQ,"XR-2`R,#`V+S`V+S`V(#$U.C0T.C(W('-L=7-A<GH@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI
M+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?24U!4`H@*B\*8VQA<W,@24U!4%]396%R8V@@>PH*("`@("\J*@H@("`@
M("H@5&AE(&AE861E<G,@8V%C:&4N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]H96%D97)S(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J(%1H92!R97-U;'1S(&-A8VAE+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<F5S=6QT(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%1H92!P87)A;6%T97(@;&ES="X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8VAA<G-E="!O9B!T:&4@<V5A
M<F-H('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]C:&%R<V5T.PH*("`@("\J*@H@("`@("H@26YT97)N86P@
M9FQA9R!U<V5D(&)Y('-E87)C:$UA:6QB;W@H*2X*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<V5A<F-H9FQA9R`](#`[
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O('1H92!G
M;&]B86P@24U!4%]396%R8V@@;V)J96-T+"!O;FQY(&-R96%T:6YG(&ET"B`@
M("`@*B!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.CQC;V1E/@H@("`@
M("H@("`D:6UA<%]S96%R8V@@/2`F24U!4%]396%R8V@Z.G-I;F=L971O;B@I
M.SPO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M06YY('!A<F%M971E<G,@=&AE(&-O;G-T<G5C=&]R(&UA>2!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@24U!4%]396%R8V@@(%1H92!)34%07U-E87)C
M:"!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&]B:F5C
M=#L*"B`@("`@("`@:68@*"%I<W-E="@D;V)J96-T*2D@>PH@("`@("`@("`@
M("`D;V)J96-T(#T@;F5W($E-05!?4V5A<F-H*"1P87)A;7,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1O8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@=&AE(&9O;&QO=VEN9R!E;G1R
M:65S.CQP<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W!O<#,G
M(#T^(&)O;VQE86X@*'5S:6YG(%!/4#,@8V]N;F5C=&EO;C\I"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^('-T<FEN9R`H8VAA
M<G-E="!O9B!S96%R8V@@=F%L=65S*0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("=N;U]I;6%P7W-E87)C:"<@/3X@=')U92!I9B!T:&4@24U!4"!S
M97)V97(@9&]E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;F]T('-U<'!O<G0@=&AE(&-H87)S970@:6X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!S96%R8V@@8V]M;6%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07U-E87)C:"@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M
M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396%R8VAE<R!M
M97-S86=E<R!B>2!!3$P@:&5A9&5R<R`H<F%T:&5R('1H86X@=&AE(&QI;6ET
M960@<V5T('!R;W9I9&5D"B`@("`@*B!B>2!I;6%P7W-E87)C:"@I*2X*("`@
M("`J"B`@("`@*B!`<&%R86T@24U!4%]396%R8VA?475E<GD@)'%U97)Y("!4
M:&4@<V5A<F-H('%U97)Y+@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1I;6%P
M("`@("`@("`@("`@06X@24U!4"!R97-O=7)C92!S=')E86TN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1M8F]X("`@("`@("`@("`@("!4:&4@;F%M92!O9B!T
M:&4@;6%I;&)O>"!T;R!S96%R8V@N($9O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@4$]0,RP@=&AI<R!S:&]U;&0@8F4@96UP
M='DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@
M:6YD:6-E<R!T:&%T(&UA=&-H('1H92!S96%R8V@@<G5L97,@:6X@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("!C=7)R96YT(&UA:6QB;W@N"B`@("`@*B`@
M("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E87)C:$UA:6QB;W@H)'%U97)Y+"`D:6UA
M<"P@)&UB;W@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R($E-05`@97AT
M96YS:6]N+B`J+PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S
M*"=I;6%P)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A
M:7-E17)R;W(H(E1H:7,@9G5N8W1I;VX@<F5Q=6ER97,@)VEM87`G('1O(&)E
M(&)U:6QT(&EN=&\@4$A0+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E
M*3L*("`@("`@("!]"@H@("`@("`@("\J($]P96X@=&\@=&AE(&-O<G)E8W0@
M;6%I;&)O>"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R86US6R=P;W`S
M)UTI('L*("`@("`@("`@("`@:68@*"%`:6UA<%]R96]P96XH)&EM87`L("1M
M8F]X+"!/4%]214%$3TY,62DI('L*("`@("`@("`@("`@("`@(')E='5R;B!A
M<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#
M;&5A<B!T:&4@<V5A<F-H(&9L86<N("HO"B`@("`@("`@)'1H:7,M/E]S96%R
M8VAF;&%G(#T@,#L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5A<F-H36%I
M;&)O>"@D<75E<GDL("1I;6%P+"`D;6)O>"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!396%R8VAE<R!T:&4@;6%I;&)O>"!A;F0@<V]R=',@=&AE(')E<W5L
M=',N"B`@("`@*@H@("`@("H@0'!A<F%M($E-05!?4V5A<F-H7U%U97)Y("1Q
M=65R>2`@5&AE('-E87)C:"!Q=65R>2X*("`@("`J($!P87)A;2!R97-O=7)C
M92`D:6UA<"`@("`@("`@("`@($%N($E-05`@<F5S;W5R8V4@<W1R96%M+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;6)O>"`@("`@("`@("`@("`@5&AE(&YA
M;64@;V8@=&AE(&UA:6QB;W@@=&\@<V5A<F-H+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'-O<G1B>2`@("`@("`@("`@5&AE(&-R:71E<FEA('1O('-O<G0@
M8GD@*'-E90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:6UA<%]S;W)T*"DI+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-O<G1D
M:7(@("`@("`@("`@,2!F;W(@<F5V97)S92!S;W)T:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F(&EN9&EC97,@=&AA="!M
M871C:"!T:&4@<V5A<F-H(')U;&5S(&EN('1H90H@("`@("H@("`@("`@("`@
M("`@("`@8W5R<F5N="!M86EL8F]X(&%N9"!S;W)T960N"B`@("`@*B`@("`@
M("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E87)C:%-O<G1-86EL8F]X*"1Q=65R>2P@)&EM
M87`L("1M8F]X+"`D<V]R=&)Y+"`D<V]R=&1I<B`](#`I"B`@("!["B`@("`@
M("`@)&EN9&EC97,@/2`D=&AI<RT^<V5A<F-H36%I;&)O>"@D<75E<GDL("1I
M;6%P+"`D;6)O>"D["B`@("`@("`@:68@*&ES7V$H)&EN9&EC97,L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;F1I8V5S.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1I;F1I8V5S7W-O<G0@/2!`:6UA
M<%]S;W)T*"1I;6%P+"`D<V]R=&)Y+"`D<V]R=&1I<BP@4T5?54E$*3L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y7W9A;'5E<RAA<G)A>5]I;G1E<G-E8W0H
M)&EN9&EC97-?<V]R="P@)&EN9&EC97,I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!);G1E<FYA;"!W<F%P<&5R(&UE=&AO9"!T;R!I;6%P
M7W-E87)C:"!T:&%T(&%L;&]W<R!C:&%R<V5T(&%W87)E"B`@("`@*B!S96%R
M8VAE<R!I9B!A=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;6%P4V5A<F-H*"1I;6%P+"`D
M8W)I=&5R:6$I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A
M<F%M<ULG8VAA<G-E="==*2D@>PH@("`@("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]P87)A;7-;)VYO7VEM87!?8VAA<G-E="==*2`F)@H@("`@("`@("`@
M("`@("`@=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,RXS)RP@
M)SX])RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!`:6UA<%]S96%R8V@H
M)&EM87`L("1C<FET97)I82P@4T5?54E$+"`D=&AI<RT^7W!A<F%M<ULG8VAA
M<G-E="==*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1C<FET97)I82`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&-R:71E<FEA
M+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==+"`G55,M05-#24DG*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N($!I;6%P7W-E
M87)C:"@D:6UA<"P@)&-R:71E<FEA+"!315]5240I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@26YT97)N86P@9G5N8W1I;VX@=&\@<V5A<F-H('1H92!M86EL
M8F]X+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5A<F-H36%I;&)O>"@D<75E<GDL("1I;6%P+"`D;6)O
M>"D*("`@('L*("`@("`@("`D:6YD:6-E<R`](&%R<F%Y*"D["@H@("`@("`@
M("1T:&ES+3Y?<V5A<F-H9FQA9R`](#`["@H@("`@("`@("\J($1O('1H92!S
M:6UP;&4@<V5A<F-H97,@=&AA="!I;6%P7W-E87)C:"@I(&-A;B!H86YD;&4N
M("HO"B`@("`@("`@:68@*"@D;V(@/2`D<75E<GDM/F)U:6QD*"DI*2!["B`@
M("`@("`@("`@(&EF("@D;V(M/FYO="D@>PH@("`@("`@("`@("`@("`@:68@
M*"$H)&EN9&EC97,Q(#T@)'1H:7,M/E]I;6%P4V5A<F-H*"1I;6%P+"`D;V(M
M/F9L86=S*2DI('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<S$@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"$H)&EN9&EC97,R(#T@)'1H:7,M/E]I;6%P4V5A<F-H*"1I;6%P+"`D;V(M
M/G%U97)Y*2DI('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<S(@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&EN
M9&EC97,@/2!A<G)A>5]D:69F*"1I;F1I8V5S,2P@)&EN9&EC97,R*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@A*"1I;F1I
M8V5S(#T@)'1H:7,M/E]I;6%P4V5A<F-H*"1I;6%P+"`D;V(M/F9U;&QQ=65R
M>2DI*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!3970@=&AE('-E87)C:"!F;&%G+B`J+PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]S96%R8VAF;&%G(#T](#`I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V5A<F-H9FQA9R`](#$["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\J(%!R;V-E<W,@97AT96YD960@<V5A<F-H97,N("HO"B`@
M("`@("`@:68@*"@D97AT96YD960@/2`D<75E<GDM/F5X=&5N9&5D4V5A<F-H
M*"DI*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W-E87)C:%!(
M4"@D97AT96YD960L("1Q=65R>2T^9FQA9W,H*2P@)&EM87`L("1M8F]X*3L*
M("`@("`@("`@("`@+RH@4V5T('1H92!S96%R8V@@9FQA9RX@*B\*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?<V5A<F-H9FQA9R`]/2`P*2!["B`@("`@("`@
M("`@("`@("`D:6YD:6-E<R`]("1R97-U;'0["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E87)C:&9L86<@/2`Q.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&EN9&EC97,@/2!A<G)A>5]V86QU97,H87)R87E?
M:6YT97)S96-T*"1I;F1I8V5S+"`D<F5S=6QT*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\J(%!R;V-E<W,@<VEZ92!S96%R8VAE<RX@
M*B\*("`@("`@("!I9B`H*"1S:7IE3V(@/2`D<75E<GDM/G-I>F5396%R8V@H
M*2DI('L*("`@("`@("`@("`@)&]V97)V:65W(#T@0&EM87!?9F5T8VA?;W9E
M<G9I97<H)&EM87`L(&EM<&QO9&4H)RPG+"`D:6YD:6-E<RDL($947U5)1"D[
M"B`@("`@("`@("`@("1F=6YC(#T@8W)E871E7V9U;F-T:6]N*"<D82<L("=R
M971U<FX@*"1A("<@+B`D<VEZ94]B+3YS:7IE;W`@+B`G("<@+B`D<VEZ94]B
M+3YS:7IE("X@)RD[)RD["B`@("`@("`@("`@("1R97-U;'0@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!F;W)E86-H("@D;W9E<G9I97<@87,@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@:68@*"1F=6YC*"1V86PM/G-I>F4I*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@)'9A;"T^=6ED.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7W-E87)C:&9L86<@/3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S96%R8VAF;&%G(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M:6YD:6-E<R`](&%R<F%Y7W9A;'5E<RAA<G)A>5]I;G1E<G-E8W0H)&EN9&EC
M97,L("1R97-U;'0I*3L*("`@("`@("!]"@H@("`@("`@("\J(%!R;V-E<W,@
M04Y$('-E87)C:&5S(&YO=RX@*B\*("`@("`@("`D:6YD:6-E<R`]("1T:&ES
M+3Y?9&]!;F1/<E-E87)C:"@D<75E<GDM/F%N9%-E87)C:"@I+"`D:6UA<"P@
M)&UB;W@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V%N9"<L("1I;F1I8V5S*3L*"B`@("`@("`@+RH@4')O8V5S<R!/4B!S
M96%R8VAE<R!N;W<N("HO"B`@("`@("`@)&EN9&EC97,@/2`D=&AI<RT^7V1O
M06YD3W)396%R8V@H)'%U97)Y+3YO<E-E87)C:"@I+"`D:6UA<"P@)&UB;W@L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]R
M)RP@)&EN9&EC97,I.PH*("`@("`@("!R971U<FX@)&EN9&EC97,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!);G1E<FYA;"!F=6YC=&EO;B!T;R!S96%R8V@@
M=&AE(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]D;T%N9$]R4V5A<F-H*"1Q=65R>2P@)&EM
M87`L("1M8F]X+"`D;6]D92P@)&EN9&EC97,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8F%S92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D:6YD:6-E<SL*
M("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1Q=65R>2!A<R`D=F%L*2![
M"B`@("`@("`@("`@(&EF("AI<U]A*"1V86PL("=)34%07U-E87)C:%]1=65R
M>2<I*2!["B`@("`@("`@("`@("`@("`D<')E=G-E87)C:"`]("AE;7!T>2@D
M:6YD:6-E<RD@)B8@*"1T:&ES+3Y?<V5A<F-H9FQA9R`]/2`P*2D["B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]S96%R8VA-86EL8F]X*"1V
M86PL("1I;6%P+"`D;6)O>"D["B`@("`@("`@("`@("`@("!I9B`H)&UO9&4@
M/3T@)V%N9"<I('L*("`@("`@("`@("`@("`@("`@("`O*B!)9B!T:&4@<F5S
M=6QT(&ES(&5M<'1Y(&EN(&%N($%.1"!S96%R8V@L('=E(&MN;W<@=&AA=`H@
M("`@("`@("`@("`@("`@("`@("`@('1H92!E;G1I<F4@04Y$('-E87)C:"!W
M:6QL(&)E(&5M<'1Y('-O(')E='5R;@H@("`@("`@("`@("`@("`@("`@("`@
M(&EM;65D:6%T96QY+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T
M>2@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@("\J($EF('=E(&AA=F4@<F5A8VAE9"!T:&ES('!O:6YT+"!A;F0@
M:&%V92!N;W0@<&5R9F]R;65D(&$*("`@("`@("`@("`@("`@("`@("`@("!S
M96%R8V@@>65T+"!W92!M=7-T('5S92!T:&4@<F5S=6QT<R!A<R!T:&4@:6YD
M:6-E<PH@("`@("`@("`@("`@("`@("`@("`@(&QI<W0N(%=I=&AO=70@=&AI
M<R!C:&5C:RP@=&AE(&EN9&EC97,@;&ES="!W:6QL(&%L=V%Y<PH@("`@("`@
M("`@("`@("`@("`@("`@(&)E(&5M<'1Y(&EF(&%N($%.1"!S96%R8V@@:7,@
M=&AE(&9I<G-T('-E87)C:"X@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'!R979S96%R8V@I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9&EC
M97,@/2`D<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E87)C:&9L86<@/2`Q.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@87)R87E?=F%L
M=65S*&%R<F%Y7VEN=&5R<V5C="@D:6YD:6-E<RP@)')E<W5L="DI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@A
M96UP='DH)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E
M<R`](&%R<F%Y7W5N:7%U92AA<G)A>5]M97)G92@D:6YD:6-E<RP@)')E<W5L
M="DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&EN9&EC97,@/2`D=&AI<RT^7V1O06YD3W)396%R
M8V@H)'9A;"P@)&EM87`L("1M8F]X+"`D;6]D92P@)&EN9&EC97,I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN9&EC97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<V5S(%!(4"!B87-E9"!F=6YC=&EO
M;G,@=&\@<&5R9F]R;2!T:&4@<V5A<F-H+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=&1#;&%S<R`D:6UA
M<%]Q=65R>2`@4V5A<F-H('%U97)Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FQA9W,@("`@("`@("!!;GD@861D:71I;VYA;"!F;&%G<RX*("`@("`J($!P
M87)A;2!R97-O=7)C92`D:6UA<"`@("`@("`@06X@24U!4"!R97-O=7)C92!S
M=')E86TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M8F]X("`@("`@("`@(%1H
M92!N86UE(&]F('1H92!S96%R8V@@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!I;F1I8V5S('1H870@;6%T8V@N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96%R8VA02%`H)&EM87!?<75E<GDL
M("1F;&%G<RP@)&EM87`L("1M8F]X*0H@("`@>PH@("`@("`@("1I;F1I8V5S
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*&5M<'1Y*"1F;&%G<RDI('L*("`@
M("`@("`@("`@)&9L86=S(#T@)T%,3"<["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P;W`S)UTI*2!["B`@("`@("`@
M("`@("1M8F]X(#T@)U!/4#,G.PH@("`@("`@('T*"B`@("`@("`@)&-A8VAE
M7VME>2`]("1M8F]X("X@)WPG("X@)&9L86=S.PH*("`@("`@("`O*B!792!H
M879E('1O('5S92!P87)S94U)345(96%D97)S*"D@=&\@9V5T(&5A8V@@:&5A
M9&5R(&%N9"!S964@:68@86YY"B`@("`@("`@("H@9FEE;&0@;6%T8VAE<RX@
M57-E(&EM87!?<V5A<F-H*"D@=&\@9V5T('1H92!L:7-T(&]F(&UE<W-A9V4@
M:6YD:6-E<PH@("`@("`@("`J(&]R(')E='5R;B!E;7!T>2!L:7-T(&EF(&YO
M('-E87)C:"!R97-U;'1S+B`J+PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]R97-U;'1;)&-A8VAE7VME>5TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<F5S=6QT6R1C86-H95]K97E=(#T@0&EM87!?<V5A<F-H*"1I;6%P+"`D9FQA
M9W,L(%-%7U5)1"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!E;7!T>2!M
M97-S86=E(&QI<W0L(')E='5R;B!N;W<N("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?<F5S=6QT6R1C86-H95]K97E=*2D@>PH@("`@("`@("`@("!R
M971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&EN8VQU9&5?;VYC
M92`G2&]R9&4O34E-12]3=')U8W1U<F4N<&AP)SL*"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7VAE861E<G-;)&UB;WA=*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7VAE861E<G-;)&UB;WA=(#T@87)R87DH*3L*("`@("`@("!]"@H@
M("`@("`@("\J($=E="!T:&4@:&5A9&5R+W%U97)Y('1O('-E87)C:"!F;W(N
M("HO"B`@("`@("`@)'%U97)Y(#T@<F5S970H)&EM87!?<75E<GDM/G%U97)Y
M*3L*("`@("`@("`D:V5Y(#T@<W1R=&]L;W=E<BAK97DH)&EM87!?<75E<GDM
M/G%U97)Y*2D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F5S=6QT6R1C
M86-H95]K97E=(&%S("1I;F1E>"D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?:&5A9&5R<ULD;6)O>%U;)&EN9&5X72DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD;6)O>%U;)&EN9&5X72`]($U)345?
M4W1R=6-T=7)E.CIP87)S94U)345(96%D97)S*$!I;6%P7V9E=&-H:&5A9&5R
M*"1I;6%P+"`D:6YD97@L($947U5)1"DL(&YU;&PL('1R=64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1H(#T@)B1T:&ES+3Y?:&5A9&5R<ULD;6)O
M>%U;)&EN9&5X73L*"B`@("`@("`@("`@("\J(%=E(&YE960@=&\@9&\@82!C
M87-E(&EN<V5N<VET:79E('-E87)C:"!O;B!T97AT(&)E8V%U<V4L(&9O<@H@
M("`@("`@("`@("`@*B!E>&%M<&QE+"!E+6UA:6P@861D<F5S<V5S(&UA>2!N
M;W0@8F4@8V%U9VAT(&-O<G)E8W1L>0H@("`@("`@("`@("`@*B`H9FEL=&5R
M:6YG(&9O<B!E>&%M<&QE0&5X86UP;&4N8V]M('=I;&P@;F]T(&-A=&-H"B`@
M("`@("`@("`@("`J(&5X06UP;&5`97AA;7!L92YC;VTI+B`J+PH@("`@("`@
M("`@("`D;6%T8VA?<W5C8V5S<R`](&9A;'-E.PH@("`@("`@("`@("!I9B`H
M:7-S970H)&A;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D:&1R7V%R<F%Y
M(#T@*&ES7V%R<F%Y*"1H6R1K97E=*2D@/R`D:%LD:V5Y72`Z(&%R<F%Y*"1H
M6R1K97E=*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1H9')?87)R87D@
M87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1V
M86PL('-T<G9A;"@D<75E<GDI*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&UA=&-H7W-U8V-E<W,@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"@D:6UA<%]Q=65R>2T^;F]T("8F("$D;6%T8VA?<W5C8V5S<RD@?'P*("`@
M("`@("`@("`@("`@("@A)&EM87!?<75E<GDM/FYO="`F)B`D;6%T8VA?<W5C
M8V5S<RDI('L*("`@("`@("`@("`@("`@("1I;F1I8V5S6UT@/2`D:6YD97@[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YD
M:6-E<SL*("`@('T*"GT*"B\J*@H@*B!4:&4@24U!4%]396%R8VA?3V)J96-T
M.CH@8VQA<W,@:7,@=7-E9"!T;R!F;W)M=6QA=&4@<75E<FEE<R!T;R!B92!U
M<V5D('=I=&@*("H@=&AE($E-05!?4V5A<F-H.CH@8VQA<W,N"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7TE-05`*("HO"F-L87-S($E-05!?4V5A<F-H7U%U97)Y('L*"B`@("!V
M87(@)%]A;F0@/2!A<G)A>2@I.PH@("`@=F%R("1?97AT96YD961396%R8V@@
M/2!A<G)A>2@I.PH@("`@=F%R("1?9FQA9W,@/2!A<G)A>2@I.PH@("`@=F%R
M("1?;F]T(#T@9F%L<V4["B`@("!V87(@)%]O<B`](&%R<F%Y*"D["B`@("!V
M87(@)%]Q=65R>2`](&YU;&P["B`@("!V87(@)%]S:7IE(#T@;G5L;#L*("`@
M('9A<B`D7W-I>F5O<"`](&YU;&P["@H@("`@9G5N8W1I;VX@24U!4%]396%R
M8VA?475E<GDH*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A;GD@97AT96YD960@<V5A<F-H97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5X=&5N9&5D4V5A<F-H*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?97AT96YD961396%R8V@I*2!["B`@("`@("`@("`@("1S96%R8V@@
M/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`D<V5A<F-H+3YN;W0@/2`D
M=&AI<RT^7VYO=#L*("`@("`@("`@("`@)'-E87)C:"T^<75E<GD@/2`D=&AI
M<RT^7V5X=&5N9&5D4V5A<F-H.PH@("`@("`@("`@("!R971U<FX@)'-E87)C
M:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P
M87)A;65T97)S(&9O<B!A('-I>F4@<V5A<F-H+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S:7IE4V5A<F-H*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D
M=&AI<RT^7W-I>F4I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*("`@("`@("`D;V(@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("1O
M8BT^<VEZ92`]("AF;&]A="DD=&AI<RT^7W-I>F4["B`@("`@("`@)&]B+3YS
M:7IE;W`@/2`D=&AI<RT^7W-I>F5O<#L*"B`@("`@("`@<F5T=7)N("1O8CL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86YY($%.1"!S96%R8VAE
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@86YD4V5A<F-H*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]A;F0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&%N>2!/4B!S96%R8VAE<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@;W)396%R8V@H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V]R
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9FQA9W,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9L86=S*"D*("`@('L*("`@("`@("!R971U
M<FX@*"AE;7!T>2@D=&AI<RT^7V9L86=S*2D@/R`G)R`Z(&EM<&QO9&4H)R`G
M+"`D=&AI<RT^7V9L86=S*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL
M9',@=&AE($E-05`@<V5A<F-H('%U97)Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!B=6EL9"@I"B`@("!["B`@("`@("`@)'-E87)C:"`]("9N97<@<W1D0VQA
M<W,["@H@("`@("`@("1S96%R8V@M/FYO="`]("1T:&ES+3Y?;F]T.PH@("`@
M("`@("1S96%R8V@M/F9L86=S(#T@)'1H:7,M/F9L86=S*"D["@H@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W%U97)Y*2D@>PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?;W(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-E87)C:"T^<75E<GD@
M/2`G04Q,)SL*("`@("`@("`@("`@)'-E87)C:"T^;F]T(#T@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1S96%R8V@M/FYO="`F
M)B!E;7!T>2@D<V5A<F-H+3YF;&%G<RDI('L*("`@("`@("`@("`@("`@("1S
M96%R8V@M/F9L86=S(#T@)T%,3"<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-E87)C:"T^<75E<GD@/2`D=&AI<RT^7W%U97)Y.PH@("`@("`@('T*
M("`@("`@("`D<V5A<F-H+3YF=6QL<75E<GD@/2`H(65M<'1Y*"1S96%R8V@M
M/F9L86=S*2`_("1S96%R8V@M/F9L86=S("X@)R`G(#H@)R<I("X@)'-E87)C
M:"T^<75E<GD["@H@("`@("`@(')E='5R;B`D<V5A<F-H.PH@("`@?0H*("`@
M("\J($E-05`@<V5A<F-H(&UO9&EF:65R<RX@*B\*("`@(&9U;F-T:6]N(%]M
M;V1I9FEE<G,H)&]B+"`D8VUD*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1O
M8BP@)TE-05!?4V5A<F-H7U%U97)Y)RDI('L*("`@("`@("`@("`@)&]B(#T@
M87)R87DH)&]B*3L*("`@("`@("!]"B`@("`@("`@87)R87E?<'5S:"@D=&AI
M<RT^)&-M9"P@)&]B*3L*("`@('T*"B`@("!F=6YC=&EO;B!I;6%P06YD*"1O
M8BD*("`@('L*("`@("`@("`D=&AI<RT^7VUO9&EF:65R<R@D;V(L("=?86YD
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@:6UA<$]R*"1O8BD*("`@('L*("`@
M("`@("`D=&AI<RT^7VUO9&EF:65R<R@D;V(L("=?;W(G*3L*("`@('T*"B`@
M("`O*B!)34%0(%-E87)C:"!&;&%G<RX@*B\*("`@("\J(%1H97)E(&ES(&YO
M(&YE960@=&\@<W5P<&]R="!T:&4@2T595T]21"]53DM%65=/4D0@<75E<GD@
M<VEN8V4@=&AE"B`@("`@("!I;F1I=FED=6%L(&ME>7=O<F1S(&AA=F4@:61E
M;G1I8V%L(&9U;F-T:6]N86QI='DN("HO"B`@("!F=6YC=&EO;B!?:6UA<$9L
M86=S*"1F;&%G+"`D8VUD*0H@("`@>PH@("`@("`@("1C;60@/2`H)&9L86<I
M(#\@)&-M9"`Z("=53B<@+B`D8VUD.PH@("`@("`@("1T:&ES+3Y?9FQA9W-;
M72`]("1C;60["B`@("!]"@H@("`@9G5N8W1I;VX@86YS=V5R960H)&9L86<I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I;6%P1FQA9W,H)&9L86<L("=!3E-7
M15)%1"<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;&5T960H)&9L86<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I;6%P1FQA9W,H)&9L86<L("=$14Q%5$5$
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@9FQA9V=E9"@D9FQA9RD*("`@('L*
M("`@("`@("`D=&AI<RT^7VEM87!&;&%G<R@D9FQA9RP@)T9,04='140G*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!S965N*"1F;&%G*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?:6UA<$9L86=S*"1F;&%G+"`G4T5%3B<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(')E8V5N="@D9FQA9RD*("`@('L*("`@("`@("`D=&AI<RT^
M7VEM87!&;&%G<RAT<G5E+"`H*"1F;&%G*2`_("=214-%3E0G(#H@)T],1"<I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!I;6%P3F5W*"D*("`@('L*("`@("`@
M("`D=&AI<RT^7VEM87!&;&%G<RAT<G5E+"`G3D57)RD["B`@("!]"@H@("`@
M+RH@24U!4"!(96%D97(@4V5A<F-H+B`J+PH@("`@9G5N8W1I;VX@:&5A9&5R
M*"1H96%D97(L("1Q=65R>2P@)&YO="`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1H96%D97(@/2!U8V9I<G-T*')T<FEM*"1H96%D97(L("<Z)RDI.PH@("`@
M("`@("1S=&1(9')S(#T@87)R87DH)U1O)RP@)T-C)RP@)T9R;VTG+"`G4W5B
M:F5C="<I.PH@("`@("`@(&EF("@D<75E<GD@(3T@)R<I('L*("`@("`@("`@
M("`@:68@*&EN7V%R<F%Y*"1H96%D97(L("1S=&1(9')S*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]Q=65R>2`](%-T<FEN9SHZ=7!P97(H)&AE861E
M<BD@+B`G("(G("X@861D<VQA<VAE<R@D<75E<GDI("X@)R(G.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'1E;F1E
M9%-E87)C:%LD:&5A9&5R72`]("1Q=65R>3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^7VYO="`]("1N;W0["B`@("`@("`@?0H@("`@?0H*
M("`@("\J($E-05`@1&%T92!396%R8V@N("HO"B`@("!F=6YC=&EO;B!?:6UA
M<$1A=&4H)&1A>2P@)&UO;G1H+"`D>65A<BP@)&-M9"D*("`@('L*("`@("`@
M("`D=&AI<RT^7W%U97)Y(#T@)&-M9"`N("<@)R`N(&1A=&4H(F0M32UY(BP@
M;6MT:6UE*#`L(#`L(#`L("1M;VYT:"P@)&1A>2P@)'EE87(I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!B969O<F4H)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@
M('L*("`@("`@("`D=&AI<RT^7VEM87!$871E*"1D87DL("1M;VYT:"P@)'EE
M87(L("="149/4D4G*3L*("`@('T*"B`@("!F=6YC=&EO;B!S:6YC92@D9&%Y
M+"`D;6]N=&@L("1Y96%R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6UA<$1A
M=&4H)&1A>2P@)&UO;G1H+"`D>65A<BP@)U-)3D-%)RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@;VXH)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@('L*("`@("`@
M("`D=&AI<RT^7VEM87!$871E*"1D87DL("1M;VYT:"P@)'EE87(L("=/3B<I
M.PH@("`@?0H*("`@("\J($E-05`@5&5X="!S96%R8VAE<RX@*B\*("`@(&9U
M;F-T:6]N(&)O9'DH)'%U97)Y+"`D;F]T(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]Q=65R>2`]("="3T19("(G("X@)'%U97)Y("X@)R(G.PH@
M("`@("`@("1T:&ES+3Y?;F]T(#T@)&YO=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!T97AT*"1Q=65R>2P@)&YO="`](&9A;'-E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<75E<GD@/2`G5$585"`B)R`N("1Q=65R>2`N("<B)SL*("`@("`@
M("`D=&AI<RT^7VYO="`]("1N;W0["B`@("!]"@H@("`@+RH@24U!4"!3:7IE
M('-E87)C:&5S+B`J+PH@("`@9G5N8W1I;VX@<VEZ92@D<VEZ92P@)&]P97)A
M=&]R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VEZ92`]("1S:7IE.PH@("`@
M("`@("1T:&ES+3Y?<VEZ96]P(#T@)&]P97)A=&]R.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]4<F5E
M+G!H<```````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,38U-#$S
M`#$P-3$U-#,Q,#8P`#`R,#,V,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!#;VYS=&%N=',@9F]R(&UA:6QB
M;WA%;'0@871T<FEB=71E<RX*("H@06QL('9E<G-I;VYS(&]F(&,M8VQI96YT
M("AC+6-L:65N="]M86EL+F@I(&1E9FEN92!T:&5S92!C;VYS=&%N=',Z"B`J
M("`@3$%45%].3TE.1D5224]24R`H;&]N9RD@,'@Q(#T@,0H@*B`@($Q!5%1?
M3D]314Q%0U0@*&QO;F<I(#!X,B`](#(*("H@("!,05147TU!4DM%1"`H;&]N
M9RD@,'@T(#T@-`H@*B`@($Q!5%1?54Y-05)+140@*&QO;F<I(#!X."`](#@*
M("H*("H@3F5W97(@=F5R<VEO;G,@;V8@8RUC;&EE;G0@*&EM87`M,C`P,B!A
M;F0@9W)E871E<BD@9&5F:6YE('1H97-E(&-O;G-T86YT<SH*("H@("!,0514
M7U)%1D524D%,("AL;VYG*2`P>#$P(#T@,38*("H@("!,05147TA!4T-(24Q$
M4D5.("AL;VYG*2`P>#(P(#T@,S(*("H@("!,05147TA!4TY/0TA)3$1214X@
M*&QO;F<I(#!X-#`@/2`V-`H@*B`N+BYB=70@=&AE<V4@8V]N<W1A;G0@;F%M
M97,@9&\@;F]T(&%P<&5A<B!I;B!02%`@=6YT:6P@4$A0(#0N,RXU(&%N9"`U
M+C`N"B`J+PII9B`H(61E9FEN960H)TQ!5%1?2$%30TA)3$1214XG*2D@>PH@
M("`@0&1E9FEN92@G3$%45%]2149%4E)!3"<L(#$V*3L*("`@($!D969I;F4H
M)TQ!5%1?2$%30TA)3$1214XG+"`S,BD["B`@("!`9&5F:6YE*"=,05147TA!
M4TY/0TA)3$1214XG+"`V-"D["GT*"B\J(%-T87)T(&%T(#$R."!F;W(@;W5R
M(&QO8V%L(&)I=&UA<VMS('1O(&%L;&]W(&9O<B!T:&4@8RUC;&EE;G0@3$%4
M5%\J"B`@(&-O;G-T86YT<RX@*B\*9&5F:6YE*"=)34%05%)%15]%3%1?2$%3
M7T-(24Q$4D5.)RP@,3(X*3L@+R\@1$504D5#051%1`ID969I;F4H)TE-05!4
M4D5%7T5,5%])4U]/4$5.)RP@,C4V*3L*9&5F:6YE*"=)34%05%)%15]%3%1?
M25-?4U5"4T-224)%1"<L(#4Q,BD["F1E9FEN92@G24U!4%12145?14Q47TE3
M7T1)4T-/5D52140G+"`Q,#(T*3L*9&5F:6YE*"=)34%05%)%15]%3%1?25-?
M4$],3$5$)RP@,C`T."D["F1E9FEN92@G24U!4%12145?14Q47TY%141?4T]2
M5"<L(#0P.38I.PHO+R`G.#$Y,B<@:7,@=7-E9"!B>2!)35`@-"YX('-O(&1O
M(&YO="!U<V4@:70@:&5R90ID969I;F4H)TE-05!44D5%7T5,5%].04U%4U!!
M0T4G+"`Q-C,X-"D["@HO*B!4:&4@:7-/<&5N*"D@97AP86YD960@;6]D92!C
M;VYS=&%N=',N("HO"F1E9FEN92@G24U!4%12145?3U!%3E].3TY%)RP@,"D[
M"F1E9FEN92@G24U!4%12145?3U!%3E]!3$PG+"`Q*3L*9&5F:6YE*"=)34%0
M5%)%15]/4$5.7U5315(G+"`R*3L*"B\J(%=H:6-H(&UO9&4@;V8@24U!4"!A
M8V-E<W,@87)E('=E('5S:6YG+B`J+PID969I;F4H)TE-05!44D5%7TU/1$5?
M34%)3"<L(#`I.PID969I;F4H)TE-05!44D5%7TU/1$5?3D574R<L(#$I.PH*
M+RH@5&AE(&EN:71A;&EZ871I;VX@;6]D92!T;R!U<V4@=VAE;B!C<F5A=&EN
M9R!T:&4@=')E92X@*B\*9&5F:6YE*"=)34%05%)%15])3DE47U-50B<L(#$I
M.PID969I;F4H)TE-05!44D5%7TE.251?54Y354(G+"`R*3L*9&5F:6YE*"=)
M34%05%)%15])3DE47T9%5$-(04Q,)RP@-"D["@HO*B!4:&4@;6%N;F5R('1O
M('=H:6-H('1O('1R879E<G-E('1H92!T<F5E('=H96X@8V%L;&EN9R!N97AT
M*"DN("HO"F1E9FEN92@G24U!4%12145?3D585%]32$]70TQ/4T5$)RP@,2D[
M"F1E9FEN92@G24U!4%12145?3D585%]32$]74U5")RP@,BD["@HO*B!4:&4@
M<W1R:6YG('5S960@=&\@:6YD:6-A=&4@=&AE(&)A<V4@;V8@=&AE('1R964N
M("HO"F1E9FEN92@G24U!4%12145?0D%315]%3%0G+"!N=6QL*3L*"B\J*@H@
M*B!4:&4@24U!4%]4<F5E(&-L87-S('!R;W9I9&5S(&$@=')E92!V:65W(&]F
M('1H92!F;VQD97)S('-U<'!O<G1E9"!W:71H"B`J('1H92!02%`@:6UA<"!E
M>'1E;G-I;VX@*$E-05`O4$]0,R].3E10(')E<&]S:71O<FEE<RDN("!)="!P
M<F]V:61E<R!A8V-E<W,*("H@9G5N8W1I;VYS('1O(&ET97)A=&4@=&AR;W5G
M:"!T:&ES('1R964@86YD('%U97)Y(&EN9F]R;6%T:6]N(&%B;W5T"B`J(&EN
M9&EV:61U86P@;6%I;&)O>&5S+V9O;&1E<G,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TE-05`O24U!4"]4<F5E+G!H<"QV(#$N-#@N,BXT,R`R,#`V+S`U
M+S$R(#$V.C(Y.C(Y('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#`M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#`M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA
M=G-M0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T
M:&]R("!!;FEL($UA9&AA=F%P961D>2`\879S;4!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95])34%0"B`J
M+PIC;&%S<R!)34%07U1R964@>PH*("`@("\J*@H@("`@("H@07-S;V-I871I
M=F4@87)R87D@8V]N=&%I;FEN9R!T:&4@;6%I;&)O>"!T<F5E+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=')E93L*"B`@
M("`O*BH*("`@("`J($QO8V%T:6]N(&]F(&-U<G)E;G0@96QE;65N="!I;B!T
M:&4@=')E92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]C=7)R<&%R96YT(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($QO
M8V%T:6]N(&]F(&-U<G)E;G0@96QE;65N="!I;B!T:&4@=')E92X*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8W5R<FME
M>2`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!,;V-A=&EO;B!O9B!C=7)R96YT
M(&5L96UE;G0@:6X@=&AE('1R964N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]C=7)R<W1A8VL@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@4VAO=R!U;G-U8G-C<FEB960@;6%I;&)O>&5S/PH@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W
M=6YS=6(@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%!A<F5N="!L:7-T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R
M96YT(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!C86-H960@;&ES
M="!O9B!M86EL8F]X97,@=&\@<&]L;"X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!O;&P@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE(&-A8VAE9"!L:7-T(&]F(&5X<&%N9&5D(&9O;&1E<G,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]E>'!A
M;F1E9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#86-H960@;&ES="!O9B!S
M=6)S8W)I8F5D(&UA:6QB;WAE<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7W-U8G-C<FEB960@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@0V%C:&5D(&QI<W0@;V8@=6YS=6)S8W)I8F5D(&UA:6QB;WAE
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W5N<W5B<V-R:6)E9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!);FET(&UO
M9&4@9FQA9RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?:6YI=&UO9&4@/2`P.PH*("`@("\J*@H@("`@("H@5')E92!C
M:&%N9V5D(&9L86<N("!3970@=VAE;B!S;VUE=&AI;F<@:6X@=&AE('1R964@
M:&%S(&)E96X@86QT97)E9"X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?8VAA;F=E9"`](&9A;'-E.PH*("`@("\J*@H@
M("`@("H@2&%V92!W92!S:&]W;B!U;G-U8G-C<FEB960@9F]L9&5R<R!P<F5V
M:6]U<VQY/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]U;G-U8G9I97<@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H
M92!)34%07U-O<G0@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@24U!4%]3
M;W)T"B`@("`@*B\*("`@('9A<B`D7VEM87!?<V]R="`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!);G-E<G0@86X@96QE;65N="!I;B!T:&4@=')E92!T:&%T
M(&1O97-N)W0@87!P96%R(&]N('1H92!)34%0('-E<G9E<BX*("`@("`J($EF
M('-E="P@24U!4%]4<F5E.CH@=VEL;"!C86QL(%]G971.;VY)34%016QT*"D@
M=&\@;V)T86EN('1H92!E;&5M96YT"B`@("`@*B!T;R!A9&0@=&\@=&AE('1R
M964N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7VYO;FEM87!E;'0@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!N
M86UE('1O('5S92!W:&5N('-T;W)I;F<@=&AE(&]B:F5C="!I;B!T:&4@<V5S
M<VEO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]C86-H96YA;64["@H@("`@+RHJ"B`@("`@*B!4:&4@87!P;&EC871I
M;VX@=&AA="!G96YE<F%T960@=&AI<R!T<F5E+@H@("`@("H@5$A)4R!32$]5
M3$0@0D4@4T54($E.($5615)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%P<"`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@<V5R=F5R('-T<FEN9R!F;W(@
M=&AE(&-U<G)E;G0@<V5R=F5R+@H@("`@("H@5$A)4R!32$]53$0@0D4@4T54
M($E.($5615)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-E<G9E<B`]("<G.PH*
M("`@("\J*@H@("`@("H@4VAO=6QD('=E('5S92`G;6%I;"<@;6]D92!O<B`G
M;F5W<R<@;6]D93\*("`@("`J(%1(25,@4TA/54Q$($)%(%-%5"!)3B!%5D52
M62!354)#3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1?;6]D92`](&YU;&P["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;&ES="!O9B!N86UE<W!A8V5S('1O(&%D9"!T;R!T:&4@
M=')E92X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7VYA;65S<&%C97,["B`@("`O*BH*("`@("`J($1O97,@=&AE($E-05`@
M<V5R=F5R('-U<'!O<G0@=&AE(&-H:6QD<F5N(&5X=&5N<VEO;C\*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8VAI;&1R
M96YS=7!P;W)T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%5S960@=&\@9&5T
M97)M:6YE('1H92!L:7-T(&]F(&5L96UE;G0@8VAA;F=E<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5L=&1I9F8@/2!N
M=6QL.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F
M97)E;F-E('1O(&$@8V]N8W)E=&4@24U!4%]4<F5E(&EN<W1A;F-E+@H@("`@
M("H*("`@("`J($EF(&%N($E-05!?5')E92!O8FIE8W0@:7,@8W5R<F5N=&QY
M('-T;W)E9"!I;B!T:&4@;&]C86P@<V5S<VEO;BP*("`@("`J(')E8W)E871E
M('1H870@;V)J96-T+B`@16QS92P@:68@)&-R96%T92!I<R!T<G5E+"!W:6QL
M(&-R96%T92!A(&YE=PH@("`@("H@:6YS=&%N8V4N("!%;G-U<F5S('1H870@
M;VYL>2!O;F4@24U!4%]4<F5E(&EN<W1A;F-E(&ES(&%V86EL86)L90H@("`@
M("H@870@86YY('1I;64N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S
M="!B92!I;G9O:V5D(&%S.CQP<F4^"B`@("`@*B`@("1I;6%P7W1R964@/2`F
M24U!4%]4<F5E.CIS:6YG;&5T;VXH)&%P<"P@)&-L87-S;F%M92P@6R1C<F5A
M=&5;+"`D=6YS=6)=72D[/"]P<F4^"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D87!P("`@("`@("!4:&4@8W5R<F5N="!A<'!L:6-A=&EO;B!N86UE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W-N86UE("!4:&4@8VQA<W,@
M;F%M92!T;R!U<V4@=VAE;B!I;G-T86YT:6%T:6YG(&$@;F5W"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="X*("`@("`J($!P87)A
M;2!B;V]L96%N("1C<F5A=&4@("`@0W)E871E(&$@;F5W($E-05!?5')E92!I
M9B!I="!D;V5S;B=T(&5X:7-T(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!S97-S:6]N/PH@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&EN:70@("`@("!4:&4@:6YI=&EA;&EZ871I;VX@;6]D92!T;R!U<V4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C86-H96YA;64@(%1H92!N86UE('1O('5S
M92!W:&5N('-T;W)I;F<@:6X@=&AE('-E<W-I;VXN"B`@("`@*@H@("`@("H@
M0')E='5R;B!)34%07U1R964@(%1H92!)34%07U1R964@;V)J96-T(&]R(&YU
M;&PN"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&%P<"P@)&-L
M87-S;F%M92P@)&-R96%T92`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YI="`]($E-05!44D5%7TE.251?4U5"+"`D8V%C:&5N86UE(#T@
M)VEM87!T<F5E)RD*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LD87!P72DI
M('L*("`@("`@("`@("`@<F5T=7)N("1I;G-T86YC95LD87!P73L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A96UP='DH)%]315-324].6R1A<'!=6R1C86-H
M96YA;65=*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E
M<W-I;VY/8FIE8W1S+G!H<"<["B`@("`@("`@("`@("1C86-H95-E<W,@/2`F
M2&]R9&5?4V5S<VEO;D]B:F5C=',Z.G-I;F=L971O;B@I.PH@("`@("`@("`@
M("`D:6YS=&%N8V5;)&%P<%T@/2`F)&-A8VAE4V5S<RT^<75E<GDH)%]315-3
M24].6R1A<'!=6R1C86-H96YA;65=*3L*("`@("`@("`@("`@<F5G:7-T97)?
M<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1I;G-T86YC95LD87!P72P@)U]S
M=&]R92<I*3L*("`@("`@("!](&5L<V5I9B`H)&-R96%T92D@>PH@("`@("`@
M("`@("`D:6YS=&%N8V5;)&%P<%T@/2`F;F5W("1C;&%S<VYA;64H)&EN:70L
M("1C86-H96YA;64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T
M86YC95LD87!P73L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;FET("`@("`@5&AE
M(&EN:71I86QI>F%T:6]N(&UO9&4@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V%C:&5N86UE("!4:&4@;F%M92!T;R!U<V4@=VAE;B!S=&]R:6YG
M(&EN('1H92!S97-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07U1R
M964H)&EN:70@/2!)34%05%)%15])3DE47U-50BP@)&-A8VAE;F%M92`]("=I
M;6%P=')E92<I"B`@("!["B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N
M8W1I;VXH87)R87DH)B1T:&ES+"`G7W-T;W)E)RDI.PH@("`@("`@("1T:&ES
M+3Y?8V%C:&5N86UE(#T@)&-A8VAE;F%M93L*("`@("`@("`D=&AI<RT^:6YI
M="@D:6YI="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A('-E<FEA
M;&EZ960@=F5R<VEO;B!O9B!O=7)S96QF(&EN('1H92!C=7)R96YT('-E<W-I
M;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]S=&]R92@I"B`@("!["B`@("`@("`@+RH@5V4@;VYL>2!N
M965D('1O(')E<W1O<F4@=&AE(&]B:F5C="!I9B!T:&4@=')E92!H87,@8VAA
M;F=E9"X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?8VAA;F=E9"DI
M('L*("`@("`@("`@("`@+RH@1&]N)W0@<W1O<F4@)%]E>'!A;F1E9"!A;F0@
M)%]P;VQL("T@=&AE<V4@=F%L=65S(&%R92!H86YD;&5D"B`@("`@("`@("`@
M("`J(&)Y('1H92!S=6)C;&%S<V5S+@H@("`@("`@("`@("`@*B!$;VXG="!S
M=&]R92`D7VEM87!?<V]R="!O<B`D7V5L=&1I9F8@+2!T:&ES(&YE961S('1O
M(&)E"B`@("`@("`@("`@("`J(')E9V5N97)A=&5D(&9O<B!E86-H(')E<75E
M<W0N"B`@("`@("`@("`@("`J($1O;B=T('-T;W)E("1?8W5R<FME>2P@)%]C
M=7)R<&%R96YT+"!A;F0@)%]C=7)R4W1A8VL@<VEN8V4@=&AE"B`@("`@("`@
M("`@("`J('5S97(@35535"!C86QL(')E<V5T*"D@8F5F;W)E(&-Y8VQI;F<@
M=&AR;W5G:"!T:&4@=')E92X*("`@("`@("`@("`@("H@4F5S970@=&AE("1?
M8VAA;F=E9"!F;&%G+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)K97D@
M/2`D=&AI<RT^7V-U<G)P87)E;G0@/2`D=&AI<RT^7V5L=&1I9F8@/2`D=&AI
M<RT^7V5X<&%N9&5D(#T@)'1H:7,M/E]I;6%P7W-O<G0@/2`D=&AI<RT^7W!O
M;&P@/2!N=6QL.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)3=&%C:R`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`](&9A;'-E.PH*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397-S:6]N3V)J96-T
M<RYP:'`G.PH@("`@("`@("`@("`D8V%C:&5397-S(#T@)DAO<F1E7U-E<W-I
M;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@("`@("\J(%)E=7-E
M(&]L9"!S97-S:6]N($E$(&EF('!O<W-I8FQE+B`J+PH@("`@("`@("`@("!I
M9B`H:7-S970H)%]315-324].6R1T:&ES+3Y?87!P75LD=&AI<RT^7V-A8VAE
M;F%M95TI*2!["B`@("`@("`@("`@("`@("`D8V%C:&5397-S+3YO=F5R=W)I
M=&4H)%]315-324].6R1T:&ES+3Y?87!P75LD=&AI<RT^7V-A8VAE;F%M95TL
M("1T:&ES+"!F86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELD=&AI<RT^7V%P<%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?87!P72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M7U-%4U-)3TY;)'1H:7,M/E]A<'!=6R1T:&ES+3Y?8V%C:&5N86UE72`]("1C
M86-H95-E<W,M/G-T;W)E3VED*"1T:&ES+"!F86QS92D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M;&ES="!O9B!F;VQD97)S+VUA:6QB;WAE<R!M871C:&EN9R!A(&-E<G1A:6X@
M<&%T:"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@;6%I;&)O>"!P871H+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!M86EL8F]X
M7V]B:F5C=',@=VAO<V4@;F%M92!M871C:&5D("1P871H+@H@("`@("H@("`@
M("`@("`@("`@("`@5&AE('-E<G9E<B!S=')I;F<@:&%S(&)E96X@<F5M;W9E
M9"!F<F]M('1H92!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&ES
M="@D<&%T:"D*("`@('L*("`@("`@("`D=6YI<75E(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*"$D=&AI<RT^7W-H;W=U;G-U8BD@>PH@("`@("`@("`@("`D
M=&AI<RT^7VEN:713=6)S8W)I8F5D*"D["B`@("`@("`@?0H@("`@("`@("1N
M97=B;WAE<R`]($!I;6%P7V=E=&UA:6QB;WAE<R@D=&AI<RT^7V=E=%-T<F5A
M;2@I+"`D=&AI<RT^7W-E<G9E<BP@)'!A=&@I.PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D;F5W8F]X97,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1N97=B
M;WAE<R!A<R`D8F]X*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]S
M:&]W=6YS=6(@?'P*("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M
M/E]S=6)S8W)I8F5D6R1B;W@M/FYA;65=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("\J(%-T<FEP(&]F9B!S97)V97(@<W1R:6YG+B`J+PH@("`@("`@("`@
M("`@("`@("`@("1B;W@@/2`D=&AI<RT^7W)E;6]V95-E<G9E<E-T<FEN9R@D
M8F]X*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&)O>"T^;F%M92`F)B`A
M:7-S970H)'5N:7%U95LD8F]X+3YN86UE72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'5N:7%U95LD8F]X+3YN86UE72`]("1B;W@["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5N:7%U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($UA:V4@82!S:6YG;&4@;6%I;&)O>"!T<F5E(&5L96UE
M;G0N"B`@("`@*B!!;B!E;&5M96YT(&-O;G-I<W1S(&]F('1H92!F;VQL;W=I
M;F<@:71E;7,@*'=E('5S92!S:6YG;&4@;&5T=&5R<R!H97)E"B`@("`@*B!T
M;R!S879E(&EN('-E<W-I;VX@<W1O<F%G92!S<&%C92DZ"B`@("`@*B`@("=A
M)R`@+2T@($%T=')I8G5T97,*("`@("`J("`@)V,G("`M+2`@3&5V96P@8V]U
M;G0*("`@("`J("`@)VPG("`M+2`@3&%B96P*("`@("`J("`@)W`G("`M+2`@
M4&%R96YT(&YO9&4*("`@("`J("`@)W8G("`M+2`@5F%L=64*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T('-T9$-L87-S("1O8B`@5&AE(&]B:F5C="!R971U<FYE9"!B>2!I;6%P
M7V=E=&UA:6QB;WAE<R@I+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%-E92!F;W)M870@86)O=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]M86ME
M36%I;&)O>%1R965%;'0H)&]B*0H@("`@>PH@("`@("`@("1E;'1;)V$G72`]
M("1O8BT^871T<FEB=71E<SL*("`@("`@("`D96QT6R=C)UT@/2`P.PH@("`@
M("`@("1E;'1;)W`G72`]($E-05!44D5%7T)!4T5?14Q4.PH@("`@("`@("1E
M;'1;)W8G72`]("1O8BT^;F%M93L*"B`@("`@("`@+RH@4V5T('-U8G-C<FEB
M960@=F%L=65S+B!-86ME('-U<F4@24Y"3U@@:7,@86QW87ES('-U8G-C<FEB
M960*("`@("`@("`@*B!T;R`H:68@=V]R:VEN9R!W:71H(&UA:6PI('-O('1H
M97)E(&ES(&%L=V%Y<R!A="!L96%S="`Q"B`@("`@("`@("H@=FEE=V%B;&4@
M96QE;65N="X@*B\*("`@("`@("!I9B`H)&5L=%LG=B==(#T]("=)3D)/6"<I
M('L*("`@("`@("`@("`@)'1H:7,M/E]S9713=6)S8W)I8F5D*"1E;'0L('1R
M=64I.PH@("`@("`@('T@96QS96EF("@A)'1H:7,M/FES4W5B<V-R:6)E9"@D
M96QT*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VEN:713=6)S8W)I8F5D*"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?<V5T4W5B<V-R:6)E9"@D96QT+"!I<W-E
M="@D=&AI<RT^7W-U8G-C<FEB961;)&5L=%LG=B==72DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0VAE8VL@9F]R('!O;&QE9"!S=&%T=7,N("HO"B`@("`@
M("`@:68@*"$D=&AI<RT^:7-0;VQL960H)&5L="DI('L*("`@("`@("`@("`@
M)'1H:7,M/F=E=%!O;&Q,:7-T*"D["B`@("`@("`@("`@("1T:&ES+3Y?<V5T
M4&]L;&5D*"1E;'0L(&ES<V5T*"1T:&ES+3Y?<&]L;%LD96QT6R=V)UU=*2D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@;W!E;B!S=&%T=7,N
M("HO"B`@("`@("`@)'1H:7,M/E]S971/<&5N*"1E;'0L("1T:&ES+3YI<T]P
M96XH)&5L="DI.PH*("`@("`@("`O*B!#;VUP=71E9"!V86QU97,N("HO"B`@
M("`@("`@)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D96QT6R=V
M)UTI.PH@("`@("`@("1T;7`@/2!E>'!L;V1E*"AI<U]N=6QL*"1N<U]I;F9O
M*2D@/R`D=&AI<RT^7V1E;&EM:71E<B`Z("1N<U]I;F9O6R=D96QI;6ET97(G
M72P@)&5L=%LG=B==*3L*("`@("`@("`D96QT6R=C)UT@/2!C;W5N="@D=&UP
M*2`M(#$["B`@("`@("`@)&QA8F5L(#T@)&5L=%LG8R==.PH@("`@("`@(&EF
M("@A96UP='DH)&5L=%LG8R==*2`F)@H@("`@("`@("`@("`A<')E9U]M871C
M:"@B+UQ[+BIP;W`S+BI<?2\B+"`D;V(M/F9U;&Q397)V97)0871H*2D@>PH@
M("`@("`@("`@("`D96QT6R=P)UT@/2!I;7!L;V1E*"AI<U]N=6QL*"1N<U]I
M;F9O*2D@/R`D=&AI<RT^7V1E;&EM:71E<B`Z("1N<U]I;F9O6R=D96QI;6ET
M97(G72P@87)R87E?<VQI8V4H)'1M<"P@,"P@)&5L=%LG8R==*2D["B`@("`@
M("`@("`@("\J(%-T<FEP('!E<G-O;F%L(&YA;65S<&%C92X@*B\*("`@("`@
M("`@("`@:68@*"%I<U]N=6QL*"1N<U]I;F9O*2`F)@H@("`@("`@("`@("`@
M("`@(65M<'1Y*"1N<U]I;F9O6R=N86UE)UTI("8F"B`@("`@("`@("`@("`@
M("`H)&YS7VEN9F];)W1Y<&4G72`]/2`G<&5R<V]N86PG*2D@>PH@("`@("`@
M("`@("`@("`@)&5L=%LG8R==+2T["B`@("`@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1E;'1;)W`G72P@)&YS7VEN9F];)V1E;&EM:71E<B==*2`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@("`@("`@("`D96QT6R=P)UT@/2!)34%05%)%
M15]"05-%7T5,5#L*("`@("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H
M)&5L=%LG=B==+"`D;G-?:6YF;ULG;F%M92==("X@)TE.0D]8)R`N("1N<U]I
M;F9O6R=D96QI;6ET97(G72D@/3T](#`I('L*("`@("`@("`@("`@("`@("`@
M("`D96QT6R=P)UT@/2`G24Y"3U@G.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1E;'1;)VPG72`](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)'1M<%LD;&%B96Q=+"`G551&-RU)34%0)RD[
M"@H@("`@("`@(')E='5R;B`D96QT.PH@("`@?0H*("`@("\J*@H@("`@("H@
M26YI=&%L:7IE('1H92!L:7-T(&%T('1H92!T;W`@;&5V96P@;V8@=&AE(&AI
M97)A<F-H>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YI="`@
M5&AE(&EN:71I86QI>F%T:6]N(&UO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&EN:70H)&EN:70I"B`@("!["B`@("`@("`@+RH@4F5S970@86QL(&-L87-S
M('9A<FEA8FQE<R!T;R!T:&4@9&5F875L=',N("HO"B`@("`@("`@)'1H:7,M
M/E]C:&%N9V5D(#T@=')U93L*("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2!N
M=6QL.PH@("`@("`@("1T:&ES+3Y?8W5R<G!A<F5N="`](&YU;&P["B`@("`@
M("`@)'1H:7,M/E]C=7)R<W1A8VL@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES
M+3Y?=')E92`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]P87)E;G0@/2!A
M<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?<VAO=W5N<W5B(#T@)'1H:7,M/E]U
M;G-U8G9I97<@/2`H)&EN:70@)B!)34%05%)%15])3DE47U5.4U5"*3L*("`@
M("`@("`D=&AI<RT^7W-U8G-C<FEB960@/2!N=6QL.PH@("`@("`@("1T:&ES
M+3Y?=6YS=6)S8W)I8F5D(#T@;G5L;#L*"B`@("`@("`@+RH@4V5T(&EN:71I
M86QI>F%T:6]N(&UO9&4N("HO"B`@("`@("`@)'1H:7,M/E]I;FET;6]D92`]
M("1I;FET.PH*("`@("`@("`O*B!'970@=&AE(&EN:71I86P@;&ES="!O9B!M
M86EL8F]X97,@9G)O;2!T:&4@<W5B8VQA<W,N("HO"B`@("`@("`@)&)O>&5S
M(#T@)'1H:7,M/E]I;FET*"D["@H@("`@("`@("\J($-R96%T92!A('!L86-E
M:&]L9&5R(&5L96UE;G0@=&\@=&AE(&)A<V4@;V8@=&AE('1R964@;&ES="!S
M;R!W92!C86X*("`@("`@("`@*B!K965P('1R86-K(&]F('=H971H97(@=&AE
M(&)A<V4@;&5V96P@;F5E9',@=&\@8F4@<V]R=&5D+B`J+PH@("`@("`@("1T
M:&ES+3Y?=')E95M)34%05%)%15]"05-%7T5,5%T@/2!A<G)A>2@G82<@/3X@
M24U!4%12145?14Q47TE37T1)4T-/5D52140I.PH*("`@("`@("`O*B!#:&5C
M:R!T;R!M86ME('-U<F4@86QL(&YA;65S<&%C92!E;&5M96YT<R!A<F4@:6X@
M=&AE('1R964N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?;F%M97-P86-E<RD@
M>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H)'9A;%LG='EP
M92==("$]("=P97)S;VYA;"<I('L*("`@("`@("`@("`@("`@("`@("`D;F%M
M92`]('-U8G-T<B@D:V5Y+"`P+"`M,2`J('-T<FQE;B@D=F%L6R=D96QI;6ET
M97(G72DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]T<F5E6R1V86Q;)VYA;64G75TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1O8B`]("9N97<@<W1D0VQA<W,["B`@("`@("`@("`@("`@("`@("`@
M("`@("1O8BT^9&5L:6UI=&5R(#T@)'9A;%LG9&5L:6UI=&5R)UT["B`@("`@
M("`@("`@("`@("`@("`@("`@("1O8BT^871T<FEB=71E<R`]($Q!5%1?3D]3
M14Q%0U0@?"!)34%05%)%15]%3%1?3D%-15-004-%.PH@("`@("`@("`@("`@
M("`@("`@("`@("`O*B`D;V(M/F9U;&Q397)V97)0871H(&ES(&YO="!C;VUP
M;&5T96QY('-E="!H97)E+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;V(M/F9U;&Q397)V97)0871H(#T@)&]B+3YN86UE(#T@)&YA;64["B`@("`@
M("`@("`@("`@("`@("`@("`@("1E;'0@/2`D=&AI<RT^7VUA:V5-86EL8F]X
M5')E945L="@D;V(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEN<V5R=$5L="@D96QT*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($-R96%T92!T:&4@;&ES="`H24Y"3U@@86YD(&%N>2!O=&AE<B!H:65R
M87)C:&EE<RDN("HO"B`@("`@("`@)'1H:7,M/E]A9&1,979E;"@D8F]X97,I
M.PH*("`@("`@("`O*B!%;F0@:6YI=&EA;&EZ871I;VX@;6]D92X@*B\*("`@
M("`@("`D=&AI<RT^7VEN:71M;V1E(#T@,#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-U8F-L87-S('-P96-I9FEC(&EN:71I86QI>F%T:6]N('1A<VMS+@H@
M("`@("H@5$A)4R!-151(3T0@35535"!"12!$149)3D5$($E.($%,3"!354)#
M3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!I;FET:6%L(&QI<W0@;V8@96QE;65N=',@=&\@861D('1O('1H92!T
M<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI="@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!A
M;F0@82!M86EL(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;VQD97(@("`@("!4:&4@9F]L9&5R(&YA;64@=&\@97AP86YD+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&5X<&%N9&%L;"`@17AP86YD(&%L;"!F;VQD
M97)S('5N9&5R('1H:7,@;VYE/PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'!A
M;F0H)&9O;&1E<BP@)&5X<&%N9&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1F;VQD97(@/2`D=&AI<RT^7V-O;G9E<G1.86UE*"1F;VQD97(I.PH*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=')E95LD9F]L9&5R72DI('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C
M:&%N9V5D(#T@=')U93L*"B`@("`@("`@+RH@365R9V4@:6X@;F5X="!L979E
M;"!O9B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA<T-H
M:6QD<F5N*"1T:&ES+3Y?=')E95LD9F]L9&5R72DI('L*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^:7-$:7-C;W9E<F5D*"1T:&ES+3Y?=')E95LD9F]L9&5R
M72DI('L*("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/E]C:&EL9')E
M;DEN9F\H)&9O;&1E<BD["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I
M;F9O*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VEN:71M
M;V1E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@H)'1H:7,M/E]I
M;FET;6]D92`F($E-05!44D5%7TE.251?1D540TA!3$PI('Q\"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:7-/<&5N*"1T:&ES+3Y?=')E
M95LD9F]L9&5R72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?861D3&5V96PH)&EN9F\I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1,979E;"@D:6YF;RD["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D=&AI<RT^7W1R965;
M)&9O;&1E<ETL('1R=64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(&EF("@A*"1T:&ES+3Y?:6YI=&UO9&4@)B!)34%05%)%15])3DE47T9%
M5$-(04Q,*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3W!E
M;B@D=&AI<RT^7W1R965;)&9O;&1E<ETL('1R=64I.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\J($5X<&%N9"!A;&P@8VAI;&1R96X@
M8F5N96%T:"!T:&ES(&]N92X@*B\*("`@("`@("`@("`@("`@(&EF("@D97AP
M86YD86QL("8F("%E;7!T>2@D=&AI<RT^7W!A<F5N=%LD9F]L9&5R72DI('L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F5N=%LD
M9F]L9&5R72!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YE>'!A;F0H)'1H:7,M/E]T<F5E6R1V86Q=6R=V)UTL('1R=64I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O;&QA
M<'-E(&$@;6%I;"!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F]L9&5R("!4:&4@9F]L9&5R(&YA;64@=&\@8V]L;&%P<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;&QA<'-E*"1F;VQD97(I"B`@("!["B`@("`@
M("`@)&9O;&1E<B`]("1T:&ES+3Y?8V]N=F5R=$YA;64H)&9O;&1E<BD["@H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]T<F5E6R1F;VQD97)=*2D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7V-H86YG960@/2!T<G5E.PH*("`@("`@("`O*B!3970@=&AE(&9O;&1E<B!A
M='1R:6)U=&5S('1O(&YO="!E>'!A;F1E9"X@*B\*("`@("`@("`D=&AI<RT^
M7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1F;VQD97)=+"!F86QS92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!I;G1E<FYA;"!A<G)A>2!P;VEN
M=&5R('1O('1H92!N97AT(&5L96UE;G0L(&%N9"!R971U<FYS('1H90H@("`@
M("H@;F5X="!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&UA<VL@($$@;6%S:R!W:71H('1H92!F;VQL;W=I;F<@96QE;65N=',Z"B`@
M("`@*B`\<')E/@H@("`@("H@24U!4%12145?3D585%]32$]70TQ/4T5$("T@
M1&]N)W0@:6=N;W)E(&-L;W-E9"!E;&5M96YT<RX*("`@("`J($E-05!44D5%
M7TY%6%1?4TA/5U-50B`M($]N;'D@<VAO=R!S=6)S8W)I8F5D(&5L96UE;G1S
M+@H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M4F5T=7)N<R!T:&4@;F5X="!E;&5M96YT(&]R(&9A;'-E(&EF('1H92!E;&5M
M96YT(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@(&5X:7-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!N97AT*"1M87-K(#T@,"D*("`@('L*("`@("`@
M("!I9B`H:7-?;G5L;"@D=&AI<RT^7V-U<G)K97DI("8F(&ES7VYU;&PH)'1H
M:7,M/E]C=7)R<&%R96YT*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D8W5R<B`]("1T:&ES+3YC=7)R96YT*"D[
M"@H@("`@("`@("1O;&1?<VAO=W5N<W5B(#T@)'1H:7,M/E]S:&]W=6YS=6([
M"B`@("`@("`@:68@*"1M87-K("8@24U!4%12145?3D585%]32$]74U5"*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<VAO=W5N<W5B(#T@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@"B`@("`@("`@:68@*"1T:&ES+3Y?86-T:79E16QT*"1C
M=7)R*2`F)@H@("`@("`@("`@("`H*"1M87-K("8@24U!4%12145?3D585%]3
M2$]70TQ/4T5$*2!\?"`D=&AI<RT^:7-/<&5N*"1C=7)R*2D@)B8*("`@("`@
M("`@("`@*"1T:&ES+3Y?8W5R<G!A<F5N="`A/2`D8W5R<ELG=B==*2D@>PH@
M("`@("`@("`@("`O*B!)9B!T:&4@8W5R<F5N="!E;&5M96YT(&ES(&]P96XL
M(&%N9"!C:&EL9')E;B!E>&ES="P@;6]V92!I;G1O"B`@("`@("`@("`@("`J
M(&ET+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)S=&%C:UM=(#T@87)R
M87DH)VLG(#T^("1T:&ES+3Y?8W5R<FME>2P@)W`G(#T^("1T:&ES+3Y?8W5R
M<G!A<F5N="D["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<FME>2`](#`["B`@
M("`@("`@("`@("1T:&ES+3Y?8W5R<G!A<F5N="`]("1C=7)R6R=V)UT["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7VYE9613;W)T*"1T:&ES+3Y?=')E95LD
M8W5R<ELG=B==72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]R=$QI
M<W0H)'1H:7,M/E]P87)E;G1;)&-U<G);)W8G75TL(&ES7VYU;&PH)&-U<G);
M)W8G72DI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S971.965D4V]R="@D
M=&AI<RT^7W1R965;)&-U<G);)W8G75TL(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!%;'-E+"!I;F-R96UE;G0@
M=VET:&EN('1H92!C=7)R96YT('-U8F9O;&1E<BX@*B\*("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R:V5Y*RL["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T
M:&4@<&]I;G1E<B!D;V5S;B=T('!O:6YT('1O(&%N(&5L96UE;G0L('1R>2!T
M;R!M;W9E(&)A8VL@=&\*("`@("`@("`@("!T:&4@<')E=FEO=7,@<W5B9F]L
M9&5R+B`@268@=&AE<F4@:7,@;F\@<')E=FEO=7,@<W5B9F]L9&5R+`H@("`@
M("`@("`@(')E='5R;B!F86QS92X@*B\*("`@("`@("`D8W5R<B`]("1T:&ES
M+3YC=7)R96YT*"D["B`@("`@("`@:68@*"$D8W5R<B`F)@H@("`@("`@("`@
M("`H)&UA<VL@)B!)34%05%)%15].15A47U-(3U=#3$]3140I("8F"B`@("`@
M("`@("`@("$D=&AI<RT^:7-$:7-C;W9E<F5D*"1T:&ES+3Y?=')E95LD=&AI
M<RT^7V-U<G)P87)E;G1=*2`F)@H@("`@("`@("`@("`D=&AI<RT^:&%S0VAI
M;&1R96XH)'1H:7,M/E]T<F5E6R1T:&ES+3Y?8W5R<G!A<F5N=%TI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?861D3&5V96PH)'1H:7,M/E]C:&EL9')E;DEN
M9F\H)'1H:7,M/E]T<F5E6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)W8G72DI.PH@
M("`@("`@("`@("`D8W5R<B`]("1T:&ES+3YC=7)R96YT*"D["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7W-H;W=U;G-U8B`]("1O;&1?<VAO=W5N<W5B
M.PH*("`@("`@("!I9B`H(21C=7)R*2!["B`@("`@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7V-U<G)S=&%C:RDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<FME>2`](&YU;&P["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)P87)E;G0@/2!N=6QL.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9&\@>PH@
M("`@("`@("`@("`@("`@("`@("1O;&0@/2!A<G)A>5]P;W`H)'1H:7,M/E]C
M=7)R<W1A8VLI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<FME
M>2`]("1O;&1;)VLG72`K(#$["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R<&%R96YT(#T@)&]L9%LG<"==.PH@("`@("`@("`@("`@("`@?2!W
M:&EL92`H*"@D8W5R<B`]("1T:&ES+3YC=7)R96YT*"DI(#T](&9A;'-E*2`F
M)@H@("`@("`@("`@("`@("`@("`@("`@("`@8V]U;G0H)'1H:7,M/E]C=7)R
M<W1A8VLI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*"$D=&AI<RT^7V%C=&EV945L="@D8W5R<BDI('L*("`@("`@("`@("`@+RH@
M4VMI<"!T:&ES(&5N=')Y(&EF.@H@("`@("`@("`@("`@*B`Q+B!792!A<F4@
M;F]T('-H;W=I;F<@86QL(&5L96UE;G1S"B`@("`@("`@("`@("`J(#(N(%=E
M(&%R92!N;W0@<W5B<V-R:6)E9"!T;R!T:&ES(&5L96UE;G0*("`@("`@("`@
M("`@("H@,RX@270@:7,@;F]T(&$@8V]N=&%I;F5R("U/4BTL(&EF(&ET(&ES
M(&$@8V]N=&%I;F5R+"!I9B!T:&5R90H@("`@("`@("`@("`@*B`@("!A<F4@
M;F\@=FEE=V%B;&4@96QE;65N=',@=6YD97)N96%T:"!I="X*("`@("`@("`@
M("`@("H@-"X@5&AI<R!I<R!A;B!E;7!T>2!N86UE<W!A8V4@96QE;65N="X@
M*B\*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YN97AT*"1M87-K*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D8W5R<CL*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!I;G1E<FYA;"!P;VEN=&5R('1O('1H92!H96%D(&]F('1H
M92!T<F5E+@H@("`@("H@5&AI<R!-55-4(&)E(&-A;&QE9"!B969O<F4@>6]U
M(&-A;B!T<F%V97)S92!T:&4@=')E92!W:71H(&YE>'0H*2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!2971U<FYS('1H92!E;&5M96YT(&%T('1H
M92!H96%D(&]F('1H92!T<F5E(&]R(&9A;'-E"B`@("`@*B`@("`@("`@("`@
M("`@("!I9B!T:&4@96QE;65N="!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]C=7)R
M:V5Y(#T@,#L*("`@("`@("`D=&AI<RT^7V-U<G)P87)E;G0@/2!)34%05%)%
M15]"05-%7T5,5#L*("`@("`@("`D=&AI<RT^7V-U<G)S=&%C:R`](&%R<F%Y
M*"D["@H@("`@("`@(&EF("@D=&AI<RT^7VYE9613;W)T*"1T:&ES+3Y?=')E
M95LD=&AI<RT^7V-U<G)P87)E;G1=*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-O<G1,:7-T*"1T:&ES+3Y?<&%R96YT6R1T:&ES+3Y?8W5R<G!A<F5N=%TL
M(&ES7VYU;&PH)'1H:7,M/E]C=7)R<&%R96YT*2D["B`@("`@("`@("`@("1T
M:&ES+3Y?<V5T3F5E9%-O<G0H)'1H:7,M/E]T<F5E6R1T:&ES+3Y?8W5R<G!A
M<F5N=%TL(&9A;'-E*3L*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D(#T@
M=')U93L*("`@("`@("!]"@H@("`@("`@("\J(%=H96X@<F5S971T:6YG(&EN
M(&YE=W,@;6]D92P@=&AE(&9I<G-T(&5L96UE;G0@;6%Y(&YO="!B90H@("`@
M("`@("`J('9I97=A8FQE("AU;FQI:V4@;6%I;"!M;V1E+"!W:&5R92!T:&4@
M9FER<W0@96QE;65N="!I<R!)3D)/6"!A;F0*("`@("`@("`@*B!I<R!A;'=A
M>7,@=FEE=V%B;&4I+B`@5&AE<F5F;W)E+"!W92!N965D('1O('-E87)C:"!F
M;W(@=&AE(&9I<G-T"B`@("`@("`@("H@=FEE=V%B;&4@:71E;2!A;F0@=&AA
M="!W:6QL(&)E('1H92!B87-E(&]F('1H92!V:65W86)L92!T<F5E+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7VUO9&4@/3T@24U!4%12145?34]$15].15=3
M*2!["B`@("`@("`@("`@("1C=7)R(#T@)'1H:7,M/F-U<G)E;G0H*3L*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7V%C=&EV945L="@D8W5R<BDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YN97AT*"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^8W5R<F5N="@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C=7)R96YT('1R964@96QE
M;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8W5R<F5N
M="!T<F5E(&5L96UE;G0@;W(@9F%L<V4@:68@=&AE<F4@:7,@;F\*("`@("`J
M("`@("`@("`@("`@("`@(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-U<G)E;G0H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)E;G1;)'1H:7,M/E]C=7)R<&%R96YT75LD=&AI<RT^7V-U<G)K97E=*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H:7,M/E]A9&1!;&EA<V5S*"1T:&ES+3Y?=')E95LD=&AI
M<RT^7W!A<F5N=%LD=&AI<RT^7V-U<G)P87)E;G1=6R1T:&ES+3Y?8W5R<FME
M>5U=*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE
M<F4@87)E(&UO<F4@96QE;65N=',@:6X@=&AE(&-U<G)E;G0@=')E92!L979E
M;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE
M<F4@87)E(&UO<F4@96QE;65N=',L(&9A;'-E(&EF('1H:7,@:7,@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&QA<W0@96QE;65N="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<&5E:R@I"B`@("!["B`@("`@("`@9F]R("@D:2`]("@D
M=&AI<RT^7V-U<G)K97D@*R`Q*3L@.R`D:2LK*2!["B`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P87)E;G1;)'1H:7,M/E]C=7)R<&%R96YT75LD
M:5TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?86-T:79E16QT*"1T:&ES
M+3Y?861D06QI87-E<R@D=&AI<RT^7W1R965;)'1H:7,M/E]P87)E;G1;)'1H
M:7,M/E]C=7)R<&%R96YT75LD:5U=*2DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@061D<R!A;&EA<V5S('1O(&$@=')E92!E;&5M96YT(&%N
M9"!R971U<FYS('1H92!R97-U;'1I;F<@87)R87DN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@02!T<F5E(&5L96UE;G0@=VET:"!T:&4@86QI87-E<R!A9&1E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$%L:6%S97,H)&5L="D*("`@('L*
M("`@("`@("`D96QT6R=L86)E;"==(#T@)&5L=%LG;"==.PH@("`@("`@("1E
M;'1;)VQE=F5L)UT@/2`D96QT6R=C)UT["B`@("`@("`@)&5L=%LG<&%R96YT
M)UT@/2`D96QT6R=P)UT["B`@("`@("`@)&5L=%LG=F%L=64G72`]("1E;'1;
M)W8G73L*"B`@("`@("`@<F5T=7)N("1E;'0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!R97%U97-T960@96QE;65N="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@=')E
M92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%)E='5R
M;G,@=&AE(')E<75E<W1E9"!E;&5M96YT(&]R(&9A;'-E(&EF(&YO="!F;W5N
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T*"1N86UE*0H@("`@>PH@("`@
M("`@("1N86UE(#T@)'1H:7,M/E]C;VYV97)T3F%M92@D;F%M92D["@H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W1R965;)&YA;65=*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]A9&1!;&EA<V5S*"1T:&ES+3Y?=')E95LD
M;F%M95TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G-E<G0@
M82!F;VQD97(O;6%I;&)O>"!I;G1O('1H92!T<F5E+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D:60@(%1H92!N86UE(&]F('1H92!F;VQD97(@*&]R
M(&$@;&ES="!O9B!F;VQD97(@;F%M97,I"B`@("`@*B`@("`@("`@("`@("`@
M("`@("!T;R!A9&0@*&UU<W0@8F4@<')E<V5N="!O;B!T:&4@;6%I;"!S97)V
M97(I+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M:6YS97)T*"1I9"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]M;V1E(#T]
M($E-05!44D5%7TU/1$5?3D574RD@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)&ED*2D@>PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?;F]N:6UA<&5L="D@>PH@("`@("`@
M("`@("`@("`@+RH@5V4@=V%N="!T;R!A9&0@9G)O;2!T:&4@0D%312!O9B!T
M:&4@=')E92!U<"!F;W(@969F:6-I96YC>0H@("`@("`@("`@("`@("`@("H@
M<V%K92X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0H)&ED
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1I9"`](&%R<F%Y*"1I9"D["B`@("`@("`@?0H*("`@("`@("`D861D<R`]
M(&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@
M("`@("`@("`@("1N<U]I;F9O(#T@)'1H:7,M/E]G971.86UE<W!A8V4H)'9A
M;"D["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1N<U]I;F9O*2!\?"`D=&AI
M<RT^7VYO;FEM87!E;'0I('L*("`@("`@("`@("`@("`@("1A9&1S6UT@/2`D
M=F%L.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@
M0G)E86L@87!A<G0@=&AE(&YA;64@=FEA('1H92!D96QI;6ET97(@86YD(&=O
M('-T97`@8GD@<W1E<`H@("`@("`@("`@("`@("`@("H@=&AR;W5G:"!T:&4@
M;F%M92!T;R!M86ME('-U<F4@86QL('-U8F9O;&1E<G,@97AI<W0@:6X@=&AE
M"B`@("`@("`@("`@("`@("`@*B!T<F5E+B`J+PH@("`@("`@("`@("`@("`@
M)'!A<G1S(#T@97AP;&]D92@D;G-?:6YF;ULG9&5L:6UI=&5R)UTL("1V86PI
M.PH@("`@("`@("`@("`@("`@)'!A<G1S6S!=(#T@)'1H:7,M/E]C;VYV97)T
M3F%M92@D<&%R='-;,%TI.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@8V]U;G0H)'!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("1A9&1S6UT@/2!I;7!L;V1E*"1N<U]I;F9O6R=D96QI;6ET97(G72P@
M87)R87E?<VQI8V4H)'!A<G1S+"`P+"`D:2`K(#$I*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H87)R87E?=6YI<75E*"1A9&1S*2!A<R`D:60I('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD:61=*2D@>PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES
M+3Y?8VAA;F=E9"`]('1R=64["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]N
M;VYI;6%P96QT*2!["B`@("`@("`@("`@("`@("`D96QT(#T@)'1H:7,M/E]G
M971.;VY)34%016QT*"1I9"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D;V(@/2`D=&AI<RT^7V=E=$QI<W0H)&ED*3L*("`@("`@
M("`@("`@("`@("1E;'0@/2`D=&AI<RT^7VUA:V5-86EL8F]X5')E945L="AR
M97-E="@D;V(I*3L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES4W5B
M<V-R:6)E9"@D96QT*2D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!`
M:6UA<%]L<W5B*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R=F5R
M+"`D96QT6R=V)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)'1M<"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S9713
M=6)S8W)I8F5D*"1E;'0L('1R=64I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?:6YS97)T16QT*"1E;'0I*2!["B`@("`@("`@("`@("`@
M("`O*B!792!K;F]W('1H870@=&AE('!A<F5N="!F;VQD97(@:&%S(&-H:6QD
M<F5N+B`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E
M95LD96QT6R=P)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V5T0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1E;'1;)W`G75TL('1R=64I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($UA:V4@<W5R
M92!W92!A<F4@<V]R=&5D(&-O<G)E8W1L>2X@*B\*("`@("`@("`@("`@("`@
M(&EF("AC;W5N="@D=&AI<RT^7W!A<F5N=%LD96QT6R=P)UU=*2`^(#$I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$YE9613;W)T*"1T:&ES
M+3Y?=')E95LD96QT6R=P)UU=+"!T<G5E*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`O*B!!9&0@=&\@<W5B<V-R:6)E9"]U;G-U8G-C
M<FEB960@;&ES="X@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-3
M=6)S8W)I8F5D*"1E;'0I("8F"B`@("`@("`@("`@("`@("`@("`@(6ES7VYU
M;&PH)'1H:7,M/E]S=6)S8W)I8F5D*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W5B<V-R:6)E9%LD96QT6R=V)UU=(#T@,3L*("`@("`@("`@
M("`@("`@('T@96QS96EF("@A)'1H:7,M/FES4W5B<V-R:6)E9"@D96QT*2`F
M)@H@("`@("`@("`@("`@("`@("`@("`@("`@("%I<U]N=6QL*"1T:&ES+3Y?
M=6YS=6)S8W)I8F5D*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=6YS=6)S8W)I8F5D6R1E;'1;)W8G75T@/2`Q.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($EN<V5R="!A;B!E;&5M96YT(&EN
M=&\@=&AE('1R964N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@(%1H92!E;&5M96YT('1O
M(&EN<V5R="X@5&AE(&ME>2!I;B!T:&4@=')E92!I<R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`G=B<@*'9A;'5E*2!E;&5M96YT(&]F('1H92!E
M;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!A9&1E9"!T;R!T:&4@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN
M<V5R=$5L="@D96QT*0H@("`@>PH@("`@("`@("\J($1O;B=T(&EN8VQU9&4@
M=&AE('!A<F5N="!D:7)E8W1O<FEE<R!T:&%T(%57('!A<W-E<R!B86-K(&EN
M"B`@("`@("`@("`@)2\E(&QI<W1S+B`J+PH@("`@("`@(&EF("AS=')L96XH
M)&5L=%LG;"==*2`F)@H@("`@("`@("`@("`H(6ES<V5T*"1T:&ES+3Y?=')E
M95LD96QT6R=V)UU=*2!\?`H@("`@("`@("`@("`@)'1H:7,M/FES0V]N=&%I
M;F5R*"1T:&ES+3Y?=')E95LD96QT6R=V)UU=*2D@)B8*("`@("`@("`@("`@
M+RH@5$]$3SH@4F5M;W9E(&1O=&9I;&5S(&9I;'1E<B!I;B!N97AT(&UA:F]R
M(')E;&5A<V4N("HO"B`@("`@("`@("`@("@D=&AI<RT^7V1O=&9I;&5S('Q\
M("@D96QT6R=L)UU;,%T@(3T@)RXG*2DI('L*("`@("`@("`@("`@+RH@4V5T
M('1H92!P87)E;G0@87)R87D@=&\@=&AE('9A;'5E(&EN("1E;'1;)W`G72X@
M*B\*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R96YT6R1E;'1;
M)W`G75TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F5N=%LD96QT
M6R=P)UU=(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^7W!A<F5N=%LD96QT6R=P)UU=6UT@/2`D96QT6R=V)UT["B`@("`@
M("`@("`@("1T:&ES+3Y?=')E95LD96QT6R=V)UU=(#T@)&5L=#L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($1E;&5T92!A;B!E;&5M96YT(&9R;VT@=&AE('1R964N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1I9"`@5&AE(&5L96UE;G0@;F%M92!O<B!A
M;B!A<G)A>2!O9B!E;&5M96YT(&YA;65S+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@4F5T=7)N('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T92@D:60I"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@+RH@
M5V4@=V%N="!T;R!D96QE=&4@9G)O;2!T:&4@5$]0(&]F('1H92!T<F5E(&1O
M=VX@=&\@96YS=7)E('1H870*("`@("`@("`@("`@("H@<&%R96YT<R!H879E
M(&%N(&%C8W5R871E('9I97<@;V8@=VAA="!C:&EL9')E;B!A<F4@;&5F="X@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]S;W)T3&ES="@D:60I.PH@("`@("`@
M("`@("`D:60@/2!A<G)A>5]R979E<G-E*"1I9"D["@H@("`@("`@("`@("`D
M<W5C8V5S<R`]('1R=64["B`@("`@("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D
M=F%L*2!["B`@("`@("`@("`@("`@("`D8W5R<G-U8V-E<W,@/2`D=&AI<RT^
M9&5L971E*"1V86PI.PH@("`@("`@("`@("`@("`@:68@*"$D8W5R<G-U8V-E
M<W,I('L*("`@("`@("`@("`@("`@("`@("`D<W5C8V5S<R`](&9A;'-E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E
M='5R;B`D<W5C8V5S<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:60@/2`D=&AI<RT^7V-O;G9E<G1.86UE*"1I9"P@=')U92D["B`@("`@("`@
M?0H*("`@("`@("`D;G-?:6YF;R`]("1T:&ES+3Y?9V5T3F%M97-P86-E*"1I
M9"D["@H@("`@("`@(&EF("@H)&ED(#T]("=)3D)/6"<I('Q\"B`@("`@("`@
M("`@("%I<W-E="@D=&AI<RT^7W1R965;)&ED72D@?'P*("`@("`@("`@("`@
M*"1I9"`]/2`D;G-?:6YF;ULG;F%M92==*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG960@
M/2!T<G5E.PH*("`@("`@("`D96QT(#T@)B1T:&ES+3Y?=')E95LD:61=.PH*
M("`@("`@("`O*B!$;R!N;W0@9&5L971E(&9R;VT@=')E92!I9B!T:&5R92!A
M<F4@8VAI;&0@96QE;65N=',@+2!I;G-T96%D+`H@("`@("`@("`J(&-O;G9E
M<G0@=&\@82!C;VYT86EN97(@96QE;65N="X@*B\*("`@("`@("!I9B`H)'1H
M:7,M/FAA<T-H:6QD<F5N*"1E;'0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<V5T0V]N=&%I;F5R*"1E;'0L('1R=64I.PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"@H@("`@("`@("1P87)E;G0@/2`D96QT6R=P)UT[
M"@H@("`@("`@("\J($1E;&5T92!T:&4@=')E92!E;G1R:65S+B`J+PH@("`@
M("`@('5N<V5T*"1T:&ES+3Y?=')E95LD:61=*3L*("`@("`@("!U;G-E="@D
M=&AI<RT^7W-U8G-C<FEB961;)&ED72D["B`@("`@("`@=6YS970H)'1H:7,M
M/E]U;G-U8G-C<FEB961;)&ED72D["@H@("`@("`@("\J($1E;&5T92!T:&4@
M96YT<GD@9G)O;2!T:&4@<&%R96YT('1R964N("HO"B`@("`@("`@)&ME>2`]
M(&%R<F%Y7W-E87)C:"@D:60L("1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*3L*
M("`@("`@("!U;G-E="@D=&AI<RT^7W!A<F5N=%LD<&%R96YT75LD:V5Y72D[
M"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F5N=%LD<&%R96YT72DI
M('L*("`@("`@("`@("`@+RH@5&AI<R!F;VQD97(@:7,@;F]W(&-O;7!L971E
M;'D@96UP='D@*&YO(&-H:6QD<F5N*2X@($EF('1H90H@("`@("`@("`@("`@
M*B!F;VQD97(@:7,@82!C;VYT86EN97(@;VYL>2P@=V4@<VAO=6QD(&1E;&5T
M92!T:&4@9F]L9&5R(&9R;VT*("`@("`@("`@("`@("H@=&AE('1R964N("HO
M"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*3L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD<&%R96YT72DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T0VAI;&1R96XH)'1H:7,M
M/E]T<F5E6R1P87)E;G1=+"!N=6QL*3L*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^:7-#;VYT86EN97(H)'1H:7,M/E]T<F5E6R1P87)E;G1=*2`F)@H@
M("`@("`@("`@("`@("`@("`@("$D=&AI<RT^:7-.86UE<W!A8V4H)'1H:7,M
M/E]T<F5E6R1P87)E;G1=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YD96QE=&4H)'!A<F5N="D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M(21T:&ES+3YH87-#:&EL9')E;B@D=&AI<RT^7W1R965;)'!A<F5N=%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%>'!A;F1E9$QI
M<W0H)'!A<F5N="D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971#
M:&EL9')E;B@D=&AI<RT^7W1R965;)'!A<F5N=%TL(&9A;'-E*3L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1P
M87)E;G1=+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!296)U:6QD('1H
M92!P87)E;G0@=')E92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]P87)E;G1;
M)'!A<F5N=%T@/2!A<G)A>5]V86QU97,H)'1H:7,M/E]P87)E;G1;)'!A<F5N
M=%TI.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5M;W9E('1H92!M86EL8F]X
M(&9R;VT@=&AE(&5X<&%N9&5D(&9O;&1E<G,@;&ES="X@*B\*("`@("`@("`D
M=&AI<RT^7W)E;6]V945X<&%N9&5D3&ES="@D:60I.PH*("`@("`@("`O*B!2
M96UO=F4@=&AE(&UA:6QB;W@@9G)O;2!T:&4@;F%V7W!O;&P@;&ES="X@*B\*
M("`@("`@("`D=&AI<RT^<F5M;W9E4&]L;$QI<W0H)&ED*3L*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=6)S8W)I8F4@
M86X@96QE;65N="!T;R!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&ED("!4:&4@96QE;65N="!N86UE(&]R(&%N(&%R<F%Y(&]F(&5L
M96UE;G0@;F%M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-U8G-C<FEB92@D
M:60I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D:60I*2!["B`@("`@
M("`@("`@("1I9"`](&%R<F%Y*"1I9"D["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D:60@87,@)'9A;"D@>PH@("`@("`@("`@("`D=F%L(#T@)'1H
M:7,M/E]C;VYV97)T3F%M92@D=F%L*3L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?=')E95LD=F%L72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E
M=%-U8G-C<FEB960H)'1H:7,M/E]T<F5E6R1V86Q=+"!T<G5E*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T0V]N=&%I;F5R*"1T:&ES+3Y?=')E95LD
M=F%L72P@9F%L<V4I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1T
M:&ES+3Y?<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-U8G-C<FEB961;)'9A;%T@/2`Q.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]U;G-U8G-C<FEB961;)'9A
M;%TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FEN<V5R="@D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%5N<W5B<V-R:6)E(&%N(&5L96UE;G0@9G)O
M;2!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&ED("!4
M:&4@96QE;65N="!N86UE(&]R(&%N(&%R<F%Y(&]F(&5L96UE;G0@;F%M97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('5N<W5B<V-R:6)E*"1I9"D*("`@('L*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@)&ED
M(#T@87)R87DH)&ED*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!792!W86YT('1O(&1E;&5T92!F<F]M('1H92!43U`@;V8@=&AE('1R964@
M9&]W;B!T;R!E;G-U<F4@=&AA=`H@("`@("`@("`@("`@*B!P87)E;G1S(&AA
M=F4@86X@86-C=7)A=&4@=FEE=R!O9B!W:&%T(&-H:6QD<F5N(&%R92!L969T
M+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T*"1I9"D["B`@("`@
M("`@("`@("1I9"`](&%R<F%Y7W)E=F5R<V4H)&ED*3L*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@("`@("`@("`@("1V
M86P@/2`D=&AI<RT^7V-O;G9E<G1.86UE*"1V86PI.PH*("`@("`@("`@("`@
M+RH@24Y"3U@@8V%N(&YE=F5R(&)E('5N<W5B<V-R:6)E9"!T;R`H:68@:6X@
M;6%I;"!M;V1E*2X@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M=')E95LD=F%L72D@)B8@*"1V86P@(3T@)TE.0D]8)RDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W5N<W5B=FEE=R`]('1R=64["@H@("`@("`@("`@("`@("`@
M)&5L="`]("8D=&AI<RT^7W1R965;)'9A;%T["@H@("`@("`@("`@("`@("`@
M+RH@1&\@;F]T(&1E;&5T92!F<F]M('1R964@:68@=&AE<F4@87)E(&-H:6QD
M(&5L96UE;G1S("T*("`@("`@("`@("`@("`@("`J(&EN<W1E860L(&-O;G9E
M<G0@=&\@82!C;VYT86EN97(@96QE;65N="X@*B\*("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]S:&]W=6YS=6(@)B8@)'1H:7,M/FAA<T-H:6QD<F5N
M*"1E;'0I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971#;VYT
M86EN97(H)&5L="P@=')U92D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@+RH@4V5T(&%S('5N<W5B<V-R:6)E9"P@861D('1O('5N<W5B
M<V-R:6)E9"!L:7-T+"!A;F0@<F5M;W9E"B`@("`@("`@("`@("`@("`@*B!F
M<F]M('-U8G-C<FEB960@;&ES="X@*B\*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5T4W5B<V-R:6)E9"@D96QT+"!F86QS92D["B`@("`@("`@("`@("`@
M("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]U;G-U8G-C<FEB960I*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U;G-U8G-C<FEB961;)'9A;%T@/2`Q
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]S=6)S8W)I8F5D6R1V86Q=*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;F]T:&5R(&QE=F5L(&]F
M(&AI97)A<F-H>2!T;R!T:&4@=')E92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&QI<W0@($$@
M;&ES="!O9B!S=&1#;&%S<R!O8FIE8W1S(&EN('1H92!F;W)M870@<F5T=7)N
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@9G)O;2!I;6%P7V=E=&UA
M:6QB;WAE<R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D3&5V96PH)&QI
M<W0I"B`@("!["B`@("`@("`@)&5X<&%N9&%L;"`]("@D=&AI<RT^7VEN:71M
M;V1E("8@24U!4%12145?24Y)5%]&151#2$%,3"D["@H@("`@("`@(&9O<F5A
M8V@@*"1L:7-T(&%S("1V86PI('L*("`@("`@("`@("`@)&5L="`]("1T:&ES
M+3Y?;6%K94UA:6QB;WA4<F5E16QT*"1V86PI.PH*("`@("`@("`@("`@)'!A
M<F5N="`]("1E;'1;)W`G73L*("`@("`@("`@("`@)'1H:7,M/E]I;G-E<G1%
M;'0H)&5L="D["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64[
M"@H@("`@("`@("`@("!I9B`H)&5X<&%N9&%L;"!\?"`D=&AI<RT^:7-/<&5N
M*"1E;'0I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^97AP86YD*"1E;'1;
M)W8G72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-O
M<G0@=&AE(&QI<W0N("HO"B`@("`@("`@:68@*"%E;7!T>2@D;&ES="D@)B8*
M("`@("`@("`@("`@(65M<'1Y*"1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$1I<V-O=F5R960H)'1H:7,M/E]T
M<F5E6R1P87)E;G1=+"!T<G5E*3L*("`@("`@("`@("`@:68@*&-O=6YT*"1T
M:&ES+3Y?<&%R96YT6R1P87)E;G1=*2`^(#$I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5T3F5E9%-O<G0H)'1H:7,M/E]T<F5E6R1P87)E;G1=+"!T
M<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!A;B!A='1R:6)U=&4@9F]R(&%N(&5L96UE;G0N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("8D96QT("`@("!4:&4@=')E92!E;&5M96YT+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-O;G-T("!4:&4@8V]N<W1A;G0@=&\@<V5T+W)E;6]V
M92!F<F]M('1H92!B:71M87-K+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O
M;VP@("!3:&]U;&0@=&AE(&%T=')I8G5T92!B92!S970_"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]S971!='1R:6)U=&4H)B1E;'0L("1C;VYS="P@)&)O;VPI
M"B`@("!["B`@("`@("`@:68@*"1B;V]L*2!["B`@("`@("`@("`@("1E;'1;
M)V$G72!\/2`D8V]N<W0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&5L=%LG82==("8]('XD8V]N<W0["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1&]E<R!T:&4@96QE;65N="!H879E(&%N>2!A8W1I=F4@8VAI
M;&1R96X_"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E
M92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I9B!T:&4@96QE;65N="!H87,@86-T:79E(&-H:6QD<F5N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!H87-#:&EL9')E;B@D96QT*0H@("`@>PH@("`@("`@
M('-T871I8R`D:&%S0VAI;&1R96Y#86-H92`](&%R<F%Y*"D["@H@("`@("`@
M("1I<U]N<R`]("1T:&ES+3YI<TYA;65S<&%C92@D96QT*3L*"B`@("`@("`@
M+RH@1&]N)W0@9&\@=&AE(&9O;&QO=VEN9R!I9B!W92!A<F4@9&5A;&EN9R!W
M:71H(&$@;F%M97-P86-E"B`@("`@("`@("H@8V]N=&%I;F5R+B`J+PH@("`@
M("`@(&EF("@A)&ES7VYS*2!["B`@("`@("`@("`@("\J($YO="!A;&P@24U!
M4"!S97)V97)S('-U<'!O<G0@=&AE($A!4T-(24Q$4D5.(&9L86<@*&QI:V4@
M55<A*2!S;PH@("`@("`@("`@("`@*B!W92!N965D('1O('-K:7`@=&AI<R!C
M:&5C:R!I9B!T:&4@24U!4"!S97)V97(@9&]E<VXG="!S970*("`@("`@("`@
M("`@("H@96ET:&5R($A!4T-(24Q$4D5.(&]R($A!4TY/0TA)3$1214XN("HO
M"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]C:&EL9')E;G-U<'!O
M<G0I('Q\"B`@("`@("`@("`@("`@("`H:7-?;G5L;"@D=&AI<RT^7V-H:6QD
M<F5N<W5P<&]R="D@)B8*("`@("`@("`@("`@("`@("`H)&5L=%LG82==("8@
M3$%45%](05-#2$E,1%)%3BD@?'P*("`@("`@("`@("`@("`@("`H)&5L=%LG
M82==("8@3$%45%](05-.3T-(24Q$4D5.*2DI('L*("`@("`@("`@("`@("`@
M("1R970@/2`H)&5L=%LG82==("8@3$%45%](05-#2$E,1%)%3BD["@H@("`@
M("`@("`@("`@("`@+RH@0TA%0TLZ($EF('=E(&%R92!V:65W:6YG(&%L;"!F
M;VQD97)S+"!A;F0@=&AE<F4@:7,@82!F;VQD97(*("`@("`@("`@("`@("`@
M("`J(&QI<W1E9"!A<R!E>'!A;F1E9"!B=70@:70@9&]E<R!N;W0@8V]N=&%I
M;B!A;GD@8VAI;&1R96XL"B`@("`@("`@("`@("`@("`@*B!T:&5N('=E('-H
M;W5L9"!R96UO=F4@:70@9G)O;2!T:&4@97AP86YD960@;&ES="!S:6YC92!I
M=`H@("`@("`@("`@("`@("`@("H@9&]E<VXG="!E>&ES="!A;GEM;W)E+B`J
M+PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B("8F("$D
M<F5T*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;FET17AP86YD
M961,:7-T*"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7V5X<&%N9&5D6R1E;'1;)W8G75TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5M;W9E17AP86YD961,:7-T*"1E;'1;)W8G72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D=&AI
M<RT^7W1R965;)&5L=%LG=B==72P@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H
M(21R970I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@268@=V4@87)E
M('9I97=I;F<@86QL(&5L96UE;G1S("AS=6)S8W)I8F5D(&%N9"!U;G-U8G-C
M<FEB960I"B`@("`@("`@("`@("`@("`@*B!A;F0@=V4@<F5A8V@@=&AI<R!P
M;VEN="!W92!K;F]W('1H870@=&AE<F4@;75S="!B92!V:65W86)L90H@("`@
M("`@("`@("`@("`@("H@8VAI;&1R96X@<V\@<F5T=7)N('1R=64N("HO"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@0V%C:&4@<F5S
M=6QT<R!F<F]M(&)E;&]W('-I;F-E+"!M;W-T(&QI:V5L>2!I9B!W92!G970@
M=&AI<R!F87(L"B`@("`@("`@("H@=&AI<R!C;V1E('=I;&P@8F4@86-C97-S
M960@<V5V97)A;"!T:6UE<R!I;B!T:&4@8W5R<F5N="!R97%U97-T+B`J+PH@
M("`@("`@(&EF("AI<W-E="@D:&%S0VAI;&1R96Y#86-H95LD96QT6R=V)UU=
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&AA<T-H:6QD<F5N0V%C:&5;)&5L
M=%LG=B==73L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E(')E86-H('1H
M:7,@<&]I;G0L('1H96X@=V4@87)E(&5I=&AE<B!I;B!S=6)S8W)I8F4M;VYL
M>2!M;V1E"B`@("`@("`@("H@;W(@=V4@87)E(&1E86QI;F<@=VET:"!A(&YA
M;65S<&%C92!C;VYT86EN97(N($-H96-K(&9O<B!T:&4*("`@("`@("`@*B!E
M>&ES=&5N8V4@;V8@86YY('-U8G-C<FEB960@;6%I;&)O>&5S(&)E;&]W('1H
M92!C=7)R96YT(&YO9&4N("HO"B`@("`@("`@)'1H:7,M/E]I;FET4W5B<V-R
M:6)E9"@I.PH@("`@("`@("1F;VQD97)?;&ES="`]("1T:&ES+3Y?<W5B<V-R
M:6)E9#L*("`@("`@("!I9B`H)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@
M("`@("`@)'1H:7,M/E]I;FET56YS=6)S8W)I8F5D*"D["B`@("`@("`@("`@
M("1F;VQD97)?;&ES="`K/2`D=&AI<RT^7W5N<W5B<V-R:6)E9#L*("`@("`@
M("!]"B`@("`@("`@)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D
M96QT6R=V)UTI.PH@("`@("`@(&EF("@A:7-?;G5L;"@D;G-?:6YF;RDI('L*
M("`@("`@("`@("`@)'-E87)C:%]S='(@/2`D96QT6R=V)UT@+B`D;G-?:6YF
M;ULG9&5L:6UI=&5R)UT["B`@("`@("`@("`@(&EF("@H)&5L=%LG=B==(#T]
M("=)3D)/6"<I("8F"B`@("`@("`@("`@("`@("`H)&YS7VEN9F];)VYA;64G
M72`]/2`H)TE.0D]8)R`N("1N<U]I;F9O6R=D96QI;6ET97(G72DI*2!["B`@
M("`@("`@("`@("`@("`D<V5A<F-H7W-T<B`N/2`D;G-?:6YF;ULG;F%M92==
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME
M>7,H)&9O;&1E<E]L:7-T*2!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1V86PL("1S96%R8VA?<W1R*2`]/3T@,"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:&%S0VAI;&1R96Y#86-H95LD96QT6R=V
M)UU=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@1&\@;VYE(&9I;F%L(&-H96-K(&EF('1H:7,@:7,@82!N86UE
M<W!A8V4@8V]N=&%I;F5R("T@:68@=V4@9V5T"B`@("`@("`@("H@=&AI<R!F
M87(L(&%N9"!A<F4@=FEE=VEN9R!A;&P@9F]L9&5R<RP@=&AE;B!W92!K;F]W
M('=E(&AA=F4@;F\*("`@("`@("`@*B!C:&EL9')E;B!S;R!M86ME('-U<F4@
M=&AE(&5L96UE;G0@:7,@;F]T('-E="!T;R!E>'!A;F1E9"]O<&5N+B`J+PH@
M("`@("`@(&EF("@D:7-?;G,@)B8@)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@
M("`@("`@("`@)'1H:7,M/E]I;FET17AP86YD961,:7-T*"D["B`@("`@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]E>'!A;F1E9%LD96QT6R=V)UU=*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%>'!A;F1E9$QI<W0H
M)&5L=%LG=B==*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D
M=&AI<RT^7W1R965;)&5L=%LG=B==72P@9F%L<V4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D:&%S0VAI;&1R96Y#86-H95LD96QT6R=V
M)UU=(#T@9F%L<V4["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('1H92!C:&EL9')E;B!A='1R:6)U=&4@9F]R(&%N
M(&5L96UE;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("!!('1R964@96QE;65N="X*
M("`@("`J($!P87)A;2!M:7AE9"`D8F]O;"`@5&AE('-E='1I;F<N($EF(&YU
M;&PL(&-L96%R<R!T:&4@9FQA9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=$-H:6QD<F5N*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("!I9B`H:7-?
M;G5L;"@D8F]O;"DI('L*("`@("`@("`@("`@)'1H:7,M/E]S971!='1R:6)U
M=&4H)&5L="P@3$%45%](05-#2$E,1%)%3BP@9F%L<V4I.PH@("`@("`@("`@
M("`D=&AI<RT^7W-E=$%T=')I8G5T92@D96QT+"!,05147TA!4TY/0TA)3$12
M14XL(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-E=$%T=')I8G5T92@D96QT+"!,05147TA!4T-(24Q$4D5.+"`D8F]O
M;"D["B`@("`@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E;'0L($Q!
M5%1?2$%33D]#2$E,1%)%3BP@(21B;V]L*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!(87,@=&AE('1R964@96QE;65N="!B965N(&1I<V-O
M=F5R960_"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E
M92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@3F]N
M+7IE<F\@:68@=&AE(&5L96UE;G0@:&%S(&)E96X@9&ES8V]V97)E9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-$:7-C;W9E<F5D*"1E;'0I"B`@("!["B`@
M("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%7T5,5%])4U]$25-#
M3U9%4D5$.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!D:7-C;W9E
M<F5D(&%T=')I8G5T92!F;W(@86X@96QE;65N="X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1E
M;'0@("`@02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M8F]O;"`@5&AE('-E='1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971$
M:7-C;W9E<F5D*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^
M7W-E=$%T=')I8G5T92@D96QT+"!)34%05%)%15]%3%1?25-?1$E30T]615)%
M1"P@)&)O;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE('1R964@
M96QE;65N="!O<&5N/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT
M("!!('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1R=64@:68@=&AE(&5L96UE;G0@:7,@;W!E;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-/<&5N*"1E;'0I"B`@("!["B`@("`@("`@:68@*"$D=&AI
M<RT^7VEN:71M;V1E*2!["B`@("`@("`@("`@(')E='5R;B`H*"1E;'1;)V$G
M72`F($E-05!44D5%7T5,5%])4U]/4$5.*2`F)B`D=&AI<RT^:&%S0VAI;&1R
M96XH)&5L="DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('-W:71C
M:"`H)'1H:7,M/E]G971);FET17AP86YD961-;V1E*"DI('L*("`@("`@("`@
M("`@8V%S92!)34%05%)%15]/4$5.7TY/3D4Z"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@24U!4%12145?3U!%3E]!3$PZ"B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92!)34%05%)%15]/4$5.7U5315(Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEN:71%>'!A;F1E9$QI<W0H*3L*("`@("`@("`@("`@("`@(')E
M='5R;B`A96UP='DH)'1H:7,M/E]E>'!A;F1E9%LD96QT6R=V)UU=*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!O<&5N(&%T=')I8G5T92!F
M;W(@86X@96QE;65N="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@("`@02!T<F5E(&5L
M96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O;"`@5&AE('-E='1I
M;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971/<&5N*"8D96QT+"`D8F]O
M;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$%T=')I8G5T92@D96QT+"!)
M34%05%)%15]%3%1?25-?3U!%3BP@)&)O;VPI.PH@("`@("`@(&EF("@A)'1H
M:7,M/E]I;FET;6]D92D@>PH@("`@("`@("`@("`D=&AI<RT^7VEN:71%>'!A
M;F1E9$QI<W0H*3L*("`@("`@("`@("`@:68@*"1B;V]L*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%D9$5X<&%N9&5D3&ES="@D96QT6R=V)UTI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R
M96UO=F5%>'!A;F1E9$QI<W0H)&5L=%LG=B==*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H:7,@96QE;65N
M="!A(&-O;G1A:6YE<B!O;FQY+"!N;W0@82!M86EL8F]X("AM96%N:6YG('EO
M=2!C86X*("`@("`J(&YO="!O<&5N(&ET*3\*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4<G5E(&EF('1H92!E;&5M96YT(&ES(&$@8V]N
M=&%I;F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T-O;G1A:6YE<B@D96QT
M*0H@("`@>PH@("`@("`@(')E='5R;B`H*"1E;'1;)V$G72`F($Q!5%1?3D]3
M14Q%0U0I('Q\"B`@("`@("`@("`@("`@("`H(21T:&ES+3Y?<VAO=W5N<W5B
M("8F"B`@("`@("`@("`@("`@("`@(21T:&ES+3YI<U-U8G-C<FEB960H)&5L
M="D@)B8*("`@("`@("`@("`@("`@("`D=&AI<RT^:&%S0VAI;&1R96XH)&5L
M="DI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@96QE;65N="!A
M<R!A(&-O;G1A:6YE<C\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@("`@02!T<F5E(&5L
M96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O;"`@27,@=&AE(&5L
M96UE;G0@82!C;VYT86EN97(_"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971#
M;VYT86EN97(H)B1E;'0L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<V5T071T<FEB=71E*"1E;'0L($Q!5%1?3D]314Q%0U0L("1B;V]L*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($ES('1H92!U<V5R('-U8G-C<FEB960@=&\@
M=&AI<R!E;&5M96YT/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT
M("!!('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1R=64@:68@=&AE('5S97(@:7,@<W5B<V-R:6)E9"!T;R!T:&4@96QE
M;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-3=6)S8W)I8F5D*"1E;'0I
M"B`@("!["B`@("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%7T5,
M5%])4U]354)30U))0D5$.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H
M92!S=6)S8W)I<'1I;VX@<W1A='5S(&9O<B!A;B!E;&5M96YT+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`F)&5L="`@("!!('1R964@96QE;65N="X*("`@("`J($!P87)A;2!B
M;V]L96%N("1B;V]L("!)<R!T:&4@96QE;65N="!S=6)S8W)I8F5D('1O/PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4W5B<V-R:6)E9"@F)&5L="P@)&)O
M;VPI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@
M24U!4%12145?14Q47TE37U-50E-#4DE"140L("1B;V]L*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($ES('1H92!E;&5M96YT(&$@;F%M97-P86-E(&-O;G1A
M:6YE<C\*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&5L="`@02!T<F5E
M(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4<G5E
M(&EF('1H92!E;&5M96YT(&ES(&$@;F%M97-P86-E(&-O;G1A:6YE<C\*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-.86UE<W!A8V4H)&5L="D*("`@('L*("`@
M("`@("!R971U<FX@)&5L=%LG82==("8@24U!4%12145?14Q47TY!34534$%#
M13L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!T:&4@<V5R=F5R('-T
M<FEN9R!F<F]M('1H92`G;F%M92<@<&%R86UE=&5R+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@
M<W1D0VQA<W,@)&]B("!!;B!O8FIE8W0@<F5T=7)N960@9G)O;0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM87!?9V5T;6%I;&)O>&5S
M*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@5&AE(&]B:F5C
M="!R971U<FYE9"!W:71H('1H92!S97)V97(@<W1R:6YG('-T<FEP<&5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("!F<F]M('1H92`G;F%M92<@<&%R86UE
M=&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5M;W9E4V5R=F5R4W1R:6YG
M*"1O8BD*("`@('L*("`@("`@("`D;V(M/F9U;&Q397)V97)0871H(#T@)&]B
M+3YN86UE.PH@("`@("`@("1O8BT^;F%M92`]("1T:&ES+3Y?8V]N=F5R=$YA
M;64H<W5B<W1R*"1O8BT^;F%M92P@<W1R<&]S*"1O8BT^;F%M92P@)WTG*2`K
M(#$I*3L*("`@("`@("!R971U<FX@)&]B.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26YI=&EA;&EZ92!T:&4@97AP86YD960@9F]L9&5R(&QI<W0N"B`@("`@
M*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!
M4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:71%>'!A
M;F1E9$QI<W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?97AP86YD960@/2!A
M<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&%N(&5L96UE;G0@
M=&\@=&AE(&5X<&%N9&5D(&QI<W0N"B`@("`@*B!42$E3($U%5$A/1"!32$]5
M3$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@
M*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&5L96UE;G0@;F%M
M92!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1%>'!A;F1E
M9$QI<W0H)&ED*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E
M(&%N(&5L96UE;G0@9G)O;2!T:&4@97AP86YD960@;&ES="X*("`@("`J(%1(
M25,@34542$]$(%-(3U5,1"!"12!$149)3D5$($E.($%,3"!354)#3$%34T53
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4
M:&4@96QE;65N="!N86UE('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W)E;6]V945X<&%N9&5D3&ES="@D:60I"B`@("!["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!);FET:6%L:7IE+V=E="!T:&4@;&ES="!O9B!E;&5M96YT
M<R!T;R!P;VQL+@H@("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%($1%1DE.
M140@24X@04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@96QE
M;65N=',@=&\@<&]L;"`H;F%M92!I;B!K97D@9FEE;&0I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9710;VQL3&ES="@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]P;VQL(#T@87)R87DH*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]P;VQL
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&5L96UE;G0@=&\@=&AE('!O
M;&P@;&ES="X*("`@("`J(%1(25,@34542$]$(%-(3U5,1"!"12!$149)3D5$
M($E.($%,3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:60@(%1H92!E;&5M96YT(&YA
M;64@;W(@82!L:7-T(&]F(&5L96UE;G0@;F%M97,@=&\@861D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9&10;VQL3&ES="@D:60I"B`@("!["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F4@96QE;65N="!F<F]M('1H92!P;VQL(&QI
M<W0N"B`@("`@*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!
M3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&9O;&1E<B]M86EL8F]X
M(&]R(&$@;&ES="!O9B!F;VQD97)S+VUA:6QB;WAE<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5M;W9E4&]L;$QI<W0H)&ED*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&]E<R!T:&4@=7-E<B!W86YT('1O('!O;&P@=&AI<R!M86EL8F]X(&9O
M<B!N97<O=6YS965N(&UE<W-A9V5S/PH@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D96QT("!!('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1R=64@:68@=&AE('5S97(@=V%N=',@=&\@<&]L;"!T
M:&4@96QE;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-0;VQL960H)&5L
M="D*("`@('L*("`@("`@("!R971U<FX@)&5L=%LG82==("8@24U!4%12145?
M14Q47TE37U!/3$Q%1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@
M<&]L;&5D(&%T=')I8G5T92!F;W(@86X@96QE;65N="X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)B1E;'0@("`@02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D8F]O;"`@5&AE('-E='1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M9710;VQL960H)B1E;'0L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<V5T071T<FEB=71E*"1E;'0L($E-05!44D5%7T5,5%])4U]03TQ,140L("1B
M;V]L*3L*("`@('T*"B`@("`O*BH*("`@("`J($9L86<@=&AE(&5L96UE;G0@
M87,@;F5E9&EN9R!I=',@8VAI;&1R96X@=&\@8F4@<V]R=&5D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`F)&5L="`@("!!('1R964@96QE;65N="X*("`@("`J($!P87)A;2!B
M;V]L96%N("1B;V]L("!4:&4@<V5T=&EN9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-E=$YE9613;W)T*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D
M=&AI<RT^7W-E=$%T=')I8G5T92@D96QT+"!)34%05%)%15]%3%1?3D5%1%]3
M3U)4+"`D8F]O;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;V5S('1H:7,@
M96QE;65N="=S(&-H:6QD<F5N(&YE960@<V]R=&EN9S\*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4<G5E(&EF('1H92!C:&EL9')E;B!N
M965D('1O(&)E('-O<G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7VYE9613
M;W)T*"1E;'0I"B`@("!["B`@("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-
M05!44D5%7T5,5%].145$7U-/4E0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)
M;FET:6%L:7IE('1H92!L:7-T(&]F('-U8G-C<FEB960@;6%I;&)O>&5S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?:6YI=%-U8G-C<FEB960H*0H@("`@>PH@("`@("`@(&EF("AI<U]N
M=6QL*"1T:&ES+3Y?<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]C:&%N9V5D(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]S=6)S8W)I
M8F5D(#T@87)R87DH*3L*("`@("`@("`@("`@)'-U8FQI<W0@/2!A<G)A>2@I
M.PH*("`@("`@("`@("`@+RH@24Y"3U@@:7,@86QW87ES('-U8G-C<FEB960@
M=&\@:68@=V4@87)E(&EN(&UA:6P@;6]D92X@*B\*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?;6]D92`]/2!)34%05%)%15]-3T1%7TU!24PI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W5B<V-R:6)E9%LG24Y"3U@G72`](#$["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VYA;65S<&%C
M97,I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;F%M97-P
M86-E<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]($!I
M;6%P7VQS=6(H)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(L
M("1V86Q;)VYA;64G72`N("<J)RD["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W5B
M;&ES="`](&%R<F%Y7VUE<F=E*"1S=6)L:7-T+"`D=&UP*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<W5B;&ES="`]($!I;6%P7VQS=6(H
M)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(L("1T:&ES+3Y?
M<')E9FEX("X@)RHG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D<W5B;&ES="DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1S=6)L:7-T(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-U8G-C<FEB961;<W5B<W1R*"1V86PL('-T<G!O<R@D=F%L+"`G?2<I
M("L@,2E=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI>F4@=&AE
M(&QI<W0@;V8@=6YS=6)S8W)I8F5D(&UA:6QB;WAE<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:715
M;G-U8G-C<FEB960H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES
M+3Y?=6YS=6)S8W)I8F5D*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG
M960@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7VEN:713=6)S8W)I8F5D
M*"D["B`@("`@("`@("`@("1T:&ES+3Y?=6YS=6)S8W)I8F5D(#T@87)R87DH
M*3L*("`@("`@("`@("`@)&%L;%]L:7-T(#T@87)R87DH*3L*"B`@("`@("`@
M("`@("\J($=E="!L:7-T(&]F(&%L;"!M86EL8F]X97,N("HO"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7VYA;65S<&%C97,I('L*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?;F%M97-P86-E<R!A<R`D=F%L*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1M<"`]($!I;6%P7VQI<W0H)'1H:7,M/E]G9713
M=')E86TH*2P@)'1H:7,M/E]S97)V97(L("1V86Q;)VYA;64G72`N("<J)RD[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&UP*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D86QL7VQI<W0@/2!A<G)A>5]M97)G92@D
M86QL7VQI<W0L("1T;7`I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1A;&Q?;&ES="`]($!I;6%P7VQI<W0H)'1H:7,M/E]G9713=')E86TH
M*2P@)'1H:7,M/E]S97)V97(L("1T:&ES+3Y?<')E9FEX("X@)RHG*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D86QL7VQI<W0I
M*2!["B`@("`@("`@("`@("`@("`O*B!&:6YD(&%L;"!M86EL8F]X97,@=&AA
M="!A<F5N)W0@:6X@=&AE('-U8G-C<FEB960@;&ES="X@*B\*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1A;&Q?;&ES="!A<R`D=F%L*2!["B`@("`@("`@
M("`@("`@("`@("`@)'9A;"`]('-U8G-T<B@D=F%L+"!S=')P;W,H)'9A;"P@
M)WTG*2`K(#$I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]S=6)S8W)I8F5D6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W5N<W5B<V-R:6)E9%LD=F%L72`](#$["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4VAO=6QD('=E(&5X
M<&%N9"!A;&P@96QE;65N=',_"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&%N
M9$%L;"@I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)E;G1;
M;G5L;%T@87,@)'9A;"D@>PH@("`@("`@("`@("`D=&AI<RT^97AP86YD*"1V
M86PL('1R=64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-H
M;W5L9"!W92!C;VQL87!S92!A;&P@96QE;65N=',_"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O;&QA<'-E06QL*"D*("`@('L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W1R964@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF
M("@D:V5Y("$]($E-05!44D5%7T)!4T5?14Q4*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^8V]L;&%P<V4H)'9A;%LG=B==*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@0VQE87(@86QL(&5N=')I97,@9G)O;2!T
M:&4@97AP86YD960@;&ES="X@*B\*("`@("`@("`D=&AI<RT^7VEN:71%>'!A
M;F1E9$QI<W0H*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5X<&%N9&5D
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D=&AI<RT^7W)E;6]V
M945X<&%N9&5D3&ES="@D:V5Y*3L*("`@("`@("!]"@H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!L:7-T(&]F(&UA:6QB;WAE<R!I;B!T:&4@
M;F5X="!L979E;"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&-U<G)E;G0@;6%I
M;&)O>"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@
M;6%I;&)O>"!O8FIE8W1S(&]R('1H92!E;7!T>2!L:7-T+@H@("`@("H@("`@
M("`@("`@("`@("`@4V5E(%]G971,:7-T*"D@9F]R(&9O<FUA="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-H:6QD<F5N26YF;R@D:60I"B`@("!["B`@("`@
M("`@)&EN9F\@/2!A<G)A>2@I.PH@("`@("`@("1N<U]I;F9O(#T@)'1H:7,M
M/E]G971.86UE<W!A8V4H)&ED*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)&YS
M7VEN9F\I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;SL*("`@("`@("!]
M"@H@("`@("`@(&EF("@H)&ED(#T]("=)3D)/6"<I("8F"B`@("`@("`@("`@
M("@D;G-?:6YF;ULG;F%M92==(#T]("@G24Y"3U@G("X@)&YS7VEN9F];)V1E
M;&EM:71E<B==*2DI('L*("`@("`@("`@("`@)'-E87)C:"`]("1I9"`N("1N
M<U]I;F9O6R=D96QI;6ET97(G72`N("1N<U]I;F9O6R=N86UE)UT["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'-E87)C:"`]("1I9"`N("1N<U]I
M;F9O6R=D96QI;6ET97(G73L*("`@("`@("!]"@H@("`@("`@("1I;F9O(#T@
M)'1H:7,M/E]G971,:7-T*"1S96%R8V@@+B`G)2<I.PH*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]T<F5E6R1I9%TI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<V5T0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1I9%TL("%E;7!T>2@D:6YF
M;RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4W=I=&-H('-U8G-C<FEB960O=6YS=6)S8W)I8F5D
M('9I97=I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5N<W5B
M("!3:&]W('5N<W5B<V-R:6)E9"!E;&5M96YT<S\*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VAO=U5N<W5B<V-R:6)E9"@D=6YS=6(I"B`@("!["B`@("`@("`@
M:68@*"1U;G-U8B`]/3T@)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S:&]W=6YS
M=6(@/2`D=6YS=6(["B`@("`@("`@)'1H:7,M/E]C:&%N9V5D(#T@=')U93L*
M"B`@("`@("`@+RH@268@=V4@87)E('-W:71C:&EN9R!F<F]M('5N<W5B<V-R
M:6)E9"!T;R!S=6)S8W)I8F5D+"!N;R!N965D"B`@("`@("`@("H@=&\@9&\@
M86YY=&AI;F<@*'=E(&IU<W0@:6=N;W)E('5N<W5B<V-R:6)E9"!S='5F9BDN
M("HO"B`@("`@("`@:68@*"1U;G-U8B`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@87)E('-W
M:71C:&EN9R!F<F]M('-U8G-C<FEB960@=&\@=6YS=6)S8W)I8F5D+"!W92!N
M965D"B`@("`@("`@("H@=&\@861D(&%L;"!U;G-U8G-C<FEB960@96QE;65N
M=',@=&AA="!L:79E(&EN(&-U<G)E;G1L>0H@("`@("`@("`J(&1I<V-O=F5R
M960@:71E;7,N("HO"B`@("`@("`@)'1H:7,M/E]U;G-U8G9I97<@/2!T<G5E
M.PH@("`@("`@("1T:&ES+3Y?:6YI=%5N<W5B<V-R:6)E9"@I.PH@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W5N<W5B<V-R:6)E9"DI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;FET;6]D
M92`]($E-05!44D5%7TE.251?54Y354(["B`@("`@("`@)'1H:7,M/FEN<V5R
M="AA<G)A>5]K97ES*"1T:&ES+3Y?=6YS=6)S8W)I8F5D*2D["B`@("`@("`@
M)'1H:7,M/E]I;FET;6]D92`](#`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@<F5F97)E;F-E('1O(&$@8W5R<F5N=&QY(&]P96X@24U!4"!S
M=')E86TN"B`@("`@*B!42$E3($U%5$A/1"!-55-4($)%($1%1DE.140@24X@
M04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R
M;B!R97-O=7)C92`@06X@24U!4"!R97-O=7)C92!S=')E86TN"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9?9V5T4W1R96%M*"D*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C
M=7)R96YT;'D@<V5L96-T960@:6YI=&EA;&EZ871I;VX@97AP86YD960@;6]D
M92X*("`@("`J(%1(25,@34542$]$(%-(3U5,1"!"12!$149)3D5$($E.($%,
M3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE(&-U<G)E;G0@:6YI=&EA;&EZ871I;VX@97AP86YD960@
M;6]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$EN:71%>'!A;F1E9$UO
M9&4H*0H@("`@>PH@("`@("`@(')E='5R;B!)34%05%)%15]/4$5.7TY/3D4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@:6YF;W)M871I;VX@86)O=70@
M;F5W+W5N<V5E;B]T;W1A;"!M97-S86=E<R!F;W(@=&AE(&=I=F5N(&5L96UE
M;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&5L
M96UE;G0@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A
M>2!W:71H('1H92!F;VQL;W=I;F<@9FEE;&1S.@H@("`@("H@/'!R93X*("`@
M("`J("=M97-S86=E<R<@("TM("!.=6UB97(@;V8@=&]T86P@;65S<V%G97,N
M"B`@("`@*B`G;F5W;7-G)R`@("`M+2`@3G5M8F5R(&]F(&YE=R!M97-S86=E
M<RX*("`@("`J("=U;G-E96XG("`@("TM("!.=6UB97(@;V8@=6YS965N(&UE
M<W-A9V5S+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$5L96UE;G1);F9O*"1N86UE*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2!A
M<G)A>2@I.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TE-05`O0V%C
M:&4N<&AP)SL*("`@("`@("`D:6UA<%]C86-H92`]("9)34%07T-A8VAE.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`D<W1S(#T@)&EM87!?8V%C:&4M/F=E=%-T
M871U<R@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D=&AI<RT^7W-E<G9E<B`N("1N
M86UE*3L*("`@("`@("!I9B`H(65M<'1Y*"1S=',I*2!["B`@("`@("`@("`@
M("1S=&%T=7-;)VUE<W-A9V5S)UT@/2`D<W1S+3YM97-S86=E<SL*("`@("`@
M("`@("`@)'-T871U<ULG=6YS965N)UT@/2!I<W-E="@D<W1S+3YU;G-E96XI
M(#\@)'-T<RT^=6YS965N(#H@,#L*("`@("`@("`@("`@)'-T871U<ULG;F5W
M;7-G)UT@/2!I<W-E="@D<W1S+3YR96-E;G0I(#\@)'-T<RT^<F5C96YT(#H@
M,#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V]R=',@82!L:7-T(&]F(&UA:6QB;WAE<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)B1M8F]X("`@5&AE(&QI<W0@;V8@;6%I;&)O>&5S('1O('-O
M<G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F%S92`@07)E('=E('-O<G1I
M;F<@82!L:7-T(&]F(&UA:6QB;WAE<R!I;B!T:&4@8F%S90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&]F('1H92!T<F5E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<V]R=$QI<W0H)B1M8F]X+"`D8F%S92`](&9A;'-E*0H@("`@
M>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?:6UA<%]S;W)T*2D@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TE-05`O4V]R="YP:'`G
M.PH@("`@("`@("`@("`D=&AI<RT^7VEM87!?<V]R="`]("9N97<@24U!4%]3
M;W)T*"1T:&ES+3Y?9&5L:6UI=&5R*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@D8F%S92D@>PH@("`@("`@("`@("!F;W)E86-H("@D;6)O>"!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("`D8F%S97-O<G1;)'9A;%T@/2`H)'9A;"`]
M/2`G24Y"3U@G*2`_("=)3D)/6"<@.B`D=&AI<RT^7W1R965;)'9A;%U;)VPG
M73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VEM87!?<V]R
M="T^<V]R=$UA:6QB;WAE<R@D8F%S97-O<G0L("@D=&AI<RT^7VUO9&4@/3T@
M24U!4%12145?34]$15]-04E,*2P@=')U92P@=')U92D["B`@("`@("`@("`@
M("1M8F]X(#T@87)R87E?:V5Y<R@D8F%S97-O<G0I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?:6UA<%]S;W)T+3YS;W)T36%I;&)O
M>&5S*"1M8F]X+"`H)'1H:7,M/E]M;V1E(#T]($E-05!44D5%7TU/1$5?34%)
M3"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A
M($YO;BU)34%0(&UA:6QB;W@@96QE;65N="!G:79E;B!A;B!E;&5M96YT(&ED
M96YT:69I97(N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:60@(%1H92!E;&5M96YT(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@02!M86EL8F]X(&5L96UE;G0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]G971.;VY)34%016QT*"1I9"D*("`@('L*("`@("`@("!R
M971U<FX@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H92!G
M:79E;B!E;&5M96YT(&%N(")A8W1I=F4B(&5L96UE;G0@*&DN92X@86X@96QE
M;65N="!T:&%T('-H;W5L9`H@("`@("H@8F4@=V]R:V5D('=I=&@@9VEV96X@
M=&AE(&-U<G)E;G0@=FEE=VEN9R!P87)A;65T97)S*2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF(&ET(&ES(&%N(&%C=&EV92!E;&5M96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?86-T:79E16QT*"1E;'0I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B("8F"B`@("`@("`@("`@("1T:&ES
M+3YI<TYA;65S<&%C92@D96QT*2D@>PH@("`@("`@("`@("!R971U<FX@*"1T
M:&ES+3YH87-#:&EL9')E;B@D96QT*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("@D=&AI<RT^7W-H;W=U;G-U8B!\?`H@("`@("`@
M("`@("`@("`@("`@("@D=&AI<RT^:7-3=6)S8W)I8F5D*"1E;'0I("8F("$D
M=&AI<RT^:7-#;VYT86EN97(H)&5L="DI('Q\"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FAA<T-H:6QD<F5N*"1E;'0I*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T(&$@;6%I;&)O>"!N86UE('1O('1H
M92!C;W)R96-T+"!I;G1E<FYA;"!N86UE("AI+F4N(&UA:V4@<W5R90H@("`@
M("H@24Y"3U@@:7,@86QW87ES(&-A<&ET86QI>F5D(&9O<B!)34%0('-E<G9E
M<G,I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!M86EL8F]X(&YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYV97)T960@;F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G9E<G1.86UE*"1N86UE*0H@
M("`@>PH@("`@("`@(')E='5R;B`H*"1T:&ES+3Y?;6]D92`]/2!)34%05%)%
M15]-3T1%7TU!24PI("8F("AS=')C87-E8VUP*"1N86UE+"`G24Y"3U@G*2`]
M/2`P*2D@/R`G24Y"3U@G(#H@)&YA;64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@;F%M97-P86-E(&EN9F\@9F]R(&$@9G5L;"!F;VQD97(@<&%T:"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1M86EL8F]X("!4:&4@9F]L9&5R('!A=&@N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&YA;65S<&%C92!I;F9O(&9O
M<B!T:&4@9F]L9&5R('!A=&@@;W(@;G5L;"!I9B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@('!A=&@@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V=E=$YA;65S<&%C92@D;6%I;&)O>"D*("`@('L*("`@("`@("!S
M=&%T:6,@)&YA;65S<&%C94-A8VAE(#T@87)R87DH*3L*"B`@("`@("`@:68@
M*&ES<V5T*"1N86UE<W!A8V5#86-H95LD;6%I;&)O>%TI*2!["B`@("`@("`@
M("`@(')E='5R;B`D;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VYA;65S<&%C97,I*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;F%M97-P86-E<R!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("@H*"1M86EL8F]X
M("X@)'9A;%LG9&5L:6UI=&5R)UTI(#T]("1K97DI('Q\"B`@("`@("`@("`@
M("`@("`@("`@*"%E;7!T>2@D:V5Y*2`F)B`H<W1R<&]S*"1M86EL8F]X+"`D
M:V5Y*2`]/3T@,"DI*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;65S<&%C
M94-A8VAE6R1M86EL8F]X72`]("1V86P["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65S<&%C97-;)R==
M*2D@>PH@("`@("`@("`@("`@("`@)&YA;65S<&%C94-A8VAE6R1M86EL8F]X
M72`]("1T:&ES+3Y?;F%M97-P86-E<ULG)UT["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]N86UE<W!A8V5S6R<G73L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&YA;65S<&%C94-A8VAE6R1M86EL8F]X72`](&YU;&P[
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("AS=6)S='(H)'1H:7,M/E]P<F5F:7@L("TQ*2`]/2`D
M=&AI<RT^7V1E;&EM:71E<BD@>PH@("`@("`@("`@("`@("`@)&YA;64@/2!S
M=6)S='(H)'1H:7,M/E]P<F5F:7@L(#`L('-T<FQE;B@D=&AI<RT^7W!R969I
M>"D@+2`Q*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1N86UE(#T@)'1H:7,M/E]P<F5F:7@["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&YA;65S<&%C94-A8VAE6R1M86EL8F]X72`](&%R<F%Y*"=D96QI
M;6ET97(G(#T^("1T:&ES+3Y?9&5L:6UI=&5R+"`G;F%M92<@/3X@)&YA;64L
M("=T>7!E)R`]/B`G<&5R<V]N86PG*3L*("`@("`@("`@("`@<F5T=7)N("1N
M86UE<W!A8V5#86-H95LD;6%I;&)O>%T["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1&]E<R!T:&4@24U!4"!S97)V97(@<W5P<&]R="!T:&4@
M)T-(24Q$4D5.)R!)34%0(&5X=&5N<VEO;C\*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D<W5P<&]R="`@5')U92!I9B!T:&4@24U!4"!S97)V97(@
M<W5P<&]R=',@=&AE($-(24Q$4D5."B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@97AT96YS:6]N+"!F86QS92!I9B!I="!D;V5S;B=T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!)34%08VAI;&1R96Y3=7!P;W)T*"1S=7!P;W)T
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VAI;&1R96YS=7!P;W)T(#T@*&)O
M;VPI("1S=7!P;W)T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!S
M=&%R="!P;VEN="!F;W(@9&5T97)M:6YI;F<@96QE;65N="!D:69F97)E;F-E
M<R!V:6$@96QT1&EF9B@I+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S
M+C$*("`@("`J+PH@("`@9G5N8W1I;VX@96QT1&EF9E-T87)T*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7V5L=&1I9F8@/2`D=&AI<RT^7W1R964["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@96QE;65N=',@
M=&AA="!H879E(&-H86YG960@<VEN8V4@;F]D941I9F93=&%R="@I"B`@("`@
M*B!W87,@;&%S="!C86QL960N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E
M(#,N,0H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y('=I
M=&@@=&AE(&9O;&QO=VEN9R!K97ES.@H@("`@("H@/'!R93X*("`@("`J("=A
M)R`]/B!!(&QI<W0@;V8@96QE;65N=',@=&AA="!H879E(&)E96X@861D960N
M"B`@("`@*B`G8R<@/3X@02!L:7-T(&]F(&5L96UE;G1S('1H870@:&%V92!B
M965N(&-H86YG960N"B`@("`@*B`G9"<@/3X@02!L:7-T(&]F(&5L96UE;G1S
M('1H870@:&%V92!B965N(&1E;&5T960N"B`@("`@*B`\+W!R93X*("`@("`J
M("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@;F\@8VAA;F=E<R!H
M879E(&]C8W5R<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;'1$:69F*"D*
M("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?8VAA;F=E9"!\?"`A)'1H:7,M
M/E]E;'1D:69F*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1A9&1E9"`]("1C:&%N9V5D(#T@)&1E;&5T960@/2!A
M<G)A>2@I.PH*("`@("`@("`O*B!$971E<FUI;F4@=&AE(&1E;&5T960@:71E
M;7,N("HO"B`@("`@("`@)&1E;&5T960@/2!A<G)A>5]V86QU97,H87)R87E?
M9&EF9BAA<G)A>5]K97ES*"1T:&ES+3Y?96QT9&EF9BDL(&%R<F%Y7VME>7,H
M)'1H:7,M/E]T<F5E*2DI.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1R
M964@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]E;'1D:69F6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&%D
M9&5D6UT@/2`D:V5Y.PH@("`@("`@("`@("!](&5L<V5I9B`H)'9A;"`A/2`D
M=&AI<RT^7V5L=&1I9F9;)&ME>5TI('L*("`@("`@("`@("`@("`@("1C:&%N
M9V5D6UT@/2`D:V5Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H96UP='DH)&%D9&5D*2`F)B!E;7!T>2@D8VAA;F=E9"D@)B8@96UP
M='DH)&1E;&5T960I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)V$G(#T^
M("1A9&1E9"P@)V,G(#T^("1C:&%N9V5D+"`G9"<@/3X@)&1E;&5T960I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BHJ*B!$97!R96-A=&5D('9A<FEA8FQE
M<R]F=6YC=&EO;G,N(%1H97-E(')E;6%I;B!F;W(@0D,@;VYL>2X@*BHJ*B\*
M"B`@("`O*BH*("`@("`J(%1H92!P<F5F:7@@=VET:&]U="!A('1R86EL:6YG
M(&1E;&EM:71E<BX*("`@("`J"B`@("`@*B!`9&5P<F5C871E9"!S:6YC92!(
M;W)D92`S+C$*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W!R969I>&YO9&5L:6T@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!S97)V
M97(@<W1R:6YG('5S960@9F]R('1H92!D96QI;6ET97(N"B`@("`@*B!42$E3
M(%-(3U5,1"!"12!3150@24X@159%4ED@4U5"0TQ!4U,@0T].4U1254-43U(N
M"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@<VEN8V4@2&]R9&4@,RXQ"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D96QI;6ET97(@
M/2`G+R<["@H@("`@+RHJ"B`@("`@*B!7:&5R92!W92!S=&%R="!L:7-T:6YG
M(&9O;&1E<G,N"B`@("`@*B!42$E3(%-(3U5,1"!"12!3150@24X@159%4ED@
M4U5"0TQ!4U,@0T].4U1254-43U(N"B`@("`@*@H@("`@("H@0&1E<')E8V%T
M960@<VEN8V4@2&]R9&4@,RXQ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]P<F5F:7@@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!L
M;V-A=&EO;B!O9B!T:&4@9FER<W0@;&5V96P@;V8@9F]L9&5R<R!B96QO=R!T
M:&4@24Y"3U@N"B`@("`@*B!42$E3(%-(3U5,1"!"12!3150@24X@159%4ED@
M4U5"0TQ!4U,@0T].4U1254-43U(N"B`@("`@*@H@("`@("H@0&1E<')E8V%T
M960@<VEN8V4@2&]R9&4@,RXQ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]N86UE<W!A8V4@/2`G)SL*"B`@("`O*BH*("`@("`J(%-H
M;W5L9"!D;W1F:6QE<R!B92!S:&]W;C\*("`@("`J(%1(25,@4TA/54Q$($)%
M(%-%5"!)3B!%5D5262!354)#3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@
M("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?9&]T9FEL97,@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!E>&ES=&5N8V4@;V8@=&AI
M<R!F=6YC=&EO;B!I;B!)34%07U1R964@:6YD:6-A=&5S('1H870@97AT96YD
M960*("`@("`J(&YA;65S<&%C92!S=7!P;W)T(&ES(&%V86EL86)L92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AT96YD961.86UE<W!A8V53=7!P;W)T*"D*
M("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@<')E9FEX+@H@("`@("H*("`@("`J($!D97!R96-A
M=&5D('-I;F-E($AO<F1E(#,N,0H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!P<F5F:7@@=VAE<F4@9F]L9&5R<R!B96=I;B!T;R!B92!L:7-T960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R969I>"@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<')E9FEX.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&EN9F]R;6%T:6]N(&%B;W5T(&$@<W!E8VEF:6,@;6%I;&)O>"X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!D97!R96-A=&5D
M('-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@(%1H92!M86EL8F]X('1O('%U97)Y+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1D0VQA<W,@(%-E92!I;6%P7V=E=&UA:6QB;WAE<R@I+B`@5&AE
M('-E<G9E<B!S=')I;F<@:&%S"B`@("`@*B`@("`@("`@("`@("`@("`@("!A
M;')E861Y(&)E96X@<F5M;W9E9"!F<F]M('1H92`G;F%M92<@<&%R86UE=&5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T36%I;&)O>"@D<&%T:"D*("`@
M('L*("`@("`@("`D8F]X(#T@)'1H:7,M/E]G971,:7-T*"1P871H*3L*("`@
M("`@("!I9B`H96UP='DH)&)O>"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!R97-E
M="@D8F]X*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME
M('-U<F4@=&AE<F4@:7,@;F\@=')A:6QI;F<@9&5L:6UI=&5R(&]N('1H92!E
M;&5M96YT(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&5L96UE;G0@;F%M92X*("`@("`J($!D97!R96-A=&5D('-I;F-E
M($AO<F1E(#,N,0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M96QE;65N="!N86UE('=I=&@@86YY('1R86EL:6YG(&1E;&EM:71E<B!S=')I
M<'!E9`H@("`@("H@("`@("`@("`@("`@("`@(&]F9BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@;F]4<F%I;&EN9T1E;&EM:71E<B@D;F%M92D*("`@('L*("`@
M("`@("`D;G-?:6YF;R`]("1T:&ES+3Y?9V5T3F%M97-P86-E*"1N86UE*3L*
M("`@("`@("!I9B`H<W5B<W1R*"1N86UE+"`M,2D@/3T@)&YS7VEN9F];)V1E
M;&EM:71E<B==*2!["B`@("`@("`@("`@("1N86UE(#T@<W5B<W1R*"1N86UE
M+"`P+"!S=')L96XH)&YA;64I("T@,2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&YA;64["B`@("!]"@H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O5&AR96%D
M+G!H<```````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-30W-@`Q
M,#4Q-30S,3`V,``P,C`V-S8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($E-05!?5&AR96%D('!R;W9I
M9&5S(&9U;F-T:6]N<R!F;W(@=V]R:VEN9R!W:71H(&EM87!?=&AR96%D*"D@
M;W5T<'5T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-05`O5&AR
M96%D+G!H<"QV(#$N-"XQ,"XQ,R`R,#`V+S`Q+S`Q(#(Q.C(X.C(Q(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!C=7)E8V%N=&DN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!C=7)E8V%N=&DN;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!
M4`H@*B\*8VQA<W,@24U!4%]4:')E860@>PH*("`@("\J*@H@("`@("H@:6UA
M<%]T:')E860H*2!O=71P=70N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]T:')E861A<G)A>3L*"B`@("`O*BH*("`@("`J
M($EN=&5R;F%L('1H<F5A9"!D871A('-T<G5C='5R92X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1H<F5A9"`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!I;F1E>"!T;R!-97-S86=E(&EN
M9&5X(&QO;VMU<"!A<G)A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7VQO;VMU<"`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&]B("!/=71P=70@9G)O;2!I;6%P7W1H<F5A9"@I+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!)34%07U1H<F5A9"@D;V(I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]T:')E861A<G)A>2`]("1O8CL*("`@("`@("`D=&AI<RT^7W!R;V-E<W-3
M=')U8W1U<F4H*3L*("`@('T*"B`@("\J*@H@("`@("H@1V5T<R!T:&4@:6YD
M96YT:6]N(&QE=F5L(&9O<B!A;B!)34%0(&UE<W-A9V4@:6YD97@N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@24U!4"!M97-S
M86=E(&EN9&5X+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%)E='5R
M;G,@=&AE('1H<F5A9"!I;F1E;G0@;&5V96P@:68@)&EN9&5X(&9O=6YD+@H@
M("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:')E861);F1E;G0H)&EN9&5X
M*0H@("`@>PH@("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$ME>2@D:6YD97@I
M.PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]T:')E861;)&ME>5U;)VQE=F5L)UTI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T:')E861;)&ME>5U;)VQE
M=F5L)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!B87-E
M('1H<F5A9"!I;F1E>"!F;W(@86X@24U!4"!M97-S86=E(&EN9&5X+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE($E-05`@;65S
M<V%G92!I;F1E>"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U
M<FYS('1H92!B87-E($E-05`@:6YD97@@:68@)&EN9&5X(&ES('!A<G0@;V8@
M80H@("`@("H@("`@("`@("`@("`@("`@=&AR96%D+@H@("`@("H@("`@("`@
M("`@("`@("`@4F5T=7)N<R!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714:')E861"87-E*"1I;F1E>"D*("`@('L*("`@("`@
M("`D:V5Y(#T@)'1H:7,M/E]G971+97DH)&EN9&5X*3L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7W1H<F5A9%LD:V5Y75LG8F%S92==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=&AR96%D6R1K97E=6R=B87-E)UT["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J($ES('1H:7,@:6YD97@@=&AE(&QA<W0@:6X@=&AE
M(&-U<G)E;G0@;&5V96P_"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&EN9&5X("!4:&4@24U!4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF("1I;F1E>"!I<R!T
M:&4@;&%S="!E;&5M96YT(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("!C=7)R96YT('1H<F5A9"!L979E;"X*("`@("`J("`@("`@("`@("`@("`@
M("`@4F5T=7)N<R!F86QS92!I9B!N;W0L(&]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QA<W1);DQE=F5L*"1I;F1E>"D*("`@('L*("`@
M("`@("`D:V5Y(#T@)'1H:7,M/E]G971+97DH)&EN9&5X*3L*("`@("`@("!I
M9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W1H<F5A9%LD:V5Y75LG;&%S="==*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=&AR96%D6R1K97E=6R=L87-T)UT["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1O('1H92!M97-S86=E(&EN9&5X("T^(&%R
M<F%Y(&EN9&5X(&QO;VMU<"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@(%1H92!)
M34%0(&UE<W-A9V4@:6YD97@N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(&%R<F%Y(&EN9&5X('9A;'5E(&]R(&YU;&P@:68@;F\@:6YD97@N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971+97DH)&EN9&5X*0H@("`@>PH@
M("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]L;V]K=7!;)&EN9&5X72DI
M(#\@)'1H:7,M/E]L;V]K=7!;)&EN9&5X72`Z(&YU;&P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE('-O<G1E9"!L:7-T(&]F(&UE<W-A9V5S
M(&EN9&EC97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YE=R`@
M5')U92!F;W(@;F5W97-T(&9I<G-T+"!F86QS92!F;W(@;VQD97-T(&9I<G-T
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!S;W)T960@;&ES
M="!O9B!M97-S86=E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;65S<V%G94QI
M<W0H)&YE=RD*("`@('L*("`@("`@("!R971U<FX@*"1N97<I(#\@87)R87E?
M<F5V97)S92AA<G)A>5]K97ES*"1T:&ES+3Y?;&]O:W5P*2D@.B!A<G)A>5]K
M97ES*"1T:&ES+3Y?;&]O:W5P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&QI<W0@;V8@;65S<V%G97,@:6X@=&AE(&-U<G)E;G0@=&AR
M96%D+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE
M($E-05`@:6YD97@@;V8@=&AE(&-U<G)E;G0@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@24U!4"!M97-S86=E(&EN
M9&EC97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1H<F5A9"@D:6YD97@I
M"B`@("!["B`@("`@("`@+RH@1FEN9"!T:&4@8F5G:6YN:6YG(&]F('1H92!T
M:')E860N("HO"B`@("`@("`@)&)E9VEN(#T@)'1H:7,M/F=E=%1H<F5A9$)A
M<V4H)&EN9&5X*3L*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]G971+97DH)&)E
M9VEN*3L*("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y*2!\?"!E;7!T>2@D8F5G
M:6XI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@D:6YD97@I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@5V]R:R!F;W)W87)D(&9R;VT@=&AE(&9I<G-T
M('1H<F5A9"!E;&5M96YT('1O(&9I;F0@=&AE(&5N9"!O9B!T:&4*("`@("`@
M("`@*B!T:')E860N("HO"B`@("`@("`@)'1H<F5A9%]L:7-T(#T@87)R87DH
M)'1H:7,M/E]T:')E861;)&ME>5U;)VEN9&5X)UTI.PH@("`@("`@('=H:6QE
M("@K*R1K97DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1H
M<F5A9%LD:V5Y72DI('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1C=7)R(#T@)'1H:7,M/E]T:')E861;)&ME
M>5T["B`@("`@("`@("`@(&EF("@D8W5R<ELG8F%S92==(#T]("1B96=I;BD@
M>PH@("`@("`@("`@("`@("`@)'1H<F5A9%]L:7-T6UT@/2`D=&AI<RT^7W1H
M<F5A9%LD:V5Y75LG:6YD97@G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H<F5A9%]L:7-T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4')O8V5S<R!T:&4@;W5T<'5T(&9R;VT@:6UA<%]T:')E860H*2!I
M;G1O(&%N(&EN=&5R;F%L(&1A=&$@<W1R=6-T=7)E+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<')O8V5S
M<U-T<G5C='5R92@I"B`@("!["B`@("`@("`@)&-O;G1A:6YE<B`]("1C;VYT
M86EN97)?8F%S92`]("1L87-T7VEN9&5X(#T@)'1H<F5A9%]B87-E(#T@)'1H
M<F5A9%]B87-E7VED>"`]("!N=6QL.PH@("`@("`@("1I;F1I8V5S(#T@87)R
M87DH*3L*("`@("`@("`D:2`]("1L87-T7VD@/2`D;&5V96P@/2`P.PH*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W1H<F5A9&%R<F%Y(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1K97DL("<N)RD[
M"B`@("`@("`@("`@("1I;F1E>"`]('-U8G-T<B@D:V5Y+"`P+"`D<&]S*3L*
M("`@("`@("`@("`@)'1Y<&4@/2!S=6)S='(H)&ME>2P@)'!O<R`K(#$I.PH*
M("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E
M("=N=6TG.@H@("`@("`@("`@("`@("`@:68@*"1V86P@/3T](#`I('L*("`@
M("`@("`@("`@("`@("`@("`D8V]N=&%I;F5R(#T@)&EN9&5X.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:2LK.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C;VYT86EN97(I("8F
M(&5M<'1Y*"1L979E;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M<F5A9%]B87-E(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M<F5A9%]B87-E7VED>"`]("1I;F1E>#L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V]K=7!;)'9A;%T@/2`D
M:6YD97@["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E861;)&EN
M9&5X72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T
M:')E861;)&EN9&5X75LG:6YD97@G72`]("1V86P["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)VYE>'0G.@H@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1C;VYT86EN
M97(I("8F("@D8V]N=&%I;F5R(#T]/2`D:6YD97@I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-O;G1A:6YE<E]B87-E(#T@)'1H:7,M/E]T:')E861A<G)A
M>5LD=F%L("X@)RYN=6TG73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES7VYU;&PH)&-O;G1A:6YE<BDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]T:')E861;)&EN9&5X75LG8F%S92==(#T@)&-O;G1A
M:6YE<E]B87-E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&AR96%D6R1I;F1E>%U;)V)A
M<V4G72`]("@A96UP='DH)&QE=F5L*2!\?"`H)'9A;"`A/2`P*2D@/R`D=&AR
M96%D7V)A<V4@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D;&5V96PK*SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8G)A;F-H
M)SH*("`@("`@("`@("`@("`@(&EF("@D8V]N=&%I;F5R(#T]/2`D:6YD97@I
M('L*("`@("`@("`@("`@("`@("`@("`D8V]N=&%I;F5R(#T@)&-O;G1A:6YE
M<E]B87-E(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1H
M<F5A9%LD;&%S=%]I;F1E>%U;)VQA<W0G72`]('1R=64["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&AR
M96%D6R1I;F1E>%U;)VQE=F5L)UT@/2`D;&5V96PM+3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W1H<F5A9%LD:6YD97A=6R=L87-T)UT@/2`A*"%I
M<U]N=6QL*"1C;VYT86EN97(I("8F(&5M<'1Y*"1L979E;"DI.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D:6YD97@@/3T]("1T:')E861?8F%S95]I9'@I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9&5X(#T@;G5L;#L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1L979E;"D@)B8*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES7VYU;&PH)&QA<W1?
M:6YD97@I("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T
M*"1T:&ES+3Y?=&AR96%D6R1L87-T7VEN9&5X72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]T:')E861;)&QA<W1?:6YD97A=6R=L87-T
M)UT@/2`H)&QA<W1?:2`]/2`H)&D@+2`Q*2D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QA<W1?
M:6YD97@@/2`D:6YD97@["B`@("`@("`@("`@("`@("`D;&%S=%]I(#T@)&DK
M*SL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O4V]R="YP:'``````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S$P-0`Q,#4Q-30S,3`V,``P,C`T
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J($E-05!?4V]R="!P<F]V:61E<R!F=6YC=&EO;G,@9F]R
M('-O<G1I;F<@;&ES=',@;V8@24U!4"!M86EL8F]X97,O9F]L9&5R<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO24U!4"])34%0+U-O<G0N<&AP+'8@,2XV
M+C@N,3,@,C`P-B\P,B\Q-2`Q.#HP-SHU,B!S;'5S87)Z($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TE-05`*("HO"F-L87-S($E-05!?4V]R="!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@9&5L:6UI=&5R(&-H87)A8W1E<B!T;R!U<V4N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9&5L:6UI=&5R.PH*("`@
M("\J*@H@("`@("H@4VAO=6QD('=E('-O<G0@=VET:"`G24Y"3U@G(&%T('1H
M92!F<F]N="!O9B!T:&4@;&ES=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?<V]R=&EN8F]X.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&5L:6UI=&5R("!4:&4@9&5L:6UI=&5R('5S960@=&\@<V5P87)A=&4@;6%I
M;&)O>&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07U-O<G0H)&1E;&EM
M:71E<BD*("`@('L*("`@("`@("`D=&AI<RT^7V1E;&EM:71E<B`]("1D96QI
M;6ET97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&$@;&ES="!O9B!M
M86EL8F]X97,@*&)Y('9A;'5E*2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)B1M8F]X("`@(%1H92!L:7-T(&]F(&UA:6QB;WAE<R!T;R!S;W)T+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&EN8F]X("!7:&5N('-O<G1I;F<L(&%L
M=V%Y<R!P=70@)TE.0D]8)R!A="!T:&4@:&5A9"!O9@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@;&ES=#\*("`@("`J($!P87)A;2!B;V]L
M96%N("1I;F1E>"`@36%I;G1A:6X@:6YD97@@87-S;V-I871I;VX_"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-O<G1-86EL8F]X97,H)B1M8F]X+"`D:6YB;W@@
M/2!T<G5E+"`D:6YD97@@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^
M7W-O<G1I;F)O>"`]("1I;F)O>#L*("`@("`@("!I9B`H)&EN9&5X*2!["B`@
M("`@("`@("`@('5A<V]R="@D;6)O>"P@87)R87DH)B1T:&ES+"`G7VUB;WA?
M8VUP)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5S;W)T*"1M
M8F]X+"!A<G)A>2@F)'1H:7,L("=?;6)O>%]C;7`G*2D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4V]R="!A(&QI<W0@;V8@;6%I;&)O>&5S
M("AB>2!K97DI+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&UB;W@@
M("`@5&AE(&QI<W0@;V8@;6%I;&)O>&5S('1O('-O<G0L('=I=&@@=&AE(&ME
M>7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8F5I;F<@=&AE(&UA
M:6QB;W@@;F%M97,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:6YB;W@@(%=H
M96X@<V]R=&EN9RP@86QW87ES('!U="`G24Y"3U@G(&%T('1H92!H96%D(&]F
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H92!L:7-T/PH@("`@
M("HO"B`@("!F=6YC=&EO;B!S;W)T36%I;&)O>&5S0GE+97DH)B1M8F]X+"`D
M:6YB;W@@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]R=&EN8F]X
M(#T@)&EN8F]X.PH@("`@("`@('5K<V]R="@D;6)O>"P@87)R87DH)B1T:&ES
M+"`G7VUB;WA?8VUP)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@2&EE<F%R
M8VAI8V%L(&9O;&1E<B!S;W)T:6YG(&9U;F-T:6]N("AU<V5D('=I=&@@=7-O
M<G0H*2DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D82`@0V]M<&%R:7-O;B!I=&5M(#$N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1B("!#;VUP87)I<V]N(&ET96T@,BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%-E92!U<V]R="@I+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?;6)O>%]C;7`H)&$L("1B*0H@("`@>PH@("`@
M("`@("\J($%L=V%Y<R!R971U<FX@24Y"3U@@87,@(G-M86QL97(B+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7W-O<G1I;F)O>"D@>PH@("`@("`@("`@("!I
M9B`H<W1R8V%S96-M<"@D82P@)TE.0D]8)RD@/3T@,"D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("TQ.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R8V%S
M96-M<"@D8BP@)TE.0D]8)RD@/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(#$["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1A7W!A
M<G1S(#T@97AP;&]D92@D=&AI<RT^7V1E;&EM:71E<BP@)&$I.PH@("`@("`@
M("1B7W!A<G1S(#T@97AP;&]D92@D=&AI<RT^7V1E;&EM:71E<BP@)&(I.PH*
M("`@("`@("`D85]C;W5N="`](&-O=6YT*"1A7W!A<G1S*3L*("`@("`@("`D
M8E]C;W5N="`](&-O=6YT*"1B7W!A<G1S*3L*"B`@("`@("`@)&E-87@@/2!M
M:6XH)&%?8V]U;G0L("1B7V-O=6YT*3L*"B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&E-87@[("1I*RLI('L*("`@("`@("`@("`@:68@*"1A7W!A<G1S
M6R1I72`A/2`D8E]P87)T<ULD:5TI('L*("`@("`@("`@("`@("`@("\J($EF
M(&]N;'D@;VYE(&]F('1H92!F;VQD97)S(&ES('5N9&5R($E.0D]8+"!R971U
M<FX@:70@87,*("`@("`@("`@("`@("`@("`J(")S;6%L;&5R(BX@*B\*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7W-O<G1I;F)O>"`F)B`H)&D@/3T@
M,"DI('L*("`@("`@("`@("`@("`@("`@("`D85]B87-E(#T@*'-T<F-A<V5C
M;7`H)&%?<&%R='-;,%TL("=)3D)/6"<I(#T](#`I.PH@("`@("`@("`@("`@
M("`@("`@("1B7V)A<V4@/2`H<W1R8V%S96-M<"@D8E]P87)T<ULP72P@)TE.
M0D]8)RD@/3T@,"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1A7V)A<V4@
M)B8@(21B7V)A<V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("TQ.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@A)&%?8F%S92`F
M)B`D8E]B87-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`Q
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1C;7`@/2!S=')N871C87-E8VUP*"1A7W!A<G1S6R1I
M72P@)&)?<&%R='-;)&E=*3L*("`@("`@("`@("`@("`@(&EF("@D8VUP(#T]
M(#`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@<W1R8VUP*"1A7W!A
M<G1S6R1I72P@)&)?<&%R='-;)&E=*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(')E='5R;B`D8VUP.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@*"1A7V-O=6YT("T@)&)?8V]U;G0I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O0V%C
M:&4N<&AP````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C$U
M-0`Q,#4Q-30S,3`V,``P,C`T-C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!)34%07T-A8VAE
M.CH@8VQA<W,@9F%C:6QI=&%T97,@:6X@8V%C:&EN9R!O=71P=70@9G)O;2!T
M:&4@4$A0(&EM87`*("H@97AT96YS:6]N(&EN('1H92!C=7)R96YT('-E<W-I
M;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!4"]#86-H92YP
M:'`L=B`Q+C0N,3(N,3$@,C`P-B\P-"\R."`Q-3HT,SHT,"!S;'5S87)Z($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TE-05`*("HO"F-L87-S($E-05!?0V%C:&4@>PH*("`@("\J
M*@H@("`@("H@4&]I;G1E<B!T;R!T:&4@<V5S<VEO;B!C86-H92X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A8VAE.PH*
M("`@("\J*@H@("`@("H@5&AE(&-A8VAE9"!R97-U;'1S(&]F(&EM87!?<W1A
M='5S*"D@8V%L;',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]S=&%T=7-C86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O('1H92!G;&]B86P@24U!4%]#
M86-H92!O8FIE8W0L(&]N;'D@8W)E871I;F<*("`@("`J(&ET(&EF(&ET(&1O
M97-N)W0@86QR96%D>2!E>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@("`@*B`@("1I;6%P7V-A8VAE(#T@
M)DE-05!?0V%C:&4Z.G-I;F=L971O;B@I.PH@("`@("H*("`@("`J($!R971U
M<FX@24U!4%]#86-H92`@5&AE($E-05!?0V%C:&4@:6YS=&%N8V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T
M871I8R`D;V)J96-T.PH*("`@("`@("!I9B`H(6ES<V5T*"1O8FIE8W0I*2![
M"B`@("`@("`@("`@("1O8FIE8W0@/2!N97<@24U!4%]#86-H92@I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1O8FIE8W0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%0
M7T-A8VAE*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG
M:6UA<%]C86-H92==*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)VEM87!?
M8V%C:&4G72`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?
M8V%C:&4@/2`F)%]315-324].6R=I;6%P7V-A8VAE)UT["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@9&%T82!F<F]M('1H92!C86-H92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)&EM87`@("!4:&4@24U!4"!R97-O=7)C
M92!S=')E86TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("!4:&4@
M9G5L;"`H>VAO<W1N86UE?6UA:6QB;W@I(&UA:6QB;W@@;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@("`@(%1H92!N86UE(&]F(&$@<W!E8VEF
M:6,@96YT<GD@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-H
M96-K("`@0VAE8VL@9F]R('5P9&%T960@;6%I;&)O>#\*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@9&%T82!R97%U97-T960L(&]R(&9A;'-E
M(&EF(&YO="!A=F%I;&%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A
M8VAE*"1I;6%P+"`D;6%I;&)O>"P@)&ME>2`](&YU;&PL("1C:&5C:R`]('1R
M=64I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%C:&5;)&UA
M:6QB;WA=*2D@>PH@("`@("`@("`@("!I9B`H(21C:&5C:R!\?"`D=&AI<RT^
M8VAE8VM#86-H92@D:6UA<"P@)&UA:6QB;W@I*2!["B`@("`@("`@("`@("`@
M("`D<'1R(#T@)B1T:&ES+3Y?8V%C:&5;)&UA:6QB;WA=.PH@("`@("`@("`@
M("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P=');)V0G75LD:V5Y72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1P=');)V0G75LD:V5Y73L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<'1R6R=D)UT["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&-A8VAE(&EN9F]R
M;6%T:6]N('5P+71O+61A=&4_"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("1I;6%P("`@5&AE($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@*'MH;W-T;F%M97UM
M86EL8F]X*2!M86EL8F]X(&YA;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M=7!D871E("!3:&]U;&0@=&AE(&-A8VAE($E$('-T<FEN9R!B92!U<&1A=&5D
M/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!C86-H
M92!I;F9O<FUA=&EO;B!U<"UT;RUD871E+"!F86QS92!I9B!N;W0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-H96-K0V%C:&4H)&EM87`L("1M86EL8F]X+"`D
M=7!D871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?8V%C:&5;)&UA:6QB;WA=*2D@>PH@("`@("`@("`@("`D:60@/2`D=&AI
M<RT^7V=E=$-A8VAE240H)&EM87`L("1M86EL8F]X*3L*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8V%C:&5;)&UA:6QB;WA=6R=K)UT@/3T@)&ED*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=&]R94-A
M8VAE*"1I;6%P+"`D;6%I;&)O>"D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI<RT^<W1O<F5#
M86-H92@D:6UA<"P@)&UA:6QB;W@I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!D871A(&EN
M('1H92!C86-H92X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)&EM
M87`@("!4:&4@24U!4"!R97-O=7)C92!S=')E86TN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1M86EL8F]X("!4:&4@9G5L;"`H>VAO<W1N86UE?6UA:6QB;W@I
M(&UA:6QB;W@@;F%M92X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("`@
M(%1H92!D871A('1O(&%D9"!T;R!T:&4@8V%C:&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-T;W)E0V%C:&4H)&EM87`L("1M86EL8F]X+"`D=F%L=65S(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8V%C
M:&5;)&UA:6QB;WA=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-A8VAE6R1M
M86EL8F]X72`](&%R<F%Y*"=D)R`]/B!A<G)A>2@I*3L*("`@("`@("!]"B`@
M("`@("`@)'!T<B`]("8D=&AI<RT^7V-A8VAE6R1M86EL8F]X73L*("`@("`@
M("`D<'1R(#T@87)R87DH"B`@("`@("`@("`@("=K)R`]/B`D=&AI<RT^7V=E
M=$-A8VAE240H)&EM87`L("1M86EL8F]X*2P*("`@("`@("`@("`@)V0G(#T^
M(&%R<F%Y7VUE<F=E*"1P=');)V0G72P@)'9A;'5E<RD*("`@("`@("`I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;F0@8V%C:&5S('1H92!R
M97-U;'1S(&]F(&%N(&EM87!?<W1A='5S*"D@8V%L;"X*("`@("`J"B`@("`@
M*B!`<VEN8V4@2&]R9&4@,RXQ+C(*("`@("`J"B`@("`@*B!`<&%R86T@<F5S
M;W5R8V4@)&EM87`@("!4:&4@24U!4"!R97-O=7)C92!S=')I;F<N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("!4:&4@9G5L;"`H>VAO<W1N86UE
M?6UA:6QB;W@I(&UA:6QB;W@@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T9$-L87-S("!4:&4@:6UA<%]S=&%T=7,H*2!O8FIE8W0@;W(@=&AE(&5M
M<'1Y('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W1A='5S*"1I
M;6%P+"`D;6%I;&)O>"D*("`@('L*("`@("`@("`D=&AI<RT^7V=E=$-A8VAE
M240H)&EM87`L("1M86EL8F]X*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]S
M=&%T=7-C86-H95LD;6%I;&)O>%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M96YE<F%T92!T:&4@=6YI<75E($E$('-T<FEN9R!F;W(@=&AE(&UA:6QB;W@N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1I;6%P("`@5&AE($E-05`@<F5S;W5R8V4@<W1R
M96%M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@
M*'MH;W-T;F%M97UM86EL8F]X*2!M86EL8F]X(&YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@($$@=6YI<75E('-T<FEN9R!F;W(@=&AE(&-U
M<G)E;G0@<W1A=&4@;V8@=&AE(&UA:6QB;W@N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G971#86-H94E$*"1I;6%P+"`D;6%I;&)O>"D*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<W1A='5S8V%C:&5;)&UA:6QB;WA=*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-T871U<V-A8VAE6R1M86EL8F]X72`]
M($!I;6%P7W-T871U<R@D:6UA<"P@)&UA:6QB;W@L(%-!7T%,3"D["B`@("`@
M("`@("`@(&EF("@A)'1H:7,M/E]S=&%T=7-C86-H95LD;6%I;&)O>%TI('L*
M("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*&EM87!?;&%S=%]E
M<G)O<B@I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#12D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?
M<W1A='5S8V%C:&5;)&UA:6QB;WA=*2!["B`@("`@("`@("`@("1O8B`]("1T
M:&ES+3Y?<W1A='5S8V%C:&5;)&UA:6QB;WA=.PH@("`@("`@("`@("!R971U
M<FX@:6UP;&]D92@G?"<L(&%R<F%Y*"1O8BT^;65S<V%G97,L("1O8BT^<F5C
M96YT+"`D;V(M/G5N<V5E;BP@)&]B+3YU:61N97AT+"`D;V(M/G5I9'9A;&ED
M:71Y*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1M
M86EL8F]X.PH@("`@("`@('T*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U!R969S+P``````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,``P,3<R-S4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O<W%L+G!H
M<```````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,R,3<S`#$P
M-3$U-#,Q,#8P`#`R,#8Q,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@2&]R9&5?4')E
M9G,*("HO"@HO*BH*("H@4$5!4B!$0B!L87EE<BX*("HO"G)E<75I<F5?;VYC
M92`G1$(N<&AP)SL*"B\J*@H@*B!(;W)D95]3=')I;F<@8VQA<W,N"B`J+PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J(%!R969E
M<F5N8V5S('-T;W)A9V4@:6UP;&5M96YT871I;VX@9F]R(%!(4"=S(%!%05(@
M9&%T86)A<V4*("H@86)S=')A8W1I;VX@;&%Y97(N"B`J"B`J(%)E<75I<F5D
M('!A<F%M971E<G,Z/'!R93X*("H@("`G<&AP='EP92<@("!4:&4@9&%T86)A
M<V4@='EP92`H:64N("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+@H@*B`@("=C
M:&%R<V5T)R`@(%1H92!D871A8F%S92=S(&EN=&5R;F%L(&-H87)S970N/"]P
M<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G=&%B
M;&4G("`@("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC97,@=&%B;&4@:6X@
M)V1A=&%B87-E)RX*("H@("`@("`@("`@("`@("!$149!54Q4.B`G:&]R9&5?
M<')E9G,G/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T86)A<V4@
M:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO
M<W1N86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J("`@)W!R;W1O8V]L
M)R`@5&AE(&-O;6UU;FEC871I;VX@<')O=&]C;VP@*"=T8W`G+"`G=6YI>"<L
M(&5T8RXI+@H@*B`@("=D871A8F%S92<@(%1H92!N86UE(&]F('1H92!D871A
M8F%S92X*("H@("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC
M:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G
M("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J
M("`@)V]P=&EO;G,G("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@
M=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H
M:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=T='DG("`@
M("`@(%1H92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A
M<V4N/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!0
M<F5F<R!S>7-T96T@:7,@:6X*("H@<V-R:7!T<R]S<6PO:&]R9&5?<')E9G,N
M<W%L+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN
M<&AP+'8@,2XY,2XQ,"XR,"`R,#`V+S`T+S$P(#$U.C4X.C$T(&-H=6-K($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?<W%L(&5X
M=&5N9',@4')E9G,@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG
M(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B87-E(&-O
M;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V
M87(@)%]D8CL*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W
M:&5T:&5R(&]R(&YO="!W92=R92!C;VYN96-T960@=&\@=&AE(%-13"!S97)V
M97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T<R!A(&YE=R!344P@<')E9F5R96YC97,@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!4:&4@=7-E<B!W:&\@;W=N
M<R!T:&5S92!P<F5F97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M<W-W;W)D("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U<V5R+B`H
M56YU<V5D*0H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@(%1H92!C
M=7)R96YT('!R969E<F5N8V5S('-C;W!E+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<RX*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H:6YG("!3:&]U
M;&0@8V%C:&EN9R!B92!U<V5D/PH@("`@("HO"B`@("!F=6YC=&EO;B!0<F5F
M<U]S<6PH)'5S97(L("1P87-S=V]R9"`]("<G+"`D<V-O<&4@/2`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH*2P@)&-A8VAI
M;F<@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7W5S97(@/2`D=7-E
M<CL*("`@("`@("`D=&AI<RT^7W-C;W!E(#T@)'-C;W!E.PH@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@("`@("`D=&AI<RT^7V-A8VAI
M;F<@/2`D8V%C:&EN9SL*"B`@("`@("`@<&%R96YT.CI0<F5F<R@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<G-E="!U<V5D(&)Y
M('1H92!C;VYC<F5T92!P<F5F97)E;F-E(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!P<F5F97)E;F-E(&)A8VME;F0G<R!C
M:&%R<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7-;)V-H87)S970G73L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@<F5Q=65S=&5D
M('-E="!O9B!P<F5F97)E;F-E<R!F<F]M('1H92!U<V5R)W,@9&%T86)A<V4*
M("`@("`J(&5N=')Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<')E
M9G,@($%N(&%R<F%Y(&QI<W1I;F<@=&AE('!R969E<F5N8V5S('1O(')E=')I
M979E+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;F]T('-P96-I
M9FEE9"P@<F5T<FEE=F4@86QL(&]F('1H92!P<F5F97)E;F-E<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@;&ES=&5D(&EN('1H92`D<')E9G,@:&%S
M:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R971R:65V92@D<')E9G,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("\J($%T=&5M<'0@=&\@<'5L;"!T:&4@=F%L=65S(&9R;VT@
M=&AE('-E<W-I;VX@8V%C:&4@9FER<W0N("HO"B`@("`@("`@:68@*"1T:&ES
M+3YC86-H94QO;VMU<"@I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@3&]A9"!D969A=6QT<R!T;R!M86ME('-U
M<F4@=V4@:&%V92!A;&P@<')E9F5R96YC97,N("HO"B`@("`@("`@<&%R96YT
M.CIR971R:65V92@I.PH*("`@("`@("`O*B!-86ME('-U<F4@=V4G<F4@8V]N
M;F5C=&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@
M("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]
M("=314Q%0U0@<')E9E]S8V]P92P@<')E9E]N86UE+"!P<F5F7W9A;'5E($92
M3TT@)SL*("`@("`@("`D<75E<GD@+CT@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UT@+B`G("<["B`@("`@("`@)'%U97)Y("X]("=72$5212!P<F5F7W5I9"`]
M(#\G.PH@("`@("`@("1Q=65R>2`N/2`G($%.1"`H<')E9E]S8V]P92`](#\G
M.PH@("`@("`@("1Q=65R>2`N/2`B($]2('!R969?<V-O<&4@/2`G:&]R9&4G
M*2!/4D1%4B!"62!P<F5F7W-C;W!E(CL*"B`@("`@("`@)'9A;'5E<R`](&%R
M<F%Y*"1T:&ES+3Y?=7-E<BP@)'1H:7,M/E]S8V]P92D["@H@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!0<F5F<U]S
M<6PZ.G)E=')I979E*"DZ("5S)RP@)'%U97)Y*2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE
M('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R
M>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("!I9B`H:7-S970H)')E<W5L
M="D@)B8@(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`D<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%3
M4T]#*3L*("`@("`@("`@("`@:68@*&ES7V$H)')O=RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')O=RP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!3
M970@=&AE(')E<75E<W1E9"!V86QU97,@:6X@=&AE("1T:&ES+3Y?<')E9G,@
M:&%S:`H@("`@("`@("`@("`@*B!B87-E9"!O;B!T:&4@8V]N=&5N=',@;V8@
M=&AE(%-13"!R97-U;'0N"B`@("`@("`@("`@("`J"B`@("`@("`@("`@("`J
M($YO=&4@=&AA="!0<F5F<SHZ<V5T5F%L=64H*2!C86XG="!B92!U<V5D(&AE
M<F4@8F5C875S90H@("`@("`@("`@("`@*B!O9B!T:&4@8VAE8VL@9F]R('1H
M92`B8VAA;F=E86)L92(@8FET+B!792!W86YT('1O"B`@("`@("`@("`@("`J
M(&]V97)R:61E('1H870@8VAE8VL@=VAE;B!P;W!U;&%T:6YG('1H92`D=&AI
M<RT^7W!R969S"B`@("`@("`@("`@("`J(&AA<V@@9G)O;2!T:&4@4U%,('-E
M<G9E<BX@*B\*("`@("`@("`@("`@=VAI;&4@*"1R;W<@)B8@(6ES7V$H)')O
M=RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YA;64@/2!T
M<FEM*"1R;W=;)W!R969?;F%M92==*3L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!R969S6R1N86UE72DI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=%9A;'5E*"1N86UE+"`D<F]W6R=P<F5F7W9A;'5E
M)UTL(&9A;'-E+"!F86QS92D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$1I<G1Y*"1N86UE+"!F86QS92D["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H)&YA;64L("1R
M;W=;)W!R969?=F%L=64G72P@)')O=ULG<')E9E]S8V]P92==(#T]("=H;W)D
M92<@/R!?4%)%1E]32$%2140@.B`P*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#
M2$U/1$5?05-33T,I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#
M86QL(&AO;VMS+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V-A;&Q(;V]K<R@I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=.;R!P<F5F97)E;F-E<R!W97)E(')E=')I979E9"XG+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@57!D871E('1H92!S97-S:6]N
M(&-A8VAE+B`J+PH@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I.PH*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E
M<R!P<F5F97)E;F-E<R!T;R!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E
M*"D*("`@('L*("`@("`@("`O*B!#:&5C:R!F;W(@86YY(")D:7)T>2(@<')E
M9F5R96YC97,N($EF(&YO(")D:7)T>2(*("`@("`@("`@*B!P<F5F97)E;F-E
M<R!A<F4@9F]U;F0L('1H97)E)W,@;F\@;F5E9"!T;R!U<&1A=&4@=&AE(%-1
M3`H@("`@("`@("`J('-E<G9E<BX@17AI="!S=6-C97-S9G5L;'DN("HO"B`@
M("`@("`@)&1I<G1Y7W!R969S(#T@)'1H:7,M/E]D:7)T>5!R969S*"D["B`@
M("`@("`@:68@*"%C;W5N="@D9&ER='E?<')E9G,I*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E
M('=E)W)E(&-O;FYE8W1E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H('1H92`B9&ER='DB('!R969E
M<F5N8V5S+B`@268@82!R;W<@86QR96%D>0H@("`@("`@("`J(&5X:7-T<R!F
M;W(@=&AI<R!P<F5F97)E;F-E+"!A='1E;7!T('1O('5P9&%T92!I="X*("`@
M("`@("`@*B!/=&AE<G=I<V4L(&EN<V5R="!A(&YE=R!R;W<N("HO"B`@("`@
M("`@9F]R96%C:"`H)&1I<G1Y7W!R969S(&%S("1N86UE*2!["B`@("`@("`@
M("`@("\O($1O;B=T('-T;W)E(&QO8VME9"!P<F5F97)E;F-E<RX*("`@("`@
M("`@("`@:68@*"1T:&ES+3YI<TQO8VME9"@D;F%M92DI('L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<V-O<&4@/2`D=&AI<RT^9V5T4V-O<&4H)&YA;64I.PH*("`@("`@("`@("`@
M+RH@1&]E<R!A;B!E;G1R>2!A;')E861Y(&5X:7-T(&9O<B!T:&ES('!R969E
M<F5N8V4_("HO"B`@("`@("`@("`@("1Q=65R>2`]("=314Q%0U0@,2!&4D]-
M("<["B`@("`@("`@("`@("1Q=65R>2`N/2`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N("<@)SL*("`@("`@("`@("`@)'%U97)Y("X]("=72$5212!P<F5F
M7W5I9"`](#\G.PH@("`@("`@("`@("`D<75E<GD@+CT@)R!!3D0@<')E9E]N
M86UE(#T@/R<["B`@("`@("`@("`@("1Q=65R>2`N/2`G($%.1"`H<')E9E]S
M8V]P92`](#\G.PH@("`@("`@("`@("`D<75E<GD@+CT@(B!/4B!P<F5F7W-C
M;W!E(#T@)VAO<F1E)RDB.PH*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"1T:&ES+3Y?=7-E<BP@)&YA;64L("1S8V]P92D["@H@("`@("`@("`@("`O
M*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`@("`@)&-H96-K(#T@
M)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@
M("`@("`O*B!2971U<FX@86X@97)R;W(@:68@=&AE('%U97)Y(&9A:6QS+B`J
M+PH@("`@("`@("`@("!I9B`H:7-?82@D8VAE8VLL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL960@
M<F5T<FEE=FEN9R!P<F5F<R!F;W(@)R`N("1T:&ES+3Y?=7-E<BP@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!)<R!T:&5R92!A;B!E>&ES=&EN9R!R;W<@9F]R('1H:7,@<')E9F5R96YC
M93\@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D8VAE8VLI*2!["B`@("`@
M("`@("`@("`@("`O*B!5<&1A=&4@=&AE(&5X:7-T:6YG(')O=RX@*B\*("`@
M("`@("`@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R
M86US6R=T86)L92==("X@)R`G.PH@("`@("`@("`@("`@("`@)'%U97)Y("X]
M("=3150@<')E9E]V86QU92`](#\G.PH@("`@("`@("`@("`@("`@)'%U97)Y
M("X]("<@5TA%4D4@<')E9E]U:60@/2`_)SL*("`@("`@("`@("`@("`@("1Q
M=65R>2`N/2`G($%.1"!P<F5F7VYA;64@/2`_)SL*("`@("`@("`@("`@("`@
M("1Q=65R>2`N/2`G($%.1"!P<F5F7W-C;W!E(#T@/R<["@H@("`@("`@("`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"AS=')I;F<I)'1H:7,M/F=E=%9A;'5E
M*"1N86UE+"!F86QS92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]U<V5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M8V]P92D["@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M
M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@("`@("`@("`@+RH@
M4F5T=7)N(&%N(&5R<F]R(&EF('1H92!U<&1A=&4@9F%I;',N("HO"B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1R97-U;'0L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!);G-E<G0@82!N97<@
M<F]W+B`J+PH@("`@("`@("`@("`@("`@)'%U97)Y("`]("=)3E-%4E0@24Y4
M3R`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+B`G("<["B`@("`@("`@
M("`@("`@("`D<75E<GD@+CT@)RAP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E
M9E]N86UE+"!P<F5F7W9A;'5E*2!604Q515,G.PH@("`@("`@("`@("`@("`@
M)'%U97)Y("X]("<H/RP@/RP@/RP@/RDG.PH*("`@("`@("`@("`@("`@("1V
M86QU97,@/2!A<G)A>2@D=&AI<RT^7W5S97(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-C;W!E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AS=')I;F<I)'1H:7,M/F=E=%9A;'5E*"1N86UE+"!F86QS92DI.PH*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D
M<75E<GDL("1V86QU97,I.PH*("`@("`@("`@("`@("`@("\J(%)E='5R;B!A
M;B!E<G)O<B!I9B!T:&4@:6YS97)T(&9A:6QS+B`J+PH@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@($AO<F1E.CIF871A;"@D<F5S=6QT+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!-87)K('1H:7,@<')E9F5R96YC92!A<R`B8VQE86XB
M(&YO=RX@*B\*("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1N86UE+"!F
M86QS92D["B`@("`@("`@?0H*("`@("`@("`O*B!5<&1A=&4@=&AE('-E<W-I
M;VX@8V%C:&4N("HO"B`@("`@("`@)'1H:7,M/F-A8VAE57!D871E*"D["@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4&5R
M9F]R;2!C;&5A;G5P(&]P97)A=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%L;"`@0VQE86YU<"!A;&P@2&]R9&4@<')E9F5R96YC97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%N=7`H)&%L;"`](&9A;'-E*0H@
M("`@>PH@("`@("`@("\J($-L;W-E('1H92!D871A8F%S92!C;VYN96-T:6]N
M+B`J+PH@("`@("`@("1T:&ES+3Y?9&ES8V]N;F5C="@I.PH*("`@("`@("!P
M87)E;G0Z.F-L96%N=7`H)&%L;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;&5A<G,@86QL('!R969E<F5N8V5S(&9R;VT@=&AE(&)A8VME;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-L96%R*"D*("`@('L*("`@("`@("`O*B!-86ME
M('-U<F4@=V4G<F4@8V]N;F5C=&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@
M("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT["B`@("`@("`@)'%U97)Y("X]("<@5TA%4D4@<')E9E]U
M:60@/2`_)SL*"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?=7-E
M<BD["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1
M=65R>2!B>2!0<F5F<U]S<6PZ.F-L96%R*"DZ("5S)RP@)'%U97)Y*2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J
M($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("`O*B!#
M;&5A;G5P+B`J+PH@("`@("`@('!A<F5N=#HZ8VQE87(H*3L*"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T
M<R!A('9A;'5E(&9R;VT@=&AE(&1R:79E<B=S(&-H87)S970@=&\@=&AE('-P
M96-I9FEE9"!C:&%R<V5T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M=F%L=64@("`@($$@=F%L=64@=&\@8V]N=F5R="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T('1O(&-O;G9E<G0@=&\N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-O;G9E<G1E9"!V86QU
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=$9R;VU$<FEV97(H)'9A
M;'5E+"`D8VAA<G-E="D*("`@('L*("`@("`@("!S=&%T:6,@)&-O;G9E<G1E
M9"`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2![
M"B`@("`@("`@("`@(')E='5R;B!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V
M86QU92P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72P@)&-H87)S970I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES7V)O;VPH)'9A;'5E*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D8V]N=F5R=&5D6R1C:&%R<V5T75LD=F%L=65=*2D@>PH@("`@
M("`@("`@("`D8V]N=F5R=&5D6R1C:&%R<V5T75LD=F%L=65=(#T@4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1T:&ES+3Y?<&%R86US6R=C:&%R
M<V5T)UTL("1C:&%R<V5T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8V]N=F5R=&5D6R1C:&%R<V5T75LD=F%L=65=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N=F5R=',@82!V86QU92!F<F]M('1H92!S<&5C:69I960@8VAA
M<G-E="!T;R!T:&4@9')I=F5R)W,@8VAA<G-E="X*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)'9A;'5E("!!('9A;'5E('1O(&-O;G9E<G0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!C;VYV
M97)T(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-O
M;G9E<G1E9"!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=%1O
M1')I=F5R*"1V86QU92P@)&-H87)S970I"B`@("!["B`@("`@("`@<F5T=7)N
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"`D8VAA<G-E="P@)'1H
M:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!O<&5N(&$@<&5R<VES=&5N="!C;VYN96-T:6]N('1O
M('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("`O*B!#:&5C
M:R!T;R!S964@:68@=V4@87)E(&%L<F5A9'D@8V]N;F5C=&5D+B`J+PH@("`@
M("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV
M97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=P<F5F<R<L"B`@("`@("`@("`@
M(&%R<F%Y*"=P:'!T>7!E)RP@)V-H87)S970G*2P*("`@("`@("`@("`@)W!R
M969E<F5N8V5S(%-13"<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&%R86US6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG9&%T86)A<V4G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R
M9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G
M72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&%R86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T86)L92==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`]("=H;W)D95]P<F5F<R<["B`@
M("`@("`@?0H*("`@("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R
M('5S:6YG('1H92!S=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@("1T
M:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A;7,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N
M="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D[
M"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'1H:7,M/E]D8BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E="!$0B!P
M;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]D
M8BT^<&AP='EP92D@>PH@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@
M("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/
M4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24R!\
M($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T
M:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\
M($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!F<F]M('1H92!3
M44P@<V5R=F5R(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]0<F5F<R]522YP:'``````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,S0U-38`,3`U,34T,S$P-C``,#(P,S,U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!#;&%S<R!F;W(@875T;RUG96YE<F%T:6YG('1H92!P<F5F97)E
M;F-E<R!U<V5R(&EN=&5R9F%C92!A;F0*("H@<')O8V5S<VEN9R!T:&4@9F]R
M;7,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<"QV(#$N-C,N,BXQ-2`R,#`V+S`Q+S$R(#(R.C(U.C$T(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E
M9G-?54D@>PH*("`@("\J*@H@("`@("H@1&5T97)M:6YE('=H971H97(@;W(@
M;F]T(&$@<')E9F5R96YC97,@9W)O=7`@:7,@961I=&%B;&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@(%1H92!P<F5F97)E;F-E<R!G
M<F]U<"!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1H92!G<F]U<"!I<R!E9&ET86)L92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9W)O=7!)<T5D:71A8FQE*"1G<F]U<"D*("`@('L*
M("`@("`@("!G;&]B86P@)'!R969S+"`D<')E9D=R;W5P<SL*"B`@("`@("`@
M<W1A=&EC("1R97-U;'1S(#T@87)R87DH*3L*"B`@("`@("`@:68@*"%I<W-E
M="@D<F5S=6QT<ULD9W)O=7!=*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1P<F5F1W)O=7!S6R1G<F]U<%U;)W5R;"==*2D@>PH@("`@("`@("`@("`@
M("`@)')E<W5L='-;)&=R;W5P72`]('1R=64["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5S=6QT<ULD9W)O=7!=(#T@9F%L<V4[
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!R969'<F]U<'-;)&=R;W5P
M75LG;65M8F5R<R==*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1P<F5F1W)O=7!S6R1G<F]U<%U;)VUE;6)E<G,G72!A<R`D<')E9BD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21P<F5F<RT^:7-,;V-K960H
M)'!R968I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT
M<ULD9W)O=7!=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L='-;)&=R;W5P
M73L*("`@('T*"B`@("`O*BH*("`@("`J($AA;F1L92!A('!R969E<F5N8V5S
M(&9O<FT@<W5B;6ES<VEO;B!I9B!T:&5R92!I<R!O;F4L('5P9&%T:6YG"B`@
M("`@*B!A;GD@<')E9F5R96YC97,@=VAI8V@@:&%V92!B965N(&-H86YG960N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@(%1H92!P<F5F
M97)E;F-E<R!G<F]U<"!T:&%T('=A<R!E9&ET960N"B`@("`@*B!`<&%R86T@
M;V)J96-T("1S879E("`@5&AE(&]B:F5C="!W:&5R92!T:&4@8VAA;F=E9"!V
M86QU97,@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V%V960N
M($UU<W0@:6UP;&5M96YT('-E=%9A;'5E*'-T<FEN9RP@<W1R:6YG*2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@<')E9F5R96YC
M97,@:&%V92!B965N('5P9&%T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA
M;F1L949O<FTH)B1G<F]U<"P@)B1S879E*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<')E9G,L("1P<F5F1W)O=7!S+"`D7W!R969S+"`D;F]T:69I8V%T:6]N
M+"`D<F5G:7-T<GD["@H@("`@("`@("1U<&1A=&5D(#T@9F%L<V4["@H@("`@
M("`@("\J(%)U;B!T:')O=6=H('1H92!A8W1I;VX@:&%N9&QE<G,@*B\*("`@
M("`@("!I9B`H571I;#HZ9V5T4&]S="@G86-T:6]N240G*2`]/2`G=7!D871E
M7W!R969S)RD@>PH@("`@("`@("`@("!I9B`H:7-S970H)&=R;W5P*2`F)B!0
M<F5F<U]523HZ9W)O=7!)<T5D:71A8FQE*"1G<F]U<"DI('L*("`@("`@("`@
M("`@("`@("1U<&1A=&5D(#T@9F%L<V4["@H@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'!R969'<F]U<'-;)&=R;W5P75LG;65M8F5R<R==(&%S("1P<F5F
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D<')E9G,M/FES3&]C:V5D
M*"1P<F5F*2!\?`H@("`@("`@("`@("`@("`@("`@("`@("`H)%]P<F5F<ULD
M<')E9EU;)W1Y<&4G72`]/2`G<W!E8VEA;"<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@('-W:71C:"`H)%]P<F5F<ULD<')E9EU;)W1Y<&4G72D@>PH*
M("`@("`@("`@("`@("`@("`@("`@("`@+RH@5&AE<V4@96ET:&5R(&%R96XG
M="!S970@;W(@87)E('-E="!I;B!O=&AE<@H@("`@("`@("`@("`@("`@("`@
M("`@("`@*B!P87)T<R!O9B!T:&4@54DN("HO"B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)VEM<&QI8VET)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`G;&EN:R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W-E;&5C="<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W1E>'0G.@H@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E("=T97AT87)E82<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)W!A<W-W;W)D)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1U<&1A=&5D(#T@)'5P9&%T960@?"`D<V%V92T^<V5T
M5F%L=64H)'!R968L(%5T:6PZ.F=E=%!O<W0H)'!R968I*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G96YU;2<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%L(#T@571I;#HZ9V5T4&]S="@D<')E9BD["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)%]P<F5F<ULD<')E9EU;)V5N=6TG
M75LD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=7!D871E9"`]("1U<&1A=&5D('P@)'-A=F4M/G-E=%9A;'5E*"1P<F5F+"`D
M=F%L*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"A?*")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("=M=6QT:65N=6TG.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;',@/2!5=&EL.CIG9710;W-T*"1P<F5F*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S970@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN=F%L:60@/2!F86QS93L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L
M<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D=F%L<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D7W!R969S6R1P<F5F75LG96YU;2==6R1V
M86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-E=%M=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;G9A;&ED(#T@=')U93L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:6YV86QI9"D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5P
M9&%T960@/2`D=7!D871E9"!\("1S879E+3YS971686QU92@D<')E9BP@0'-E
M<FEA;&EZ92@D<V5T*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)VYU;6)E<B<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;G5M(#T@571I;#HZ9V5T4&]S="@D<')E9BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:6YT=F%L*"1N=6TI("$]
M("1N=6TI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)&YU;2`]/2`P*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1U<&1A=&5D(#T@)'5P9&%T960@
M?"`D<V%V92T^<V5T5F%L=64H)'!R968L("1N=6TI.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=C:&5C:V)O
M>"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L(#T@571I;#HZ
M9V5T4&]S="@D<')E9BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=7!D871E9"`]("1U<&1A=&5D('P@)'-A=F4M/G-E=%9A;'5E*"1P<F5F+"!I
M<W-E="@D=F%L*2`_(#$@.B`P*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G<W!E
M8VEA;"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O*B!#;V1E(&9O
M<B!S<&5C:6%L(&5L96UE;G1S(&UU<W0@8F4*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`J('=R:71T96X@<W!E8VEF:6-A;&QY(&9O<B!E86-H"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*B!A<'!L:6-A=&EO;BX@*B\*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)VAA;F1L95\G("X@)'!R968I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'5P9&%T960@/2`D=7!D871E9"!\(&-A;&Q?=7-E<E]F
M=6YC*"=H86YD;&5?)R`N("1P<F5F+"`D=7!D871E9"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!I9B`H)'5P9&%T960I('L*("`@("`@("`@("`@("`@("`@("!I9B`H9G5N
M8W1I;VY?97AI<W1S*"=P<F5F<U]C86QL8F%C:R<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@('!R969S7V-A;&QB86-K*"D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P<F5F<RP@
M)U!R969S7W-E<W-I;VXG*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB*2P@
M)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB*2P@)VAO<F1E
M+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)&=R;W5P(#T@;G5L;#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<&1A=&5D
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE(%5)(&9O<B!T
M:&4@<')E9F5R96YC97,@:6YT97)F86-E+"!E:71H97(@9F]R(&$*("`@("`J
M('-P96-I9FEC(&=R;W5P+"!O<B!T:&4@9W)O=7`@<V5L96-T:6]N(&EN=&5R
M9F%C92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@5&AE
M(&=R;W5P('1O(&=E;F5R871E('1H92!522!F;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E;F5R871E54DH)&=R;W5P(#T@;G5L;"D*("`@('L*("`@("`@
M("!G;&]B86P@)&)R;W=S97(L("1C;VYF+"`D<')E9G,L("1P<F5F1W)O=7!S
M+"`D7W!R969S+"`D<F5G:7-T<GDL("1A<'`["@H@("`@("`@("\J($-H96-K
M(&EF(&%N>2!O<'1I;VYS(&%R92!A8W1U86QL>2!A=F%I;&%B;&4N("HO"B`@
M("`@("`@:68@*&ES7VYU;&PH)'!R969'<F]U<',I*2!["B`@("`@("`@("`@
M("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"A?*")4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N(BDL("=H;W)D92YM97-S86=E)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!3:&]W('1H92!H96%D97(N("HO"B`@("`@
M("`@4')E9G-?54DZ.F=E;F5R871E2&5A9&5R*"1G<F]U<"D["@H@("`@("`@
M("\J($%S<VEG;B!V87)I86)L97,@=&\@:&]L9"!S96QE8W0@;&ES=',N("HO
M"B`@("`@("`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=L86YG=6%G92<I*2![
M"B`@("`@("`@("`@("1'3$]"04Q36R=L86YG=6%G95]O<'1I;VYS)UT@/2`D
M1TQ/0D%,4ULG;FQS)UU;)VQA;F=U86=E<R==.PH@("`@("`@("`@("!A<G)A
M>5]U;G-H:69T*"1'3$]"04Q36R=L86YG=6%G95]O<'1I;VYS)UTL(%\H(D1E
M9F%U;'0B*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1G<F]U
M<"D@)B8@4')E9G-?54DZ.F=R;W5P27-%9&ET86)L92@D9W)O=7`I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1P<F5F1W)O=7!S6R1G<F]U<%U;)VUE;6)E
M<G,G72!A<R`D<')E9BD@>PH@("`@("`@("`@("`@("`@:68@*"$D<')E9G,M
M/FES3&]C:V5D*"1P<F5F*2D@>PH@("`@("`@("`@("`@("`@("`@("\J($=E
M="!T:&4@:&5L<"!L:6YK+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)%]P<F5F<ULD<')E9EU;)VAE;'`G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&AE;'!L:6YK(#T@2&5L<#HZ;&EN:R@A96UP='DH)%]P
M<F5F<ULD<')E9EU;)W-H87)E9"==*2`_("=H;W)D92<@.B`D<F5G:7-T<GDM
M/F=E=$%P<"@I+"`D7W!R969S6R1P<F5F75LG:&5L<"==*3L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M:&5L<&QI;FL@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`@("`@<W=I=&-H("@D7W!R969S6R1P<F5F75LG='EP92==
M*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G:6UP;&EC:70G.@H@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G<W!E8VEA;"<Z"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("%E;7!T>2@D7W!R
M969S6R1P<F5F75LG<VAA<F5D)UTI(#\@)VAO<F1E)R`Z("1R96=I<W1R>2T^
M9V5T07!P*"DI("X@(B]P<F5F<R\D<')E9BYI;F,B.PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM
M/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+W!R969S+R<@+B`D7W!R
M969S6R1P<F5F75LG='EP92==("X@)RYI;F,G.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5Q=6ER92`D
M<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+W!R969S
M+V5N9"YI;F,G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S<&%N
M(#T@,3`P.PH@("`@("`@("`@("`D8V]L=6UN<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D<')E9D=R;W5P<RDI('L*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1P<F5F1W)O=7!S(&%S("1G<F]U<"`]/B`D9W9A
M;',I('L*("`@("`@("`@("`@("`@("`@("!I9B`H4')E9G-?54DZ.F=R;W5P
M27-%9&ET86)L92@D9W)O=7`I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1C;VP@/2`D9W9A;'-;)V-O;'5M;B==.PH@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D9W9A;'-;)V-O;'5M;B==*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;'5M;G-;)&-O;%U;)&=R;W5P72`]("1G=F%L<SL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H8V]U;G0H)&-O;'5M;G,I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'-P86X@/2!R;W5N9"@Q,#`@+R!C;W5N="@D8V]L=6UN<RDI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!R
M97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N
M("<O<')E9G,O;W9E<G9I97<N:6YC)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE('1H92!F=6QL(&AE861E<B!O9B!A
M('!R969E<F5N8V4@<V-R965N(&EN8VQU9&EN9PH@("`@("H@;65N=2!A;F0@
M;F%V:6=A=&EO;B!B87)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&=R;W5P("!4:&4@9W)O=7`@=&\@9V5N97)A=&4@=&AE(&AE861E<B!F;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E2&5A9&5R*"1G<F]U<"`]
M(&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@)'!R969'
M<F]U<',L("1A<'`L("1P97)M<RP@)'!R969S+"`D;F]T:69I8V%T:6]N.PH*
M("`@("`@("`D=&ET;&4@/2!?*")5<V5R($]P=&EO;G,B*3L*("`@("`@("!I
M9B`H)&=R;W5P(#T]("=I9&5N=&ET:65S)R`F)B`A)'!R969S+3YI<TQO8VME
M9"@G9&5F875L=%]I9&5N=&ET>2<I*2!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H)VYE=T-H;VEC92@I)RP@)VIA=F%S8W)I<'0G*3L*("`@
M("`@("!]"B`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA
M=&5S)RP@)&%P<"D@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*("`@("`@("!I
M9B`H:7-?8V%L;&%B;&4H87)R87DH)&%P<"P@)V=E=$UE;G4G*2DI('L*("`@
M("`@("`@("`@)&UE;G4@/2!C86QL7W5S97)?9G5N8RAA<G)A>2@D87!P+"`G
M9V5T365N=2<I*3L*("`@("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E
M="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+VUE;G4O;65N=2YI;F,G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%5S92!A(&1E9F%U;'0@
M;65N=2X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-96YU
M+G!H<"<["B`@("`@("`@("`@("1M96YU(#T@)FYE=R!-96YU*"D["B`@("`@
M("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I("X@)R]M96YU+VUE;G4N:6YC)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]C86QL86)L92AA<G)A>2@D87!P+"`G<W1A='5S)RDI*2!["B`@
M("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1A<'`L("=S=&%T=7,G
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)$=,3T)!3%-;)VYO
M=&EF:6-A=&EO;B==+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T
M871U<R<I*3L*("`@("`@("!]"@H@("`@("`@("\J($=E="!L:7-T(&]F(&%C
M8V5S<VEB;&4@87!P;&EC871I;VYS+B`J+PH@("`@("`@("1A<'!S(#T@87)R
M87DH*3L*("`@("`@("!F;W)E86-H("@D<F5G:7-T<GDM/F%P<&QI8V%T:6]N
M<R!A<R`D87!P;&EC871I;VX@/3X@)'!A<F%M<RD@>PH@("`@("`@("`@("`O
M+R!-86ME('-U<F4@=&AE(&%P<"!I<R!I;G-T86QL960@86YD(&AA<R!A('!R
M969S(&9I;&4N"B`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)')E9VES
M=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<&QI8V%T:6]N*2`N("<O8V]N9FEG
M+W!R969S+G!H<"<I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1P87)A;7-;)W-T871U<R==
M(#T]("=H96%D:6YG)R!\?`H@("`@("`@("`@("`@("`@)'!A<F%M<ULG<W1A
M='5S)UT@/3T@)V)L;V-K)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-H96-K(&EF('1H92!C
M=7)R96YT('5S97(@:&%S('!E<FUI<W-O;B!T;R!S964@=&AI<PH@("`@("`@
M("`@("`@*B!A<'!L:6-A=&EO;BP@86YD(&EF('1H92!A<'!L:6-A=&EO;B!I
M<R!A8W1I=F4N"B`@("`@("`@("`@("`J($%D;6EN:7-T<F%T;W)S(&%L=V%Y
M<R!S964@86QL(&%P<&QI8V%T:6]N<RX@*B\*("`@("`@("`@("`@:68@*"A!
M=71H.CII<T%D;6EN*"D@)B8@)'!A<F%M<ULG<W1A='5S)UT@(3T@)VEN86-T
M:79E)RD@?'P*("`@("`@("`@("`@("`@("@D<F5G:7-T<GDM/FAA<U!E<FUI
M<W-I;VXH)&%P<&QI8V%T:6]N*2`F)@H@("`@("`@("`@("`@("`@("@D<&%R
M86US6R=S=&%T=7,G72`]/2`G86-T:79E)R!\?"`D<&%R86US6R=S=&%T=7,G
M72`]/2`G;F]T;V]L8F%R)RDI*2!["B`@("`@("`@("`@("`@("`D87!P<ULD
M87!P;&EC871I;VY=(#T@7R@D<&%R86US6R=N86UE)UTI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&%S;W)T*"1A<'!S*3L*"B`@("`@("`@
M+RH@4VAO=R!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;B!A;F0@82!F;W)M(&9O
M<B!S=VET8VAI;F<*("`@("`@("`@*B!A<'!L:6-A=&EO;G,N("HO"B`@("`@
M("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E
M)RD@+B`G+W!R969S+V%P<"YI;F,G.PH*("`@("`@("`O*B!)9B!T:&5R92=S
M(&]N;'D@;VYE('!R969'<F]U<"P@:G5S="!S:&]W(&ET+B`J+PH@("`@("`@
M(&EF("AE;7!T>2@D9W)O=7`I("8F(&-O=6YT*"1P<F5F1W)O=7!S*2`]/2`Q
M*2!["B`@("`@("`@("`@("1G<F]U<"`](&%R<F%Y7VME>7,H)'!R969'<F]U
M<',I.PH@("`@("`@("`@("`D9W)O=7`@/2!A<G)A>5]P;W`H)&=R;W5P*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&=R;W5P*2`F)B!0<F5F
M<U]523HZ9W)O=7!)<T5D:71A8FQE*"1G<F]U<"DI('L*("`@("`@("`@("`@
M<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@
M+B`G+W!R969S+V)E9VEN+FEN8R<["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1V5N97)A=&4@=&AE(&-O;G1E;G0@;V8@=&AE('1I=&QE(&)A
M<B!N879I9V%T:6]N(&-E;&P@*'!R979I;W5S('P@;F5X=`H@("`@("H@;W!T
M:6]N(&=R;W5P*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U
M<"`@0W5R<F5N="!O<'1I;VX@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E;F5R871E3F%V:6=A=&EO;D-E;&PH)&=R;W5P*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<')E9D=R;W5P<RP@)')E9VES=')Y+"`D87!P.PH*("`@("`@
M("`O+R!396%R8V@@9F]R('!R979I;W5S(&%N9"!N97AT(&=R;W5P<RX*("`@
M("`@("`D<')E=FEO=7,@/2!N=6QL.PH@("`@("`@("1N97AT(#T@;G5L;#L*
M("`@("`@("`D;&%S="`](&YU;&P["B`@("`@("`@)&9I<G-T(#T@;G5L;#L*
M("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("`D9FEN:7-H(#T@9F%L
M<V4["B`@("`@("`@9F]R96%C:"`H)'!R969'<F]U<',@87,@)'!G<F]U<"`]
M/B`D9W9A;"D@>PH@("`@("`@("`@("!I9B`H4')E9G-?54DZ.F=R;W5P27-%
M9&ET86)L92@D<&=R;W5P*2D@>PH@("`@("`@("`@("`@("`@:68@*"$D9FER
M<W0I('L*("`@("`@("`@("`@("`@("`@("`D9FER<W0@/2`D<&=R;W5P.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"$D9F]U;F0I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'!G<F]U<"`]/2`D9W)O=7`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!R979I;W5S(#T@)&QA<W0[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H(21F:6YI<V@I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I;FES:"`]('1R=64["B`@("`@("`@("`@("`@("`@
M("`@("`@("1N97AT(#T@)'!G<F]U<#L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;&%S="`]("1P
M9W)O=7`["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"$D
M<')E=FEO=7,I('L*("`@("`@("`@("`@)'!R979I;W5S(#T@)&QA<W0["B`@
M("`@("`@?0H@("`@("`@(&EF("@A)&YE>'0I('L*("`@("`@("`@("`@)&YE
M>'0@/2`D9FER<W0["B`@("`@("`@?0H*("`@("`@("`O*B!$;VXG="!L;V]P
M(&EF('1H97)E)W,@;VYL>2!O;F4@9W)O=7`N("HO"B`@("`@("`@:68@*"1N
M97AT(#T]("1P<F5V:6]U<RD@>PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("!E8VAO("<\=6P^/&QI/B<["B`@("`@("`@:68@*"%E
M;7!T>2@D<')E9D=R;W5P<ULD<')E=FEO=7-=6R=U<FPG72DI('L*("`@("`@
M("`@("`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC871I;VY5<FPH
M)'!R969'<F]U<'-;)'!R979I;W5S75LG=7)L)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%\H(E!R979I;W5S(&]P=&EO;G,B*2D["B`@("`@
M("`@("`@(&5C:&\@)R9L=#LF;'0[("<@+B`D<')E9D=R;W5P<ULD<')E=FEO
M=7-=6R=L86)E;"==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C
M:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU<FPH
M)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC
M97,O<')E9G,N<&AP)RDL(&%R<F%Y*"=G<F]U<"<@/3X@)'!R979I;W5S+"`G
M87!P)R`]/B`D87!P*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7R@B4')E=FEO=7,@;W!T:6]N<R(I*3L*("`@("`@("`@("`@96-H;R`G)FQT
M.R9L=#L@)R`N("1P<F5F1W)O=7!S6R1P<F5V:6]U<UU;)VQA8F5L)UT["B`@
M("`@("`@?0H@("`@("`@(&5C:&\@)SPO83XF;F)S<#M\)FYB<W`[)SL*("`@
M("`@("!I9B`H(65M<'1Y*"1P<F5F1W)O=7!S6R1N97AT75LG=7)L)UTI*2![
M"B`@("`@("`@("`@(&5C:&\@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"1P<F5F1W)O=7!S6R1N97AT75LG=7)L)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%\H(DYE>'0@;W!T:6]N<R(I*3L*("`@("`@
M("`@("`@96-H;R`D<')E9D=R;W5P<ULD;F5X=%U;)VQA8F5L)UT@+B`G("9G
M=#LF9W0[)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO($AO
M<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ=7)L*"1R96=I
M<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!R
M969S+G!H<"<I+"!A<G)A>2@G9W)O=7`G(#T^("1N97AT+"`G87!P)R`]/B`D
M87!P*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B3F5X="!O
M<'1I;VYS(BDI.PH@("`@("`@("`@("!E8VAO("1P<F5F1W)O=7!S6R1N97AT
M75LG;&%B96PG72`N("<@)F=T.R9G=#LG.PH@("`@("`@('T*("`@("`@("!E
M8VAO("<\+V$^/"]L:3X\+W5L/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE(&1E9F%U;'0@87!P;&EC871I;VX@=&\@<VAO=R!P<F5F97)E;F-E
M<R!F;W(N($1E9F%U;'1S"B`@("`@*B!T;R`G:&]R9&4G+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971$969A=6QT07!P*"D*("`@('L*("`@("`@("`D87!P
M;&EC871I;VYS(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!<'!S*&YU
M;&PL('1R=64L(%!%4DU37U)%040I.PH@("`@("`@(')E='5R;B!I<W-E="@D
M87!P;&EC871I;VYS6R=H;W)D92==*2`_("=H;W)D92<@.B!A<G)A>5]S:&EF
M="@D87!P;&EC871I;VYS*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]K;VQA8BYP:'``
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S-C<`,3`U,34T
M,S$P-C``,#(Q,3`T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+VQD
M87`N<&AP)SL*"B\J*@H@*B!+;VQA8B!I;7!L96UE;G1A=&EO;B!O9B!T:&4@
M2&]R9&4@<')E9F5R96YC92!S>7-T96TN($1E<FEV97,@9G)O;2!T:&4*("H@
M4')E9G-?;&1A<"!,1$%0(&%U=&AE;G1I8V%T:6]N(&]B:F5C="P@86YD('-I
M;7!L>2!P<F]V:61E<R!P87)A;65T97)S('1O(&ET"B`J(&)A<V5D(&]N('1H
M92!G;&]B86P@2V]L86(@8V]N9FEG=7)A=&EO;BX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O:V]L86(N<&AP+'8@,2XQ+C$P+C@@,C`P
M-B\P-B\R,2`R,#HP.3HP-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!3='5A<G0@0FEN9V4@/',N8FEN9V5`8V]D969U<VEO;BYC;RYZ
M83X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%-T=6%R="!":6YG92`\
M<RYB:6YG94!C;V1E9G5S:6]N+F-O+GIA/@H@*B!`<VEN8V4@("!(;W)D92`Q
M+C,*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S(%!R969S7VMO
M;&%B(&5X=&5N9',@4')E9G-?;&1A<"!["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1S(&$@;F5W($MO;&%B('!R969E<F5N8V5S(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@5&AE('5S97(@=VAO
M(&]W;G,@=&AE<V4@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P87-S=V]R9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`D=7-E
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E("`@("!4:&4@8W5R<F5N
M="!A<'!L:6-A=&EO;B!S8V]P92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E
M<G,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V%C:&EN9R`@4VAO=6QD(&-A
M8VAI;F<@8F4@=7-E9#\*("`@("`J+PH@("`@9G5N8W1I;VX@4')E9G-?:V]L
M86(H)'5S97(L("1P87-S=V]R9"P@)'-C;W!E(#T@)R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH*2P@)&-A8VAI;F<@/2!F
M86QS92D*("`@('L*("`@("`@("`D<&%R86US6R=H;W-T<W!E8R==(#T@)$=,
M3T)!3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=S97)V97(G73L*("`@
M("`@("`D<&%R86US6R=P;W)T)UT@/2`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA
M8B==6R=L9&%P)UU;)W!O<G0G73L*("`@("`@("`D<&%R86US6R=V97)S:6]N
M)UT@/2`G,R<["B`@("`@("`@)'!A<F%M<ULG8F%S961N)UT@/2`D1TQ/0D%,
M4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;)V)A<V5D;B==.PH@("`@("`@
M("1P87)A;7-;)V9E=&-H9&XG72`]('1R=64["B`@("`@("`@)'!A<F%M<ULG
M<V5A<F-H9&XG72`]("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G
M75LG<&AP9&XG73L*("`@("`@("`D<&%R86US6R=S96%R8VAP87-S)UT@/2`D
M1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;)W!H<'!W)UT["B`@
M("`@("`@)'!A<F%M<ULG=6ED)UT@/2!A<G)A>2@G;6%I;"<L("=U:60G*3L*
M"B`@("`@("`@<&%R96YT.CI0<F5F<U]L9&%P*"1U<V5R+"`D<&%S<W=O<F0L
M("1S8V]P92P@)'!A<F%M<RP@)&-A8VAI;F<I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'``````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4P,3`S`#$P-3$U-#,Q,#8P
M`#`R,#<R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*+RHJ"B`J($AO<F1E7U-T<FEN9R!C;&%S<RX*("HO"G)E
M<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@4')E9F5R
M96YC97,@<W1O<F%G92!I;7!L96UE;G1A=&EO;B!F;W(@4$A0)W,@3$1!4"!E
M>'1E;G1I;VXN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@
M("`G8F%S961N)R`@("!4:&4@8F%S92!$3B!F;W(@=&AE($Q$05`@<V5R=F5R
M+@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@3$1!4"!S
M97)V97(N"B`J("`@)W5I9"<@("`@("`@5&AE('5S97)N86UE('-E87)C:"!K
M97DN/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G<&%S<W=O<F0G("`G<F]O=&1N)W,@<&%S<W=O<F0@9F]R(&)I;F0@875T
M:&5N=&EC871I;VXN"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;V8@=&AE
M($Q$05`@<V5R=F5R+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z(#,X.0H@
M*B`@("=R;V]T9&XG("`@(%1H92!$3B!O9B!T:&4@<F]O="`H861M:6YI<W1R
M871I=F4I(&%C8V]U;G0@=&\@8FEN9"!F;W(*("H@("`@("`@("`@("`@("!W
M<FET92!O<&5R871I;VYS+@H@*B`@("=U<V5R;F%M92<@(%1/1$\*("H@("`G
M=F5R<VEO;B<@("!4:&4@=F5R<VEO;B!O9B!T:&4@3$1!4"!P<F]T;V-O;"!T
M;R!U<V4N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@3D].12`H<WES=&5M
M(&1E9F%U;'0@=VEL;"!B92!U<V5D*3PO<')E/@H@*@H@*B!.3U1%.B!P87)A
M;65T97(@)W5S97)N86UE)R!H87,@8F5E;B!D97!R96-A=&5D+B!5<V4@)W)O
M;W1D;B<N"B`J"B`J"B`J($EF('-E='1I;F<@=7`@87,@=&AE($AO<F1E('!R
M969E<F5N8V4@:&%N9&QE<B!I;B!C;VYF+G!H<"P@=&AE(&9O;&QO=VEN9PH@
M*B!I<R!A;B!E>&%M<&QE(&-O;F9I9W5R871I;VXN"B`J(%1H92!S8VAE;6%S
M(&YE961E9"!F;W(@;&1A<"!A<F4@:6X@:&]R9&4O<V-R:7!T<R]L9&%P+@H@
M*@H@*B`\<')E/@H@*B`@("1C;VYF6R=P<F5F<R==6R=D<FEV97(G72`]("=L
M9&%P)SL*("H@("`D8V]N9ELG<')E9G,G75LG<&%R86US)UU;)VAO<W1S<&5C
M)UT@/2`G;&]C86QH;W-T)SL*("H@("`D8V]N9ELG<')E9G,G75LG<&%R86US
M)UU;)W!O<G0G72`]("<S.#DG.PH@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A
M;7,G75LG8F%S961N)UT@/2`G9&,]97AA;7!L92QD8SUO<F<G.PH@*B`@("1C
M;VYF6R=P<F5F<R==6R=P87)A;7,G75LG=6ED)UT@/2`G;6%I;"<["B`J(#PO
M<')E/@H@*@H@*B!4:&4@9F]L;&]W:6YG(&ES('9A;&ED(&)U="!W;W5L9"!O
M;FQY(&)E(&YE8V5S<V%R>2!I9B!U<V5R<PH@*B!D;R!.3U0@:&%V92!P97)M
M:7-S:6]N('1O(&UO9&EF>2!T:&5I<B!O=VX@3$1!4"!A8V-O=6YT<RX*("H*
M("H@/'!R93X*("H@("`D8V]N9ELG<')E9G,G75LG<&%R86US)UU;)W)O;W1D
M;B==(#T@)V-N/4UA;F%G97(L9&,]97AA;7!L92QD8SUO<F<G.PH@*B`@("1C
M;VYF6R=P<F5F<R==6R=P87)A;7,G75LG<&%S<W=O<F0G72`]("=P87-S=V]R
M9"<["B`J(#PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]L9&%P+G!H<"QV(#$N.#4N,3`N,C`@,C`P-B\P-B\R,2`R,#HP
M-SHU-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@
M4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0
M<F5F<U]L9&%P(&5X=&5N9',@4')E9G,@>PH*("`@("\J*@H@("`@("H@2&%S
M:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT
M($Q$05`@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E
M"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@
M*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!O<B!N;W0@=V4G<F4@8V]N
M;F5C=&5D('1O('1H92!,1$%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T:&4@=7-E<B=S($1.
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7V1N(#T@)R<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($Q$
M05`@<')E9F5R96YC97,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97(@("`@("!4:&4@=7-E<B!W:&\@;W=N<R!T:&5S92!P<F5F
M97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!4:&4@
M<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U<V5R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<V-O<&4@("`@(%1H92!C=7)R96YT(&%P<&QI8V%T:6]N('-C
M;W!E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C
M;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J($!P87)A
M;2!B;V]L96%N("1C86-H:6YG("!3:&]U;&0@8V%C:&EN9R!B92!U<V5D/PH@
M("`@("HO"B`@("!F=6YC=&EO;B!0<F5F<U]L9&%P*"1U<V5R+"`D<&%S<W=O
M<F0L("1S8V]P92`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M86US(#T@87)R87DH*2P@)&-A8VAI;F<@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;&1A<"<I*2!["B`@("`@
M("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*%\H(E!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB*2DL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7W5S97(@/2`D=7-E<CL*("`@("`@("`D=&AI<RT^7W-C;W!E(#T@)'-C
M;W!E.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@("`@
M("`D=&AI<RT^7V-A8VAI;F<@/2`D8V%C:&EN9SL*"B`@("`@("`@+RH@268@
M82!V86QI9"!S97)V97(@<&]R="!H87,@;F]T(&)E96X@<W!E8VEF:65D+"!S
M970@=&AE(&1E9F%U;'0N("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A<F%M<ULG<&]R="==*2!\?"`A:7-?:6YT*"1T:&ES+3Y?<&%R86US6R=P
M;W)T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UT@
M/2`S.#D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B`D<&%R86US6R=R;V]T
M9&XG72!I<R!E;7!T>2P@875T:&5N=&EC871E(&%S('1H92!C=7)R96YT('5S
M97(N"B`@("`@("`@("`@3F]T93H@5&AI<R!A<W-U;65S('1H92!U<V5R(&ES
M(&%L;&]W960@=&\@;6]D:69Y('1H96ER(&]W;B!,1$%0"B`@("`@("`@("`@
M("`@("`@96YT<GDN("HO"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M92==*2`F)@H@("`@("`@("`@("!E;7!T>2@D=&AI<RT^
M7W!A<F%M<ULG<F]O=&1N)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M92==(#T@)'5S97(["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P87-S=V]R9"==(#T@)'!A<W-W;W)D.PH@("`@("`@('T*"B`@
M("`@("`@<&%R96YT.CI0<F5F<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3W!E;G,@82!C;VYN96-T:6]N('1O('1H92!,1$%0('-E<G9E<BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I
M"B`@("!["B`@("`@("`@+RH@4F5T=7)N(&EF(&%L<F5A9'D@8V]N;F5C=&5D
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIA
M<W-E<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=P<F5F<R<L"B`@
M("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=B87-E9&XG+"`G=6ED)RP@
M)W!A<W-W;W)D)RDL"B`@("`@("`@("`@("=P<F5F97)E;F-E<R!,1$%0)RD[
M"@H@("`@("`@("\J($%L;&]W(&9O<B!M=6QT:7!L92!U:60@<V5A<F-H(&9I
M96QD<R`J+PH@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A;7-;
M)W5I9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=6ED)UT@
M/2!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG=6ED)UTI.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(@86YO;GEM;W5S
M;'DN("HO"B`@("`@("`@)&-O;FX@/2!L9&%P7V-O;FYE8W0H)'1H:7,M/E]P
M87)A;7-;)VAO<W1S<&5C)UTL("1T:&ES+3Y?<&%R86US6R=P;W)T)UTI.PH@
M("`@("`@(&EF("@A)&-O;FXI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H"B`@("`@("`@("`@("`@("!S<')I;G1F*"=&86EL960@=&\@;W!E
M;B!A;B!,1$%0(&-O;FYE8W1I;VX@=&\@)7,N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTI+`H@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('1H92!,1$%0
M('!R;W1O8V]L('9E<G-I;VXN("HO"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@(&EF("@A;&1A
M<%]S971?;W!T:6]N*"1C;VYN+"!,1$%07T]05%]04D]43T-/3%]615)324].
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G4V5T($Q$
M05`@<')O=&]C;VP@=F5R<VEO;B!T;R`E9"!F86EL960Z(%LE9%T@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9E
M<G-I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R
M;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C;VYN96-T:6]N*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!N96-E<W-A
M<GDL(&)I;F0@=&\@=&AE($Q$05`@<V5R=F5R(&%S('1H92!U<V5R('=I=&@@
M<V5A<F-H"B`@("`@("`@("H@<&5R;6ES<VEO;G,N("HO"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<V5A<F-H9&XG72DI('L*("`@("`@
M("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD*"1C;VYN+"`D=&AI<RT^7W!A<F%M
M<ULG<V5A<F-H9&XG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=S96%R8VAP87-S)UTI.PH@("`@("`@("`@("!I
M9B`H(21B:6YD*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*"=":6YD('1O('-E<G9E<B`E<SHE9"!W:71H($1.
M("5S(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T
M<W!E8R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R="==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<V5A<F-H9&XG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O
M;FYE8W1I;VXI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI
M*3L*("`@("`@("`@("`@?0H)?0H*("`@("`@("`O*B!296=I<W1E<B!O=7(@
M8V%L;&)A8VL@9G5N8W1I;VX@=&\@:&%N9&QE(')E9F5R<F%L<RX@*B\*("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=L9&%P7W-E=%]R96)I;F1?<')O
M8R<I("8F"B`@("`@("`@("`@("%L9&%P7W-E=%]R96)I;F1?<')O8R@D8V]N
M;BP@87)R87DH)'1H:7,L("=?<F5B:6YD4')O8R<I*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@("`@('-P<FEN=&8H
M)U-E="!R96)I;F0@<')O8R!F86EL960Z(%LE9%T@)7,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES+3Y?8V]N;F5C=&EO;BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C
M;VYN96-T:6]N*2DL"B`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!3=&]R92!T:&4@8V]N;F5C=&EO;B!H86YD;&4@870@=&AE(&EN
M<W1A;F-E(&QE=F5L+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C=&EO;B`]
M("1C;VYN.PH@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*"B`@
M("`@("`@:68@*"$D=&AI<RT^7W!A<F%M<ULG9F5T8VAD;B==*2!["B`@("`@
M("`@("`@("\J($1E9FEN92!T:&4@1$X@;V8@=&AE(&-U<G)E;G0@=7-E<BX@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]D;B`]('-P<FEN=&8H)R5S/25S+"5S
M)RP@)'1H:7,M/E]P87)A;7-;)W5I9"==6S!=+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72D[
M"@H@("`@("`@("`@("`O*B!!;F0@=&AE($1.(&]F('1H92!A=71H96YT:6-A
M=&EN9R!U<V5R("AM87D@8F4@=&AE('-A;64@87,@86)O=F4I+B`J+PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=R;V]T9&XG72DI
M('L*("`@("`@("`@("`@("`@("1B:6YD7V1N(#T@)'1H:7,M/E]P87)A;7-;
M)W)O;W1D;B==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&)I;F1?9&X@/2!S<')I;G1F*"<E<STE<RPE<R<L("1T:&ES+3Y?<&%R
M86US6R=U:60G75LP72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG8F%S961N
M)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!":6YD('1O('1H
M92!,1$%0('-E<G9E<B!A<R!T:&4@875T:&5N=&EC871I;F<@=7-E<BX@*B\*
M("`@("`@("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD*"1T:&ES+3Y?8V]N;F5C
M=&EO;BP@)&)I;F1?9&XL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@("`@(&EF
M("@A)&)I;F0I('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*`H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H)T)I;F0@=&\@<V5R=F5R
M("5S.B5D('=I=&@@1$X@)7,@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1B:6YD7V1N
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI
M<RT^7V-O;FYE8W1I;VXI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!396%R8V@@9F]R('1H92!U<V5R)W,@9G5L;"!$3BX@*B\*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG=6ED)UT@87,@)'5I9%]F:65L
M9"D@>PH@("`@("`@("`@("`D<V5A<F-H(#T@;&1A<%]S96%R8V@H)'1H:7,M
M/E]C;VYN96-T:6]N+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6ED7V9I96QD("X@)STG
M("X@)'1H:7,M/E]U<V5R+"!A<G)A>2@G9&XG*2D["B`@("`@("`@("`@(&EF
M("@D<V5A<F-H*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@;&1A<%]G
M971?96YT<FEE<R@D=&AI<RT^7V-O;FYE8W1I;VXL("1S96%R8V@I.PH@("`@
M("`@("`@("`@("`@:68@*"1R97-U;'0@)B8@)')E<W5L=%LG8V]U;G0G72`^
M(#`I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1N(#T@)')E<W5L
M=%LP75LG9&XG73L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]P
M87)A;7-;)V9E=&-H9&XG72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!292UB:6YD(&%S('1H92!U<V5R+@H@("`@("`@("`@("`@("`@("`@("`@
M("`D8FEN9"`]($!L9&%P7V)I;F0H)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI
M<RT^7V1N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H"B`@("`@("`@("`@('-P<FEN=&8H
M)T9A:6QE9"!T;R!R971R:65V92!U<V5R7"=S($1..B!;)61=("5S)RP*("`@
M("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES+3Y?8V]N;F5C=&EO
M;BDL"B`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O
M;FYE8W1I;VXI*2P*("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&ES8V]N;F5C="!F<F]M('1H92!,1$%0('-E<G9E<B!A;F0@8VQE86X@=7`@
M=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D
M:7-C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T
M960I('L*("`@("`@("`@("`@)'1H:7,M/E]D;B`]("<G.PH@("`@("`@("`@
M("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U
M<FX@;&1A<%]C;&]S92@D=&AI<RT^7V-O;FYE8W1I;VXI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($-A;&QB86-K(&9U;F-T:6]N(&9O<B!,1$%0
M(')E9F5R<F%L<RX@(%1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D('=H96X@86X*
M("`@("`J($Q$05`@;W!E<F%T:6]N(')E='5R;G,@82!R969E<G)A;"!T;R!A
M;B!A;'1E<FYA=&4@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@,2!O;B!E<G)O
M<BP@,"!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5B:6YD
M4')O8R@D8V]N;BP@)'=H;RD*("`@('L*("`@("`@("`O*B!3=')I<"!O=70@
M=&AE(&AO<W1N86UE('=E)W)E(&)E:6YG(')E9&ER96-T960@=&\N("HO"B`@
M("`@("`@)'=H;R`]('!R96=?<F5P;&%C92AA<G)A>2@G?%XN*CHO+WPG+"`G
M?#I<9"HD?"<I+"`G)RP@)'=H;RD["@H@("`@("`@("\J($9I9W5R92!O=70@
M=&AE($1.(&]F('1H92!A=71H96YT:6-A=&EN9R!U<V5R+B`J+PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W)O;W1D;B==*2D@>PH@("`@
M("`@("`@("`D8FEN9%]D;B`]("1T:&ES+3Y?<&%R86US6R=R;V]T9&XG73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8FEN9%]D;B`]('-P<FEN
M=&8H)R5S/25S+"5S)RP@)'1H:7,M/E]P87)A;7-;)W5I9"==6S!=+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S
M97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG8F%S961N)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M36%K92!S=7)E('1H92!S97)V97(@=V4G<F4@8F5I;F<@<F5D:7)E8W1E9"!T
M;R!I<R!I;B!O=7(@;&ES="!O9@H@("`@("`@("`@('9A;&ED('-E<G9E<G,N
M("HO"B`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7W!A<F%M<ULG:&]S='-P
M96,G72P@)'=H;RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*`H@("`@("`@("`@("`@("`@<W!R:6YT9B@G4F5F97)R86P@
M=&%R9V5T("5S(&9O<B!$3B`E<R!I<R!N;W0@:6X@=&AE(&%U=&AO<FEZ960@
M<V5R=F5R(&QI<W0A)RP@)'=H;RP@)&)I;F1?9&XI+`H@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@<F5T=7)N(#$[
M"B`@("`@("`@?0H*("`@("`@("`O*B!":6YD('1O('1H92!N97<@<V5R=F5R
M+B`J+PH@("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D8V]N;BP@)&)I;F1?
M9&XL("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*3L*("`@("`@("!I9B`H
M(21B:6YD*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@
M("`@("`@("`@("`@<W!R:6YT9B@G4F5B:6YD('1O('-E<G9E<B`E<SHE9"!W
M:71H($1.("5S(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R="==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D8FEN9%]D;BP*("`@("`@("`@("`@("`@("`@
M("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O;FYE8W1I;VXI+`H@("`@("`@
M("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO
M;BDI+`H@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`P.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T<FEE=F5S('1H92!R97%U97-T960@<V5T(&]F('!R969E<F5N8V5S
M(&9R;VT@=&AE('5S97(G<R!,1$%0(&5N=')Y+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I
M979E*"D*("`@('L*("`@("`@("`O*B!!='1E;7!T('1O('!U;&P@=&AE('9A
M;'5E<R!F<F]M('1H92!S97-S:6]N(&-A8VAE(&9I<G-T+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^8V%C:&5,;V]K=7`H*2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J($QO860@9&5F875L=',@
M=&\@;6%K92!S=7)E('=E(&AA=F4@86QL('!R969E<F5N8V5S+B`J+PH@("`@
M("`@('!A<F5N=#HZ<F5T<FEE=F4H*3L*"B`@("`@("`@+RH@36%K92!S=7)E
M('=E(&%R92!C;VYN96-T960N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M*"D["@H@("`@("`@("\J($]N;'D@9F5T8V@@=&AE(&9I96QD<R!F;W(@=&AE
M(&%T=')I8G5T97,@=V4@;F5E9"X@*B\*("`@("`@("`D871T<G,@/2!A<G)A
M>2@G:&]R9&50<F5F<R<I.PH@("`@("`@(&EF("AS=')C;7`H)'1H:7,M/E]S
M8V]P92P@)VAO<F1E)RD@(3T@,"D@>PH@("`@("`@("`@("`D871T<G-;72`]
M("1T:&ES+3Y?<V-O<&4@+B`G4')E9G,G.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4V5A<F-H(&9O<B!T:&4@;75L=&DM=F%L=65D(&9I96QD(&-O;G1A:6YI
M;F<@=&AE(&%R<F%Y(&]F"B`@("`@("`@("`@<')E9F5R96YC97,N("HO"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;)W5I9"==(&%S("1U:61?
M9FEE;&0I('L*("`@("`@("`@("`@)'-E87)C:"`](&QD87!?<V5A<F-H*"1T
M:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5I9%]F:65L9"`N
M("<])R`N("1T:&ES+3Y?=7-E<BP@)&%T=')S*3L*("`@("`@("`@("`@:68@
M*"1S96%R8V@I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!L9&%P7V=E
M=%]E;G1R:65S*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'-E87)C:"D["B`@("`@
M("`@("`@("`@("!I9B`H)')E<W5L="`F)B`D<F5S=6QT6R=C;W5N="==(#X@
M,"D@>PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S
M970H)')E<W5L="DI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)T9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<')E9F5R96YC97,@<V5R=F5R
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O
M*B!L9&%P7V=E=%]E;G1R:65S*"D@8V]N=F5R=',@871T<FEB=71E(&EN9&5X
M97,@=&\@;&]W97)C87-E+B`J+PH@("`@("`@("1F:65L9"`](%-T<FEN9SHZ
M;&]W97(H)'1H:7,M/E]S8V]P92`N("=P<F5F<R<I.PH*("`@("`@("!I9B`H
M:7-S970H)')E<W5L="DI('L*("`@("`@("`@("`@+RH@4V5T('1H92!R97%U
M97-T960@=F%L=65S(&EN('1H92`D=&AI<RT^7W!R969S(&AA<V@@8F%S960@
M;VX*("`@("`@("`@("`@("`@=&AE(&-O;G1E;G1S(&]F('1H92!,1$%0(')E
M<W5L="X*"B`@("`@("`@("`@("`@(%!R969E<F5N8V5S(&%R92!S=&]R960@
M87,@8V]L;VXM<V5P87)A=&5D(&YA;64Z=F%L=64@<&%I<G,N"B`@("`@("`@
M("`@("`@($5A8V@@<&%I<B!I<R!S=&]R960@87,@:71S(&]W;B!A='1R:6)U
M=&4@;V9F(&]F('1H92!M=6QT:2T*("`@("`@("`@("`@("`@=F%L=64@871T
M<FEB=71E(&YA;65D(&EN.B`D=&AI<RT^7W-C;W!E("X@)U!R969S)PH*("`@
M("`@("`@("`@("`@3F]T92!T:&%T(%!R969S.CIS971686QU92@I(&-A;B=T
M(&)E('5S960@:&5R92!B96-A=7-E(&]F('1H90H@("`@("`@("`@("`@("!C
M:&5C:R!F;W(@=&AE(")C:&%N9V5A8FQE(B!B:70N("!792!W86YT('1O(&]V
M97)R:61E('1H870*("`@("`@("`@("`@("`@8VAE8VL@=VAE;B!P;W!U;&%T
M:6YG('1H92`D=&AI<RT^7W!R969S(&AA<V@@9G)O;2!T:&4@3$1!4`H@("`@
M("`@("`@("`@("!S97)V97(N"B`@("`@("`@("`@("`J+PH*("`@("`@("`@
M("`@)'!R969S(#T@87)R87DH*3L*"B`@("`@("`@("`@("\J($EF(&AO<F1E
M4')E9G,@97AI<W1S+"!M97)G92!T:&5M(&%S('1H92!B87-E(&]F('1H92!P
M<F5F<RX@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1R97-U;'1;,%U;)VAO
M<F1E<')E9G,G72DI('L*("`@("`@("`@("`@("`@("1P<F5F<R`](&%R<F%Y
M7VUE<F=E*"1P<F5F<RP@)')E<W5L=%LP75LG:&]R9&5P<F5F<R==*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@268@=&AI<R!S8V]P92=S('!R
M969S(&%R92!A=F%I;&%B;&4L(&UE<F=E('1H96T@87,@=VEL;"X@($=I=F4*
M("`@("`@("`@("`@("H@=&AE;2!A(&AI9VAE<B!P<F5C961E;F-E('1H86X@
M:&]R9&50<F5F<RX@*B\*("`@("`@("`@("`@:68@*'-T<F-M<"@D=&AI<RT^
M7W-C;W!E+"`G:&]R9&4G*2`A/2`P*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)')E<W5L=%LP75LD9FEE;&1=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1P<F5F<R`](&%R<F%Y7VUE<F=E*"1P<F5F<RP@)')E<W5L=%LP75LD
M9FEE;&1=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@9F]R96%C:"`H)'!R969S(&%S("1P<F5F<W1R*2!["B`@("`@
M("`@("`@("`@("`O*B!)9B!T:&4@<W1R:6YG(&1O97-N)W0@8V]N=&%I;B!A
M(&-O;&]N(&1E;&EM:71E<BP@<VMI<"!I="X@*B\*("`@("`@("`@("`@("`@
M(&EF("AS=6)S=')?8V]U;G0H)'!R969S='(L("<Z)RD@/3T@,"D@>PH@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("\J(%-P;&ET('1H92!S=')I;F<@:6YT;R!I=',@
M;F%M93IV86QU92!C;VUP;VYE;G1S+B`J+PH@("`@("`@("`@("`@("`@;&ES
M="@D<')E9BP@)'9A;"D@/2!S<&QI="@G.B<L("1P<F5F<W1R+"`R*3L*"B`@
M("`@("`@("`@("`@("`O*B!2971R:65V92!T:&ES('!R969E<F5N8V4N("HO
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<ULD<')E
M9ETI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971686QU92@D
M<')E9BP@8F%S938T7V1E8V]D92@D=F%L*2P@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS971$969A=6QT*"1P<F5F+"!F86QS92D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YA9&0H)'!R968L(&)A<V4V-%]D96-O9&4H)'9A;"DL(%]04D5&7U-(
M05)%1"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($-A;&P@:&]O:W,N("HO"B`@("`@("`@("`@("1T:&ES+3Y?
M8V%L;$AO;VMS*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)TYO('!R969E<F5N8V5S('=E<F4@<F5T<FEE=F5D
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T92!T:&4@<V5S<VEO;B!C86-H
M92X@*B\*("`@("`@("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@<')E
M9F5R96YC97,@=&\@=&AE($Q$05`@<V5R=F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E
M*"D*("`@('L*("`@("`@("`D=7!D871E9"`]('1R=64["@H@("`@("`@("\J
M($-H96-K(&9O<B!A;GD@(F1I<G1Y(B!P<F5F97)E;F-E<RX@268@;F\@(F1I
M<G1Y(@H@("`@("`@("`J('!R969E<F5N8V5S(&%R92!F;W5N9"P@=&AE<F4G
M<R!N;R!N965D('1O('5P9&%T92!T:&4@3$1!4`H@("`@("`@("`J('-E<G9E
M<BX@17AI="!S=6-C97-S9G5L;'DN("HO"B`@("`@("`@)&1I<G1Y7W!R969S
M(#T@)'1H:7,M/E]D:7)T>5!R969S*"D["B`@("`@("`@:68@*"%C;W5N="@D
M9&ER='E?<')E9G,I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('=E(&%R92!C;VYN96-T960N
M("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U
M:6QD(&$@:&%S:"!O9B!T:&4@<')E9F5R96YC97,@86YD('1H96ER('9A;'5E
M<R!T:&%T(&YE960*("`@("`@("`@*B!T;R!B92!S=&]R960@:6X@=&AE($Q$
M05`@<V5R=F5R+B!"96-A=7-E('=E(&AA=F4@=&\@=7!D871E"B`@("`@("`@
M("H@86QL(&]F('1H92!V86QU97,@;V8@82!M=6QT:2UV86QU92!E;G1R>2!W
M:&]L97-A;&4L('=E"B`@("`@("`@("H@8V%N)W0@:G5S="!P:6-K(&]U="!T
M:&4@9&ER='D@<')E9F5R96YC97,[('=E(&UU<W0@=7!D871E"B`@("`@("`@
M("H@979E<GET:&EN9RX@*B\*("`@("`@("`D;F5W7W9A;'5E<R`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^7W!R969S
M*2!A<R`D<')E9BD@>PH@("`@("`@("`@("`O+R!$;VXG="!S=&]R92!L;V-K
M960@<')E9F5R96YC97,N"B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES3&]C
M:V5D*"1P<F5F*2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y(#T@)'!R968@
M+B`G.B<@+B!B87-E-C1?96YC;V1E*"1T:&ES+3YG971686QU92@D<')E9BDI
M.PH@("`@("`@("`@("`@("`@)&9I96QD(#T@)'1H:7,M/F=E=%-C;W!E*"1P
M<F5F*2`N("=0<F5F<R<["B`@("`@("`@("`@("`@("`D;F5W7W9A;'5E<ULD
M9FEE;&1=6UT@/2`D96YT<GD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J($5N=')I97,@;75S="!H879E('1H92!O8FIE8W1C;&%S<V5S
M("=T;W`G(&%N9"`G:&]R9&5P97)S;VXG"B`@("`@("`@("H@=&\@<W5C8V5S
M<V9U;&QY('-T;W)E($Q$05`@<')E9G,N($-H96-K(&9O<B!B;W1H(&]F('1H
M96TL"B`@("`@("`@("H@86YD(&%D9"!T:&5M(&EF(&YE8V5S<V%R>2X@*B\*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG=6ED)UT@87,@)'5I
M9%]F:65L9"D@>PH@("`@("`@("`@("`D<V5A<F-H(#T@;&1A<%]S96%R8V@H
M)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6ED7V9I96QD
M("X@)STG("X@)'1H:7,M/E]U<V5R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V]B:F5C=&-L87-S)RDI.PH@("`@("`@("`@
M("!I9B`H)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](&QD
M87!?9V5T7V5N=')I97,H)'1H:7,M/E]C;VYN96-T:6]N+"`D<V5A<F-H*3L*
M("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT("8F("1R97-U;'1;)V-O=6YT
M)UT@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)'1O<"`](&9A;'-E.PH@
M("`@("`@("`@("`@("`@("`@("1H;W)D97!E<G-O;B`](&9A;'-E.PH*("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<F5S=6QT6S!=
M6R=O8FIE8W1C;&%S<R==6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D<F5S=6QT6S!=6R=O8FIE8W1C;&%S<R==6R1I
M72`]/2`G=&]P)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1O
M<"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D
M<F5S=6QT6S!=6R=O8FIE8W1C;&%S<R==6R1I72`]/2`G:&]R9&5097)S;VXG
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:&]R9&5P97)S;VX@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O*B!!9&0@86YY(&UI
M<W-I;F<@;V)J96-T8VQA<W-E<RX@*B\*("`@("`@("`@("`@("`@("`@("!I
M9B`H(21T;W`I('L*("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]M;V1?
M861D*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]D;BP@87)R87DH)V]B
M:F5C=&-L87-S)R`]/B`G=&]P)RDI.PH@("`@("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`@("`@:68@*"$D:&]R9&5P97)S;VXI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@;&1A<%]M;V1?861D*"1T:&ES+3Y?8V]N
M;F5C=&EO;BP@)'1H:7,M/E]D;BP@87)R87DH)V]B:F5C=&-L87-S)R`]/B`G
M:&]R9&5097)S;VXG*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!396YD('1H92!H87-H
M('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("!I9B`H;&1A<%]M;V1?
M<F5P;&%C92@D=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?9&XL("1N97=?
M=F%L=65S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D9&ER='E?<')E9G,@
M87,@)'!R968I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971$:7)T>2@D
M<')E9BP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H"B`@("`@("`@("`@("`@
M('-P<FEN=&8H)U5N86)L92!T;R!M;V1I9GD@<')E9F5R96YC97,Z(%LE9%T@
M)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES
M+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?
M97)R;W(H)'1H:7,M/E]C;VYN96-T:6]N*2DL"B`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`D=7!D871E9"`](&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@071T96UP="!T;R!C86-H92!T
M:&4@<')E9F5R96YC97,@:6X@=&AE('-E<W-I;VXN("HO"B`@("`@("`@)'1H
M:7,M/F-A8VAE57!D871E*"D["@H@("`@("`@(')E='5R;B`D=7!D871E9#L*
M("`@('T*"B`@("`O*BH*("`@("`J($-L96%R<R!A;&P@<')E9F5R96YC97,@
M9G)O;2!T:&4@3$1!4"!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&5A<B@I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&%R92!C;VYN
M96-T960N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("1A='1R<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YL:7-T07!P<RAA<G)A
M>2@G:6YA8W1I=F4G+"`G86-T:79E)RP@)VAI9&1E;B<L("=N;W1O;VQB87(G
M+"`G861M:6XG*2D["B`@("`@("`@9F]R96%C:"`H)&%T=')S(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("`D871T<G-;)&ME>5T@/2`D=F%L("X@
M)U!R969S)SL*("`@("`@("!]"@H@("`@("`@("1S96%R8V@@/2!L9&%P7W)E
M860H)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7V1N+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V]B:F5C=$-L87-S/6AO<F1E4&5R<V]N)RP@
M)&%T=')S+"`Q*3L*"B`@("`@("`@:68@*"1S96%R8V@I('L*("`@("`@("`@
M("`@)')E<W5L="`](&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]C;VYN96-T
M:6]N+"`D<V5A<F-H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!P
M<F5F97)E;F-E<R!S97)V97(N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@("1A='1R<R`](&%R<F%Y*"D["B`@("`@("`@:68@
M*"1R97-U;'0I('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)')E
M<W5L=%LP75LG8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&%T
M=')S6R1R97-U;'1;,%U;)&E=72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"%L9&%P7VUO9%]D96PH)'1H:7,M/E]C;VYN96-T
M:6]N+"`D=&AI<RT^7V1N+"`D871T<G,I*2!["B`@("`@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@("`@("`@("!S<')I;G1F
M*"=5;F%B;&4@=&\@8VQE87(@<')E9F5R96YC97,Z(%LE9%T@)7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O
M;FYE8W1I;VXI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E
M<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H"B`@("`@
M("`@("`@("`@("!S<')I;G1F*"=5;F%B;&4@=&\@8VQE87(@<')E9F5R96YC
M97,Z(%LE9%T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R
M<FYO*"1T:&ES+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@(&QD87!?97)R;W(H)'1H:7,M/E]C;VYN96-T:6]N*2DL"B`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/F-L96%N=7`H=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!097)F;W)M(&-L96%N=7`@;W!E<F%T:6]N<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D86QL("!#;&5A;G5P(&%L;"!(;W)D92!P<F5F97)E
M;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE86YU<"@D86QL(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@+RH@0VQO<V4@=&AE($Q$05`@8V]N;F5C=&EO
M;BX@*B\*("`@("`@("`D=&AI<RT^7V1I<V-O;FYE8W0H*3L*"B`@("`@("`@
M<&%R96YT.CIC;&5A;G5P*"1A;&PI.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<```
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,#<T`#$P-3$U-#,Q,#8P`#`R,S`V
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@0VQA<W,@9F]R(&AA;F1L:6YG(&$@;&ES="!O9B!C871E
M9V]R:65S('-T;W)E9"!I;B!A('5S97(G<PH@*B!P<F5F97)E;F-E<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<"QV(#$N,3$N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,R(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA
M<W,@4')E9G-?0V%T96=O<GE-86YA9V5R('L*"B`@("`O*BH*("`@("`J($=E
M="!A;&P@8V%T96=O<FEE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T*"D*
M("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`D<W1R:6YG
M(#T@)'!R969S+3YG971686QU92@G8V%T96=O<FEE<R<I.PH@("`@("`@(&EF
M("AE;7!T>2@D<W1R:6YG*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@("1C871E9V]R:65S(#T@97AP;&]D92@G
M?"<L("1S=')I;F<I.PH@("`@("`@(&%S;W)T*"1C871E9V]R:65S*3L*"B`@
M("`@("`@<F5T=7)N("1C871E9V]R:65S.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%-E;&5C="@D:60L("1C=7)R96YT(#T@;G5L;"D*("`@('L*("`@("`@
M("!G;&]B86P@)'!R969S.PH*("`@("`@("`D:'1M;"`]("<\<V5L96-T(&ED
M/2(G("X@:'1M;'-P96-I86QC:&%R<R@D:60I("X@)R(@;F%M93TB)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H)&ED*2`N("<B/B<["@H@("`@("`@("1C871E9V]R
M:65S(#T@4')E9G-?0V%T96=O<GE-86YA9V5R.CIG970H*3L*("`@("`@("!I
M9B`H(6EN7V%R<F%Y*"1C=7)R96YT+"`D8V%T96=O<FEE<RD@)B8@(65M<'1Y
M*"1C=7)R96YT*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V
M86QU93TB*FYE=RHG("X@:'1M;'-P96-I86QC:&%R<R@D8W5R<F5N="D@+B`G
M(CXG("X@<W!R:6YT9BA?*")5<V4@0W5R<F5N=#H@)7,B*2P@:'1M;'-P96-I
M86QC:&%R<R@D8W5R<F5N="DI("X@)SPO;W!T:6]N/B<@+@H@("`@("`@("`@
M("`@("`@)SQO<'1I;VX@=F%L=64](B(^+2TM+3PO;W!T:6]N/B<["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(21P<F5F<RT^:7-,;V-K960H)V-A=&5G;W)I
M97,G*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB
M*FYE=RHB/B<@+B!?*").97<@0V%T96=O<GDB*2`N("(\+V]P=&EO;CY<;B(@
M+@H@("`@("`@("`@("`@("`@)SQO<'1I;VX@=F%L=64](B(^+2TM+3PO;W!T
M:6]N/B<["B`@("`@("`@?0H*("`@("`@("`O+R!!;'=A>7,@861D(&%N(%5N
M9FEL960@;W!T:6]N+@H@("`@("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E
M/2(B)R`N"B`@("`@("`@("`@("AE;7!T>2@D8W5R<F5N="D@/R`G('-E;&5C
M=&5D/2)S96QE8W1E9"(^)R`Z("<^)RD@+@H@("`@("`@("`@("!H=&UL<W!E
M8VEA;&-H87)S*%\H(E5N9FEL960B*2D@+B`G/"]O<'1I;VX^)SL*"B`@("`@
M("`@9F]R96%C:"`H)&-A=&5G;W)I97,@87,@)&YA;64I('L*("`@("`@("`@
M("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1N86UE*2`N("<B)R`N"B`@("`@("`@("`@("`@("`H)&YA;64@/3T]
M("1C=7)R96YT(#\@)R!S96QE8W1E9#TB<V5L96-T960B/B<@.B`G/B<I("X*
M("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I("X@)SPO
M;W!T:6]N/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P@+B`G
M/"]S96QE8W0^)SL*("`@('T*"B`@("!F=6YC=&EO;B!G971*879A4V-R:7!T
M*"1F;W)M;F%M92P@)&5L96UE;G1N86UE*0H@("`@>PH@("`@("`@("1P<F]M
M<'0@/2!A9&1S;&%S:&5S*%\H(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93HB*2D["B`@("`@("`@)&5R<F]R(#T@861D<VQA<VAE<RA?*")9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(BDI.PH*("`@("`@
M("!R971U<FX@/#P\2D%605-#4DE05`H*/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/@H\(2TM"F9U;F-T:6]N(&-H96-K0V%T96=O<GDH*0I["B`@
M("!I9B`H9&]C=6UE;G0N)&9O<FUN86UE+B1E;&5M96YT;F%M92YV86QU92`]
M/2`G*FYE=RHG*2!["B`@("`@("`@=F%R(&-A=&5G;W)Y(#T@=VEN9&]W+G!R
M;VUP="@G)'!R;VUP="<L("<G*3L*("`@("`@("!I9B`H8V%T96=O<GD@(3T@
M;G5L;"`F)B!C871E9V]R>2`A/2`G)RD@>PH@("`@("`@("`@("!D;V-U;65N
M="XD9F]R;6YA;64N;F5W7V-A=&5G;W)Y+G9A;'5E(#T@8V%T96=O<GD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=VEN9&]W+F%L97)T*"<D97)R
M;W(G*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M('T@96QS92!I9B`H9&]C=6UE;G0N)&9O<FUN86UE+B1E;&5M96YT;F%M92YV
M86QU92YI;F1E>$]F*"<J;F5W*B<I("$]("TQ*2!["B`@("`@("`@9&]C=6UE
M;G0N)&9O<FUN86UE+FYE=U]C871E9V]R>2YV86QU92`](&1O8W5M96YT+B1F
M;W)M;F%M92XD96QE;65N=&YA;64N=F%L=64N<W5B<W1R*#4L(&1O8W5M96YT
M+B1F;W)M;F%M92XD96QE;65N=&YA;64N=F%L=64N;&5N9W1H*3L*("`@('T*
M"B`@("!R971U<FX@=')U93L*?0HO+RTM/@H\+W-C<FEP=#X*2D%605-#4DE0
M5#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A(&YE=R!C871E9V]R>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C871E9V]R>2`@5&AE(&YA
M;64@;V8@=&AE(&-A=&5G;W)Y('1O(&%D9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!&86QS92!O;B!F86EL=7)E+"!O<B!T:&4@;F5W(&-A=&5G
M;W)Y)W,@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1C871E9V]R
M>2D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("!I9B`H
M)'!R969S+3YI<TQO8VME9"@G8V%T96=O<FEE<R<I('Q\(&5M<'1Y*"1C871E
M9V]R>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)&-A=&5G;W)I97,@/2!0<F5F<U]#871E9V]R>4UA;F%G97(Z
M.F=E="@I.PH@("`@("`@(&EF("AI;E]A<G)A>2@D8V%T96=O<GDL("1C871E
M9V]R:65S*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D8V%T96=O<FEE<UM=(#T@)&-A=&5G;W)Y.PH@("`@("`@
M("1P<F5F<RT^<V5T5F%L=64H)V-A=&5G;W)I97,G+"!I;7!L;V1E*"=\)RP@
M)&-A=&5G;W)I97,I*3L*"B`@("`@("`@<F5T=7)N("1C871E9V]R>3L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&-A=&5G;W)Y+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-A=&5G;W)Y("!4:&4@8V%T96=O<GD@
M=&\@<F5M;W9E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96UO=F4H)&-A=&5G;W)Y*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<')E9G,["@H@("`@("`@(&EF("@D<')E9G,M/FES3&]C:V5D*"=C871E
M9V]R:65S)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)&-A=&5G;W)I97,@/2!0<F5F<U]#871E9V]R>4UA;F%G
M97(Z.F=E="@I.PH*("`@("`@("`D:V5Y(#T@87)R87E?<V5A<F-H*"1C871E
M9V]R>2P@)&-A=&5G;W)I97,I.PH@("`@("`@(&EF("@D:V5Y(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("!R971U<FX@)&ME>3L*("`@("`@("!]"@H@("`@
M("`@('5N<V5T*"1C871E9V]R:65S6R1K97E=*3L*("`@("`@("`D<')E9G,M
M/G-E=%9A;'5E*"=C871E9V]R:65S)RP@:6UP;&]D92@G?"<L("1C871E9V]R
M:65S*2D["@H@("`@("`@("\O(%)E;6]V92!A;GD@8V]L;W(@<V5T=&EN9W,@
M9F]R("1C871E9V]R>2X*("`@("`@("`D8V]L;W)S(#T@4')E9G-?0V%T96=O
M<GE-86YA9V5R.CIC;VQO<G,H*3L*("`@("`@("!U;G-E="@D8V]L;W)S6R1C
M871E9V]R>5TI.PH@("`@("`@(%!R969S7T-A=&5G;W)Y36%N86=E<CHZ<V5T
M0V]L;W)S*"1C;VQO<G,I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;&]R(&9O<B!E86-H(&]F
M('1H92!U<V5R)W,@8V%T96=O<FEE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!(&QI<W0@;V8@8V]L;W)S+"!K97D@:7,@=&AE(&-A=&5G;W)Y
M(&YA;64L('9A;'5E(&ES('1H90H@("`@("H@("`@("`@("`@("`@("`@2%1-
M3"!C;VQO<B!C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VQO<G,H*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@("\J($1E9F%U
M;'0@=F%L=65S('1H870@8V%N(&)E(&]V97)R:61D96X@8G5T(&UU<W0@86QW
M87ES(&)E"B`@("`@("`@("H@<')E<V5N="X@*B\*("`@("`@("`D8V]L;W)S
M6R=?9&5F875L=%\G72`]("<C1D9&1D9&)SL*("`@("`@("`D8V]L;W)S6R=?
M=6YF:6QE9%\G72`]("<C1$1$1$1$)SL*"B`@("`@("`@)'!A:7)S(#T@97AP
M;&]D92@G?"<L("1P<F5F<RT^9V5T5F%L=64H)V-A=&5G;W)Y7V-O;&]R<R<I
M*3L*("`@("`@("!F;W)E86-H("@D<&%I<G,@87,@)'!A:7(I('L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D<&%I<BDI('L*("`@("`@("`@("`@("`@(&QI
M<W0H)&-A=&5G;W)Y+"`D8V]L;W(I(#T@97AP;&]D92@G.B<L("1P86ER*3L*
M("`@("`@("`@("`@("`@("1C;VQO<G-;)&-A=&5G;W)Y72`]("1C;VQO<CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-O;&]R<ULG)UT@
M/2`D8V]L;W)S6R=?=6YF:6QE9%\G73L*"B`@("`@("`@<F5T=7)N("1C;VQO
M<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!F;W)E9W)O
M=6YD(&-O;&]R(&9O<B!E86-H(&]F('1H92!U<V5R)W,@8V%T96=O<FEE<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@8V]L;W)S
M+"!K97D@:7,@=&AE(&-A=&5G;W)Y(&YA;64L('9A;'5E(&ES('1H90H@("`@
M("H@("`@("`@("`@("`@("`@2%1-3"!C;VQO<B!C;V1E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!F9T-O;&]R<R@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]);6%G92YP:'`G.PH*("`@("`@("`D8V]L;W)S(#T@4')E
M9G-?0V%T96=O<GE-86YA9V5R.CIC;VQO<G,H*3L*("`@("`@("`D9F=C;VQO
M<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C;VQO<G,@87,@)&YA
M;64@/3X@)&-O;&]R*2!["B`@("`@("`@("`@("1F9V-O;&]R<ULD;F%M95T@
M/2!(;W)D95]);6%G93HZ8G)I9VAT;F5S<R@D8V]L;W(I(#P@,3(X(#\@)R-F
M-F8V9C8G(#H@)R,P,#`G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F
M9V-O;&]R<SL*("`@('T*"B`@("!F=6YC=&EO;B!S971#;VQO<B@D8V%T96=O
M<GDL("1C;VQO<BD*("`@('L*("`@("`@("`D8V]L;W)S(#T@4')E9G-?0V%T
M96=O<GE-86YA9V5R.CIC;VQO<G,H*3L*("`@("`@("`D8V]L;W)S6R1C871E
M9V]R>5T@/2`D8V]L;W(["B`@("`@("`@4')E9G-?0V%T96=O<GE-86YA9V5R
M.CIS971#;VQO<G,H)&-O;&]R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T
M0V]L;W)S*"1C;VQO<G,I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*
M"B`@("`@("`@)'!A:7)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D
M8V]L;W)S(&%S("1C871E9V]R>2`]/B`D8V]L;W(I('L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D8V%T96=O<GDI*2!["B`@("`@("`@("`@("`@("`D<&%I
M<G-;72`]("(D8V%T96=O<GDZ)&-O;&]R(CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)'!R969S+3YS971686QU92@G8V%T96=O<GE?8V]L
M;W)S)RP@:6UP;&]D92@G?"<L("1P86ER<RDI.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN
M<&AP````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S$Q-P`Q,#4Q
M-30S,3`V,``P,C$T-S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%!R969E<F5N8V5S('-T;W)A9V4@
M:6UP;&5M96YT871I;VX@9F]R(%!(4"=S('-E<W-I;VX@:6UP;&5M96YT871I
M;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I
M;VXN<&AP+'8@,2XS,BXQ,BXW(#(P,#8O,#4O,3$@,3<Z,3,Z,C,@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,RXT
M"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0<F5F<U]S97-S
M:6]N(&5X=&5N9',@4')E9G,@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!S97-S:6]N('!R969E<F5N8V5S(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@5&AE('5S97(@=VAO(&]W
M;G,@=&AE<V4@<')E9F5R96YC97,N("A5;G5S960I"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87-S=V]R9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET
M:"`D=7-E<BX@*%5N=7-E9"D*("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E
M("`@("!4:&4@8W5R<F5N="!P<F5F97)E;F-E<R!S8V]P92X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN
M96-T:6]N('!A<F%M971E<G,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("A5;G5S960I"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V%C:&EN
M9R`@4VAO=6QD(&-A8VAI;F<@8F4@=7-E9#\@*%5N=7-E9"D*("`@("`J"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%!R969S7W-E<W-I;VXH)'5S97(L("1P87-S
M=V]R9"`]("<G+"`D<V-O<&4@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M<R`](&YU;&PL("1C86-H:6YG(#T@=')U92D*("`@('L*
M("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G<V5S<VEO;B<I
M*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R
M*%\H(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*2D["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7W-C;W!E(#T@)'-C;W!E.PH*("`@("`@("!P
M87)E;G0Z.E!R969S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M97,@=&AE(')E<75E<W1E9"!S970@;V8@<')E9F5R96YC97,@9G)O;2!T:&4@
M8W5R<F5N="!S97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I979E*"D*("`@('L*
M("`@("`@("`O*B!,;V%D(&1E9F%U;'1S('1O(&UA:V4@<W5R92!W92!H879E
M(&%L;"!P<F5F97)E;F-E<RX@*B\*("`@("`@("!P87)E;G0Z.G)E=')I979E
M*"D["@H@("`@("`@("1G;&]B86Q?<')E9G,@/2!A<G)A>2@I.PH@("`@("`@
M("1L;V-A;%]P<F5F<R`](&%R<F%Y*"D["@H@("`@("`@("\J(%)E=')I979E
M(&=L;V)A;"!A;F0@;&]C86P@<')E9F5R96YC97,@9G)O;2!T:&4@<V5S<VEO
M;B!V87)I86)L92X@*B\*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=H
M;W)D95]P<F5F<R==6R=H;W)D92==*2D@>PH@("`@("`@("`@("`D9VQO8F%L
M7W!R969S(#T@)%]315-324].6R=H;W)D95]P<F5F<R==6R=H;W)D92==.PH@
M("`@("`@('T*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=H;W)D95]P
M<F5F<R==6R1T:&ES+3Y?<V-O<&5=*2D@>PH@("`@("`@("`@("`D;&]C86Q?
M<')E9G,@/2`D7U-%4U-)3TY;)VAO<F1E7W!R969S)UU;)'1H:7,M/E]S8V]P
M95T["B`@("`@("`@?0H*("`@("`@("`O*B!2971R:65V92!A;F0@<W1O<F4@
M=&AE(&QO8V%L(&%N9"!G;&]B86P@<')E9F5R96YC97,N("HO"B`@("`@("`@
M)'1H:7,M/E]P<F5F<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?<')E9G,L("1G
M;&]B86Q?<')E9G,L("1L;V-A;%]P<F5F<RD["@H@("`@("`@("\J($-A;&P@
M:&]O:W,N("HO"B`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)VAO<F1E
M7W!R969S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V%L;$AO;VMS*"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-T;W)E<R!P<F5F97)E;F-E<R!I;B!T:&4@8W5R<F5N="!S
M97-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<')E9G,@($%N
M(&%R<F%Y(&QI<W1I;F<@=&AE('!R969E<F5N8V5S('1O(&)E('-T;W)E9"X@
M268*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&YO="!S<&5C:69I960L
M('-T;W)E(&%L;"!T:&4@<')E9F5R96YC97,@;&ES=&5D(&EN"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!T:&4@)'!R969S(&AA<V@N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<W1O<F4H)'!R969S(#T@87)R87DH*2D*("`@('L*("`@("`@("`O*B!#
M<F5A=&4@86YD(')E9VES=&5R('1H92!P<F5F97)E;F-E<R!A<G)A>2P@:68@
M;F5C97-S87)Y+B`J+PH@("`@("`@(&EF("@A:7-S970H)%]315-324].6R=H
M;W)D95]P<F5F<R==*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)VAO<F1E
M7W!R969S)UT@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]P
M>2!T:&4@8W5R<F5N="!P<F5F97)E;F-E<R!I;G1O('1H92!S97-S:6]N('9A
M<FEA8FQE+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<')E9G,@87,@
M)&YA;64@/3X@)'!R968I('L*("`@("`@("`@("`@)'-C;W!E(#T@)'1H:7,M
M/F=E=%-C;W!E*"1N86UE*3L*("`@("`@("`@("`@)%]315-324].6R=H;W)D
M95]P<F5F<R==6R1S8V]P95U;)&YA;65=(#T@)'!R968["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%!E
M<F9O<FT@8VQE86YU<"!O<&5R871I;VYS+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1A;&P@($-L96%N=7`@86QL($AO<F1E('!R969E<F5N8V5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P*"1A;&P@/2!F86QS92D*
M("`@('L*("`@("`@("`O*B!097)F;W)M(&$@2&]R9&4M=VED92!C;&5A;G5P
M/R`J+PH@("`@("`@(&EF("@D86QL*2!["B`@("`@("`@("`@('5N<V5T*"1?
M4T534TE/3ELG:&]R9&5?<')E9G,G72D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@=6YS970H)%]315-324].6R=H;W)D95]P<F5F<R==6R1T:&ES
M+3Y?<V-O<&5=*3L*("`@("`@("`@("`@)%]315-324].6R=H;W)D95]P<F5F
M<R==6R=?9FEL;&5D)UT@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@('!A
M<F5N=#HZ8VQE86YU<"@D86QL*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U!R969S+VEM<W`N<&AP````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,#<W,``Q,#4Q-30S,3`V,``P,C`W-C``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%!R
M969E<F5N8V4@<W1O<F%G92!I;7!L96UE;G1A=&EO;B!F;W(@86X@24U34"!S
M97)V97(N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S+U!R969S+VEM
M<W`N<&AP+'8@,2XQ+C$P+C$Q(#(P,#8O,#(O,C@@,#4Z-3DZ,3D@<VQU<V%R
M>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4G5B
M:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R
M9SX*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S(%!R969S7VEM
M<W`@97AT96YD<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<B!F=6YC=&EO;BX*("`@("`J("1P87)A;7,@;75S="!C;VYT86EN.@H@("`@
M("H@)V%U=&A?;65T:&]D)RP@)W-E<G9E<B<L("=P;W)T)PH@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1U<V5R("`@("!5<V5R;F%M92!O9B!C=7)R
M96YT('5S97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%S<W=O<F0@4&%S
M<W=O<F0@9F]R(&-U<G)E;G0@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@
M("1S8V]P92`@("!4:&4@<V-O<&4@9F]R('1H97-E('!R969E<F5N8V5S+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("`@)'!A<F%M<R`@(%1H92!P87)A;65T97)S
M(&YE961E9"!F;W(@=&AI<R!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D8V%C:&EN9R`@07)E('=E('5S:6YG('-E<W-I;VX@8V%C:&4_"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%!R969S7VEM<W`H)'5S97(L("1P87-S=V]R9"`]
M("<G+"`D<V-O<&4@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<R`](&YU;&PL("1C86-H:6YG(#T@=')U92D*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["@H@("`@("`@('!A<F5N=#HZ4')E9G,H*3L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TYE="])35-0+G!H<"<["@H@("`@("`@("1T:&ES
M+3Y?<V-O<&4@/2`D<V-O<&4["B`@("`@("`@)'1H:7,M/E]C86-H:6YG(#T@
M)&-A8VAI;F<["B`@("`@("`@)'1H:7,M/E]U<V5R(#T@)'5S97(["B`@("`@
M("`@)'1H:7,M/G!A<F%M<R`]("1P87)A;7,["@H@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O*%XN*BE`+R<L("1U<V5R+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@)'1H:7,M/G!A<F%M<ULG=7-E<FYA;64G72`]("1M871C:&5S6S%=
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YP87)A;7-;
M)W5S97)N86UE)UT@/2`D=7-E<CL*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/G!A<F%M<ULG<&%S<W=O<F0G72`]("1P87-S=V]R9#L*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/G!A<F%M<ULG<V]C:V5T)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3YP87)A;7-;)W-O8VME="==(#T@)'!A<F%M<ULG<V]C:V5T)UT@
M+B`G:6US<%\G("X@)'1H:7,M/G!A<F%M<ULG=7-E<FYA;64G72`N("<N<V-K
M)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]I;7-P(#T@)DYE=%])35-0
M.CIS:6YG;&5T;VXH)T]P=&EO;G,G+"`D=&AI<RT^<&%R86US*3L*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;FET*"D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ9F%T86PH)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]I;7-P+3YS971,;V=G97(H)&-O;F9;
M)VQO9R==*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@
M<F5Q=65S=&5D('-E="!O9B!P<F5F97)E;F-E<R!F<F]M('1H92!)35-0('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R971R:65V92@I"B`@("!["B`@("`@("`@+RH@
M1V5T('1H92!D969A=6QT<RX@*B\*("`@("`@("!P87)E;G0Z.G)E=')I979E
M*"D["@H@("`@("`@("\J($=E="!T:&4@<VAA<F5D('!R969S(&%N9"!R96UO
M=F4@=&AE('-C;W!E('9A;'5E(&9R;VT@=&AE"B`@("`@("`@("H@<W1R:6YG
M+B`J+PH@("`@("`@("1G;&]B86Q?<')E9G,@/2`D=&AI<RT^7VEM<W`M/F=E
M="@G:&]R9&4N*B<I.PH@("`@("`@(&EF("AI<U]A*"1G;&]B86Q?<')E9G,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1G;&]B86Q?
M<')E9G,["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9VQO8F%L7W!R
M969S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D;F5W2V5Y(#T@
M<W1R7W)E<&QA8V4H)VAO<F1E+B<L("<G+"`D:V5Y*3L*("`@("`@("`@("`@
M:68@*"1V86P@/3T@)RTG*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H
M:7,M/F=E=$1E9F%U;'0H)&YE=TME>2D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R969S6R1N97=+97E=*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%9A;'5E*"1N97=+97DL("1V86PI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F%D9"@D;F5W2V5Y+"`D=F%L+"!?4%)%1E]32$%2140I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!$;VXG="!F;W)G970@=&\@8VQE86X@:70N
M("HO"B`@("`@("`@("`@("1T:&ES+3YS971$:7)T>2@D;F5W2V5Y+"!F86QS
M92D["B`@("`@("`@?0H*("`@("`@("`O*B!.;W<@=&AE(&%P<"!S<&5C:69I
M8R!P<F5F<RX@*B\*("`@("`@("`D;&]C86Q?<')E9G,@/2`D=&AI<RT^7VEM
M<W`M/F=E="@D=&AI<RT^7W-C;W!E("X@)RXJ)RD["B`@("`@("`@:68@*&ES
M7V$H)&QO8V%L7W!R969S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D;&]C86Q?<')E9G,["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D;&]C86Q?<')E9G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("1N97=+97D@/2!S=')?<F5P;&%C92@D=&AI<RT^7W-C;W!E("X@)RXG
M+"`G)RP@)&ME>2D["B`@("`@("`@("`@(&EF("@D=F%L(#T]("<M)RD@>PH@
M("`@("`@("`@("`@("`@)'9A;"`]("1T:&ES+3YG971$969A=6QT*"1N97=+
M97DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!R969S6R1N97=+97E=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=%9A;'5E*"1N97=+97DL("1V86PI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9"@D;F5W2V5Y+"`D=F%L+"`P
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0VQE86X@=&AE('!R
M968N("HO"B`@("`@("`@("`@("1T:&ES+3YS971$:7)T>2@D;F5W2V5Y+"!F
M86QS92D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-A;&Q(;V]K<R@I
M.PH@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I.PH@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S(&%L;"!D:7)T
M>2!P<F5F<R!T;R!)35-0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@I"B`@
M("!["B`@("`@("`@)&1I<G1Y7W!R969S(#T@)'1H:7,M/E]D:7)T>5!R969S
M*"D["B`@("`@("`@:68@*"%C;W5N="@D9&ER='E?<')E9G,I*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)&1I<G1Y7W!R969S(&%S("1N86UE*2!["B`@("`@("`@("`@("1S8V]P
M92`]("1T:&ES+3YG97138V]P92@D;F%M92D["B`@("`@("`@("`@("1V86QU
M92`]("1T:&ES+3YG971686QU92@D;F%M92D["B`@("`@("`@("`@(&EF("AE
M;7!T>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D=F%L=64@/2`G+2<[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VEM<W`M/G-E="@D<V-O<&4@+B`G+B<@+B`D;F%M92P@)'9A;'5E*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H
M*")4:&5R92!W87,@82!P<F]B;&5M('-A=FEN9R!T:&4@<')E9G)E;F-E<R(I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($-L96%N('1H92!P<F5F('-I;F-E(&ET('=A
M<R!J=7-T('-A=F5D+B`J+PH@("`@("`@("`@("`D=&AI<RT^<V5T1&ER='DH
M)&YA;64L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F-A8VAE
M57!D871E*"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2\`
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#8P`#`Q-S$R,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]&;W)M+U1Y<&4O````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C``,#(P,#0R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E
M="YP:'``````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8S,@`Q,#4Q-30S
M,3`V,``P,C(S-38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G
M.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<"QV(#$N,RXR+C$@,C`P-2\Q,"\Q."`Q,3HP,3HP."!J86X@
M17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B!`<VEN8V4@("!(
M;W)D92`S+C$*("HO"F-L87-S($AO<F1E7T9O<FU?5'EP95]T86)L97-E="!E
M>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?=F%L=65S.PH@
M("`@=F%R("1?:&5A9&5R.PH*("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RP@
M)&AE861E<BD*("`@('L*("`@("`@("`D=&AI<RT^7W9A;'5E<R`]("1V86QU
M97,["B`@("`@("`@)'1H:7,M/E]H96%D97(@/2`D:&5A9&5R.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F
M)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?=F%L
M=65S*2`]/2`P('Q\(&-O=6YT*"1V86QU92D@/3T@,"D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)'9A
M;'5E(&%S("1I=&5M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]V86QU97-;)&ET96U=*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@
M=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)&5R<F]R*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E
M(#T@7R@B26YV86QI9"!D871A('-U8FUI='1E9"XB*3L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T2&5A9&5R*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97(["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T5F%L=65S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]V86QU97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF
M;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U
M="@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G
M;F%M92<@/3X@7R@B5&%B;&4@4V5T(BDL"B`@("`@("`@("`@("=P87)A;7,G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@
M("`@("`@("`@("=H96%D97(G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B2&5A
M9&5R<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`G<W1R:6YG;&ES="<I*2P*("`@("`@("`@("`@*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O1F]R;2]!8W1I;VXO````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8P`#`R,#,S-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]C;VYD:71I;VYA
M;%]E;F%B;&4N<&AP````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,T,34`,3`U,34T,S$P-C``
M,#(T-C8P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!(;W)D95]&;W)M7T%C=&EO;E]C;VYD:71I;VYA
M;%]E;F%B;&4@:7,@82!(;W)D95]&;W)M7T%C=&EO;B!T:&%T"B`J(&5N86)L
M97,@;W(@9&ES86)L97,@86X@96QE;65N="!B87-E9"!O;B!T:&4@=F%L=64@
M;V8@86YO=&AE<B!E;&5M96YT"B`J"B`J($9O<FUA="!O9B!T:&4@)'!A<F%M
M<R!P87-S960@=&\@=&AE(&-O;G-T<G5C=&]R.@H@*B`\<')E/@H@*B`@)'!A
M<F%M<R`](&%R<F%Y*`H@*B`@("`@("=T87)G970G("`]/B`G6VYA;64@;V8@
M96QE;65N="!T:&ES(&ES(&-O;F1I=&EO;F%L(&]N72<L"B`J("`@("`@)V5N
M86)L960G(#T^("=T<G5E)R!\("=F86QS92<L"B`J("`@("`@)W9A;'5E<R<@
M(#T^(&%R<F%Y*%MT87)G970@=F%L=65S('1O(&-H96-K72D*("H@("D["B`J
M(#PO<')E/@H@*@H@*B!3;R`D<&%R86US(#T@87)R87DH)V9O;R<L("=T<G5E
M)RP@87)R87DH,2P@,BDI('=I;&P@96YA8FQE('1H92!F:65L9"!T:&ES"B`J
M(&%C=&EO;B!I<R!A='1A8VAE9"!T;R!I9B!T:&4@=F%L=64@;V8@)V9O;R<@
M:7,@,2!O<B`R+"!A;F0@9&ES86)L92!I=`H@*B!O=&AE<G=I<V4N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXO8V]N9&ET:6]N
M86Q?96YA8FQE+G!H<"QV(#$N-"XQ,"XS(#(P,#8O,#$O,#$@,C$Z,C@Z,3<@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36%T="!+>6YA
M<W1O;B`\;6%T=$!K>6YX+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UA='0@2WEN87-T;VX@/&UA='1`:WEN>"YO<F<^"B`J($!P86-K86=E
M($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?06-T:6]N7V-O;F1I
M=&EO;F%L7V5N86)L92!E>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N('L*"B`@
M("!V87(@)%]T<FEG9V5R(#T@87)R87DH)V]N;&]A9"<I.PH*("`@(&9U;F-T
M:6]N(&=E=$%C=&EO;E-C<FEP="@F)&9O<FTL("1R96YD97)E<BP@)'9A<FYA
M;64I"B`@("!["B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V9O<FU?
M:&5L<&5R<RYJ<R<L("=H;W)D92<L('1R=64I.PH*("`@("`@("`D9F]R;5]N
M86UE(#T@)&9O<FTM/F=E=$YA;64H*3L*("`@("`@("`D=&%R9V5T(#T@)'1H
M:7,M/E]P87)A;7-;)W1A<F=E="==.PH@("`@("`@("1E;F%B;&5D(#T@)'1H
M:7,M/E]P87)A;7-;)V5N86)L960G73L*("`@("`@("!I9B`H(6ES7W-T<FEN
M9R@D96YA8FQE9"DI('L*("`@("`@("`@("`@)&5N86)L960@/2`H)&5N86)L
M960I(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@("`@("!]"B`@("`@("`@)'9A
M;',@/2`D=&AI<RT^7W!A<F%M<ULG=F%L=65S)UT["B`@("`@("`@)'9A;',@
M/2`H:7-?87)R87DH)'9A;',I*2`_("1V86QS(#H@87)R87DH)'9A;',I.PH@
M("`@("`@("1A<F=S(#T@(B<D=F%R;F%M92<L("1E;F%B;&5D+"`G(B`N(&EM
M<&QO9&4H(B<L)R(L("1V86QS*2`N("(G(CL*"B`@("`@("`@<F5T=7)N(")I
M9B`H861D179E;G0H9&]C=6UE;G0N)&9O<FU?;F%M92XD=&%R9V5T+"`G;VYC
M:&%N9V4G+"!<(F-H96-K16YA8FQE9"AT:&ES+"`D87)G<RD[7"(I*2![("(*
M("`@("`@("`@("`@+B`B("!C:&5C:T5N86)L960H9&]C=6UE;G0N)&9O<FU?
M;F%M92XD=F%R;F%M92P@)&%R9W,I.R`B"B`@("`@("`@("`@("X@)WT[)SL*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO<F5L;V%D+G!H<```````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3<S`#$P-3$U-#,Q,#8P`#`R,C,R
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@2&]R9&5?1F]R;5]!8W1I;VY?<F5L;V%D(&ES(&$@2&]R
M9&5?1F]R;2!!8W1I;VX@=&AA="!R96QO861S('1H90H@*B!F;W)M('=I=&@@
M=&AE(&-U<G)E;G0@*&YO="!T:&4@;W)I9VEN86PI('9A;'5E(&%F=&5R('1H
M92!F;W)M(&5L96UE;G0*("H@=&AA="!T:&4@86-T:6]N(&ES(&%T=&%C:&5D
M('1O(&ES(&UO9&EF:65D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO06-T:6]N+W)E;&]A9"YP:'`L=B`Q+C<N,3`N-"`R,#`V+S`Q+S`Q
M(#(Q.C(X.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C
M=&EO;E]R96QO860@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@
M=F%R("1?=')I9V=E<B`](&%R<F%Y*"=O;F-H86YG92<I.PH*("`@(&9U;F-T
M:6]N(&=E=$%C=&EO;E-C<FEP="@D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M
M92D*("`@('L*("`@("`@("!R971U<FX@)VEF("AT:&ES+G9A;'5E*2![(&1O
M8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M92@I("X@)RYF;W)M;F%M92YV86QU
M93U<)UPG.R<@+@H@("`@("`@("`@("`G9&]C=6UE;G0N)R`N("1F;W)M+3YG
M971.86UE*"D@+B`G+G-U8FUI="@I('TG.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO8V]N9&ET:6]N
M86Q?<V5T=F%L=64N<&AP`````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,#$P`#$P-3$U-#,Q,#8P
M`#`R-3(U,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@2&]R9&5?1F]R;5]!8W1I;VY?8V]N9&ET:6]N
M86Q?<V5T=F%L=64@:7,@82!(;W)D95]&;W)M7T%C=&EO;B!T:&%T"B`J('-E
M=',@=&AE('9A;'5E(&]F(&]N92!(;W)D95]&;W)M('9A<FEA8FQE(&)A<V5D
M(&]N('1H92!V86QU92!O9B!T:&4*("H@=F%R:6%B;&4@=&AE(&%C=&EO;B!I
M<R!A='1A8VAE9"!T;RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+T%C=&EO;B]C;VYD:71I;VYA;%]S971V86QU92YP:'`L=B`Q+C$Y+C$P
M+C4@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J
M+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]C;VYD:71I;VYA;%]S971V86QU
M92!E>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N('L*"B`@("`O*BH*("`@("`J
M(%=H:6-H($I3(&5V96YT<R!S:&]U;&0@=')I9V=E<B!T:&ES(&%C=&EO;C\*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1R
M:6=G97(@/2!A<G)A>2@G;VYC:&%N9V4G+"`G;VYL;V%D)RD["@H@("`@9G5N
M8W1I;VX@9V5T06-T:6]N4V-R:7!T*"1F;W)M+"`D<F5N9&5R97(L("1V87)N
M86UE*0H@("`@>PH@("`@("`@(')E='5R;B`G;6%P*%PG)R`N("1R96YD97)E
M<BT^7V=E;DE$*"1V87)N86UE+"!F86QS92D@+B`B)RP@)R(@+B`D<F5N9&5R
M97(M/E]G96Y)1"@D=&AI<RT^9V5T5&%R9V5T*"DL(&9A;'-E*2`N("=<)RD[
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!S971686QU97,H)B1V87)S+"`D<V]U
M<F-E5F%L+"`D87)R87E686P@/2!F86QS92D*("`@('L*("`@("`@("`D;6%P
M(#T@)'1H:7,M/E]P87)A;7-;)VUA<"==.PH@("`@("`@("1T87)G970@/2`D
M=&AI<RT^9V5T5&%R9V5T*"D["@H@("`@("`@(&EF("@D87)R87E686PI('L*
M("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)'-O=7)C959A;"DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S;W5R
M8V5686P@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&UA<%LD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<G,M/G-E="@D=&%R9V5T+"`D;6%P6R1V86Q=+"`D:2D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1M87!;)'-O=7)C959A;%TI*2!["B`@("`@
M("`@("`@("`@("`D=F%R<RT^<V5T*"1T87)G970L("1M87!;)'-O=7)C959A
M;%TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N('!R:6YT2F%V85-C<FEP="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]P
M<FEN=$IA=F%38W)I<'13=&%R="@I.PH@("`@("`@("1M87`@/2`D=&AI<RT^
M7W!A<F%M<ULG;6%P)UT["C\^"@IV87(@7VUA<"`](&YE=R!!<G)A>2@\/W!H
M<`HD:2`](#`["F9O<F5A8V@@*"1M87`@87,@)'9A;"D@>PH@("`@:68@*"1I
M(#X@,"D@>PH@("`@("`@(&5C:&\@)RP@)SL*("`@('T*("`@(&5C:&\@)R(G
M("X@)'9A;"`N("<B)SL*("`@("1I*RL["GT_/BD["@IF=6YC=&EO;B!M87`H
M<V]U<F-E260L('1A<F=E=$ED*0I["B`@("!V87(@;F5W=F%L.PH@("`@=F%R
M('-O=7)C92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'-O=7)C94ED*3L*
M("`@('9A<B!E;&5M96YT(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R
M9V5T260I.PH@("`@:68@*&5L96UE;G0I('L*("`@("`@("!I9B`H7VUA<%MS
M;W5R8V4N<V5L96-T961);F1E>%TI('L*("`@("`@("`@("`@;F5W=F%L(#T@
M7VUA<%MS;W5R8V4N<V5L96-T961);F1E>%T["B`@("`@("`@("`@(')E<&QA
M8V4@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&YE=W9A
M;"`]("<G.PH@("`@("`@("`@("!R97!L86-E(#T@9F%L<V4["B`@("`@("`@
M("`@(&9O<B`H:2`](#`[(&D@/"!?;6%P+FQE;F=T:#L@:2LK*2!["B`@("`@
M("`@("`@("`@("!I9B`H96QE;65N="YV86QU92`]/2!?;6%P6VE=*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5P;&%C92`]('1R=64["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("AR97!L86-E*2!["B`@("`@("`@
M("`@(&5L96UE;G0N=F%L=64@/2!N97=V86P["B`@("`@("`@?0H@("`@?0I]
M/#]P:'`*("`@("`@("`D=&AI<RT^7W!R:6YT2F%V85-C<FEP=$5N9"@I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]&;W)M+T%C=&EO;B]S=6)M:70N<&AP````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$S-S<`,3`U,34T,S$P-C``,#(R,S4W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!(;W)D95]&;W)M7T%C=&EO;E]S=6)M:70@:7,@82!(;W)D95]&;W)M($%C
M=&EO;B!T:&%T('-U8FUI=',@=&AE"B`J(&9O<FT@869T97(@=&AE(&9O<FT@
M96QE;65N="!T:&%T('1H92!A8W1I;VX@:7,@871T86-H960@=&\@:7,*("H@
M;6]D:69I960N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!
M8W1I;VXO<W5B;6ET+G!H<"QV(#$N,3`N,3(N-"`R,#`V+S`Q+S`Q(#(Q.C(X
M.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!P86-K86=E($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?
M06-T:6]N7W-U8FUI="!E>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N('L*"B`@
M("!V87(@)%]T<FEG9V5R(#T@87)R87DH)V]N8VAA;F=E)RD["@H@("`@9G5N
M8W1I;VX@9V5T06-T:6]N4V-R:7!T*"1F;W)M+"`D<F5N9&5R97(L("1V87)N
M86UE*0H@("`@>PH@("`@("`@(')E='5R;B`G9&]C=6UE;G0N)R`N("1F;W)M
M+3YG971.86UE*"D@+B`G+G-U8FUI="@I)SL*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]U<&1A=&5F:65L9"YP:'``````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,W,#$`,3`U,34T,S$P-C``,#(S,S,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!(;W)D95]&;W)M7T%C=&EO;E]U<&1A=&5F:65L9"!I<R!A($AO
M<F1E7T9O<FU?06-T:6]N('1H870@=7!D871E<PH@*B!T:&4@=F%L=64@;V8@
M;VYE($AO<F1E7T9O<FT@=F%R:6%B;&4@87,@=&AE('9A<FEA8FQE('1H92!A
M8W1I;VX@:7,*("H@871T86-H960@=&\@:7,@=7!D871E9"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO1F]R;2]&;W)M+T%C=&EO;B]U<&1A=&5F:65L9"YP
M:'`L=B`Q+C4N,3(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E($AO
M<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?06-T:6]N7W5P9&%T969I
M96QD(&5X=&5N9',@2&]R9&5?1F]R;5]!8W1I;VX@>PH*("`@('9A<B`D7W1R
M:6=G97(@/2!A<G)A>2@G;VYC:&%N9V4G+"`G;VYL;V%D)RP@)V]N:V5Y=7`G
M*3L*"B`@("!F=6YC=&EO;B!G971!8W1I;VY38W)I<'0H)B1F;W)M+"`F)')E
M;F1E<F5R+"`D=F%R;F%M92D*("`@('L*("`@("`@("!R971U<FX@)W5P9&%T
M949I96QD)R`N("1T:&ES+3YI9"@I("X@)R@I.R<["B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T5F%L=65S*"8D=F%R<RP@)'-O=7)C959A;"P@)&%R<F%Y5F%L
M(#T@9F%L<V4I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@<')I;G1*879A
M4V-R:7!T*"D*("`@('L*("`@("`@("`D=&AI<RT^7W!R:6YT2F%V85-C<FEP
M=%-T87)T*"D["B`@("`@("`@)'!I96-E<R`](&5X<&QO9&4H)R5S)RP@)'1H
M:7,M/E]P87)A;7-;)V9O<FUA="==*3L*("`@("`@("`D9FEE;&1S(#T@)'1H
M:7,M/E]P87)A;7-;)V9I96QD<R==.PH@("`@("`@("1V86Q?9FER<W0@/2`H
M<W5B<W1R*"1T:&ES+3Y?<&%R86US6R=F;W)M870G72P@,"P@,BD@/3T@)R5S
M)RD["B`@("`@("`@:68@*"1V86Q?9FER<W0I('L*("`@("`@("`@("`@87)R
M87E?<VAI9G0H)'!I96-E<RD["B`@("`@("`@?0H@("`@("`@(&EF("AS=6)S
M='(H)'1H:7,M/E]P87)A;7-;)V9O<FUA="==+"`M,BD@/3T@)R5S)RD@>PH@
M("`@("`@("`@("!A<G)A>5]P;W`H)'!I96-E<RD["B`@("`@("`@?0H*("`@
M("`@("`D87)G<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1V86Q?9FER<W0I
M('L*("`@("`@("`@("`@)&%R9W-;72`](")D;V-U;65N="YG971%;&5M96YT
M0GE)9"@G(B`N(&%R<F%Y7W-H:69T*"1F:65L9',I("X@(B<I+G9A;'5E(CL*
M("`@("`@("!]"B`@("`@("`@=VAI;&4@*&-O=6YT*"1P:65C97,I*2!["B`@
M("`@("`@("`@("1A<F=S6UT@/2`B)R(@+B!A<G)A>5]S:&EF="@D<&EE8V5S
M*2`N("(G(CL*("`@("`@("`@("`@)&%R9W-;72`](")D;V-U;65N="YG971%
M;&5M96YT0GE)9"@G(B`N(&%R<F%Y7W-H:69T*"1F:65L9',I("X@(B<I+G9A
M;'5E(CL*("`@("`@("!]"C\^"B\O(%5P9&%T97(@9F]R(#P_<&AP(&5C:&\@
M)'1H:7,M/F=E=%1A<F=E="@I(#\^+@IF=6YC=&EO;B!U<&1A=&5&:65L9#P_
M<&AP(&5C:&\@)'1H:7,M/FED*"D@/SXH*0I["B`@("!V87(@=&%R9V5T(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)SP_<&AP(&5C:&\@)'1H:7,M/F=E
M=%1A<F=E="@I(#\^)RD["B`@("!I9B`H=&%R9V5T*2!["B`@("`@("`@=&%R
M9V5T+G9A;'5E(#T@/#]P:'`@96-H;R!I;7!L;V1E*"<@*R`G+"!S=')?<F5P
M;&%C92@B7&XB+"`B7%QN(BP@)&%R9W,I*2`_/CL*("`@('T*?3P_<&AP"B`@
M("`@("`@)'1H:7,M/E]P<FEN=$IA=F%38W)I<'1%;F0H*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O1F]R;2]!8W1I;VXO<W5M7V9I96QD<RYP:'``````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-S8P`#$P-3$U-#,Q,#8P`#`R,S(P,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@2&]R9&5?1F]R;5]!8W1I;VY?<W5M7V9I96QD<R!I<R!A($AO<F1E7T9O
M<FU?06-T:6]N('1H870@<V5T<R!T:&4@=&%R9V5T"B`J(&9I96QD('1O('1H
M92!S=6T@;V8@;VYE(&]R(&UO<F4@;W1H97(@;G5M97)I8R!F:65L9',N"B`J
M"B`J(%1H92!P87)A;7,@87)R87D@<VAO=6QD(&-O;G1A:6X@=&AE(&YA;65S
M(&]F('1H92!F:65L9',@=VAI8V@@=VEL;"!B90H@*B!S=6UM960N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXO<W5M7V9I96QD
M<RYP:'`L=B`Q+C4N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA='0@2WEN87-T;VX@/&UA
M='1`:WEN>"YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-871T
M($MY;F%S=&]N(#QM871T0&MY;G@N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&
M;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]S=6U?9FEE;&1S(&5X
M=&5N9',@2&]R9&5?1F]R;5]!8W1I;VX@>PH*("`@('9A<B`D7W1R:6=G97(@
M/2!A<G)A>2@G;VYL;V%D)RD["@H@("`@9G5N8W1I;VX@9V5T06-T:6]N4V-R
M:7!T*"8D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*("`@('L*("`@("`@
M("!(;W)D93HZ861D4V-R:7!T1FEL92@G9F]R;5]H96QP97)S+FIS)RP@)VAO
M<F1E)RP@=')U92D["@H@("`@("`@("1F;W)M7VYA;64@/2`D9F]R;2T^9V5T
M3F%M92@I.PH@("`@("`@("1F:65L9',@/2`B)R(@+B!I;7!L;V1E*"(G+"<B
M+"`D=&AI<RT^7W!A<F%M<RD@+B`B)R(["B`@("`@("`@)&IS(#T@87)R87DH
M*3L*("`@("`@("`D:G-;72`]('-P<FEN=&8H)V1O8W5M96YT+F9O<FUS6UPG
M)7-<)UTN96QE;65N='-;7"<E<UPG72YD:7-A8FQE9"`]('1R=64[)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9O<FU?;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?<&%R86US(&%S("1F:65L9"D@>PH@("`@("`@("`@("`D:G-;72`]('-P
M<FEN=&8H(F%D9$5V96YT*&1O8W5M96YT+F9O<FUS6R<E,5PD<R==+F5L96UE
M;G1S6R<E,EPD<R==+"!<(F]N8VAA;F=E7"(L(%PB<W5M1FEE;&1S*&1O8W5M
M96YT+F9O<FUS6R<E,5PD<R==+"`G)3-<)',G+"`E-%PD<RD[7"(I.R(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;5]N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I96QD+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEE;&1S*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!I;7!L
M;V1E*")<;B(L("1J<RD["B`@("!]"@I]"@`````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;BYP
M:'``````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`W,#,`,3`U
M,34T,S$P-C``,#(Q,#0U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?1F]R;5]!8W1I
M;VX@8VQA<W,@<')O=FED97,@86X@05!)(&9O<B!A9&1I;F<@86-T:6]N<R!T
M;PH@*B!(;W)D95]&;W)M('9A<FEA8FQE<RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+T%C=&EO;BYP:'`L=B`Q+C$Y+C$P+C8@,C`P-B\P
M,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D
M95]&;W)M7T%C=&EO;B!["@H@("`@=F%R("1?:60["B`@("!V87(@)%]P87)A
M;7,["B`@("!V87(@)%]T<FEG9V5R(#T@;G5L;#L*"B`@("!F=6YC=&EO;B!(
M;W)D95]&;W)M7T%C=&EO;B@D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@)'1H:7,M/E]I
M9"`](&UD-2AM=%]R86YD*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1R
M:6=G97(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1R:6=G97([
M"B`@("!]"@H@("`@9G5N8W1I;VX@:60H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VED.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$%C=&EO;E-C
M<FEP="@D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*("`@('L*("`@("`@
M("!R971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@<')I;G1*879A4V-R
M:7!T*"D*("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!?<')I;G1*879A4V-R
M:7!T4W1A<G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(CX\(2TM)SL*("`@('T*"B`@("!F=6YC=&EO;B!?
M<')I;G1*879A4V-R:7!T16YD*"D*("`@('L*("`@("`@("!E8VAO("<O+R`M
M+3X\+W-C<FEP=#XG.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1A<F=E="@I
M"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<&%R86US6R=T
M87)G970G72D@/R`D=&AI<RT^7W!A<F%M<ULG=&%R9V5T)UT@.B!N=6QL.PH@
M("`@?0H*("`@(&9U;F-T:6]N('-E=%9A;'5E<R@F)'9A<G,L("1S;W5R8V56
M86PL("1I;F1E>"`](&YU;&PL("1A<G)A>59A;"`](&9A;'-E*0H@("`@>PH@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N
M8W)E=&4@2&]R9&5?1F]R;5]!8W1I;VX@:6YS=&%N8V4*("`@("`J(&)A<V5D
M(&]N("1F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9F]R;2`@
M("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]&;W)M7T%C=&EO;B!S=6)C
M;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1O(')E='5R;BX@
M268@)&9O<FT@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&9O<FU;,%TO;&EB+T9O<FTO
M06-T:6]N+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@:6UP;&5M96YT871I;VX@;F%M960@)&9O<FU;,5TN<&AP+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG
M(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&9O<FT@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($AO<F1E7T9O<FU?06-T:6]N("!4:&4@8V]N8W)E=&4@2&]R
M9&5?1F]R;5]!8W1I;VX@<F5F97)E;F-E+"!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1A8W1I;VXL("1P87)A;7,@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D86-T:6]N*2D@>PH@("`@
M("`@("`@("`D87!P(#T@)&%C=&EO;ELP73L*("`@("`@("`@("`@)&%C=&EO
M;B`]("1A8W1I;VY;,5T["B`@("`@("`@?0H*("`@("`@("`D86-T:6]N(#T@
M8F%S96YA;64H)&%C=&EO;BD["B`@("`@("`@:68@*&5M<'1Y*"1A8W1I;VXI
M('Q\("AS=')C;7`H)&%C=&EO;BP@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V%N;F]T(&EN<W1A;G1I
M871E(&%B<W1R86-T(&-L87-S($AO<F1E7T9O<FU?06-T:6]N+B<I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL
M97)O;W0G+"`D87!P*2`N("<O;&EB+T9O<FTO06-T:6]N+R<@+B`D86-T:6]N
M("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+T%C=&EO;B\G("X@)&%C=&EO;B`N("<N<&AP
M)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]!8W1I;VXO)R`N("1A8W1I;VX@+B`G+G!H<"<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M
M+T%C=&EO;B\G("X@)&%C=&EO;B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@
M("`@("1C;&%S<R`]("=(;W)D95]&;W)M7T%C=&EO;E\G("X@)&%C=&EO;CL*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)&EN<W1A;F-E(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&EN<W1A;F-E(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@
M9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M<F5F97)E;F-E('1O(&$@8V]N8W)E=&4*("`@("`J($AO<F1E7T9O<FU?06-T
M:6]N(&EN<W1A;F-E(&)A<V5D(&]N("1A8W1I;VXN($ET('=I;&P@;VYL>0H@
M("`@("H@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E7T9O<FU?
M06-T:6]N(&EN<W1A;F-E('=I=&@*("`@("`J('1H92!S86UE('!A<F%M971E
M<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L
M9"!B92!U<V5D(&EF(&UU;'1I<&QE('1Y<&5S(&]F(&9O<FT@<F5N9&5R97)S
M("AA;F0L"B`@("`@*B!T:'5S+"!M=6QT:7!L92!(;W)D95]&;W)M7T%C=&EO
M;B!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/0H@("`@("H@)DAO
M<F1E7T9O<FU?06-T:6]N.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D86-T:6]N("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D
M95]&;W)M7T%C=&EO;B!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC
M;'5D960N($EF("1A8W1I;VX@:7,@86X@87)R87DL"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@=&AE;B!W92!W:6QL(&QO;VL@:6X@)&%C=&EO;ELP
M72]L:6(O1F]R;2]!8W1I;VXO(&9O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@('1H92!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE9"`D86-T
M:6]N6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA
M<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F;W)M(&UI9VAT(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]&;W)M7T%C=&EO;B`@5&AE
M(&-O;F-R971E($AO<F1E7T9O<FU?06-T:6]N(')E9F5R96YC92P@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&]N(&%N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1A8W1I;VXL
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N
M8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@
M("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1A8W1I;VXL("1P87)A
M;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R
M95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F
M2&]R9&5?1F]R;5]!8W1I;VXZ.F9A8W1O<GDH)&%C=&EO;BP@)'!A<F%M<RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E73L*("`@('T*"GT*````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-#(P-``Q,#4Q-30S,3`V,``P
M,C$T,#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]&;W)M7U)E;F1E<F5R(&-L87-S
M('!R;W9I9&5S($A434P@86YD(&]T:&5R(')E;F1E<FEN9W,@;V8*("H@9F]R
M;7,@9F]R('1H92!(;W)D95]&;W)M.CH@<&%C:V%G92X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<"QV(#$N,3@U+C0N
M,34@,C`P-B\P-"\Q-2`Q.#HP-3HP-"!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,2TR,#`V(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE
M0&AO=&UA:6PN8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]B
M97)T($4N($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!P
M86-K86=E($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?4F5N9&5R
M97(@>PH*("`@('9A<B`D7VYA;64["B`@("!V87(@)%]R97%U:7)E9$QE9V5N
M9"`](&9A;'-E.PH@("`@=F%R("1?<F5Q=6ER961-87)K97(@/2`G*B<["B`@
M("!V87(@)%]H96QP36%R:V5R(#T@)S\G.PH@("`@=F%R("1?;VY,;V%D2E,@
M/2!A<G)A>2@I.PH@("`@=F%R("1?<VAO=TAE861E<B`]('1R=64["B`@("!V
M87(@)%]C;VQS(#T@,CL*("`@('9A<B`D7W9A<E)E;F1E<F5R(#T@;G5L;#L*
M("`@('9A<B`D7V9I<G-T1FEE;&0@/2!N=6QL.PH@("`@=F%R("1?<W1R:7!E
M9%)O=W,@/2!T<G5E.PH*("`@("\J*@H@("`@("H@1&]E<R!T:&4@=&ET;&4@
M;V8@=&AE(&9O<FT@8V]N=&%I;B!(5$U,/R!)9B!S;RP@>6]U(&%R92!R97-P
M;VYS:6)L92!F;W(*("`@("`J(&1O:6YG(&%N>2!N965D960@97-C87!I;F<O
M<V%N:71I>F%T:6]N('EO=7)S96QF+B!/=&AE<G=I<V4@=&AE('1I=&QE"B`@
M("`@*B!W:6QL(&)E(')U;B!T:')O=6=H(&AT;6QS<&5C:6%L8VAA<G,H*2!B
M969O<F4@8F5I;F<@;W5T<'5T+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A
M;@H@("`@("HO"B`@("!V87(@)%]E;F-O9&54:71L92`]('1R=64["@H@("`@
M+RHJ"B`@("`@*B!7:61T:"!O9B!T:&4@871T<FEB=71E<R!C;VQU;6XN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]A='1R0V]L=6UN5VED=&@@/2`G,34E)SL*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C="!A(&YE=R!(;W)D95]&;W)M7U)E
M;F1E<F5R.CHN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M(%1H:7,@:7,@82!H87-H(&]F(')E;F1E<F5R+7-P96-I9FEC('!A<F%M971E
M<G,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@4&]S<VEB;&4@:V5Y
M<SH\8V]D93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G=F%R<F5N
M9&5R97)?9')I=F5R)SH@<W!E8VEF:65S('1H92!D<FEV97(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R('1O($AO<F1E7U5)
M7U9A<E)E;F1E<F5R.CIF86-T;W)Y*"DN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@)V5N8V]D95]T:71L92<Z($!S964@)%]E;F-O9&54:71L93PO
M8V]D93X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?1F]R;5]296YD97)E
M<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH@("`@("`@(&EF("AI<W-E="@D<F5G:7-T<GDI("8F(&ES7V$H
M)')E9VES=')Y+"`G4F5G:7-T<GDG*2D@>PH@("`@("`@("`@("`O*B!296=I
M<W1R>2!A=F%I;&%B;&4L('-O('5S92!A('!R971T>2!I;6%G92X@*B\*("`@
M("`@("`@("`@)'1H:7,M/E]R97%U:7)E9$UA<FME<B`]($AO<F1E.CII;6<H
M)W)E<75I<F5D+G!N9R<L("<J)RP@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J
M($YO(')E9VES=')Y(&%V86EL86)L92P@=7-E('-O;65T:&EN9R!P;&%I;BX@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]R97%U:7)E9$UA<FME<B`]("<J)SL*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=E;F-O9&5?
M=&ET;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/F5N8V]D951I=&QE*"1P
M87)A;7-;)V5N8V]D95]T:71L92==*3L*("`@("`@("!]"@H@("`@("`@("1D
M<FEV97(@/2`G:'1M;"<["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W9A
M<G)E;F1E<F5R7V1R:79E<B==*2D@>PH@("`@("`@("`@("`D9')I=F5R(#T@
M)'!A<F%M<ULG=F%R<F5N9&5R97)?9')I=F5R)UT["B`@("`@("`@?0H@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O54DO5F%R4F5N9&5R97(N<&AP)SL*
M("`@("`@("`D=&AI<RT^7W9A<E)E;F1E<F5R(#T@)DAO<F1E7U5)7U9A<E)E
M;F1E<F5R.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@?0H*("`@
M(&9U;F-T:6]N('-H;W=(96%D97(H)&)O;VPI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]S:&]W2&5A9&5R(#T@)&)O;VP["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S(&]R(')E='5R;G,@=VAE=&AE<B!T:&4@9F]R;2!T:71L92!S:&]U
M;&0@8F4@96YC;V1E9"!W:71H"B`@("`@*B!H=&UL<W!E8VEA;&-H87)S*"DN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&5N8V]D92`@268@=')U
M92P@=&AE(&9O<FT@=&ET;&4@9V5T<R!E;F-O9&5D+B`@268@9F%L<V4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H92!T:71L92!C86X@8V]N
M=&%I;B!(5$U,+"!B=70@=&AE(&-L87-S('5S97(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@(&ES(')E<W!O;G-I8FQE('1O(&5N8V]D92!A;GD@
M<W!E8VEA;"!C:&%R86-T97)S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5VAE=&AE<B!T:&4@9F]R;2!T:71L92!S:&]U;&0@8F4@96YC;V1E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E5&ET;&4H)&5N8V]D92`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1E;F-O9&4I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?96YC;V1E5&ET;&4@/2`D96YC;V1E.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]E;F-O9&54:71L92`]
M("1E;F-O9&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3<&5C:69Y('1H92!W
M:61T:"!O9B!T:&4@871T<FEB=71E(&-O;'5M;B!I;B!T:&4@<F5N9&5R960@
M9F]R;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@5&AE
M('=I9'1H(&]F('1H92!A='1R:6)U=&4@8V]L=6UN+@H@("`@("H*("`@("`J
M($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!S971!='1R0V]L
M=6UN5VED=&@H)'=I9'1H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?871T<D-O
M;'5M;E=I9'1H(#T@)'=I9'1H.PH@("`@?0H*("`@(&9U;F-T:6]N(&]P96XH
M)&%C=&EO;BP@)&UE=&AO9"P@)&YA;64L("1E;F-T>7!E(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D;F%M
M92`](&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I.PH@("`@("`@(&5C:&\@(CQF
M;W)M(&%C=&EO;CU<(B1A8W1I;VY<(B!M971H;V0]7"(D;65T:&]D7"(B("X@
M*&5M<'1Y*"1N86UE*2`_("<G(#H@(B!N86UE/5PB)&YA;65<(B!I9#U<(B1N
M86UE7"(B*2`N("AI<U]N=6QL*"1E;F-T>7!E*2`_("<G(#H@(B!E;F-T>7!E
M/5PB)&5N8W1Y<&5<(B(I("X@(CY<;B(["B`@("`@("`@571I;#HZ<&9O<FU)
M;G!U="@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&)E9VEN06-T:79E*"1N86UE
M+"`D97AT<F$@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5N9&5R
M0F5G:6Y!8W1I=F4H)&YA;64L("1E>'1R82D["B`@("!]"@H@("`@9G5N8W1I
M;VX@8F5G:6Y);F%C=&EV92@D;F%M92P@)&5X=')A(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W)E;F1E<D)E9VEN26YA8W1I=F4H)&YA;64L("1E
M>'1R82D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E-E8W1I;VY486)S
M*"8D9F]R;2D*("`@('L*("`@("`@("`O*B!)9B!J879A<V-R:7!T(&ES(&YO
M="!A=F%I;&%B;&4L(&1O(&YO="!R96YD97(@=&%B<RX@*B\*("`@("`@("!I
M9B`H(21'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E871U<F4H)VIA=F%S8W)I
M<'0G*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@
M("`D;W!E;E]S96-T:6]N(#T@)&9O<FTM/F=E=$]P96Y396-T:6]N*"D["@H@
M("`@("`@("\J($%D9"!T:&4@:F%V87-C<FEP="!F;W(@=&AE('1O9V=L:6YG
M('1H92!S96-T:6]N<RX@*B\*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL
M92@G9F]R;5]S96-T:6]N<RYJ<R<L("=H;W)D92<L('1R=64I.PH@("`@("`@
M(&5C:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CXG("X@(EQN
M(CL*("`@("`@("!P<FEN=&8H)W9A<B!S96-T:6]N<U\E,21S(#T@;F5W($AO
M<F1E7T9O<FU?4V5C=&EO;G,H7"<E,21S7"<L(%PG)3(D<UPG*3LG+`H@("`@
M("`@("`@("`@("`D9F]R;2T^9V5T3F%M92@I+`H@("`@("`@("`@("`@("`D
M;W!E;E]S96-T:6]N*3L*("`@("`@("!E8VAO(")<;B(@+B`G/"]S8W)I<'0^
M)SL*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H('1H92!S96-T:6]N<R!A;F0@
M<')I;G0@;W5T(&$@=&%B(&9O<B!E86-H+B`J+PH@("`@("`@(&5C:&\@(CQD
M:78@8VQA<W,]7")T86)S971<(CX\=6P^7&XB.PH@("`@("`@(&9O<F5A8V@@
M*"1F;W)M+3Y?<V5C=&EO;G,@87,@)'-E8W1I;VX@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`D8VQA<W,@/2`H)'-E8W1I;VX@/3T@)&]P96Y?<V5C=&EO;BD@
M/R`G(&-L87-S/2)A8W1I=F5486(B)R`Z("<G.PH@("`@("`@("`@("`D:G,@
M/2!S<')I;G1F*"=O;F-L:6-K/2)S96-T:6]N<U\E<RYT;V=G;&4H7"<E<UPG
M*3L@<F5T=7)N(&9A;'-E.R(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W)M+3YG971.86UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-E8W1I;VXI.PH@("`@("`@("`@("!P<FEN=&8H)SQL:25S(&ED/2(E<R(^
M/&$@:')E9CTB(R(@)7,^)7,E<SPO83X@/"]L:3XG("X@(EQN(BP*("`@("`@
M("`@("`@("`@("`@("1C;&%S<RP@)U]T86)?)R`N("1S96-T:6]N+"`D:G,L
M"B`@("`@("`@("`@("`@("`@("`D9F]R;2T^9V5T4V5C=&EO;DEM86=E*"1S
M96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("1F;W)M+3YG971396-T:6]N
M1&5S8R@D<V5C=&EO;BDI.PH@("`@("`@('T*("`@("`@("!E8VAO("(\+W5L
M/CPO9&EV/CQB<B!C;&%S<SU<(F-L96%R7"(@+SY<;B(["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E-E8W1I;VY"96=I;B@F)&9O<FTL("1S96-T:6]N
M*0H@("`@>PH@("`@("`@("\O(%-T<FEP92!A;'1E<FYA=&4@<F]W<R!I9B!T
M:&%T(&]P=&EO;B!I<R!T=7)N960@;VXN"B`@("`@("`@:68@*"1T:&ES+3Y?
M<W1R:7!E9%)O=W,I('L*("`@("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I
M;&4H)W-T<FEP92YJ<R<L("=H;W)D92<L('1R=64I.PH@("`@("`@("`@("`D
M8VQA<W,@/2`G(&-L87-S/2)S=')I<&5D(B<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-L87-S(#T@)R<["B`@("`@("`@?0H*("`@("`@("`D
M;W!E;E]S96-T:6]N(#T@)&9O<FTM/F=E=$]P96Y396-T:6]N*"D["B`@("`@
M("`@:68@*&5M<'1Y*"1O<&5N7W-E8W1I;VXI*2!["B`@("`@("`@("`@("1O
M<&5N7W-E8W1I;VX@/2`G7U]B87-E)SL*("`@("`@("!]"B`@("`@("`@<')I
M;G1F*"<\9&EV(&ED/2(E<R(@<W1Y;&4](F1I<W!L87DZ)7,[(CX\=&%B;&4E
M<R!C96QL<W!A8VEN9STB,"(^)RP*("`@("`@("`@("`@("`@)U]S96-T:6]N
M7R<@+B`D<V5C=&EO;BP*("`@("`@("`@("`@("`@*"1O<&5N7W-E8W1I;VX@
M/3T@)'-E8W1I;VX@/R`G8FQO8VLG(#H@)VYO;F4G*2P*("`@("`@("`@("`@
M("`@)&-L87-S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4V5C=&EO
M;D5N9"@I"B`@("!["B`@("`@("`@96-H;R`G/"]T86)L93X\+V1I=CXG.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&5N9"@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]R96YD97)%;F0H*3L*("`@('T*"B`@("!F=6YC=&EO;B!C;&]S92@D9F]C
M=7,@/2!T<G5E*0H@("`@>PH@("`@("`@(&5C:&\@(CPO9F]R;3Y<;B(["B`@
M("`@("`@:68@*"1F;V-U<R`F)B`A96UP='DH)'1H:7,M/E]F:7)S=$9I96QD
M*2D@>PH@("`@("`@("`@("!E8VAO("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(^"CPA+2T*=')Y('L*("`@(&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*"(G("X@)'1H:7,M/E]F:7)S=$9I96QD("X@)R(I+F9O8W5S*"D["GT@
M8V%T8V@H92D@>WT*+R\M+3X*/"]S8W)I<'0^"B<["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&QI<W1&;W)M5F%R<R@F)&9O<FTI"B`@("!["B`@
M("`@("`@)'9A<FEA8FQE<R`]("8D9F]R;2T^9V5T5F%R:6%B;&5S*'1R=64L
M('1R=64I.PH@("`@("`@("1V87)S(#T@87)R87DH*3L*("`@("`@("!I9B`H
M)'9A<FEA8FQE<RD@>PH@("`@("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S
M(&%S("1V87(I('L*("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A
M<BDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(21V87(M/FES4F5A9&]N
M;'DH*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%R<ULD=F%R+3YG
M971687).86UE*"E=(#T@,3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V87)S
M6R1V87)=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TY,4RYP:'`G
M.PH@("`@("`@(&5C:&\@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](E]F
M;W)M=F%R<R(@=F%L=64](B<@+B!`:'1M;'-P96-I86QC:&%R<RAS97)I86QI
M>F4H)'9A<G,I+"!%3E1?455/5$53+"!.3%,Z.F=E=$-H87)S970H*2D@+B`G
M(B`O/B<["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R1F]R;4%C=&EV92@F
M)&9O<FTL("8D=F%R<RD*("`@('L*("`@("`@("`D=&AI<RT^7W)E;F1E<D9O
M<FTH)&9O<FTL("1V87)S+"!T<G5E*3L*("`@('T*"B`@("!F=6YC=&EO;B!R
M96YD97)&;W)M26YA8W1I=F4H)B1F;W)M+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]R96YD97)&;W)M*"1F;W)M+"`D=F%R<RP@9F%L<V4I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)&;W)M*"8D9F]R;2P@)B1V87)S
M+"`D86-T:79E*0H@("`@>PH@("`@("`@("\J($EF(&AE;'`@:7,@<')E<V5N
M="`S(&-O;'5M;G,@87)E(&YE961E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O
M;',@/2`D9F]R;2T^:&%S2&5L<"@I(#\@,R`Z(#(["@H@("`@("`@("1V87)I
M86)L97,@/2`F)&9O<FTM/F=E=%9A<FEA8FQE<RAF86QS92D["@H@("`@("`@
M("\J($-H96-K(&9O<B!A(&9O<FT@=&]K96X@97)R;W(N("HO"B`@("`@("`@
M:68@*"@D=&]K96Y%<G)O<B`]("1F;W)M+3YG971%<G)O<B@G7U]F;W)M5&]K
M96XG*2D@(3T](&YU;&PI('L*("`@("`@("`@("`@<')I;G1F*"<\='(@=F%L
M:6=N/2)T;W`B/CQT9"!C;VQS<&%N/2(E9"(^/'-P86X@8VQA<W,](F9O<FTM
M97)R;W(B/B5S/"]S<&%N/CPO=&0^/"]T<CXG+`H@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C;VQS+`H@("`@("`@("`@("`@("`@("`@)'1O:V5N17)R
M;W(I.PH@("`@("`@('T*"B`@("`@("`@)&5R<F]R7W-E8W1I;VX@/2!N=6QL
M.PH@("`@("`@(')E<V5T*"1V87)I86)L97,I.PH@("`@("`@(&EF("AC;W5N
M="@D=F%R:6%B;&5S*2`^(#$@?'P@:V5Y*"1V87)I86)L97,I("$]("=?7V)A
M<V4G*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R4V5C=&EO;E1A8G,H
M)&9O<FTI.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'9A<FEA8FQE
M<R!A<R`D<V5C=&EO;E]I9"`]/B`D<V5C=&EO;BD@>PH@("`@("`@("`@("`D
M=&AI<RT^7W)E;F1E<E-E8W1I;VY"96=I;B@D9F]R;2P@)'-E8W1I;VY?:60I
M.PH@("`@("`@("`@("!F;W)E86-H("@D<V5C=&EO;B!A<R`D=F%R*2!["B`@
M("`@("`@("`@("`@("`D='EP92`]("1V87(M/F=E=%1Y<&5.86UE*"D["@H@
M("`@("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("`@
M("`@8V%S92`G:&5A9&5R)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W)E;F1E<DAE861E<B@D=F%R+3YG971(=6UA;DYA;64H*2P@)&9O<FTM/F=E
M=$5R<F]R*"1V87(M/F=E=%9A<DYA;64H*2DI.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V1E<V-R:7!T:6]N
M)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E;F1E<D1E<V-R:7!T
M:6]N*"1V87(M/F=E=$AU;6%N3F%M92@I*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=S<&%C97(G.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R4W!A8V5R*"D["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@("`@("`D:7-);G!U="`]("@D86-T:79E("8F
M("$D=F%R+3YI<U)E861O;FQY*"DI.PH@("`@("`@("`@("`@("`@("`@("1F
M;W)M870@/2`D:7-);G!U="`_("=);G!U="<@.B`G1&ES<&QA>2<["B`@("`@
M("`@("`@("`@("`@("`@)&)E9VEN(#T@(E]R96YD97)687(D>V9O<FUA='U"
M96=I;B(["B`@("`@("`@("`@("`@("`@("`@)&5N9"`](")?<F5N9&5R5F%R
M)'MF;W)M871]16YD(CL*"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/B1B
M96=I;B@D9F]R;2P@)'9A<BP@)'9A<G,I.PH*("`@("`@("`@("`@("`@("`@
M("!E8VAO("1T:&ES+3Y?=F%R4F5N9&5R97(M/G)E;F1E<B@D9F]R;2P@)'9A
M<BP@)'9A<G,L("1I<TEN<'5T*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^)&5N9"@D9F]R;2P@)'9A<BP@)'9A<G,I.PH*("`@("`@("`@("`@("`@
M("`@("`O*B!0<FEN="!A;GD@:F%V87-C<FEP="!I9B!A8W1I;VYS('!R97-E
M;G0N("HO"B`@("`@("`@("`@("`@("`@("`@:68@*"1V87(M/FAA<T%C=&EO
M;B@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V87(M/E]A8W1I;VXM
M/G!R:6YT2F%V85-C<FEP="@I.PH@("`@("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`@("`@+RH@2V5E<"!F:7)S="!F:65L9"X@*B\*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&%C=&EV92`F)B!E;7!T>2@D=&AI<RT^
M7V9I<G-T1FEE;&0I("8F("$D=F%R+3YI<U)E861O;FQY*"D@)B8@(21V87(M
M/FES2&ED9&5N*"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]F:7)S=$9I96QD(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@+RH@2V5E<"!S96-T
M:6]N('=I=&@@9FER<W0@97)R;W(N("HO"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7VYU;&PH)&5R<F]R7W-E8W1I;VXI("8F("1F;W)M+3YG971%<G)O
M<B@D=F%R*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D97)R;W)?<V5C
M=&EO;B`]("1S96-T:6]N7VED.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H
M:7,M/E]R96YD97)396-T:6]N16YD*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES7VYU;&PH)&5R<F]R7W-E8W1I;VXI("8F("1F;W)M+3Y?<V5C=&EO
M;G,I('L*("`@("`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/B<@+@H@("`@("`@("`@("`@("`@(EQN(B`N('-P<FEN=&8H
M)W-E8W1I;VYS7R5S+G1O9V=L92A<)R5S7"<I.R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9F]R;2T^9V5T3F%M92@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<F]R7W-E8W1I;VXI("X*("`@("`@
M("`@("`@("`@(")<;CPO<V-R:7!T/B(["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N('-U8FUI="@D<W5B;6ET(#T@;G5L;"P@)')E<V5T(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'-U8FUI="D@?'P@96UP
M='DH)'-U8FUI="DI('L*("`@("`@("`@("`@)'-U8FUI="`](%\H(E-U8FUI
M="(I.PH@("`@("`@('T*("`@("`@("!I9B`H)')E<V5T(#T]/2!T<G5E*2![
M"B`@("`@("`@("`@("1R97-E="`](%\H(E)E<V5T(BD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?<F5N9&5R4W5B;6ET*"1S=6)M:70L("1R97-E="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);7!L96UE;G1A=&EO;B!S<&5C:69I
M8R!B96=I;B!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;F1E
M<D)E9VEN06-T:79E*"1N86UE+"`D97AT<F$I"B`@("!["B`@("`@("`@96-H
M;R`G/&1I=B!C;&%S<STB9F]R;2(@:60](B<@+B!H=&UL<W!E8VEA;&-H87)S
M*"1T:&ES+3Y?;F%M92D@+B`G(CXG.PH@("`@("`@(&EF("@D=&AI<RT^7W-H
M;W=(96%D97(I('L*("`@("`@("`@("`@)'1H:7,M/E]S96-T:6]N2&5A9&5R
M*"1N86UE+"`D97AT<F$I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M
M/E]R97%U:7)E9$QE9V5N9"D@>PH@("`@("`@("`@("!E8VAO("<\<W!A;B!C
M;&%S<STB9F]R;2UE<G)O<B(^)R`N("1T:&ES+3Y?<F5Q=6ER961-87)K97(@
M+B`G/"]S<&%N/B`]("<@+B!?*")297%U:7)E9"!&:65L9"(I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($EM<&QE;65N=&%T:6]N('-P96-I
M9FEC(&)E9VEN(&9U;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5N
M9&5R0F5G:6Y);F%C=&EV92@D;F%M92P@)&5X=')A*0H@("`@>PH@("`@("`@
M(&5C:&\@)SQD:78@8VQA<W,](F9O<FTB(&ED/2(G("X@:'1M;'-P96-I86QC
M:&%R<R@D=&AI<RT^7VYA;64I("X@)R(^)SL*("`@("`@("!I9B`H)'1H:7,M
M/E]S:&]W2&5A9&5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5C=&EO;DAE
M861E<B@D;F%M92P@)&5X=')A*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!);7!L96UE;G1A=&EO;B!S<&5C:69I8R!E;F0@9G5N8W1I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96YD97)%;F0H*0H@("`@>PH@("`@
M("`@(&5C:&\@)SPO9&EV/B<@+B`D=&AI<RT^7W9A<E)E;F1E<F5R+3YR96YD
M97)%;F0H*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R2&5A9&5R*"1H
M96%D97(L("1E<G)O<B`]("<G*0H@("`@>PH_/CQT<CX\=&0@8VQA<W,](F-O
M;G1R;VPB('=I9'1H/2(Q,#`E(B!C;VQS<&%N/2(\/W!H<"!E8VAO("1T:&ES
M+3Y?8V]L<R`_/B(@=F%L:6=N/2)B;W1T;VTB/CQS=')O;F<^/#]P:'`@96-H
M;R`D:&5A9&5R(#\^/"]S=')O;F<^/#]P:'`*("`@("`@("!I9B`H(65M<'1Y
M*"1E<G)O<BDI('L*/SX\8G(@+SX\<W!A;B!C;&%S<STB9F]R;2UE<G)O<B(^
M/#]P:'`@96-H;R`D97)R;W(@/SX\+W-P86X^/#]P:'`*("`@("`@("!]"C\^
M/"]T9#X\+W1R/@H\/W!H<`H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)$
M97-C<FEP=&EO;B@D=&5X="D*("`@('L*/SX\='(^/'1D('=I9'1H/2(Q,#`E
M(B!C;VQS<&%N/2(\/W!H<"!E8VAO("1T:&ES+3Y?8V]L<R`_/B(^/'`@<W1Y
M;&4](G!A9&1I;F<Z.'!X(CX\/W!H<"!E8VAO("1T97AT(#\^/"]P/CPO=&0^
M/"]T<CX*/#]P:'`*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4W!A8V5R
M*"D*("`@('L*/SX\='(^/'1D(&-O;'-P86X](CP_<&AP(&5C:&\@)'1H:7,M
M/E]C;VQS(#\^(CXF;F)S<#L\+W1D/CPO='(^"CP_<&AP"B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E-U8FUI="@D<W5B;6ET+"`D<F5S970I"B`@("![
M"C\^/&1I=B!C;&%S<STB8V]N=')O;"(^"B`@/#]P:'`@:68@*"%I<U]A<G)A
M>2@D<W5B;6ET*2D@)'-U8FUI="`](&%R<F%Y*"1S=6)M:70I.R!F;W)E86-H
M("@D<W5B;6ET(&%S("1S=6)M:71B=71T;VXI.B`_/@H@("`@/&EN<'5T(&-L
M87-S/2)B=71T;VXB(&YA;64](G-U8FUI=&)U='1O;B(@='EP93TB<W5B;6ET
M(B!V86QU93TB/#]P:'`@96-H;R`D<W5B;6ET8G5T=&]N(#\^(B`O/@H@(#P_
M<&AP(&5N9&9O<F5A8V@[(#\^"B`@/#]P:'`@:68@*"%E;7!T>2@D<F5S970I
M*3H@/SX*("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!N86UE/2)R97-E=&)U
M='1O;B(@='EP93TB<F5S970B('9A;'5E/2(\/W!H<"!E8VAO("1R97-E="`_
M/B(@+SX*("`\/W!H<"!E;F1I9CL@/SX*/"]D:78^"CP_<&AP"B`@("!]"@H@
M("`@+R\@26UP;&5M96YT871I;VX@<W!E8VEF:6-S("TM(&EN<'5T('9A<FEA
M8FQE<RX*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=$)E9VEN*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D;65S<V%G92`]("1F
M;W)M+3YG971%<G)O<B@D=F%R*3L*("`@("`@("`D:7-V86QI9"`](&5M<'1Y
M*"1M97-S86=E*3L*("`@("`@("!E8VAO("(\='(@=F%L:6=N/5PB=&]P7"(^
M7&XB.PH@("`@("`@('!R:6YT9B@G("`\=&0E<R!A;&EG;CTB<FEG:'0B/B5S
M)7,E<R5S/"]T9#XG("X@(EQN(BP*("`@("`@("`@("`@("`@96UP='DH)'1H
M:7,M/E]A='1R0V]L=6UN5VED=&@I(#\@)R<@.B`G('=I9'1H/2(G("X@)'1H
M:7,M/E]A='1R0V]L=6UN5VED=&@@+B`G(B<L"B`@("`@("`@("`@("`@("1I
M<W9A;&ED(#\@)R<@.B`G/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/B<L"B`@
M("`@("`@("`@("`@("1V87(M/FES4F5Q=6ER960H*2`_("<\<W!A;B!C;&%S
M<STB9F]R;2UE<G)O<B(^)R`N("1T:&ES+3Y?<F5Q=6ER961-87)K97(@+B`G
M/"]S<&%N/B9N8G-P.R<@.B`G)RP*("`@("`@("`@("`@("`@)'9A<BT^9V5T
M2'5M86Y.86UE*"DL"B`@("`@("`@("`@("`@("1I<W9A;&ED(#\@)R<@.B`G
M/&)R("\^)R`N("1M97-S86=E("X@)SPO<W!A;CXG*3L*("`@("`@("!P<FEN
M=&8H)R`@/'1D)7,^)RP*("`@("`@("`@("`@("`@*"@A)'9A<BT^:&%S2&5L
M<"@I("8F("1F;W)M+3YH87-(96QP*"DI(#\@)R!C;VQS<&%N/2(R(B<@.B`G
M)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=$5N9"@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@+RH@1&ES<&QA
M>2!A;GD@9&5S8W)I<'1I;VX@9F]R('1H92!F:65L9"X@*B\*("`@("`@("!I
M9B`H)'9A<BT^:&%S1&5S8W)I<'1I;VXH*2D@>PH@("`@("`@("`@("!E8VAO
M("<\8G(@+SXG("X@)'9A<BT^9V5T1&5S8W)I<'1I;VXH*3L*("`@("`@("!]
M"@H@("`@("`@("\J($1I<W!L87D@86YY(&AE;'`@9F]R('1H92!F:65L9"X@
M*B\*("`@("`@("!I9B`H)'9A<BT^:&%S2&5L<"@I*2!["B`@("`@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@(&EF("AI<W-E="@D<F5G
M:7-T<GDI("8F(&ES7V$H)')E9VES=')Y+"`G4F5G:7-T<GDG*2D@>PH@("`@
M("`@("`@("`@("`@)&QI;FL@/2!(96QP.CIL:6YK*"1'3$]"04Q36R=R96=I
M<W1R>2==+3YG971!<'`H*2P@)'9A<BT^9V5T2&5L<"@I*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L:6YK(#T@)SQA(&AR968]
M(B,B(&]N8VQI8VL](F%L97)T*%PG)R`N(&%D9'-L87-H97,H0&AT;6QS<&5C
M:6%L8VAA<G,H)'9A<BT^9V5T2&5L<"@I*2D@+B`G7"<I.W)E='5R;B!F86QS
M93LB/B<@+B`D=&AI<RT^7VAE;'!-87)K97(@+B`G/"]A/B<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96-H;R`B/"]T9#Y<;B`@/'1D('-T>6QE/5PB
M=&5X="UA;&EG;CIR:6=H=%PB/B1L:6YK)FYB<W`[(CL*("`@("`@("!]"@H@
M("`@("`@(&5C:&\@(CPO=&0^7&X\+W1R/EQN(CL*("`@('T*"B`@("`O+R!)
M;7!L96UE;G1A=&EO;B!S<&5C:69I8W,@+2T@9&ES<&QA>2!V87)I86)L97,N
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>4)E9VEN*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D;65S<V%G92`]("1F;W)M
M+3YG971%<G)O<B@D=F%R*3L*("`@("`@("`D:7-V86QI9"`](&5M<'1Y*"1M
M97-S86=E*3L*("`@("`@("!E8VAO("(\='(@=F%L:6=N/5PB=&]P7"(^7&XB
M.PH@("`@("`@('!R:6YT9B@G("`\=&0E<R!A;&EG;CTB<FEG:'0B/B5S/'-T
M<F]N9SXE<SPO<W1R;VYG/B5S/"]T9#XG("X@(EQN(BP*("`@("`@("`@("`@
M("`@96UP='DH)'1H:7,M/E]A='1R0V]L=6UN5VED=&@I(#\@)R<@.B`G('=I
M9'1H/2(G("X@)'1H:7,M/E]A='1R0V]L=6UN5VED=&@@+B`G(B<L"B`@("`@
M("`@("`@("`@("1I<W9A;&ED(#\@)R<@.B`G/'-P86X@8VQA<W,](F9O<FTM
M97)R;W(B/B<L"B`@("`@("`@("`@("`@("1V87(M/F=E=$AU;6%N3F%M92@I
M+`H@("`@("`@("`@("`@("`D:7-V86QI9"`_("<G(#H@)SQB<B`O/B<@+B`D
M;65S<V%G92`N("<\+W-P86X^)RD["B`@("`@("`@96-H;R`G("`\=&0^)SL*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>45N9"@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@96-H;R`B/"]T9#Y<
M;CPO='(^7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S96-T:6]N2&5A9&5R
M*"1T:71L92P@)&5X=')A(#T@)R<I"B`@("!["B`@("`@("`@:68@*'-T<FQE
M;B@D=&ET;&4I*2!["B`@("`@("`@("`@(&5C:&\@)SQD:78@8VQA<W,](FAE
M861E<B(^)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D97AT<F$I*2!["B`@
M("`@("`@("`@("`@("!E8VAO("<\<W!A;B!S='EL93TB9FQO870Z<FEG:'0B
M/B<@+B`D97AT<F$@+B`G/"]S<&%N/B<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96-H;R`D=&AI<RT^7V5N8V]D951I=&QE(#\@:'1M;'-P96-I86QC
M:&%R<R@D=&ET;&4I(#H@)'1I=&QE.PH@("`@("`@("`@("!E8VAO("<\+V1I
M=CXG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7T9O<FU?4F5N9&5R97(@:6YS
M=&%N8V4@8F%S960@;VX*("`@("`J("1R96YD97)E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)')E;F1E<F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!(;W)D95]&;W)M7U)E;F1E<F5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!S=6)C;&%S<R!T;R!R971U<FXN(%1H92!C;V1E(&ES(&1Y;F%M
M:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E
M9"X@268@)')E;F1E<F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&QO;VL@:6X@)')E;F1E<F5R
M6S!=+VQI8B]&;W)M+U)E;F1E<F5R+R!F;W(@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE
M9"`D<F5N9&5R97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG
M=7)A=&EO;B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!F;W)M
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]&;W)M
M7U)E;F1E<F5R("!4:&4@8V]N8W)E=&4@2&]R9&5?1F]R;5]296YD97)E<B!R
M969E<F5N8V4L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F%C=&]R>2@D<F5N9&5R97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D<F5N9&5R97(I*2!["B`@("`@("`@("`@("1A
M<'`@/2`D<F5N9&5R97);,%T["B`@("`@("`@("`@("1R96YD97)E<B`]("1R
M96YD97)E<ELQ73L*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!A(&)A
M<V4@2&]R9&5?1F]R;5]296YD97)E<B!O8FIE8W0@:68@;F\@9')I=F5R(&ES
M"B`@("`@("`@("H@<W!E8VEF:65D+B`J+PH@("`@("`@("1R96YD97)E<B`]
M(&)A<V5N86UE*"1R96YD97)E<BD["B`@("`@("`@:68@*&5M<'1Y*"1R96YD
M97)E<BD@?'P@*'-T<F-M<"@D<F5N9&5R97(L("=N;VYE)RD@/3T@,"DI('L*
M("`@("`@("`@("`@)&9O<FUR96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]2
M96YD97)E<B@D<&%R86US*3L*("`@("`@("`@("`@<F5T=7)N("1F;W)M<F5N
M9&5R97(["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2![
M"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O1F]R;2]296YD97)E
M<B\G("X@)')E;F1E<F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`
M9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E;F1E<F5R+R<@
M+B`D<F5N9&5R97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(&EN8VQU9&5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4F5N9&5R97(O)R`N("1R96YD
M97)E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`
M:6YC;'5D95]O;F-E("=(;W)D92]&;W)M+U)E;F1E<F5R+R<@+B`D<F5N9&5R
M97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C;&%S<R`]("=(;W)D
M95]&;W)M7U)E;F1E<F5R7R<@+B`D<F5N9&5R97(["B`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1F;W)M<F5N9&5R
M97(@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9F]R;7)E;F1E<F5R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N
M)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9O<FUR96YD97)E<CL*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E
M9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7T9O<FU?4F5N9&5R97(*("`@
M("`J(&EN<W1A;F-E(&)A<V5D(&]N("1R96YD97)E<BX@270@=VEL;"!O;FQY
M(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;PH@("`@("H@2&]R9&5?1F]R
M;5]296YD97)E<B!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@
M8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B
M92!U<V5D(&EF(&UU;'1I<&QE('1Y<&5S(&]F(&9O<FT@<F5N9&5R97)S("AA
M;F0L"B`@("`@*B!T:'5S+"!M=6QT:7!L92!(;W)D95]&;W)M7U)E;F1E<F5R
M(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9(;W)D95]&;W)M
M7U)E;F1E<F5R.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D<F5N9&5R97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T9O
M<FU?4F5N9&5R97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('-U
M8F-L87-S('1O(')E='5R;BX@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&5D+B!)9B`D<F5N
M9&5R97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@;&]O:R!I;B`D<F5N9&5R97);,%TO;&EB+T9O
M<FTO4F5N9&5R97(O(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('-U8F-L87-S(&EM<&QE;65N=&%T:6]N(&YA;65D("1R96YD97)E
M<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@9F]R;2!M:6=H="!N965D+@H@
M("`@("H*("`@("`J($!R971U<FX@2&]R9&5?1F]R;5]296YD97)E<B`@5&AE
M(&-O;F-R971E($AO<F1E7T9O<FU?4F5N9&5R97(@<F5F97)E;F-E+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!F86QS92!O;B!A
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D<F5N
M9&5R97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D
M:6YS=&%N8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*
M("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1R96YD97)E
M<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD
M<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E72`]("9(;W)D95]&;W)M7U)E;F1E<F5R.CIF86-T;W)Y*"1R96YD97)E
M<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A
M;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;B\`
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C``,#$W,C<V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U1O:V5N+V9I;&4N<&AP````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,#8T-``Q,#4Q-30S,3`V,``P,C`W,S``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1O:V5N('1R86-K:6YG(&EM<&QE;65N=&%T:6]N(&9O<B!L;V-A;"!F
M:6QE<RX*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=T
M;VME;E]D:7(G("!4:&4@9&ER96-T;W)Y('=H97)E('1O(&ME97`@=&]K96X@
M9FEL97,N"B`J("`@)W1I;65O=70G("`@(%1H92!P97)I;V0@*&EN('-E8V]N
M9',I(&%F=&5R('=H:6-H(&%N(&ED(&ES('!U<F=E9"X*("H@("`@("`@("`@
M("`@("`@1&5F875L=',@=&\@.#8T,#`@*&DN92X@,C0@:&]U<G,I+CPO<')E
M/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]4;VME;B]4;VME;B]F:6QE+G!H
M<"QV(#$N,3DN-BXW(#(P,#8O,#$O,#$@,C$Z,C@Z,SD@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@36%X($MA;&EK82`\;6%X0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA>"!+86QI:V$@
M/&UA>$!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]4;VME;@H@*B\*8VQA<W,@2&]R9&5?5&]K96Y?9FEL92!E
M>'1E;F1S($AO<F1E7U1O:V5N('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F
M;W(@=&AE(&]P96X@9FEL92!D97-C<FEP=&]R+@H@("`@("H*("`@("`J($!V
M87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?9F0@/2!F86QS93L*"B`@
M("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R(&]R(&YO
M="!W92!H879E(&%N(&]P96X@9FEL92!D97-C<FEP=&]R+@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T960@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($-R96%T92!A(&YE=R!F:6QE(&)A
M<V5D('1O:V5N+71R86-K:6YG(&-O;G1A:6YE<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@<W1O<F%G
M92!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]4;VME
M;E]F:6QE*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<&%R86US(#T@)'!A<F%M<SL*"B`@("`@("`@+RH@0VAO;W-E('1H92!D
M:7)E8W1O<GD@=&\@<V%V92!T:&4@<W1U8B!F:6QE<RX@*B\*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1O:V5N7V1I<B==(#T@571I;#HZ
M9V5T5&5M<$1I<B@I.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('1I;65O
M=70@=&\@,C0@:&]U<G,@:68@;F]T('-P96-I9FEE9"X@*B\*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T:6UE;W5T)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T:6UE;W5T)UT@/2`X-C0P,#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%L;"!E>'!I
M<F5D(&-O;FYE8W1I;VX@:60G<R!F<F]M('1H92!344P@<V5R=F5R+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B!4<G5E(&]N('-U8V-E<W,L(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<'5R9V4H*0H@("`@>PH@("`@("`@("\O($UA:V4@<W5R92!W92!H
M879E(&YO(&]P96X@9FEL92!D97-C<FEP=&]R<R!B969O<F4@=6YL:6YK:6YG
M"B`@("`@("`@+R\@9FEL97,N"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<V-O
M;FYE8W0H*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G56YA8FQE('1O(&-L;W-E(&9I;&4@9&5S8W)I<'1O<G,G*3L*("`@("`@
M("!]"@H@("`@("`@("\J($)U:6QD('-T=6(@9FEL92!L:7-T+B`J+PH@("`@
M("`@(&EF("@A*"1D:7(@/2!O<&5N9&ER*"1T:&ES+3Y?<&%R86US6R=T;VME
M;E]D:7(G72DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=5;F%B;&4@=&\@;W!E;B!T;VME;B!D:7)E8W1O<GDG*3L*("`@("`@
M("!]"@H@("`@("`@("\J($9I;F0@97AP:7)E9"!S='5B(&9I;&5S("HO"B`@
M("`@("`@=VAI;&4@*"@D9&ER16YT<GD@/2!R96%D9&ER*"1D:7(I*2`A/2`G
M)RD@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G?%YC;VYN7UQW>SA]
M)'PG+"`D9&ER16YT<GDI("8F("AT:6UE*"D@+2!F:6QE;71I;64H)'1H:7,M
M/E]P87)A;7-;)W1O:V5N7V1I<B==("X@)R\G("X@)&1I<D5N=')Y*2`^/2`D
M=&AI<RT^7W!A<F%M<ULG=&EM96]U="==*2D@>PH@("`@("`@("`@("`@("`@
M:68@*"%`=6YL:6YK*"1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72`N("<O
M)R`N("1D:7)%;G1R>2DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O('!U<F=E('1O:V5N(&9I;&4N
M)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&-L;W-E9&ER*"1D:7(I.PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&5X:7-T<R@D=&]K96Y)1"D*("`@('L*
M("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]("1T:&ES+3Y?8V]N;F5C="@D
M=&]K96Y)1"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@1FEN9"!A;')E861Y
M('5S960@241S+B`J+PH@("`@("`@("1F:6QE0V]N=&5N=',@/2!`9FEL92@D
M=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER)UT@+B`G+V-O;FY?)R`N("1T:&ES
M+3YE;F-O9&5296UO=&5!9&1R97-S*"DI.PH@("`@("`@(&EF("@D9FEL94-O
M;G1E;G1S*2!["B`@("`@("`@("`@("1I36%X(#T@8V]U;G0H)&9I;&5#;VYT
M96YT<RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I36%X.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H8VAO<"@D9FEL94-O;G1E;G1S
M6R1I72D@/3T@)'1O:V5N240I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&%D9"@D=&]K96Y)1"D*("`@('L*("`@("`@("!I9B`H:7-?82@H)')E
M<W5L="`]("1T:&ES+3Y?8V]N;F5C="@D=&]K96Y)1"DI+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@5W)I=&4@=&AE(&5N=')Y+B`J+PH@("`@("`@(&9W<FET
M92@D=&AI<RT^7V9D+"`B)'1O:V5N241<;B(I.PH*("`@("`@("`O*B!2971U
M<FX@86X@97)R;W(@:68@=&AE('5P9&%T92!F86EL<RP@=&]O+B`J+PH@("`@
M("`@(&EF("@A)'1H:7,M/E]D:7-C;VYN96-T*"DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!C;&]S92!T;VME
M;B!F:6QE(&-L96%N;'DN)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS(&$@9FEL92!D97-C
M<FEP=&]R('1O(&$@;F5W(&]R(&5X:7-T:6YG(&9I;&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-O;FYE8W0H)'1O:V5N240I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^
M7V-O;FYE8W1E9"D@>PH*("`@("`@("`@("`@+R\@3W!E;B!A(&9I;&4@9&5S
M8W)I<'1O<B!T;R!T:&4@=&]K96X@<W1U8B!F:6QE+@H@("`@("`@("`@("`D
M=&AI<RT^7V9D(#T@0&9O<&5N*"1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G
M72`N("<O8V]N;E\G("X@)'1H:7,M/F5N8V]D95)E;6]T94%D9')E<W,H*2P@
M)V$G*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V9D*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&]P
M96X@=&]K96X@9FEL92XG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE
M(&9I;&4@9&5S8W)I<'1O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O
M;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@9F-L;W-E*"1T
M:&ES+3Y?9F0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M5&]K96XO<W%L+G!H<```````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$T,C0P`#$P-3$U-#,Q,#8P`#`R,#8P-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&]K96X@
M=')A8VMI;F<@:6UP;&5M96YT871I;VX@9F]R(%!(4"=S(%!%05(@9&%T86)A
M<V4@86)S=')A8W1I;VX@;&%Y97(N"B`J"B`J(%)E<75I<F5D('!A<F%M971E
M<G,Z/'!R93X*("H@("`G<&AP='EP92<@("!4:&4@9&%T86)A<V4@='EP92`H
M:64N("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+CPO<')E/@H@*@H@*B!297%U
M:7)E9"!B>2!S;VUE(&1A=&%B87-E(&EM<&QE;65N=&%T:6]N<SH\<')E/@H@
M*B`@("=D871A8F%S92<@(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@
M("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E
M<G9E<BX*("H@("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC
M:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G
M("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J
M("`@)V]P=&EO;G,G("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@
M=&AE(&1A=&%B87-E+@H@*B`@("=T='DG("`@("`@(%1H92!45%D@;VX@=VAI
M8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!O<G0G("`@
M("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A
M<V4N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G=&%B;&4G("`@("!4:&4@;F%M92!O9B!T:&4@=&]K96YS('1A8FQE(&EN
M("=D871A8F%S92<N"B`J("`@("`@("`@("`@("`@1&5F875L=',@=&\@)VAO
M<F1E7W1O:V5N<R<N"B`J("`@)W1I;65O=70G("`@5&AE('!E<FEO9"`H:6X@
M<V5C;VYD<RD@869T97(@=VAI8V@@86X@:60@:7,@<'5R9V5D+@H@*B`@("`@
M("`@("`@("`@($1E9F%U;'1S('1O(#@V-#`P("AI+F4N(#(T(&AO=7)S*2X\
M+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE('1O:V5N
M<R!I<R!A<R!F;VQL;W=S.@H@*@H@*B`\<')E/@H@*B!#4D5!5$4@5$%"3$4@
M:&]R9&5?=&]K96YS("@*("H@("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!
M4B@Q,#`I($Y/5"!.54Q,+`H@*B`@("`@=&]K96Y?:60@("`@("`@("!605)#
M2$%2*#,R*2!.3U0@3E5,3"P*("H@("`@('1O:V5N7W1I;65S=&%M<"`@0DE'
M24Y4($Y/5"!.54Q,+`H@*@H@*B`@("`@4%))34%262!+15D@*'1O:V5N7V%D
M9')E<W,L('1O:V5N7VED*0H@*B`I.PH@*B`\+W!R93X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO5&]K96XO5&]K96XO<W%L+G!H<"QV(#$N,C,N-BXQ,B`R
M,#`V+S`Q+S$X(#$Y.C0P.C4Q(&)E;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($UA>"!+86QI:V$@/&UA>$!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?5&]K
M96X*("HO"F-L87-S($AO<F1E7U1O:V5N7W-Q;"!E>'1E;F1S($AO<F1E7U1O
M:V5N('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@
M9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($1""B`@
M("`@*B\*("`@('9A<B`D7V1B(#T@)R<["@H@("`@+RHJ"B`@("`@*B!";V]L
M96%N(&EN9&EC871I;F<@=VAE=&AE<B!O<B!N;W0@=V4G<F4@8V]N;F5C=&5D
M('1O('1H92!344P*("`@("`J('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%-13"!C;VYN96-T
M:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]4;VME;E]S<6PH)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH*("`@("`@("`O*B!3970@=&EM96]U="!T;R`R-"!H;W5R<R!I9B!N
M;W0@<W!E8VEF:65D+B`J+PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)W1I;65O=70G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1I;65O=70G72`](#@V-#`P.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($1E;&5T97,@86QL(&5X<&ER960@8V]N;F5C=&EO;B!I9"=S
M(&9R;VT@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<'5R9V4H*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T
M*"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@0G5I;&0@4U%,('%U97)Y+B`J
M+PH@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UT@+B`G(%=(15)%("<["B`@("`@("`@)'%U97)Y("X]
M("=T;VME;E]T:6UE<W1A;7`@/"`_)SL*"B`@("`@("`@)'9A;'5E<R`](&%R
M<F%Y*'1I;64H*2`M("1T:&ES+3Y?<&%R86US6R=T:6UE;W5T)UTI.PH*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L
M=65S*3L*"B`@("`@("`@+RH@4F5T=7)N(&%N(&5R<F]R(&EF('1H92!U<&1A
M=&4@9F%I;',L('1O;RX@*B\*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N
M8W1I;VX@97AI<W1S*"1T;VME;DE$*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M*"@D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T*"DI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J($)U:6QD(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@(#T@
M)U-%3$5#5"!T;VME;E]I9"!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G73L*("`@("`@("`D<75E<GD@+CT@)R!72$5212!T;VME;E]A9&1R97-S
M(#T@/R<["B`@("`@("`@)'%U97)Y("X]("<@04Y$('1O:V5N7VED(#T@/R<[
M"@H@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^96YC;V1E4F5M;W1E
M061D<F5S<R@I+"`D=&]K96Y)1"D["@H@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YG971/;F4H)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@(65M<'1Y*"1R97-U;'0I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!A9&0H)'1O:V5N240I"B`@("!["B`@("`@("`@:68@*&ES7V$H*"1R
M97-U;'0@/2`D=&AI<RT^7V-O;FYE8W0H*2DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@
M("`O*B!"=6EL9"!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y("`]("=)
M3E-%4E0@24Y43R`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+B`G("AT
M;VME;E]A9&1R97-S+"!T;VME;E]I9"P@=&]K96Y?=&EM97-T86UP*2`G.PH@
M("`@("`@("1Q=65R>2`N/2`G5D%,5453("@_+"`_+"`_*2<["@H@("`@("`@
M("1V86QU97,@/2!A<G)A>2@D=&AI<RT^96YC;V1E4F5M;W1E061D<F5S<R@I
M+"`D=&]K96Y)1"P@=&EM92@I*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@3W!E;G,@82!C;VYN96-T:6]N('1O('1H
M92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!O;B!S=6-C97-S+"!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@571I;#HZ
M87-S97)T1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US+"!A<G)A>2@G<&AP
M='EP92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1O:V5N(%-13"<L(&%R<F%Y*"=D<FEV97(G(#T^("=T;VME;B<I
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;64G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S
M97)N86UE)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT@/2`G)SL*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UT@/2`G:&]R9&5?=&]K96YS)SL*("`@("`@("!]"@H@("`@("`@("\J($-O
M;FYE8W0@=&\@=&AE(%-13"!S97)V97(@=7-I;F<@=&AE('-U<'!L:65D('!A
M<F%M971E<G,N("HO"B`@("`@("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@
M("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A
M;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M<&5R<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T
M96YT)UTI*2D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D8CL*("`@
M("`@("!]"@H@("`@("`@("\O(%-E="!$0B!P;W)T86)I;&ET>2!O<'1I;VYS
M+@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@>PH@("`@
M("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T
M3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12!\($1"7U!/4E1!0DE,25197T524D]24R!\($1"7U!/4E1!0DE,25197U)4
M4DE-*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L
M($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T52
M4D]24RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]
M('1R=64["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&ES8V]N;F5C="!F<F]M('1H92!344P@<V5R=F5R(&%N9"!C;&5A
M;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O````````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,0`P,38W-#8`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8Q`#`R,#(P-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U9I97=E<B]O;V\O````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#(Q,#`S`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]T86)L95]C96QL
M<RYX<VP````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V-C(W,@`Q,#4Q-30S,3`V,``P,C0P
M,34`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A
M=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F
M('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@
M("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E
M<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L
M(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!6
M97)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O
M<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!
M;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S
M;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO
M9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N
M97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES
M:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES
M(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W
M:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W
M:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!
M3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N
M<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E
M:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*
M("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W
M<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N
M+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@
M,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3
M;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT
M96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U
M<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@
M*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@
M(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M
M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O
M=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E
M('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A
M;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+
M24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@
M(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T94
M5T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4
M($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N
M"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO
M;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C
M;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L
M;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M
M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES
M=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R
M:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY
M+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@
M("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN
M<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@
M("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@
M("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN
M<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS
M.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@
M("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@
M("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I
M8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT
M='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T
M82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@
M("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B
M"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L
M87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@
M("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C
M:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S
M=6QT+7!R969I>&5S/2)J879A(CX*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ('=R:71E
M(')E<&5A=&EN9R!T86)L92!C96QL<R`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*"B`@("`\(2TM
M(&UA=&-H:6YG(&-E;&QS('1O(&=I=F4@;W5T("T^(&-O=F5R960@=&%B;&4@
M8V5L;',@87)E(&YO="!W<FET=&5N(&]U="`M+3X*("`@(#QX<VPZ=&5M<&QA
M=&4@;6%T8V@](G1A8FQE.G1A8FQE+6-E;&PB/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#PA+2T@
M<&]S:71I;VX@;V8@=&AE(&-U<G)E;G0@:6YP=70@8V5L;"!T;R!G970@=&AE
M(&-O<G)E8W0@8V]L=6T@<W1Y;&4@*&AI9&1E;B!A<F4@86QS;R!C;W5N=&5D
M*2TM/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2;W=,96YG
M=&@B+SX*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^"BTM+2TM+2TM+2TM+2TM/B!T86)L
M93IT86)L92UC96QL(&AA<R!B965N(&5N=&5R960@=VET:"!N;V1E('9A;'5E
M.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93YT86)L93IN=6UB97(M8V]L=6UN<RUR
M97!E871E9#H@+3QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&%B;&4Z;G5M8F5R
M+6-O;'5M;G,M<F5P96%T960B+SXM/"]X<VPZ;65S<V%G93X*("`@("`@("`\
M+WAS;#II9CX*"B`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R
M96%T92UC;VQU;6XM<&]S:71I;VXM=F%R:6%B;&4B/@H@("`@("`@("`@("`\
M(2TM('!O<VET:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T
M('1H92!C;W)R96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U
M;G1E9"DM+3X*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y
M;&5%;G1R:65S(B\^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O
M=TQE;F=T:"(O/@H@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R
M96%T92UC;VQU;6XM<&]S:71I;VXM=F%R:6%B;&4B/@H@("`@("`@(#PA+2T@
M<&]S:71I;VX@;V8@=&AE(&-U<G)E;G0@:6YP=70@8V5L;"!T;R!G970@=&AE
M(&-O<G)E8W0@8V]L=6T@<W1Y;&4@*&AI9&1E;B!A<F4@86QS;R!C;W5N=&5D
M*2TM/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2;W=,
M96YG=&@B+SX*"B`@("`@("`@/"$M+2!C;VQU;6X@<&]S:71I;VX@;F5E9&5D
M(&9O<B!S='EL97,L(&5S<"X@9F]R(&-O;'5M;BUH:61D96XM9FQA9R`M+3X*
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!R96-E9&EN9RUC;VQU;6YS
M(CX*("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](G!R96-E9&EN
M9RUS:6)L:6YG.CHJ(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)Q=6%N=&ET>2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S
M=')I;F<M;&5N9W1H*$!T86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E9"D@
M/2`P(CXQ/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^/'AS;#IV86QU92UO9B!S96QE8W0](D!T86)L93IN=6UB
M97(M8V]L=6UN<RUR97!E871E9"(O/CPO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@
M("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H
M)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F-R96%T92UT86)L92UC96QL(CX*("`@("`@("`@("`@
M("`@("`@("`\(2TM('!O<VET:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E
M;&P@=&\@9V5T('1H92!C;W)R96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E
M(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE
M8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@
M("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7!O<VET:6]N
M(B`@("`@("`@("!S96QE8W0](G-U;2AX=#IN;V1E+7-E="@D<')E8V5D:6YG
M+6-O;'5M;G,I+W%U86YT:71Y*2`K(#$B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM
M879A:6QA8FQE*"=X86QA;CIN;V1E<V5T)RDB/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT86)L92UC96QL(CX*
M("`@("`@("`@("`@("`@("`@("`\(2TM('!O<VET:6]N(&]F('1H92!C=7)R
M96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R96-T(&-O;'5M('-T>6QE
M("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R
M:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W
M3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M=6UN+7!O<VET:6]N(B`@("`@("`@("!S96QE8W0](G-U;2AX86QA;CIN;V1E
M<V5T*"1P<F5C961I;F<M8V]L=6UN<RDO<75A;G1I='DI("L@,2(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](DYO9&53
M971&=6YC=&EO;DYO=$%V86EL86)L92(O/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT86)L92UC96QL(B\^"B`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TB8W)E871E+71A8FQE+6-E;&PB/@H@("`@("`@(#PA+2T@<&]S:71I
M;VX@;V8@=&AE(&-U<G)E;G0@:6YP=70@8V5L;"!T;R!G970@=&AE(&-O<G)E
M8W0@8V]L=6T@<W1Y;&4@*&AI9&1E;B!A<F4@86QS;R!C;W5N=&5D*2TM/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S
M(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2;W=,96YG=&@B
M+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(O
M/@H*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^3D57(%9!3%5%.B!C;VQU;6XM<&]S:71I
M;VXZ("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B(O
M/BT\+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L.FEF/@H*"B`@("`@("`@
M/"$M+2!A(&AI9&1E;B!C;VQU;6X@=VEL;"!G:79E(&]U="!N;W1H:6YG("TM
M/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*"1A;&Q#;VQU;6Y3='EL945N
M=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N*"D@/2`D8V]L=6UN
M+7!O<VET:6]N72]`8V]L=6UN+6AI9&1E;BUF;&%G*2(^"B`@("`@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"$M+2!W:&5N('1H92!C
M;VQU;6YS(&%R92!N;W0@<F5P96%T960@=&AE(&YE>'0@8V]L=6UN+7!O<VET
M:6]N<R!R86ES97,@=7`@=&\@,2P@;W1H97)W:7-E('5P('1O('1H92!A;6]U
M;G0@;V8@<F5P96%T960@8V]L=6UN<R`M+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960B
M/@H@("`@("`@("`@("`@("`@("`@(#PA+2T@=W)I=&5S(&UU;'1I<&QE(&5N
M=')I97,@;V8@82!C96QL("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)R97!E870M=W)I=&4M8V5L;"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB)&%L;$-O
M;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7!O<VET:6]N(B`@("`@("`@
M("!S96QE8W0](B1C;VQU;6XM<&]S:71I;VXB+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@
M("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB97(M
M8V]L=6UN<RUR97!E871E9"(@('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`\(2TM('=R:71E<R!A;B!E;G1R>2!O9B!A(&-E;&P@+2T^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6-E
M;&PB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE
M8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO
M;B(@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2
M;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#II9CX*"B`@("`\+WAS;#IT96UP
M;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB<F5P96%T+7=R:71E
M+6-E;&PB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQU
M;6XM<&]S:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FUA>%)O
M=TQE;F=T:"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;G5M8F5R+6-O
M;'5M;G,M<F5P96%T960B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#PA+2T@,D1/.B!4:&ES(&ES('1H92!C=7)R96YT('=O<FMA<F]U
M;F0@86=A:6YS="!T:&4@8F%C:V=R;W5N9"!S:6UU;&%T:6]N(&)Y(&%N("=E
M;F1L97-S)R!R97!E871I;F<@8V5L;"`M+3X*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](B1N=6UB97(M8V]L=6UN<RUR97!E871E9"`^(#$@86YD("1M
M87A2;W=,96YG=&@@/B`D8V]L=6UN+7!O<VET:6]N(CX*"B`@("`@("`@("`@
M("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IM97-S86=E/BLK*RLK*RLK*R!S=&%R=&EN9R!C96QL
M('=R:71I;F<@*RLK*RLK*RLK/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^;G5M8F5R+6-O;'5M;G,M<F5P96%T960Z
M("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YU;6)E<BUC;VQU;6YS+7)E<&5A
M=&5D(B\^+3PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IM97-S86=E/FUA>%)O=TQE;F=T:#H@+3QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D;6%X4F]W3&5N9W1H(B\^+3PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IM97-S86=E/F-O;'5M;BUP;W-I=&EO;CH@+3QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N(B\^+3PO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@
M("`@("`\(2TM('=R:71E<R!A;B!E;G1R>2!O9B!A(&-E;&P@+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8V5L
M;"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](B1A;&Q#
M;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7!O<VET:6]N(B`@("`@("`@("!S
M96QE8W0](B1C;VQU;6XM<&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@
M("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\(2TM(')E
M<&5A="!C86QL:6YG('1H:7,@;65T:&]D('5N=&EL(&%L;"!E;&5M96YT<R!W
M<FET=&5N(&]U="`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^*RLK*RLK*RLK(&-E;&P@<F5P971I=&EO;B`K*RLK*RLK*RL\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<F5P96%T+7=R:71E+6-E
M;&PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL
M0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@("`@("`@
M<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N("L@,2(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@
M("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB97(M8V]L=6UN
M<RUR97!E871E9"(@('-E;&5C=#TB)&YU;6)E<BUC;VQU;6YS+7)E<&5A=&5D
M("T@,2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(#)$3SH@5&AI<R!I<R!T:&4@
M8W5R<F5N="!W;W)K87)O=6YD(&%G86EN<W0@=&AE(&)A8VMG<F]U;F0@<VEM
M=6QA=&EO;B!B>2!A;B`G96YD;&5S<R<@<F5P96%T:6YG(&-E;&P@+2T^"B`@
M("`@("`@("`@("`@("`\(2TM("`@("`@5VAE;B!T:&4@;6%X4F]W3&5N9W1H
M(&ES(')E86-H960@82!L87-T(&5N=')Y(&]F(&$@8V5L;"!I<R!W<FET=&5N
M("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(G=R:71E+6-E;&PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@
M("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I
M=&EO;B(@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O
M=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(G=R:71E+6-E;&PB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL
M0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQU;6XM<&]S:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(FUA>%)O=TQE;F=T:"(O/@H*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$
M96)U9TUO9&4B/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^5W)I=&5497-T
M("T^($EF(&YO=&AI;F<@8F5T=V5E;B`G+2<@=W)I=&4@8V5L;"`M/'AS;#IV
M86QU92UO9B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN
M+7-T>6QE+65N=')Y6W!O<VET:6]N*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`
M8V]L=6UN+6AI9&1E;BUF;&%G(B\^+3PO>'-L.FUE<W-A9V4^"B`@("`@("`@
M/"]X<VPZ:68^"@H@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1A;&Q#;VQU
M;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N*"D@
M/2`D8V]L=6UN+7!O<VET:6]N72]`8V]L=6UN+6AI9&1E;BUF;&%G(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^5$%"3$4@0T],54U.(&ES
M(&AI9&1E;B$\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M:68^"B`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/"$M+2!A(&AI9&1E;B!C;VQU;6X@=VEL;"!G:79E
M(&]U="!N;W1H:6YG("TM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C;VQU;6XM<W1Y;&4M96YT<GE;<&]S
M:71I;VXH*2`]("1C;VQU;6XM<&]S:71I;VY=+T!C;VQU;6XM:&ED9&5N+69L
M86<B/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO
M9&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y404),12!#
M3TQ534X@:7,@:&ED9&5N(3PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@
M("`\+WAS;#II9CX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@
M("`@(#PA+2T@3D]4(&$@:&ED9&5N(&-O;'5M;B`M+3X*("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"@H@("`@("`@("`@("`@("`@/"$M+2!A('1A8FQE
M(&ES(&$@=&%B;&4@:&5A9&5R+"!W:&5N(&ET(&AA<R!A(")T86)L93IT86)L
M92UH96%D97(M<F]W<R(@86YC97-T;W(@+2T^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](G1A8FQE1&%T851Y<&4B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.G1A8FQE.G1A8FQE+6AE861E
M<BUR;W=S(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YT:#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G1D/"]X
M<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!#4U,@
M*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!62`K*RLK
M*RTM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T
M<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)[)'1A8FQE1&%T851Y<&5](CX*"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E
M8G5G36]D92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IM97-S86=E/@HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B<\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1A8FQE1&%T851Y<&4B
M+SXG(&5L96UE;G0@:&%S(&)E96X@861D960A/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB0'1A8FQE.FYU;6)E
M<BUC;VQU;6YS+7-P86YN960B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;'-P86XB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN960B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB0'1A8FQE.FYU;6)E
M<BUR;W=S+7-P86YN960B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](G)O=W-P86XB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB0'1A8FQE.FYU;6)E<BUR;W=S+7-P86YN960B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"@H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@*BHJ('1H92!C96QL+7-T>6QE("HJ*B`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@5&AE(&-E;&P@
M<W1Y;&4@:&%S(&YO(&-O;F-L=7-I;VX@=VET:"!T:&4@8V]L=6UN('-T>6QE
M+"!S;R!W92!S=VET8V@@=&AE(&]R9&5R+W!R:6]R:71I97,@9'5E('1O(&)R
M;W=S97(@:7-S=65S"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%1H92!C96QL+7-T>6QE(&1E<&5N9',@;VX@='=O(&%T=')I8G5T97,Z"@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$I('1A8FQE.G-T>6QE
M+6YA;64@+2!T:&4@<W1Y;&4@<')O<&5R=&EE<R!O9B!C96QL+B!7:&5N('1H
M97D@97AI<W0L(&$@9&5F875L="!A;&EG;F5M96YT("AC<"X@8F5L;W<I('=I
M;&P@8F4@861D960@9F]R('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E(&]F(&YO(&%L:6=N
M;65N="!I;B!T:&4@<W1Y;&4@97AI<W0N"@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#(I('1A8FQE.G9A;'5E+71Y<&4@+2!T:&4@=F%L=64@
M='EP92!O9B!T:&4@=&%B;&4M8V5L;"!G:79I;F<@=&AE(&1E9F%U;'0@86QI
M9VYM96YT<RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@0GD@9&5F875L="!A('-T<FEN9R!V86QU92!I
M<R!L969T(&%L:6=N960L(&%L;"!O=&AE<B!A<F4@86QI9VYE9#IR:6=H="X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T86)L93IS='EL92UN
M86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@0T5,3"U35%E,13H@86QI9VYM
M96YT(&)Y('1A8FQE.G9A;'5E+71Y<&4@*'=I=&AO=70@97AI<W1I;F<@=&%B
M;&4Z<W1Y;&4M;F%M92DM+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8V5L;%-T>6QE(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H
M*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB<W1R:6YG+6QE;F=T:"@D8V5L;%-T>6QE*2`^(#`@86YD
M(&YO="AC;VYT86EN<R@D8V5L;%-T>6QE+"`G=&5X="UA;&EG;B<I*2(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PA+2T@0T5,3"U35%E,13H@86QI9VYM96YT(&)Y('1A8FQE.G9A;'5E+71Y
M<&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@;F\@86QI9VYM96YT(&EN('1H92!C96QL('-T>6QE
M+"!T:&4@86QI9VYM96YT(&)A<V5D(&]N('1H92!T86)L93IV86QU92UT>7!E
M('=I;&P@8F4@861D960@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](D!T86)L93IV86QU92UT>7!E(&%N9"!N;W0H0'1A8FQE
M.G9A;'5E+71Y<&4@/2`G<W1R:6YG)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;VYC870H)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL
M<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2]`=&%B;&4Z<W1Y;&4M;F%M95TL
M("=T97AT+6%L:6=N.G)I9VAT.R`G*2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)C;VYC870H)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL<W1Y
M;&5S+RI;;F%M92@I/6-U<G)E;G0H*2]`=&%B;&4Z<W1Y;&4M;F%M95TL("=T
M97AT+6%L:6=N.FQE9G0[("<I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM($-%3$PM4U193$4Z(&%L:6=N;65N="!B>2!T86)L93IV86QU92UT
M>7!E("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&YO($-34R!S='EL92!P<F]P97)T:65S(&5X:7-T
M+"!O;FQY(&%L:6=N;65N="!F<F]M('1H92!T86)L93IV86QU92UT>7!E('=I
M;&P@8F4@=7-E9"`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'1A8FQE.G9A;'5E+71Y<&4@86YD(&YO="A`=&%B;&4Z=F%L
M=64M='EP92`]("=S=')I;F<G*2(^=&5X="UA;&EG;CIR:6=H=#L@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/G1E>'0M86QI9VXZ;&5F=#L@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&-O;'5M;BUS='EL92`H9&ES:G5N8W0@;V8@8V5L
M;"!S='EL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\(2TM(#)$3SH@;VYL>2!A8G-O;'5T('-T>6QE<R!A<F4@<W5P
M<&]R=&5D+"!R96QA=&EV92!S='EL97,@*&DN92X@)W-T>6QE.G)E;"UC;VQU
M;6XM=VED=&@G(&4N9RX@=VET:"!V86QU92`B.#DS,RHB(&%R92!I9VYO<F5D
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@27-S=64Z(&)R;W=S97)S("AN;W0@<W5R92!I9B!#4U,I(&1O97,@;F]T
M('-U<'!O<G0@=&AE("<J)R!R96QA=&EO;G-H:7`L(&]N;'D@=&AE("<E)RP@
M=VAE<F4@=&AE('-U;2!I<R!A;'=A>7,@)S$P,"<A"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!&;W(@=&AI<RP@:70@
M:7,@96%S:65R('1O('=O<FL@;VX@=VET:"!T:&4@86)S;VQU=&4@=F%L=65S
M+"!I;G-T96%D(&]F(&-A;&-U;&%T:6YG('1H92!V86QU97,@9F]R(#$P,"4@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O
M8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N*"D])&-O;'5M;BUP;W-I=&EO
M;ETB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM($-%3$PM4U193$4Z('1A8FQE.G-T>6QE+6YA;64@+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](F-L87-S(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)T<F%N<VQA=&4H
M0'1A8FQE.G-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)S='EL92(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM($-%3$PM4U193$4Z(&%L:6=N;65N="!B
M>2!T86)L93IV86QU92UT>7!E("AW:71H;W5T(&5X:7-T:6YG('1A8FQE.G-T
M>6QE+6YA;64I+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\(2TM(&YO('1A8FQE.G-T>6QE+6YA;64@97AI<W0L(&]N;'D@
M86QI9VYM96YT(&9R;VT@=&AE('1A8FQE.G9A;'5E+71Y<&4@=VEL;"!B92!U
M<V5D("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T86)L93IV86QU92UT
M>7!E(&%N9"!N;W0H0'1A8FQE.G9A;'5E+71Y<&4@/2`G<W1R:6YG)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T97AT+6%L:6=N.G)I9VAT.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1E>'0M86QI9VXZ;&5F=#L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!)
M;B!C87-E(&]F(&YO(&-E;&P@8V]N=&5N="!A(&YO;BUB<F5A:V%B;&4@<W!A
M8V4@=VEL;"!B92!I;G-E<G1E9`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@;6%K92!T:&4@8G)O=W-E<B!S:&]W('1H92!T86)L
M92UC96QL(&=R:60@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](FYO="AC:&EL9#HZ=&5X="@I*2!A;F0@;F]T
M*&-H:6QD.CHJ*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#X@)B,Q-C`[/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM("HJ*B!T:&4@8V]L=6UN
M+7-T>6QE("HJ*B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2`@=&AE(&-O;'5M;B!S='EL92!H87,@;F\@8V]N8VQU<VEO
M;B!W:71H('1H92!C96QL('-T>6QE+"!S;R!W92!S=VET8V@@=&AE(&]R9&5R
M+W!R:6]R:71I97,@9'5E('1O(&)R;W=S97(@:7-S=65S+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)S<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-L87-S(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C;VQU;6XM<W1Y;&4M
M96YT<GE;<&]S:71I;VXH*2`]("1C;VQU;6XM<&]S:71I;VY=+T!S='EL92UN
M86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@("`@
M("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E
M(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)[)'1A8FQE1&%T851Y<&5](CX*"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN=6UB
M97(M8V]L=6UN<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VQS<&%N(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN=6UB
M97(M<F]W<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)R;W=S<&%N(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](D!T86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8V5L;"US='EL
M92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL<W1Y;&5S
M+RI;;F%M92@I/6-U<G)E;G0H*2]`=&%B;&4Z<W1Y;&4M;F%M95TB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-O;'5M;BUS='EL
M92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C;VQU;6XM
M<W1Y;&4M96YT<GE;<&]S:71I;VXH*3TD8V]L=6UN+7!O<VET:6]N72(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@5$%"3$4Z5D%,
M544M5%E012`M('1H92!V86QU92!O9B!A('1A8FQE+6-E;&P@=VEL;"!B92!A
M;&EG;F5D(&QE9G0@8GD@9&5F875L="!O;FQY(&5X;&EC:70@;F]N+7-T<FEN
M9R!I<R!A;&EG;F5D.G)I9VAT+2T^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z=F%L=64M='EP
M92!A;F0@;F]T*$!T86)L93IV86QU92UT>7!E(#T@)W-T<FEN9R<I(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YT97AT+6%L:6=N.G)I9VAT.SPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/G1E>'0M86QI9VXZ;&5F=#L\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@)B,Q-C`@:7,@82!N;VXM8G)E
M86MA8FQE('-P86-E+"!N96-E<W-A<GD@=&\@;6%K92!T;R!T:&4@8G)O=W-E
M<B!S:&]W('1H92!T86)L92UC96QL(&=R:60@+2T^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](FYO="AC:&EL9#HZ=&5X="@I
M*2!A;F0@;F]T*&-H:6QD.CHJ*2(^("8C,38P.SPO>'-L.FEF/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-($E.3$E.140@
M5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)[)'1A8FQE1&%T851Y<&5](CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB0'1A
M8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN960B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;'-P86XB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN960B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T
M86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)R;W=S<&%N(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](D!T86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@/"$M+2LK*RLK(%=-3"!705D@("LK
M*RLK+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O
M=71P=714>7!E(#T@)U=-3"<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)N;W0H)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C;VQU;6XM
M<W1Y;&4M96YT<GE;;&%S="@I(#T@)&-O;'5M;BUP;W-I=&EO;ETI(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L
M871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/BP@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L
M871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB8G(B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP
M;&%T93X*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O;6%I
M;E]H=&UL+GAS;```````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-38U,S,`,3`U,34T,S$P
M-C``,#(S-3$S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E
M(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I
M=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*
M("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC
M96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/
M8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI
M8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L
M(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES
M(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O
M<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S
M<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S
M('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*
M("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H
M870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)2
M04Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@
M($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@
M4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI
M8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA
M=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF
M(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO
M;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*
M("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N
M9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4
M:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3
M=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I
M;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@
M9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E
M+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@
M:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3
M;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED
M960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/
M1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$
M24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!4
M2$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"
M3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D92
M24Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P
M<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A
M=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA
M;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R
M;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-
M:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@
M("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N
M,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@
M("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A
M8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS
M.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@
M("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY
M.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@
M("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@
M("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T
M:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C
M<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@
M("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@
M("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS
M.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@
M("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@
M('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN
M8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O
M=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z=7)L96YC;V1E<CTB:'1T<#HO+W=W=RYJ8VQA
M<FLN8V]M+WAT+VIA=F$O:F%V82YN970N55),16YC;V1E<B(*("`@("`@("`@
M("`@("`@('AM;&YS.GAA;&%N/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>&%L
M86XB"B`@("`@("`@("`@("`@("!X;6QN<SIJ879A/2)H='1P.B\O>&UL+F%P
M86-H92YO<F<O>'-L="]J879A(@H@("`@("`@("`@("`@("`@97AC;'5D92UR
M97-U;'0M<')E9FEX97,](FIA=F$B/@H*("`@(#QX<VPZ;W5T<'5T(&UE=&AO
M9"`@("`@(#TB>&UL(@H@("`@("`@("`@("`@("`@96YC;V1I;F<@("`@/2)5
M5$8M."(*("`@("`@("`@("`@("`@(&EN9&5N="`@("`@(#TB>65S(B\^"@H*
M"B`@("`\(2TM*RLK*RL@24Y#3%5$140@6%-,($U/1%5,15,@*RLK*RLM+3X*
M("`@(#PA+2T@:6YH97)I=&5D('-T>6QE('!R;W!E<G1I97,@=VEL;"!B92!C
M;VQL96-T960@86YD('=R:71T96X@:6X@82!#4U,@:&5A9&5R("A#4U,I("TM
M/@H@("`@/'AS;#II;F-L=61E(&AR968](G-T>6QE7VAE861E<BYX<VPB+SX*
M"B`@("`\(2TM(&EN:&5R:71E9"!S='EL92!P<F]P97)T:65S('=I;&P@8F4@
M8V]L;&5C=&5D(&%N9"!W<FET=&5N(&%S(&AT;6P@<')O<&5R=&EE<R!I;B!A
M('1E;7!O<F%R>2!V87)I86)L92`H2%1-3#0L(%!!3$TI("TM/@H@("`@/'AS
M;#II;F-L=61E(&AR968](G-T>6QE7VEN;&EN960N>'-L(B\^"@H@("`@/"$M
M+2!O=7(@>&UL('-T>6QE('!R;W!E<G1I97,@=VEL;"!B92!M87!P960@=&\@
M0U-3(&%N9"!(5$U,-"YX('!R;W!E<G1I97,@+2T^"B`@("`\>'-L.FEN8VQU
M9&4@:')E9CTB<W1Y;&5?;6%P<&EN9RYX<VPB+SX*"B`@("`\(2TM(&-O;6UO
M;B!E;&5M96YT(&AA;F1L:6YG("TM/@H@("`@/'AS;#II;F-L=61E(&AR968]
M(F-O;6UO;BYX<VPB+SX*"B`@("`\(2TM('1A8FQE(&AA;F1L:6YG("TM/@H@
M("`@/'AS;#II;F-L=61E(&AR968](G1A8FQE+GAS;"(O/@H*("`@(#PA+2T@
M<&%L;2!H86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)P86QM
M+GAS;"(O/@H*("`@(#PA+2T@9VQO8F%L(&1O8W5M96YT(&AA;F1L:6YG("TM
M/@H@("`@/'AS;#II;F-L=61E(&AR968](F=L;V)A;%]D;V-U;65N="YX<VPB
M+SX*"@H*"@H*"B`@("`\(2TM*RLK*RL@4$%204U%5$52($923TT@5$A%($%0
M4$Q)0T%424].($%.1"!'3$]"04P@5D%224%"3$53("LK*RLK+2T^"@H@("`@
M/"$M+2!-04Y$051/4EDZ(%523"!O9B!M971A('-T<F5A;2`M+3X*("`@(#QX
M<VPZ<&%R86T@;F%M93TB;65T849I;&554DPB+SX*"B`@("`\(2TM($U!3D1!
M5$]263H@55),(&]F('-T>6QE<R!S=')E86T@+2T^"B`@("`\>'-L.G!A<F%M
M(&YA;64](G-T>6QE<T9I;&554DPB+SX*"B`@("`\(2TM($U!3D1!5$]263H@
M9F]R(')E<V]L=FEN9R!R96QA=&EV92!L:6YK<PH@("`@("`@($9O<B!R97-O
M;'9I;F<@<F5A;'1I=F4@;&EN:W,@=&\@=&AE('!A8VME9"!33R!D;V-U;65N
M="P@:2YE+B!T:&4@<&%T:"]54DP@;V8@=&AE(&IA<F5D('-X=R!F:6QE("AE
M+F<N(&UE=&$N>&UL+"!S='EL97,N>&UL+"!L:6YK<R!T;R!G<F%P:&EC<R!I
M;B!A(')E;&%T:79E(&1I<F5C=&]R>2D@+2T^"B`@("`\>'-L.G!A<F%M(&YA
M;64](F%B<V]L=71E4V]U<F-E1&ER4F5F(B\^"@H@("`@/"$M+2!/4%1)3TY!
M3"`H;6%N9&%T;W)Y+"!W:&5N('=H96X@<V]U<F-E(&ES(&-O;7!R97-S960I
M.B!.96-E<W-A<GD@9F]R('1H92!I;B!T:&4@<&%C:V5D($]/(&1O8W5M96YT
M(&5M8F5D9&5D(&9I;&5S("AM;W-T;'D@9W)A<&AI8W,@9G)O;2!T:&4@8V]M
M<')E<W-E9"`O4&EC='5R92!D:7(I+@H@("`@("`@("!7:&5N('1H92!/<&5N
M3V9F:6-E("A/3RD@9FEL92!H87,@8F5E;B!U;G!A8VME9"!T:&4@86)S;VQU
M=&53;W5R941I<E)E9B!C86X@8F4@=&%K96XL"B`@("`@("`@($]T:&5R=VES
M92P@82!*05(@55),(&-O=6QD(&)E(&-H;V]S96X@;W(@=VAE;B!W;W)K:6YG
M('=I=&@@3W!E;D]F9FEC92!A('-O(&-A;&QE9"!086-K86=E+5523"!E;F-O
M9&5D(&]V97(@2%144"!C86X@8F4@=7-E9"!T;PH@("`@("`@("!A8V-E<W,@
M=&AE(&IA<F5D(&-O;G1E;G1S(&]F('1H92!T:&4@:F%R960@9&]C=6UE;G0N
M("X@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](FIA<F5D4F]O=%523"(@<V5L
M96-T/2(D86)S;VQU=&53;W5R8V5$:7)2968B+SX*"B`@("`\(2TM($]05$E/
M3D%,("AM86YD871O<GDL('=H96X@=7-E9"!I;B!S97-S:6]N(&)A<V5D(&5N
M=FER;VYM96YT*0H@("`@("`@("!5<V5F=6P@9F]R(%=E8D%P<&QI8V%T:6]N
M<SH@:68@82!(5%10('-E<W-I;VX@:7,@;F]T(&-O;VMI92!B87-E9"P@55),
M(')E=W)I=&EN9R!I<R!B965I;F<@=7-E9"`H=&AE('-E<W-I;VX@:7,@87!P
M96YD960@=&\@=&AE(%523"DN"B`@("`@("`@(%1H:7,@55),('-E<W-I;VX@
M:7,@=7-E9"!W:&5N(&-R96%T:6YG(&QI;FMS('1O(&=R87!H:6-S(&)Y(%A3
M3%0N($]T:&5R=VES92!T:&4@=7-E<B!H879T('1O(&QO9R!A9V%I;B!I;B!F
M;W(@979E<GD@9W)A<&AI8R!H92!W;W5L9"!L:6ME('1O('-E92X@+2T^"B`@
M("`\>'-L.G!A<F%M(&YA;64](F]P=&EO;F%L55),4W5F9FEX(B\^"@H@("`@
M/"$M+2!/4%1)3TY!3#H@1%!)("AD;W1S('!E<B!I;F-H*2!T:&4@<W1A;F1A
M<F0@<V]L=71I;VX@;V8@9VEV96X@<&EC='5R97,@*&YE8V5S<V%R>2!F;W(@
M=&AE(&-O;G9E<G-I;VX@;V8@)V-M)R!I;G1O("=P:7AE;"<I+2T^"B`@("`\
M(2TM($%L=&AO=6=H(&UA;GD@<&EC='5R97,@:&%V92!T:&4@.38@9'!I(')E
M<V]L=71I;VXL(&$@:&EG:&5R(')E<V]L=&EO;B!G:79E(&)E='1E<B!R97-U
M;'1S(&9O<B!C;VUM;VX@8G)O=W-E<G,@+2T^"B`@("`\>'-L.G!A<F%M(&YA
M;64](F1P:2(@<V5L96-T/2(Y-B(O/@H*("`@(#PA+2T@3U!424].04PZ(&EN
M(&-A<V4@;V8@=7-I;F<@82!D:69F97)E;G0@<')O8V5S<V]R('1H86X@82!*
M059!(%A33%0L('EO=2!C86X@=6YA8FQE('1H92!*879A(&9U;F-T:6]N86QI
M='D*("`@("`@("`@*&DN92X@9&5B=6=G:6YG('1I;64@86YD(&5N8V]D:6YG
M(&-H87!T97(@;F%M97,@9F]R('1H92!C;VYT96YT+71A8FQE(&%S(&AR968@
M86YD(&%N8VAO<G,@*2`M+3X*("`@(#QX<VPZ<&%R86T@;F%M93TB9&ES86)L
M94IA=F$B("`@('-E;&5C=#TB9F%L<V4B+SX*("`@(#QX<VPZ<&%R86T@;F%M
M93TB:7-*879A1&ES86)L960B('-E;&5C=#TB8F]O;&5A;B@D9&ES86)L94IA
M=F$I(B\^"@H@("`@/"$M+2!/4%1)3TY!3#H@=7-E<BUA9V5N="!W:6QL(&)E
M(&1I9F9E<FYT:6%T960@8GD@=&AI<R!P87)A;65T97(@9VEV96X@8GD@87!P
M;&EC871I;VX@*&4N9RX@:F%V82!S97)V;&5T*2TM/@H@("`@/'AS;#IP87)A
M;2!N86UE/2)O=71P=714>7!E(B!S96QE8W0](B=#4U-?2$5!1$52)R(O/@H@
M("`@/"$M+2!S970@;V8@<&]S<VEB;&4@9&5V:6-E5'EP<R`H5TU,(&ES('-E
M="!I;B!I=',@;W=N('-T87)T9FEL92!M86EN7W=M;"YX<VPI.@H@("`@/'AS
M;#IP87)A;2!N86UE/2)O=71P=714>7!E(B!S96QE8W0](B=#4U-?2$5!1$52
M)R(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)O=71P=714>7!E(B!S96QE8W0]
M(B=#4U-?24Y,24Y%1"<B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB;W5T<'5T
M5'EP92(@<V5L96-T/2(G4$%,32<B+SX@+2T^"@H@("`@/"$M+2!/4%1)3TY!
M3#H@9F]R(&%C=&EV871I;F<@=&AE(&1E8G5G(&UO9&4@<V5T('1H92!V87)I
M86)L92!H97)E('1O("=T<G5E*"DG(&]R(&=I=F4@86YY('9A;'5E(&9R;VT@
M;W5T<VED92`M+3X*("`@(#QX<VPZ<&%R86T@;F%M93TB9&5B=6<B("`@("`@
M("`@<V5L96-T/2)F86QS92(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)I<T1E
M8G5G36]D92(@("!S96QE8W0](F)O;VQE86XH)&1E8G5G*2(O/@H*/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"B`@("!/4%1)3TY!3#H@3D5%
M1$5$($E.($-/3DY%0U1)3TX@5TE42"!!($=,3T)!3"!$3T-5345.5"`M+3X*
M"B`@("`\(2TM4U5-34%263H*("`@("`@("`@9F]L;&]W:6YG('!A<F%M971E
M<B!T<FEG9V5R<R!A("AQ=6ET92!T:6UE(&-O;G-U;6EN9RD@96YA8FQI;F<@
M;V8@8F]O:VUA<FMS(&EN('1H92!T86)L92UO9BUC;VYT96YT+@H@("`@("`@
M($E.($1%5$%)3#H*("`@("`@("`@0W5R<F5N=&QY('-O;64@;&EN:W,@=7-E
M9"!I;B!T:&4@3V9F:6-E(%A-3"`H92YG+B!I;B!T:&4@8V]N=&5N="!T86)L
M92!A<R`G(S<N4V]M924R,$5X86UP;&4E,C!(96%D;&EN924W3W5T;&EN92<I
M"B`@("`@("`@(&ES(&YO="!A('9A;&ED(%523"`H8VUP+B!B=6<@:60C(#$P
M,C,Q,2DN($YO(&9I;&4@9&5S=&EN871I;VX@:7,@<W!E8VEF:65D(&YO<B!E
M>&ES="!A;GD@86YC:&]R(&5L96UE;G0@9F]R('1H97-E"B`@("`@("`@(&QI
M;FMS(&EN('1H92!/9F9I8V4@6$U,+@H@("`@("`@("!!('=O<FMA<F]U;F0@
M9F]R('1H:7,@=')A;G-F;W)M871I;VX@=&AE<F5F;W)E(&AA9"!T;R!B92!M
M861E+B!4:&ES('1I;64M8V]N<W5M:6YG(&UE8VAA;FES;2!I<R!D:7-A8FQE
M9"!B>2!D969A=6QT(&%N9`H@("`@("`@("!C86X@8F4@86-T:79A=&5D(&)Y
M(&$@<&%R86UE=&5R("AI+F4N("=D:7-A8FQE3&EN:V5D5&%B;&5/9D-O;G1E
M;G0G*2X@02!C<F5A=&EO;B!O9B!A;B!A;F-H;W(@:7,@;6%D92!F;W(@96%C
M:"!H96%D97(@96QE;65N="X*("`@("`@("`@06QL(&AE861E<B!T:71L97,@
M9V]N;F$@8F4@96YC;V1I;F<@=&\@8F4@=7-A8FQE(&EN(&$@<F5L871I=F4@
M55),+B`@("`M+3X*("`@(#QX<VPZ<&%R86T@;F%M93TB9&ES86)L94QI;FME
M9%1A8FQE3V9#;VYT96YT(B!S96QE8W0](F9A;'-E*"DB+SX*"B`@("`\(2TM
M(%1H92!C:&%P=&5R(&YU;6)E<G,@;V8@=&AE(&-U<G)E;G0@9&]C=6UE;G0@
M*&%S(&$@<V5Q=65N8V4@;V8@82!G;&]B86P@9&]C=6UE;G0I(&ES(&1E<&5N
M9&5N="!O9B!T:&4@;G5M8F5R"B`@("`@("`@;V8@8VAA<'1E<B!O9B!T:&4@
M<V%M92!L979E;"!I;B!P<F5C961I;F<@9&]C=6UE;G1S+B`M+3X*("`@(#QX
M<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(@('-E;&5C
M=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C961I;F=#:&%P=&5R
M3&5V96PR(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](G!R
M96-E9&EN9T-H87!T97),979E;#,B("!S96QE8W0](C`B+SX*("`@(#QX<VPZ
M<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L-"(@('-E;&5C=#TB
M,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C961I;F=#:&%P=&5R3&5V
M96PU(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E
M9&EN9T-H87!T97),979E;#8B("!S96QE8W0](C`B+SX*("`@(#QX<VPZ<&%R
M86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L-R(@('-E;&5C=#TB,"(O
M/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C961I;F=#:&%P=&5R3&5V96PX
M(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN
M9T-H87!T97),979E;#DB("!S96QE8W0](C`B+SX*("`@(#QX<VPZ<&%R86T@
M;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L,3`B('-E;&5C=#TB,"(O/@H*
M("`@(#PA+2T@6$U,(&1O8W5M96YT<R!C;VYT86EN:6YG(&$@=&%B;&4@;V8@
M8V]N=&5N=',L"B`@("`@("`@9V]N;F$@;&EN:R!F;W(@=7-A8FEL:71Y(')E
M87-O;B!A8F]V92!E86-H(&-H87!T97(@=&\@=&AE('!R96-E9&EN9R!A;F0@
M9F]L;&]W:6YG(&1O8W5M96YT(&%N9"!T:&4@8V]N=&5N="!T86)L92`M+3X*
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]N=&5N=%1A8FQE55),(B\^"@H@("`@
M/"$M+2!.965D960@9F]R('1H92!B=6<@=V]R:V%R;W5N9"!O9B!M:7-S:6YG
M(&-O;G1E;G0@=&%B;&4@;&EN:W,*("`@("`@("!B>2!T:&ES(&%M8FEG;W5S
M($A434P@<F5F97)E;F-E<R!F<F]M('1H92!C;VYT96YT('1A8FQE(&-A;B!B
M92!E=F]I9&5D+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F=L;V)A;$1O8W5M
M96YT4F5F5&]#=7)R96YT1FEL92(O/@H*("`@(#PA+2T@3F5E9&5D(&9O<B!T
M:&4@8G5G('=O<FMA<F]U;F0@;V8@;6ES<VEN9R!C;VYT96YT('1A8FQE(&QI
M;FMS"B`@("`@("`@8GD@=&AI<R!N;V1E+7-E="!T:&4@<F5L871I;VX@8F5T
M=V5E;B!C;VYT96YT+71A8FQE(&QI;FL@86YD(&-H:6QD<F5N(&1O8W5M96YT
M(&AE861E<B!C86X@8F4@=6YA;6)I9V]U<R!E<W1A8FQI<VAE9"`M+3X*("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]N=&5N=%1A8FQE2&5A9&EN9W,B+SX*"@H\
M(2TM($5.1"!/1B!'3$]"04P@1$]#54U%3E0@4T5#5$E/3@HJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ+2T^"@H*"B`@("`\(2TM('=O<FMS(&9O<B!N
M;W)M86P@<V5P87)A=&5D('II<'!E9"!X;6P@9FEL97,@87,@9F]R(&9L870@
M9FEL=&5R('-I;F=L92!X;6P@9FEL92!F;W)M870@87,@=V5L;"`M+3X*("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB;V9F:6-E.FUE=&$M9FEL92(@("`@("`@
M("`@('-E;&5C=#TB9&]C=6UE;G0H)&UE=&%&:6QE55),*2(O/@H@("`@/'AS
M;#IV87)I86)L92!N86UE/2)O9F9I8V4Z<W1Y;&5S+69I;&4B("`@("`@("`@
M<V5L96-T/2)D;V-U;65N="@D<W1Y;&5S1FEL95523"DB+SX*("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB;V9F:6-E.F9O;G0M9&5C;',B("`@("`@("`@('-E
M;&5C=#TB)&]F9FEC93IS='EL97,M9FEL92\J+V]F9FEC93IF;VYT+61E8VQS
M(B\^"B`@("`\>'-L.G9A<FEA8FQE(&YA;64](F]F9FEC93IS='EL97,B("`@
M("`@("`@("`@("!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+69I;&4O*B]O9F9I
M8V4Z<W1Y;&5S(B\^"B`@("`\(2TM(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S
M(&UA>2!O8V-U<F4@:6X@='=O(&1I9F9E<F5N="!F:6QE<R`H:2YD+B!C;VYT
M96YT+GAM;"!A;F0@<W1Y;&5S+GAM;"DN($9U<G1H97)M;W)E('1H92!T;W`@
M;&5V96P@=&%G(&ES(&1I9F9E<F5N="!I;B!A(&9L870@>&UL(&9I;&4@+2T^
M"B`@("`\>'-L.G9A<FEA8FQE(&YA;64](F]F9FEC93IA=71O;6%T:6,M<W1Y
M;&5S(B`@("!S96QE8W0](B\J+V]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(B\^
M"@H@("`@/"$M+2!S:6UP;&4@9&5C;&%R871I;VX@;V8@5TU,('5S960@=&\@
M879O:60@<&%R<V5R(&5R<F]R<R`M+3X*("`@(#QX<VPZ=F%R:6%B;&4@;F%M
M93TB=V%P+7!A<F%G<F%P:"UE;&5M96YT<RUW:71H;W5T+71A8FQE+7)O=R(O
M/@H@("`@/'AS;#IV87)I86)L92!N86UE/2)W87`M<&%R86=R87!H+65L96UE
M;G1S(B\^"B`@("`\>'-L.G1E;7!L871E(&YA;64](G=M;"UR97!E870M=W)I
M=&4M<F]W(B\^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&)U:6QD('1H92!P<F]P
M<FEA=&4@2%1-3"!F:6QE("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L
M871E(&UA=&-H/2(O(CX*"B`@("`@("`@/"$M+3QX<VPZ;65S<V%G93X*"@H@
M("`@("`@($5N=&5R960@=&AE('-T>6QE4VAE971S+"!T<F%N<V9O<FUA=&EO
M;B!B96=I;G,N+BX@/"]X<VPZ;65S<V%G93XM+3X*"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D:7-$96)U9TUO
M9&4B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F-H96-K+7!A<F%M971E<B(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ:68@
M=&5S=#TB;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)D96)U9RUS='EL92UC;VQL
M96-T:6YG+71I;64B+SX*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@(#PA+2T@=&\@86-C97-S('1H92!V87)I86)L
M92!L:6ME(&$@;F]D92US970@:70@:7,@;F5C97-S87)Y('1O(&-O;G9E<G0@
M:70*("`@("`@("`@("`@("`@("`@("`@9G)O;2!A(')E<W5L="UT<F5E+69R
M86=M96YT("A25$8I('1O(&$@;F]D92!S970@=7-I;F<@=&AE($IA;65S($-L
M87)K(&5X=&5N<VEO;B`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82U25$8B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=C<F5A=&4M86QL
M+6EN;&EN92US='EL97,G+SX*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA
M8FQE/@H*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H
M)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB<W1A<G0B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB>'0Z;F]D92US970H)&-O;&QE8W1E9$=L;V)A
M;$1A=&$M4E1&*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N
M+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T87)T(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](GAA;&%N.FYO9&5S970H
M)&-O;&QE8W1E9$=L;V)A;$1A=&$M4E1&*2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2).;V1E4V5T1G5N8W1I;VY.;W1!=F%I;&%B;&4B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T87)T
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)S=&%R="(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*RLK*RL@0U-3
M("A#05-#041)3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK
M*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E
M(#T@)T-34U](14%$15(G(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N
M="!N86UE/2)H=&UL(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB:&5A9"(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX\>'-L.FUE<W-A9V4^0U-3(&AE;'!E
M<B!V87)I86)L92!W:6QL(&)E(&-R96%T960N+BXN/"]X<VPZ;65S<V%G93X\
M+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64])V-O;6UO;BUH96%D97(M<')O<&5R=&EE<R<O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D
M92(^/'AS;#IM97-S86=E/D-34R!V87)I86)L92!R96%D>2P@:&5A9&5R('=I
M;&P@8F4@8W)E871E9"XN+BX\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM(&-O;G-T<G5C=&EN9R!T:&4@8W-S
M(&AE861E<B!S:6UU;&%T:6YG(&EN:&5R:71A;F-E(&]F('-T>6QE+69A;6EL
M:65S(&)Y('-T>6QE(&]R9&5R("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG8W)E871E+6-S<RUS='EL96AE
M861E<B<O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D-34R!H96%D97(@8W)E871I
M;VX@9FEN:7-H960A/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*"@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8F%C:V=R;W5N9$EM86=E55),(B!S
M96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IP86=E+6UA
M<W1E<B]S='EL93IP<F]P97)T:65S+W-T>6QE.F)A8VMG<F]U;F0M:6UA9V4O
M0'AL:6YK.FAR968B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB8F]D>2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@
M8F%C:V=R;W5N9"!I;6%G92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2(D8F%C:V=R;W5N9$EM86=E55),(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F)A8VMG
M<F]U;F0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM(&9O<B!I;6%G97,@:F%R960@:6X@;W!E;B!O9F9I8V4@9&]C=6UE;G0@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)C;VYT86EN<R@D8F%C:V=R;W5N9$EM86=E55),+"`G(U!I
M8W1U<F5S+R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@8W)E871I;F<@86X@86)S;VQU=&4@:'1T<"!54DP@=&\@
M=&AE(&-O;G1A:6YE9"]P86-K960@:6UA9V4@9FEL92`M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)C;VYC870H)&IA<F5D4F]O=%523"P@)R]0:6-T=7)E<R\G+"!S
M=6)S=')I;F<M869T97(H)&)A8VMG<F]U;F1);6%G95523"P@)R-0:6-T=7)E
M<R\G*2P@)&]P=&EO;F%L55),4W5F9FEX*2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](G-R8R(^/'AS;#IV86QU92UO9B!S96QE8W0](B1B86-K9W)O
M=6YD26UA9V554DPB+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!P<F]C97-S:6YG('1H92!C;VYT96YT(&]F('1H92!X
M;6P@9FEL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L
M>2UT96UP;&%T97,@<V5L96-T/2(O*B]O9F9I8V4Z8F]D>2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP
M;&%T97,^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.
M24Y'("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U
M='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)H=&UL(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB:&5A9"(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=C;VUM;VXM:&5A9&5R+7!R
M;W!E<G1I97,G+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F)A
M8VMG<F]U;F1);6%G95523"(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS
M='EL97,O<W1Y;&4Z<&%G92UM87-T97(O<W1Y;&4Z<')O<&5R=&EE<R]S='EL
M93IB86-K9W)O=6YD+6EM86=E+T!X;&EN:SIH<F5F(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F)O9'DB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\(2TM(&)A8VMG<F]U;F0@:6UA9V4@+2T^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&)A8VMG<F]U;F1)
M;6%G95523"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)B86-K9W)O=6YD(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2!F;W(@:6UA9V5S(&IA<F5D(&EN(&]P
M96X@;V9F:6-E(&1O8W5M96YT("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)&)A8VMG
M<F]U;F1);6%G95523"P@)R-0:6-T=7)E<R\G*2(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-R96%T:6YG(&%N(&%B
M<V]L=71E(&AT='`@55),('1O('1H92!C;VYT86EN960O<&%C:V5D(&EM86=E
M(&9I;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1J87)E9%)O;W15
M4DPL("<O4&EC='5R97,O)RP@<W5B<W1R:6YG+6%F=&5R*"1B86-K9W)O=6YD
M26UA9V554DPL("<C4&EC='5R97,O)RDL("1O<'1I;VYA;%523%-U9F9I>"DB
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S<F,B/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D8F%C:V=R;W5N9$EM86=E55),(B\^/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II
M9CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T
M97,@<V5L96-T/2(O*B]O9F9I8V4Z8F]D>2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@
M("`@("`@("`@("`\(2TM*RLK*RL@4$%,32U624D@*#,N,B!(5$U,(%-50E-%
M5"D@("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T
M<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@("`\(2TM('1H92!P
M<F]X>2!W:6QL(&-O;G9E<G0@=&AE(&AT;6P@9FEL92!L871E<B!T;R!044$@
M+2T^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB:'1M;"(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FAE860B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TG<&%L;2UH96%D97(M<')O<&5R=&EE<R<O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)B;V1Y(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2!P<F]C97-S:6YG('1H92!C;VYT96YT(&]F('1H92!X;6P@9FEL
M92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP
M;&%T97,@<V5L96-T/2(O*B]O9F9I8V4Z8F]D>2(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*
M"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($AE861E<B!F;W(@0U-37TE.
M3$E.140@86YD($-34U](14%$15(@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2=C;VUM;VXM:&5A9&5R+7!R;W!E<G1I
M97,G/@H@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB)&]F
M9FEC93IM971A+69I;&4O*B]O9F9I8V4Z;65T82]D8SIT:71L92(O/@H@("`@
M("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB)&]F9FEC93IM971A
M+69I;&4O*B]O9F9I8V4Z;65T82]D8SID97-C<FEP=&EO;B(O/@H\(2TM,D1/
M(&%D9"!F=7)T:&5R(&AE861E<B!E;&5M96YT<RXN"B`@("`@("`@/'AS;#IA
M<'!L>2UT96UP;&%T97,@<V5L96-T/2(D;V9F:6-E.FUE=&$M9FEL92\J+V]F
M9FEC93IM971A+V1C.G-U8FIE8W0B+SX*("`@("`@("`\>'-L.F%P<&QY+71E
M;7!L871E<R!S96QE8W0](B1O9F9I8V4Z;65T82UF:6QE+RHO;V9F:6-E.FUE
M=&$O;65T83IK97EW;W)D<UMP;W-T:71I;VXH*3TQ72(O/BTM/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB9&,Z=&ET
M;&4B/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T:71L92(^"B`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^"B`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;6%T8V@](F1C.F1E<V-R:7!T:6]N(CX*("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](FYA;64B/@H@("`@("`@("`@("`@("`@/'AS;#IT97AT/F1E<V-R
M:7!T:6]N/"]X<VPZ=&5X=#X*("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E
M/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^"B`@
M("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@
M/"$M+2`J*BH@365A<W5R:6YG('1H92!T:6UE(&9O<B!S='EL92!C<F5A=&EN
M9R`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)D96)U9RUS='EL92UC;VQL96-T:6YG+71I;64B/@H*("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](G-T87)T5&EM92U25$8B/@H@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)F=6YC=&EO;BUA=F%I;&%B;&4H)W-Y<W1E;3IC=7)R96YT+71I;64M;6EL
M;&ES)RDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI<R@I(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IJ879A+FQA;F<N4WES
M=&5M+F-U<G)E;G14:6UE36EL;&ES)RDB/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.FIA=F$N;&%N9RY3>7-T96TN
M8W5R<F5N=%1I;65-:6QL:7,H*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@(#PO>'-L
M.G9A<FEA8FQE/@H*"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82U25$8B/@H@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TG8W)E871E+6%L;"UI;FQI;F4M<W1Y;&5S)R\^"B`@
M("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H*("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L
M92@G>'0Z;F]D92US970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^0W)E871I;F<@=&AE(&EN;&EN92!S='EL97,N+BXN/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB<W1A<G14
M:6UE(B`@("`@("`@("`@("`@<V5L96-T/2)N=6UB97(H>'0Z;F]D92US970H
M)'-T87)T5&EM92U25$8I*2(O/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("!S96QE8W0](GAT
M.FYO9&4M<V5T*"1C;VQL96-T961';&]B86Q$871A+5)41BDB+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96YD5&EM92(@("`@("`@
M("`@("`@("`@<V5L96-T/2)S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI<R@I
M(B\^"@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/E1I;64@9F]R(&EN
M<W1A;G1I871I;F<@<W1Y;&4@=F%R:6%B;&4Z(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(H)&5N9%1I;64@+2`D<W1A<G14:6UE*2(O/B!M<SPO>'-L.FUE<W-A
M9V4^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M<W1A<G0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X86QA;CIN;V1E<V5T
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/D-R96%T:6YG('1H
M92!I;FQI;F4@<W1Y;&5S+BXN+CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T87)T5&EM92(@("`@("`@("`@
M("`@('-E;&5C=#TB;G5M8F5R*'AA;&%N.FYO9&5S970H)'-T87)T5&EM92U2
M5$8I*2(O/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)E
M;F14:6UE(B`@("`@("`@("`@("`@("!S96QE8W0](FIA=F$Z:F%V82YL86YG
M+E-Y<W1E;2YC=7)R96YT5&EM94UI;&QI<R@I(B\^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@
M('-E;&5C=#TB>&%L86XZ;F]D97-E="@D8V]L;&5C=&5D1VQO8F%L1&%T82U2
M5$8I(B\^"@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/E1I;64@9F]R
M(&EN<W1A;G1I871I;F<@<W1Y;&4@=F%R:6%B;&4Z(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(H)&5N9%1I;64@+2`D<W1A<G14:6UE*2(O/B!M<SPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB<W1A<G0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\(2TM($1%0E5'
M('!U<G!O<V4@;VYL>3H@8VAE8VMI;F<@=&AE('!A<F%M971E<G,@;V8@=&AI
M<R!T96UP;&%T92TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C:&5C:RUP
M87)A;65T97(B/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@9'!I
M.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&1P:2(O/CPO>'-L.FUE<W-A9V4^
M"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!M971A1FEL95523#H@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1M971A1FEL95523"(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!S='EL97-&
M:6QE55),.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'-T>6QE<T9I;&554DPB
M+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T
M97(@86)S;VQU=&53;W5R8V5$:7)2968Z(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D86)S;VQU=&53;W5R8V5$:7)2968B+SX\+WAS;#IM97-S86=E/@H@("`@
M("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE
M=F5L,2`Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E
M<DQE=F5L,2(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E
M/E!A<F%M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PR(#H@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PR(B\^/"]X<VPZ
M;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E
M9&EN9T-H87!T97),979E;#,@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R
M96-E9&EN9T-H87!T97),979E;#,B+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M(#QX<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L
M-"`Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE
M=F5L-"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A
M<F%M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PU(#H@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PU(B\^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN
M9T-H87!T97),979E;#8@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E
M9&EN9T-H87!T97),979E;#8B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX
M<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L-R`Z
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M-R(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M
M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PX(#H@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PX(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H
M87!T97),979E;#D@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN
M9T-H87!T97),979E;#DB+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ
M;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L,3`Z(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L,3`B
M+SX\+WAS;#IM97-S86=E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H\+WAS;#IS
M='EL97-H965T/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O
M;V\O<&%L;2YX<VP`````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#$U,S<`,3`U
M,34T,S$P-C``,#(R-#<R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I
M;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F
M"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@
M("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R
M8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!)
M;F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P
M(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO
M(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R
M87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET
M(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R
M+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T
M:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.
M62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y
M(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO
M=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A
M<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U
M;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O
M<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R
M>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O
M('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E
M(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E
M('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,
M:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N
M<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN
M"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@
M<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)2
M04Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@
M24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@
M5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#
M2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/
M3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C
M:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@
M;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@
M26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V
M960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I
M;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W
M=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I
M8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT
M97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V
M9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R
M,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA
M=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM
M;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T
M(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@
M("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@
M('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*
M("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@
M("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H
M='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A
M8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT
M='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@
M("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H@("`@/'AS;#IO
M=71P=70@8V1A=&$M<V5C=&EO;BUE;&5M96YT<STB;65T82(O/@H*"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM
M("HJ*B!S<&5C:69I8R!P86QM(&AE861E<B`J*BH@+2T^"B`@("`\(2TM("HJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2=P86QM+6AE861E<BUP<F]P97)T:65S)SX*("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](FYA;64B/E!A;&U#;VUP=71I;F=0;&%T9F]R;3PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M8V]N=&5N="(^=')U93PO>'-L.F%T=')I8G5T93X*("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)M971A(CX*("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M92(^2&%N9&AE;&1&
M<FEE;F1L>3PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB8V]N=&5N="(^=')U93PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)M971A(CX*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M
M92(^2&ES=&]R>4QI<W1497AT/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT(CY$871E:6UA;F%G97(F
M(S$P.SH@)F%M<#MD871E("9A;7`[=&EM93PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)M971A(CX*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M
M92(^9&5S8W)I<'1I;VX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](F-O;G1E;G0B/E-T87)0;W)T86P\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FYA;64B/FME>7=O<F1S/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT(CYS=&%R<&]R
M=&%L+"!S=&%R;V9F:6-E+"!S;V9T=V%R93PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)M971A(CX*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:'1T
M<"UE<75I=B(^0V]N=&5N="U4>7!E/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT(CYT97AT+VAT;6P[
M(&-H87)S970]:7-O+3@X-3DM,3PO>'-L.F%T=')I8G5T93X*("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M
M+2`J*BH@8W)E871I;F<@=&%B;&4@871T<FEB=71E<R`J*BH@+2T^"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@
M("`\(2TM('1A8FQE(&1A=&$@*'1D*2!A;F0@=&%B;&4@:&5A9&5R("AT:"D@
M871T<FEB=71E<R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E
M+6%T=')I8G5T92U!3$E'3B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S
M='EL95!R;W!E<G1I97,B+SX*"B`@("`@("`@/'AS;#II9B!T97-T/2)C;VYT
M86EN<R@D<W1Y;&50<F]P97)T:65S+"`G86QI9VXG*2(^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](F%L:6=N(CX*("`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N.FQE9G0G
M*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YL969T/"]X
M<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y
M;&50<F]P97)T:65S+"`G86QI9VXZ<FEG:'0G*2(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YR:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F-E;G1E<CPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.FEF
M/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@8W)E871I
M;F<@3&ES="!A='1R:6)U=&5S("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*/"$M+0H@("`@/'AS;#IT
M96UP;&%T92!N86UE/2)C<F5A=&4M;&ES="UA='1R:6)U=&5S(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H*"B$A(2$A
M(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A"C(@8F4@:6UP;&5M96YT960*(2$A
M(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$*"@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"BTM/@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@8W)E871I
M;F<@;F5S=&5D(&9O<FUA="!T86=S("A004Q-("8@5TU,*2`J*BH@+2T^"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\(2TM($ET86QI8R`M+3X*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TB8W)E871E+6YE<W1E9"UF;W)M870M=&%G<R(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=I=&%L:6,G*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB:2(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F)O;&0B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8F]L9"(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!";VQD("TM/@H@("`@
M/'AS;#IT96UP;&%T92!N86UE/2)B;VQD(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S
M='EL95!R;W!E<G1I97,L("=B;VQD)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](F(B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)U;F1E<FQI;F4B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T
M:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=6YD97)L:6YE(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P
M97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"B`@("`\(2TM(%5N9&5R;&EN92`Z(&QA<W0@9F]R
M;6%T(&%T=')I8G5T92P@=VAI8V@@:7,@86QS;R!U<V5D(&9R;VT@5TU,("T@
M5TU,(&5N9',@:&5R92$@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](G5N
M9&5R;&EN92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R
M;W!E<G1I97,B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)W5N
M9&5R;&EN92<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](G4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G-T<FEK971H<F]U9V@B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S
M=')I:V5T:')O=6=H(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB
M)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS
M*"1S='EL95!R;W!E<G1I97,L("=U;F1E<FQI;F4G*2(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)U(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP
M;&%T97,^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#PA+2T@<W1R:6ME=&AR;W5G:"`M+3X*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB<W1R:6ME=&AR;W5G:"(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"B`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT
M86EN<R@D<W1Y;&50<F]P97)T:65S+"`G<W1R:6ME)RDB/@H@("`@("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-T<FEK92(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%L:6=N(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%L:6=N(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y
M;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM($%L:6=N;65N="`M+3X*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB86QI9VXB/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F1I=B(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB86QI9VXB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R
M=&EE<RP@)V%L:6=N.FQE9G0G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/FQE9G0\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50
M<F]P97)T:65S+"`G86QI9VXZ<FEG:'0G*2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/G)I9VAT/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8V5N=&5R/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F9O;G1?8V]M
M8FEN960B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E
M<G1I97,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB9F]N=%]C;VUB:6YE9"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y
M;&50<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@
M/"$M+2!";W1H('-I>F4@86YD($-O;&]R(&9O<B!F;VYT("TM/@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)F;VYT7V-O;6)I;F5D(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H*("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A
M:6YS*"1S='EL95!R;W!E<G1I97,L("=C;VQO<B<I(&%N9"!C;VYT86EN<R@D
M<W1Y;&50<F]P97)T:65S+"`G<VEZ92<I(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)F;VYT(CX*"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB8V]L;W(B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE
M<RP@)V-O;&]R.B,P,#`P,#`G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/B,P,#`P,#`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC1D9&1D9&/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-I>F4B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R
M:6YG+6%F=&5R*'-U8G-T<FEN9RUB969O<F4H)'-T>6QE4')O<&5R=&EE<R`L
M)SIS:7IE)RDL("=S:7IE.B<I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@("`@("`\(2TM(&=E="!T
M:&4@96UB961D960@8V]N=&5N="`M+3X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)F;VYT7W-I;7!L92(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@
M<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP
M;&%T93X*"@H@("`@/"$M+2!S:7IE(&]R($-O;&]R(&9O<B!F;VYT("TM/@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)F;VYT7W-I;7!L92(^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"B`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C
M;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G8V]L;W(G*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB9F]N="(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]L;W(B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE
M4')O<&5R=&EE<RP@)V-O;&]R.B,P,#`P,#`G*2(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/B,P,#`P,#`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC1D9&1D9&
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@
M("`@("`@("`@("`@("`@("`@(#PA+2T@9V5T('1H92!E;6)E9&1E9"!C;VYT
M96YT("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY
M+71E;7!L871E<SX*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)W-I>F4G*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB9F]N="(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<VEZ92(^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S
M=6)S=')I;F<M869T97(H<W5B<W1R:6YG+6)E9F]R92@D<W1Y;&50<F]P97)T
M:65S("PG.G-I>F4G*2P@)W-I>F4Z)RDB+SX*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@
M9V5T('1H92!E;6)E9&1E9"!C;VYT96YT("TM/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PA
M+2T@9V5T('1H92!E;6)E9&1E9"!C;VYT96YT("TM/@H@("`@("`@("`@("`@
M("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"CPO>'-L.G-T>6QE<VAE970^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O;V]O+W-T>6QE7VUA<'!I;F<N>'-L````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,3$P-#,R`#$P-3$U-#,Q,#8P`#`R-#0P,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\(2TM"@H@("!4:&4@0V]N=&5N=',@
M;V8@=&AI<R!F:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H
M92!T97)M<R!O9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E
M<PH*("`@("`@("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E
M;G-E(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N
M9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R
M;W-Y<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y
M<FEG:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!3
M86X@06YT;VYI;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@
M(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES
M=')I8G5T92!I="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M
M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E
M('9E<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A
M<F4@1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E
M9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@
M5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE
M9"!W87)R86YT>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&
M3U(@02!005)424-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S
M97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*
M("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5
M($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@
M=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W
M87)E"B`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I
M=&4@,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3
M=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@
M,2XQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@
M<W5B:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R
M8V4@3&EC96YS92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M
M87D@;F]T('5S92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@
M=VET:"!T:&4@3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H
M90H@("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC
M96YS92YH=&UL+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,
M:6-E;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)
M5$A/550@5T%24D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2
M($E-4$Q)140L($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!7
M05)204Y42453(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-4
M4RP*("`@34520TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)0
M3U-%+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O
M<B!T:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H
M=',@86YD"B`@(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E
M+@H*("`@5&AE($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#
M;V1E(&ES.B!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@
MPJD@,C`P,B!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG
M:'1S(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S
M:&5E="!V97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP]
M(FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@
M("`@("`@("`@('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O;V9F:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X
M="(*("`@("`@("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R
M87<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@
M("`@("`@("`@("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]8
M4TPO1F]R;6%T(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z
M+R]W=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN
M<SIN=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL
M92(*("`@("`@("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO
M<F<O,C`P,"]S=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@
M("!X;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY."]-871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O
M<FT](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@
M("`@("`@("!X;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W-C<FEP="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X
M="(*("`@("`@("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@
M("`@("`@("`@("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE
M;G1S+S$N,2\B"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B
M"B`@("`@("`@("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT
M='`Z+R]W=W<N:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@('AM;&YS
M.G-Y<W1E;3TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL
M86YG+E-Y<W1E;2(*("`@("`@("`@("`@("`@('AM;&YS.GAA;&%N/2)H='1P
M.B\O>&UL+F%P86-H92YO<F<O>&%L86XB"B`@("`@("`@("`@("`@("!X;6QN
M<SIJ879A/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>'-L="]J879A(@H@("`@
M("`@("`@("`@("`@97AC;'5D92UR97-U;'0M<')E9FEX97,](FIA=F$B/@H*
M"B`@("`\>'-L.G1E;7!L871E(&YA;64](G=R:71E+7-T>6QE+7!R;W!E<G1I
M97,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&5!='1R:6)U=&50
M871H(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM
M*RLK*RL@0U-3(%!23U!%4E1)15,@("LK*RLK+2T^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R!O<B`D
M;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%1"<B/@H*("`@("`@("`@("`@("`@
M(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D<W1Y;&5!='1R:6)U=&50871H(CX*
M("`@("`@("`@("`@("`@(#PA+2T@:7-$96)U9TUO9&5-15-304=%.@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@3F%M93H\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB;F%M92@I(B\^(%9A;'5E.CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(N(B\^/"]X<VPZ;65S<V%G93X@("`@("`M+3X*"@H@("`@("`@("`@
M("`@("`@("`@(#PA+2T@/"%!5%1,25-4('-T>6QE.G!R;W!E<G1I97,@<W1Y
M;&4Z:&]R:7IO;G1A;"UP;W,@*&9R;VTM;&5F='QL969T?&-E;G1E<GQR:6=H
M='QF<F]M+6EN<VED97QI;G-I9&5\;W5T<VED92DC24U03$E%1#XM+3X*("`@
M("`@("`@("`@("`@("`@("`\(2TM(#)$3SH@:7,@:6YS:61E+V9R;VTM:6YS
M:61E(&%L<V\@8F5T=&5R('-H;W=A8FQE(#\@+2T^"B`@("`@("`@("`@("`@
M("`@("`@/"$M+2`A(2$A(#)$3SH@4W1I;&P@=&AE<F4@:&%V92!T;R!B92!P
M;&%C960@82`\8G(@8VQE87(])V%L;"<O/B!T;R!D:7-A8FQE('1H92!F;&]W
M(2$A(2TM/@H@("`@("`@("`@("`@("`@("`@(#PA+2T@("`@("`@("`@(%1H
M92!/3V\@871T<FEB=71E("=S='EL93IN=6UB97(M=W)A<'!E9"UP87)A9W)A
M<&AS)R!I<R!C=7)R96YT;'D@:6=N;W)E9"`M+3X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G=R87`B)SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)L969T(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YF;&]A=#H@<FEG:'0[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG+CTB<FEG:'0B)SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F9L
M;V%T.B!L969T.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TG;F%M92@N*2`](")S='EL93IH;W)I>F]N=&%L+7!O<R(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX](FQE
M9G0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/F%L:6=N.B!L969T.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX](G)I9VAT(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YA;&EG;CH@<FEG:'0[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG+CTB8V5N=&5R(B<^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YA
M;&EG;CH@8V5N=&5R.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"CPA+2T@<F5S=6QT<R!I;G1O(&$@8F%D('9I97<@*&]V
M97)L87!P960I(&EN($UO>FEL;&$@,2XP"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI(#T@(G1A8FQE.F%L:6=N(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M+CTB;&5F="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^9FQO870Z(')I9VAT.R`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX](G)I
M9VAT(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YF;&]A=#H@;&5F=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@HM+3X*"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@4$%$1$E.1R!F;W(@86QL('9A<FEA=&EO;G,Z(&9O.G!A9&1I
M;F<L(&9O.G!A9&1I;F<M=&]P+"!F;SIP861D:6YG+6)O='1O;2P@9F\Z<&%D
M9&EN9RUL969T+"!F;SIP861D:6YG+7)I9VAT("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG8V]N=&%I;G,H;F%M92@N*2PB
M9F\Z<&%D9&EN9R(I)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YP861D:6YG.B`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T*("`@("`@("`@("`@("`@("`@("`@("`@
M9F\Z8F]R9&5R"B`@("`@("`@("`@("`@("`@("`@("`@(&9O.F)O<F1E<BUT
M;W`*("`@("`@("`@("`@("`@("`@("`@("`@9F\Z8F]R9&5R+6)O='1O;0H@
M("`@("`@("`@("`@("`@("`@("`@("!F;SIB;W)D97(M;&5F=`H@("`@("`@
M("`@("`@("`@("`@("`@("!F;SIB;W)D97(M<FEG:'0*"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!!="!P<F5S96YT+"!A;&P@9F]U<B!B;W)D97)S
M(&UU<W0@8F4@<V5T('-I;75L=&%N96]U<VQY(&)Y('5S:6YG(&5I=&AE<@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&9O.F)O<F1E<B!P<F]P
M97)T>2!O<B!B>2!A='1A8VAI;F<@86QL(&9O=7(@;V8@=&AE(&]T:&5R(&)O
M<F1E<@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<')O<&5R=&EE<R!T
M;R!A;B!I=&5M('-E="!E;&5M96YT+B!);B!T:&4@;&%T=&5R(&-A<V4L(&EF
M(&]N92!O<B!M;W)E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!O9B!T
M:&4@<')O<&5R=&EE<R!I<R!M:7-S:6YG('1H96ER('9A;'5E<R!A<F4@87-S
M=6UE9"!T;R!B92!N;VYE+B!4:&4*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]N;'D@8F]R9&5R('-T>6QE<R!S=7!P;W)T960@87)E(&YO;F4@;W(@
M:&ED9&5N+"!S;VQI9"P@86YD(&1O=6)L92X@06YY"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!O=&AE<B!B;W)D97(@<W1Y;&4@<W!E8VEF:65D(&ES
M(&1I<W!L87EE9"!A<R!S;VQI9"X@5')A;G-P87)E;G0@8F]R9&5R<PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)E(&YO="!S=7!P;W)T960@86YD
M('1H92!B;W)D97(@=VED=&AS('1H:6XL(&UE9&EU;2P@86YD('1H:6-K(&%R
M90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;6%P<&5D('1O(&QE;F=T
M:',N($EN(&%D9&ET:6]N+"!O;FQY('-O;64@9&ES=&EN8W0@8F]R9&5R('=I
M9'1H<R!A<F4*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-U<'!O<G1E
M9"X@56YS=7!P;W)T960@=VED=&AS(&%R92!R;W5N9&5D('5P('1O('1H92!N
M97AT('-U<'!O<G1E9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VED
M=&@N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!T:&5R92!A<F4@
M;F\@<&%D9&EN9R!P<F]P97)T:65S('-P96-I9FEE9"!W:71H:6X@=&AE('-A
M;64*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ET96T@<V5T(&5L96UE
M;G0L(&$@9&5F875L="!P861D:6YG(&ES('5S960@9F]R('-I9&5S('1H870@
M:&%V92!A"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B;W)D97(N($$@
M=F%L=64@;V8@,&-M(&ES('5S960@9F]R('-I9&5S('=I=&AO=70@82!B;W)D
M97(N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H8W`N('=D+7-O+7AM
M;"UT97AT+G-D=RD*("`@("`@("`@("`@("`@("`@("`@("`@+2T^"@H\(2TM
M,D1/(%-405)4.B!C:&%N9V4@;65A<W5R96UE;G0@97%U86QL>2`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD]
M(F9O.F)O<F1E<B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M
M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC:"!T;R!I;B`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7=I9'1H.CPO>'-L
M.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H
M+BPG8V@@)RDB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7-T
M>6QE.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN
M9RUB969O<F4H<W5B<W1R:6YG+6%F=&5R*"XL)V-H("<I+"`G("<I(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUC;VQO<CH\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H<W5B<W1R
M:6YG+6%F=&5R*"XL)V-H("<I+"`G("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@N+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M=VED=&@Z/"]X
M<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R
M92@N+"<@)RDB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7-T
M>6QE.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN
M9RUB969O<F4H<W5B<W1R:6YG+6%F=&5R*"XL)V-M("<I+"`G("<I(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUC;VQO<CH\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H<W5B<W1R
M:6YG+6%F=&5R*"XL)V-M("<I+"`G("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@N+"`G<'0G*2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M=VED=&@Z/"]X
M<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R
M92@N+"<@)RDB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7-T
M>6QE.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN
M9RUB969O<F4H<W5B<W1R:6YG+6%F=&5R*"XL)W!T("<I+"`G("<I(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUC;VQO<CH\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H<W5B<W1R
M:6YG+6%F=&5R*"XL)W!T("<I+"`G("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z
M8F]R9&5R+71O<"(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/F)O<F1E<BUT;W`Z(#PO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S
M96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z8F]R9&5R+6)O='1O
M;2(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O
M<F1E<BUB;W1T;VTZ(#PO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0]
M(BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z8F]R9&5R+6QE9G0B)SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M;&5F
M=#H@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ
M=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2=N86UE*"XI/2)F;SIB;W)D97(M<FEG:'0B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M<FEG:'0Z(#PO>'-L
M.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M
M92@N*3TB<W1Y;&4Z8V]L=6UN+7=I9'1H(B<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&-H86YG:6YG('1H92!D:7-T86YC92!M96%S=7)E
M.B!I;F-H('1O(&EN("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@N+"`G8V@G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YW:61T
M:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M
M8F5F;W)E*"XL)V-H)RDB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YW
M:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2=N86UE*"XI/2)S='EL93IR;W<M:&5I9VAT(B<^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM(&-H86YG:6YG('1H92!D:7-T86YC
M92!M96%S=7)E.B!I;F-H('1O(&EN("TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@N+"`G8V@G
M*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YH96EG:'0Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<W5B<W1R:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^:&5I9VAT.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE
M8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.G=I9'1H(B<^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-H86YG:6YG('1H92!D:7-T
M86YC92!M96%S=7)E.B!I;F-H('1O(&EN("TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@N+"`G
M8V@G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YW:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2)S=6)S=')I;F<M8F5F;W)E*"XL)V-H)RDB+SX\>'-L.G1E>'0^.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YW:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"CPA+2TR1$\@14Y$.B!C:&%N9V4@
M;65A<W5R96UE;G0@97%U86QL>2`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F9O;G0M<W1Y;&4B)SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X
M=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ
M=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2=N86UE*"XI/2)S='EL93IF;VYT+6YA;64B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YF;VYT+69A;6EL>3H\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB8V]N=&5N="(@<V5L96-T/2(N(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1O
M9F9I8V4Z9F]N="UD96-L<R]S='EL93IF;VYT+61E8VQ;0'-T>6QE.FYA;64]
M)&-O;G1E;G1=+T!F;SIF;VYT+69A;6EL>2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB8V]N=&%I;G,H)&]F
M9FEC93IF;VYT+61E8VQS+W-T>6QE.F9O;G0M9&5C;%M`<W1Y;&4Z;F%M93TD
M8V]N=&5N=%TO0'-T>6QE.F9O;G0M<W1Y;&4M;F%M92P@)TET86QI8R<I(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^9F]N
M="US='EL93II=&%L:6,[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ:68@=&5S=#TB8V]N=&%I;G,H)&]F9FEC93IF;VYT+61E8VQS
M+W-T>6QE.F9O;G0M9&5C;%M`<W1Y;&4Z;F%M93TD8V]N=&5N=%TO0'-T>6QE
M.F9O;G0M<W1Y;&4M;F%M92P@)T)O;&0G*2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/F9O;G0M=V5I9VAT.F)O;&0[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II
M9CX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O
M.F9O;G0M=V5I9VAT(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL
M("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S
M96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z9F]N="US:7IE(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E
M>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L
M.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TG;F%M92@N*3TB9F\Z9F]N="UF86UI;'DB)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I
M;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI
M/2)F;SIC;VQO<B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G
M.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.FUA<F=I;BUL969T(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E
M>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L
M.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TG;F%M92@N*3TB9F\Z;6%R9VEN+7)I9VAT(B<^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R
M:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E
M>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N
M*3TB9F\Z;6%R9VEN+71O<"(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE
M*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.FUA<F=I;BUB
M;W1T;VTB)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O
M/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIL:6YE+6AE:6=H="(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\
M+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT
M/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M)VYA;64H+BD](F9O.G1E>'0M86QI9VXB)SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@24U03U)404Y4(&ES(&YE8V5S<V%R>2!A<R!T86)L
M92!C96QL('9A;'5E(&%L:6=N;65N="!I<R!D96-I9&5D(&)Y(')U;G1I;64@
M;W9E<B!T:&4@=F%L=65T>7!E"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($]T:&5R=VES92!A('1A8FQE(&-E;&P@<W1Y;&4M8VQA<W,@=VEL
M;"!!3%=!65,@8F4@;W9E<G=R:71T96X@8GD@=&AE(')U;BUT:6UE('9A;'5E
M("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)C;VYT86EN<R@N+"`G<W1A<G0G*2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT97AT+6%L:6=N.FQE9G0@
M(2!I;7!O<G1A;G0[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V5N9"<I
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/G1E>'0M86QI9VXZ<FEG:'0@(2!I;7!O<G1A;G0[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/G1E>'0M86QI9VXZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TG+B<O/CQX<VPZ=&5X=#X@(2!I;7!O<G1A;G0[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.G1E
M>'0M:6YD96YT(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z
M)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE
M8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z=&5X="UB86-K9W)O
M=6YD+6-O;&]R(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G1E>'0^8F%C:V=R;W5N9"UC;VQO<CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F)A8VMG<F]U
M;F0M8V]L;W(B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YB86-K9W)O=6YD+6-O;&]R.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z8F%C:V=R
M;W5N9"UI;6%G92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/F)A8VMG<F]U;F0M:6UA9V4Z=7)L*#PO>'-L.G1E>'0^/'AS;#IV
M86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^/'AS;#IT97AT/BD[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'-T>6QE.G)E<&5A="`]("=R97!E870G(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)A8VMG<F]U
M;F0M<F5P96%T.G)E<&5A=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F%C:V=R;W5N9"UR
M97!E870Z;F\M<F5P96%T.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"$M+2!T97AT+7-H861O=R!I<R!A($-34S(@9F5A='5R92!A;F0@>65T(&YO
M="!C;VUM;VX@=7-E9"!I;B!U<V5R+6%G96YT<R`M+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.G1E>'0M
M<VAA9&]W(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB
M+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0]
M(BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z=&5X="UC<F]S<VEN9RUO
M=70B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S
M=#TG;F]T*"X](FYO;F4B*2<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/G1E>'0M9&5C;W)A=&EO;CIL:6YE+71H<F]U9V@[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD]
M(G-T>6QE.G1E>'0M=6YD97)L:6YE(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.FEF('1E<W0])VYO="@N/2)N;VYE(BDG/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT97AT+61E8V]R
M871I;VXZ=6YD97)L:6YE.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2=N86UE*"XI/2)S='EL93IT97AT+7!O<VET:6]N(B<^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0])V-O;G1A:6YS
M*"XL(")S=6(B*2<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/G9E<G1I8V%L+6%L:6=N.G-U8CL@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2=C;VYT86EN<R@N+"`B
M<W5P(BDG/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YV97)T:6-A;"UA;&EG;CIS=7`[(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"$M+2!I<T1E8G5G36]D94U%4U-!1T4Z"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;65S<V%G93Y.;R!T<F%N<V9O<FUA=&EO;B!I;7!L96UE
M;G1E9"!F;W(@871T<FEB=71E+71Y<"`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M;F%M92@N*2(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93XM+3X*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/"$M+2LK*RLK
M(%!!3$T@,RXR(%-50E-%5"!!3D0@5T%0(%!23U!%4E1)15,@("LK*RLK+2T^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/'AS;#IF;W(M96%C:"!S96QE8W0](B1S='EL94%T=')I8G5T95!A=&@B/@H@
M("`@("`@("`@("`@("`@("`@(#PA+2T@:7-$96)U9TUO9&5-15-304=%.@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@3F%M93H\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB;F%M92@I(B\^(%9A;'5E.CQX<VPZ=F%L=64M;V8@
M<V5L96-T/2(N(B\^/"]X<VPZ;65S<V%G93X@("`@("`M+3X*"B`@("`@("`@
M("`@("`@("`@("`@/"$M+2!"54<@5T]22R!!4D]53D0Z"B`@("`@("`@("`@
M("`@("`@("`@1'5E('1O(&$@8G5G(&EN('1H92!85"!0<F]C97-S;W(L(&ET
M(&ES(&YO="!P;W-S:6)L92!T;R!C<F5A=&4@<V5R=F5R86P@96QE;65N=',@
M:6X@=F%R:6%B;&4@86YD('-E87)C:"!O=F5R('1H96TL"B`@("`@("`@("`@
M("`@("`@("`@869T97(@97AP;&EC:70@8V]N=F5R<VEO;B!T;R!N;V1E<V5T
M"B`@("`@("`@("`@("`@("`@("`@5&AI<R!G96YE<F%T960@<W1I;F<@:61E
M;G1I9FEE<B!S:&%L;"!B92!L871E<B!C:&%N9V5D(&)A8VL@=&\@82!S970@
M;V8@96QE;65N=',*("`@("`@("`@("`@("`@("`@("`M+3X*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2HJ*B!&3U)-050@05144DE"551%4R`J*BHM+3X*"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@271A;&EC("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z9F]N="US
M='EL92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T
M97-T/2)C;VYT86EN<R@N+"`G:71A;&EC)RD@;W(@8V]N=&%I;G,H+BP@)V]B
M;&EQ=64G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/FET86QI8RP@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!";VQD
M9F%C92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0])VYA;64H+BD](F9O.F9O;G0M=V5I9VAT(B<^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](F-O;G1A:6YS*"XL("=B;VQD
M)RD@;W(@8V]N=&%I;G,H+BP@)V)O;&1E<B<I(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]L9"P@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!5;F1E<FQI;F4@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IT97AT+75N
M9&5R;&EN92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/G5N9&5R;&EN92P@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@06QI9VYM96YT("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z=&5X="UA;&EG;B(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@N+"`G<W1A<G0G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YA;&EG;CIL969T+"`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"XL("=E;F0G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YA;&EG;CIR:6=H="P@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@N+"`G8V5N=&5R)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ8V5N=&5R+"`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@
M("`@("`@("`@("`@("`@("`@("`@/"$M+2!S=')I:V5T:')O=6=H("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N
M*3TB<W1Y;&4Z=&5X="UC<F]S<VEN9RUO=70B)SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#YS=')I:V4L(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@
M("`@("`@("`@("`@("`\(2TM($9O;G0@+2!S:7IE("A086QM.B!E;75L871O
M<B!T<F%N<V9O<FUE9"!S:7IE<R!T;R!A=F%I;&%B;&4@<V5T("AE+F<N(#,P
M('1O("AP<F]B86)L>2D@.2DM+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F9O;G0M<VEZ92(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G-I>F4Z/"]X<VPZ
M=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#XZ<VEZ
M92P@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@1F]N="`M($-O
M;&]R("A004Q-.B!B=70@;6]S=&QY(&]N;'D@,B!A=F%I;&%B;&4I"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B;&%C:R`H(S`P,#`P,"D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&=R87D@*",X,#@P.#`I*')E;F1E<F5D
M(&%S(&1A<FL@9W)A>2D*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-I
M;'9E<B`H(T,P0S!#,"DH<F5N9&5R960@87,@;&EG:'0@9W)A>2D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('=H:71E("@C1D9&1D9&*2TM/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB
M9F\Z8V]L;W(B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)C;VYT86EN<R@N("P@)R-&1D9&1D8G*2!O<B!C;VYT86EN
M<R@N("P@)R-F9F9F9F8G*2!O<B!C;VYT86EN<R@N("P@)W=H:71E)RD@;W(@
M8V]N=&%I;G,H+B`L("=72$E412<I(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/F-O;&]R.B-&1D9&1D8L(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/F-O;&]R.B,P,#`P,#`L(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2TJ*BH@5$%"3$4@05144DE"551%4R`J*BHM+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD]
M(F9O.F9O;G0M<VEZ92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/G-I>F4Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/CQX<VPZ=&5X=#XZ<VEZ92P@/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.F-O;'5M;BUW
M:61T:"(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C:&%N
M9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS
M;#IT97AT/CIW:61T:"P@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#XZ=VED=&@[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB<W1Y;&4Z<F]W+6AE:6=H="(G/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R
M93H@:6YC:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^:&5I
M9VAT.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN
M9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ=&5X=#XZ:&5I9VAT.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YH96EG:'0Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/CQX<VPZ=&5X=#XZ:&5I9VAT.R`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G=I9'1H
M(B<^(#PA+2UE87)L:65R(&9O.G=I9'1H+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&-H86YG:6YG('1H92!D:7-T86YC92!M96%S=7)E
M.B!I;F-H('1O(&EN("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@N+"`G8V@G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YW:61T
M:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M
M8F5F;W)E*"XL)V-H)RDB+SX\>'-L.G1E>'0^.G=I9'1H.R`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YW:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N
M(B\^/'AS;#IT97AT/CIW:61T:#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^
M"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*/"$M+2`R1$\Z($Y!34E.
M1R!#3TY614Y424].('9A<FEA8FQE(&%R92!W<FET=&5N('=I=&@@)RTG(&EN
M<W1E860@;V8@8V%S92US96YS:71I=F4@=W)I=&EN9R`M+3X*"@H*("`@(#PA
M+2T@*BHJ*BH@345!4U5214U%3E0@0T].5D524TE/3E,@*BHJ*BH*"B`@("`@
M*B`Q(&-E;G1I;65T97(@/2`Q,"!M;0H*("`@("`J(#$@:6YC:"`](#(U+C0@
M;6T*("`@("`@("!7:&EL92!T:&4@16YG;&ES:"!H879E(&%L<F5A9'D@<V5E
M;B!T:&4@;&EG:'0@*')E860Z('1H92!M971R:6,@<WES=&5M*2P@=&AE(%53
M"B`@("`@("`@<F5M86EN<R!L;WEA;"!T;R!T:&ES(&UE9&EE=F%L('-Y<W1E
M;2X*"B`@("`@*B`Q(&1I9&]T('!O:6YT(#T@,"XS-S8P-C4@;6T*("`@("`@
M("`@("`@5&AE(&1I9&]T('-Y<W1E;2!O<FEG:6YA=&5D(&EN($9R86YC92!B
M=70@=V%S('5S960@:6X@;6]S="!O9B!%=7)O<&4*"B`@("`@*B`Q('!I8V$@
M<&]I;G0@/2`P+C,U,30V(&UM"B`@("`@("`@("`@(%1H92!0:6-A('!O:6YT
M<R!S>7-T96T@=V%S(&1E=F5L;W!E9"!I;B!%;F=L86YD(&%N9"!I<R!U<V5D
M(&EN($=R96%T+4)R:71A:6X@86YD('1H92!54RX*"B`@("`@*B`Q(%!O<W13
M8W)I<'0@<&]I;G0@/2`P+C,U,C<W,3,X(&UM"B`@("`@("`@("`@(%=H96X@
M061O8F4@8W)E871E9"!0;W-T4V-R:7!T+"!T:&5Y(&%D9&5D('1H96ER(&]W
M;B!S>7-T96T@;V8@<&]I;G1S+@H@("`@("`@("`@("!4:&5R92!A<F4@97AA
M8W1L>2`W,B!0;W-T4V-R:7!T('!O:6YT<R!I;B`Q(&EN8V@N"@H@("`@("H@
M,2!P:7AE;"`](#`N,C8T-3@S,S,N+B!M;2`@("AB>2`Y-B!D<&DI"B`@("`@
M("`@("`@($UO<W0@<&EC='5R97,@:&%V92!T:&4@.38@9'!I(')E<V]L=71I
M;VXL(&)U="!T:&4@9'!I('9A<FEA8FQE(&UA>2!V87)Y(&)Y('-T>6QE<VAE
M970@<&%R86UE=&5R"B`@("`M+3X*"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S
M=7)E('1O(&UM("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C;VYV97)T
M,FUM(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G9A;'5E(B\^"@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V5N=&EM971E<BUI;BUM;2(@("`@("`@
M("`@<V5L96-T/2(Q,"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB:6YC
M:"UI;BUM;2(@("`@("`@("`@("`@("`@<V5L96-T/2(R-2XT(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)D:61O="UP;VEN="UI;BUM;2(@("`@("`@
M("!S96QE8W0](C`N,S<V,#8U(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)P:6-A+7!O:6YT+6EN+6UM(B`@("`@("`@("!S96QE8W0](C`N,S4Q-#8B
M+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=C;2<I(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R
M:6YG+6)E9F]R92@D=F%L=64L)V-M)R`I*2`J("1C96YT:6UE=&5R+6EN+6UM
M*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G:6XG*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U
M8G-T<FEN9RUB969O<F4H)'9A;'5E+"=I;B<@*2D@*B`D:6YC:"UI;BUM;2DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V1P="<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B
M<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I*2`J("1D:61O="UP;VEN="UI
M;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)W!P="<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB
M97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)W!P="<I*2`J("1P:6-A+7!O
M:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D=F%L=64B+SX*("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"B`@("`\(2TM(&-H86YG:6YG(&UE87-U<F4@=&\@8VT@+2T^"B`@
M("`\>'-L.G1E;7!L871E(&YA;64](F-O;G9E<G0R8VTB/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB=F%L=64B+SX*"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C96YT:6UE=&5R+6EN+6UM(B`@("`@("`@("!S96QE8W0](C$P(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)I;F-H+6EN+6UM(B`@("`@("`@
M("`@("`@("!S96QE8W0](C(U+C0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F1I9&]T+7!O:6YT+6EN+6UM(B`@("`@("`@('-E;&5C=#TB,"XS-S8P
M-C4B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!I8V$M<&]I;G0M:6XM
M;6TB("`@("`@("`@('-E;&5C=#TB,"XS-3$T-B(O/@H*("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS
M*"1V86QU92P@)VUM)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU
M92P@)VUM)RDI(&1I=B`D8V5N=&EM971E<BUI;BUM;2DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"1V86QU92P@)VEN)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E
M*"1V86QU92P@)VEN)RDI(&1I=B`D8V5N=&EM971E<BUI;BUM;2`J("1I;F-H
M+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G9'!T)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG9'!T)RDI(&1I=B`D8V5N
M=&EM971E<BUI;BUM;2`J("1D:61O="UP;VEN="UI;BUM;2DB+SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"1V86QU92P@)W!P="<I(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E
M9F]R92@D=F%L=64L)W!P="<I*2!D:78@)&-E;G1I;65T97(M:6XM;6T@*B`D
M<&EC82UP;VEN="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"B`@("`\(2TM(&-H86YG:6YG(&UE87-U<F4@=&\@:6YC
M:"`H8W`N('-E8W1I;VX@8V]M;65N="D@+2T^"B`@("`\>'-L.G1E;7!L871E
M(&YA;64](F-O;G9E<G0R:6YC:"(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)V86QU92(O/@H*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I;65T
M97(M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E;&5C
M=#TB,C4N-"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I
M;G0M:6XM;6TB("`@("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@("`@
M<V5L96-T/2(P+C,U,30V(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G;6TG
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U
M;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G;6TG*2D@9&EV
M("1I;F-H+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G8VTG
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U
M;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G8VTG*2D@9&EV
M("1I;F-H+6EN+6UM("H@)&-E;G1I;65T97(M:6XM;6TI(B\^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C
M;VYT86EN<R@D=F%L=64L("=D<'0G*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O
M<F4H)'9A;'5E+"=D<'0G*2D@9&EV("1I;F-H+6EN+6UM("H@)&1I9&]T+7!O
M:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G<'!T)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD
M*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG<'!T)RDI(&1I=B`D
M:6YC:"UI;BUM;2`J("1P:6-A+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=F%L=64B+SX*
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM(&-H86YG:6YG
M(&UE87-U<F4@=&\@9'!T("AC<"X@<V5C=&EO;B!C;VUM96YT*2`M+3X*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)D<'0B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB=F%L=64B+SX*"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C96YT:6UE=&5R+6EN+6UM(B`@("`@("`@("!S96QE8W0](C$P(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)I;F-H+6EN+6UM(B`@("`@("`@
M("`@("`@("!S96QE8W0](C(U+C0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F1I9&]T+7!O:6YT+6EN+6UM(B`@("`@("`@('-E;&5C=#TB,"XS-S8P
M-C4B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!I8V$M<&]I;G0M:6XM
M;6TB("`@("`@("`@('-E;&5C=#TB,"XS-3$T-B(O/@H*("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS
M*"1V86QU92P@)VUM)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU
M92P@)VUM)RDI(&1I=B`D9&ED;W0M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C
M;VYT86EN<R@D=F%L=64L("=C;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R
M92@D=F%L=64L("=C;2<I*2!D:78@)&1I9&]T+7!O:6YT+6EN+6UM("H@)&-E
M;G1I;65T97(M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=I
M;B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R
M;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=I;B<I*2!D
M:78@)&1I9&]T+7!O:6YT+6EN+6UM("H@)&EN8V@M:6XM;6TI(B\^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@D=F%L=64L("=P<'0G*2(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB
M969O<F4H)'9A;'5E+"=P<'0G*2D@9&EV("1D:61O="UP;VEN="UI;BUM;2`J
M("1P:6-A+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=F%L=64B+SX*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E('1O
M('!P="`H8W`N('-E8W1I;VX@8V]M;65N="D@+2T^"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F-O;G9E<G0R<'!T(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](G9A;'5E(B\^"@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V5N=&EM
M971E<BUI;BUM;2(@("`@("`@("`@<V5L96-T/2(Q,"(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB:6YC:"UI;BUM;2(@("`@("`@("`@("`@("`@<V5L
M96-T/2(R-2XT(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)D:61O="UP
M;VEN="UI;BUM;2(@("`@("`@("!S96QE8W0](C`N,S<V,#8U(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)P:6-A+7!O:6YT+6EN+6UM(B`@("`@("`@
M("!S96QE8W0](C`N,S4Q-#8B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=M
M;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R
M;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=M;2<I*2!D
M:78@)'!I8V$M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L
M=64L("=C;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=C
M;2<I*2!D:78@)'!I8V$M<&]I;G0M:6XM;6T@*B`D8V5N=&EM971E<BUI;BUM
M;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)VEN)RDB/@H@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS
M=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)VEN)RDI(&1I=B`D<&EC82UP;VEN
M="UI;BUM;2`J("1I;F-H+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A
M;'5E+"`G9'!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG
M9'!T)RDI(&1I=B`D<&EC82UP;VEN="UI;BUM;2`J("1D:61O="UP;VEN="UI
M;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E('1O('!I>&5L(&)Y('9I82!P
M87)A;65T97(@<')O=FED960@9'!I("AD;W1S('!E<B!I;F-H*2!S=&%N9&%R
M9"!F86-T;W(@*&-P+B!S96-T:6]N(&-O;6UE;G0I("TM/@H@("`@/'AS;#IT
M96UP;&%T92!N86UE/2)C;VYV97)T,G!I>&5L(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G9A;'5E(B\^"@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V5N=&EM971E<BUI;BUM;2(@("`@("`@("`@<V5L96-T/2(Q,"(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI;BUM;2(@("`@("`@("`@("`@
M("`@<V5L96-T/2(R-2XT(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)D
M:61O="UP;VEN="UI;BUM;2(@("`@("`@("!S96QE8W0](C`N,S<V,#8U(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P:6-A+7!O:6YT+6EN+6UM(B`@
M("`@("`@("!S96QE8W0](C`N,S4Q-#8B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](G!I>&5L+6EN+6UM(B`@("`@("`@("`@("`@('-E;&5C=#TB)&EN
M8V@M:6XM;6T@9&EV("1D<&DB+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=M
M;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R
M;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=M;2<I*2!D
M:78@)'!I>&5L+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G
M8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G8VTG*2D@
M9&EV("1P:7AE;"UI;BUM;2`J("1C96YT:6UE=&5R+6EN+6UM*2(O/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB8V]N=&%I;G,H)'9A;'5E+"`G:6XG*2(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB
M969O<F4H)'9A;'5E+"`G:6XG*2D@9&EV("1P:7AE;"UI;BUM;2`J("1I;F-H
M+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G9'!T)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG9'!T)RDI(&1I=B`D<&EX
M96PM:6XM;6T@*B`D9&ED;W0M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1V86QU92(O/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H\+WAS;#IS='EL97-H965T/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+V]O;R]G;&]B86Q?9&]C=6UE;G0N>'-L````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(U
M,C4S-P`Q,#4Q-30S,3`V,``P,C0W,#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(#PA+2T*"B`@(%1H92!#;VYT96YT<R!O
M9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE
M('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S
M"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N
M<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD
M87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O
M<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER
M:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A
M;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@
M5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T
M<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS
M(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@
M=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R
M92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D
M(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7
M251(3U54($%.62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D
M('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/
M4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E
M<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@
M("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@
M3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T
M:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A
M<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET
M92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U
M;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q
M+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S
M=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C
M92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA
M>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W
M:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE
M"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E
M;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI
M8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE4
M2$]55"!705)204Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@
M24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!
M4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13
M+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/
M4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R
M('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT
M<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N
M"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O
M9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"
MJ2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H
M=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H
M965T('9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB
M:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@
M("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A
M=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@
M("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA3
M3"]&;W)M870B"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO
M+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS
M.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R
M9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@
M('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B
M"B`@("`@("`@("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R
M9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R
M;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@
M("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT
M(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@
M("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N
M=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN
M<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*
M("`@("`@("`@("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T
M<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@97AT96YS
M:6]N+65L96UE;G0M<')E9FEX97,](GAT(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z=7)L96YC;V1E<CTB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O
M:F%V82YN970N55),16YC;V1E<B(*("`@("`@("`@("`@("`@('AM;&YS.G-X
M9VAE;'!E<CTB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O8V]M+G-U
M;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(B"B`@("`@
M("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G
M+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM
M;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU
M9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"@H*"B`@("`\(2TM("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^
M"B`@("`\(2TM("HJ*B!';&]B86P@1&]C=6UE;G0@+2`@5&%B;&4@;V8@0V]N
M=&5N="`@("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*"B`@("`\>'-L.G1E
M;7!L871E(&UA=&-H/2)T97AT.G1A8FQE+6]F+6-O;G1E;G0B/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@
M("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT
M96UP;&%T97,^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;6%T8V@](G1E>'0Z:6YD97@M8F]D>2(^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX
M<VPZ87!P;'DM=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B/@H@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@(#PO>'-L.G1E;7!L871E/@H*
M"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#II;F1E>"UT:71L92(@
M;6]D93TB8V]N=&5N="UT86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ87!P;'DM
M=&5M<&QA=&5S/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@(#PO
M>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z
M<F5F97)E;F-E+7)E9B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#PA+2T@2F%V82!I<R!N965D
M960@87,@=V4@:&%V92!T;R!E;F-O9&4@=&AE(')E;&%T:79E(&QI;FMS("AB
M=6<C,3`R,S$Q*2`M+3X*("`@("`@("`\>'-L.FEF('1E<W0](FYO="@D:7-*
M879A1&ES86)L960I(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F$B/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E
M9B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/B,\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`@("`@("`@("`@("`@("`@/"$M
M+2!T:&4@<W!A8V4@:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A<F=U;65N
M="!E>&-E<'1I;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O
M0F5%;F-O9&5D(B!S96QE8W0](D!T97AT.G)E9BUN86UE(B\^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@("`\>'-L.F%P
M<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ87!P
M;'DM=&5M<&QA=&5S/@H*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;6%T8V@](G1E>'0Z<F5F97)E;F-E+6UA<FLB/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@
M("`@("`\(2TM($IA=F$@:7,@;F5E9&5D(&%S('=E(&AA=F4@=&\@96YC;V1E
M('1H92!R96QA=&EV92!L:6YK<R`H8G5G(S$P,C,Q,2D@+2T^"B`@("`@("`@
M/'AS;#II9B!T97-T/2)N;W0H)&ES2F%V841I<V%B;&5D*2(^"B`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](FYA;64B/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/"$M+2!T:&4@<W!A8V4@:&%S('1O(&)E
M(&YO<FUA;&EZ960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!O=&AE
M<G=I<V4@86X@:6QL96=A;"!A<F=U;65N="!E>&-E<'1I;VX@=VEL;"!B92!T
M:')O=VX@9F]R(%A4+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)T97AT5&]"945N8V]D960B('-E;&5C=#TB0'1E
M>'0Z;F%M92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@
M("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<F5F
M97)E;F-E+6UA<FLM<W1A<G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM($IA=F$@:7,@
M;F5E9&5D(&%S('=E(&AA=F4@=&\@96YC;V1E('1H92!R96QA=&EV92!L:6YK
M<R`H8G5G(S$P,C,Q,2D@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H
M)&ES2F%V841I<V%B;&5D*2(^"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)A(CX*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(FYA;64B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2!T:&4@<W!A8V4@:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A
M<F=U;65N="!E>&-E<'1I;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T
M97AT5&]"945N8V]D960B('-E;&5C=#TB0'1E>'0Z;F%M92(O/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)E;F1/9E)E9F5R96YC92(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](G1E>'0Z<F5F97)E;F-E+6UA
M<FLM96YD6T!N86UE/6-U<G)E;G0H*2]`=&5X=#IN86UE72(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)P;W-I=&EO
M;B@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@
M("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@("`@("`@
M("`\>'-L.F9O<BUE86-H('-E;&5C=#TB9F]L;&]W:6YG+7-I8FQI;F<Z.BI;
M<&]S:71I;VXH*2`F;'0[("1E;F1/9E)E9F5R96YC95TB/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H*"B`@("`@/"$M+2!C;VYT96YT('1A8FQE(&QI;FL@("TM/@H@("`@/'AS
M;#IT96UP;&%T92!M871C:#TB=&5X=#IA(B!M;V1E/2)C;VYT96YT+71A8FQE
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*"@H@("`@("`@(#PA+2T@1F]R(&%N8VAO<G,@:6X@8V]N=&5N="UH
M96%D97)S(&$@8G5G(&5X:7-T<R`H8W`N(&)U9R!I9",@,3`R,S$Q*2!A;F0@
M=&AE>2!H879E('1O(&)E('=O<FME9"!O=70@<V5P87)A=&5L>2X*("`@("`@
M("`@("`@0W5R<F5N=&QY('1H92!L:6YK('5S960@:6X@=&AE(&-O;G1E;G0M
M=&%B;&4@;V8@86X@3V9F:6-E(%A-3"`H92YG+B!I;B!T:&4@8V]N=&5N="!T
M86)L92!A<R`G(S<N4V]M924R,$5X86UP;&4E,C!(96%D;&EN924W3W5T;&EN
M92<I"B`@("`@("`@("`@(&ES(&YO="!A('9A;&ED(%523"`H8W`N(&)U9R!I
M9",@,3`R,S$Q*2X@3F\@9FEL92!D97-T:6YA=&EO;B!I<R!S<&5C:69I960@
M;F]R(&5X:7-T(&%N>2!A;F-H;W(@96QE;65N="!F;W(@=&AE<V4*("`@("`@
M("`@("`@;&EN:W,@:6X@=&AE($]F9FEC92!834PL(&YO<B!I<R!T:&4@8VAA
M<'1E<B!N;RX@:VYO=VX@:6X@=&AE(&QI;FME9"!F:6QE<RX*("`@("`@("`@
M("`@02!W;W)K87)O=6YD(&9O<B!T:&ES('1R86YS9F]R;6%T:6]N('1H97)E
M9F]R92!H860@=&\@8F4@;6%D92X@5&AI<R!T:6UE+6-O;G-U;6EN9R!M96-H
M86YI<VT@:7,@9&ES86)L960@8GD@9&5F875L="!A;F0*("`@("`@("`@("`@
M8V%N(&)E(&%C=&EV871E9"!B>2!A('!A<F%M971E<B`H:2YE+B`G9&ES86)L
M94QI;FME9%1A8FQE3V9#;VYT96YT)RDN($$@8W)E871I;VX@;V8@86X@86YC
M:&]R(&ES(&UA9&4@9F]R(&5A8V@@:&5A9&5R(&5L96UE;G0N"B`@("`@("`@
M("`@($%L;"!H96%D97(@=&ET;&5S(&=O;FYA(&)E(&5N8V]D:6YG('1O(&)E
M('5S86)L92!I;B!A(')E;&%T:79E(%523"X@+2T^"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D9&ES86)L94QI
M;FME9%1A8FQE3V9#;VYT96YT(&]R("1I<TIA=F%$:7-A8FQE9"(^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-O
M;6UO;BUL:6YK(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB8W)E871E+6-O;G1E;G0M=&%B;&4M;&EN:R(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TB9V5T+6%B<V]L=71E+6-H87!T97(M;F\B/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(O/@H*("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B/@H*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$9I;&5(96%D:6YG
M3F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G970M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)T97-T4F5S=6QT(B!S96QE8W0](B1C;VYT96YT5&%B
M;&5(96%D:6YG<R]H96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N
M=$9I;&4@/2!`9FEL92UU<FQ=6VYU;6)E<B@D8W5R<F5N=$9I;&5(96%D:6YG
M3F\I72(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G970M9VQO8F%L+6AE861I;F<M;F\B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT1FEL94AE861I;F=.
M;R(@<V5L96-T/2)T<F%N<VQA=&4H)'1E<W1297-U;'0O0&%B<V]L=71E+6-H
M87!T97(M;&5V96PL("<K)RP@)RXG*2(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P<F5C961I;F=#:&%P=&5R3&5V96PQ
M(B!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PQ(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/"$M+2!7:&5N('1H92!C:&%P=&5R(&ES(&EN('1H92!G;&]B86P@
M9&]C=6UE;G0@:71S96QF('1H92!L:6YK(&AA<R!T;R!B92!R96QA=&EV92`H
M92YG+B`C:6YD97@I(&$@86)S;VQU=&4@:')E9B!D;V5S(&YO=`H@("`@("`@
M("`@("`@("`@("`@('=O<FL@=VET:"!T:&4@8G)O=W-E<BX@26X@8V%S92!O
M9B!C:&%P=&5R(&EN('1H92!G;&]B86P@9&]C=6UE;G0L('1H92!O=71P=70@
M55),(&]F('1H92!G;&]B86P@9&]C=6UE;G0@=V%S('1A:V5N+B`M+3X*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$9I;&5(
M96%D:6YG3F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)G970M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)T97-T4F5S=6QT(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A+V-O;G1E;G0M=&%B;&4M:&5A9&EN9W,O:&5A9&EN
M9ULD8V]N=&5N=%1A8FQE55),(#T@0&9I;&4M=7)L75MN=6UB97(H)&-U<G)E
M;G1&:6QE2&5A9&EN9TYO*5TB+SX*"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB9V5T+6=L;V)A;"UH96%D:6YG+6YO(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N
M=$9I;&5(96%D:6YG3F\B('-E;&5C=#TB=')A;G-L871E*"1T97-T4F5S=6QT
M+T!A8G-O;'5T92UC:&%P=&5R+6QE=F5L+"`G*R<L("<N)RDB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E8V5D:6YG
M0VAA<'1E<DQE=F5L,2(@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M,2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F=E="UC=7)R96YT+69I;&4M:&5A9&EN9RUN;R(^"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO
M;BUA=F%I;&%B;&4H)W-X9VAE;'!E<CIG970M8W5R<F5N="UC:&EL9"UH96%D
M:6YG+6YO)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](G-X9VAE;'!E<CIG970M8W5R<F5N="UC:&EL9"UH96%D:6YG+6YO*"DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T
M87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971#=7)R96YT
M0VAI;&1(96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYG971#=7)R96YT0VAI;&1(96%D:6YG3F\H*2(O
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F=E="UN97AT+6-U<G)E;G0M9FEL92UH96%D:6YG+6YO(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F9I;&4B+SX*("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL
M86)L92@G<WAG:&5L<&5R.F=E="UN97AT+6-U<G)E;G0M8VAI;&0M:&5A9&EN
M9RUN;R<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)S>&=H96QP97(Z9V5T+6YE>'0M8W5R<F5N="UC:&EL9"UH96%D:6YG+6YO
M*"1F:6QE*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A.F-O
M;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E
M=$YE>'1#=7)R96YT0VAI;&1(96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L
M="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971.97AT0W5R<F5N=$-H
M:6QD2&5A9&EN9TYO*"1F:6QE*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*
M"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E="UG;&]B86PM:&5A9&EN9RUN
M;R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C=7)R96YT1FEL94AE861I
M;F=.;R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA
M<'1E<DQE=F5L,2(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L
M<&5R.F=E="UG;&]B86PM:&5A9&EN9RUN;R<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z9V5T+6=L;V)A;"UH
M96%D:6YG+6YO*'-T<FEN9R@D8W5R<F5N=$9I;&5(96%D:6YG3F\I+"!N=6UB
M97(H)'!R96-E9&EN9T-H87!T97),979E;#$I*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3
M>&=#:&EL9%1R86YS9F]R;65R+F=E=$=L;V)A;$AE861I;F=.;R<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.F-O;2YS
M=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$=L
M;V)A;$AE861I;F=.;RAS=')I;F<H)&-U<G)E;G1&:6QE2&5A9&EN9TYO*2P@
M;G5M8F5R*"1P<F5C961I;F=#:&%P=&5R3&5V96PQ*2DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H*"B`@("`\(2TM(&YE8V5S<V%R>2!A<R!A;F-H;W(@
M9F]R('1H92!C;VYT96YT('1A8FQE("TM/@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)C<F5A=&4M:&5A9&EN9RUA;F-H;W(B/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM
M"B`@("`@("`@0W5R<F5N=&QY('1H92!L:6YK('5S960@:6X@=&AE($]F9FEC
M92!834P@*&4N9RX@:6X@=&AE(&-O;G1E;G0@=&%B;&4@87,@)R,W+E-O;64E
M,C!%>&%M<&QE)3(P2&5A9&QI;F4E-T]U=&QI;F4G*0H@("`@("`@(&ES(&YO
M="!A('9A;&ED(%523"`H8VUP+B!B=6<@:60C(#$P,C,Q,2DN($YO(&9I;&4@
M9&5S=&EN871I;VX@:7,@<W!E8VEF:65D(&YO<B!E>&ES="!A;GD@86YC:&]R
M(&5L96UE;G0@9F]R('1H97-E"B`@("`@("`@;&EN:W,@:6X@=&AE($]F9FEC
M92!834PN"B`@("`@("`@2&5R92!W92!A<F4@8W)E871I;F<@86X@86YC:&]R
M('=I=&@@=&AE('-P86-E(&YO<FUA;&EZ960@=&5X="!O9B!T:&ES(&AE861E
M<B!A<R!P;W1E;G1I86P@:G5M<"!A9&1R97-S(&]F('1H92!C;VYT96YT('1A
M8FQE("TM/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B
M/@H*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N
M=$9I;&5(96%D:6YG3F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)G970M;F5X="UC=7)R96YT+69I;&4M:&5A9&EN
M9RUN;R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB9FEL92(@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U
M<G)E;G1&:6QE(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*"B`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W1297-U;'0B
M('-E;&5C=#TB)&-O;G1E;G1486)L94AE861I;F=S+VAE861I;F=;)&=L;V)A
M;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92`]($!F:6QE+75R;%U;;G5M8F5R
M*"1C=7)R96YT1FEL94AE861I;F=.;RE=(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IM97-S86=E/DUA=&-H:6YG(&-H:6QD(&1O8W5M96YT(&AE861E
M<B!.;RX@/'AS;#IV86QU92UO9B!S96QE8W0](B1C=7)R96YT1FEL94AE861I
M;F=.;R(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IM97-S86=E/F%B<V]L=71E+6-H87!T97(M;&5V96PZ("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1T97-T4F5S=6QT+T!A8G-O;'5T92UC:&%P
M=&5R+6QE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.FUE<W-A9V4^96YC;V1E9%1I=&QE.B`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&5N8V]D960M
M=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93YG;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4Z(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E
M;G1&:6QE(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^*BHJ(#PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@
M("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB82(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL979E
M;"(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^*SPO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D=&5S=%)E<W5L="]`96YC;V1E9"UT:71L92(O/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(%=H
M96X@=&AE(&-H87!T97(@:7,@:6X@=&AE(&=L;V)A;"!D;V-U;65N="!I='-E
M;&8@=&AE(&QI;FL@:&%S('1O(&)E(')E;&%T:79E("AE+F<N("-I;F1E>"D@
M82!A8G-O;'5T92!H<F5F(&1O97,@;F]T"B`@("`@("`@("`@("`@("`@("`@
M=V]R:R!W:71H('1H92!B<F]W<V5R+B!);B!C87-E(&]F(&-H87!T97(@:6X@
M=&AE(&=L;V)A;"!D;V-U;65N="P@=&AE(&]U='!U="!54DP@;V8@=&AE(&=L
M;V)A;"!D;V-U;65N="!W87,@=&%K96XN("TM/@H@("`@("`@("`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT1FEL94AE861I;F=.;R(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E
M="UN97AT+6-U<G)E;G0M9FEL92UH96%D:6YG+6YO(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)F:6QE(B!S96QE
M8W0](B1C;VYT96YT5&%B;&554DPB+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=F%R
M:6%B;&4^"@H*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M=&5S=%)E<W5L="(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT
M96YT+71A8FQE+6AE861I;F=S+VAE861I;F=;)&-O;G1E;G1486)L95523"`]
M($!F:6QE+75R;%U;;G5M8F5R*"1C=7)R96YT1FEL94AE861I;F=.;RE=(B\^
M"@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y-871C:&EN9R!G
M;&]B86P@9&]C=6UE;G0@:&5A9&5R($YO+B`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)&-U<G)E;G1&:6QE2&5A9&EN9TYO(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^86)S;VQU=&4M8VAA<'1E
M<BUL979E;#H@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`
M86)S;VQU=&4M8VAA<'1E<BUL979E;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F5N8V]D9614:71L93H@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&5N
M8V]D960M=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93YC;VYT96YT5&%B;&554DPZ("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1C;VYT96YT5&%B;&554DPB+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93XJ*BH@
M/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T97-T
M4F5S=6QT+T!A8G-O;'5T92UC:&%P=&5R+6QE=F5L(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#XK/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T97-T4F5S
M=6QT+T!E;F-O9&5D+71I=&QE(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC
M:&]O<V4^"@H*"CPA+2T*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T
M:71L92(@<V5L96-T/2)N;W)M86QI>F4M<W!A8V4H+BDB+SX*("`@("`@("`\
M(7Y^1$].)U0@5T]22R`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1I=&QE(B!S
M96QE8W0](FYO<FUA;&EZ92US<&%C92AD97-C96YD86YT.CIT97AT*"DI(B\^
M("`@("`@("!^?CX*("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&
M:6QE(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&5S
M=%)E<W5L=',B('-E;&5C=#TB)&-O;G1E;G1486)L94AE861I;F=S+VAE861I
M;F=;)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92`]($!F:6QE+75R
M;%U;)'1I=&QE(#T@0'1I=&QE75MC=7)R96YT*"DO0'1E>'0Z;&5V96P@/2!`
M;&5V96Q=(B\^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](C$@)FQT
M.R!C;W5N="@D=&5S=%)E<W5L=',I(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^("HJ*B!#055424]..B!-=6QT:7!L92!C:&%P=&5R(&AE
M861I;F=S('=I=&@@<VEM:6QA<B!N86UE<SH@/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^("HJ*B!4:71L93H@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1T:71L92(O/B!,979E;#H@/'AS;#IV86QU
M92UO9B!S96QE8W0](D!T97AT.FQE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](F5N8V]D9614:71L92(@<V5L96-T/2(D=&5S=%)E
M<W5L=',O0&5N8V]D960M=&ET;&4B+SX*("`@("`@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1E;F-O9&5D5&ET;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M92(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1E;F-O
M9&5D5&ET;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(7Y^(&5V96X@=VAE;B!I="!I<R!N;W0@?GX^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W16YC
M;V1E9%1I=&QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\(7Y^('1H92!S<&%C92!H87,@=&\@
M8F4@;F]R;6%L:7IE9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;W1H97)W:7-E(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T:6]N
M('=I;&P@8F4@=&AR;W=N(&9O<B!85'Y^/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%
M;F-O9&5D(B!S96QE8W0](B1T:71L92(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)&YE=T5N8V]D9614:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W12
M97-U;'1S(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V-O;G1E;G0M
M=&%B;&4M:&5A9&EN9W,O:&5A9&EN9ULD8V]N=&5N=%1A8FQE55),(#T@0&9I
M;&4M=7)L75LD=&ET;&4@/2!`=&ET;&5=6V-U<G)E;G0H*2]`=&5X=#IL979E
M;"`]($!L979E;%TB+SX*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M,2`F;'0[(&-O=6YT*"1T97-T4F5S=6QT<RDB/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93X@*BHJ($-!551)3TXZ($UU;'1I<&QE(&-H87!T
M97(@:&5A9&EN9W,@=VET:"!S:6UI;&%R(&YA;65S.B`\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@*BHJ(%1I=&QE
M.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1I=&QE(B\^($QE=F5L.B`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB0'1E>'0Z;&5V96PB+SX\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@*BHJ(#PO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N8V]D9614:71L92(@<V5L
M96-T/2(D=&5S=%)E<W5L=',O0&5N8V]D960M=&ET;&4B+SX*("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&5N8V]D9614:71L92(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB)&5N8V]D9614:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PA?GX@979E;B!W:&5N(&ET(&ES(&YO
M="!^?CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)N97=%;F-O9&5D5&ET;&4B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F5N8V]D92US=')I;F<B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA?GX@=&AE('-P
M86-E(&AA<R!T;R!B92!N;W)M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A<F=U;65N
M="!E>&-E<'1I;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4?GX^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)T97AT5&]"945N8V]D960B('-E;&5C=#TB)'1I=&QE(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA
M;64B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D;F5W16YC;V1E9%1I=&QE(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H*+2T^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*B`M+3X*("`@(#PA+2T@("`@0U)%051)3TX@3T8@02!#3TY414Y4(%1!0DQ%
M($Q)3DL@("`@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*"B`@("`\(2TM(&$@<W!E8VEA;"!B96AA
M=FEO<B!O9B!T97AT.F$*("`@("`@("`H8V%L;&5D(&9R;VT@=&AE("=T97AT
M.F$G('1E;7!L871E*2`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R
M96%T92UC;VYT96YT+71A8FQE+6QI;FLB/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="@D;W5T<'5T
M5'EP92`]("=734PG*2(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB:')E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](G-T87)T<RUW:71H*$!X;&EN:SIH<F5F+"`G(R<I(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-O
M<G)E8W1(96%D:6YG(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V-O
M;G1E;G0M=&%B;&4M:&5A9&EN9W,O:&5A9&EN9UMC=7)R96YT*"DO0'AL:6YK
M.FAR968@/2!`8V]N=&5N="UT86)L92UI9%TB+SX*"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;W)R
M96-T2&5A9&EN9R]`;W5T+69I;&4M=7)L(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/B,\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D8V]R<F5C=$AE861I;F<O0&%B<V]L=71E+6-H87!T97(M;&5V96PB+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^*SPO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1C;W)R96-T2&5A9&EN9R]`96YC;V1E9"UT
M:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)C<F5A=&4M8V]M;6]N+6QI;FLB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#PA+2T@,D1/.B!C=7)R96YT;'D@;F\@5TU,('-U<'!O<G0*"B`@("`@("`@
M("`@("`@("`\(7Y^(&YO(&YE<W1E9"!P('1A9W,@:6X@=VUL,2XQ(&%L;&]W
M960@?GX^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I
M;G,H)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M:')E9B(^/'AS;#IV86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2(N(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE
M8W0](BXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ8VAO;W-E/B`@+2T^"B`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H)/"$M+0H)("`@($-214%424].($]&($$@2$5,4$52(%9!
M4DE!0DQ%($%3(%=/4DM!4D]53D0@1D]2(%1(12!#3TY414Y4(%1!0DQ%(%5,
M4B!"54<*"@H@("`@("`@($%S(&YO('9A;&ED(%523"!F<F]M('1H92!C;VYT
M96YT('1A8FQE('1O('1H92!C:&EL9"!D;V-U;65N=',@97AI<W0@:6X@=&AE
M(&-O;G1E;G0@=&%B;&4L"B`@("`@("`@82!W;W)K+6%R;W5N9"!I<R!D;VYE
M.@H*("`@("`@("!&:7)S="!T=V\@:&5L<&5R('9A<FEA8FQE<R!A<F4@8F5I
M;F<@8W)E871E9"X*"B`@("`@("`@3VYE(&-O;G1A:6YI;F<@=&AE(&QI<W0@
M;V8@86QL(')E9F5R96YC97,@;V8@=&AE(&=L;V)A;"!D;V-U;65N=#H*("`@
M("`@("!C;VYT86EN9R!A;&P@=&AE:7(@=&ET;&4L"B`@("`@("`@9F]R(&5X
M86UP;&4Z"@H@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE
M(#$B+SX*("`@("`@("`@(`D\8VAA<'1E<BUR968@=&ET;&4](F%4:71L92`R
M(B\^"B`@("`@("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,B\^
M"B`@("`@("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,R\^"@H@
M("`@("`@(%1H92!O=&AE<B!C;VYT86EN:6YG(&%L;"!H96%D:6YG(&9R;VT@
M=&AE(&-H:6QD(&1O8W5M96YT<R!L:6YK960@9G)O;2!T:&4@9VQO8F%L(&1O
M8W5M96YT+@H@("`@("`@(%1H92!V87)I86)L92`G8VAI;&1R96Y(96%D:6YG
M<R<@8V]N=&%I;G,@=&AE:7(@=&ET;&4@86YD('1H92!N=6UB97(@;V8@<')E
M8V5D:6YG('-I;6EL87(@=&ET;&5S+`H@("`@("`@(&9O<B!E>&%M<&QE.@H*
M"B`@("`@("`@("`)/&-H:6QD(&9I;&4M=7)L/2)A55),(CX*("`@("`@("`@
M(`D)/&AE861I;F<@=&ET;&4](F%4:71L93$B(&QE=F5L/2(Q(CX*("`@("`@
M("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L93(B(&QE=F5L/2(R(CX*("`@
M("`@("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L93,B(&QE=F5L/2(Q(CX*
M("`@("`@("`@("`@/"]C:&EL9#X*"B`@("`@("`@1F]R(&5A8V@@8VAA<'1E
M<B!R969E<F5N8V4@9G)O;2!T:&4@8V]N=&5N="!T86)L92!T:&4*"B`@("`@
M("`@(&)Y(&5N8V]D:6YG('1H92!C:&%P=&5R(&YA;65S(&]F('1H92!C:&EL
M9"!D;V-U;65N="!W:71H('1H92!J879A(%523$5N8V]D97(@86YD"B`@("`@
M("`@=7-E('1H:7,@87,@82!P87)T(&]F(&$@;&EN:RX@1G5R=&AE<FUO<F4@
M9F]R(&%L;"!H96%D:6YG(&5L96UE;G1S(&$@96YC;V1E9"!A;F-H;W(@=VEL
M;"!B92!C<F5A=&5D(&9R;VT@=&AE(&AE861I;F<N"B`@("`@("`@3&%S="!T
M:&4@=V]R:V%R;W5N9"!P87)S97,@86QL(&-H:6QD<F5N(&1O8W5M96YT<R!F
M;W(@=&AI<R!A;FAO<BP@87,@=&AE<F4@:7,@;F\@9&ES=&EN8W1I;VX@;V8@
M9FEL97,@9G)O;2!T:&4@8V]N=&5N="!T86)L92!E;G1R:65S+@H*("`@("`@
M("!4:&4@;F5W(&%D9&5D(&YO9&4@<V5T('1O('1H92!C;VQL96-T961';&]B
M86Q$871A('9A<FEA8FQE(&-O;F-E<FEN9R!T:&4@8V]N=&5N="!T86)L92!I
M<R!W<FET=&5N(&%S"@H*"0D\8V]N=&5N="UT86)L92UH96%D:6YG<R!C;VYT
M96YT+71A8FQE+75R;#TB85523%]4;U1H94=E;F5R871E9$-O;G1E;G1486)L
M92(^"B`@("`@(`D)/&AE861I;F<@9FEL92UU<FP](F%&:6QE55),5&]4:&5'
M96YE<F%T961(96%D:6YG,2(@;&5V96P](C$B/@H@("`@("`)"3QH96%D:6YG
M(&9I;&4M=7)L/2)A1FEL95523%1O5&AE1V5N97)A=&5D2&5A9&EN9S(B(&QE
M=F5L/2(R(CX*("`@("`@"0D\:&5A9&EN9R!F:6QE+75R;#TB849I;&554DQ4
M;U1H94=E;F5R871E9$AE861I;F<Q(B!L979E;#TB,2(^"B`@("`@(`D)/&AE
M861I;F<@9FEL92UU<FP](F%&:6QE55),5&]4:&5'96YE<F%T961(96%D:6YG
M,B(@;&5V96P](C(B/@H)"3PO8V]N=&5N="UT86)L92UH96%D:6YG<SX*"@H@
M("`@("`@(%!R96-O;F1I=&EO;G,Z"@D)5&AE(&-O<G)E8W0@<V5Q=65N8V4@
M;V8@8VAI;&0@9&]C=6UE;G1S(&%C8V]R9&EN9R!T;R!T:&4@0V]N=&5N="!4
M86)L92!I<R!N96-E<W-A<GDL(&=R86YT960@8GD@=&AE(&]F9FEC92X*"2TM
M/@H)/'AS;#IT96UP;&%T92!N86UE/2)#<F5A=&4M:&5L<&5R+79A<FEA8FQE
M<RUF;W(M0V]N=&5N="U486)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S
M=#TB)&ES1&5B=6=-;V1E(CX\>'-L.FUE<W-A9V4^0W)E871I;VX@;V8@9VQO
M8F%L(&1O8W5M96YT(&AE;'!E<B!V87)I86)L92!F;W(@=&AE(&-O;G1E;G0@
M=&%B;&4N+BXN/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"B`@("`@("`@/"$M
M+2!(97)E(&$@:&5L<&5R('9A<FEA8FQE(&]F('1H92!C;VYT96YT('1A8FQE
M(&ES(&-R96%T960L(&]F(&%L;"!C:&%P=&5R+7)E9F5R96YC97,@=VAI8V@@
M<&]I;G0@=&\@82!C:&EL9"!D;V-U;65N="X*("`@("`@("`@("`@(&%N("=C
M:&%P=&5R+7)E9B<@96QE;65N="!W:6QL(&)E(&-R96%T960L(&-O;G1A:6YG
M('1H96ER('1I=&QE(&%N9"!T:&4@;G5M8F5R(&]F('!R96-E9&EN9R!S:6UI
M;&%R('1I=&QE<RP*("`@("`@("`@("`@(&9O<B!E>&%M<&QE.@H*("`@("`@
M("`@("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,2(O/@H@("`@
M("`@("`@("`@(`D\8VAA<'1E<BUR968@=&ET;&4](F%4:71L92`R(B\^"B`@
M("`@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE(#(B+SX*
M("`@("`@("`@("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,R(O
M/@H@("`@("`@("`@("`M+3X*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F-H87!T97)2969S+5)41B(^"B`@("`@("`@("`@(#PA+2T@)R\J+R<@87,@
M=&AE(&9L870@86YD('1H92!Z:7!P960@6$U,(&9I;&4@9F]R;6%T(&AA=F4@
M9&EF9F5R96YT(')O;W0@96QE;65N=',@+2T^"B`@("`@("`@("`@(#QX<VPZ
M9F]R+65A8V@@<V5L96-T/2(O*B]O9F9I8V4Z8F]D>2]T97AT.G1A8FQE+6]F
M+6-O;G1E;G0O=&5X=#II;F1E>"UB;V1Y+W1E>'0Z<"]T97AT.F$B/@H@("`@
M("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT5&ET;&4B
M('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*'-T<FEN9R@N*2DB+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)C:&%P=&5R+7)E9B(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB=&ET;&4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)&-U<G)E;G14:71L92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)C;VYT96YT+71A8FQE+6ED(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IF;W(M96%C
M:#X*("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`\>'-L.FEF('1E
M<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D9I;FES:&5D('1H92!#
M<F5A=&EO;B!O9B!G;&]B86P@9&]C=6UE;G0@:&5L<&5R('9A<FEA8FQE(&9O
M<B!T:&4@8V]N=&5N="!T86)L92$\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H*
M"@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM
M97-S86=E/D-R96%T:6]N(&]F(&=L;V)A;"!D;V-U;65N="!H96QP97(@=F%R
M:6%B;&4@9F]R('1H92!C:&EL9"!D;V-U;65N=',N+BXN/"]X<VPZ;65S<V%G
M93X\+WAS;#II9CX*("`@("`@("`\(2TM($AE<F4@82!H96QP97(@=F%R:6%B
M;&4@;V8@8W)E871E9"!F<F]M('1H92!C:&EL9')E;B!D;V-U;65N=',N"B`@
M("`@("`@("`@("!#;VYT86EN9R!A;&P@:&5A9&EN9R!E;&5M96YT<R!F<F]M
M('1H92!C:&EL9"!D;V-U;65N=',N(%-O;64@;W(@86QL(&]F('1H96T@87)E
M"B`@("`@("`@("`@("!C:&%P=&5R<R!R969E<F5N8V5D(&)Y('1H92!';&]B
M86P@1&]C=6UE;G0N"B`@("`@("`@("`@("!4:&4@=F%R:6%B;&4@8V]N=&%I
M;G,@=&AE:7(@=&ET;&4L('1H92!L979E;"!O9B!T:&4@:&5A9&EN9R!A;F0@
M=&AE(&9I;&4@55),(&]F('1H92!C:&EL9"P*("`@("`@("`@("`@(&9O<B!E
M>&%M<&QE.@H*("`@("`@("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L93$B
M(&QE=F5L/2(Q(B!F:6QE+75R;#TB85523#$B/@H@("`@("`@("`@"0D\:&5A
M9&EN9R!T:71L93TB851I=&QE,B(@;&5V96P](C(B(&9I;&4M=7)L/2)A55),
M,2(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4S(B!L979E
M;#TB,2(@9FEL92UU<FP](F%54DPQ(CX*("`@("`@("`@(`D)/&AE861I;F<@
M=&ET;&4](F%4:71L930B(&QE=F5L/2(Q(B!F:6QE+75R;#TB85523#(B/@H@
M("`@("`@("`@"0D\:&5A9&EN9R!T:71L93TB851I=&QE-2(@;&5V96P](C(B
M(&9I;&4M=7)L/2)A55),,B(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE
M/2)A5&ET;&4R(B!L979E;#TB,R(@9FEL92UU<FP](F%54DPR(CX*("`@("`@
M("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L938B(&QE=F5L/2(S(B!F:6QE
M+75R;#TB85523#(B/@H@("`@("`@("`@("`@("`@/&AE861I;F<M8V]U;G0^
M-SPO:&5A9&EN9RUC;W5N=#X*("`@("`@("`@("`@+2T^"B`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)C:&EL9')E;DAE861I;F=S+5)41B(^"B`@("`@
M("`@("`@(#PA+2T@86QL(&AE861E<G,@9G)O;2!C:&EL9')E;B!D;V-U;65N
M=',@=VEL;"!B92!A9&1E9"`M+3X*("`@("`@("`@("`@/'AS;#IA<'!L>2UT
M96UP;&%T97,@<V5L96-T/2(O*B]O9F9I8V4Z8F]D>2]T97AT.G-E8W1I;VXB
M(&UO9&4](F-R96%T:6]N+6]F+79A<FEA8FQE(B\^"B`@("`@("`@/"]X<VPZ
M=F%R:6%B;&4^"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B
M/CQX<VPZ;65S<V%G93Y&:6YI<VAE9"!T:&4@0W)E871I;VX@;V8@9VQO8F%L
M(&1O8W5M96YT(&AE;'!E<B!V87)I86)L92!F;W(@=&AE(&-H:6QD(&1O8W5M
M96YT<R$\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H*"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA
M=F%I;&%B;&4H)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](D-R96%T92UG;&]B86PM=F%R:6%B;&4M
M9F]R+4-O;G1E;G0M5&%B;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C:&%P=&5R4F5F<R(@("`@('-E;&5C=#TB>'0Z
M;F]D92US970H)&-H87!T97)2969S+5)41BDB+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAI;&1R96Y(96%D:6YG<R(@
M("`@('-E;&5C=#TB>'0Z;F]D92US970H)&-H:6QD<F5N2&5A9&EN9W,M4E1&
M*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B`@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)#
M<F5A=&4M9VQO8F%L+79A<FEA8FQE+69O<BU#;VYT96YT+51A8FQE(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E
M<E)E9G,B("`@("!S96QE8W0](GAA;&%N.FYO9&5S970H)&-H87!T97)2969S
M+5)41BDB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8VAI;&1R96Y(96%D:6YG<R(@("`@('-E;&5C=#TB>&%L86XZ;F]D
M97-E="@D8VAI;&1R96Y(96%D:6YG<RU25$8I(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB0W)E871E+6=L;V)A
M;"UV87)I86)L92UF;W(M0V]N=&5N="U486)L92(^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)C:&%P=&5R4F5F<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8VAI;&1R96Y(96%D:6YG<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*"B`@("`@("`@/'AS;#II
M9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`\(2TM(&AE;'!E
M<B!V87)I86)L92!C;VQL96-T:6YG(&%L;"!H96%D:6YG<R!F<F]M('1H92!G
M;&]B86P@9&]C=6UE;G0@9FEL92!C:&EL9')E;BTM/@H@("`@("`@("`@("`\
M>'-L.F9O<BUE86-H('-E;&5C=#TB)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN
M9R(^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^(R`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G!O<VET:6]N*"DB+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/FQE=F5L.B`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`;&5V96PB+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/G1I=&QE.B`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&ET;&4B+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F5N8V]D960M
M=&ET;&4Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`96YC;V1E9"UT:71L92(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M9FEL92UU<FPZ("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!F:6QE+75R
M;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^:&5A9&5R+6YO.B`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!H96%D
M97(M;F\B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/BHJ/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93XJ*CPO>'-L.FUE<W-A
M9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93XJ*CPO>'-L.FUE<W-A9V4^
M"@H@("`@("`@("`@("`\(2TM(&AE;'!E<B!V87)I86)L92!C;VQL96-T:6YG
M(&%L;"!H96%D:6YG(')E9F5R96YC97,@9G)O;2!T:&4@8V]N=&5N="!T86)L
M92!O9B!T:&4@=&AE(&=L;V)A;"!D;V-U;65N="`M+3X*("`@("`@("`@("`@
M/'AS;#IM97-S86=E/F-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N=#H@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1C:&EL9')E;DAE861I;F=S+VAE861I
M;F<M8V]U;G0B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.F9O
M<BUE86-H('-E;&5C=#TB)&-H87!T97)2969S+V-H87!T97(M<F5F(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ;65S<V%G93XC(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)P;W-I=&EO;B@I(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93YT:71L93H@/'AS;#IV86QU92UO9B!S96QE8W0]
M(D!T:71L92(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^*BH\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\+WAS;#IF
M;W(M96%C:#X*("`@("`@("`\+WAS;#II9CX*"@H@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A
M:6QA8FQE*"=S>&=H96QP97(Z<V5T+6AE861I;F<M;F\G*2(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIS
M970M:&5A9&EN9RUN;R@Q*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z<V5T+6-U<G)E;G0M8VAI;&0M
M;F\H,2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB<WAG:&5L<&5R.G-E="UC=7)R96YT+6-H:6QD+75R;"AS=')I;F<H
M)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9R]`9FEL92UU<FPI*2(O/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT
M+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+G-E=$AE861I;F=.;R<I(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V
M83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE
M<BYS971(96%D:6YG3F\H,2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP
M97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971#=7)R96YT0VAI;&1.;R@Q*2(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J
M879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R
M;65R+G-E=$-U<G)E;G1#:&EL9%5R;"AS=')I;F<H)&-H:6QD<F5N2&5A9&EN
M9W,O:&5A9&EN9R]`9FEL92UU<BDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`\>'-L.FEF('1E
M<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D-R96%T:6YG(&=L;V)A
M;"!D;V-U;65N="!V87)I86)L92!F;W(@8VAA<'1E<B!R96QA=&EO;G,N+BXN
M/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](F-O;G1E;G1486)L94AE861I;F=S1VQO8F%L1&%T82U25$8B/@H@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8V]N=&5N="UT86)L92UH
M96%D:6YG<R(^"B`@("`@("`@("`@("`@("`\(2TM(&%L;"!H96%D:6YG<R!A
M<F4@;&EN:V5D(&9R;VT@=&AE(&-U<G)E;G0@9VQO8F%L(&1O8W5M96YT(&EN
M<'5T(&9I;&4@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)C;VYT96YT+71A8FQE+75R;"(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VYT96YT5&%B;&554DPB+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@
M("`\(2TM(&AA9"!T;R!U<V4@82!F;W(@;&]O<"P@87,@82!R96-U<G-I;VX@
M96YD<R!W:71H(&%N('-T86-K;W9E<F9L;W<@97AC97!T:6]N(&%F=&5R(&%B
M;W5T(#8P,"!R96-U<G-I=F4@8V%L;',@+2T^"B`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T+6AE861I;F<M
M;F\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H
M('-E;&5C=#TB)&-H87!T97)2969S+V-H87!T97(M<F5F(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S
M96%R8VA(96%D:6YG26Y#:&EL9$1O8W5M96YT(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E
M<E)E9G,B("`@("`@("`@<V5L96-T/2(D8VAA<'1E<E)E9G,B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8VAI;&1R96Y(96%D:6YG<R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D
M:6YG<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C=7)R96YT0VAA<'1E<E)E9DYO(B!S96QE8W0]
M(G!O<VET:6]N*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$AE861I;F=.;R(@("`@
M<V5L96-T/2)S>&=H96QP97(Z9V5T+6AE861I;F<M;F\H*2(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C=7)R96YT0VAI;&154DPB("`@("!S96QE8W0](G-X9VAE;'!E<CIG970M
M8W5R<F5N="UC:&EL9"UU<FPH*2(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT0VAI;&1.
M;R(@("`@("!S96QE8W0](G-X9VAE;'!E<CIG970M8W5R<F5N="UC:&EL9"UN
M;R@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M
M96%C:#X*("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R
M86YS9F]R;65R+F=E=$AE861I;F=.;R<I(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D8VAA<'1E<E)E9G,O8VAA
M<'1E<BUR968B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](G-E87)C:$AE861I;F=);D-H:6QD1&]C=6UE
M;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C:&%P=&5R4F5F<R(@("`@("`@("!S96QE8W0](B1C
M:&%P=&5R4F5F<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C:&EL9')E;DAE861I;F=S(B`@("!S
M96QE8W0](B1C:&EL9')E;DAE861I;F=S(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#
M:&%P=&5R4F5F3F\B('-E;&5C=#TB<&]S:71I;VXH*2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M=7)R96YT2&5A9&EN9TYO(B`@("!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R
M+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T2&5A9&EN9TYO
M*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD55),(B`@("`@<V5L96-T/2)J
M879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R
M;65R+F=E=$-U<G)E;G1#:&EL9%5R;"@I(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#
M:&EL9$YO(B`@("`@('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH
M96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971#=7)R96YT0VAI;&1.;R@I
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C
M:#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H*("`@("`@("`@("`@/"$M+2!A9&1I;F<@=&AE(&%L<F5A9'D@97AI<VET
M:6YG(&=L;V)A;"!D871A(&5N=FER;VYM96YT("TM/@H@("`@("`@("`@("`\
M>'-L.F-O<'DM;V8@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB
M)&ES1&5B=6=-;V1E(CX\>'-L.FUE<W-A9V4^1FEN:7-H960@9VQO8F%L(&1O
M8W5M96YT('9A<FEA8FQE(&9O<B!C:&%P=&5R(')E;&%T:6]N<R$\+WAS;#IM
M97-S86=E/CPO>'-L.FEF/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G>'0Z
M;F]D92US970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB<W1A<G0M<V5L9BUA;F0M8VAI;&1R96XM=')A;G-F;W)M871I
M;VXB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](GAT.FYO9&4M
M<V5T*"1C;VYT96YT5&%B;&5(96%D:6YG<T=L;V)A;$1A=&$M4E1&*2(O/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U
M;F-T:6]N+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="US96QF+6%N
M9"UC:&EL9')E;BUT<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M("`@("`@('-E;&5C=#TB>&%L86XZ;F]D97-E="@D8V]N=&5N=%1A8FQE2&5A
M9&EN9W-';&]B86Q$871A+5)41BDB+SX*("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB<V5A<F-H2&5A9&EN9TEN0VAI;&1$;V-U;65N
M="(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C:&%P=&5R4F5F<R(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8VAI;&1R96Y(96%D:6YG<R(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N=$-H87!T97)2969.;R(O
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N=$AE861I;F=.;R(O
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD55),(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C=7)R96YT0VAI;&1.;R(O/@H*
M"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT0VAA<'1E<E)E
M9B(@("`@("!S96QE8W0](B1C:&%P=&5R4F5F<R]C:&%P=&5R+7)E9ELD8W5R
M<F5N=$-H87!T97)2969.;UTB+SX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](F-U<G)E;G1#:&%P=&5R240B("`@("`@('-E;&5C=#TB)&-U<G)E;G1#
M:&%P=&5R4F5F+T!C;VYT96YT+71A8FQE+6ED(B\^"B`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)C=7)R96YT0VAA<'1E<E1I=&QE(B`@("!S96QE8W0]
M(B1C=7)R96YT0VAA<'1E<E)E9B]`=&ET;&4B+SX*"B`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)C=7)R96YT0VAI;&1(96%D:6YG(B`@("!S96QE8W0]
M(B1C:&EL9')E;DAE861I;F=S+VAE861I;F=;)&-U<G)E;G1(96%D:6YG3F]=
M(B\^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)H96%D:6YG5&ET;&4B
M("`@("`@("`@("!S96QE8W0](B1C=7)R96YT0VAI;&1(96%D:6YG+T!T:71L
M92(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB:&5A9&EN9TQE=F5L
M(B`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N=$-H:6QD2&5A9&EN9R]`;&5V
M96PB+SX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FAE861I;F=.;R(@
M("`@("`@("`@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9$AE861I;F<O0&AE
M861E<BUN;R(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W0VAI
M;&154DPB("`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N=$-H:6QD2&5A9&EN
M9R]`9FEL92UU<FPB+SX*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U
M9TUO9&4B/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^*BHJ(&YE=R!H96%D
M:6YG(#PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC
M=7)R96YT0VAA<'1E<DE$.B`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U
M<G)E;G1#:&%P=&5R240B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^8W5R<F5N=$-H87!T97)4:71L93H@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1C=7)R96YT0VAA<'1E<E1I=&QE(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/F-U<G)E;G1#:&%P=&5R240Z
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H87!T97))1"(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC=7)R
M96YT2&5A9&EN9TYO.B`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E
M;G1(96%D:6YG3F\B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^:&5A9&EN9U1I=&QE.B`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1H96%D:6YG5&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^:&5A9&EN9TQE=F5L.B`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1H96%D:6YG3&5V96PB+SX\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^:&5A9&EN9TYO.B`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1H96%D:6YG3F\B+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^;F5W0VAI;&154DPZ
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1N97=#:&EL9%523"(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB;W5T1FEL95523"(^"B`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S
M=6)S=')I;F<M8F5F;W)E*"1N97=#:&EL9%523"PG+GAM;"<I(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*'-U
M8G-T<FEN9RUB969O<F4H)&YE=T-H:6QD55),+"<N>&UL)RDL)RYH=&TG*2(O
M/@H@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](G-U8G-T<FEN9RUB969O<F4H)&YE=T-H:6QD
M55),+"<N<W@G*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](F-O;F-A="AS=6)S=')I;F<M8F5F;W)E*"1N97=#:&EL9%52
M3"PG+G-X)RDL)RYH=&TG*2(O/@H@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#IV
M87)I86)L93X*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FES0VAA<'1E
M<DAE861I;F<B('-E;&5C=#TB)&AE861I;F=4:71L92`]("1C=7)R96YT0VAA
M<'1E<E1I=&QE(B\^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)I<TYE
M=T9I;&4B('-E;&5C=#TB<W1R:6YG*"1N97=#:&EL9%523"D@(3T@<W1R:6YG
M*"1C=7)R96YT0VAI;&154DPI(B\^"@H*"@H@("`@("`@(#QX<VPZ:68@=&5S
M=#TB)&ES3F5W1FEL92(^"B`@("`@("`@("`@(#PA+2T@<F5S970@;V8@=&AE
M(&%L<F5A9'D@8V]L;&5C=&5D(&-H:6QD(&AE861E<G,@+2T^"B`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C86QC+6-H87!T97(M;G5M
M8F5R<R(^"B`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(FQE=F5L(B!S96QE8W0](C`B+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`\+WAS;#II9CX*("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](F%B<V]L=71E0VAA<'1E<DQE=F5L(CX*("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F-A;&,M8VAA<'1E<BUN=6UB97)S
M(CX*("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;&5V
M96PB('-E;&5C=#TB;G5M8F5R*"1H96%D:6YG3&5V96PI(B\^"B`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ=F%R:6%B
M;&4^"@H*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB:&5A9&EN9R(^"B`@
M("`@("`@("`@(#PA+2T@;F5C97-S87)Y('1O(&%S($E$(&9R;VT@=&AE(&-O
M;G1E;G0@=&%B;&4@=&\@9V5T('1H92!C;W)R96-T(&AE861I;F<@96QE;65N
M="`H=&AE(&)U9V=Y(%523"!U<V5D(&%S($E$*2TM/@H@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT+71A8FQE+6ED(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D:7-#:&%P=&5R2&5A9&EN9R(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H
M87!T97))1"(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#YO;FQY(&$@:&5A9&EN9RP@8G5T(&YO
M="!A(&-H87!T97(\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\(2TM
M(&YO(&]F('1H92!U<V5D(&-H:6QD+"!N96-E<W-A<GD@9F]R('%U:6-K(&9I
M;F1I;F<@;V8@8VAA<'1E<G,@;V8@;F5X="!F:6QE("`M+3X*("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8VAI;&0M9&]C=6UE;G0M;F\B/@H@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](B1I<TYE=T9I;&4B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1#:&EL
M9$YO("L@,2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H
M:6QD3F\B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO
M>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/"$M+2!T:&4@55),(&]F('1H
M92!C:&EL9"!D;V-U;65N="!S;W5R8V4L(&-O;G1A:6YI;F<@=&AE(&AE861I
M;F<@+2T^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F9I;&4M
M=7)L(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D
M;F5W0VAI;&154DPB+SX*("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)O=70M9FEL92UU<FPB
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1O=71&
M:6QE55),(B\^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;&5V96PB/@H@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1H96%D:6YG3&5V96PB+SX*
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)T:71L92(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)&AE861I;F=4:71L92(O/@H@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](F5N8V]D960M=&ET;&4B/@H@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1C=7)R96YT0VAI;&1(96%D:6YG+T!E;F-O9&5D
M+71I=&QE(B\^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB86)S;VQU=&4M8VAA<'1E<BUL
M979E;"(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)&%B<V]L=71E0VAA<'1E<DQE=F5L(B\^"B`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`\+WAS;#IE;&5M96YT/@H*"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D8VAI;&1R
M96Y(96%D:6YG<R]H96%D:6YG+6-O=6YT("$]("1C=7)R96YT2&5A9&EN9TYO
M(CX*("`@("`@("`@("`@("`@(#PA+2T@<')O8V5D92!A<R!L;VYG('1H92!L
M:7-T(&]F(&-H:6QD<F5N(&ES;B=N="!W;W)K960@=&AR;W5G:"`M+3X*("`@
M("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2(D:7-#:&%P=&5R2&5A9&EN9R(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@9VQO8F%L('9A<FEA8FQE<R!H879E('1O
M(&)E('-E="P@<V\@=&AE(&9O<BUE86-H(&QO;W`@8V%N(&%C8V5S<R!T:&5M
M("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC
M=&EO;BUA=F%I;&%B;&4H)W-X9VAE;'!E<CIS970M:&5A9&EN9RUN;R<I(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB<WAG:&5L<&5R.G-E="UH96%D:6YG+6YO*"1C=7)R96YT2&5A
M9&EN9TYO("L@,2DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.FEF('1E<W0](B1I<TYE=T9I;&4B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG
M:&5L<&5R.G-E="UC=7)R96YT+6-H:6QD+6YO*"1C=7)R96YT0VAI;&1.;R`K
M(#$I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z<V5T+6-U<G)E;G0M8VAI
M;&0M=7)L*'-T<FEN9R@D;F5W0VAI;&154DPI*2(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J
M879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R
M;65R+G-E=$AE861I;F=.;R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T
M87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971(96%D:6YG
M3F\H)&-U<G)E;G1(96%D:6YG3F\@*R`Q*2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES3F5W1FEL92(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#
M:&EL9%1R86YS9F]R;65R+G-E=$-U<G)E;G1#:&EL9$YO*"1C=7)R96YT0VAI
M;&1.;R`K(#$I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.F-O;2YS=6XN<W1A<BYX
M<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+G-E=$-U<G)E;G1#:&EL
M9%5R;"@D;F5W0VAI;&154DPI(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!N;W0@82!C:&%P=&5R(&AE861I;F<L(&-A;&P@:71S
M96QF('5N=&EL(&$@8VAA<'1E<B!R968@:7,@9F]U;F0@;W(@=&AE(&5N9"!O
M9B!H96%D:6YG<R!I<R!R96%C:&5D("TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<V5A<F-H2&5A9&EN9TEN
M0VAI;&1$;V-U;65N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B("`@("`@("`@<V5L
M96-T/2(D8VAA<'1E<E)E9G,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C:&EL9')E;DAE861I;F=S(B`@
M("!S96QE8W0](B1C:&EL9')E;DAE861I;F=S(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H
M87!T97)2969.;R(@<V5L96-T/2(D8W5R<F5N=$-H87!T97)2969.;R(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-U<G)E;G1(96%D:6YG3F\B("`@('-E;&5C=#TB)&-U<G)E;G1(96%D
M:6YG3F\@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD55),(B`@("`@<V5L96-T
M/2(D8W5R<F5N=$-H:6QD55),(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD3F\B("`@
M("`@<V5L96-T/2(D8W5R<F5N=$-H:6QD3F\B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D
M:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93Y!;&P@8VAI;&0@9&]C=6UE;G1S(&AA=F4@8F5E;B!W86QK960@=&AR;W5G
M:"!W:71H;W5T(&9I;F1I;F<@=&AE(&-H87!T97(@;F%M92$\+WAS;#IM97-S
M86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@("`@("`@
M8VAI;&1R96Y(96%D:6YG<R]H96%D:6YG+6-O=6YT.B`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N="(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S
M86=E/B`@("`@("!C=7)R96YT2&5A9&EN9TYO.B`@("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$AE861I;F=.;R(O/CPO
M>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"@H*"@D\(2TM($-H87!T97)S(&9R;VT@
M=&AE($-O;G1E;G0@5&%B;&4@:&%V92!C=7)R96YT;'D@;F\@86YC:&]R('1O
M(&-H:6QD(&1O8W5M96YT<R!I;B!/3V\@6$U,+@H)"2!!<R!S;VQU=&EO;BP@
M=VAE;F5V97(@82!A(&=L;V)A;"!D;V-U;65N="`@979E<GD@:&5A9&5R(&]F
M('1H92!(5$U,(&]U='!U="!G971S(&=E="=S(&%N(&%N8VAO<B!I;B!T:&4@
M5&AE<F5F;W)E+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F5N8V]D92US
M=')I;F<B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB96YC;V1I;F<B('-E
M;&5C=#TB)U541BTX)R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=&5X
M=%1O0F5%;F-O9&5D(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=U<FQE
M;F-O9&5R.F5N8V]D92<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)U<FQE;F-O9&5R.F5N8V]D92AN;W)M86QI>F4M<W!A8V4H
M)'1E>'14;T)E16YC;V1E9"DL)&5N8V]D:6YG*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=J879A.FIA=F$N;F5T+E523$5N8V]D97(N96YC;V1E
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA
M=F$Z:F%V82YN970N55),16YC;V1E<BYE;F-O9&4H<W1R:6YG*&YO<FUA;&EZ
M92US<&%C92@D=&5X=%1O0F5%;F-O9&5D*2DL<W1R:6YG*"1E;F-O9&EN9RDI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H*("`@(#PA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B`@5%)!3E-&3U)-051)3TX@3T8@
M04Q,($-(24Q$($1/0U5-14Y44R!/1B!42$4@1TQ/0D%,($1/0U5-14Y44R!"
M62!54TE.1R!!($585$523D%,($A%3%!%4B!#3$%34R`@*BHJ("TM/@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H)/"$M+2!A(&YE=R!E;&5M96YT
M("=C;VYT96YT5&%B;&5(96%D:6YG<R<@=VEL;"!B92!A9&1E9"!T;R!T:&4@
M:&5L<&5R('9A<FEA8FQE('1H92!F:7)S="!T:6UE(&$@8VAI;&0@=VEL;"!B
M92!T<F%N<V9O<FUE9"`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB=')A
M;G-F;W)M+6=L;V)A;"UD;V-U;65N="UA;F0M8VAI;&1R96XB/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*"B`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A8FQE+6AE861I;F=S
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S
M=&%R="UC:&EL9"UT<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"@D@("`@("`@("`@
M("`\(2TM(%1H92!N96-E<W-A<GD@875X:6QI87)Y('9A<FEA8FQE(&AA<VXG
M="!B=6EL9"!Y970N"@D@("`@("`@("`@("!4:&ES('9A<FEA8FQE(&=O;FYA
M('-T;W)E(&%L;"!H96%D97)S("AW:71H(&-H87!T97(@;G5M8F5R<RD@86YD
M('1H92!54DP@;V8@=&AE:7(@9FEL97,@+2T^"@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](D-R96%T92UH96QP97(M=F%R:6%B
M;&5S+69O<BU#;VYT96YT+51A8FQE(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"@H)/'AS;#IT96UP;&%T92!N86UE/2)S=&%R="US96QF+6%N9"UC
M:&EL9')E;BUT<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ:68@
M=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F1E8G5G+6-O;G1E;G0M=&%B;&4M:&5A9&EN9W,M=F%R
M:6%B;&4B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93Y087)S:6YG('1H92!G;&]B86P@9&]C
M=6UE;G0N+BX\+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L.FEF/@H*("`@
M("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT
M96UP;&%T97,^"@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D
M92(^/'AS;#IM97-S86=E/E!A<G-I;F<@=&AE(&-H:6QD(&1O8W5M96YT<RXN
M+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G-T87)T+6-H:6QD+71R86YS9F]R;6%T:6]N(CX*("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H*"3PO>'-L.G1E;7!L871E/@H*"@H*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB<W1A<G0M8VAI;&0M=')A;G-F;W)M
M871I;VXB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D
M92(^/'AS;#IM97-S86=E/E-T87)T:6YG('1H92!C:&EL9"!T<F%N<V9O<FUA
M=&EO;G,N+BX\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H*("`@("`@("`\(2TM
M($%S('1H92!C:&EL9',@;V8@82!G;&]B86P@9&]C=6UE;G0@*'=I=&@@<W5F
M9FEX("YS>&<I(&1O(&YO="!K;F]W(&%N>71H:6YG(&%B;W5T('1H96ER(&=L
M;V)A;"!P87)E;G0L"B`@("`@("`@("`@('1H92!T<F%N<V9O<FUA=&EO;B!O
M9B!G;&]B86P@9&]C=6UE;G1S(&-H:6QD<F5N(&AA=F4@=&\@8F4@9&]N92!I
M;7!L:7II="X*("`@("`@("`@("`@3W1H97)W:7-E('1H92!C:&%P=&5R(&YU
M;6)E<B!O9B!T:&4@8VAI;&1R96X@=VEL;"!A;'=A>7,@<W1A<G0@=VET:"!Z
M97)O+"!A<R!T:&5Y(&1O(&YO="!K;F]W(&%N>71H:6YG(&%B;W5T('1H90H@
M("`@("`@("`@("!P<F]C961I;F<@8VAA<'1E<G,N"B`@("`@("`@("`@($9U
M<G1H97)M;W)E+"!T:&5Y(&1O;B=T(&AA=F4@86YY(&QI;FMS(&%B;W5T('!R
M96-E961I;F<@86YD(&9O;&QO=VEN9R!D;V-U;65N=',@86YD(&YO(&QI;FMI
M;F<@9F]R('5S86)I;&ET>2!R96%S;VYS"B`@("`@("`@("`@(&-O=6QD(&)E
M(&1O;F4N(%1H97)E9F]R92!T:&4@8VAI;&1R96X@:&%V92!T;R!B92!T<F%N
M<V9O<FUE9"!D=7)I;F<@=&AE('1R86YS9F]R;6%T:6]N(&]F(&$@9VQO8F%L
M("AS>&<I(&1O8W5M96YT("TM/@H)"3QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-
M;V1E(CX*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N
M="UT86)L92UH96%D:6YG<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/D-O;G1E;G1A8FQE(&1A=&$@97AI<W1S(&%S(&=L;V)A;"!D871A
M(3PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IM97-S86=E/DYO($-O;G1E;G1A8FQE(&=L;V)A;"!D871A
M(&5X:7-T<R$\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M/"]X<VPZ:68^"@H@("`@("`@(#PA+2T@8W5R<F5N=&QY('1H:7,@9G5N8W1I
M;VX@;VYL>2!W;W)K<R!W:71H(&YO9&4M<V5T<R!F<F]M(%A4("TM/@H@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z=')A;G-F;W)M+6-H:6QD
M<F5N)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z
M=')A;G-F;W)M+6-H:6QD<F5N*"`D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT
M96YT+71A8FQE+6AE861I;F=S+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')I;F<H)&IA<F5D4F]O=%523"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<FEN9R@D86)S;VQU=&53;W5R8V5$:7)2968I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=')I;F<H)&]P=&EO;F%L55),4W5F9FEX
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG*"1D<&DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<H)&]U='!U=%1Y<&4I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:7-$96)U9TUO9&4I(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93Y*879A(&UE=&AO9"!T<F%N<V9O<FU#
M:&EL9')E;B!T;R!T<F%N<V9O<FT@86QL(&-H:6QD<F5N(&]F(&$@9VQO8F%L
M(&1O8W5M96YT(&-O=6QD(&YO="!B92!F;W5N9"X@0F4@<W5R92!T;R!U<V4@
M=&AE(%A4('!R;V-E<W-O<BX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ("!#<F5A=&EO;B!O
M9B!H96QP97(@=F%R:6%B;&4@;V8@=&AE(&AE861I;F=S(&]F(&%L;"!C:&EL
M9')E;B!D;V-U;65N=',@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/'AS;#IT96UP;&%T
M92!M871C:#TB+RHO;V9F:6-E.F)O9'DO=&5X=#IS96-T:6]N(B!M;V1E/2)C
M<F5A=&EO;BUO9BUV87)I86)L92(^"B`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F=E=$-H:6QD4F]O=$YO9&4B+SX*"B`@("`@("`@/"$M+2!A
M9G1E<B!T:&4@;&%S="!C:&EL9"!D;V-U;65N="!T:&4@9VQO8F%L(&1O8W5M
M96YT('=I;&P@8F4@<&%R<V5D("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB
M<&]S:71I;VXH*2`](&QA<W0H*2(^"B`@("`@("`@("`@(#PA+2T@<V5A<F-H
M('1H92!G;&]B86P@9&]C=6UE;G0@869T97(@86QL(&-H:6QD(&1O8W5M96YT
M<R!H879E(&)E96X@<V5A<F-H960*"D]$2R!0051#2"!.3R!)3D1%6"!%3$5-
M14Y4(%=!3E1%1"`A(2`M(&YU;&P@<&]I;G1E<B!E>&-E<'1I;VX*("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E=%!R979I;W5S2&5A
M9&5R3F\B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F9I;&554DPB("`@("`@("`@("`@("`@("`@<V5L96-T/2(D8V]N=&5N=%1A
M8FQE55),(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB86UO=6YT3V9#=7)R96YT2&5A9&EN9R(@("!S96QE8W0](F-O=6YT*&9O
M;&QO=VEN9RUS:6)L:6YG.CIT97AT.F@I(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(@
M("!S96QE8W0](F9O;&QO=VEN9RUS:6)L:6YG.CIT97AT.F@B+SX*("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*+2T^"B`@("`@("`@("`@/"$M
M+2!G970@=&AE(&]V97)A;&P@3F\@;V8@2&5A9&5R<R`M+3X*("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T06QL2&5A9&5R3F\B+SX*
M("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F=E=$-H:6QD4F]O=$YO9&4B/@H@("`@("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB9FEL95523"(@("`@<V5L96-T/2)T97AT
M.G-E8W1I;VXM<V]U<F-E+T!X;&EN:SIH<F5F(B\^"@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@(`D\(2TM(&EF(&%B<V]L=71E(%523"!O<B!A
M8G-O;'5T92!$3U,@4$%42"!O<B!A8G-O;'5T92!5;FEX('!A=&@@+2T^"@D)
M"3QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D9FEL95523"PG+R\G*2!O<B`H
M<W5B<W1R:6YG*"1F:6QE55),+#(L,2D@/2`G.B<I(&]R('-T87)T<RUW:71H
M*"1F:6QE55),+"`G+R<I(CX*("`@(`D)"3QX<VPZ=F%R:6%B;&4@;F%M93TB
M8VAI;&12;V]T3F]D92(@<V5L96-T/2)D;V-U;65N="@D9FEL95523"DB+SX*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G9710
M<F5V:6]U<TAE861E<DYO(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB9FEL95523"(@("`@("`@("`@("`@("`@<V5L96-T
M/2(D9FEL95523"(O/@H@("`@("`@("`@("`@("`@"3PA+2T@3D\@86)S;VQU
M=&4@<V]U<F-E('!A=&@@=VEL;"!B92!A9&1E9"!A<R!P<F5F:7@@+2T^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%M;W5N
M=$]F0W5R<F5N=$AE861I;F<B('-E;&5C=#TB8V]U;G0H)&-H:6QD4F]O=$YO
M9&4O*B]O9F9I8V4Z8F]D>2]D97-C96YD86YT.CIT97AT.F@I(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54;U-E
M87)C:$9O<DAE861I;F<B('-E;&5C=#TB)&-H:6QD4F]O=$YO9&4O*B]O9F9I
M8V4Z8F]D>2]D97-C96YD86YT.CIT97AT.F@B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@"0D)/'AS;#IV87)I
M86)L92!N86UE/2)C:&EL9%)O;W1.;V1E(B!S96QE8W0](F1O8W5M96YT*&-O
M;F-A="@D86)S;VQU=&53;W5R8V5$:7)2968L)R\G+"1F:6QE55),*2DB+SX*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G9710
M<F5V:6]U<TAE861E<DYO(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB9FEL95523"(@("`@("`@("`@("`@("`@<V5L96-T
M/2(D9FEL95523"(O/@H@("`@("`@("`@("`@("`@"3PA+2T@=&AE(&%B<V]L
M=71E('-O=7)C92!P871H('=I;&P@8F4@861D960@87,@<')E9FEX("TM/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;6]U
M;G1/9D-U<G)E;G1(96%D:6YG(B!S96QE8W0](F-O=6YT*"1C:&EL9%)O;W1.
M;V1E+RHO;V9F:6-E.F)O9'DO9&5S8V5N9&%N=#HZ=&5X=#IH*2(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N;V1E5&]3
M96%R8VA&;W)(96%D:6YG(B!S96QE8W0](B1C:&EL9%)O;W1.;V1E+RHO;V9F
M:6-E.F)O9'DO9&5S8V5N9&%N=#HZ=&5X=#IH(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T4')E=FEO=7-(96%D
M97).;R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)F:6QE55),(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)N;V1E5&]396%R8VA&;W)(96%D:6YG
M(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;6]U;G1/9D-U<G)E;G1(
M96%D:6YG(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z
M9V5T+7!R979I;W5S+6-H:6QD+61O8W5M96YT<RUH96%D:6YG+6-O=6YT)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D
M9$AE861I;F=);F9O(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(@("!S96QE8W0]
M(B1N;V1E5&]396%R8VA&;W)(96%D:6YG(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&554DPB("`@("`@("`@("`@
M("`@("`@<V5L96-T/2(D9FEL95523"(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P<F5V:6]U<TAE861E<B(@("`@("`@
M("`@('-E;&5C=#TB<WAG:&5L<&5R.F=E="UP<F5V:6]U<RUC:&EL9"UD;V-U
M;65N=',M:&5A9&EN9RUC;W5N="@D86UO=6YT3V9#=7)R96YT2&5A9&EN9RDB
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N
M:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T4')E=FEO=7-#:&EL9$1O
M8W5M96YT<TAE861I;F=#;W5N="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A9&1(96%D:6YG26YF;R(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54;U-E87)C
M:$9O<DAE861I;F<B("`@<V5L96-T/2(D;F]D951O4V5A<F-H1F]R2&5A9&EN
M9R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)F:6QE55),(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&9I;&554DPB
M+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<')E=FEO=7-(96%D97(B("`@("`@("`@("!S96QE8W0](FIA=F$Z8V]M+G-U
M;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T4')E
M=FEO=7-#:&EL9$1O8W5M96YT<TAE861I;F=#;W5N="@D86UO=6YT3V9#=7)R
M96YT2&5A9&EN9RDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F%D9$AE861I;F=);F9O(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F9I;&554DPB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!R
M979I;W5S2&5A9&5R(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)N;V1E
M5&]396%R8VA&;W)(96%D:6YG(B\^"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB<')E=FEO=7-(96%D97(R(B!S96QE8W0](FYU;6)E<B@D<')E=FEO
M=7-(96%D97(I(B\^"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1N
M;V1E5&]396%R8VA&;W)(96%D:6YG(CX*"B`@("`@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB=&ET;&4B('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"XI
M(B\^"@H@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N8V]D9614
M:71L92(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB96YC;V1E+7-T<FEN9R(^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!T
M:&4@<W!A8V4@:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@("`@("`@("`@
M("`@("`@("`@(&]T:&5R=VES92!A;B!I;&QE9V%L(&%R9W5M96YT(&5X8V5P
M=&EO;B!W:6QL(&)E('1H<F]W;B!F;W(@6%0M+3X*("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1E>'14;T)E16YC;V1E9"(@
M<V5L96-T/2(D=&ET;&4B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](FAE861I;F<B/@H@("`@("`@("`@
M("`@("`@/"$M+2!O9&0@8G5T("=D97-C96YD86YT.G1E>'0H*2<@9&ED;B=T
M('=O<FLL(&)U="`G+B<L('1O(&=E="!A;&P@=&5X="!N;V1E<R!O9B!T:&4@
M:&5A9&5R("TM/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB=&ET;&4B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&ET;&4B+SX\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)E;F-O9&5D+71I=&QE(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&5N
M8V]D9614:71L92(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](FQE=F5L(CX\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB0'1E>'0Z;&5V96PB+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)F:6QE+75R;"(^/'AS;#IV
M86QU92UO9B!S96QE8W0](B1F:6QE55),(B\^/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:&5A9&5R+6YO
M(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB<&]S:71I;VXH*2`K("1P<F5V:6]U
M<TAE861E<C(B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T06QL2&5A
M9&5R3F\B/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E
M="UA;&PM8VAI;&0M9&]C=6UE;G1S+6AE861I;F<M8V]U;G0G*2(^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D06QL2&5A
M9&5R3F]%;&5M96YT(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB86QL2&5A9&5R(B`@('-E;&5C=#TB<WAG:&5L<&5R.F=E
M="UA;&PM8VAI;&0M9&]C=6UE;G1S+6AE861I;F<M8V]U;G0H*2(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T
M:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N
M4WAG0VAI;&14<F%N<V9O<FUE<BYG971!;&Q#:&EL9$1O8W5M96YT<TAE861I
M;F=#;W5N="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)A9&1!;&Q(96%D97).;T5L96UE;G0B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q(96%D97(B("`@<V5L
M96-T/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R
M86YS9F]R;65R+F=E=$%L;$-H:6QD1&]C=6UE;G1S2&5A9&EN9T-O=6YT*"DB
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&1!
M;&Q(96%D97).;T5L96UE;G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M86QL2&5A9&5R(B\^"@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H96%D
M:6YG+6-O=6YT(CX*("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(B1A;&Q(96%D97(B+SX*("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@(#PO
M>'-L.G1E;7!L871E/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@
M("`\(2TM("HJ*B`@0W)E871I;VX@;V8@82!L:6YE(&]F(&QI;FMS(&%T('1H
M92!B96=I;FYI;F<@86YD(&5N9"!O9B!A(&-H:6QD(&1O8W5M96YT('1O(&5N
M:&%N8V4@=7-A8FEL:71Y("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&0M8VAI;&0M9&]C
M=6UE;G0M=7-A8FEL:71Y+6QI;FMS(CX*("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB8V5N=&5R(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(G-M86QL(CX*("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#Y;(#PO>'-L.G1E
M>'0^"@H*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB9VQO
M8F%L1&]C=6UE;G1$:7(B('-E;&5C=#TB<WAG:&5L<&5R.F=E="UG;&]B86PM
M9&]C=6UE;G0M9&ER*"DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB8W5R<F5N=$-H:6QD3F\B('-E;&5C=#TB;G5M8F5R*"1C;VYT
M96YT5&%B;&5(96%D:6YG<R]H96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O
M0W5R<F5N=$9I;&4@/2!`9FEL92UU<FQ=+T!C:&EL9"UD;V-U;65N="UN;RDB
M+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96%R;&EE
M<D1O8U523"(@<V5L96-T/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,O:&5A9&EN
M9ULH)&-U<G)E;G1#:&EL9$YO("T@,2D@/2!`8VAI;&0M9&]C=6UE;G0M;F]=
M+T!O=70M9FEL92UU<FPB+SX*/"$M+0H\>'-L.FUE<W-A9V4^9G)O;3H@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N
M=$9I;&4B+SX\+WAS;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^=&\Z(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D96%R;&EE<D1O8U523"(O/CPO>'-L.FUE<W-A
M9V4^"CQX<VPZ;65S<V%G93Y)<SH@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F=E="UR96QA=&EV92UF:6QE+7)E9B(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52968B('-E;&5C=#TB
M)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&:6QE4F5F
M(B!S96QE8W0](B1E87)L:65R1&]C55),(B\^"B`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*/"]X<VPZ;65S<V%G93XM+3X*"@H@("`@
M("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D96%R;&EE<D1O8U523"(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=VAE;B!T:&4@
M;&EN:W,@<W1A<G1S('=I=&@@82`G(R<@:70G<R!A(&QI;FL@=&\@=&AE($-O
M;G1E;G0@5&%B;&4M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)S=&%R=',M=VET:"@D96%R;&EE<D1O8U523"P@)R,G
M*2(^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E+69I;&4M<F5F(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)S;W5R8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B
M86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)T87)G971&:6QE4F5F(B!S96QE8W0](BXB+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M
M+2`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D8V]N=&5N
M=%1A8FQE55),+"`D96%R;&EE<D1O8U523"DB+SXM+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F=E="UR96QA=&EV92UF:6QE+7)E9B(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<V]U<F-E1FEL95)E9B(@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694
M;T-U<G)E;G1&:6QE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%R9V5T1FEL95)E
M9B(@<V5L96-T/2(D96%R;&EE<D1O8U523"(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H\(2TM
M"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1G;&]B86Q$;V-U;65N=$1I<BP@)&5A
M<FQI97)$;V-54DPI(B\^+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#Y0<F5V:6]U<R!D;V-U;65N=#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/B!\(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`\+WAS
M;#II9CX*"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E
M9B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=VAE;B!G;&]B86Q$
M;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4@:7,@=6YS970@=&AE(&-U<G)E;G0@
M9FEL92!I<R!T:&4@0V]N=&5N="!486)L92TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E
M;G1&:6QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](F-O;G1E;G1486)L941I<B(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G970M;F%M92UO9BUT86)L92UO9BUC;VYT96YT+61O8W5M96YT(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B
M;&4^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)G970M<F5L871I=F4M9FEL92UR968B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<V]U<F-E1FEL95)E9B(@<V5L96-T/2(D9VQO8F%L1&]C=6UE
M;G129694;T-U<G)E;G1&:6QE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&:6QE
M4F5F(B!S96QE8W0](B1C;VYT96YT5&%B;&5$:7(B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H*/"$M+2`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VYT
M96YT5&%B;&554DPB+SXM+3X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/D-O;G1E
M;G0@5&%B;&4\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*"@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N
M97AT1&]C55),(B!S96QE8W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R]H96%D
M:6YG6R@D8W5R<F5N=$-H:6QD3F\@*R`Q*2`]($!C:&EL9"UD;V-U;65N="UN
M;UTO0&]U="UF:6QE+75R;"(O/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T
M97-T/2(D;F5X=$1O8U523"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/B!\(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)H<F5F(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@=VAE;B!T:&4@;&EN:W,@<W1A<G1S('=I=&@@82`G(R<@
M:70G<R!A(&QI;FL@=&\@=&AE($-O;G1E;G0@5&%B;&4M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=&%R=',M=VET
M:"@D;F5X=$1O8U523"P@)R,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M<F5L
M871I=F4M9FEL92UR968B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52
M968B('-E;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G1A<F=E=$9I;&52968B('-E;&5C=#TB+B(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H\(2TM("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1C;VYT96YT5&%B
M;&554DPL("1N97AT1&]C55),*2(O/BTM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G
M970M<F5L871I=F4M9FEL92UR968B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C
M949I;&52968B('-E;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT
M1FEL92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A<F=E=$9I;&52968B('-E;&5C
M=#TB)&YE>'1$;V-54DPB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M+2`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C
M;VYC870H)&=L;V)A;$1O8W5M96YT1&ER+"`D;F5X=$1O8U523"DB+SXM+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/DYE>'0@9&]C=6UE;G0\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#X@73PO>'-L.G1E>'0^"B`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E
M/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E="UR96QA=&EV92UF:6QE
M+7)E9B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S;W5R8V5&:6QE4F5F
M(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)T87)G971&:6QE4F5F(B\^
M"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T+7)E;&%T
M:79E+69I;&4M<F5F)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G-X9VAE;'!E<CIG970M<F5L871I=F4M9FEL92UR968H<W1R
M:6YG*"1S;W5R8V5&:6QE4F5F*2P@<W1R:6YG*"1T87)G971&:6QE4F5F*2DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T
M87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971296QA=&EV
M949I;&52968G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14
M<F%N<V9O<FUE<BYG971296QA=&EV949I;&52968H<W1R:6YG*"1S;W5R8V5&
M:6QE4F5F*2P@<W1R:6YG*"1T87)G971&:6QE4F5F*2DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T+6YA
M;64M;V8M=&%B;&4M;V8M8V]N=&5N="UD;V-U;65N="(^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T+6YA;64M;V8M=&%B;&4M;V8M
M8V]N=&5N="UD;V-U;65N="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)S>&=H96QP97(Z9V5T+6YA;64M;V8M=&%B;&4M;V8M
M8V]N=&5N="UD;V-U;65N="@I(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B
M;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A
M;G-F;W)M97(N9V5T3F%M94]F5&%B;&5/9D-O;G1E;G1$;V-U;65N="<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.F-O
M;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E
M=$YA;65/9E1A8FQE3V9#;VYT96YT1&]C=6UE;G0H*2(O/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H)/'AS;#IT96UP;&%T92!N86UE/2)D96)U9RUC;VYT
M96YT+71A8FQE+6AE861I;F=S+79A<FEA8FQE(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS
M;#IM97-S86=E/CQX<VPZ=&5X=#XJ*BHJ(%1(12!(14%$24Y'(%9!4DE!0DQ%
M("HJ*BH@/"]X<VPZ=&5X=#X\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ
M;65S<V%G93YC;VYT96YT+71A8FQE+75R;#H@/'AS;#IV86QU92UO9B!S96QE
M8W0](F-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG
M<R]C;VYT96YT+71A8FQE+75R;"(O/CPO>'-L.FUE<W-A9V4^"@H@("`@("`@
M(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C
M;VYT96YT+71A8FQE+6AE861I;F=S+VAE861I;F<B/@H@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^/'AS;#IT97AT/BHJ*BH@;F5W(&AE861I;F<Z("`@("`@
M("`\+WAS;#IT97AT/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ
M;65S<V%G93YC;VYT96YT+71A8FQE+6ED.B`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`8V]N=&5N="UT86)L92UI9"(O/CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93YC:&EL9"UD;V-U;65N="UN;SH@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`8VAI;&0M9&]C=6UE;G0M;F\B+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^9FEL92UU
M<FPZ("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&9I;&4M
M=7)L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E
M/F]U="UF:6QE+75R;#H@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(D!O=70M9FEL92UU<FPB+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^;&5V96PZ("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB0&QE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@
M("`@/'AS;#IM97-S86=E/G1I=&QE.B`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](D!T:71L92(O/CPO>'-L.FUE<W-A9V4^"B`@("`@
M("`@("`@(#QX<VPZ;65S<V%G93YE;F-O9&5D+71I=&QE.B`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`96YC;V1E9"UT:71L92(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YA8G-O;'5T92UC:&%P
M=&5R+6QE=F5L.CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`86)S;VQU=&4M8VAA
M<'1E<BUL979E;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"@H)/"]X<VPZ=&5M<&QA=&4^"@H*"3PA+2T@5&\@;6%K92!T:&4@
M:&5A9&EN9W,@=6YI<75E+"!T:&4@86)S;VQU=&4@:&5A9&EN9R!I<R!A9&1E
M9"!T;R!T:&5M"@D@("`@($4N9RX@5&AE(&QE=F5L(#$N,BXS+C0N('=O=6QD
M(')E<W5L="!I;G1O(&$@,2LR*S,K-"!S=')I;F<@+2T^"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](F-A;&,M8VAA<'1E<BUN=6UB97)S(CX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](FQE=F5L(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=S>&=H96QP97(Z8V%L8RUC:&%P=&5R+6YU;6)E<G,G*2(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.F-A
M;&,M8VAA<'1E<BUN=6UB97)S*"1L979E;"DB+SX*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N
M+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYC86QC0VAA<'1E<DYU;6)E<G,G*2(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N
M+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYC86QC0VAA
M<'1E<DYU;6)E<G,H)&QE=F5L*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G`B(&UO9&4](F-O
M;G1E;G0M=&%B;&4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M
M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IN86UE(#T@8W5R<F5N="@I+T!T
M97AT.G-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,O<W1Y;&4Z=&%B+7-T
M;W!S(B\^"@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T86)L92(^"B`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F)O<F1E<B(^,#PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M8VQA<W,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&5X=#IS='EL92UN86UE
M(B\^/"]X<VPZ871T<FEB=71E/@H\(2TM"CQX<VPZ;65S<V%G93XJ*BHJ*BHJ
M*BH\+WAS;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^4W1Y;&5N86UE.CQX<VPZ
M=F%L=64M;V8@<V5L96-T/2)`=&5X=#IS='EL92UN86UE(B\^/"]X<VPZ;65S
M<V%G93X*/'AS;#IM97-S86=E/G!O<VET:6]N.B`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB8V]U;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`I
M(B\^/"]X<VPZ;65S<V%G93X*+2T^"@H@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB8V]L9W)O=7`B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F-R96%T92UC;VPM96QE;65N="(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S
M:71I;VXB('-E;&5C=#TB8V]U;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z
M=&%B+7-T;W`I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T
M;W!3='EL97,B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H*("`@("`@("`@("`@
M/"$M+2!A;&P@96QE;65N=',@8F5F;W)E('1H92!F:7)S="!T86)3=&]P("TM
M/@H@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W1.;RU25$8B
M/@H@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T
M/2)N;V1E*"DB(&UO9&4](F-E;&PM8V]N=&5N="(O/@H@("`@("`@("`@("`\
M+WAS;#IV87)I86)L93X*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN
M;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M
M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2)X=#IN;V1E+7-E="@D=&5S
M=$YO+5)41BDB+SX*"0D)/'AS;#IE;&5M96YT(&YA;64](G1R(CX*("`@("`@
M("`@("`@("`@"2`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+71D
M+65L96UE;G1S(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2)C;W5N="@D86QL
M5&%B4W1O<%-T>6QE<R]S='EL93IT86(M<W1O<"DB+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB("`@("`@
M("`@<V5L96-T/2(Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A
M8E-T;W!3='EL97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D
M95!O<VET:6]N<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F9U;F-T:6]N+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&%B3F]D95!O<VET:6]N
M<R(@<V5L96-T/2)X86QA;CIN;V1E<V5T*"1T97-T3F\M4E1&*2(O/@H)"0D\
M>'-L.F5L96UE;G0@;F%M93TB='(B/@H@("`@("`@("`@("`@("`)(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&0M96QE;65N=',B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D
M95!O<VET:6]N(B!S96QE8W0](F-O=6YT*"1A;&Q486)3=&]P4W1Y;&5S+W-T
M>6QE.G1A8BUS=&]P*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@("`@("`@("!S96QE8W0](C$B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL
M5&%B4W1O<%-T>6QE<R(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).
M;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`@("`@("`@/"$M+2`\>'-L
M.G9A<FEA8FQE(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB>'0Z
M;F]D92US970H)'1E<W1.;RU25$8I(B\^"@H@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB='(B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F-R96%T92UT9"UE;&5M96YT<R(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I
M;VXB('-E;&5C=#TB8V]U;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B
M+7-T;W`I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G!O<VET:6]N(B`@("`@("`@('-E;&5C=#TB,2(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P
M4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I
M=&EO;G,B('-E;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#XM+3X*"@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C
M<F5A=&4M8V]L+65L96UE;G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M;&%S=$YO9&50;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M86QL5&%B4W1O<%-T>6QE<R(O/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E
M;&5C=#TB)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`B/@H@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8V]L(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^=VED=&@Z(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=R87`M8V5L
M;"UW:61T:"(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)P;W-I=&EO;B(@("`@("`@("!S96QE8W0](G!O<VET:6]N
M*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3
M='EL97,B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*
M("`@(#PO>'-L.G1E;7!L871E/@H\(2TM"E-C96YA<FEO<R!T86)S=&]P<PH*
M,2D@<W1Y;&4Z='EP92!O9B!S='EL93IT86(M<W1O<"!I<R`G<FEG:'0G(&%N
M9"!E87)L:65R('1A8E-T;W`@:7,@;F]T(')I9VAT"B`M/B!%87)L:65R('1E
M>'0M;F]D97,@86YD(&9O;&QO=VEN9R!T97AT+6YO9&5S+"!W:6QL(&)E('!U
M="!I;G1O(&%N(&EN;F5R('1A8FQE+"!W:71H('1W;R!41"!F:7)S="!A;&EG
M;F5D(&QE9G0L('=I=&@@<')O8V5D:6YG('1E>'1N;V1E<RP@=&AE(&QA='1E
M<B!A;&EG;F5D(')I9VAT+@H*,BD@<W1Y;&4Z='EP92!I<R`G<FEG:'0G(&%N
M9"!E87)L:65R('1A8E-T;W`@:7,@<FEG:'0*("T^(&9O;&QO=VEN9R!T97AT
M+6YO9&5S+"!W:6QL(&)E('!U="!I;G1O(&$@<FEG:'0@86QI9VYE9"!41`H*
M,RD@<W1Y;&4Z='EP92!I<R`G;F]N+7)I9VAT)R!A;F0@96%R;&EE<B!T86)3
M=&]P("=N;VXM<FEG:'0G(&%S('=E;&P*("T^('!U="!T:&4@<')E8V5D:6YG
M('1A8B!S=&]P<R!I;G1O(&$@5$0@*&QE9G0@86QI9VYE9"!I<R!D969A=6QT
M*0H*-"D@9FER<W0@<W1Y;&4Z='EP92!W;W5L9"!H879E(&YO(')I9VAT('!R
M96-E9&EG;B!T86)3=&]P"B`M/B!W;W)K<R!W96QL('=I=&@@9FER<W0@<V-E
M86YR:6]S(#$@86YD(#,*"C4I(&QA<W0@<W1Y;&4Z='EP92!W;W5L9"!B92!A
M('-P96-I86P@8V%S92P@:68@:70@=V]U;&0@8F4@;&5F="!A;&EG;F5D+"!B
M=70@=&AI<R!W;VXG="!H87!P96X@:6X@;W5R(&-A<V4N+B`Z1`H*4V-E;F%R
M:6]S('5N;6%T8VAE9#H*+2!T97AT.G-T>6QE<&]S:71I;VX@)V-E;G1E<B<@
M=VEL;"!N;W0@8F4@;6%T8VAE9"!I;B!O=7(@8V%S92`H969F;W)T(&9O<B!N
M;W1H:6YG*2P@=&AE<F4@=VEL;"!B92!O;FQY("=R:6=H="<@86YD(&YO="`G
M<FEG:'0G"BT@268@=&AE(&QA<W0@=&%B4W1O<"!I<R!N;W0@9G)O;2!T97AT
M.G-T>6QE<&]S=&EO;B`G<FEG:'0G+"!T:&4@;&5N9W1H(&]F('1H92!L87-T
M(&-E;&P@:7,@=6YD969I;F5D(&%N9"!A(&1O8W5M96YT(&QE;F=T:"!M=7-T
M(&)E(&9O=6YD+@H@($YO="!H87!P96YS(&EN(&]U<B!G;&]B86P@9&]C=6UE
M;G0@8V%S92X@06QS;R!T:&4@86QG;W)I=&AM(&)E;&]W('=O=6QD(&AA=F4@
M=&\@8F4@97AP86YD960@*&-P+B!S8V5N87)I;R`U*2X*"BTM/@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)C<F5A=&4M=&0M96QE;65N=',B/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<&]S:71I;VXB+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B+SX*/"$M+0H\>'-L.FUE
M<W-A9V4^*RLK*RLK*RL\+WAS;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^4&]S
M:71I;VXZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<&]S:71I;VXB+SX\+WAS
M;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^;&%S=$YO9&50;W-I=&EO;CH@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^/"]X<VPZ
M;65S<V%G93X*+2T^"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R
M<F5N=%-T>6QE5'EP92(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R]S='EL
M93IT86(M<W1O<%LD<&]S:71I;VY=+T!S='EL93IT>7!E(B\^"B`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)E87)L:65R4W1Y;&54>7!E(B!S96QE8W0]
M(B1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P6R1P;W-I=&EO;B`M
M(#%=+T!S='EL93IT>7!E(B\^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D8W5R<F5N=%-T>6QE5'EP92`]("=R
M:6=H="<B/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E87)L:65R4W1Y;&54>7!E
M(#T@)W)I9VAT)R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T*("`@
M("`@("`@("`@("`@("`@("`@("`@,BD@<W1Y;&4Z='EP92!I<R`G<FEG:'0G
M(&%N9"!E87)L:65R('1A8E-T;W`@:7,@<FEG:'0*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("T^(&9O;&QO=VEN9R!T97AT+6YO9&5S+"!W:6QL(&)E
M('!U="!I;G1O(&$@<FEG:'0@86QI9VYE9"!41"`M+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M86QI9VXZ(')I9VAT/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N
M=&5N="UB969O<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N
M("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](B1L
M87-T3F]D95!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B
M('-E;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`\(2TM"B`@("`@("`@("`@("`@
M("`@("`@("`@(#$I('-T>6QE.G1Y<&4@;V8@<W1Y;&4Z=&%B+7-T;W`@:7,@
M)W)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P(&ES(&YO="!R:6=H=`H@("`@
M("`@("`@("`@("`@("`@("`@("`@+3X@16%R;&EE<B!T97AT+6YO9&5S(&%N
M9"!F;VQL;W=I;F<@=&5X="UN;V1E<RP@=VEL;"!B92!P=70@:6YT;R!A;B!I
M;FYE<B!T86)L92P@=VET:"!T=V\@5$0@9FER<W0@86QI9VYE9"!L969T+"!W
M:71H('!R;V-E9&EN9R!T97AT;F]D97,L('1H92!L871T97(@86QI9VYE9"!R
M:6=H="XM+3X*/"$M+2!V86QI9"!(5$U,(&)U="!B<F]W<V5R<R!M86ME(&$@
M;&EN92!B<F5A:R`H8F]R9&5R/3`@86YD('!A<F%G<F%P:'-T>6QE(&%L<V\@
M;6ES<VEN9RDZ"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N
M="!N86UE/2)T86)L92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB=&0B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM
M8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB96YD:6YG5&%B4W1O<%!O<VET:6]N(B`@<V5L96-T
M/2(D<&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB
M('-E;&5C=#TB)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A
M8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N
M="!N86UE/2)T9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ(')I9VAT/"]X
M<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F=R87`M8V5L;"UC;VYT96YT+6)E
M9F]R92UT86(M<W1O<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)E;F1I;F=486)3=&]P4&]S:71I;VXB("!S96QE8W0](B1P;W-I=&EO
M;B`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C
M=#TB)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50
M;W-I=&EO;G,B('-E;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M=&0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B
M+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB96YD
M:6YG5&%B4W1O<%!O<VET:6]N(B`@<V5L96-T/2(D<&]S:71I;VXB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB)&QA<W1.;V1E
M4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E
M;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H\(2TM($]$2R!&
M14%455)%($Y/(%!!1T53"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/F%L:6=N.B!R:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F=R87`M8V5L;"UC;VYT96YT+6)E9F]R92UT86(M<W1O<"(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F5N
M9&EN9U1A8E-T;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N("L@,2(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB
M)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E
M4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X@("`@("`@("`@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&5A<FQI97)3='EL951Y<&4@/2`G
M<FEG:'0G(CX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@(#PA+2T*("`@("`@("`@("`@("`@("`@("`@("`S*2!S='EL93IT
M>7!E(&ES("=N;VXM<FEG:'0G(&%N9"!E87)L:65R('1A8E-T;W`@)VYO;BUR
M:6=H="<@87,@=V5L;`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+3X@
M<'5T('1H92!P<F5C961I;F<@=&%B('-T;W!S(&EN=&\@82!41"`H;&5F="!A
M;&EG;F5D(&ES(&1E9F%U;'0I("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB=&0B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=R87`M8V5L;"UC
M;VYT96YT+6)E9F]R92UT86(M<W1O<"(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB96YD:6YG5&%B4W1O<%!O<VET:6]N(B`@<V5L96-T/2(D<&]S:71I
M;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2(D;&%S
M=$YO9&50;W-I=&EO;B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S
M96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*"B`@("`@("`@/'AS;#II9B!T97-T/2(D<&]S:71I;VX@(3T@
M)&QA<W1.;V1E4&]S:71I;VXB/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB8W)E871E+71D+65L96UE;G1S(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@
M<V5L96-T/2(D;&%S=$YO9&50;W-I=&EO;B(O/@H@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G!O<VET:6]N(B`@("`@("`@('-E;&5C
M=#TB)'!O<VET:6]N("L@,2(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A
M8E-T;W!3='EL97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S
M:71I;VYS(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B
M+7-T;W`B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB96YD:6YG5&%B
M4W1O<%!O<VET:6]N(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)T86).
M;V1E4&]S:71I;VYS(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)L87-T
M3F]D95!O<VET:6]N(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&5N9&EN9U1A8E-T;W!0;W-I=&EO;B`]
M(#$B/@H@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@;6]D
M93TB8V]N=&5N="UT86)L92(@<V5L96-T/2)N;V1E*"E;<&]S:71I;VXH*2`F
M;'0[("1T86).;V1E4&]S:71I;VYS+W1A8BUS=&]P+6YO9&4M<&]S:71I;VY;
M)&5N9&EN9U1A8E-T;W!0;W-I=&EO;EU=(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&5N9&EN9U1A8E-T
M;W!0;W-I=&EO;B`^("1L87-T3F]D95!O<VET:6]N(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B
M('-E;&5C=#TB;F]D92@I6W!O<VET:6]N*"D@/B`D=&%B3F]D95!O<VET:6]N
M<R]T86(M<W1O<"UN;V1E+7!O<VET:6]N6R1E;F1I;F=486)3=&]P4&]S:71I
M;VX@+2`Q75TB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT
M96UP;&%T97,^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT
M96UP;&%T97,@;6]D93TB8V]N=&5N="UT86)L92(@<V5L96-T/2)N;V1E*"E;
M<&]S:71I;VXH*2`F;'0[("1T86).;V1E4&]S:71I;VYS+W1A8BUS=&]P+6YO
M9&4M<&]S:71I;VY;)&5N9&EN9U1A8E-T;W!0;W-I=&EO;EU=6W!O<VET:6]N
M*"D@/B`D=&%B3F]D95!O<VET:6]N<R]T86(M<W1O<"UN;V1E+7!O<VET:6]N
M6R1E;F1I;F=486)3=&]P4&]S:71I;VX@+2`Q75TB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"B`@("`\>'-L.G1E;7!L871E(&UO9&4](F-O;G1E;G0M
M=&%B;&4B(&UA=&-H/2)T97AT.G,B/@H@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92(^"B`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W:&ET97-P86-E<R(@<V5L
M96-T/2)`=&5X=#IC(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H
M/2(J(B!M;V1E/2)C96QL+6-O;G1E;G0B/@H*("`@("`@("`\>'-L.FEF('1E
M<W0](FYA;64H*2`]("=T97AT.G1A8BUS=&]P)R!O<B`J6VYA;64H*2`]("=T
M97AT.G1A8BUS=&]P)UTB/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB=&%B+7-T;W`M;F]D92UP;W-I=&EO;B(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<&]S:71I;VXH*2(O/@H@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL
M+7=I9'1H(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!O<VET:6]N(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B\^
M"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&%B4W1O<%!O<VET:6]N
M(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P6R1P
M;W-I=&EO;ETO0'-T>6QE.G!O<VET:6]N(B\^"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=&%B
M4W1O<%!O<VET:6]N+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-E;&PM=VED=&@B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W:61T:"(@("`@
M<V5L96-T/2)N=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=&%B4W1O<%!O<VET
M:6]N+"=C;2<I*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)U;FET(B`@("`@<V5L96-T/2(G8VTG(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O<VET:6]N(B!S
M96QE8W0](B1P;W-I=&EO;B`M(#$B+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5&%B4W1O<%-T>6QE<R(@<V5L96-T
M/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1T86)3=&]P4&]S:71I
M;VXL("=I;B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)C<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G=I9'1H(B`@("!S96QE8W0](FYU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1T86)3=&]P4&]S:71I;VXL)VEN)RDI
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G5N:70B("`@("!S96QE8W0](B=I;B<B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB('-E;&5C=#TB)'!O
M<VET:6]N("T@,2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3
M=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)'1A8E-T;W!0;W-I=&EO;BP@)V-H)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R
M96%T92UC96QL+7=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB=VED=&@B("`@('-E;&5C=#TB;G5M8F5R*'-U8G-T
M<FEN9RUB969O<F4H)'1A8E-T;W!0;W-I=&EO;BPG8V@G*2DB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=6YI="(@("`@
M('-E;&5C=#TB)V-H)R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@+2`Q
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@D=&%B4W1O<%!O<VET:6]N+"`G<'0G*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-E;&PM
M=VED=&@B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)W:61T:"(@("`@<V5L96-T/2)N=6UB97(H<W5B<W1R:6YG+6)E9F]R
M92@D=&%B4W1O<%!O<VET:6]N+"=P="<I*2(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)U;FET(B`@("`@<V5L96-T/2(G
M<'0G(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!O<VET:6]N(B!S96QE8W0](B1P;W-I=&EO;B`M(#$B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5&%B4W1O
M<%-T>6QE<R(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP
M;&%T93X*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T92UC96QL+7=I
M9'1H(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G=I9'1H(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)U;FET(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)P;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M86QL5&%B4W1O<%-T>6QE<R(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1P;W-I=&EO;B`^(#$B/@H@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC
M96QL+7=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB=VED=&@B("`@('-E;&5C=#TB)'=I9'1H("T@;G5M8F5R*'-U
M8G-T<FEN9RUB969O<F4H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T
M;W!;)'!O<VET:6]N72]`<W1Y;&4Z<&]S:71I;VXL)'5N:70I*2(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)U;FET(B`@
M("`@<V5L96-T/2(D=6YI="(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@
M+2`Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL
M97,B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D<&]S:71I;VX@/2`Q(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;VYC870H)'=I9'1H("T@;G5M8F5R*'-U8G-T<FEN
M9RUB969O<F4H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W!;)'!O
M<VET:6]N72]`<W1Y;&4Z<&]S:71I;VXL)'5N:70I*2P@)'5N:70I(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O
M;F-A="@D=VED=&@L("1U;FET*2(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H\+WAS;#IS='EL97-H965T/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O;V]O+W1A8FQE7W)O=W,N>'-L````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W
M-3(U`#$P-3$U-#,Q,#8Q`#`R,S<P,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@
M=&AI<R!F:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T
M97)M<R!O9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*
M("`@("`@("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E
M(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R
M9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y
M<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE
M<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG
M:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@
M06YT;VYI;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H
M:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I
M8G5T92!I="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O
M9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E
M<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@
M1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I
M;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE4
M2$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W
M87)R86YT>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@
M02!005)424-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@
M1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@
M66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE
M<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI
M<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E
M"B`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@
M,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@
M26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ
M"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B
M:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@
M3&EC96YS92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@
M;F]T('5S92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET
M:"!T:&4@3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@
M("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS
M92YH=&UL+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E
M;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/
M550@5T%24D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-
M4$Q)140L($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)2
M04Y42453(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*
M("`@34520TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T
M:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@
M86YD"B`@(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*
M("`@5&AE($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E
M(&ES.B!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@
M,C`P,B!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S
M(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E
M="!V97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@
M("`@("`@('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O;V9F:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*
M("`@("`@("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@
M("`@("`@("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO
M1F]R;6%T(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W
M=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN
M=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*
M("`@("`@("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O
M,C`P,"]S=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X
M;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O
M,3DY."]-871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@
M("`@("!X;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+W-C<FEP="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*
M("`@("`@("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@
M("`@("`@("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S
M+S$N,2\B"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@
M("`@("`@("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z
M+R]W=W<N:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y
M<W1E;3TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG
M+E-Y<W1E;2(*("`@("`@("`@("`@("`@('AM;&YS.GAA;&%N/2)H='1P.B\O
M>&UL+F%P86-H92YO<F<O>&%L86XB"B`@("`@("`@("`@("`@("!X;6QN<SIJ
M879A/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>'-L="]J879A(@H@("`@("`@
M("`@("`@("`@97AC;'5D92UR97-U;'0M<')E9FEX97,](FIA=F$B/@H*"@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!W<FET92`H97AP;&EC:70I(')E
M<&5A=&EN9R!T86)L92!R;W=S("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB<F5P96%T+7=R:71E+7)O=R(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B
M+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FYU;6)E<BUR;W=S+7)E<&5A
M=&5D(B!S96QE8W0](C$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FUA
M>%)O=TQE;F=T:"(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/"$M+2!W<FET92!A;B!E;G1R>2!O9B!A(')O=R!A;F0@<F5P96%T(&-A
M;&QI;F<@=&AI<R!M971H;V0@=6YT:6P@86QL(&5L96UE;G1S(&%R92!W<FET
M=&5N(&]U="`M+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1N=6UB
M97(M<F]W<RUR97!E871E9"`^(#$@86YD("AT86)L93IT86)L92UC96QL+W1E
M>'0H*2!O<B!T86)L93IT86)L92UC96QL+RHI(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UR;W<B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T
M/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H*("`@("`@("`@("`@("`@(#PA+2T@,D1/.B!T86ME('9A
M<FEA8FQE(&9R;VT@=&AE(&]U='!U="!O9B!R97!E871E9"!W<FET92UR;W<@
M86YD(&ET97)A=&4@9VEV:6YG(&]U="!T:&4@=F%R:6%B;&4@+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<F5P96%T+7=R
M:71E+7)O=R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S
M96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@
M("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R+7)O=W,M
M<F5P96%T960B("`@("!S96QE8W0](B1N=6UB97(M<F]W<RUR97!E871E9"`M
M(#$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#PA+2T@=W)I=&4@
M82!S:6YG;&4@96YT<GD@;V8@82!R;W<@+2T^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=R:71E+7)O=R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R
M:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W
M3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M=W)I=&4M<F]W(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O
M;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M;6%X4F]W3&5N9W1H(B\^"@H*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M='(B/@H@("`@("`@("`@("`\(2TM('=R:71I;F<@=&AE('-T>6QE(&]F('1H
M92!R;W<@+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2=A9&0M<W1Y;&4M<')O<&5R=&EE<R<^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H*("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$
M96)U9TUO9&4B/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/@HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ)W1R)R!E;&5M96YT(&AA<R!B965N(&%D
M9&5D(3PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@
M("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2)T86)L93IT
M86)L92UC96QL(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0]
M(B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@
M('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`\+WAS;#IA
M<'!L>2UT96UP;&%T97,^"@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@2$5,4$52.B!T86)L92!S='EL
M97,@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB861D+7-T>6QE+7!R
M;W!E<G1I97,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L
M=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)N
M;V1E+7!O<VET:6]N(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%
M041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-L87-S(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB=')A;G-L871E*$!T
M86)L93IS='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9
M("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U
M=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL
M<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2]`=&%B;&4Z<W1Y;&4M;F%M95TB
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"CPO>'-L.G-T>6QE<VAE970^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]S='EL95]I;FQI;F5D+GAS
M;``````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`U-C,R,P`Q,#4Q-30S,3`V,0`P,C0T,#,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/"$M+0H*
M("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B
M;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F('1H92!F
M;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S97(@1V5N
M97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@("`@+2!3
M=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@
M,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L(#(P,#`*
M"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N
M(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M
M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#
M02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R
M93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I
M="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y
M('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES(&QI8G)A
M<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E
M('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T
M(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!3E1!0DE,
M2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E
M('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R
M(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A
M(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC
M96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T
M;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!4
M96UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M
M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@
M3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O
M9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3
M=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B
M3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P
M="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T
M86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O=W=W+F]P
M96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I
M9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A;B`B05,@
M25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%
M251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@(%=)5$A/
M550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T945T%212!)
M4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4($9/4B!!
M(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E
M92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO;G,@9V]V
M97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N
M:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L;W!E<B!O
M9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M<RP@26YC
M+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@
M26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R:6)U=&]R
M*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*
M"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4
M<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@("`@("`@
M('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL
M92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIT86)L
M93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@
M("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W
M=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@("`@('AM
M;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIS=F<]
M(FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I
M8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS.FUA=&@]
M(FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@("`@("`@
M("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@("`@("!O
M9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z=F5R
M<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P
M=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T82(*("`@
M("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z:&5L<#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@("`@("`@
M("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@
M("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L87)K+F-O
M;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@("`@("!X
M;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N;W)G
M+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT+7!R
M969I>&5S/2)J879A(CX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@
M:&%R9"!A='1R:6)U=&5D("AI;FQI;F5D*2!P<F]P97)T:65S("`J*BH@+2T^
M"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/"$M+2!215-44DE#5$E/3E,Z"B`@("`@
M("`@("`@(#$I("!!<R!T:&4@<W1Y;&5S+6YO9&4M=F%R:6%B;&5S(&%R92!.
M3U0@9VQO8F%L+"!T:&4@<W1Y;&4@=F%R:6%B;&5S(&%R92!N;W0@9VQO8F%L
M+"!E:71H97(A(0H@("`@("`@("`@("`R*2`@07,@82!L:7-T(&]F(&5L96UE
M;G1S(&-A;B!O;FQY(&)E(&%D9&5D('1O(&$@=F%R:6%B;&4@87,@82!R97-U
M;'0@=')E92!F<F%G;65N="!T:&4*("`@("`@("`@("`@("`@(&5X=&5N<VEO
M;B!I<R!N96-C97-S87)Y(2$*("`@("TM/@H*("`@(#PA+2T@,D1/.B!);FQI
M;F4@<W1Y;&5S(&1O(&YO="!I;FAE<FET(&9R;VT@6$U,(&]F9FEC92!D969A
M=6QT<R!N;W(@9F]N=#IF86UI;'D@9&5F875L=',@87,@=&AE('-T>6QE(&AE
M861E<B!D;V5S"B`@("`@("`@("`@("`@*&-P+B!S='EL97-H965T("=S='EL
M95]H96%D97(N>'-L)R!A;F0@=&AE("=W<FET92UD969A=6QT+7-T>6QE<R<@
M=&5M<&QA=&4I("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG8W)E871E
M+6%L;"UI;FQI;F4M<W1Y;&5S)SX*"B`@("`@("`@/"$M+2HJ('1R879E<G-E
M92!A;&P@<W1Y;&4@=')E97,@86YD('1H96ER(&)R86YC:&5S(&-O;&QE8W1I
M;F<@<W1Y;&4@<')O<&5R=&EE<R`J*BTM/@H@("`@("`@(#QX<VPZ96QE;65N
M="!N86UE/2)A;&QS='EL97,B/@H@("`@("`@(#PA+2TJ*B!T<F%V97)S964@
M86QL(&]F9FEC93IS='EL97,@=')E97,@8F5G:6YN:6YG('=I=&@@=&AE('1O
M<"UL979E;"!S='EL97,J*BTM/@H@("`@("`@("`@("`\>'-L.F9O<BUE86-H
M('-E;&5C=#TB)&]F9FEC93IS='EL97,O<W1Y;&4Z<W1Y;&5;;F]T*$!S='EL
M93IP87)E;G0M<W1Y;&4M;F%M92E=(CX*"B`@("`@("`@("`@("`@("`\(2TM
M*BH@9VEV92!O=70@=&AE('-T>6QE('!R;W!E<G1I97,@;V8@=&AE('!A<F5N
M="!N;V1E("HJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TG=W)I=&4M8W5R<F5N="UA;F0M:6YH97)I=&5D+7-T>6QE+7!R
M;W!E<G1I97,G/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)S='EL97,M;F]D92(@("`@("`@("`@("`@("`@("!S96QE8W0]
M(B1O9F9I8V4Z<W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(@("`@("`@("`@("`@("`@
M('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(@
M("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I
M+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"@H@("`@("`@("`@("`@("`@/"$M+2HJ(&%L;"!O9F9I8V4Z<W1Y;&5S
M(&-H:6QD<F5N(&]F('1H92!C=7)R96YT('1O<"UL979E;"!O9F9I8V4Z<W1Y
M;&5S("HJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TG9F]R+6%L;"UT96UP;&%T97,M8VAI;&0M<W1Y;&5S)SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y
M;&5.86UE(B`@("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E
M;G13='EL949A;6EL>2(@("`@("`@("`@("!S96QE8W0](D!S='EL93IF86UI
M;'DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N
M<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@("`@("`@("`@("`@
M(#PA+2TJ*B!A;&P@;V9F:6-E.F%U=&]M871I8RUS='EL97,@8VAI;&1R96X@
M;V8@=&AE(&-U<G)E;G0@=&]P+6QE=F5L('-T>6QE("HJ+2T^"B`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG9F]R+6%L;"UA=71O
M;6%T:6,M8VAI;&0M<W1Y;&5S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE(B`@("`@("`@("`@
M("`@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(@("`@
M("`@("`@("!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME
M;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L
M("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*"B`@("`@
M("`@/"$M+2HJ('1R879E<G-E92!A;&P@;V9F:6-E.F%U=&]M871I8RUS='EL
M97,@=')E97,@8F5G:6YN:6YG('=I=&@@=&AE('1O<"UL979E;"!S='EL97,@
M*BHM+3X*("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I
M8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95MN;W0H0'-T>6QE.G!A
M<F5N="US='EL92UN86UE*5TB/@H@("`@("`@("`@("`@("`@/"$M+2HJ(&=I
M=F4@;W5T('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!P87)E;G0@;F]D
M92`J*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64])W=R:71E+6-U<G)E;G0M86YD+6EN:&5R:71E9"US='EL92UP<F]P97)T
M:65S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L96-T/2(D;V9F
M:6-E.F%U=&]M871I8RUS='EL97,B+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B`@("`@("`@("`@
M("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI
M>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE+"`G
M+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM*BH@86QL(&-H:6QD<F5N
M(&]F('1H92!T;W`M;&5V96P@;V9F:6-E.F%U=&]M871I8RUS='EL97-S("`J
M*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M)V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M
M92(@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y
M;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E
M*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2=F;W(M86QL+71E;7!L
M871E<RUC:&EL9"US='EL97,G/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M<&%R96YT4W1Y;&5.86UE(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M87)E;G13='EL949A;6EL>2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M<W1Y;&4M;F%M92UT;VME;FEZ960B+SX*"B`@("`@("`@/'AS;#IF;W(M96%C
M:"!S96QE8W0](BXN+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])'!A<F5N
M=%-T>6QE1F%M:6QY(&%N9"!`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64])'!A
M<F5N=%-T>6QE3F%M95TB/@H@("`@("`@("`@("`\(2TM*BH@9VEV92!O=70@
M=&AE('-T>6QE('!R;W!E<G1I97,@;V8@=&AE(&-U<G)E;G0@;F]D92`J*BTM
M/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1S='EL92UN86UE
M+71O:V5N:7IE9'TB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64])W=R:71E+6-U<G)E;G0M86YD+6EN:&5R:71E9"US='EL92UP
M<F]P97)T:65S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L96-T
M/2(D;V9F:6-E.G-T>6QE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)S='EL92UF86UI;'DB("`@("`@("`@("`@("`@
M("!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B
M("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H
M*2]<)RP@)R<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@("`@
M/"$M+2HJ(&9O<B!A;&P@=&5M<&QA=&4M8VAI;&1R96X@;V8@=&AE(&-U<G)E
M;G0@;V9F:6-E.G-T>6QE<R`@*BHM+3X*("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64])V9O<BUA;&PM=&5M<&QA=&5S+6-H:6QD+7-T>6QE
M<R<^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y
M;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L96-T/2(D;V9F:6-E.G-T
M>6QE<R(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE
M.FYA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P87)E;G13='EL949A;6EL>2(@("`@("`@("`@("!S96QE8W0](D!S='EL
M93IF86UI;'DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE8W0](G1R
M86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@(#PA+2TJ
M*B!F;W(@86QL(&%U=&]M871I8RUC:&EL9')E;B!O9B!T:&4@8W5R<F5N="!O
M9F9I8V4Z<W1Y;&5S("`J*BTM/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TG9F]R+6%L;"UA=71O;6%T:6,M8VAI;&0M<W1Y;&5S)SX*
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL97,M
M;F]D92(@("`@("`@("`@("`@("`@("!S96QE8W0](B1O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE<R(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@("`@('-E;&5C=#TB
M0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)P87)E;G13='EL949A;6EL>2(@("`@("`@("`@("!S96QE8W0]
M(D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE
M8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@/"]X
M<VPZ9F]R+65A8V@^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TG9F]R+6%L;"UA=71O;6%T:6,M8VAI;&0M<W1Y;&5S
M)SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B+SX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M:6QY(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(O
M/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IA=71O
M;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])'!A<F5N
M=%-T>6QE1F%M:6QY(&%N9"!`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64])'!A
M<F5N=%-T>6QE3F%M95TB/@H@("`@("`@("`@("`\(2TM*BH@9VEV92!O=70@
M=&AE('-T>6QE('!R;W!E<G1I97,@;V8@=&AE(&-U<G)E;G0@;F]D92`J*BTM
M/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1S='EL92UN86UE
M+71O:V5N:7IE9'TB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64])W=R:71E+6-U<G)E;G0M86YD+6EN:&5R:71E9"US='EL92UP
M<F]P97)T:65S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L96-T
M/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B`@("`@
M("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M
M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN
M86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@
M("`@("`@("`@(#PA+2TJ*B!F;W(@86QL(&%U=&]M871I8RUC:&EL9')E;B!O
M9B!T:&4@8W5R<F5N="!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R`@*BHM+3X*
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V9O<BUA;&PM
M875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@
M("`@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,B+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA
M;64B("`@("`@("`@("`@("!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&
M86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M
M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE
M.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2=W<FET92UC
M=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O<&5R=&EE<R<^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)S='EL92UF86UI;'DB+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(O/@H*("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB>R1S='EL92UN86UE+71O:V5N:7IE9'TB/@H@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E;G0M<W1Y;&4M
M;F%M92(@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](G!A<F5N="US='EL92UN86UE(B!S96QE8W0](D!S
M='EL93IP87)E;G0M<W1Y;&4M;F%M92(O/@H*("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)N97<M<')O<&5R='DM;&ES="(^"B`@("`@("`@("`@
M("`@("`\(2TM*BHJ($-/3$Q%0U0@4U193$4@05144DE"551%4R`H;VYL>2!T
M;W!L979E;"D@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&4M<')O<&5R=&EE<R(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE071T<FEB
M=71E4&%T:"(@("!S96QE8W0](B1S='EL97,M;F]D92]S='EL93IS='EL95M`
M<W1Y;&4Z9F%M:6QY/21S='EL92UF86UI;'D@86YD($!S='EL93IN86UE/21C
M=7)R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,O0"HB+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@(#PA+2TJ*BH@0$5N9#H@1TE612!/550@06QL($-/3$Q%
M0U1%1"!35%E,12!!5%1224)55$53("AO;FQY('1O<&QE=F5L*2`J*BHM+3X*
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=')I;F<M;&5N9W1H
M*"1P87)E;G0M<W1Y;&4M;F%M92D],"(^"B`@("`@("`@("`@("`@("`\(2TM
M*BH@:68@;F\@<W1Y;&5087)E;G0@:7,@9VEV96XL('1H92!P<F]P97)T:65S
M(&%R92!G:79E;B!O=70@870@;VYC92`J*BTM/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N;W)M86QI>F4M<W!A8V4H)&YE
M=RUP<F]P97)T>2UL:7-T*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6YA
M;65S(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S
M96QE8W0](B1S='EL97,M;F]D92]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY
M/21S='EL92UF86UI;'D@86YD($!S='EL93IN86UE/21C=7)R96YT+7-T>6QE
M+6YA;65=+W-T>6QE.G!R;W!E<G1I97,O0"HB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYA;64H*2(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@
M("`@("`\(2TM*BH@9G5R=&AE<B!A='1R:6)U=&5S(&]F('1H92!P87)E;G0@
M<W1Y;&4@;75S="!B92!C;VQL96-T960@*BHM+3X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D+7!A<F5N="US='EL
M92UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@("`@<V5L
M96-T/2(D;F5W+7!R;W!E<G1Y+6YA;65S(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VUP;&5T92UP<F]P97)T
M>2UL:7-T(B`@('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"1N97<M<')O<&5R
M='DM;&ES="DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(@("`@("`@<V5L96-T
M/2(D8W5R<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@
M("`@("`@('-E;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UF
M86UI;'DB("`@("`@("`@("`@('-E;&5C=#TB)'-T>6QE+69A;6EL>2(O/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F%D9"UP87)E;G0M
M<W1Y;&4M871T<FEB=71E<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;7!L971E+7!R;W!E<G1Y+6QI<W0B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G-T>6QE+69A;6EL>2(O/@H*("`@("`@("`\(2TM*BHJ($YE
M=R!T=V\@8F4@861D960@<')O<&5R='D@;F%M97,@=VEL;"!B92!C;VQL96-T
M960@*&]N;'D@;VYE('9A<FEA8FQE('!E<B!T96UP;&%T92D@*BHJ+2T^"B`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97<M<')O<&5R='DM;F%M97,B
M/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YE
M=RUS='EL92UN86UE<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<')O<&5R='DM;F%M92UL:7-T(B`@("`@("!S96QE8W0](B1P
M<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@("`@("`@('-E;&5C
M=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N="US='EL92UN86UE(B`@("`@("!S
M96QE8W0](B1C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#IV87)I86)L93X*"B`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2TJ*BH@8VAE8VL@
M:68@=&AE(&YE=R!P87)E;G0@<W1Y;&4@97AI<W0@:6X@=&AE(&]F9FEC93IA
M=71O;6%T:6,M<W1Y;&5S('-E8W1I;VX@*&1E9FEN960@8GD@;F%M92!A;F0@
M9F%M:6QY*2`J*BHM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O
M9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M
M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M93TD8W5R<F5N="US='EL
M92UN86UE72(^"B`@("`@("`@("`@("`@("`\(2TM*BHJ(%)%0U524TE/3CH@
M861D:6YG(&YE=R!P87)E;G0@<W1Y;&4@871T<FEB=71E<R!T;R!T:&4@8W5R
M<F5N="!S='EL92`J*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6%T=')I8G5T97,B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M;F5W+7-T
M>6QE+6%T=')I8G5T97,B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;65S(B`@("`@("`@
M("`@<V5L96-T/2(D;F5W+7!R;W!E<G1Y+6YA;65S(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT+7-T
M>6QE+6YA;64B("`@("`@("`@("!S96QE8W0](B1C=7)R96YT+7-T>6QE+6YA
M;64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G!A<F5N="US='EL92UN86UE(B`@("`@("`@("`@('-E;&5C=#TB
M)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA
M8FQE/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!%;F0@0T].1$E424]..B!T
M:&4@;&%S="!S='EL92!P87)E;G0@:&%S(&%L<F5A9'D@8F5E;B!E>&5C=71E
M9"`J*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M;F5W+7!A<F5N="US='EL92UN86UE(B`@<V5L96-T/2(D;V9F:6-E.F%U=&]M
M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R
M87!H)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN86UE72]`<W1Y
M;&4Z<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S
M=')I;F<M;&5N9W1H*"1N97<M<&%R96YT+7-T>6QE+6YA;64I/3`B/@H@("`@
M("`@("`@("`@("`@("`@(#PA+2TJ*B!N;R!F=7)T:&5R('!A<F5N="!I<R!F
M;W5N9"P@=&AE(&=I=F5N('!A<F%M971E<B!P<F]P97)T>2UN;V1E(&ES('1H
M92!F:6YA;"!S='EL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D8V]M<&QE=&4M<')O<&5R='DM
M;&ES="PD;F5W+7!R;W!E<G1Y+6%T=')I8G5T97,I(B\^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\(2TM*BH@9G5R=&AE
M<B!A='1R:6)U=&5S(&]F('1H92!P87)E;G0@<W1Y;&4@;75S="!B92!C;VQL
M96-T960@*BHM+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F%D9"UP87)E;G0M<W1Y;&4M871T<FEB=71E<R(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<')O<&5R='DM;F%M92UL:7-T(B`@("`@("!S96QE8W0](F-O;F-A
M="@D<')O<&5R='DM;F%M92UL:7-T+"`D;F5W+7!R;W!E<G1Y+6YA;65S*2(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;7!L971E+7!R;W!E<G1Y+6QI<W0B("`@<V5L96-T/2)C;VYC
M870H)&-O;7!L971E+7!R;W!E<G1Y+6QI<W0L)&YE=RUP<F]P97)T>2UA='1R
M:6)U=&5S*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(@("`@("`@<V5L
M96-T/2(D<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M
M;F%M92(@("`@("`@('-E;&5C=#TB)&YE=RUP87)E;G0M<W1Y;&4M;F%M92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G-T>6QE+69A;6EL>2(@("`@("`@("`@("`@<V5L96-T/2(D<W1Y
M;&4M9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2HJ('1H92!S<&5C:69I
M8R!S='EL92`H9&5F:6YE9"!B>2!N86UE(&%N9"!F86UI;'DI(&UU<W0@8F4@
M9F]U;F0@:6X@=&AE(&]F9FEC93IS='EL97,@<V5C=&EO;B`M+3X*("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM*BHJ
M(%)%0U524TE/3CH@861D:6YG(&YE=R!P87)E;G0@<W1Y;&4@871T<FEB=71E
M<R!T;R!T:&4@8W5R<F5N="!S='EL92`J*BHM+3X*("`@("`@("`@("`@("`@
M(#PA+2TJ*BH@861D:6YG(&YE=R!P87)E;G0@<W1Y;&4@871T<FEB=71E<R!T
M;R!T:&4@8W5R<F5N="!S='EL92`J*BHM+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6%T=')I8G5T97,B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G
M970M;F5W+7-T>6QE+6%T=')I8G5T97,B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;65S
M(B`@("`@("`@("`@<V5L96-T/2(D;F5W+7!R;W!E<G1Y+6YA;65S(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M=7)R96YT+7-T>6QE+6YA;64B("`@("`@("`@("!S96QE8W0](B1C=7)R96YT
M+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G!A<F5N="US='EL92UN86UE(B`@("`@("`@("`@
M('-E;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO
M>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!%;F0@0T].
M1$E424]..B!T:&4@;&%S="!S='EL92!P87)E;G0@:&%S(&%L<F5A9'D@8F5E
M;B!E>&5C=71E9"`J*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB;F5W+7!A<F5N="US='EL92UN86UE(B`@<V5L96-T/2(D;V9F
M:6-E.G-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A
M<&@G(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T>6QE+6YA;65=+T!S='EL
M93IP87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](G-T
M<FEN9RUL96YG=&@H)&YE=RUP87)E;G0M<W1Y;&4M;F%M92D],"(^"B`@("`@
M("`@("`@("`@("`@("`@/"$M+2HJ(&YO(&9U<G1H97(@<&%R96YT(&ES(&9O
M=6YD+"!T:&4@9VEV96X@<&%R86UE=&5R('!R;W!E<G1Y+6YO9&4@:7,@=&AE
M(&9I;F%L('-T>6QE("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1C;VUP;&5T92UP<F]P97)T>2UL
M:7-T+"1N97<M<')O<&5R='DM871T<FEB=71E<RDB+SX*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PA+2TJ*B!F=7)T:&5R
M(&%T=')I8G5T97,@;V8@=&AE('!A<F5N="!S='EL92!M=7-T(&)E(&-O;&QE
M8W1E9"`J*B`@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)A9&0M<&%R96YT+7-T>6QE+6%T=')I8G5T97,B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@("`@<V5L96-T/2)C;VYC
M870H)'!R;W!E<G1Y+6YA;64M;&ES="P@)&YE=RUP<F]P97)T>2UN86UE<RDB
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VUP;&5T92UP<F]P97)T>2UL:7-T(B`@('-E;&5C=#TB8V]N
M8V%T*"1C;VUP;&5T92UP<F]P97)T>2UL:7-T+"1N97<M<')O<&5R='DM871T
M<FEB=71E<RDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B("`@("`@('-E
M;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT+7-T>6QE
M+6YA;64B("`@("`@("!S96QE8W0](B1N97<M<&%R96YT+7-T>6QE+6YA;64B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)S='EL92UF86UI;'DB("`@("`@("`@("`@('-E;&5C=#TB)'-T
M>6QE+69A;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G
M970M;F5W+7-T>6QE+6YA;65S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(G!R;W!E<G1Y+6YA;64M;&ES="(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@(#PA+2TJ*B!W:&5R
M92!T;R!F:6YD('1H92!S<&5C:69I8R!S='EL92`H9&5F:6YE9"!B>2!N86UE
M(&%N9"!F86UI;'DI('=H971E<B!I;B!O9F9I8V4Z875T;VUA=&EC+7-T>6QE
M<R!O<B!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#PA+2TJ*B!I9B!T:&4@<W!E8VEF:6,@<W1Y
M;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M:6QY*2!C86X@8F4@9F]U;F0@
M:6X@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S('-E8W1I;VX@+2T^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;V9F:6-E.F%U=&]M871I8RUS
M='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A
M;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN86UE72(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A<F5N="UP<F]P97)T>2UN
M;V1E(B!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS
M='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M
M93TD<&%R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,B+SX*"B`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T
M>2UN86UE+6QI<W0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A
M8V@@<V5L96-T/2(D<&%R96YT+7!R;W!E<G1Y+6YO9&4O0"I;;F]T*&-O;G1A
M:6YS*"1P<F]P97)T>2UN86UE+6QI<W0L(&YA;64H*2DI72(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N86UE*"DB
M+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@
M("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1N97<M<')O<&5R='DM;F%M92UL:7-T(B\^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#PA+2TJ*B!T
M:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M:6QY
M*2!S:&]U;&0@8F4@9F]U;F0@:6X@=&AE(&]F9FEC93IS='EL97,@<V5C=&EO
M;B`M+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A<F5N="UP<F]P97)T>2UN;V1E
M(B!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF
M86UI;'D])W!A<F%G<F%P:"<@86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y
M;&4M;F%M95TO<W1Y;&4Z<')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)N97<M<')O<&5R='DM;F%M92UL:7-T(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)'!A
M<F5N="UP<F]P97)T>2UN;V1E+T`J6VYO="AC;VYT86EN<R@D<')O<&5R='DM
M;F%M92UL:7-T+"!N86UE*"DI*5TB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F%M92@I(B\^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@("`@("`\+WAS
M;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(O/@H@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E="UN
M97<M<W1Y;&4M871T<FEB=71E<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)N97<M<')O<&5R='DM;F%M97,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<&%R96YT+7-T>6QE+6YA;64B+SX*"B`@("`@("`@/"$M+2HJ('=H
M97)E('1O(&9I;F0@=&AE('-P96-I9FEC('-T>6QE("AD969I;F5D(&)Y(&YA
M;64@86YD(&9A;6EL>2D@=VAE=&AE<B!I;B!O9F9I8V4Z875T;VUA=&EC+7-T
M>6QE<R!O<B!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2TJ*B!I9B!T:&4@<W!E8VEF:6,@
M<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M:6QY*2!C86X@8F4@9F]U
M;F0@:6X@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S('-E8W1I;VX@+2T^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;V9F:6-E.F%U=&]M871I
M8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H
M)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN86UE72(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A<F5N="UP<F]P97)T
M>2UN;V1E(B!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL
M93IS='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z
M;F%M93TD<&%R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,B+SX*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E
M<G1Y+6YA;64M;&ES="(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+7!R;W!E<G1I97,B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y
M;&5!='1R:6)U=&50871H(B`@('-E;&5C=#TB)'!A<F5N="UP<F]P97)T>2UN
M;V1E+T`J6V-O;G1A:6YS*"1N97<M<')O<&5R='DM;F%M97,L(&YA;64H*2E=
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYO<FUA;&EZ92US<&%C92@D;F5W
M+7!R;W!E<G1Y+6YA;64M;&ES="DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/"$M+2HJ(&]T:&5R=VES92!T:&4@<W!E8VEF:6,@
M<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M:6QY*2!S:&]U;&0@8F4@
M9F]U;F0@:6X@=&AE(&]F9FEC93IS='EL97,@<V5C=&EO;B`M+3X*("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](G!A<F5N="UP<F]P97)T>2UN;V1E(B!S96QE8W0](B1O
M9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G
M<F%P:"<@86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M95TO<W1Y
M;&4Z<')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)N97<M<')O<&5R='DM;F%M92UL:7-T(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&4M
M<')O<&5R=&EE<R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)S='EL94%T=')I8G5T95!A=&@B("`@<V5L96-T/2(D
M<&%R96YT+7!R;W!E<G1Y+6YO9&4O0"I;8V]N=&%I;G,H)&YE=RUP<F]P97)T
M>2UN86UE<RP@;F%M92@I*5TB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B
M;&4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F]R
M;6%L:7IE+7-P86-E*"1N97<M<')O<&5R='DM;F%M92UL:7-T*2(O/@H@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]T86)L95]C;VQU
M;6YS+GAS;``````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-#8T-0`Q,#4Q-30S,3`V,0`P,C0S
M-S(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A
M=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F
M('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@
M("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E
M<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L
M(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!6
M97)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O
M<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!
M;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S
M;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO
M9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N
M97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES
M:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES
M(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W
M:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W
M:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!
M3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N
M<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E
M:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*
M("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W
M<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N
M+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@
M,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3
M;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT
M96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U
M<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@
M*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@
M(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M
M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O
M=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E
M('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A
M;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+
M24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@
M(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T94
M5T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4
M($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N
M"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO
M;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C
M;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L
M;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M
M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES
M=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R
M:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY
M+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@
M("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN
M<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@
M("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@
M("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN
M<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS
M.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@
M("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@
M("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I
M8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT
M='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T
M82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@
M("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B
M"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L
M87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@
M("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C
M:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S
M=6QT+7!R969I>&5S/2)J879A(CX*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@
M*BHJ($-R96%T92!T86)L92!C;VQU;6YS('-T>6QE('9A<FEA8FQE("`J*BH@
M+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB861D
M:6YG+6-O;'5M;BUS='EL97,M96YT<FEE<R(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)A;&Q486)L94-O;'5M;G,B+SX*"B`@("`@("`@/'AS;#IF
M;W(M96%C:"!S96QE8W0](B1A;&Q486)L94-O;'5M;G,B/@H*("`@("`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)C;VQU;6XM<W1Y;&4M96YT<GDB('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL<W1Y;&5S+RI;;F%M92@I
M(#T@=')A;G-L871E*&-U<G)E;G0H*2]`=&%B;&4Z<W1Y;&4M;F%M92P@)RX@
M)2@I+UPG+"`G)RE=(B\^"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="A`=&%B;&4Z;G5M8F5R
M+6-O;'5M;G,M<F5P96%T960I(CX*("`@("`@("`@("`@("`@("`@("`\(2TM
M('=R:71E<R!A;B!E;G1R>2!O9B!A(&-O;'5M;B!I;B!T:&4@8V]L=6UN<RUV
M87)I86)L92`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB861D:6YG+6-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU
M;6XM<W1Y;&4M96YT<GDB('-E;&5C=#TB)&-O;'5M;BUS='EL92UE;G1R>2(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M
M+2!.;R!H:6=H97(@<F5P971I=&EO;B!O9B!C96QL<R!G<F5A=&5R('1H86X@
M-"!F;W(@=&AE(&QA<W0@86YD('-E8V]N9"!L87-T(&-O;'5M;B`M+3X*("`@
M("`@("`@("`@("`@(#PA+2T@82!H86-K(&9O<B!T:&4@<V%M<&QE(&1O8W5M
M96YT("=7865H<G5N9W-U;7)E8VAN97(N<WAC(&AA=FEN9R`R,S`@<F5P96%T
M960@8V]L=6UN<R!I;B!T:&4@<V5C;VYD(&QA<W0@8V]L=6UN("TM/@H@("`@
M("`@("`@("`@("`@/"$M+2`_/S\@/'AS;#IW:&5N('1E<W0](BAP;W-I=&EO
M;B@I(#T@;&%S="@I(&]R("AP;W-I=&EO;B@I(#T@*&QA<W0H*2`M(#$I*2!A
M;F0@0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D("9L=#L@-2DB/B`_
M/S\M+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)P;W-I=&EO
M;B@I(#T@;&%S="@I(&]R('!O<VET:6]N*"D@/2`H;&%S="@I("T@,2DB/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB0'1A8FQE.FYU;6)E
M<BUC;VQU;6YS+7)E<&5A=&5D("9L=#L@-2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@=W)I=&5S(&%N(&5N=')Y(&]F(&$@8V]L=6UN(&EN('1H
M92!C;VQU;6YS+79A<FEA8FQE("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<F5P96%T+6%D9&EN9RUC;VQU
M;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUS='EL92UE;G1R>2(@("`@
M("`@<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R
M+6-O;'5M;G,M<F5P96%T960B("!S96QE8W0](C$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`\(2TM(')E<&5A=&5D(&-O;'5M<R!W:6QL(&)E('=R:71T96X@
M97AP;&EC:70@<V5V97)A;"!T:6UE<R!I;B!T:&4@=F%R:6%B;&4M+3X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<F5P
M96%T+6%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7-T>6QE
M+65N=')Y(B`@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N=')Y
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)N=6UB97(M8V]L=6UN<RUR97!E871E9"(@("`@("!S96QE8W0](D!T
M86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E9"(O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/"$M+2!74DE415,@5$A%(%)%4$5!5$5$($-/3%5-3B!35%E,12!%6%!,
M24-)5"!!4R!!3B!%3$5-14Y4($E.(%1(12!#3TQ534Y3+59!4DE!0DQ%("TM
M/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)R97!E870M861D:6YG+6-O;'5M
M;BUS='EL92UE;G1R>2(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQU
M;6XM<W1Y;&4M96YT<GDB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FYU
M;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&YU;6)E<BUC;VQU;6YS
M+7)E<&5A=&5D(#X@,2(^"B`@("`@("`@("`@("`@("`\(2TM('=R:71E<R!A
M;B!E;G1R>2!O9B!A(&-O;'5M;B!I;B!T:&4@8V]L=6UN<RUV87)I86)L92`M
M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A
M9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B`@
M('-E;&5C=#TB)&-O;'5M;BUS='EL92UE;G1R>2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PA+2T@
M<F5P96%T(&-A;&QI;F<@=&AI<R!M971H;V0@=6YT:6P@86QL(&5L96UE;G1S
M('=R:71T96X@;W5T("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G)E<&5A="UA9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L=6UN+7-T>6QE+65N=')Y(B`@("`@("!S96QE8W0](B1C;VQU;6XM<W1Y
M;&4M96YT<GDB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB;G5M8F5R+6-O;'5M;G,M<F5P96%T960B("!S96QE8W0](B1N
M=6UB97(M8V]L=6UN<RUR97!E871E9"`M(#$B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C;VQU;6X@:6X@=&AE(&-O;'5M
M;G,M=F%R:6%B;&4@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB861D:6YG+6-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUS
M='EL92UE;G1R>2(@("!S96QE8W0](B1C;VQU;6XM<W1Y;&4M96YT<GDB+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!42$4@0T],54U.+5-464Q%
M(%=2251%+5!!5%1%4DX@1D]2($5!0T@@0T],54U.(%=2251414X@24X@02!6
M05))04),12`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB861D:6YG+6-O
M;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M;VQU;6XM<W1Y;&4M96YT<GDB+SX*"B`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T86)L93IV
M:7-I8FEL:71Y(#T@)V-O;&QA<'-E)R!O<B!`=&%B;&4Z=FES:6)I;&ET>2`]
M("=F:6QT97(G(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)C;VQU;6XM:&ED9&5N+69L86<B/G1R=64\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M87)I86)L92`@;F%M93TB=&%B;&4Z<W1Y;&4M;F%M92(@("`@("`@("!S96QE
M8W0](G1R86YS;&%T92A`=&%B;&4Z<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G
M)RDB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE
M/2)S='EL92UN86UE(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1A8FQE.G-T
M>6QE+6YA;64B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VQU;6XM<W1Y;&4M96YT<GDB
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2UI<T1E8G5G36]D92U35$%25"TM
M/@H@("`@/"$M+2!G:79I;F<@;W5T('1H92`G86QL0V]L=6UN4W1Y;&4G('9A
M<FEA8FQE.@H@("`@("`@($9O<B!E86-H("=C;VQU;6XM<W1Y;&4M96YT<GDG
M(&]F('1H92`G86QL0V]L=6UN4W1Y;&5%;G1R:65S)R!V87)I86)L92!T:&4@
M<W1Y;&4M;F%M92!I<R!G:79E;B!O=70N"B`@("`@("`@26X@8V%S92!O9B`G
M8V]L=6UN+6AI9&1E;BUF;&%G)R!A='1R:6)U=&4@=&AE('1E>'0@)T-O;'5M
M;B!I<R!H:61D96X@:7,@9VEV96X@;W5T+BTM/@H@("`@/'AS;#IT96UP;&%T
M92!N86UE/2)T86)L92UD96)U9RUA;&Q#;VQU;6Y3='EL945N=')I97,B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S
M(B\^"@H@("`@("`@(#PA+2T@9&5B=6<@;W5T<'5T(&%S('1A8FQE('-U;6UA
M<GD@871T<FEB=70@:6X@:'1M;"`M+3X*("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)S=6UM87)Y(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](G1A8FQE+61E8G5G+6-O;'5M;BUO=70B/@H@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT
M<FEE<R(@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@(#PA+2T@9&5B=6<@;W5T<'5T('1O(&-O;G-O;&4@
M+2T^"B`@("`@("`@/'AS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB=&%B;&4M9&5B=6<M8V]L=6UN+6]U="(^"B`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B
M+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\
M+WAS;#IM97-S86=E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TB=&%B;&4M9&5B=6<M8V]L=6UN+6]U="(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*
M("`@("`@("`@("`@/'AS;#IT97AT/@H@("`@("`@("`@("!$96)U9TEN9F]R
M;6%T:6]N.B!&;W(@96%C:"`G8V]L=6UN+7-T>6QE+65N=')Y)R!O9B!T:&4@
M)V%L;$-O;'5M;E-T>6QE16YT<FEE<R<@=F%R:6%B;&4@=&AE('-T>6QE+6YA
M;64@:7,@9VEV96X@;W5T+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!);B!C87-E(&]F("=C;VQU;6XM:&ED9&5N+69L86<G(&%T=')I8G5T92!T
M:&4@=&5X="`G8V]L=6UN(&ES(&AI9&1E;B<@:7,@9VEV96X@;W5T+@H@("`@
M("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M
M96%C:"!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T
M>6QE+65N=')Y(CX*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!C;VQU;6XM:&ED9&5N+69L
M86<B/@H@("`@("`@("`@("`\>'-L.G1E>'0^("`\+WAS;#IT97AT/CQX<VPZ
M=F%L=64M;V8@<V5L96-T/2)`<W1Y;&4M;F%M92(O/CQX<VPZ=&5X=#YC;VQU
M;6X@:7,@:&ED9&5N/"]X<VPZ=&5X=#X\>'-L.G1E>'0^"B`@("`@("`@("`@
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#QX<VPZ
M=&5X=#X@(#PO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](D!S='EL
M92UN86UE(B\^/'AS;#IT97AT/B`](#PO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^"B`@("`@("`@("`@(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F9O<BUE86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^"B`@("`\
M(2TM:7-$96)U9TUO9&4M14Y$+2T^"@H\+WAS;#IS='EL97-H965T/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O
M;V]O+V-O;6UO;BYX<VP`````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,38W,#<S`#$P
M-3$U-#,Q,#8Q`#`R,S`S-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F
M:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M<R!O
M9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@
M("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I
M;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U
M<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@
M26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U
M8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P
M,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI
M;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB
M<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I
M="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@
M1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@
M,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A
M=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@
M:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!
M3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT
M>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)4
M24-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N97)A
M;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H
M;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R
M87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O
M=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!"
M;W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T
M<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T
M;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS
M92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S
M92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@
M3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E
M;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL
M+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES
M('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%2
M4D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L
M($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)204Y42453
M(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@3452
M0TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.
M3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E
M8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@
M(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE
M($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3
M=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B
M>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R
M=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S
M:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W
M=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@
M('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F
M:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@
M("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@
M("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N
M;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB97(]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@
M("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S
M=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID
M<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-
M871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X
M;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP
M="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@
M("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@
M("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B
M"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@
M("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N
M:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@(&5X=&5N<VEO;BUE;&5M
M96YT+7!R969I>&5S/2)X="(*("`@("`@("`@("`@("`@('AM;&YS.GAA;&%N
M/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>&%L86XB"B`@("`@("`@("`@("`@
M("!X;6QN<SIJ879A/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>'-L="]J879A
M(@H@("`@("`@("`@("`@("`@97AC;'5D92UR97-U;'0M<')E9FEX97,](FIA
M=F$B/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ
M*B!B;V1Y("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ("TM/@H*"B`@
M("`\>'-L.G1E;7!L871E(&UA=&-H/2(O*B]O9F9I8V4Z8F]D>2(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@
M("`@("`@(#PA+2T@:7-$96)U9TUO9&4M4U1!4E0Z(&]N;'D@:7-$96)U9TUO
M9&4@<'5R<&]S93H@<VAO=W,@=&AE(&EN;&EN960@<W1Y;&4@871T<FEB=71E
M<R!O9B!T:&4@=&5M<&]R87)Y('9A<FEA8FQE("TM/@H@("`@("`@(#QX<VPZ
M:68@=&5S=#TB)&ES1&5B=6=-;V1E(&%N9"!N;W0H)&]U='!U=%1Y<&4@/2`G
M0U-37TA%041%4B<I(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F1E8G5G7W1R965?;V9?<W1Y;&5S(CX\>'-L.G1E>'0^"B`@("`@("`@("`@
M(#PO>'-L.G1E>'0^/'AS;#IF;W(M96%C:"!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A+V%L;'-T>6QE<R\J(CX*/'AS;#IT97AT/B`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)N
M86UE*"DB+SX\>'-L.G1E>'0^(#T@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X*("`@("`@("`@("`@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\+WAS;#II9CX*("`@(#PA
M+2T@:7-$96)U9TUO9&4M14Y$("TM/@H*"@D)/"$M+2!N;W0@=7-I;F<@;V8@
M)V%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="<@87,@=&AE(&-O;G1E;G0@=&%B
M;&4@:6YF;W)M871I;VX@;6EG=&@@:&%V92!B965N(&%D9&5D('1O("=C;VQL
M96-T961';&]B86Q$871A)R!V87)I86)L92`M+3X*("`@("`@("`\>'-L.F%P
M<&QY+71E;7!L871E<R!S96QE8W0](D!T97AT.G-T>6QE+6YA;64@?"!`9')A
M=SIS='EL92UN86UE('P@0&1R87<Z=&5X="US='EL92UN86UE('P@0'1A8FQE
M.G-T>6QE+6YA;64B/CPA+2T@?"!`<')E<V5N=&%T:6]N.G-T>6QE+6YA;64@
M+2T^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*"B`@("`@("`@/"$M
M+2!5<V%B:6QI='D@9F5A='5R92P@82!L:6YK('1O('1H92!#;VYT96YT('1A
M;&)E(&%B;W9E(&%L;"!L979E;"`Q(&AE861E<B`M+3X*("`@("`@("`\>'-L
M.FEF('1E<W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R(^"B`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A9&0M8VAI;&0M9&]C=6UE;G0M
M=7-A8FEL:71Y+6QI;FMS(B\^"B`@("`@("`@/"]X<VPZ:68^"@H*"0D\>'-L
M.F-H;V]S93X*"2`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="@D;W5T<'5T
M5'EP92`]("=734PG*2!A;F0@;F]T*"1O=71P=714>7!E(#T@)U!!3$TG*2(^
M"@D@("`@("`@(`D\>'-L.F-H;V]S93X*"0D)("`@("`@("`\(2TM268@=&AE
M(&EN<'5T(&1O8W5M96YT(&ES(&$@9VQO8F%L(&1O8W5M96YT(&%N9"!E;6)E
M9"!C:&EL9"!D;V-U;65N=',@*&QI;FMS*2!T:&4@=')A;G-F;W)M871I;VX@
M;V8@=&AE(&-H:6QD<F5N('=I;&P@8F4@<W1A<G1E9"!A<R!W96QL+@H)"0D@
M("`@("`@("`@("!4:&ES(&ES(&YE8V5S<V%R>2!A<R!C:&EL9"!D;V-U;65N
M=',@9&\@;F]T(&MN;W<@86YY=&AI;F<@86)O=70@=&AE:7(@96UB961D:6YG
M(&EN=&\@82!G;&]B86P@9&]C=6UE;G0N($-H87!T97)S(&]F(&-H:6QD<PH)
M"0D@("`@("`@("`@("!A;'=A>7,@<W1A<G0@=&\@8V]U;G0@8GD@>F5R;R!I
M;G-T96%D(&]F(&-O;G1I;F]U<VQY(&YU;6)E<FEN9RX*"0D)("`@("`@("`@
M("`@1F]R('1H:7,L('1H92!C:&%P=&5R(&YU;6)E<G,@;V8@=&AE(&-U<G)E
M;G0@9&]C=6UE;G0@*&%S(&$@<V5Q=65N8V4@;V8@82!G;&]B86P@9&]C=6UE
M;G0I(&ES(&1E<&5N9&5N=`H)"0D@("`@("`@("`@("!O9B!T:&4@;G5M8F5R
M(&]F(&-H87!T97(@;V8@=&AE('-A;64@;&5V96P@:6X@<')E8V5D:6YG(&1O
M8W5M96YT<RX*"0D)("`@("`@("`@("`@26X@8V%S92!O9B!M=6QT:7!L92!C
M:&EL9')E;BP@9F]R('5S86)I;&ET>2!R96%S;VYS('-O;64@;&EN:VEN9R!I
M<R!G;VYN82!B92!O9F9E<F5D(&%N9"!T:&4@55),<R!O9B!T:&4@8V]N=&5N
M="UT86)L92P*"0D)("`@("`@("`@("`@<')E8V5D:6YG(&%N9"!F;VQL;W=I
M;F<@9FEL92!H879E('1O(&)E(&=I=F5N(&9O<B!T:&4@=')A;G-F;W)M871I
M;VXN"@D)"2`@("`@("`@("`@("TM/@H)"2`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(O*B]`;V9F:6-E.F-L87-S/2=T97AT+6=L;V)A;"<@86YD("\J
M+V]F9FEC93IB;V1Y+W1E>'0Z<V5C=&EO;B]T97AT.G-E8W1I;VXM<V]U<F-E
M+T!X;&EN:SIH<F5F(CX*"0D)"0D)/"$M+2!T:&4@8VAI;&1R96X@=VEL;"!B
M92!C86QL960@;&%T97(@=VET:"!A(&UO9&EF:65D("=C;VQL96-T961';&]B
M86Q$871A)R!V87)I86)L92`M+3X*"0D@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](G1R86YS9F]R;2UG;&]B86PM9&]C=6UE;G0M
M86YD+6-H:6QD<F5N(CX*"0D@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"@D)("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"@D)("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"0D)
M"0D\>'-L.F]T:&5R=VES93X*"0D)"2`@("`@("`@/'AS;#IA<'!L>2UT96UP
M;&%T97,^"@D)"0D@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H)"0D)("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@D)
M"0D)/"]X<VPZ;W1H97)W:7-E/@H)"0D)/"]X<VPZ8VAO;W-E/@H)("`@("`@
M("`\+WAS;#IW:&5N/@H)"0D\>'-L.F]T:&5R=VES93X*"0D@("`@("`@(#QX
M<VPZ87!P;'DM=&5M<&QA=&5S/@H)"2`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"@D)("`@("`@("`\+WAS;#IA<'!L>2UT96UP
M;&%T97,^"@D)"3PO>'-L.F]T:&5R=VES93X*"0D\+WAS;#IC:&]O<V4^"@H*
M"B`@("`@("`@/"$M+2!5<V%B:6QI='D@9F5A='5R92P@82!L:6YK('1O('1H
M92!#;VYT96YT('1A;&)E(&%B;W9E(&%L;"!L979E;"`Q(&AE861E<B`M+3X*
M("`@("`@("`\>'-L.FEF('1E<W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R(^
M"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A9&0M8VAI
M;&0M9&]C=6UE;G0M=7-A8FEL:71Y+6QI;FMS(B\^"B`@("`@("`@/"]X<VPZ
M:68^"@H*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*("`@(#PA+2T@9&5A8W1I
M=F%T:6YG(&1E9F%U;'0@=&5M<&QA=&4@+2T^"B`@("`\>'-L.G1E;7!L871E
M(&UA=&-H/2(J(B\^"@H*("`@(#PA+2T@86QL;W=I;F<@86QL(&UA=&-H960@
M=&5X="!N;V1E<R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0H
M*2(^"CPA+2T@5TU,("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYO
M<FUA;&EZ92US<&%C92@N*2(O/B`M+3X*("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB+B(O/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM
M(",C(R,C(R,C(R,C(R,C(R,C(R,@+2T^"B`@("`\(2TM(",C(R!)3DQ)3D4M
M5$585"`C(R,@+2T^"B`@("`\(2TM(",C(R,C(R,C(R,C(R,C(R,C(R,@+2T^
M"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J
M*BH@5VAI=&5S<&%C92`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IS(CX*
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA
M8FQE+7=H:71E<W!A8V4B/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB=VAI=&5S<&%C97,B('-E;&5C=#TB0'1E>'0Z8R(O/@H@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/"$M+7=R:71E('1H92!N=6UB97(@;V8@)W=H:71E<W!A8V5S)R`M+3X*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E
M<W!A8V4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=VAI=&5S<&%C97,B
M+SX*"B`@("`@("`@/"$M+7=R:71E('1W;R!S<&%C92!C:&%R<R!A<R!T:&4@
M;F]R;6%L('=H:71E('-P86-E(&-H87)A8W1E<B!W:6QL(&)E('-T<FEP<&5D
M"B`@("`@("`@("`@(&%N9"!T:&4@;W1H97(@:7,@86)L92!T;R!B<F5A:R`M
M+3X*("`@("`@("`\>'-L.G1E>'0^)B,Q-C`[/"]X<VPZ=&5X=#X*("`@("`@
M("`\>'-L.FEF('1E<W0](B1W:&ET97-P86-E<R`^/2`R(CX*("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6)R96%K86)L92UW
M:&ET97-P86-E+3(B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G=H:71E<W!A8V5S(B!S96QE8W0](B1W:&ET97-P86-E<R`M(#$B
M+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\
M+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM=W)I=&4@
M=&AE(&YU;6)E<B!O9B`G=VAI=&5S<&%C97,G("TM/@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92TR(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](G=H:71E<W!A8V5S(B\^"B`@("`@("`@
M/"$M+7=R:71E('1W;R!S<&%C92!C:&%R<R!A<R!T:&4@;F]R;6%L('=H:71E
M('-P86-E(&-H87)A8W1E<B!W:6QL(&)E('-T<FEP<&5D"B`@("`@("`@("`@
M(&%N9"!T:&4@;W1H97(@:7,@86)L92!T;R!B<F5A:R`M+3X*("`@("`@("`\
M>'-L.G1E>'0^(#PO>'-L.G1E>'0^"B`@("`@("`@/'AS;#II9B!T97-T/2(D
M=VAI=&5S<&%C97,@/CT@,B(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92(^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=VAI=&5S<&%C97,B
M('-E;&5C=#TB)'=H:71E<W!A8V5S("T@,2(O/@H@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@
M("`\(2TM("HJ*B!497AT8F]X("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](F1R87<Z=&5X
M="UB;W@B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I
M($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#PA
M+2T@("`@("`@("`@("`@("`@;W(@("`@("`@("`@("`@("`@("`M+3X*("`@
M("`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!62`@
M*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T
M<'5T5'EP92`]("=#4U-?2$5!1$52)R!O<B`D;W5T<'5T5'EP92`]("=#4U-?
M24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)S<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T
M97-T/2)`9F\Z;6EN+6AE:6=H="!\($!S=F<Z=VED=&@B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB;F]T*$!S=F<Z=VED=&@I(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YH96EG:'0Z(#PO>'-L
M.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](D!F;SIM:6XM:&5I9VAT(B\^
M/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="A`9F\Z;6EN
M+6AE:6=H="DB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/G=I9'1H.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2)`<W9G.G=I9'1H(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^:&5I9VAT.B`\+WAS;#IT97AT/CQX<VPZ=F%L
M=64M;V8@<V5L96-T/2)`9F\Z;6EN+6AE:6=H="(O/CQX<VPZ=&5X=#X[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^=VED=&@Z(#PO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](D!S=F<Z=VED=&@B+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@
M<V5L96-T/2)`9')A=SIN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O
M;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@(#PA+2T@,D1/('!R;W9E(&)E<W0@=7-A9V4@9F]R(%!!3$T@
M+2T^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@4U5"4T54
M($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<W!A;B(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@(#PA+2T@,D1/('!R;W9E(&)E<W0@=7-A
M9V4@9F]R(%=-3"`M+3X*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!734P@
M+R!705`@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`\(2TM(&YO(&YE<W1E9"!P('1A9W,@
M:6X@=VUL,2XQ(&%L;&]W960@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M
M96YT<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N
M=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H@("`@/"$M+2!)1"`O($Y!344@;V8@=&5X="UB
M;W@@+2T^"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)`9')A=SIN86UE(CX*
M"B`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:60B/@H@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/@H@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!087)A9W)A<&AS("HJ
M*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<"!\(&1R87<Z<&%G92(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA+2TK
M*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-464Q%
M(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1O=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!7
M05D@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@24Y,
M24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M(&EN('!A;&T@<&%R86=R87!H<R!C:&EL9')E;B!O9B!T97AT.FQI<W0M:71E
M;7,@87)E(&)E='1E<B!S:&]W;B!W:71H;W5T("=P)R!T86<M+3X*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYA;64H<&%R96YT
M.CHJ*2`]("=T97AT.FQI<W0M:71E;2<B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE
M<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L
M>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!7
M34P@+R!705`@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`\(2TM(&YO(&YE<W1E9"!P('1A
M9W,@:6X@=VUL,2XQ(&%L;&]W960@+2T^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE
M;&5M96YT<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M
M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL
M97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ("TM/@H@("`@/"$M+2`J*BH@5&5X="!3<&%N("HJ*B`M+3X*("`@(#PA
M+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M
M871C:#TB=&5X=#IS<&%N(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%
M5"D@2$5!1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-P86XB/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@
M("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-3
M7TE.3$E.140G(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)S<&%N(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)
M3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E
M;G0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\(2TM*RLK
M*RL@5TU,("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#PA+2T@;F\@;F5S=&5D('`@=&%G<R!I
M;B!W;6PQ+C$@86QL;W=E9"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E
M<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@;F%M
M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(96%D
M:6YG<R`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@
M("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IH(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@
M/"$M+2!%=F5R>2!H96%D:6YG(&5L96UE;G0@=VEL;"!G970@86X@=6YI<75E
M(&%N8VAO<B!F;W(@:71S(&9I;&4L(&9R;VT@:71S(&AI96%R8VAY(&QE=F5L
M(&%N9"!N86UE.@H@("`@("`@("`@("!&;W(@97AA;7!L93H@(%1H92!H96%D
M:6YG('1I=&QE("=->2!F879O<FET92!H96%D:6YG)R!M:6=H="!G970@/&$@
M;F%M93TB,2LR*S(K37DK9F%V;W)I=&4K:&5A9&EN9R(O/B`M+3X*("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1D
M:7-A8FQE3&EN:V5D5&%B;&5/9D-O;G1E;G0@;W(@)&ES2F%V841I<V%B;&5D
M(&]R(&YO="@D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)RDB/@H@("`@("`@
M("`@("`\(2TM(%1H92!54DP@;&EN:VEN9R!O9B!A;B!T86)L92UO9BUC;VYT
M96YT(&ES(&1U92!T;R!A(&)U9R`H8VUP+B!B=6<@:60C(#$P,C,Q,2D@;F]T
M(&UA<'!E9"!A<R!54DP@:6X@=&AE(%A-3"X*("`@("`@("`@("`@("`@("!,
M:6YK:6YG(&]F('1H92!T86)L92UO9BUC;VYT96YT(&-A;B!T:&5R969O<F4@
M;VYL>2!B92!A<F-H:65V960@8GD@82!W;W)K+6%R;W5N9"!I;B!(5$U,("TM
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R
M96%T92UH96%D:6YG(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!N96-E<W-A
M<GD@87,@86YC:&]R(&9O<B!T:&4@8V]N=&5N="!T86)L92`M+3X*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M:&5A
M9&EN9RUA;F-H;W(B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H*("`@("`@("`@("`@("`@(#PA+2T@;F\@96UB961D:6YG
M('1H92!O<F=I;F%L(&AE861E<BP@87,@86X@97AP;&EC:70@86YC:&]R(&UI
M9VAT(&)E(&%L<F5A9'D@<V5T("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F-R96%T92UH96%D:6YG(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"B`@("`\(2TM(&1E9F%U;'0@;6%T8VAI;F<@9F]R
M(&AE861E<B!E;&5M96YT<R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M8W)E871E+6AE861I;F<B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454
M*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"@H@("`@
M("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)H96%D97)T>7`B('-E
M;&5C=#TB8V]N8V%T*"=H)RP@0'1E>'0Z;&5V96PI(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1H96%D97)T>7!](CX*"B`@("`@
M("`@("`@("`@("`@("`@/"$M+2!O=71L:6YE('-T>6QE("=T97AT.FUI;BUL
M86)E;"UW:61T:"<@:7,@:6YT97)P<F5T960@87,@82!#4U,@)VUA<F=I;BUL
M969T)R!A='1R:6)U=&4@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)M:6XM;&%B96PB('-E;&5C=#TB)&]F9FEC93IS='EL
M97,O=&5X=#IO=71L:6YE+7-T>6QE+W1E>'0Z;W5T;&EN92UL979E;"US='EL
M95M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TO<W1Y;&4Z
M<')O<&5R=&EE<R]`=&5X=#IM:6XM;&%B96PM=VED=&@B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.FEF('1E<W0](B1M:6XM;&%B96PB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^
M/'AS;#IT97AT/FUA<F=I;BUL969T.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](B1M:6XM;&%B96PB+SX\>'-L.G1E>'0^.SPO>'-L.G1E>'0^
M/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF
M/@H*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M8VQA<W,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)T<F%N<VQA=&4H0'1E>'0Z
M<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX\+WAS;#IA='1R:6)U=&4^
M"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@=W)I=&EN9R!O=70@82!C:&%P
M=&5R(&YU;6)E<B!I9B!D97-I<F5D("AN;W1I8V%B;&4@=VAE;B!A(&-O<G)E
M<W!O;F1I;F<@)W1E>'0Z;W5T;&EN92US='EL92<@97AI<W0@+2T^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)S=')I;F<M;&5N9W1H*"1O
M9F9I8V4Z<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M
M;&5V96PM<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V
M96Q=+T!S='EL93IN=6TM9F]R;6%T*2`A/2`P(CX*"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](B1D:7-A8FQE3&EN:V5D5&%B;&5/9D-O
M;G1E;G0@;W(@)&ES2F%V841I<V%B;&5D(&]R(&YO="@D;W5T<'5T5'EP92`]
M("=#4U-?2$5!1$52)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@=&AE(&-H87!T97(@;G5M8F5R(&ES('1H92!S=6T@;V8@)W1E
M>'0Z<W1A<G0M=F%L=64G(&%N9"!P<F5C961I;F<@<VEB;&EN9W,@;V8@)W1E
M>'0Z:"<@=VET:"!T:&4@<V%M92`G=&5X=#IL979E;"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!F=7)T:&5R;6]R92!W:&5N('1H
M92!C=7)R96YT(&1O8W5M96YT(&ES(')E9F5R96YC960@8GD@82!G;&]B86P@
M9&]C=6UE;G0@+2!A<R!P87)T(&]F(&$@=VAO;&4@<V5Q=65N8V4@;V8@9&]C
M=6UE;G1S("TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@8VAA<'1E<B!N;RX@:7,@9&5P96YD96YT(&]F('1H92!A;6]U;G0@
M;V8@<W1A<G1E9"!H96%D97)S(&EN('!R96-E9&EN9R!D;V-U;65N=',N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!T:&4@)W1E
M>'0Z<W1A<G0M=F%L=64@:7,@;F]T('-E="!T:&4@9&5F875L="!V86QU92!O
M9B`G,2<@:&%S('1O(&)E('1A:V5N+B`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T87)T5F%L=64B
M('-E;&5C=#TB)&]F9FEC93IS='EL97,O=&5X=#IO=71L:6YE+7-T>6QE+W1E
M>'0Z;W5T;&EN92UL979E;"US='EL95M`=&5X=#IL979E;"`](&-U<G)E;G0H
M*2]`=&5X=#IL979E;%TO0'1E>'0Z<W1A<G0M=F%L=64B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1S
M=&%R=%9A;'5E(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E
M;#TG,2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D
M:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`
M=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T
M97),979E;#$*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<R)R(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ
M=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L,@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'1E>'0Z;&5V96P])S,G(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PS"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@
M)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X
M=#IL979E;#TG-"<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H
M<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E
M;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN
M9T-H87!T97),979E;#0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<U)R(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB
M;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE
M=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M-0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S8G(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;
M0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PV"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)`=&5X=#IL979E;#TG-R<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`]
M(&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R
M96-E9&EN9T-H87!T97),979E;#<*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G16
M86QU92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L
M/2<X)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I
M;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T
M97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E
M<DQE=F5L.`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])SDG(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT
M97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PY"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("L@)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)`=&5X=#IL979E;#TG,3`G(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PQ,`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K
M("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S$G(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG
M.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=
M*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PQ"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(D!T97AT.FQE=F5L/2<R)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C
M;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@
M8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E
M8V5D:6YG0VAA<'1E<DQE=F5L,@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG,R<B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z
M.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#,*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M0'1E>'0Z;&5V96P])S0G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O
M=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C
M=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C
M961I;F=#:&%P=&5R3&5V96PT"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@,2(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<U)R(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ
M=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`
M=&5X=#IL979E;#TG-B<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U
M;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U
M<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E
M9&EN9T-H87!T97),979E;#8*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S<G(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT
M97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PW"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T
M97AT.FQE=F5L/2<X)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N
M="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R
M<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D
M:6YG0VAA<'1E<DQE=F5L.`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG.2<B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E
M>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E
M>'0Z;&5V96P])S$P)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N
M="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R
M<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D
M:6YG0VAA<'1E<DQE=F5L,3`*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6%B<V]L=71E+6-H
M87!T97(M;F\B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L
M,2(@("`@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/B`F(S$V,#L@)B,Q-C`[/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"@H@("`@
M("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK
M+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]
M("=#4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)H96%D97)T>7`B('-E;&5C=#TB8V]N8V%T*"=H)RP@0'1E>'0Z
M;&5V96PI(B\^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M>R1H96%D97)T>7!](CX*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L
M>2UT96UP;&%T97,@<V5L96-T/2)`=&5X=#IS='EL92UN86UE(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@=W)I=&EN9R!O=70@82!C:&%P
M=&5R(&YU;6)E<B!I9B!D97-I<F5D("AN;W1I8V%B;&4@=VAE;B!A(&-O<G)E
M<W!O;F1I;F<@)W1E>'0Z;W5T;&EN92US='EL92<@97AI<W0@+2T^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D;V9F:6-E.G-T>6QE<R]T
M97AT.F]U=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE+6QE=F5L+7-T>6QE6T!T
M97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72]`=&5X=#IS='EL
M92UN86UE(CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=&AE(&-H
M87!T97(@;G5M8F5R(&ES('1H92!S=6T@;V8@)W1E>'0Z<W1A<G0M=F%L=64G
M(&%N9"!P<F5C961I;F<@<VEB;&EN9W,@;V8@)W1E>'0Z:"<@=VET:"!T:&4@
M<V%M92`G=&5X=#IL979E;"<@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN
M9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L
M72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1O9F9I8V4Z<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U
M=&QI;F4M;&5V96PM<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E
M>'0Z;&5V96Q=+T!T97AT.G-T87)T+79A;'5E(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#X@)B,Q-C`[("8C,38P.SPO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@
M("`@("`@("`@(#PA+2T@,D1/.B!A9&0@0VAA<'1E<B!.;RX@9F]R(%!!3$T@
M86YD(%=-3"`\+3X@<')O8FQE;2!N97-T960@87!P;'DM=&5M<&QA=&5S("TM
M/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)3DQ)
M3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB:&5A9&5R='EP(B!S96QE8W0](F-O;F-A="@G:"<L
M($!T97AT.FQE=F5L*2(O/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](GLD:&5A9&5R='EP?2(^"@H*("`@("`@("`@("`@("`@("`@("`\
M(2TM($%L;"!C:&EL9')E;B!C;VYT96YT(&AA=F4@=&\@8F4@;F5S=&5D(&EN
M('1H92!S='EL97,@*&4N9RX@/&D^/&(^04Y9($-/3E1%3E0\+V(^/"]I/BD*
M("`@("`@("`@("`@("`@("`@("`@("`@(&9O<B!T:&ES('AS;#IA<'!L>2UT
M96UP;&%T97,@=VEL;"!B92!C86QL960@;&%T97(@+R!I;7!L:6-I="`M+3X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M8W)E871E+6%T=')I8G5T92U!3$E'3B(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@9V5T=&EN9R!T:&4@8W-S('-T>6QE<R!F;W(@=&AE('-T>6QE
M(&YA;64@*&UA<'!E9"!B>2!S='EL92UM87!P:6YG+GAS;"D@+2T^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL
M95!R;W!E<G1I97,B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL
M<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2]`=&5X=#IS='EL92UN86UE72(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!4"`@*RLK
M*RLM+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\(2TM(&YO(&YE<W1E9"!P('1A9W,@:6X@=VUL,2XQ(&%L;&]W960@
M+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H
M)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!S:6YC92!N;R!H96%D97(@<W1Y;&5S(&5X
M:7-T+"!A;B!E;7!H87-I<R!I<R!U<V5D("TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB96TB/@H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@=W)I=&EN9R!O=70@82!C:&%P=&5R(&YU
M;6)E<B!I9B!D97-I<F5D("AN;W1I8V%B;&4@=VAE;B!A(&-O<G)E<W!O;F1I
M;F<@)W1E>'0Z;W5T;&EN92US='EL92<@97AI<W0@+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1O9F9I8V4Z<W1Y;&5S
M+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M;&5V96PM<W1Y;&5;
M0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=+T!T97AT.G-T
M>6QE+6YA;64B/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM('1H92!C:&%P=&5R(&YU;6)E<B!I<R!T:&4@<W5M(&]F("=T97AT.G-T
M87)T+79A;'5E)R!A;F0@<')E8V5D:6YG('-I8FQI;F=S(&]F("=T97AT.F@G
M('=I=&@@=&AE('-A;64@)W1E>'0Z;&5V96PG("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N
M="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R
M<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)&]F9FEC93IS='EL97,O
M=&5X=#IO=71L:6YE+7-T>6QE+W1E>'0Z;W5T;&EN92UL979E;"US='EL95M`
M=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TO0'1E>'0Z<W1A
M<G0M=F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^("8C,38P.R`F(S$V,#L\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2)`=&5X
M=#IS='EL92UN86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M('-I;F-E(&YO(&AE861E<B!S='EL97,@97AI<W0L(&%N(&5M<&AA<VES(&ES
M('5S960@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB96TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD
M+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M
M+2`J*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@3&EN:R`@*BHJ("TM
M/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA
M=&4@;6%T8V@](G1E>'0Z82!\(&1R87<Z82(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M8V]M;6]N+6QI;FLB/@H@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M8V]M;6]N+6QI;FLB/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](FYO="@D;W5T<'5T5'EP92`]("=734PG*2(^"B`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^/'AS;#IV86QU92UO9B!S
M96QE8W0](D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`@("`@("`@(#PA+2T\>'-L.F%T=')I8G5T92!N86UE/2)C;&%S<R(^
M0V]N=&5N=$QI;FL\+WAS;#IA='1R:6)U=&4^+2T^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA
M;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!N;R!N97-T960@<"!T
M86=S(&EN('=M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L96UE;G1S
M+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB
M9&5S8V5N9&%N=#HZ=&5X="@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ
M:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](F1E<V-E
M;F1A;G0Z.G1E>'0H*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M("TM/@H@("`@/"$M+2`J*BH@26UA9V4@3&EN:R`@*BHJ("TM/@H@("`@/"$M
M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;6%T8V@](F1R87<Z:6UA9V4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM($Y/($E-04=%
M4R!355!03$E%1"!&3U(@5T%0($]2(%!!3$T@+2T^"B`@("`@("`@/'AS;#II
M9B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R!O<B`D;W5T<'5T
M5'EP92`]("=#4U-?24Y,24Y%1"<B/@H*("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](FEM9R(^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(D!S=F<Z=VED=&@B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](G=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F-O;G9E<G0R<&EX96PB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G9A
M;'5E(B!S96QE8W0](D!S=F<Z=VED=&@B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*
M("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB0'-V9SIH96EG:'0B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAE:6=H
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)C;VYV97)T,G!I>&5L(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)V86QU92(@<V5L96-T/2)`
M<W9G.FAE:6=H="(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@
M("`@/'AS;#II9B!T97-T/2)S=F<Z9&5S8R(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB86QT(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-V9SID97-C(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@/"$M+2!F;W(@:6UA9V5S(&IA<F5D(&EN
M(&]P96X@;V9F:6-E(&1O8W5M96YT("TM/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<RA`>&QI;FLZ:')E9BP@)R-0:6-T
M=7)E<R\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8W)E871I
M;F<@86X@86)S;VQU=&4@:'1T<"!54DP@=&\@=&AE('!A8VME9"!I;6%G92!F
M:6QE("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&IA
M<F5D4F]O=%523"P@)R]0:6-T=7)E<R\G+"!S=6)S=')I;F<M869T97(H0'AL
M:6YK.FAR968L("<C4&EC='5R97,O)RDL("1O<'1I;VYA;%523%-U9F9I>"DB
M+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*/"$M+2`@("`@("`@("`@("`@("`@("`@1'5E('1O(&$@6%0@8G5G
M(&YO($1/4R`G.B<@8F5F;W)E($12259%(&QE='1E<B!I<R!A;&QO=V5D+"!I
M="!W;W5L9"!R97-U;'0@:6X@82!U;FMO=VX@<')O=&]C;R!E>&-E<'1I;VXL
M(&)U="!A(&9I;&4@55),(&9O<B!A($1/4PH)"0D)"0EP871H(&YE961S('1H
M92!$4DE612!L971T97(L('1H97)E9F]R92!A;&P@<F5L871I=F4@55),<R!R
M96UA:6X@<F5L871I=@H*"0D)"0D\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M0'AL:6YK.FAR968L)R\O)RD@;W(@*'-U8G-T<FEN9RA`>&QI;FLZ:')E9BPR
M+#$I(#T@)SHG*2!O<B!S=&%R=',M=VET:"A`>&QI;FLZ:')E9BP@)R\G*2(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(G-R8R(^/'AS;#IV86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA?GX@8W)E871I;F<@82!A8G-O;'5T92!P871H
M+U523"!F;W(@=&AE(')E9F5R96YC960@<F5S;W5R8V4@?GX^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-R8R(^/'AS
M;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D86)S;VQU=&53;W5R8V5$:7)2
M968L($!X;&EN:SIH<F5F+"`D;W!T:6]N86Q54DQ3=69F:7@I(B\^/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*+2T^"@D)"0D)/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-R8R(^/'AS;#IV86QU92UO
M9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"$M+2!A9&1I;F<@
M82!L:6YE(&)R96%K('1O(&UA:V4@=&AE('!R97-E;G1A=&EO;B!M;W)E(&5V
M96X@=VET:"!T:&4@3T]O('9I97<@+2T^"B`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)B<B(O/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H@("`@/"$M+2`J*BH@;W)D97)E9"!L:7-T("HJ*B`M+3X*("`@(#PA+2T@
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M
M871C:#TB=&5X=#IO<F1E<F5D+6QI<W0B/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#
M041)3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]
M("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](F]L(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@
M)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](F]L(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!!3D0@5T%0($E.3$E.140@
M5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB;VPB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC
M;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`\(2TM*RLK*RL@5TU,("\@5T%0("`K*RLK*RTM/@H@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@
M<VEM=6QA=&EN9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T960@;&ES="!E
M;&5M96YT<R`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F%N8V5S=&]R.CIT97AT.FQI<W0M:71E;2(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;
M8V]N=&%I;G,H)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!S:6UU
M;&%T:6YG(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L871E9"!L:7-T(&5L96UE
M;G1S("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB8G(B/CPO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('-I
M;75L871I;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D(&QI<W0@96QE
M;65N=',@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB8G(B/CPO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@=6YO<F1E<F5D(&QI<W0@
M*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*
M("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z=6YO<F1E<F5D+6QI<W0B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK
M*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@4U193$4@
M5T%9("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T
M<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB=6PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK($A434P@
M-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)U;"(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE
M<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\
M(2TM*RLK*RL@4$%,32`S+C(@4U5"4T54($%.1"!705`@24Y,24Y%1"!705D@
M("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T
M5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB=6PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!4"`@*RLK
M*RLM+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\(2TM('-I
M;75L871I;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D(&QI<W0@96QE
M;65N=',@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F%N8V5S=&]R.CIT97AT.FQI<W0M:71E;2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M
M<&%R86=R87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T:6YG(&-O;G1E;G0@8G)E
M86L@;V8@8V%P<W5L871E9"!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B<B(^
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC
M;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T
M:6YG(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L871E9"!L:7-T(&5L96UE;G1S
M("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB8G(B/CPO>'-L.F5L96UE;G0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E
M/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*
M"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ
M*B!L:7-T(&ET96T@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z;&ES="UI
M=&5M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA
M+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-4
M64Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](FQI(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT
M96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(
M5$U,(#0N,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@
M("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;&DB/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@
M("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!!3D0@5T%0($E.3$E.140@
M5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U
M='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](FQI(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@
M("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R
M87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@<VEM=6QA=&EN9R!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB86YC97-T
M;W(Z.G1E>'0Z;&ES="UI=&5M(CXJ/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XJ(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A
M<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2!L:7-T(&ET96T@8G)E86L@<VEM=6QA
M=&EO;B`H;F]T(&EN(&$@=&%B;&4I+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ:68@=&5S=#TB;F]T*&%N8V5S=&]R.CIT86)L93IT86)L92UC
M96QL*2!O<B!F;VQL;W=I;F<M<VEB;&EN9SHZ=&5X=#IL:7-T+6ET96TB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F)R(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@<VEM=6QA=&EN9R!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](F%N
M8V5S=&]R.CIT97AT.FQI<W0M:71E;2(^*CPO>'-L.F9O<BUE86-H/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/BH@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M
M+2!L:7-T(&ET96T@8G)E86L@<VEM=6QA=&EO;B`H;F]T(&EN(&$@=&%B;&4I
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(FYO="AA;F-E<W1O<CHZ=&%B;&4Z=&%B;&4M8V5L;"D@;W(@9F]L;&]W:6YG
M+7-I8FQI;F<Z.G1E>'0Z;&ES="UI=&5M(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8G(B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H@("`@/"$M+2`J*BH@5&5X="!396-T:6]N("AC;VYT86EN<SH@9')A=SIT
M97AT+6)O>"D@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@("`@("`\>'-L
M.G1E;7!L871E(&UA=&-H/2)T97AT.G-E8W1I;VXB/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\
M>'-L.FEF('1E<W0](FYO="AC;VYT86EN<RA`=&5X=#ID:7-P;&%Y+"`G;F]N
M92<I*2(^"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$
M15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S<&%N(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P
M<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP
M($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-P86XB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S
M+C(@4U5"4T54($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYA;64H<&%R96YT.CHJ*2`]("=T
M97AT.FQI<W0M:71E;2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T
M>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E
M;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@("LK*RLK+2T^
M"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](FYO="@D;W5T<'5T5'EP92`]("=734PG*2(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M82(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB:')E9B(^/'AS;#IV86QU92UO9B!S96QE8W0](D!X;&EN
M:SIH<F5F(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@;F\@;F5S=&5D('`@=&%G<R!I;B!W;6PQ
M+C$@86QL;W=E9"`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G
M<F%P:"UE;&5M96YT<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P
M;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;6%T8V@](G1E>'0Z;&EN92UB<F5A:R(^"B`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](F)R(B\^"B`@("`\+WAS;#IT96UP;&%T93X*"@H\
M(2TM"B`@("!404)(04Y$3$E.1R!04D]"3$5-.B!486)S(&%R92!P;W-S:6)L
M92!T;R!B92!S:&]W;B!I;B!T:&4@2%1-3"!T97AT(&9I;&4L(&)U="!W:6QL
M(&)E(&QA=&5R('-T<FEP<&5D(&%S('=H:71E<W!A8V5S+@H@("`@("`@(%1O
M('!R979E;G0@=&AI<R!O;F4@=V%Y('=O=6QD(&)E('1H92!04D4@=&%G('=H
M:6-H('5N9F]R='5N871E;'D@04Q705E3(')E<W5L="!I;G1O(&$@;&EN92UB
M<F5A:RX@3F\@<W5R<F]U;F1I;F<@3D]"4B!T86=S(&AE;'`N"@H@("`@/'AS
M;#IT96UP;&%T92!M871C:#TB=&5X=#IT86(M<W1O<"(^"B`@("`@("`@/'AS
M;#II9B!T97-T/2)N;W0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z=&%B+7-T
M;W`I(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G!R92(^/'AS
M;#IT97AT/B8C.3L\+WAS;#IT97AT/CQX<VPZ9F]R+65A8V@@<V5L96-T/2)F
M;VQL;W=I;F<M<VEB;&EN9SHZ=&5X=#IT86(M<W1O<"(^/'AS;#IT97AT/B8C
M.3L\+WAS;#IT97AT/CPO>'-L.F9O<BUE86-H/CPO>'-L.F5L96UE;G0^"B`@
M("`@("`@/"]X<VPZ:68^"B`@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS
M;#IT96UP;&%T92!M871C:#TB=&5X=#IT86(M<W1O<"(^/'AS;#IT97AT/B8C
M.3L\+WAS;#IT97AT/CPO>'-L.G1E;7!L871E/@HM+3X*("`@(#PA+2T@2$]4
M1DE8.B`X(&YO;BUB<F5A:V%B;&4M<W!A8V5S(&EN<W1E860@;V8@82!404(@
M:7,@82!H86-K('-O;65T:6UE<R!L97-S(%1A8G,@87)E(&YE961E9"!A;F0@
M=&AE(&-O9&4@;6]R92!D:69F:6-U;'0@=&\@<F5A9"`M+3X*("`@(#QX<VPZ
M=&5M<&QA=&4@;6%T8V@](G1E>'0Z=&%B+7-T;W`B/@H@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C
M92(^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W:&ET97-P
M86-E<R(@<V5L96-T/2(X(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#PA+2T@8W5R<F5N=&QY('1H
M97)E(&AA=F4@=&\@8F4@86X@97AP;&EC:70@8V%L;"!O9B!T:&4@<W1Y;&4@
M871T<FEB=71E(&YO9&5S+"!M87EB92!T:&4@871T<FEB=71E<R!N;V1E<R!H
M879E(&YO('!R:6]R:71Y(&]N;'D@;W)D97(@<F5L979A;G0M+3X*("`@(#PA
M+2T@4U1204Y'13H@8VAE8VME9"!W:71H(&)I;W)Y=&AM+G-X8R!A('-I;7!L
M92!X<VPZ87!P;'DM=&5M<&QA=&5S(&1I9"!N;W0@<F5C;V=N:6-E('1H92!S
M='EL97,N($UA>6)E(&-A=7-E9"!B>2!T:&4@=&5M<&QA=&4@;6%T8V@@;W)D
M97(_("`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S
M+6%N9"UC;VYT96YT(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T
M97,@<V5L96-T/2)`=&5X=#IS='EL92UN86UE('P@0&1R87<Z<W1Y;&4M;F%M
M92!\($!D<F%W.G1E>'0M<W1Y;&4M;F%M92!\($!T86)L93IS='EL92UN86UE
M(CX\(2TM('P@0'!R97-E;G1A=&EO;CIS='EL92UN86UE("TM/@H@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#PO
M>'-L.F%P<&QY+71E;7!L871E<SX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP
M;&%T97,^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](D!T97AT.G-T
M>6QE+6YA;64@?"!`9')A=SIS='EL92UN86UE('P@0&1R87<Z=&5X="US='EL
M92UN86UE('P@0'1A8FQE.G-T>6QE+6YA;64B/CPA+2T@?"!`<')E<V5N=&%T
M:6]N.G-T>6QE+6YA;64M+3X*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%
M5"D@2$5!1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8VQA<W,B/CQX<VPZ
M=F%L=64M;V8@<V5L96-T/2)T<F%N<VQA=&4H+BP@)RX@)2@I+UPG+"`G)RDB
M+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@
M("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK
M*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP
M92`]("=#4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB<W1Y;&4B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82]A;&QS='EL97,O*EMN86UE*"D]8W5R<F5N="@I
M+RY=(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)3DQ)
M3D5$(%=!62`@86YD("!734P@+R!705`@("`K*RLK*RTM/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<@;W(@)&]U
M='!U=%1Y<&4@/2`G5TU,)R(^"B`@("`@("`@("`@("`@("`\(2TM(&=E='1I
M;F<@=&AE(&-S<R!S='EL97,@9F]R('1H92!S='EL92!N86UE("AM87!P960@
M8GD@<W1Y;&4M;6%P<&EN9RYX<VPI("TM/@H@("`@("`@("`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$O86QL<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H
M*2\N72(O/@H@("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@8V]N
M=&5X="!N;V1E("TM/@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S
M96QE8W0](G!A<F5N=#HZ*B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F-R96%T92UN97-T960M9F]R;6%T+71A9W,B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E
M>'0Z<V5Q=65N8V4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E
M<SX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`\+WAS;#IT96UP
M;&%T93X*"@H\+WAS;#IS='EL97-H965T/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O=&%B;&4N>'-L
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,W,#``,3`U,34T,S$P-C$`,#(R
M-C(S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@
M879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O
M9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S
M<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@
M("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!6
M97)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R
M+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@
M5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R
M;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@
M06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@
M<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M
M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI
M<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI
M<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@
M=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@
M=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(
M04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]3
M12X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E
M;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C
M96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC
M"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@
M=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC
M+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@
M(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@
M4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N
M=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD
M=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ
M("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@
M("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@
M;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO
M+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R
M92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@
M86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@
M2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@
M("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&
M5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)
M5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'
M+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I
M;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@
M8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E
M;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E
M;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y
M<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT
M<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@
M("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY
M.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@
M("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H
M='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@
M("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN
M:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@
M("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN
M<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@
M("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F
M:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H
M='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@
M("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE
M=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS
M.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@
M("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC
M;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA
M;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A
M8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E
M<W5L="UP<F5F:7AE<STB:F%V82(^"@H*("`@(#PA+2T@=&%B;&4@<F]W(&AA
M;F1L:6YG("TM/@H@("`@/'AS;#II;F-L=61E(&AR968](G1A8FQE7W)O=W,N
M>'-L(B\^"B`@("`\(2TM('1A8FQE(&-O;'5M;B!H86YD;&EN9R`M+3X*("`@
M(#QX<VPZ:6YC;'5D92!H<F5F/2)T86)L95]C;VQU;6YS+GAS;"(O/@H@("`@
M/"$M+2!T86)L92!C96QL(&AA;F1L:6YG("TM/@H@("`@/'AS;#II;F-L=61E
M(&AR968](G1A8FQE7V-E;&QS+GAS;"(O/@H*"@H@("`@/"$M+2`J*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@;6%I;B!T86)L92`@*BHJ
M("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;6%T8V@](G1A8FQE.G1A8FQE('P@=&%B;&4Z<W5B+71A
M8FQE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*"B`@("`@("`@/"$M+2!A('1A8FQE('=I;&P@;VYL>2!B92!C
M<F5A=&5D(&EF('1H92`B<V-E;F%R:6\B(&ES(&%C=&EV92`M+3X*("`@("`@
M("`\>'-L.FEF('1E<W0](G-T<FEN9RUL96YG=&@H=&%B;&4Z<V-E;F%R:6\O
M0'1A8FQE.FES+6%C=&EV92D@/2`P(CX*("`@("`@("`@("`@/"$M+2!C;VQL
M96-T:6YG(&%L;"!V:7-I8FQE(")T86)L93IT86)L92UR;W<B(&5L96UE;G1S
M(&]F('1H92!T86)L92`M+3X*("`@("`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S(B!S96QE8W0](G1A8FQE.G1A8FQE
M+7)O=UMN;W0H0'1A8FQE.G9I<VEB:6QI='D@/2`G8V]L;&%P<V4G(&]R($!T
M86)L93IV:7-I8FEL:71Y(#T@)V9I;'1E<B<I70H@("`@("`@("`@("`@("`@
M("`@('P@("`@=&%B;&4Z=&%B;&4M:&5A9&5R+7)O=W,O9&5S8V5N9&%N=#HZ
M=&%B;&4Z=&%B;&4M<F]W6VYO="A`=&%B;&4Z=FES:6)I;&ET>2`]("=C;VQL
M87!S92<@;W(@0'1A8FQE.G9I<VEB:6QI='D@/2`G9FEL=&5R)RE="B`@("`@
M("`@("`@("`@("`@("`@?"`@("!T86)L93IT86)L92UR;W<M9W)O=7`O9&5S
M8V5N9&%N=#HZ=&%B;&4Z=&%B;&4M<F]W6VYO="A`=&%B;&4Z=FES:6)I;&ET
M>2`]("=C;VQL87!S92<@;W(@0'1A8FQE.G9I<VEB:6QI='D@/2`G9FEL=&5R
M)RE=(B\^"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@/"$M+2!F;W(@86QL(&)U="!705`O5TU,(&1E=FEC97,@82!T86)L92!B
M;W)D97(@8VAE8VL@:7,@9&]N92`H8W`N(")C:&5C:RUF;W(M=&%B;&4M8F]R
M9&5R(BD@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB;F]T
M*"1O=71P=714>7!E(#T@)U=-3"<I(CX*"B`@("`@("`@("`@("`@("`@("`@
M/"$M+2!!<R!T:&4@86QI9VYM96YT(&]F(&$@=&%B;&4@:7,@8GD@)V%L:6=N
M)R!A='1R:6)U="!I<R!D97!R96-A=&5D(&%N9"!A<R!T:&4@0U-3("=F;&]A
M="<@871T<FEB=71E(&YO="!W96QL(&1I<W!L87EE9"P*("`@("`@("`@("`@
M("`@("`@("`@("`@('=E(&1O(&$@;&ET=&QE('1R:6-K(&)Y(&5N8V%P<W5L
M871I;F<@=&AE('1A8FQE('=I=&@@82!A;&EG;F5D("=D:78G(&5L96UE;G0M
M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1A
M8FQE+6%L:6=N;65N="(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL
M97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.FYA;64@/2!C=7)R96YT*"DO0'1A8FQE
M.G-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,O0'1A8FQE.F%L:6=N(B\^
M"@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R:6YG+6QE;F=T:"@D
M=&%B;&4M86QI9VYM96YT*2`A/2`P(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)D:78B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F%L:6=N
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TG)'1A8FQE+6%L:6=N;65N=#TB;&5F="(@;W(@
M)'1A8FQE+6%L:6=N;65N=#TB;6%R9VEN<R(G/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^;&5F
M=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])R1T86)L92UA;&EG;FUE
M;G0](G)I9VAT(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/G)I9VAT/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TG)'1A8FQE+6%L:6=N;65N=#TB8V5N=&5R(B<^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F-E;G1E<CPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T
M86)L92(^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](D!T86)L93IS='EL92UN86UE
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=V]R:V%R
M;W5N9"P@<V5T('1A8FQE(&)O<F1E<B!A='1R:6)U="!I9B!A;GD@8V5L;"UB
M;W)D97(@97AI<W1S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C:&5C:RUF;W(M=&%B;&4M
M8F]R9&5R(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S
M(B!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;'5M;BUS='EL92UV87)I
M86)L92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@
M<V5L96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB=&%B;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB0'1A8FQE.G-T
M>6QE+6YA;64B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!W;W)K87)O=6YD
M+"!S970@=&%B;&4@8F]R9&5R(&%T=')I8G5T(&EF(&%N>2!C96QL+6)O<F1E
M<B!E>&ES=',*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB8VAE8VLM9F]R+71A8FQE+6)O<F1E<B(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S(B!S96QE8W0](B1A
M;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X@("TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)C<F5A=&4M8V]L=6UN+7-T>6QE+79A<FEA8FQE(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;%9I<VEB;&5486)L95)O=W,B('-E;&5C=#TB)&%L;%9I<VEB;&5486)L
M95)O=W,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@/"$M+2!F;W(@5TU,(&1E=FEC97,@;VYL>2!!4T-)22!T86)L
M92!A<F4@=W)I='1E;B!A<R!T86)L97,@87)E(&YO="!I;7!L96UE;G1E9"!W
M:61L97DN"B`@("`@("`@("`@("`@("`@("`@($)E9VEN;FEN9R!F<F]M("=R
M97!E870M=W)I=&4M<F]W)R!T:&4@=&5M<&QA=&5S(&%R92!H86YD;&5D(&)Y
M('1H92!T86)L95]W;6PN>'-L('-T>6QE<VAE970@+2T^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC;VQU
M;6XM<W1Y;&4M=F%R:6%B;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B
M;&52;W=S(B`@<V5L96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*
M"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M8V]L=6UN+7-T>6QE
M+79A<FEA8FQE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;%9I
M<VEB;&5486)L95)O=W,B+SX*"B`@("`@("`@/"$M+2!A;&P@8V]L=6UN<R!O
M9B!T:&4@=&%B;&4@+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)A
M;&Q486)L94-O;'5M;G,B('-E;&5C=#TB=&%B;&4Z=&%B;&4M8V]L=6UN('P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T86)L93IT86)L92UC;VQU;6XM9W)O=7`O9&5S8V5N9&%N=#HZ
M=&%B;&4Z=&%B;&4M8V]L=6UN('P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T86)L93IT86)L92UH96%D
M97(M8V]L=6UN<R]D97-C96YD86YT.CIT86)L93IT86)L92UC;VQU;6XB+SX*
M("`@("`@("`\(2TM(&%L;$-O;'5M;E-T>6QE16YT<FEE<SH@0V]N=&%I;FEN
M9R!A;&P@8V]L=6UN<R!O9B!T:&4@=&%B;&4L(&AI9&1E;B!A;F0@=FEE=V5D
M+@H@("`@("`@("`@("`M(&EF(&$@8V]L=6UN(&ES(&AI9&1E;BP@:70@8V]N
M=&%I;G,@=&AE(&AI9&1E;B!A='1R:6)U=&4L(&]T:&5R=VES92!T:&4@<W1Y
M;&4M<')O<&5R=&EE<R!W:6QL(&)E('-T;W)E9`H@("`@("`@("`@("`M(&EF
M(&$@8V]L=6UN(&ES(&)E:6YG(')E<&5A=&5D+"!E86-H(')E<&5A=&5D(&-O
M;'5M;B!I<R!E>'!L:6-I=&QY('=R:71T96X@87,@96YT<GD@:6X@=&AI<R!V
M87)I86)L92X*("`@("`@("`@("`@("!,871E<B`H9'5R:6YG('1E;7!L871E
M(")W<FET92UC96QL(BD@=&AE('-T>6QE(&]F('1H92!C;VQU;6X@=VEL;"!B
M92!M:7AE9"!W:71H('1H92!C96QL+7-T>6QE(&)Y('5S:6YG"B`@("`@("`@
M("`@("`@=&AE('!O<VET:6]N*"D@;V8@=&AE(&-O;'5M;B!E;G1R>2!A;F0@
M8V]M<&%R:6YG(&ET('=I=&@@=&AE(&ET97)A=&EN9R!C96QL(&YU;6)E<BX@
M+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)A;&Q#;VQU;6Y3='EL
M945N=')I97,M4E1&(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&5S+65N=')I97,B/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%1A8FQE0V]L
M=6UN<R(@("`@("!S96QE8W0](B1A;&Q486)L94-O;'5M;G,B+SX*("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#IV87)I
M86)L93X*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAT.FYO9&4M<V5T)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R
M96%T92UT86)L92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@("`@
M("!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(@("`@<V5L96-T/2)X=#IN;V1E+7-E="@D86QL0V]L=6UN4W1Y
M;&5%;G1R:65S+5)41BDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO
M9&5S970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB8W)E871E+71A8FQE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52
M;W=S(B`@("`@('-E;&5C=#TB)&%L;%9I<VEB;&5486)L95)O=W,B+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L
M=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](GAA;&%N.FYO9&5S970H)&%L
M;$-O;'5M;E-T>6QE16YT<FEE<RU25$8I(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS;#IT96UP;&%T93X*"@H*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+71A8FQE(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B+SX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(O/@H*"B`@("`@("`@/"$M+2!3;VUE($]F9FEC92!#86QC(&1O8W5M96YT
M<R!S:6UU;&%T92!A(&)A8VMG<F]U;F0@8GD@<F5P96%T:6YG('1H92!L87-T
M(&-E;&P@=6YT:6P@96YD(&]F('-P86-E"B`@("`@("`@("`@("`H5&AE('9A
M;'5E(&]F(")T86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E9"(@:7,@96YO
M=7)M;W5S*2X@5W)I=&EN9R!O=70@86QL('1H97-E(&-E;&QS('=O=6QD(&)E
M(&9A=&%L+@H@("`@("`@("`@("`@5&AE<F5F;W)E+"!T:&ES(&=L;V)A;"!V
M87)I86)L92!S:&]W<R!U<R!T:&4@;&]N9V5S="!R;W<@=VET:"!C;VYT96YT
M+@H*("`@("`@("!%87)L:65R(&]N;'D@=&AE('9I97=A8FQE(&-O;'5M;G,@
M=V5R92!L:7-T960L(&)U="!I="!I<R!E87-I97(@=&\@:&%N9&QE('=I=&@@
M86QL(&-O;'5M;G,Z"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)M87A2
M;W=,96YG=&@B('-E;&5C=#TB8V]U;G0H)&%L;$-O;'5M;E-T>6QE16YT<FEE
M<R]C;VQU;6XM<W1Y;&4M96YT<GE;;F]T*$!C;VQU;6XM:&ED9&5N+69L86<I
M72DB+SX@+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)M87A2;W=,
M96YG=&@B('-E;&5C=#TB8V]U;G0H)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C
M;VQU;6XM<W1Y;&4M96YT<GDI(B\^"@H*("`@("`@("`\(2TM:7-$96)U9TUO
M9&4M4U1!4E0M+3X*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D
M92(^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YM87A2;W=,96YG=&@Z(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N=6UB97)/
M9DAI9&1E;D-O;'5M;G,B('-E;&5C=#TB8V]U;G0H)&%L;$-O;'5M;E-T>6QE
M16YT<FEE<R]C;VQU;6XM<W1Y;&4M96YT<GE;0&-O;'5M;BUH:61D96XM9FQA
M9UTI(B\^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YN=6UB97)/9DAI9&1E
M;D-O;'5M;G,Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;G5M8F5R3V9(:61D
M96Y#;VQU;6YS(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](G1A8FQE+61E8G5G+6%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B!S96QE8W0](B1A;&Q#;VQU;6Y3
M='EL945N=')I97,B+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`\+WAS;#II9CX*("`@("`@("`\(2TM:7-$96)U9TUO9&4M
M14Y$+2T^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=734PG(CX*("`@("`@("`@("`@
M("`@(#PA+2T@;6%T8VAI;F<@86QL(')O=W,@+2!W92!C86X@;F]T('5S92!X
M<VPZ87!P;'DM=&5M<&QA=&4@=VET:"!A(&YO9&4M<V5T('!A<F%M971E<B!A
M<R!B>2!A(&)U9R!I;B!85"`H2F%M97,@0VQA<FLI"B`@("`@("`@("`@("`@
M("`@("`@("AH97)E.B!A;&Q#;VQU;6Y3='EL945N=')I97,I('=I;&P@8F4@
M:6YT97)P<F5T960@87,@82!R97-U;'0@=')E92!F<F%G;65N="P@=VAE<F4@
M;F\@<V5A<F-H(&5X<')E<W-I;VX@*%A0871H*2!C86X@8F4@=7-E9`H@("`@
M("`@("`@("`@("`@("`@("`R1$\Z0TA%0TL@5TE42"!804Q!3BTM/@H@("`@
M("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1A;&Q6:7-I8FQE
M5&%B;&52;W=S(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB=VUL+7)E<&5A="UW<FET92UR;W<B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](B1A;&Q#
M;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUR;W=S+7)E<&5A=&5D(B`@
M("`@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<F5P96%T960B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA
M>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@(#PA+2T@;6%T8VAI;F<@86QL(')O=W,@+2!W92!C86X@;F]T
M('5S92!X<VPZ87!P;'DM=&5M<&QA=&4@=VET:"!A(&YO9&4M<V5T('!A<F%M
M971E<B!A<R!B>2!A(&)U9R!I;B!85"`H2F%M97,@0VQA<FLI"B`@("`@("`@
M("`@("`@("`@("`@("AH97)E.B!A;&Q#;VQU;6Y3='EL945N=')I97,I('=I
M;&P@8F4@:6YT97)P<F5T960@87,@82!R97-U;'0@=')E92!F<F%G;65N="P@
M=VAE<F4@;F\@<V5A<F-H(&5X<')E<W-I;VX@*%A0871H*2!C86X@8F4@=7-E
M9`H@("`@("`@("`@("`@("`@("`@("`R1$\Z0TA%0TL@5TE42"!804Q!3B`M
M+3X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D86QL
M5FES:6)L951A8FQE4F]W<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](G)E<&5A="UW<FET92UR;W<B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](B1A
M;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUR;W=S+7)E<&5A=&5D
M(B`@("`@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<F5P96%T960B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N
M9W1H(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@
M("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($A%3%!%4CH@=&%B;&4@
M8F]R9&5R("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B`M+3X*"B`@("`\(2TM(&]N;'D@;VYE('1A8FQE(&)O<F1E<B!F
M;W(@2%1-3#0@;W(@0U-3(&1E=FEC97,@=VAI8V@@8V]N=&%I;B!O;F4@;W(@
M;6]R92`G9F\Z8F]R9&5R+71O<"<@871T<FEB=71E<R`H<&%R<R!P<F\@=&]T
M;RP@:68@;VYE(&5X:7-T('1H92!O=&AE<B!U<W5A;&QY(&5X:7-T+"!T;V\I
M("TM/@H@("`@/"$M+2!T:&ES('=A<R!A('=O<FLM87)O=6YD(&9O<B!T:&4@
M;F5T<V-A<&4@-"YX>"!B=70@;F]T(&QO;F=E<B!N96-E<W-A<GD@9F]R($UO
M>FEL;&$@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-H96-K+69O<BUT
M86)L92UB;W)D97(B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL5FES
M:6)L951A8FQE4F]W<R(O/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(G-T87)T5&EM92(^"B`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B
M=6=-;V1E(&%N9"!N;W0H)&ES2F%V841I<V%B;&5D*2(^"B`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>7-T96TZ8W5R<F5N="UT
M:6UE+6UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G-Y<W1E;3IC=7)R96YT+71I;64M;6EL;&ES*"DB
M+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H
M)VIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM94UI;&QI<R<I(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(FIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM94UI;&QI<R@I(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@(#PA+2T@8VAE8VMS(&EF(&]N
M92!C96QL("AT86)L93IT86)L92UC96QL*2!O9B!T:&4@<F]W<R!O9B!T:&ES
M('1A8FQE("AA;&Q6:7-I8FQE5&%B;&52;W=S*2!C;VYT86EN<R!A(&)O<F1E
M<B!S='EL92`H:2YE+B!F;SIB;W)D97(M=&]P*0H@("`@("`@("`@("`@268@
M;VYL>2!O;F4@<VEN9VQE(&)O<F1E<B!E;&5M96YT(&5X:7-T+"!T:&4@=VAO
M;&4@=&%B;&4@=VEL;"!G971S('!R92UD969I;F5D(&)O<F1E<G,@*'-I;7!L
M92!H975R:7-T:6,@9F]R(&)E='1E<B!B<F]W<V5R(&1I<W!L87DI("TM/@H@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&%L;%9I<VEB;&5486)L95)O=W,O=&%B
M;&4Z=&%B;&4M8V5L;%M`=&%B;&4Z<W1Y;&4M;F%M93TO*B\J+W-T>6QE.G-T
M>6QE6W-T>6QE.G!R;W!E<G1I97,O0&9O.F)O<F1E<BUT;W!=+T!S='EL93IN
M86UE72(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F)O<F1E
M<B(^,3PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U
M=&4@;F%M93TB8F]R9&5R8V]L;W(B/B,P,#`P,#`\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-E;&QP861D:6YG
M(CXR/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)C96QL<W!A8VEN9R(^,#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<&%G92UB<F5A:RUI;G-I9&4B
M/G!A9V4M8G)E86LM:6YS:61E.F%V;VED/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@(#PO>'-L.FEF/@H*"B`@("`@("`@/"$M+2!C:&5C:R!T:&4@=&EM92!F
M;W(@8F]R9&5R8VAE8VMI;F<@*&1E8G5G*2TM/@H@("`@("`@(#QX<VPZ:68@
M=&5S=#TB)&ES1&5B=6=-;V1E(&%N9"!N;W0H)&ES2F%V841I<V%B;&5D*2(^
M"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96YD5&EM92(^"B`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>7-T96TZ
M8W5R<F5N="UT:6UE+6UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-Y<W1E;3IC=7)R96YT+71I;64M
M;6EL;&ES*"DB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA
M=F%I;&%B;&4H)VIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM94UI
M;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](FIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM94UI
M;&QI<R@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ
M=F%R:6%B;&4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y4:6UE(&9O<B!C
M:&5C:VEN9R!";W)D97)3='EL93H@/'AS;#IV86QU92UO9B!S96QE8W0](B@D
M96YD5&EM92`M("1S=&%R=%1I;64I(B\^(&US/"]X<VPZ;65S<V%G93X*("`@
M("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y
M;&5S:&5E=#X*````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]S='EL95]H96%D
M97(N>'-L```````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,C,S-@`Q,#4Q-30S,3`V,0`P,C0R
M,3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A
M=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F
M('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@
M("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E
M<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L
M(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!6
M97)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O
M<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!
M;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S
M;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO
M9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N
M97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES
M:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES
M(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W
M:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W
M:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!
M3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N
M<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E
M:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*
M("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W
M<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N
M+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@
M,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3
M;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT
M96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U
M<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@
M*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@
M(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M
M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O
M=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E
M('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A
M;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+
M24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@
M(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T94
M5T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4
M($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N
M"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO
M;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C
M;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L
M;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M
M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES
M=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R
M:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY
M+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@
M("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN
M<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@
M("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@
M("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN
M<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS
M.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@
M("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@
M("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I
M8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT
M='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T
M82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@
M("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B
M"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L
M87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@
M("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C
M:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S
M=6QT+7!R969I>&5S/2)J879A(CX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@<W1Y;&4@<VAE
M970@<')O8V5S<VEN9R`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2=C<F5A=&4M8W-S+7-T>6QE:&5A9&5R)SX*("`@("`@("`\>'-L.F-O;6UE
M;G0^"B`@("`@("`@("`@(#QX<VPZ=&5X=#Y4:&4@0U-3('-T>6QE(&AE861E
M<B!M971H;V0@9F]R('-E='1I;F<@<W1Y;&5S/"]X<VPZ=&5X=#X*("`@("`@
M("`\+WAS;#IC;VUM96YT/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S
M='EL92(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G1Y<&4B
M/G1E>'0O8W-S/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\>'-L.F-O
M;6UE;G0^"B`@("`@("`@("`@("`@("`\>'-L.G1E>'0^"@H@("`@("`@(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB=W)I=&4M9&5F875L="US='EL97,B+SX*"B`@("`@("`@("`@("`@
M("`\(2TM(%1(12!35%E,12!04D]015)42453($]&(%1(12!&25)35"!74DE4
M5$5.(%-464Q%("A005)%3E0I($E3($=)5D5.($]55"`M+3X*"B`@("`@("`@
M("`@("`@("`\(2TM(#$I('-T>6QE<R!F<F]M(&]F9FEC93IS='EL97,@87)E
M('!O<W-I8FQE('!A<F5N="!F<F]M(&%L;"`H:71S96QF(&]R(&]F9FEC93IA
M=71O;6%T:6,M<W1Y;&5S*2X*("`@("`@("`@("`@("`@("`@("`@5&AE<F5F
M;W)E('1H97D@87)E(&-R96%T960@9FER<W0N"B`@("`@("`@("`@("`@("`@
M("`@($)E9VEN;FEN9R!W:71H('1H92!T;W`M;&5V96P@<&%R96YT<R`H=&AE
M('-T>6QE<R!W:71H;W5T(&%N>2!P87)E;G0I+B`M+3X*("`@("`@("`@("`@
M("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.G-T>6QE<R]S='EL
M93IS='EL95MN;W0H0'-T>6QE.G!A<F5N="US='EL92UN86UE*5TB/@H*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I
M=&4M<W1Y;&5P<F]P97)T>2UL:6YE(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM
M;&EN97,M9F]R+6-H:6QD<F5N(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IF
M;W(M96%C:#X*"B`@("`@("`@("`@("`@("`\>'-L.G1E>'0^(#PO>'-L.G1E
M>'0^"@H@("`@("`@("`@("`@("`@/"$M+2`R*2!S='EL97,@9G)O;2!O9F9I
M8V4Z875T;VUA=&EC+7-T>6QE<R!C86X@;VYL>2!B92!P87)E;G0@;V8@<W1Y
M;&5S(&9R;VT@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S('-E8W1I;VXN
M"B`@("`@("`@("`@("`@("`@("`@($)E9VEN;FEN9R!W:71H('1O<"UL979E
M;"!S='EL97,L(&%G86EN+"!A;&P@8VAI;&1R96X@<W1Y;&4@=VEL;"!B92!R
M96-U<G-I=FQY('1R879E<G-E9"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ
M9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y
M;&4Z<W1Y;&5;;F]T*$!S='EL93IP87)E;G0M<W1Y;&4M;F%M92E=(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I
M=&4M<W1Y;&5P<F]P97)T>2UL:6YE(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I
M8U-T>6QE<R(@<V5L96-T/2)T<G5E*"DB+SX*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL97!R;W!E<G1Y+6QI
M;F5S+69O<BUC:&EL9')E;B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S96%R8VA/;FQY26Y!=71O;6%T:6-3='EL
M97,B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@
M("\O/"]X<VPZ8V]M;65N=#X*("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG=W)I
M=&4M<W1Y;&5P<F]P97)T>2UL:6YE)SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O/@H*("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](G-T>6QE4')O<&5R=&EE<R(^"B`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL92UP<F]P
M97)T:65S(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S='EL94%T=')I8G5T95!A=&@B("`@<V5L96-T/2)C=7)R96YT*"DO<W1Y
M;&4Z<')O<&5R=&EE<R]`*B(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`\(2TM
M(&1O(&YO="!W<FET92!S='EL97,@=VET:"!N;R!C<W,@<')O<&5R='D@+2T^
M"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H<W1R:6YG+6QE;F=T:"@D<W1Y
M;&50<F]P97)T:65S*2`](#`I(CX*("`@("`@("`@("`@/"$M+2!W<FET92!O
M=70@=&AE(&YA;64@;V8@=&AE(&-U<G)E;G0@*'!A<F5N="D@<W1Y;&4@:6X@
M=&AE($-34R!H96%D97)S96-T:6]N("AE+F<N(")S<&%N+FUY4W1Y;&4B*2`M
M+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E
M+7-T>6QE+6YA;64B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FES+7!A<F5N="US='EL92(@<V5L96-T/2)T<G5E*"DB+SX*("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@(#PA
M+2T@=&AE(&YA;65S(&]F(&%L;"!S='EL97,@8VAI;&1R96X@=VEL;"!B92!W
M<FET=&5N(&]U="AO9F9I8V4Z<W1Y;&4@04Y$(&]F9FEC93IA=71O;6%T:6,M
M<W1Y;&4I("TM/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB=W)I=&4M8VAI;&1R96XM<W1Y;&4M;F%M97,B/@H@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@("`@
M("`@("`@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M:6QY(B`@("`@
M("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y
M;&5S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@
M("`@(#PA+2T@=&AE('-T>6QE('!R;W!E<G1I97,@;V8@=&AE(&9I<G-T('=R
M:71T96X@<W1Y;&4@*'!A<F5N="D@:7,@9VEV96X@;W5T("TM/@H@("`@("`@
M(#QX<VPZ=&5X=#X@>PH@("`@("`@("`@("`@("`@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<W1Y;&50<F]P
M97)T:65S(B\^"B`@("`@("`@/'AS;#IT97AT/GT*("`@("`@("`\+WAS;#IT
M97AT/@H*("`@("`@("`\+WAS;#II9CX*"@H*("`@(#PO>'-L.G1E;7!L871E
M/@H*"@H*("`@(#PA+2T@4D5#55)324].(%=)5$@@14Y$0T].1$E43TXZ(&%D
M9&EN9R!S='EL92!C;&%S<V5S(&9O<B!A;&P@97AI<W1I;F<@8VAI;&1S("TM
M/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2=W<FET92US='EL97!R;W!E<G1Y
M+6QI;F5S+69O<BUC:&EL9')E;B<^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)S96%R8VA/;FQY26Y!=71O;6%T:6-3='EL97,B+SX*"B`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)P87)E;G13='EL94YA;64B("`@('-E;&5C=#TB
M0'-T>6QE.FYA;64B+SX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!A
M<F5N=%-T>6QE1F%M:6QY(B`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"@H@
M("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*'-E87)C:$]N;'E);D%U=&]M871I
M8U-T>6QE<RDB/@H@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB
M+BXO<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TD<&%R96YT4W1Y;&5&86UI
M;'D@86YD($!S='EL93IP87)E;G0M<W1Y;&4M;F%M93TD<&%R96YT4W1Y;&5.
M86UE72(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB=W)I=&4M<W1Y;&5P<F]P97)T>2UL:6YE(B\^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P97)T
M>2UL:6YE<RUF;W(M8VAI;&1R96XB+SX*("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@/'AS;#IF;W(M96%C
M:"!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL
M95M`<W1Y;&4Z9F%M:6QY/21P87)E;G13='EL949A;6EL>2!A;F0@0'-T>6QE
M.G!A<F5N="US='EL92UN86UE/21P87)E;G13='EL94YA;65=(CX*("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE<')O
M<&5R='DM;&EN92(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)W<FET92US='EL97!R;W!E<G1Y+6QI;F5S+69O
M<BUC:&EL9')E;B(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ9F]R+65A
M8V@^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)W<FET92UD969A=6QT+7-T>6QE<R(^"@H@("`@("`@(#PA+2T@<V]M
M92!D969A=6QT(&%T=')I8G5T97,@:6X@>&UL(&AA=F4@=&\@8F4@97AP;&EC
M:71L>2!S970@:6X@2%1-3"`H92YG+B!M87)G:6XM=&]P/2(P(BD@+2T^"B`@
M("`@("`@/'AS;#IT97AT/BHN3T]O7V1E9F%U;'1S/"]X<VPZ=&5X=#X*"B`@
M("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IS
M='EL97,O<W1Y;&4Z<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#XL(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H0'-T>6QE
M.FYA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ9F]R+65A8V@^"@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S
M96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL92(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/BP@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N
M8V%T*"<J+B<L('1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G
M)RDI(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@
M("`\(2TM(#)$3SH@=&AE(&1E9F%U;'1S(&UI9VAT(&)E(&)E='1E<B!C;VQL
M96-T960@86YD('=R:71T96X@:6X@82!S97!A<F%T960@*%A-3"D@9FEL92`M
M+3X*/'AS;#IT97AT/B!["B`@("`@("`@("`@("`@("!M87)G:6XM=&]P.C!C
M;3L@;6%R9VEN+6)O='1O;3HP8VT[('T*("`@("`@("`\+WAS;#IT97AT/@H*
M("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IS='EL97,O
M<W1Y;&4Z9&5F875L="US='EL92(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)W<FET92UD969A=6QT+7-T>6QE(B\^"B`@("`@("`@
M/"]X<VPZ9F]R+65A8V@^"@H@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T
M/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z9&5F875L="US='EL
M92(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET
M92UD969A=6QT+7-T>6QE(B\^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(G=R:71E+61E9F%U;'0M<W1Y;&4B/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB9F%M:6QY+7-T>6QE(B!S96QE8W0](D!S='EL93IF86UI;'DB+SX*
M"B`@("`@("`@/"$M+2!S;VUE(&1E9F%U;'0@871T<FEB=71E<R!F;W(@9F]R
M;6%T(&9A;6EL:65S("AE+F<N(&=R87!H:6-S+"!P87)A9W)A<&AS+"!E=&,N
M*2!W<FET=&5N(&%S('-T>6QE.F1E9F%U;'0M<W1Y;&4@+2T^"B`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H
M)&9A;6EL>2US='EL92P@)RX@)2@I+UPG+"`G)RDL("=?9&5F875L=',G*2(O
M/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IS='EL
M97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>2`]("1F86UI;'DM<W1Y;&5=
M(CX*("`@("`@("`@("`@/'AS;#IT97AT/BP@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N
M<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@
M(#PO>'-L.F9O<BUE86-H/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C
M=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL
M93IF86UI;'D@/2`D9F%M:6QY+7-T>6QE72(^"B`@("`@("`@("`@(#QX<VPZ
M=&5X=#XL(#PO>'-L.G1E>'0^"B`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*$!S='EL93IN86UE+"`G
M+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`\+WAS;#IF;W(M96%C:#X*"@H@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB<W1Y;&50<F]P97)T:65S(CX*
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T
M>6QE+7!R;W!E<G1I97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G-T>6QE071T<FEB=71E4&%T:"(@("!S96QE8W0](F-U<G)E
M;G0H*2]S='EL93IP<F]P97)T:65S+T`J(B\^"B`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@
M("`@(#PA+2T@9&\@;F]T('=R:71E('-T>6QE<R!W:71H(&YO(&-S<R!P<F]P
M97)T>2`M+3X*("`@("`@("`\>'-L.FEF('1E<W0](FYO="AS=')I;F<M;&5N
M9W1H*"1S='EL95!R;W!E<G1I97,I(#T@,"DB/@H@("`@("`@(#PA+2T@=&AE
M('-T>6QE('!R;W!E<G1I97,@;V8@=&AE(&9I<G-T('=R:71T96X@<W1Y;&4@
M*'!A<F5N="D@:7,@9VEV96X@;W5T("TM/@H@("`@("`@(#QX<VPZ=&5X=#X@
M>PH@("`@("`@("`@("`@("`@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@
M("`@("`@/'AS;#IT97AT/GT*("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@
M(#PO>'-L.FEF/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM*RL*
M("`@("`@("`@(%1H92!P87)E;G0@<W1Y;&4@=VEL;"!B92!W<FET=&5N(&]U
M="$*("`@("`@("`@($9O<B!E86-H(%-T>6QE.F9A;6EL>2!A('!R969I>"!M
M=7-T(&)E(&%D9&5D"B`@("`@("`@("`@(#PA14Y42519("4@<W1Y;&5&86UI
M;'D*("`@("`@("`@("`@(BAP87)A9W)A<&A\=&5X='QS96-T:6]N?'1A8FQE
M?'1A8FQE+6-O;'5M;GQT86)L92UR;W=\=&%B;&4M8V5L;'QT86)L92UP86=E
M?&-H87)T?&=R87!H:6-S?&1E9F%U;'1\9')A=VEN9RUP86=E?'!R97-E;G1A
M=&EO;GQC;VYT<F]L*2(^"B`@("`@("`@*RLM+3X*("`@(#QX<VPZ=&5M<&QA
M=&4@;F%M93TB=W)I=&4M<W1Y;&4M;F%M92(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)I<RUP87)E;G0M<W1Y;&4B+SX*"B`@("`@("`@/"$M+2!4:&ES
M(&-O;G-T<G5C="!I<R!F;W(@;&ES="!E;&5M96YT<RX@5VAE;F5V97(@82!P
M87)A9W)A<&@@96QE;65N="!I<R!B96EN9R!U<V5D(&%S(&-H:6QD(&]F(&$@
M;&ES="!E;&5M96YT('1H92!N86UE('!A<F%G<F%P:"!S='EL92!I<R!B965N
M('5S960@9F]R"B`@("`@("`@("`@('1H92!L:7-T(&ET96TN(%1H:7,@8V%N
M(&)E('-W:71C:&5D(&%S('1H92!P87)A9V%P:"!S='EL92UN86UE(&%N9"!T
M:&4@;&ES="US='EL92UN86UE(&%R92!I;B!T:&4@<V%M92!E;&5M96YT+@H@
M("`@("`@("`@("!/=&AE<G=I<V4@=&AE<F4@=V]U;&0@8F4@9F]R;6%T=&EN
M9R!E<G)O<G,@*&4N9RX@;6%R9VEN+6QE9G0@=VEL;"!B92!U<V5D(&9O<B!T
M:&4@8V]N=&5N="!I;B!T:&4@;&ES="!E;&UE;G0@86YD(&YO="!F;W(@=&AE
M(&QI<W0@96QE;65N="!I='-E;&8I+B`M+3X*("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](G-T>6QE+6YA;64B/@H@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z;&ES
M="US='EL92UN86UE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB0'-T>6QE.FQI<W0M<W1Y;&4M;F%M92(O/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X
M<VPZ=F%R:6%B;&4^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*"1I<RUP
M87)E;G0M<W1Y;&4I(CX*("`@("`@("`@("`@/'AS;#IT97AT/BP@/"]X<VPZ
M=&5X=#X*("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@(#PA+2T@;F]R;6%L;'D@)W`N)R!W;W5L9"!B92!U<V5D
M(&%S($-34R!E;&5M96YT+`H@("`@("`@("`@("`@("`@(&)U="!H96%D97(@
M*&@Q+"!H,BPN+BXI(&%R92!A;'-O(&9R;VT@=&AE('-T>6QE.F9A;6EL>2!P
M87)A9W)A<&@@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y
M;&4Z9F%M:6QY/2=P87)A9W)A<&@G(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL
M92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI
M;'D])W1E>'0G(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E
M*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W-E8W1I;VXG
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC
M870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G
M*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W1A8FQE)R(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"=T86)L92XG
M+"!T<F%N<VQA=&4H)'-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB0'-T>6QE.F9A;6EL>3TG=&%B;&4M8V]L=6UN)R(^"B`@("`@("`@
M("`@(#PA+2T@87,@8V]L=6UN('-T>6QE<R!H879E('1O(&)E(&EN8VQU9&5D
M(&%S('-P86X@<W1Y;&5S($%&5$52('1H92!T86)L92`H;F\@='=O(&-L87-S
M(&%T=')I8G5T97,@:6X@5$0@86QL;W=E9"`M+3X*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E
M*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL
M93IF86UI;'D])W1A8FQE+7)O=R<B/@H@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](F-O;F-A="@G='(N)RP@=')A;G-L871E*"1S='EL
M92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI
M;'D])W1A8FQE+6-E;&PG(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE
M+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W1A
M8FQE+7!A9V4G(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E
M*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])V-H87)T)R(^
M"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T
M*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=G<F%P:&EC<R<B/@H@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T
M<F%N<VQA=&4H)'-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB0'-T>6QE.F9A;6EL>3TG9&5F875L="<B/@H@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H
M)'-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE
M.F9A;6EL>3TG9')A=VEN9RUP86=E)R(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y
M;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M
M:6QY/2=P<F5S96YT871I;VXG(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN
M86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D]
M)V-O;G1R;VPG(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E
M*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M
M+2!F:6YD:6YG(&%L;"!S='EL92!C:&EL9"!O9B!A('-E8W1I;VX@86YD(&=I
M=F4@=&AE:7(@<W1Y;&5)9&5N=&EF:65R('1O('1H92!O=71P=70@+2T^"B`@
M("`\>'-L.G1E;7!L871E(&YA;64])W=R:71E+6-H:6QD<F5N+7-T>6QE+6YA
M;65S)SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M
M92(@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB('-E;&5C=#TB0'-T>6QE.F9A;6EL
M>2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T
M;VUA=&EC4W1Y;&5S(B\^"@H*("`@("`@("`\(2TM*BH@=&AE(&YA;65S(&]F
M(&%L;"!O9F9I8V4Z<W1Y;&5S(&-H:6QD<F5N('=I;&P@8F4@=W)I='1E;B!O
M=70*("`@("`@("`@("`@*BH@*&$@875T;VUA=&EC('-T>6QE(&-A;B!O;FQY
M(&AA=F4@8VAI;&1R96X@:6X@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&4@
M<V5C=&EO;BD@+2T^"@H@("`@("`@(#PA+2T@:68@3D]4(&-A;&QE9"!F<F]M
M(&$@;V9F:6-E.F%U=&]M871I8RUS='EL92!P87)E;G0@+2T^"B`@("`@("`@
M/'AS;#II9B!T97-T/2)N;W0H<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S
M*2(^"B`@("`@("`@("`@(#PA+2T@9F]R(&%L;"!C:&EL9')E;B!I;B!T:&4@
M;V9F:6-E.G-T>6QE('-E8W1I;VX@+2T^"B`@("`@("`@("`@(#QX<VPZ9F]R
M+65A8V@@<V5L96-T/2(N+B]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P
M87)E;G13='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE
M/21P87)E;G13='EL94YA;65=(CX*("`@("`@("`@("`@("`@(#PA+2T@=W)I
M=&4@=&AE('-T>6QE(&YA;64@:6X@=&AE(&-S<R!H96%D97(@+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y
M;&4M;F%M92(O/@H*("`@("`@("`@("`@("`@(#PA+2T@<V5A<F-H(&9O<B!C
M:&EL9"!S='EL97,@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB=W)I=&4M8VAI;&1R96XM<W1Y;&4M;F%M97,B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13
M='EL94YA;64B('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI
M;'DB('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@(#PO>'-L.F9O<BUE
M86-H/@H@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`\(2TM*BH@=&AE(&YA
M;65S(&]F(&%L;"!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!C:&EL9')E;B!W
M:6QL(&)E('=R:71T96X@;W5T("TM/@H*("`@("`@("`\(2TM(&9O<B!A;&P@
M8VAI;&1R96X@:6X@=&AE(&]F9FEC93IA=71O;6%T:6,M<W1Y;&4@<V5C=&EO
M;B`M+3X*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IA
M=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])'!A
M<F5N=%-T>6QE1F%M:6QY(&%N9"!`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64]
M)'!A<F5N=%-T>6QE3F%M95TB/@H@("`@("`@("`@("`\(2TM('=R:71E('1H
M92!S='EL92!N86UE(&EN('1H92!C<W,@:&5A9&5R("TM/@H@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&4M;F%M92(O
M/@H*("`@("`@("`@("`@/"$M+2!S96%R8V@@9F]R(&-H:6QD('-T>6QE<R`M
M+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E
M+6-H:6QD<F5N+7-T>6QE+6YA;65S(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B('-E;&5C=#TB0'-T
M>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)P87)E;G13='EL949A;6EL>2(@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY
M(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V5A
M<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H\+WAS;#IS='EL97-H965T/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V1E8BYP:'``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,S0P-P`Q,#4Q-30S,3`V,0`P,C$T-3,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-
M24U%7U9I97=E<E]D96(@8VQA<W,@<F5N9&5R<R!O=70@;&ES=',@;V8@9FEL
M97,@:6X@1&5B:6%N('!A8VMA9V5S(&)Y"B`J('5S:6YG('1H92!D<&MG('1O
M;VP@=&\@<75E<GD@=&AE('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<"QV(#$N,3$N,3`N."`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\
M86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R
M7V1E8B!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E
M;F1E<B!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@06YY('!A<F%M971E<G,@=&AE('9I97=E<B!M87D@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!G;&]B86P@)&UI;65?9')I=F5R<SL*"B`@("`@
M("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E('1H92!P<F]G<F%M(&%C='5A;&QY
M(&5X:7-T<RX@*B\*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)V1E8B==6R=L;V-A=&EO;B==*2D@>PH@("`@("`@
M("`@("!R971U<FX@)SQP<F4^)R`N('-P<FEN=&8H7R@B5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+B(I+"`D;6EM95]D<FEV97)S6R=H;W)D92==6R=D
M96(G75LG;&]C871I;VXG72D@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@
M("`@("1T;7!?9&5B(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=H;W)D95]D96(G
M*3L*"B`@("`@("`@)&9H(#T@9F]P96XH)'1M<%]D96(L("=W)RD["B`@("`@
M("`@9G=R:71E*"1F:"P@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H
M*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@("1F:"`]('!O<&5N
M*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V1E8B==6R=L;V-A=&EO;B==("X@
M(B`M9B`D=&UP7V1E8B`R/B8Q(BP@)W(G*3L*("`@("`@("!W:&EL92`H*"1R
M8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@("`@("`@("1D871A("X]
M("1R8SL*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F:"D["@H@("`@("`@
M(')E='5R;B`G/'!R93XG("X@:'1M;'-P96-I86QC:&%R<R@D9&%T82D@+B`G
M/"]P<F4^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@34E-
M12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@
M=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,
M4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,38Q,C8`,3`U,34T,S$P-C$`,#(Q-3`W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6
M:65W97)?<F%R(&-L87-S(')E;F1E<G,@;W5T('1H92!C;VYT96YT<R!O9B`N
M<F%R(&%R8VAI=F5S(&EN($A434P*("H@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`L=B`Q+C$X+C$P
M+CD@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@
M*B!`875T:&]R("!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R
M9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W)A<B!E>'1E
M;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)A<B!C;VUP<F5S
M<VEO;B!M971H;V1S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?;65T:&]D<R`](&%R<F%Y*`H@("`@("`@(#!X,S`@(#T^
M("`G4W1O<F4G+`H@("`@("`@(#!X,S$@(#T^("`G1F%S=&5S="<L"B`@("`@
M("`@,'@S,B`@/3X@("=&87-T)RP*("`@("`@("`P>#,S("`]/B`@)TYO<FUA
M;"<L"B`@("`@("`@,'@S-"`@/3X@("=';V]D)RP*("`@("`@("`P>#,U("`]
M/B`@)T)E<W0G"B`@("`I.PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T
M:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<R!U<VEN9R!R87(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H
M92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1C
M;VYT96YT<R`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"D["@H@
M("`@("`@("\J($UA:V4@<W5R92!T:&ES(&ES(&$@=F%L:60@<F%R(&9I;&4N
M("HO"B`@("`@("`@:68@*"1T:&ES+3YC:&5C:U)A<D1A=&$H)&-O;G1E;G1S
M*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!?
M*")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(I("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@)')A<D1A=&$@/2`D
M=&AI<RT^9V5T4F%R1&%T82@D8V]N=&5N=',I.PH@("`@("`@("1F:6QE0V]U
M;G0@/2!C;W5N="@D<F%R1&%T82D["@H@("`@("`@("1T97AT("`]("<\<W1R
M;VYG/B<@+B!H=&UL<W!E8VEA;&-H87)S*'-P<FEN=&8H7R@B0V]N=&5N=',@
M;V8@7"(E<UPB(BDL("1T:&ES+3YM:6UE7W!A<G0M/F=E=$YA;64H*2DI("X@
M)SH\+W-T<F]N9SXG("X@(EQN(CL*("`@("`@("`D=&5X="`N/2`G/'1A8FQE
M/CQT<CX\=&0@86QI9VX](FQE9G0B/CQT=#X\<W!A;B!C;&%S<STB9FEX960B
M/B<["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<RA?*")!
M<F-H:79E($YA;64B*2`N("<Z("`G("X@)'1H:7,M/FUI;65?<&%R="T^9V5T
M3F%M92@I*2`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L
M;%-P86-E<RA?*")!<F-H:79E($9I;&4@4VEZ92(I("X@)SH@)R`N('-T<FQE
M;B@D8V]N=&5N=',I("X@)R!B>71E<R<I("X@(EQN(CL*("`@("`@("`D=&5X
M="`N/2!497AT.CIH=&UL06QL4W!A8V5S*"@D9FEL94-O=6YT("$](#$I(#\@
M<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE<R(I+"`D9FEL94-O=6YT
M*2`Z('-P<FEN=&8H7R@B1FEL92!#;W5N=#H@)7,@9FEL92(I+"`D9FEL94-O
M=6YT*2D["B`@("`@("`@)'1E>'0@+CT@(EQN7&XB.PH@("`@("`@("1T97AT
M("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@("`@("`@("`@
M('-T<E]P860H7R@B1FEL92!.86UE(BDL("`@("`U,"P@)R`G+"!35%)?4$%$
M7U))1TA4*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B071T
M<FEB=71E<R(I+"`@("`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@
M("`@("`@("`@("`@("`@<W1R7W!A9"A?*")3:7IE(BDL("`@("`@("`@(#$P
M+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("!S
M=')?<&%D*%\H(DUO9&EF:65D($1A=&4B*2P@,3DL("<@)RP@4U127U!!1%],
M1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B365T:&]D
M(BDL("`@("`@("`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@
M("`@("`@("`@("`@<W1R7W!A9"A?*")2871I;R(I+"`@("`@("`@("`W+"`G
M("<L(%-44E]0041?3$5&5"D*("`@("`@("`@("`@("`@("`I("X@(EQN(CL*
M"B`@("`@("`@)'1E>'0@+CT@<W1R7W)E<&5A="@G+2<L(#$P-BD@+B`B7&XB
M.PH*("`@("`@("!F;W)E86-H("@D<F%R1&%T82!A<R`D=F%L*2!["B`@("`@
M("`@("`@("1R871I;R`]("AE;7!T>2@D=F%L6R=S:7IE)UTI*2`_(#`@.B`Q
M,#`@*B`H)'9A;%LG8W-I>F4G72`O("1V86Q;)W-I>F4G72D["B`@("`@("`@
M("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')?<&%D*"1V86Q;)VYA;64G72P@-3`L("<@)RP@
M4U127U!!1%]224=(5"D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@<W1R
M7W!A9"@D=F%L6R=A='1R)UTL(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D=F%L6R=S:7IE)UTL
M(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R7W!A9"AS=')F=&EM92@B)60M)6(M)5D@)4@Z)4TB+"`D=F%L
M6R=D871E)UTI+"`Q.2P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<E]P860H)'9A;%LG;65T:&]D)UTL(#$P+"`G
M("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M<W1R7W!A9"AS<')I;G1F*"(E,2XQ9B4E(BP@)')A=&EO*2P@-RP@)R`G+"!3
M5%)?4$%$7TQ%1E0I"B`@("`@("`@("`@("`@("`@("`@("D@+B`B7&XB.PH@
M("`@("`@('T*"B`@("`@("`@)'1E>'0@+CT@<W1R7W)E<&5A="@G+2<L(#$P
M-BD@+B`B7&XB.PH@("`@("`@("1T97AT("X]("<\+W-P86X^/"]T=#X\+W1D
M/CPO='(^/"]T86)L93XG.PH*("`@("`@("!R971U<FX@;FPR8G(H)'1E>'0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@34E-12!T>7!E
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE($U)344@='EP92!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL
M.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!T;R!S964@:68@=&AE(&1A=&$@:7,@82!V86QI
M9"!287(@87)C:&EV92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D
M9&%T82`@5&AE(')A<B!A<F-H:79E(&1A=&$N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&EF('9A;&ED+"!F86QS92!I9B!I;G9A;&ED
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&5C:U)A<D1A=&$H)B1D871A*0H@
M("`@>PH@("`@("`@("1F:6QE2&5A9&5R(#T@(EQX-3)<>#8Q7'@W,EQX,C%<
M>#%A7'@P-UQX,#`B.PH@("`@("`@(&EF("AS=')P;W,H)&1A=&$L("1F:6QE
M2&5A9&5R*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@;&ES="!O
M9B!F:6QE<R]D871A(&9R;VT@=&AE(')A<B!A<F-H:79E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@<F%R(&%R8VAI=F4@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!+15DZ(%!O<VET:6]N
M(&EN(%)!4B!A<F-H:79E"B`@("`@*B`@("`@("`@("`@("`@("!604Q515,Z
M("=A='1R)R`@("`M+2`@1FEL92!A='1R:6)U=&5S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("=D871E)R`@("`M+2`@1FEL92!M;V1I9FEC871I
M;VX@=&EM90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G8W-I>F4G
M("`@+2T@($-O;7!R97-S960@9FEL92!S:7IE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("=M971H;V0G("`M+2`@0V]M<')E<W-I;VX@;65T:&]D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@("`M+2`@
M1FEL96YA;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)W-I>F4G
M("`@("TM("!/<FEG:6YA;"!F:6QE('-I>F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4F%R1&%T82@F)&1A=&$I"B`@("!["B`@("`@("`@)')E='5R;E]A
M<G)A>2`](&%R<F%Y*"D["@H@("`@("`@("1B;&]C:U-T87)T(#T@<W1R<&]S
M*"1D871A+"`B7'@U,EQX-C%<>#<R7'@R,5QX,6%<>#`W7'@P,"(I.PH@("`@
M("`@("1P;W-I=&EO;B`]("1B;&]C:U-T87)T("L@-SL*"B`@("`@("`@=VAI
M;&4@*"1P;W-I=&EO;B`\('-T<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@
M)&AE861?8W)C("`@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K(#`L(#(I
M.PH@("`@("`@("`@("`D:&5A9%]T>7!E("`](&]R9"AS=6)S='(H)&1A=&$L
M("1P;W-I=&EO;B`K(#(L(#$I*3L*("`@("`@("`@("`@)&AE861?9FQA9W,@
M/2!U;G!A8VLH)W9&;&%G<R<L('-U8G-T<B@D9&%T82P@)'!O<VET:6]N("L@
M,RP@,BDI.PH@("`@("`@("`@("`D:&5A9%]F;&%G<R`]("1H96%D7V9L86=S
M6R=&;&%G<R==.PH@("`@("`@("`@("`D:&5A9%]S:7IE("`]('5N<&%C:R@G
M=E-I>F4G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K(#4L(#(I*3L*("`@
M("`@("`@("`@)&AE861?<VEZ92`@/2`D:&5A9%]S:7IE6R=3:7IE)UT["@H@
M("`@("`@("`@("`D<&]S:71I;VX@*ST@-SL*("`@("`@("`@("`@)&AE861?
M<VEZ92`M/2`W.PH*("`@("`@("`@("`@<W=I=&-H("@D:&5A9%]T>7!E*2![
M"@H@("`@("`@("`@("!C87-E(#!X-S,Z"B`@("`@("`@("`@("`@("`O*B!!
M<F-H:79E(&AE861E<B`J+PH@("`@("`@("`@("`@("`@)'!O<VET:6]N("L]
M("1H96%D7W-I>F4["@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(#!X-S0Z"B`@("`@("`@("`@("`@("`D9FEL92`](&%R<F%Y
M*"D["@H@("`@("`@("`@("`@("`@+RH@1FEL92!(96%D97(@*B\*("`@("`@
M("`@("`@("`@("1I;F9O(#T@=6YP86-K*"=64&%C:V5D+U95;G!A8VME9"]#
M3U,O5D-20S,R+U94:6UE+T-697)S:6]N+T--971H;V0O=DQE;F=T:"]V071T
M<FEB)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VXI*3L*"B`@("`@("`@("`@
M("`@("`D9FEL95LG;F%M92==(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VX@
M*R`R-2P@)&EN9F];)TQE;F=T:"==*3L*("`@("`@("`@("`@("`@("1F:6QE
M6R=S:7IE)UT@/2`D:6YF;ULG56YP86-K960G73L*("`@("`@("`@("`@("`@
M("1F:6QE6R=C<VEZ92==(#T@)&EN9F];)U!A8VME9"==.PH*("`@("`@("`@
M("`@("`@("1F:6QE6R=D871E)UT@/2!M:W1I;64H*"@D:6YF;ULG5&EM92==
M(#X^(#$Q*2`F(#!X,68I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@/CX@-2D@)B`P>#-F*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"@D:6YF;ULG
M5&EM92==(#P\(#$I("8@,'@S92DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("@H)&EN9F];)U1I;64G72`^/B`R,2D@)B`P>#`W
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"@D
M:6YF;ULG5&EM92==(#X^(#$V*2`F(#!X,68I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`H*"@D:6YF;ULG5&EM92==(#X^(#(U
M*2`F(#!X-V8I("L@.#`I*3L*"B`@("`@("`@("`@("`@("`D9FEL95LG;65T
M:&]D)UT@/2`D=&AI<RT^7VUE=&AO9'-;)&EN9F];)TUE=&AO9"==73L*"B`@
M("`@("`@("`@("`@("`D9FEL95LG871T<B==("`]("<G.PH@("`@("`@("`@
M("`@("`@)&9I;&5;)V%T='(G72`N/2`H)&EN9F];)T%T=')I8B==("8@,'@Q
M,"D@/R`G1"<@.B`G+2<["B`@("`@("`@("`@("`@("`D9FEL95LG871T<B==
M("X]("@D:6YF;ULG071T<FEB)UT@)B`P>#(P*2`_("=!)R`Z("<M)SL*("`@
M("`@("`@("`@("`@("1F:6QE6R=A='1R)UT@+CT@*"1I;F9O6R=!='1R:6(G
M72`F(#!X,#,I(#\@)U,G(#H@)RTG.PH@("`@("`@("`@("`@("`@)&9I;&5;
M)V%T='(G72`N/2`H)&EN9F];)T%T=')I8B==("8@,'@P,BD@/R`G2"<@.B`G
M+2<["B`@("`@("`@("`@("`@("`D9FEL95LG871T<B==("X]("@D:6YF;ULG
M071T<FEB)UT@)B`P>#`Q*2`_("=2)R`Z("<M)SL*"B`@("`@("`@("`@("`@
M("`D<F5T=7)N7V%R<F%Y6UT@/2`D9FEL93L*"B`@("`@("`@("`@("`@("`D
M<&]S:71I;VX@*ST@)&AE861?<VEZ93L*("`@("`@("`@("`@("`@("1P;W-I
M=&EO;B`K/2`D:6YF;ULG4&%C:V5D)UT["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D<&]S
M:71I;VX@*ST@)&AE861?<VEZ93L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D861D7W-I>F4I*2!["B`@("`@("`@("`@("`@("`@("`@)'!O<VET:6]N
M("L]("1A9&1?<VEZ93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R971U<FY?87)R87D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'``````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C4P,``Q,#4Q-30S,3`V,0`P,C$W,C0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%
M7U9I97=E<E]R9F,X,C(@8VQA<W,@<F5N9&5R<R!O=70@;65S<V%G97,@9G)O
M;2!T:&4*("H@;65S<V%G92]R9F,X,C(@8V]N=&5N="!T>7!E+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`L
M=B`Q+C@N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?<F9C.#(R(&5X
M=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U
M="!T:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@=VET:"!A;GD@<&%R86UE
M=&5R<R!N965D960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96YD97)E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'!A<G0@/2`D=&AI
M<RT^;6EM95]P87)T.PH@("`@("`@("1P87)T+3YT<F%N<V9E<D1E8V]D94-O
M;G1E;G1S*"D["@H@("`@("`@("1T97AT(#T@)'!A<G0M/F=E=$-O;G1E;G1S
M*"D["B`@("`@("`@:68@*"$D=&5X="D@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@("`@("`@
M)&-O;G1E;G1S(#T@)FYE=R!-24U%7T-O;G1E;G1S*&YE=R!-24U%7U!A<G0H
M*2D["B`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=',M/F9O<FUA=%-T871U
M<TUS9RA?*")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1E>'0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5N9&5R(&]U="!A='1A8VAM96YT(&EN9F]R;6%T:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!W:71H(&%N>2!P
M87)A;65T97)S(&YE961E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(')E;F1E<F5D('1E>'0@:6X@2%1-3"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N9&5R071T86-H;65N=$EN9F\H)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@)&US9R`]("<G.PH*("`@("`@("`O*B!'970@=&AE
M('1E>'0@;V8@=&AE('!A<G0N("!3:6YC92!W92!N965D('1O(&QO;VL@9F]R
M('1H92!E;F0@;V8*("`@("`@("`@*B!T:&4@:&5A9&5R<R!B>2!S96%R8VAI
M;F<@9F]R('1H92!#4DQ&0U),1B!S97%U96YC92P@=7-E"B`@("`@("`@("H@
M9V5T0V%N;VYI8V%L0V]N=&5N=',H*2!T;R!M86ME('-U<F4@=V4@87)E(&=E
M='1I;F<@=&AE('1E>'0@=VET:`H@("`@("`@("`J($-23$8G<RX@*B\*("`@
M("`@("`D=&5X="`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-A;F]N:6-A;$-O
M;G1E;G1S*"D["@H@("`@("`@("\J(%-E87)C:"!F;W(@=&AE(&5N9"!O9B!T
M:&4@:&5A9&5R('1E>'0@*$-23$9#4DQ&*2X@*B\*("`@("`@("`D=&5X="`]
M('-U8G-T<B@D=&5X="P@,"P@<W1R<&]S*"1T97AT+"`B7')<;EQR7&XB*2D[
M"@H@("`@("`@("\J($=E="!T:&4@;&ES="!O9B!H96%D97)S(&YO=RX@*B\*
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H
M<"<["B`@("`@("`@)&AE861E<G,@/2!-24U%7U-T<G5C='5R93HZ<&%R<V5-
M24U%2&5A9&5R<R@D=&5X="P@=')U92P@=')U92D["@H@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O34E-12]#;VYT96YT<RYP:'`G.PH@("`@("`@("1C
M;VYT96YT<R`]("9N97<@34E-15]#;VYT96YT<RAN97<@34E-15]087)T*"DI
M.PH@("`@("`@("1M<V<@/2`D8V]N=&5N=',M/F9O<FUA=%-T871U<TUS9RA?
M*")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+B(I+"!(;W)D93HZ:6UG*"=I;F9O7VEC;VXN
M<&YG)RP@7R@B26YF;R(I+"`G:&5I9VAT/2(Q-B(@=VED=&@](C$V(B<L("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2DL(&9A
M;'-E*3L*"B`@("`@("`@)&US9R`N/2`G/'-P86X@8VQA<W,](F9I>&5D(CXG
M.PH*("`@("`@("`D:&5A9&5R7V%R<F%Y(#T@87)R87DH"B`@("`@("`@("`@
M("=D871E)R`]/B!?*")$871E(BDL"B`@("`@("`@("`@("=S=6)J96-T)R`]
M/B!?*")3=6)J96-T(BDL"B`@("`@("`@("`@("=F<F]M)R`]/B!?*")&<F]M
M(BDL"B`@("`@("`@("`@("=T;R<@/3X@7R@B5&\B*0H@("`@("`@("D["B`@
M("`@("`@)&AE861E<E]O=71P=70@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E
M86-H("@D:&5A9&5R7V%R<F%Y(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)&AE861E<G-;)&ME>5TI*2!["B`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)&AE861E<G-;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&AE861E<G-;)&ME>5T@/2`D:&5A9&5R<ULD:V5Y75LP
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1H96%D97)?
M;W5T<'5T6UT@/2`G/'-T<F]N9SXG("X@)'9A;"`N("<Z/"]S=')O;F<^("<@
M+B`D:&5A9&5R<ULD:V5Y73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH@
M("`@("`@("1M<V<@+CT@:6UP;&]D92@B/&)R("\^7&XB+"!497AT7T9I;'1E
M<CHZ9FEL=&5R*"1H96%D97)?;W5T<'5T+"`G96UA:6QS)RDI("X@)SPO<W!A
M;CXG.PH*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@9F]R('1H92!R96YD
M97)E9"!D871A+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M8V]N=&5N="!T>7!E(&]F('1H92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O<&QA:6X[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M24U%+U9I97=E<B]P;&%I;BYP:'``````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#4T-S8`,3`U,34T,S$P-C$`,#(R,#,T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-
M15]6:65W97)?<&QA:6X@8VQA<W,@<F5N9&5R<R!O=70@<&QA:6X@=&5X="!W
M:71H(%523',@;6%D90H@*B!I;G1O(&AY<&5R;&EN:W,@*&EF('9I97=I;F<@
M:6YL:6YE*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]P;&%I;BYP:'`L=B`Q+C$X+C8N,3`@,C`P-B\P,2\R,R`Q-3HS-3HP
M-B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI
M;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT
M(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D
M9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS
M"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%
M7U9I97=E<E]P;&%I;B!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*
M("`@("`J(%)E;F1E<B!O=70@=&AE(&-O;G1E;G1S+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE
M=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*"B`@("`@("`@)'1E
M>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH*("`@("`@
M("`O*B!#:&5C:R!F;W(@)V9L;W=E9"<@=&5X="!D871A+B`J+PH@("`@("`@
M("1F;&]W960@/2`H)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=%1Y<&50
M87)A;65T97(H)V9O<FUA="<I(#T]("=F;&]W960G*3L*("`@("`@("!I9B`H
M)&9L;W=E9"D@>PH@("`@("`@("`@("`D=&5X="`]("1T:&ES+3Y?9F]R;6%T
M1FQO=V5D*"1T97AT*3L*("`@("`@("!]"@H@("`@("`@("\J($EF(&-A;&QI
M;F<@87,@86X@871T86-H;65N="!F<F]M('9I97<N<&AP+"!W92!D;R!N;W0@
M=V%N=`H@("`@("`@("`@('1O(&%L=&5R('1H92!T97AT(&EN(&%N>2!W87D@
M=VET:"!(5$U,+B`J+PH@("`@("`@(&EF("A-24U%7T-O;G1E;G1S.CIV:65W
M07-!='1A8VAM96YT*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T97AT.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`@("`@<F5T=7)N(%1E>'1?
M1FEL=&5R.CIF:6QT97(H)'1E>'0L("=T97AT,FAT;6PG+"!A<G)A>2@G<&%R
M<V5L979E;"<@/3X@5$585%](5$U,7TU)0U)/+"`G8VAA<G-E="<@/3X@;G5L
M;"P@)V-L87-S)R`]/B!N=6QL*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@
M<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@("!R971U<FX@
M*$U)345?0V]N=&5N=',Z.G9I97=!<T%T=&%C:&UE;G0H*2D@/R`D=&AI<RT^
M;6EM95]P87)T+3YG9714>7!E*'1R=64I(#H@)W1E>'0O:'1M;#L@8VAA<G-E
M=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&;W)M870@9FQO=V5D('1E>'0@9F]R($A434P@;W5T<'5T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@5&AE('1E>'0@=&\@9F]R
M;6%T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]P="`@("!4:&4@;W!T:6UA
M;"!L96YG=&@@=&\@=W)A<"X*("`@("`J($!P87)A;2!I;G1E9V5R("1M87@@
M("`@5&AE(&UA>&EM=6T@;&5N9W1H('1O('=R87`N(#`@;65A;G,@9&]N)W0@
M=W)A<"X*("`@("`J($!P87)A;2!B;V]L96%N("1D96QS<"`@5V%S('1E>'0@
M8W)E871E9"!W:71H($1E;%-P(&9O<FUA='1I;F<_"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@=&5X="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V9O<FUA=$9L;W=E9"@D=&5X="P@)&]P="`](&YU;&PL
M("1M87@@/2!N=6QL+"`D9&5L<W`@/2!N=6QL*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G5&5X="]&;&]W960N<&AP)SL*("`@("`@("`D9FQO=V5D
M(#T@)FYE=R!497AT7T9L;W=E9"@D=&AI<RT^;6EM95]P87)T+3YR97!L86-E
M14],*"1T97AT+"`B7&XB*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T0VAA<G-E
M="@I*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)&]P="DI('L*("`@("`@("`@
M("`@)&9L;W=E9"T^<V5T3W!T3&5N9W1H*"1O<'0I.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES7VYU;&PH)&UA>"DI('L*("`@("`@("`@("`@)&9L;W=E
M9"T^<V5T36%X3&5N9W1H*"1M87@I.PH@("`@("`@('T*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&1E;'-P*2D@>PH@("`@("`@("`@("`D9FQO=V5D+3YS971$
M96Q3<"@D9&5L<W`I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&9L;W=E
M9"T^=&]&:7AE9"@I.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V-S<RYP
M:'``````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C<P-0`Q,#4Q-30S
M,3`V,0`P,C$U,34`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O<V]U<F-E+G!H<"<["@HO*BH*("H@5&AE($U)345?5FEE=V5R7V-S
M<R!C;&%S<R!R96YD97)S($-34R!S;W5R8V4@87,@2%1-3"!W:71H(&%N(&5F
M9F]R=`H@*B!T;R!R96UO=F4@<&]T96YT:6%L;'D@;6%L:6-I;W5S(&-O9&4N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O8W-S
M+G!H<"QV(#$N,2XQ,"XX(#(P,#8O,#8O,#$@,#,Z,#@Z-3,@8VAU8VL@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO
M"F-L87-S($U)345?5FEE=V5R7V-S<R!E>'1E;F1S($U)345?5FEE=V5R7W-O
M=7)C92!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT
M;'D@<V5T(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@=FEE=V5R(&UA>2!N965D+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1C<W,@/2!H=&UL<W!E8VEA;&-H87)S*"1T:&ES
M+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DL($5.5%].3U%53U1%4RD["B`@
M("`@("`@)&-S<R`]('!R96=?<F5P;&%C95]C86QL8F%C:R@G(2A]?%PJ+RDN
M*C\H>WPO7"HI(7,G+"!A<G)A>2@D=&AI<RP@)U]H86YD;&5S)RDL("1C<W,I
M.PH@("`@("`@("1C<W,@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH)R%[6UY]
M72I](7,G+"!A<G)A>2@D=&AI<RP@)U]A='1R:6)U=&5S)RDL("1C<W,I.PH@
M("`@("`@("1C<W,@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH)R$O7"HN*C]<
M*B\A<R<L(&%R<F%Y*"1T:&ES+"`G7V-O;6UE;G1S)RDL("1C<W,I.PH@("`@
M("`@("1C<W,@/2!T<FEM*"1C<W,I.PH*("`@("`@("`O+R!%9'5C871E9"!'
M=65S<R!A="!W:&5T:&5R('=E(&%R92!I;FQI;F4@;W(@;F]T+@H@("`@("`@
M(&EF("AH96%D97)S7W-E;G0H*2!\?"!O8E]G971?;&5N9W1H*"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YL:6YE3G5M8F5R*"1C<W,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!5=&EL.CIB=69F97)/
M=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T
M96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+6AE861E<BYI;F,G*2`N
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&EN94YU;6)E<B@D8W-S*2`N"B`@
M("`@("`@("`@("`@("!5=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G
M*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7V-O;6UE;G1S*"1M871C:&5S*0H@("`@>PH@("`@("`@
M("1P871T97)N<UM=(#T@)R$H:'1T<#HO+ULO7'<M+ETK*2%S)SL*("`@("`@
M("`D<F5P;&%C97-;72`]("<\82!H<F5F/2)<7#$B/EQ<,3PO83XG.PH*("`@
M("`@("`D8V]M;65N=',@/2!P<F5G7W)E<&QA8V4H)'!A='1E<FYS+"`D<F5P
M;&%C97,L("1M871C:&5S6S!=*3L*"B`@("`@("`@<F5T=7)N("<\<W!A;B!C
M;&%S<STB8V]M;65N="(^)R`N("1C;VUM96YT<R`N("<\+W-P86X^)SL*("`@
M('T*"B`@("!F=6YC=&EO;B!?871T<FEB=71E<R@D;6%T8VAE<RD*("`@('L*
M("`@("`@("`O+R!!='1R:6)U=&5S+@H@("`@("`@("1P871T97)N<UM=(#T@
M)R$H6RU<=UTK7',J*3HA<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G/'-P
M86X@8VQA<W,](F%T='(B(CY<7#$\+W-P86X^.B<["@H@("`@("`@("\O(%9A
M;'5E<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A.BA<<RHI*"XK/RDH7',J
M.RDA<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G.EQ<,3QS<&%N(&-L87-S
M/2)V86QU92(^7%PR/"]S<&%N/CQS<&%N(&-L87-S/2)E;VPB/EQ<,SPO<W!A
M;CXG.PH*("`@("`@("`O+R!54DQS+@H@("`@("`@("1P871T97)N<UM=(#T@
M)R$H=7)L7"A;7"<B73\I*"XJ/RDH6UPG(ET_7"DI(7,G.PH@("`@("`@("1R
M97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)U<FPB/EQ<,3QS<&%N(&-L87-S
M/2)F:6QE(CY<7#(\+W-P86X^7%PS/"]S<&%N/B<["@H@("`@("`@("\O($-O
M;&]R<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A*"-;6SIX9&EG:70Z75U[
M,RPV?2DA<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G/'-P86X@8VQA<W,]
M(F-O;&]R(CY<7#$\+W-P86X^)SL*"B`@("`@("`@+R\@4&%R96YT:&5S97,N
M"B`@("`@("`@)'!A='1E<FYS6UT@/2`G(2A[?'TI(7,G.PH@("`@("`@("1R
M97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)P87)E;G1H97-E<R(^7%PQ/"]S
M<&%N/B<["@H@("`@("`@("\O(%5N:71Y+@H@("`@("`@("1P871T97)N<UM=
M(#T@)R$H96U\<'A\)2E<8B%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\
M96T^7%PQ/"]E;3XG.PH*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"1P
M871T97)N<RP@)')E<&QA8V5S+"`D;6%T8VAE<ULP72D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7VAA;F1L97,H)&UA=&-H97,I"B`@("!["B`@("`@("`@+R\@
M2%1-3"!486=S+@H@("`@("`@("1P871T97)N<UM=(#T@)R%<8BAB;V1Y?&A<
M9'QA?'-P86Y\9&EV?&%C<F]N>6U\<VUA;&Q\<W1R;VYG?&5M?'!R97QU;'QO
M;'QL:7QP*5QB(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L
M87-S/2)H=&%G(CY<7#$\+W-P86X^7%PR)SL*"B`@("`@("`@+R\@241S+@H@
M("`@("`@("1P871T97)N<UM=(#T@)R$H(ULM7'==*RDA<R<["B`@("`@("`@
M)')E<&QA8V5S6UT@/2`G/'-P86X@8VQA<W,](FED(CY<7#$\+W-P86X^)SL*
M"B`@("`@("`@+R\@0VQA<W,N"B`@("`@("`@)'!A='1E<FYS6UT@/2`G(2A<
M+ELM7'==*RE<8B%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A;B!C
M;&%S<STB8VQA<W,B/EQ<,3PO<W!A;CXG.PH*("`@("`@("`O+R!-151!<RX*
M("`@("`@("`D<&%T=&5R;G-;72`]("<A*#IL:6YK?#IV:7-I=&5D?#IH;W9E
M<GPZ86-T:79E?#IF:7)S="UL971T97(I(7,G.PH@("`@("`@("1R97!L86-E
M<UM=(#T@)SQS<&%N(&-L87-S/2)M971A8R(^7%PQ/"]S<&%N/B<["@H@("`@
M("`@(')E='5R;B!P<F5G7W)E<&QA8V4H)'!A='1E<FYS+"`D<F5P;&%C97,L
M("1M871C:&5S6S!=*3L*("`@('T*"GT*````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]E;G-C
M<FEP="YP:'``````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<V-34`,3`U,34T
M,S$P-C$`,#(R-38Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+W-O=7)C92YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]E
M;G-C<FEP="!C;&%S<R!R96YD97)S(&]U="!V87)I;W5S(&-O;G1E;G0*("H@
M:6X@2%1-3"!F;W)M870@8GD@=7-I;F<@1TY5($5N<V-R:7!T+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H
M<"QV(#$N,SDN,3`N."`R,#`V+S`V+S`Q(#`S.C`X.C4S(&-H=6-K($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@
M*B\*8VQA<W,@34E-15]6:65W97)?96YS8W)I<'0@97AT96YD<R!-24U%7U9I
M97=E<E]S;W5R8V4@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@
M9&%T82!U<VEN9R!%;G-C<FEP="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!G;&]B86P@)&UI;65?9')I=F5R<SL*
M"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E('1H92!P<F]G<F%M(&%C
M='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VQO8V%T:6]N)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VQO8V%T:6]N)UTI("X@)SPO<')E/B<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<&]R87)Y(&9I;&5S
M(&9O<B!I;G!U="!T;R!%;G-C<FEP="X@3F]T92!T:&%T('=E"B`@("`@("`@
M("`@8V%N;F]T('5S92!A('!I<&4L('-I;F-E(&5N<V-R:7!T(&UU<W0@:&%V
M92!A8V-E<W,@=&\@=&AE"B`@("`@("`@("`@=VAO;&4@9FEL92!T;R!D971E
M<FUI;F4@:71S('1Y<&4@9F]R(&-O;&]U<F5D('-Y;G1A>`H@("`@("`@("`@
M(&AI9VAL:6=H=&EN9RX@*B\*("`@("`@("`D=&UP:6X@/2!(;W)D93HZ9V5T
M5&5M<$9I;&4H)T5N<V-R:7!T26XG*3L*"B`@("`@("`@+RH@5W)I=&4@=&AE
M(&-O;G1E;G1S(&]F(&]U<B!B=69F97(@=&\@=&AE('1E;7!O<F%R>2!I;G!U
M="!F:6QE+B`J+PH@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$-O;G1E;G1S*"D["B`@("`@("`@)&9H(#T@9F]P96XH)'1M<&EN
M+"`G=V(G*3L*("`@("`@("!F=W)I=&4H)&9H+"`D8V]N=&5N=',L('-T<FQE
M;B@D8V]N=&5N=',I*3L*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@
M+RH@17AE8W5T92!T:&4@96YS8W)I<'0@8V]M;6%N9"X@*B\*("`@("`@("`D
M;&%N9R`](&5S8V%P97-H96QL87)G*"1T:&ES+3Y?='EP951O3&%N9R@D=&AI
M<RT^;6EM95]P87)T+3YG9714>7!E*"DI*3L*("`@("`@("`D<F5S=6QT<R`]
M('-H96QL7V5X96,H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YS8W)I<'0G
M75LG;&]C871I;VXG72`N("(@+44D;&%N9R`M+6QA;F=U86=E/6AT;6P@+2UC
M;VQO<B`M+6]U='!U=#TM(#P@)'1M<&EN(BD["@H@("`@("`@("\J(%-T<FEP
M(&]U="!T:&4@97AT<F%N96]U<R!(5$U,(&9R;VT@16YS8W)I<'0L(&%N9"!O
M=71P=70@:70N("HO"B`@("`@("`@)')E<U]A<G(@/2!P<F5G7W-P;&ET*"<O
M7#Q<+S]P<F5</B]I)RP@)')E<W5L=',I.PH@("`@("`@(&EF("AC;W5N="@D
M<F5S7V%R<BD@/3T@,RD@>PH@("`@("`@("`@("`D<F5S=6QT<R`]('1R:6TH
M)')E<U]A<G);,5TI.PH@("`@("`@('T*"B`@("`@("`@+RH@161U8V%T960@
M1W5E<W,@870@=VAE=&AE<B!W92!A<F4@:6YL:6YE(&]R(&YO="X@*B\*("`@
M("`@("!I9B`H:&5A9&5R<U]S96YT*"D@?'P@;V)?9V5T7VQE;F=T:"@I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;&EN94YU;6)E<B@D<F5S=6QT
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%5T:6PZ
M.F)U9F9E<D]U='!U="@G<F5Q=6ER92<L("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<I("X*("`@("`@("`@("`@("`@("1T:&ES+3YL:6YE3G5M8F5R*"1R
M97-U;'1S*2`N"B`@("`@("`@("`@("`@("!5=&EL.CIB=69F97)/=71P=70H
M)W)E<75I<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T
M97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!D971E<FUI
M;F4@=VAA="!L86YG=6%G92!T;R!U<V4@9F]R('1H92!E;G-C<FEP="!P<F]G
M<F%M"B`@("`@*B!F<F]M(&$@34E-12!T>7!E+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y
M<&4@(%1H92!-24U%('1Y<&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!E;G-C<FEP="`G;&%N9W5A9V4G('!A<F%M971E<B!S=')I;F<N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T>7!E5&],86YG*"1T>7!E*0H@("`@
M>PH@("`@("`@(&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO36%G:6,N<&AP)SL*"B`@("`@("`@)&5X="`]($U)345?36%G:6,Z.DU)
M3454;T5X="@D='EP92D["@H@("`@("`@('-W:71C:"`H)&5X="D@>PH@("`@
M("`@(&-A<V4@)V-S)SH*("`@("`@("`@("`@<F5T=7)N("=J879A)SL*"B`@
M("`@("`@8V%S92`G96PG.@H@("`@("`@("`@("!R971U<FX@)V5L:7-P)SL*
M"B`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@(')E='5R;B`G8R<["@H@
M("`@("`@(&-A<V4@)T,G.@H@("`@("`@(&-A<V4@)T@G.@H@("`@("`@(&-A
M<V4@)V-C)SH*("`@("`@("!C87-E("=H:"<Z"B`@("`@("`@8V%S92`G8RLK
M)SH*("`@("`@("!C87-E("=C>'@G.@H@("`@("`@(&-A<V4@)V-P<"<Z"B`@
M("`@("`@("`@(')E='5R;B`G8W!P)SL*"B`@("`@("`@8V%S92`G:'1M)SH*
M("`@("`@("!C87-E("=S:'1M;"<Z"B`@("`@("`@8V%S92`G>&UL)SH*("`@
M("`@("`@("`@<F5T=7)N("=H=&UL)SL*"B`@("`@("`@8V%S92`G:G,G.@H@
M("`@("`@("`@("!R971U<FX@)VIA=F%S8W)I<'0G.PH*("`@("`@("!C87-E
M("=P87,G.@H@("`@("`@("`@("!R971U<FX@)W!A<V-A;"<["@H@("`@("`@
M(&-A<V4@)V%L)SH*("`@("`@("!C87-E("=C9VDG.@H@("`@("`@(&-A<V4@
M)W!L)SH*("`@("`@("!C87-E("=P;2<Z"B`@("`@("`@("`@(')E='5R;B`G
M<&5R;"<["@H@("`@("`@(&-A<V4@)W!S)SH*("`@("`@("`@("`@<F5T=7)N
M("=P;W-T<V-R:7!T)SL*"B`@("`@("`@8V%S92`G=F(G.@H@("`@("`@("`@
M("!R971U<FX@)W9B82<["@H@("`@("`@(&-A<V4@)W9H9"<Z"B`@("`@("`@
M("`@(')E='5R;B`G=FAD;"<["@H@("`@("`@(&-A<V4@)W!A=&-H)SH*("`@
M("`@("!C87-E("=D:69F)SH*("`@("`@("`@("`@<F5T=7)N("=D:69F=2<[
M"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`D97AT.PH@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U9I97=E<B]I;6%G97,N<&AP````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#8V,3$`,3`U,34T,S$P-C$`,#(R,38V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M34E-15]6:65W97)?:6UA9V5S(&-L87-S(&%L;&]W<R!I;6%G97,@=&\@8F4@
M9&ES<&QA>65D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`L=B`Q+C$X+C@N.2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@
M,BXR"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-
M24U%7U9I97=E<E]I;6%G97,@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(&-O;G1E;G0M='EP92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0M='EP92!O9B!T:&4@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*
M("`@("`@("`D='EP92`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=%1Y<&4H*3L*
M("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:7-"<F]W<V5R*"=M
M;WII;&QA)RD@)B8*("`@("`@("`@("`@*"1T>7!E(#T]("=I;6%G92]P:G!E
M9R<I*2!["B`@("`@("`@("`@("\J(&EM86=E+VIP96<@86YD(&EM86=E+W!J
M<&5G("IA<'!E87(J('1O(&)E('1H92!S86UE"B`@("`@("`@("`@("`J(&5N
M=&ET>2P@8G5T($UO>FEL;&$@9&]N)W0@<V5E;2!T;R!W86YT('1O(&%C8V5P
M="!T:&4*("`@("`@("`@("`@("H@;&%T=&5R+B`@1F]R(&]U<B!P=7)P;W-E
M<RP@=V4@=VEL;"!T<F5A="!T:&5M('1H90H@("`@("`@("`@("`@*B!S86UE
M+B`J+PH@("`@("`@("`@("!R971U<FX@)VEM86=E+VIP96<G.PH@("`@("`@
M('T@96QS96EF("@D='EP92`]/2`G:6UA9V4O>"UP;F<G*2!["B`@("`@("`@
M("`@("\J(&EM86=E+W@M<&YG(&ES(&5Q=6EV86QE;G0@=&\@:6UA9V4O<&YG
M+B`J+PH@("`@("`@("`@("!R971U<FX@)VEM86=E+W!N9R<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E($A434P@;W5T<'5T(&9O
M<B!A(&IA=F%S8W)I<'0@875T;RUR97-I>F4@=FEE=R!W:6YD;W<N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7)L("`@(%1H92!54DP@=VAI8V@@8V]N=&%I;G,@=&AE(&%C
M='5A;"!I;6%G92!D871A+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&ET;&4@
M(%1H92!T:71L92!T;R!U<V4@9F]R('1H92!P86=E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]P;W!U<$EM86=E5VEN9&]W*"1U<FPL("1T:71L92D*("`@
M('L*("`@("`@("!G;&]B86P@)&)R;W=S97(["@H@("`@("`@("1S='(@/2`\
M/#Q%3T0*/&AT;6P^"CQH96%D/@H\=&ET;&4^)'1I=&QE/"]T:71L93X*/'-T
M>6QE('1Y<&4](G1E>'0O8W-S(CX\(2TM(&)O9'D@>R!M87)G:6XZ,'!X.R!P
M861D:6YG.C!P>#L@?2`M+3X\+W-T>6QE/@I%3T0["@H@("`@("`@("\J($]N
M;'D@=7-E(&IA=F%S8W)I<'0@:68@=V4@87)E('5S:6YG(&$@1$]-(&-A<&%B
M;&4@8G)O=W-E<BX@*B\*("`@("`@("!I9B`H)&)R;W=S97(M/F=E=$9E871U
M<F4H)V1O;2<I*2!["B`@("`@("`@("`@("\J(%1R86YS;&%T92`G)F%M<"<@
M96YT:71I97,@=&\@)R8G(&9O<B!*4R!54DP@;&EN:W,N("HO"B`@("`@("`@
M("`@("1U<FP@/2!S=')?<F5P;&%C92@G)F%M<#LG+"`G)B<L("1U<FPI.PH*
M("`@("`@("`@("`@+RH@36]Z:6QL82!A;F0@244@9&5T97)M:6YE('=I;F1O
M=R!D:6UE;G-I;VYS(&EN(&1I9F9E<F5N="!W87ES+B`J+PH@("`@("`@("`@
M("!I9B`H)&)R;W=S97(M/FES0G)O=W-E<B@G;7-I92<I*2!["B`@("`@("`@
M("`@("`@("`D:5=I9'1H7V-O9&4@/2`G9&]C=6UE;G0N8F]D>2YC;&EE;G17
M:61T:#LG.PH@("`@("`@("`@("`@("`@)&E(96EG:'1?8V]D92`]("=D;V-U
M;65N="YB;V1Y+F-L:65N=$AE:6=H=#LG.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&E7:61T:%]C;V1E(#T@)W=I;F1O=RYI;FYE
M<E=I9'1H.R<["B`@("`@("`@("`@("`@("`D:4AE:6=H=%]C;V1E(#T@)W=I
M;F1O=RYI;FYE<DAE:6=H=#LG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!*879A<V-R:7!T(&1I<W!L87DN("HO"B`@("`@("`@("`@("1L;V%D
M:6YG(#T@7R@B3&]A9&EN9RXN+B(I.PH@("`@("`@("`@("`D<W1R("X](#P\
M/$5/1`H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"F9U;F-T:6]N
M(')E<VEZ95=I;F1O=R@I('L*("`@('=I;F1O=RYM;W9E5&\H,"P@,"D["B`@
M("!D;V-U;65N="YG971%;&5M96YT0GE)9"@G<W!L87-H)RDN<W1Y;&4N9&ES
M<&QA>2`]("=N;VYE)SL*("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=D
M:7-P7VEM86=E)RDN<W1Y;&4N9&ES<&QA>2`]("=B;&]C:R<["B`@("!V87(@
M:5=I9'1H(#T@9&]C=6UE;G0N:6UA9V5S6S!=+G=I9'1H("T@)&E7:61T:%]C
M;V1E"B`@("!V87(@:4AE:6=H="`](&1O8W5M96YT+FEM86=E<ULP72YH96EG
M:'0@+2`D:4AE:6=H=%]C;V1E"B`@("!W:6YD;W<N<F5S:7IE0GDH:5=I9'1H
M+"!I2&5I9VAT*3L*("`@('-E;&8N9F]C=7,H*3L@"GT*/"]S8W)I<'0^/"]H
M96%D/@H\8F]D>2!O;FQO860](G)E<VEZ95=I;F1O=R@I.R(^/'-P86X@:60]
M(G-P;&%S:"(@<W1Y;&4](F-O;&]R.F=R87D[9F]N="UF86UI;'DZ<V%N<RUS
M97)I9CMP861D:6YG.C)P>#LB/B1L;V%D:6YG/"]S<&%N/CQI;6<@:60](F1I
M<W!?:6UA9V4B('-T>6QE/2)D:7-P;&%Y.FYO;F4[(B!S<F,](B1U<FPB("\^
M/"]B;V1Y/CPO:'1M;#X*14]$.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\J($YO;BUJ879A<V-R:7!T(&1I<W!L87DN("HO"B`@("`@("`@("`@
M("1I;6=?='AT(#T@7R@B26UA9V4B*3L*("`@("`@("`@("`@)'-T<B`N/2`\
M/#Q%3T0*/"]H96%D/@H\8F]D>2!B9V-O;&]R/2(C9F9F9F9F(B!T;W!M87)G
M:6X](C`B(&UA<F=I;FAE:6=H=#TB,"(@;&5F=&UA<F=I;CTB,"(@;6%R9VEN
M=VED=&@](C`B/@H\:6UG(&)O<F1E<CTB,"(@<W)C/2(D=7)L(B!A;'0](B1I
M;6=?='AT(B`O/@H\+V)O9'D^"CPO:'1M;#X*14]$.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1S='(["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<```````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S-3$R`#$P-3$U-#,Q,#8Q`#`R,S0V-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($U)345?5FEE=V5R7VUS<&]W97)P;VEN="!C;&%S<R!R96YD97)S(&]U="!-
M:6-R;W-O9G0@4&]W97)P;VEN=`H@*B!D;V-U;65N=',@:6X@2%1-3"!F;W)M
M870@8GD@=7-I;F<@=&AE('AL2'1M;"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`L
M=B`Q+C$S+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI
M;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI
M;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC
M;&%S<R!-24U%7U9I97=E<E]M<W!O=V5R<&]I;G0@97AT96YD<R!-24U%7U9I
M97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT
M(&1A=&$@=7-I;F<@<'!T:'1M;"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D
M(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E
M<G,["@H@("`@("`@("\J($-H96-K('1O(&UA:V4@<W5R92!T:&4@<')O9W)A
M;2!A8W1U86QL>2!E>&ES=',N("HO"B`@("`@("`@:68@*"%F:6QE7V5X:7-T
M<R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W!O=V5R<&]I;G0G75LG;&]C
M871I;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!S<')I
M;G1F*%\H(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP
M92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB*2P@)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;)VQO8V%T:6]N)UTI
M("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D9&%T82`]("<G.PH@
M("`@("`@("1T;7!?<'!T(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=H;W)D95]M
M<W!O=V5R<&]I;G0G*3L*"B`@("`@("`@)&9H(#T@9F]P96XH)'1M<%]P<'0L
M("=W)RD["B`@("`@("`@9G=R:71E*"1F:"P@)'1H:7,M/FUI;65?<&%R="T^
M9V5T0V]N=&5N=',H*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@
M("1F:"`]('!O<&5N*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P
M;VEN="==6R=L;V-A=&EO;B==("X@(B`D=&UP7W!P="`R/B8Q(BP@)W(G*3L*
M("`@("`@("!W:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@
M("`@("`@("`@("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@("`@<&-L
M;W-E*"1F:"D["@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE
M(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'``````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-3$R-``Q,#4Q-30S,3`V,0`P,C(R,S(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%
M7U9I97=E<E]M<W=O<F0@8VQA<W,@<F5N9&5R<R!O=70@36EC<F]S;V9T(%=O
M<F0*("H@9&]C=6UE;G1S(&EN($A434P@9F]R;6%T(&)Y('5S:6YG('1H92!W
M=E=A<F4@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP+'8@,2XR-2XQ,"XX(#(P,#8O,#$O,#$@
M,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E
M8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(
M;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?;7-W;W)D
M(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R
M(&]U="!T:&4@8W5R<F5N="!D871A('5S:6YG('=V5V%R92X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE
M(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO
M8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J($-H96-K('1O(&UA:V4@
M<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES=',N("HO"B`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O
M<F0G75LG;&]C871I;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E
M/B<@+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB
M*2P@)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N
M)UTI("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D9&%T82`]("<G
M.PH@("`@("`@("1T;7!?=V]R9"`@(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=M
M<W=O<F0G*3L*("`@("`@("`D=&UP7V]U='!U="`]($AO<F1E.CIG971496UP
M1FEL92@G;7-W;W)D)RD["B`@("`@("`@)'1M<%]D:7(@("`@/2!(;W)D93HZ
M9V5T5&5M<$1I<B@I.PH@("`@("`@("1T;7!?9FEL92`@(#T@<W1R7W)E<&QA
M8V4H)'1M<%]D:7(@+B`G+R<L("<G+"`D=&UP7V]U='!U="D["@H@("`@("`@
M(&EF("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1A<F=S(#T@)R`M>"`G
M("X@9&ER;F%M92@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G75LG
M;&]C871I;VXG72D@+B`B7%QW=DAT;6PN>&UL("UD("1T;7!?9&ER("TQ("1T
M;7!?=V]R9"`^("1T;7!?;W5T<'5T(CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=F5R<VEO;B`](&5X96,H)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG;7-W;W)D)UU;)VQO8V%T:6]N)UT@+B`G("TM=F5R<VEO;B<I.PH@("`@
M("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`G,"XW+C`G
M*2`^/2`P*2!["B`@("`@("`@("`@("`@("`D87)G<R`]("(@+2UC:&%R<V5T
M/2(@+B!.3%,Z.F=E=$-H87)S970H*2`N("(@+2UT87)G971D:7(])'1M<%]D
M:7(@)'1M<%]W;W)D("1T;7!?9FEL92(["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D87)G<R`]("(@)'1M<%]W;W)D("1T;7!?;W5T
M<'5T(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&9H(#T@
M9F]P96XH)'1M<%]W;W)D+"`G=R<I.PH@("`@("`@(&9W<FET92@D9F@L("1T
M:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@("`@(&9C;&]S
M92@D9F@I.PH*("`@("`@("!E>&5C*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)VUS=V]R9"==6R=L;V-A=&EO;B==("X@)&%R9W,I.PH*("`@("`@("!I9B`H
M(69I;&5?97AI<W1S*"1T;7!?;W5T<'5T*2D@>PH@("`@("`@("`@("!R971U
M<FX@7R@B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B
M*3L*("`@("`@("!]"@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?;W5T<'5T
M+"`G<B<I.PH@("`@("`@('=H:6QE("@H)')C(#T@9F=E=',H)&9H+"`X,3DR
M*2DI('L*("`@("`@("`@("`@)&1A=&$@+CT@)')C.PH@("`@("`@('T*("`@
M("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP
M92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R
M971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T
M*"D["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP
M:'``````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-3$Q`#$P-3$U-#,Q
M,#8Q`#`R,38V,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7VAT;6P@8VQA
M<W,@<F5N9&5R<R!O=70@2%1-3"!T97AT('=I=&@@86X@969F;W)T('1O"B`J
M(')E;6]V92!P;W1E;G1I86QL>2!M86QI8VEO=7,@8V]D92X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<"QV(#$N
M,30N-"XR,"`R,#`V+S`V+S`W(#$S.C,T.C$V(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E
M8V]I;"YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\
M:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I
M97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?:'1M;"!E>'1E;F1S($U)345?
M5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E
M;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!V:65W97(@;6%Y(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!T
M97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&YU
M;&PI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VQE86Y(5$U,*"1T
M:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEL=&5R<R!A8W1I=F4@8V]N=&5N="P@9&5R969E<F5N8V5S
M(&5X=&5R;F%L(&QI;FMS+"!D971E8W1S('!H:7-H:6YG+`H@("`@("H@971C
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&$@(%1H92!(5$U,(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;&5A;F5D($A434P@9&%T82X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-L96%N2%1-3"@D9&%T82D*("`@('L*
M("`@("`@("!G;&]B86P@)&)R;W=S97(L("1P<F5F<SL*"B`@("`@("`@)'!H
M:7-H7W=A<FX@/2!F86QS93L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]-24U%+T-O;G1E;G1S+G!H<"<["B`@("`@("`@)&%T=&%C:&UE;G0@/2!-
M24U%7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"D["@H@("`@("`@("\J
M($1E86P@=VET:"`\8F%S93X@=&%G<R!I;B!T:&4@2%1-3"P@<VEN8V4@=&AE
M>2!W:6QL('-C<F5W('5P(&]U<B!O=VX*("`@("`@("`@*B!R96QA=&EV92!P
M871H<RX@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+SQB87-E(&AR968]
M(C\H6UXB/B!=*BDB/R`_7"\_/B]I)RP@)&1A=&$L("1M871C:&5S*2D@>PH@
M("`@("`@("`@("`D8F%S92`]("1M871C:&5S6S%=.PH@("`@("`@("`@("!I
M9B`H<W5B<W1R*"1B87-E+"`M,2P@,2D@(3T@)R\G*2!["B`@("`@("`@("`@
M("`@("`D8F%S92`N/2`G+R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J(%)E8W5R<VEV96QY(&-A;&P@7V-L96%N2%1-3"@I('1O('!R979E;G0@
M8VQE=F5R(&9I96YD<R!F<F]M"B`@("`@("`@("`@("`J('-N96%K:6YG(&YA
M<W1Y('1H:6YG<R!I;G1O('1H92!P86=E('9I82`D8F%S92X@*B\*("`@("`@
M("`@("`@)&)A<V4@/2`D=&AI<RT^7V-L96%N2%1-3"@D8F%S92D["B`@("`@
M("`@?0H*("`@("`@("`O*B!!='1E;7!T('1O(&9I>"!P871H<R!T:&%T('=E
M<F4@<F5L>6EN9R!O;B!A(#QB87-E/B!T86<N("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D8F%S92DI('L*("`@("`@("`@("`@)'!A='1E<FX@/2!A<G)A>2@G
M?'-R8STH6R)<)UTI*%M>.B)<)UTK*5PQ?&DG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=\<W)C/2A;7CH@/B)<)UTK*7QI)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G?&AR968]("HH6R)<)UTI*%M>.B)<)UTK
M*5PQ?&DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=\:')E9CTH
M6UXZ(#XB7"==*RE\:2<I.PH@("`@("`@("`@("`D<F5P;&%C92`](&%R<F%Y
M*"=S<F,]7#$G("X@)&)A<V4@+B`G7#)<,2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W-R8STG("X@)&)A<V4@+B`G7#$G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=H<F5F/5PQ)R`N("1B87-E("X@)UPR7#$G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H<F5F/2<@+B`D8F%S
M92`N("=<,2<I.PH@("`@("`@("`@("`D9&%T82`]('!R96=?<F5P;&%C92@D
M<&%T=&5R;BP@)')E<&QA8V4L("1D871A*3L*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@
M("`D<W1R:7!?<W1Y;&5S(#T@(21A='1A8VAM96YT('Q\"B`@("`@("`@("`@
M("@D8G)O=W-E<BT^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8*("`@("`@("`@
M("`@("1B<F]W<V5R+3YG971-86IO<B@I(#T](#0I('Q\"B`@("`@("`@("`@
M("1B<F]W<V5R+3YI<T)R;W=S97(H)VUS:64G*3L*("`@("`@("`D9&%T82`]
M(%1E>'1?1FEL=&5R.CIF:6QT97(H)&1A=&$L("=X<W,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8F]D>5]O;FQY)R`]
M/B`A)&%T=&%C:&UE;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S=')I<%]S='EL97,G(#T^("1S=')I<%]S='EL97,I
M*3L*"B`@("`@("`@+RH@0VAE8VL@9F]R('!H:7-H:6YG(&5X<&QO:71S+B`J
M+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O:')E9EQS*CU<<RI;(EPG73]<
M<RHH:'1T<'QH='1P<WQF='`I.EPO7"]<9'LQ+#-]7"Y<9'LQ+#-]7"Y<9'LQ
M+#-]7"Y<9'LQ+#-]+VDG+"`D9&%T82DI('L*("`@("`@("`@("`@+RH@0VAE
M8VL@,3H@0VAE8VL@9F]R($E0(&%D9')E<W,@;&EN:W,N("HO"B`@("`@("`@
M("`@("1P:&ES:%]W87)N(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:%]A;&PH)R]H<F5F7',J/5QS*ELB7"==/UQS*B@_.FAT='!\:'1T
M<'-\9G1P*3I<+UPO*%M>7',B7"<^72LI6R)<)UT_6UX^72H^7',J*#\Z*#\Z
M:'1T<'QH='1P<WQF='`I.EPO7"\I/R@N*C\I/%PO82]I<R<L("1D871A+"`D
M;2DI('L*("`@("`@("`@("`@+RH@)&U;,5T@/2!,:6YK.R`D;5LR72`](%1A
M<F=E=`H@("`@("`@("`@("`@*B!#:&5C:R`R.B!#:&5C:R!F;W(@;&EN:W,@
M=&AA="!P;VEN="!T;R!A(&1I9F9E<F5N="!H;W-T('1H86X*("`@("`@("`@
M("`@("H@=&AE('1A<F=E="!U<FP[(&EF('1A<F=E="!L;V]K<R!L:6ME(&$@
M9&]M86EN(&YA;64L(&-H96-K(&ET"B`@("`@("`@("`@("`J(&%G86EN<W0@
M=&AE(&QI;FLN("HO"B`@("`@("`@("`@("1L:6YK<R`](&-O=6YT*"1M6S!=
M*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QI;FMS.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D;5LQ75LD:5T@/2!S=')T;VQO=V5R*'5R
M;&1E8V]D92@D;5LQ75LD:5TI*3L*("`@("`@("`@("`@("`@("1M6S)=6R1I
M72`]('-T<G1O;&]W97(H<')E9U]R97!L86-E*"<O7BAH='1P?&AT='!S?&9T
M<"DZ7"]<+R\G+"`G)RP@<W1R:7!?=&%G<R@D;5LR75LD:5TI*2D["B`@("`@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;+2Y?7&1A+7I=*UPN6V$M
M>EU[,BQ]+VDG+"`D;5LR75LD:5TI("8F"B`@("`@("`@("`@("`@("`@("`@
M<W1R<&]S*"1M6S%=6R1I72P@)&U;,EU;)&E=*2`A/3T@,"`F)@H@("`@("`@
M("`@("`@("`@("`@('-T<G!O<R@D;5LR75LD:5TL("1M6S%=6R1I72D@(3T]
M(#`I('L*("`@("`@("`@("`@("`@("`@("`O*B!$;VXG="!C;VYS:61E<B!T
M:&4@;&EN:R!A('!H:7-H:6YG(&QI;FL@:68@=&AE(&1O;6%I;@H@("`@("`@
M("`@("`@("`@("`@("`J(&ES('1H92!S86UE(&]N(&)O=&@@;&EN:W,@*&4N
M9RX@861T<F%C:VEN9RYE>&%M<&QE+F-O;0H@("`@("`@("`@("`@("`@("`@
M("`J("8@=W=W+F5X86UP;&4N8V]M*2X@*B\*("`@("`@("`@("`@("`@("`@
M("!P<F5G7VUA=&-H*"<O7"X_*%M>7"Y<+UTK7"Y;7EPN7"]=*RE<+R\G+"`D
M;5LQ75LD:5TL("1H;W-T,2D["B`@("`@("`@("`@("`@("`@("`@<')E9U]M
M871C:"@G+UPN/RA;7EPN7"]=*UPN6UY<+EPO72LI*%PO+BHI/R0O)RP@)&U;
M,EU;)&E=+"`D:&]S=#(I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A*&-O
M=6YT*"1H;W-T,2D@)B8@8V]U;G0H)&AO<W0R*2D@?'P*("`@("`@("`@("`@
M("`@("`@("`@("`@<W1R8V%S96-M<"@D:&]S=#%;,5TL("1H;W-T,ELQ72D@
M(3T](#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!H:7-H7W=A<FX@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@5')Y('1O
M(&1E<F5F97(@86QL(&5X=&5R;F%L(')E9F5R96YC97,N("HO"B`@("`@("`@
M)&1A=&$@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH)R]H<F5F7',J/5QS*BA;
M(EPG72D_*"@_*#$I6UY<,5TJ/WQ;7EQS/ETK*2DH/R@Q*5PQ?"DO:2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E7V9U
M;F-T:6]N*"<D;2<L("=R971U<FX@7"=H<F5F/2)<)R`N("AS=')L96XH)&U;
M,ETI("8F("1M6S)=>S!](#T](%PG(UPG(#\@)&U;,ET@.B!(;W)D93HZ97AT
M97)N86Q5<FPH)&U;,ETI*2`N(%PG(EPG.R<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D871A*3L*"B`@("`@("`@+RH@4')E
M<&5N9"!P:&ES:&EN9R!W87)N:6YG+B`J+PH@("`@("`@(&EF("@D<&AI<VA?
M=V%R;BD@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP)SL*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)FYE=R!-
M24U%7T-O;G1E;G1S*&YE=R!-24U%7U!A<G0H*2D["B`@("`@("`@("`@("1P
M:&ES:%]W87)N:6YG(#T@<W!R:6YT9BA?*"(E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H
M92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(BDL(%\H
M(E=A<FYI;F<B*2D["B`@("`@("`@("`@(&EF("@D8V]N=&5N=',M/G9I97=!
M<T%T=&%C:&UE;G0H*2D@>PH@("`@("`@("`@("`@("`@)'!H:7-H7W=A<FYI
M;F<@/2`G/'-P86X@<W1Y;&4](F)A8VMG<F]U;F0M8V]L;W(Z(V9F9#!A9CMC
M;VQO<CIB;&%C:R(^)R`N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'!H:7-H
M7W=A<FYI;F<L($Y,4SHZ9V5T0VAA<G-E="@I+"`D=&AI<RT^;6EM95]P87)T
M+3YG971#:&%R<V5T*"DI("X@)SPO<W!A;CX\8G(@+SXG.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1P:&ES:%]W87)N:6YG(#T@)&-O;G1E;G1S+3YF
M;W)M8713=&%T=7--<V<H)'!H:7-H7W=A<FYI;F<L(&YU;&PL('1R=64L("=M
M:6UE4W1A='5S5V%R;FEN9R<I.PH@("`@("`@("`@("!I9B`H<W1R:7-T<B@D
M9&%T82P@)SQB;V1Y)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M9&%T82`]("1P:&ES:%]W87)N:6YG("X@)&1A=&$["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D9&%T82`]('!R96=?<F5P;&%C92@G
M+R@N*CQB;V1Y+BH_/BDH+BHI+VDG+"`G)#$G("X@)'!H:7-H7W=A<FYI;F<@
M+B`G)#(G+"`D9&%T82D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@8V]N=&5N="UT>7!E(&]F('1H92!R96YD97)E9"!T97AT+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!#;VYT96YT+51Y
M<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]#;VYT96YT<RYP:'`G.PH@
M("`@("`@(')E='5R;B!-24U%7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT
M*"D@/R`D=&AI<RT^;6EM95]P87)T+3YG9714>7!E*'1R=64I(#H@)W1E>'0O
M:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+V1E9F%U;'0N<&AP````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3$W-P`Q,#4Q-30S,3`V,0`P,C(S-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]D969A=6QT(&-L87-S('-I;7!L>2!P<FEN=',@;W5T('1H92!E;F-A
M<'-U;&%T960*("H@8V]N=&5N="X@($ET(&5X:7-T<R!A<R!A(&9A;&QB86-K
M(&EF(&YO(&]T:&5R(&EN=&5L;&EG96YT(')E;F1E<FEN9PH@*B!M96-H86YI
M<VT@8V]U;&0@8F4@=7-E9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]D969A=6QT+G!H<"QV(#$N.2XQ,BXT(#(P,#8O,#$O
M,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL
M0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G
M92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?9&5F
M875L="!E>'1E;F1S($U)345?5FEE=V5R('L*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<```````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R-S0U-@`Q,#4Q-30S,3`V,0`P,C(P,S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-
M24U%7U9I97=E<E]V8V%R9"!C;&%S<R!R96YD97)S(&]U="!V0V%R9',@:6X@
M2%1-3"!F;W)M870N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP+'8@,2XS-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#(N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E
M<@H@*B\*8VQA<W,@34E-15]6:65W97)?=F-A<F0@97AT96YD<R!-24U%7U9I
M97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!V8V%R9"!C
M;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@)'!R969S.PH*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH*("`@("`@
M("`D87!P(#T@9F%L<V4["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^;6EM95]P
M87)T+3YG971#;VYT96YT<R@I.PH@("`@("`@("1H=&UL(#T@)R<["B`@("`@
M("`@)&EM<&]R=%]M<V<@/2!N=6QL.PH@("`@("`@("1T:71L92`](%\H(G9#
M87)D(BD["@H@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H
M*3L*("`@("`@("!I9B`H(21I0V%L+3YP87)S979#86QE;F1A<B@D9&%T82DI
M('L*("`@("`@("`@("`@)&EM<&]R=%]M<V<@/2!?*")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(BD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)VEM<&]R="<I("8F
M"B`@("`@("`@("`@(%5T:6PZ.F=E=$9O<FU$871A*"=S;W5R8V4G*2`F)@H@
M("`@("`@("`@("`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G8V]N=&%C=',O:6UP
M;W)T)RDI('L*("`@("`@("`@("`@)'-O=7)C92`](%5T:6PZ.F=E=$9O<FU$
M871A*"=S;W5R8V4G*3L*("`@("`@("`@("`@)&-O;G1A8W1S(#T@)')E9VES
M=')Y+3YC86QL*"=C;VYT86-T<R]I;7!O<G0G+"!A<G)A>2@D9&%T82P@)W1E
M>'0O>"UV8V%R9"<L("1S;W5R8V4I*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&-O;G1A8W1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D
M:6UP;W)T7VUS9R`](%\H(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&-O;G1A8W0@9&%T82XB*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&EF("@D:4-A;"T^9V5T0V]M<&]N96YT0V]U;G0H*2`]
M/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&EM<&]R=%]M<V<@/2!?*")4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D:6UP;W)T7VUS9R`](%\H(D-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D:'1M;"`@/2!5=&EL.CIB=69F97)/=71P=70H)VEN8VQU9&4G+"`D
M<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)RD["B`@("`@("`@)&AT;6P@+CT@)SQT86)L92!C96QL
M<W!A8VEN9STB,2(@8F]R9&5R/2(P(B!C96QL<&%D9&EN9STB,2(^)SL*("`@
M("`@("!I9B`H(6ES7VYU;&PH)&EM<&]R=%]M<V<I*2!["B`@("`@("`@("`@
M("1H=&UL("X]("<\='(^/'1D(&-O;'-P86X](C(B(&-L87-S/2)H96%D97(B
M/B<@+B`D:6UP;W)T7VUS9R`N("<\+W1D/CPO='(^/'1R/CQT9#XF;F)S<#L\
M+W1D/CPO='(^)SL*("`@("`@("!](&5L<V5I9B`H)')E9VES=')Y+3YH87--
M971H;V0H)V-O;G1A8W1S+VEM<&]R="<I("8F"B`@("`@("`@("`@("`@("`@
M("1R96=I<W1R>2T^:&%S365T:&]D*"=C;VYT86-T<R]S;W5R8V5S)RDI('L*
M("`@("`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0@8V]L<W!A;CTB,B(@8VQA
M<W,](FAE861E<B(^/&9O<FT@86-T:6]N/2(G("X@)%]315)615);)U!(4%]3
M14Q&)UT@+B`G(B!M971H;V0](F=E="(@;F%M93TB=F-A<F1?:6UP;W)T(CXG
M("X@571I;#HZ9F]R;4EN<'5T*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1?
M1T54(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B<@+B!H=&UL<W!E8VEA
M;&-H87)S*"1K97DI("X@)R(@=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H87)S
M*"1V86PI("X@)R(@+SXG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<V]U<F-E<R`]("1R96=I<W1R>2T^8V%L;"@G8V]N=&%C=',O<V]U<F-E<R<L
M(&%R<F%Y*'1R=64I*3L*("`@("`@("`@("`@:68@*&-O=6YT*"1S;W5R8V5S
M*2`^(#$I('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<\:6YP=70@='EP
M93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)I;7!O<G0B('9A;'5E
M/2(G("X@7R@B061D('1O(&%D9')E<W,@8F]O:SHB*2`N("<B("\^)SL*("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\<V5L96-T(&YA;64](G-O=7)C92(^
M)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S;W5R8V5S(&%S("1K97D@
M/3X@)&QA8F5L*2!["B`@("`@("`@("`@("`@("`@("`@)'-E;&5C=&5D(#T@
M*"1K97D@/3T@)'!R969S+3YG971686QU92@G861D7W-O=7)C92<I*2`_("<@
M<V5L96-T960](G-E;&5C=&5D(B<@.B`G)SL*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA
M<G,H)&ME>2D@+B`G(B<@+B`D<V5L96-T960@+B`G/B<@+B!H=&UL<W!E8VEA
M;&-H87)S*"1L86)E;"D@+B`G/"]O<'1I;VX^)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H=&UL
M("X]("<\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE
M/2)I;7!O<G0B('9A;'5E/2(G("X@7R@B061D('1O(&UY(&%D9')E<W,@8F]O
M:R(I("X@)R(@+SXG.PH@("`@("`@("`@("`@("`@)'-O=7)C92`](&%R<F%Y
M7VME>7,H)'-O=7)C97,I.PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](G-O=7)C92(@=F%L=64](B<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1S;W5R8V5;,%TI("X@)R(@+SXG.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D:'1M;"`N/2`G/"]F;W)M/CPO=&0^/"]T
M<CX\='(^/'1D/B9N8G-P.SPO=&0^/"]T<CXG.PH@("`@("`@('T*"B`@("`@
M("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1I0V%L+3YG971#;VUP;VYE
M;G1S*"D@87,@)'9C*2!["B`@("`@("`@("`@(&EF("@D:2`^(#`I('L*("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D/B9N8G-P.SPO=&0^/"]T
M<CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("LK)&D["@H@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1R/CQT9"!C;VQS<&%N/2(R(B!C;&%S<STB:&5A
M9&5R(CXG.PH@("`@("`@("`@("`D9G5L;&YA;64@/2`D=F,M/F=E=$%T=')I
M8G5T941E9F%U;'0H)T9.)RP@9F%L<V4I.PH@("`@("`@("`@("!I9B`H)&9U
M;&QN86UE("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M)&9U;&QN86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]
M("<\+W1D/CPO='(^)SL*"B`@("`@("`@("`@("1N(#T@)'9C+3YP<FEN=&%B
M;&5.86UE*"D["B`@("`@("`@("`@(&EF("@A96UP='DH)&XI*2!["B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*").86UE(BDL("1N
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&%L:6%S97,@/2`D=F,M
M/F=E=$%T=')I8G5T959A;'5E<R@G04Q)05,G*3L*("`@("`@("`@("`@:68@
M*"%I<U]A*"1A;&EA<V5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")!;&EA<R(I+"!I;7!L;V1E
M*"<\8G(@+SXG+"`D86QI87-E<RDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1B:7)T:&1A>7,@/2`D=F,M/F=E=$%T=')I8G5T959A;'5E<R@G0D1!
M62<I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)&)I<G1H9&%Y<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R
M;W<H7R@B0FER=&AD87DB*2P@9&%T92@G62UM+60G+"`D8FER=&AD87ES6S!=
M*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L86)E;',@/2`D=F,M
M/F=E=$%L;$%T=')I8G5T97,H)TQ!0D5,)RD["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1L86)E;',@87,@)&QA8F5L*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&QA8F5L6R=P87)A;7,G75LG5%E012==*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1L86)E;%LG<&%R86US)UU;)U194$4G72!A
M<R`D='EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&%B96Q;)W!A
M<F%M<R==6U-T<FEN9SHZ=7!P97(H)'1Y<&4I72`]('1R=64["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1L86)E;%LG<&%R86US)UU;)TA/344G72DI('L*("`@
M("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")(;VUE
M($%D9')E<W,B*2P@;FPR8G(H)&QA8F5L6R=V86QU92==*2D["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H:7-S970H)&QA8F5L6R=P87)A;7,G75LG5T]2
M2R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?
M<F]W*%\H(E=O<FL@061D<F5S<R(I+"!N;#)B<B@D;&%B96Q;)W9A;'5E)UTI
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B061D<F5S<R(I+"!N;#)B<B@D
M;&%B96Q;)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@1F]R('9#87)D(#,N,"X*("`@("`@("`@
M("`@)&%D<G,@/2`D=F,M/F=E=$%L;$%T=')I8G5T97,H)T%$4B<I.PH@("`@
M("`@("`@("!F;W)E86-H("@D861R<R!A<R`D:71E;2D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG5%E012==*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&ET96U;)W!A<F%M
M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M
M6R=P87)A;7,G75LG5%E012==(#T@87)R87DH)&ET96U;)W!A<F%M<R==6R=4
M65!%)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==
M6R=465!%)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D:71E;5LG<&%R86US)UU;)U=/4DLG72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UU;72`]("=73U)+
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG2$]-12==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;)U194$4G75M=(#T@
M)TA/344G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1A9&1R97-S(#T@)&ET96U;)W9A;'5E<R==
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ET96U;)W!A<F%M<R==6R=4
M65!%)UT@87,@)&%D<BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("A3=')I
M;F<Z.G5P<&5R*"1A9'(I(#T]("=(3TU%)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D82`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4U12145472DI("`@>R`D
M85M=(#T@)&%D9')E<W-;5D-!4D1?04127U-44D5%5%T[('T*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E],
M3T-!3$E465TI*2![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?3$]#04Q)
M5%E=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D
M<F5S<UM60T%21%]!1%)?4D5'24].72DI("`@>R`D85M=(#T@)&%D9')E<W-;
M5D-!4D1?04127U)%1TE/3ET[('T*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]03U-40T]$15TI*2![("1A
M6UT@/2`D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=.R!]"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?
M0T]53E1265TI*2`@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127T-/54Y4
M4EE=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES
M+3Y?<F]W*%\H(DAO;64@061D<F5S<R(I+"!N;#)B<BAI;7!L;V1E*")<;B(L
M("1A*2DI.PH*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H4W1R:6YG
M.CIU<'!E<B@D861R*2`]/2`G5T]22R<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&$@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127U-44D5%5%TI*2`@('L@)&%;
M72`]("1A9&1R97-S6U9#05)$7T%$4E]35%)%151=.R!]"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?3$]#
M04Q)5%E=*2D@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127TQ/0T%,2519
M73L@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E
M<W-;5D-!4D1?04127U)%1TE/3ETI*2`@('L@)&%;72`]("1A9&1R97-S6U9#
M05)$7T%$4E]214=)3TY=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=*2D@>R`D85M=
M(#T@)&%D9')E<W-;5D-!4D1?04127U!/4U1#3T1%73L@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127T-/
M54Y44EE=*2D@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)9
M73L@?0H@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^
M7W)O=RA?*")7;W)K($%D9')E<W,B*2P@;FPR8G(H:6UP;&]D92@B7&XB+"`D
M82DI*3L*"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&$@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127U-44D5%5%TI
M*2`@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]35%)%151=.R!]"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%2
M1%]!1%)?3$]#04Q)5%E=*2D@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?0412
M7TQ/0T%,251973L@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ETI*2`@('L@)&%;72`]("1A
M9&1R97-S6U9#05)$7T%$4E]214=)3TY=.R!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=
M*2D@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127U!/4U1#3T1%73L@?0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!
M4D1?04127T-/54Y44EE=*2D@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$
M4E]#3U5.5%)973L@?0H@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`D=&AI<RT^7W)O=RA?*")!9&1R97-S(BDL(&YL,F)R*&EM<&QO9&4H(EQN
M(BP@)&$I*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;G5M8F5R<R`]("1V
M8RT^9V5T06QL071T<FEB=71E<R@G5$5,)RD["@H@("`@("`@("`@("!F;W)E
M86-H("@D;G5M8F5R<R!A<R`D;G5M8F5R*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&YU;6)E<ELG<&%R86US)UU;)U194$4G72DI('L*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D;G5M8F5R6R=P87)A;7,G75LG5%E0
M12==(&%S("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N=6UB
M97);)W!A<F%M<R==6U-T<FEN9SHZ=7!P97(H)'1Y<&4I72`]('1R=64["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1N=6UB97);)W!A<F%M<R==6R=&05@G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?
M*")&87@B*2P@)&YU;6)E<ELG=F%L=64G72D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;G5M8F5R
M6R=P87)A;7,G75LG2$]-12==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")(;VUE(%!H;VYE(BDL("1N=6UB
M97);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D;G5M8F5R6R=P87)A;7,G75LG5T]22R==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")7;W)K(%!H
M;VYE(BDL("1N=6UB97);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("AI<W-E="@D;G5M8F5R6R=P87)A;7,G75LG0T5,3"==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O
M=RA?*")#96QL(%!H;VYE(BDL("1N=6UB97);)W9A;'5E)UTI.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(E!H;VYE(BDL("1N=6UB97);)W9A
M;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&%D9')E<W-E<R`]("1V
M8RT^9V5T06QL071T<FEB=71E<R@G14U!24PG*3L*("`@("`@("`@("`@)&5M
M86EL<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1A9&1R97-S
M97,@87,@)&%D9')E<W,I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M861D<F5S<ULG<&%R86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D861D<F5S<ULG<&%R86US)UU;)U194$4G72!A<R`D
M='EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D861D<F5S<ULG<&%R
M86US)UU;4W1R:6YG.CIU<'!E<B@D='EP92E=(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D96UA:6P@/2`G/&$@:')E9CTB)SL*("`@("`@("`@("`@("`@(&EF("@D
M<F5G:7-T<GDM/FAA<TUE=&AO9"@G;6%I;"]C;VUP;W-E)RDI('L*("`@("`@
M("`@("`@("`@("`@("`D96UA:6P@+CT@)')E9VES=')Y+3YC86QL*"=M86EL
M+V-O;7!O<V4G+"!A<G)A>2AA<G)A>2@G=&\G(#T^("1A9&1R97-S6R=V86QU
M92==*2DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D96UA:6P@+CT@)VUA:6QT;SHG("X@)&%D9')E<W-;)W9A;'5E
M)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D96UA:6P@
M+CT@)R(^)R`N("1A9&1R97-S6R=V86QU92==("X@)SPO83XG.PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6R=P87)A;7,G75LG4%)%1B==
M*2D@>PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&5M86EL
M<RP@)&5M86EL*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&5M86EL<UM=(#T@)&5M86EL.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H8V]U;G0H)&5M
M86EL<RDI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W
M*%\H(D5M86EL(BDL(&EM<&QO9&4H)SQB<B`O/B<L("1E;6%I;',I*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'1I=&QE(#T@)'9C+3YG971!='1R
M:6)U=&5686QU97,H)U1)5$Q%)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D
M=&ET;&4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1H=&UL
M("X]("1T:&ES+3Y?<F]W*%\H(E1I=&QE(BDL("1T:71L95LP72D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1R;VQE(#T@)'9C+3YG971!='1R:6)U
M=&5686QU97,H)U)/3$4G*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1R;VQE
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D
M=&AI<RT^7W)O=RA?*")2;VQE(BDL("1R;VQE6S!=*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&]R9R`]("1V8RT^9V5T071T<FEB=71E5F%L=65S
M*"=/4D<G*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1O<F<L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W
M*%\H(D-O;7!A;GDB*2P@)&]R9ULP72D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1N;W1E<R`]("1V8RT^9V5T071T<FEB=71E5F%L=65S*"=.3U1%
M)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D;F]T97,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H
M(DYO=&5S(BDL(&YL,F)R*"1N;W1E<ULP72DI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D=7)L(#T@)'9C+3YG971!='1R:6)U=&5686QU97,H)U52
M3"<I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)'5R;"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B
M55),(BDL("<\82!H<F5F/2(G("X@)'5R;%LP72X@)R(@=&%R9V5T/2)?8FQA
M;FLB/B<@+B`D=7)L6S!=("X@)SPO83XG*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&AT;6P@+CT@)SPO=&%B;&4^)SL*("`@("`@("`D
M:'1M;"`N/2!5=&EL.CIB=69F97)/=71P=70H)VEN8VQU9&4G+"`D<F5G:7-T
M<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T
M97(N:6YC)RD["@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F]W*"1L86)E;"P@)'9A;'5E*0H@("`@>PH@("`@("`@(')E
M='5R;B`G/'1R/CQT9"!C;&%S<STB:71E;2(@=F%L:6=N/2)T;W`B/B<@+B`D
M;&%B96P@+B`G/"]T9#X\=&0@8VQA<W,](FET96TB('9A;&EG;CTB=&]P(CXG
M("X@)'9A;'5E("X@(CPO=&0^/"]T<CY<;B(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD
M97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H
M=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H<```````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#0U`#$P-3$U-#,Q,#8Q`#`R
M,34R,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W)P;2!C;&%S<R!R96YD
M97)S(&]U="!L:7-T<R!O9B!F:6QE<R!I;B!24$T*("H@<&%C:V%G97,@8GD@
M=7-I;F<@=&AE(')P;2!T;V]L('1O('%U97)Y('1H92!P86-K86=E+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`L
M=B`Q+C$R+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI
M;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI
M;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC
M;&%S<R!-24U%7U9I97=E<E]R<&T@97AT96YD<R!-24U%7U9I97=E<B!["@H@
M("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!24$T@8V]N=&5N=',N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T
M97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D;6EM95]D<FEV97)S.PH*("`@("`@("`O*B!#:&5C:R!T
M;R!M86ME('-U<F4@=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S+B`J+PH@
M("`@("`@(&EF("@A9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG<G!M)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G
M/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)P;2==6R=L;V-A=&EO
M;B==*2`N("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`G
M)SL*("`@("`@("`D=&UP7W)P;2`]($AO<F1E.CIG971496UP1FEL92@G:&]R
M9&5?<G!M)RD["@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?<G!M+"`G=R<I
M.PH@("`@("`@(&9W<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O
M;G1E;G1S*"DI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`D9F@@
M/2!P;W!E;B@D;6EM95]D<FEV97)S6R=H;W)D92==6R=R<&TG75LG;&]C871I
M;VXG72`N("(@+7%I<"`D=&UP7W)P;2`R/B8Q(BP@)W(G*3L*("`@("`@("!W
M:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@("`@("`@
M("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F:"D[
M"@H@("`@("`@(')E='5R;B`G/'!R93XG("X@:'1M;&5N=&ET:65S*"1D871A
M*2`N("<\+W!R93XG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP
M92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG
M("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W)E<&]R="YP:'``````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`W-@`Q,#4Q-30S,3`V,0`P,C(R-#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]R97!O<G0@8VQA<W,@:7,@82!W
M<F%P<&5R('5S960@=&\@;&]A9"!T:&4@87!P<F]P<FEA=&4*("H@34E-15]6
M:65W97(@9F]R(&UU;'1I<&%R="]R97!O<G0@9&%T82`H4D9#(#,T-C(I+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)E<&]R
M="YP:'`L=B`Q+C8N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]R
M97!O<G0@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!3
M=&]R97,@=&AE($U)345?5FEE=V5R(&]F('1H92!S<&5C:69I960@<')O=&]C
M;VPN"B`@("`@*@H@("`@("H@0'9A<B!-24U%7U9I97=E<@H@("`@("HO"B`@
M("!V87(@)%]V:65W97(["@H@("`@+RHJ"B`@("`@*B!296YD97(@=&AE(&UU
M;'1I<&%R="]R97!O<G0@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@06X@87)R87D@;V8@<&%R86UE=&5R<R!N965D960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@+RH@1V5T('1H92!A<'!R;W!R:6%T92!-24U%
M7U9I97=E<B!F;W(@=&AE('!R;W1O8V]L('-P96-I9FEE9"X@*B\*("`@("`@
M("!I9B`H(2@D=&AI<RT^7W)E<V]L=F56:65W97(H*2DI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5N9&5R('5S:6YG
M('1H92!L;V%D960@34E-15]6:65W97(@;V)J96-T+B`J+PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W9I97=E<BT^<F5N9&5R*"1P87)A;7,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N="UT>7!E(&]F('1H
M92!6:65W97(@=7-E9"!T;R!V:65W('1H92!P87)T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!!(&-O;G1E;G0M='EP92!S=')I;F<N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@("\J($=E
M="!T:&4@87!P<F]P<FEA=&4@34E-15]6:65W97(@9F]R('1H92!P<F]T;V-O
M;"!S<&5C:69I960N("HO"B`@("`@("`@:68@*"$H)'1H:7,M/E]R97-O;'9E
M5FEE=V5R*"DI*2!["B`@("`@("`@("`@(')E='5R;B`G87!P;&EC871I;VXO
M;V-T970M<W1R96%M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]V:65W97(M/F=E=%1Y<&4H*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D(&$@34E-15]6:65W97(@86-C;W)D
M:6YG('1O('1H92!R97!O<G0M='EP92!P87)A;65T97(@<W1O<F5D"B`@("`@
M*B!I;B!T:&4@34E-15]087)T('1O(')E;F1E<BX@268@=6YS=6-C97-S9G5L
M+"!T<GD@=&\@;&]A9"!A(&=E;F5R:6,*("`@("`J(&UU;'1I<&%R="!-24U%
M7U9I97=E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E<V]L=F56
M:65W97(H*0H@("`@>PH@("`@("`@("1V:65W97(@/2!N=6QL.PH*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]V:65W97(I*2!["B`@("`@("`@("`@(&EF
M("@A*"1T>7!E(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=%1Y<&50
M87)A;65T97(H)W)E<&]R="UT>7!E)RDI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1V:65W
M97(@/2`F34E-15]6:65W97(Z.F9A8W1O<GDH)'1H:7,M/FUI;65?<&%R="P@
M)VUE<W-A9V4O)R`N(%-T<FEN9SHZ;&]W97(H)'1Y<&4I*3L*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1V:65W97(I('Q\"B`@("`@("`@("`@("`@("`H4W1R
M:6YG.CIL;W=E<BAG971?8VQA<W,H)'9I97=E<BDI(#T]("=M:6UE7W9I97=E
M<E]D969A=6QT)RDI('L*("`@("`@("`@("`@("`@(&EF("@A*"1V:65W97(@
M/2`F34E-15]6:65W97(Z.F9A8W1O<GDH)'1H:7,M/FUI;65?<&%R="P@)'1H
M:7,M/FUI;65?<&%R="T^9V5T4')I;6%R>51Y<&4H*2`N("<O*B<I*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W9I97=E
M<B`]("1V:65W97(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M34E-12]6:65W97(O=V5B8W!P+G!H<```````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`V,S,T`#$P-3$U-#,Q,#8Q`#`R,C(P,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)
M345?5FEE=V5R7W=E8F-P<"!C;&%S<R!R96YD97)S(&]U="!V87)I;W5S(&-O
M;G1E;G0*("H@:6X@2%1-3"!F;W)M870@8GD@=7-I;F<@5V5B($,@4&QU<R!0
M;'5S+@H@*@H@*B!796(@0R!0;'5S('!L=7,Z(&AT='`Z+R]W96)C<'`N<V]U
M<F-E9F]R9V4N;F5T+PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W=E8F-P<"YP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P,2`R
M,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]W
M96)C<'`@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!2
M96YD97(@;W5T('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S('5S:6YG(%=E
M8B!#(%!L=7,@4&QU<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E
M;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]#;VYT96YT<RYP:'`G
M.PH@("`@("`@("1A='1A8VAM96YT(#T@34E-15]#;VYT96YT<SHZ=FEE=T%S
M071T86-H;65N="@I.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@
M=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A
M9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;
M)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@
M<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=L;V-A=&EO;B==*2`N
M("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7!O
M<F%R>2!F:6QE<R!F;W(@5V5B8W!P+B`J+PH@("`@("`@("1T;7!I;B`@/2!(
M;W)D93HZ9V5T5&5M<$9I;&4H)U=E8F-P<$EN)RD["B`@("`@("`@)'1M<&]U
M="`]($AO<F1E.CIG971496UP1FEL92@G5V5B8W!P3W5T)RD["@H@("`@("`@
M("\J(%=R:71E('1H92!C;VYT96YT<R!O9B!O=7(@8G5F9F5R('1O('1H92!T
M96UP;W)A<GD@:6YP=70@9FEL92X@*B\*("`@("`@("`D8V]N=&5N=',@/2`D
M=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH@("`@("`@("1F:"`]
M(&9O<&5N*"1T;7!I;BP@)W=B)RD["B`@("`@("`@9G=R:71E*"1F:"P@)&-O
M;G1E;G1S+"!S=')L96XH)&-O;G1E;G1S*2D["B`@("`@("`@9F-L;W-E*"1F
M:"D["@H@("`@("`@("\J($=E="!T:&4@97AT96YS:6]N(&9O<B!T:&4@;6EM
M92!T>7!E+B`J+PH@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O34E-12]-
M86=I8RYP:'`G.PH@("`@("`@("1E>'0@/2!-24U%7TUA9VEC.CI-24U%5&]%
M>'0H)'1H:7,M/FUI;65?<&%R="T^9V5T5'EP92@I*3L*"B`@("`@("`@+RH@
M17AE8W5T92!796(@0R!0;'5S(%!L=7,N(%-P96-I9GEI;F<@=&AE(&EN(&%N
M9"!O=70@9FEL97,@9&ED;B=T"B`@("`@("`@("`@=V]R:R!F;W(@;64@8G5T
M('!I<&5S(&1I9"X@*B\*("`@("`@("!E>&5C*"1M:6UE7V1R:79E<G-;)VAO
M<F1E)UU;)W=E8F-P<"==6R=L;V-A=&EO;B==("X@(B`M+7!I<&4@+2UP:7!E
M("UX/21E>'0@+6P@+6$@+70@/"`D=&UP:6X@/B`D=&UP;W5T(BD["B`@("`@
M("`@)')E<W5L=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&UP;W5T*3L*"B`@
M("`@("`@+RH@268@=V4@87)E(&YO="!D:7-P;&%Y:6YG(&EN;&EN92P@86QL
M('1H92!F;W)M871T:6YG(&ES(&%L<F5A9'D*("`@("`@("`@*B!D;VYE(&9O
M<B!U<RX@*B\*("`@("`@("!I9B`H)&%T=&%C:&UE;G0I('L*("`@("`@("`@
M("`@+RH@5&AE(&9I<G-T(#(@;&EN97,@87)E('1H92!#;VYT96YT+51Y<&4@
M;&EN92!A;F0@82!B;&%N:R!L:6YE"B`@("`@("`@("`@("`J('-O('=E('-H
M;W5L9"!R96UO=F4@=&AE;2!B969O<F4@;W5T<'5T=&EN9RX@*B\*("`@("`@
M("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@B+RXJ7&XN*EQN+R(L("<G+"`D
M<F5S=6QT<RP@,2D["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H
M92!S='EL92!S:&5E="P@<F5M;W9I;F<@86YY(&=L;V)A;"!B;V1Y(&9O<FUA
M='1I;F<*("`@("`@("`@*B!I9B!W92=R92!D:7-P;&%Y:6YG(&EN;&EN92X@
M*B\*("`@("`@("`D<F5S(#T@<')E9U]S<&QI="@G.R@\+W-T>6QE/BE\*#QS
M='EL92!T>7!E/2)T97AT+V-S<R(^*3LG+"`D<F5S=6QT<RD["B`@("`@("`@
M)'-T>6QE(#T@)')E<ULQ73L*("`@("`@("`D<W1Y;&4@/2!P<F5G7W)E<&QA
M8V4H)R]<;F)O9'E<<RL_>RXJ/WTO<R<L("<G+"`D<W1Y;&4I.PH*("`@("`@
M("`O*B!%>'1R86-T('1H92!C;VYT96YT+B`J+PH@("`@("`@("1R97,@/2!P
M<F5G7W-P;&ET*"<O7#Q<+S]P<F5</B\G+"`D<F5S=6QT<RD["B`@("`@("`@
M)&)O9'D@/2`D<F5S6S%=.PH*("`@("`@("!R971U<FX@)SQS='EL93XG("X@
M)'-T>6QE("X@)SPO<W1Y;&4^/&1I=B!C;&%S<STB=V5B8W!P(B!S='EL93TB
M=VAI=&4M<W!A8V4Z<')E.V9O;G0M9F%M:6QY.FUO;F]S<&%C92(^)R`N("1B
M;V1Y("X@)SPO9&EV/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T
M>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T
M/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,#8V-P`Q,#4Q-30S,3`V,0`P,C$U,S$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-
M24U%7U9I97=E<E]Z:7`@8VQA<W,@<F5N9&5R<R!O=70@=&AE(&-O;G1E;G1S
M(&]F(%I)4"!F:6QE<R!I;B!(5$U,"B`J(&9O<FUA="X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP+'8@,2XS,"XQ
M,"XQ,"`R,#`V+S`R+S$P(#$S.C4T.C`T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,"TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0&%U=&AO<B`@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,BXP"B`J($!P86-K86=E($AO<F1E
M7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]Z:7`@97AT96YD
M<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H
M92!C=7)R96YT('II<"!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@
M;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E
M<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F5N9&5R*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@3W5T<'5T('1H92!F:6QE(&QI<W0N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]N=&5N=',@(%1H92!C;VYT96YT<R!O9B!T:&4@>FEP(&%R
M8VAI=F4N"B`@("`@*B!`<&%R86T@;6EX960@)&-A;&QB86-K("`@5&AE(&-A
M;&QB86-K(&9U;F-T:6]N('1O('5S92!O;B!T:&4@>FEP9FEL90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!L:7-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<F5N9&5R*"1C;VYT96YT<RP@)&-A;&QB86-K(#T@
M;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R
M97-S+G!H<"<["@H@("`@("`@("1Z:7`@/2`F2&]R9&5?0V]M<')E<W,Z.G-I
M;F=L971O;B@G>FEP)RD["@H@("`@("`@("\J($UA:V4@<W5R92!T:&ES(&ES
M(&$@=F%L:60@>FEP(&9I;&4N("HO"B`@("`@("`@:68@*"1Z:7`M/F-H96-K
M6FEP1&%T82@D8V]N=&5N=',I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@)SQP<F4^)R`N(%\H(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N(BD@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@
M("`@("`@("1Z:7!);F9O(#T@)'II<"T^9&5C;VUP<F5S<R@D8V]N=&5N=',L
M(&%R<F%Y*"=A8W1I;VXG(#T^($A/4D1%7T-/35!215-37UI)4%],25-4*2D[
M"B`@("`@("`@:68@*&ES7V$H)'II<$EN9F\L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1Z:7!);F9O+3YG971-97-S86=E*"D["B`@
M("`@("`@?0H@("`@("`@("1F:6QE0V]U;G0@/2!C;W5N="@D>FEP26YF;RD[
M"@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*("`@
M("`@("`D=&5X="`]("<\<W1R;VYG/B<@+B!H=&UL<W!E8VEA;&-H87)S*'-P
M<FEN=&8H7R@B0V]N=&5N=',@;V8@7"(E<UPB(BDL("1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$YA;64H*2DI("X@)SH\+W-T<F]N9SXG("X@(EQN(CL*("`@("`@
M("`D=&5X="`N/2`G/'1A8FQE/CQT<CX\=&0@86QI9VX](FQE9G0B/CQT=#X\
M<W!A;B!C;&%S<STB9FEX960B/B<["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ
M:'1M;$%L;%-P86-E<RA?*")!<F-H:79E($YA;64B*2`N("<Z("<@+B`D=&AI
M<RT^;6EM95]P87)T+3YG971.86UE*"DI("X@(EQN(CL*("`@("`@("`D=&5X
M="`N/2!497AT.CIH=&UL06QL4W!A8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE
M(BD@+B`G.B`G("X@<W1R;&5N*"1C;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B
M7&XB.PH@("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F
M:6QE0V]U;G0@(3T@,2D@/R!S<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I
M;&5S(BDL("1F:6QE0V]U;G0I(#H@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E
M<R!F:6QE(BDL("1F:6QE0V]U;G0I*3L*("`@("`@("`D=&5X="`N/2`B7&Y<
M;B(["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@
M("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")&:6QE($YA;64B*2P@("`@
M("`U,"P@)R`G+"!35%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@("`@("`@
M("`@('-T<E]P860H7R@B071T<FEB=71E<R(I+"`@("`@,3`L("<@)RP@4U12
M7U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B
M4VEZ92(I+"`@("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@
M("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B36]D:69I960@1&%T92(I
M+"`@,3DL("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@
M("`@('-T<E]P860H7R@B365T:&]D(BDL("`@("`@("`@,3`L("<@)RP@4U12
M7U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B
M0U)#(BDL("`@("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@
M("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B4F%T:6\B*2P@("`@("`@
M("`@(#<L("<@)RP@4U127U!!1%],1494*0H@("`@("`@("`@("`@("`@("D@
M+B`B7&XB.PH*("`@("`@("`D=&5X="`N/2!S=')?<F5P96%T*"<M)RP@,3$V
M*2`N(")<;B(["@H@("`@("`@(&9O<F5A8V@@*"1Z:7!);F9O(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("`D<F%T:6\@/2`H96UP='DH)'9A;%LG
M<VEZ92==*2D@/R`P(#H@,3`P("H@*"1V86Q;)V-S:7IE)UT@+R`D=F%L6R=S
M:7IE)UTI.PH*("`@("`@("`@("`@)'9A;%LG;F%M92==(#T@<W1R7W!A9"@D
M=F%L6R=N86UE)UTL(#4P+"`G("<L(%-44E]0041?4DE'2%0I.PH@("`@("`@
M("`@("`D=F%L6R=A='1R)UT@/2!S=')?<&%D*"1V86Q;)V%T='(G72P@,3`L
M("<@)RP@4U127U!!1%],1494*3L*("`@("`@("`@("`@)'9A;%LG<VEZ92==
M(#T@<W1R7W!A9"@D=F%L6R=S:7IE)UTL(#$P+"`G("<L(%-44E]0041?3$5&
M5"D["B`@("`@("`@("`@("1V86Q;)V1A=&4G72`]('-T<E]P860H<W1R9G1I
M;64H(B5D+25B+259("5(.B5-(BP@)'9A;%LG9&%T92==*2P@,3DL("<@)RP@
M4U127U!!1%],1494*3L*("`@("`@("`@("`@)'9A;%LG;65T:&]D)UT@/2!S
M=')?<&%D*"1V86Q;)VUE=&AO9"==+"`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I
M.PH@("`@("`@("`@("`D=F%L6R=C<F,G72`]('-T<E]P860H)'9A;%LG8W)C
M)UTL(#$P+"`G("<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1V86Q;
M)W)A=&EO)UT@/2!S=')?<&%D*'-P<FEN=&8H(B4Q+C%F)24B+"`D<F%T:6\I
M+"`W+"`G("<L(%-44E]0041?3$5&5"D["@H@("`@("`@("`@("`D=F%L(#T@
M87)R87E?;6%P*&%R<F%Y*"=497AT)RP@)VAT;6Q!;&Q3<&%C97,G*2P@)'9A
M;"D["@H@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&-A;&QB86-K*2D@>PH@
M("`@("`@("`@("`@("`@)'9A;"`](&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C
M:RP@)&ME>2P@)'9A;"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M97AT("X]("1V86Q;)VYA;64G72`N("1V86Q;)V%T='(G72`N("1V86Q;)W-I
M>F4G72`N"B`@("`@("`@("`@("`@("`@("`@("1V86Q;)V1A=&4G72`N("1V
M86Q;)VUE=&AO9"==("X@)'9A;%LG8W)C)UT@+@H@("`@("`@("`@("`@("`@
M("`@("`D=F%L6R=R871I;R==("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@
M("1T97AT("X]('-T<E]R97!E870H)RTG+"`Q,38I("X@(EQN(CL*("`@("`@
M("`D=&5X="`N/2`G/"]S<&%N/CPO='0^/"]T9#X\+W1R/CPO=&%B;&4^)SL*
M"B`@("`@("`@<F5T=7)N(&YL,F)R*"1T97AT*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA
M<G-E="@I.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<```````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-#4V
M`#$P-3$U-#,Q,#8Q`#`R,34R-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R
M7W1G>B!C;&%S<R!R96YD97)S(&]U="!P;&%I;B!O<B!G>FEP<&5D('1A<F)A
M;&QS(&EN($A434PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<"QV(#$N,S<N,3`N,3,@,C`P-B\P,2\R-B`Q,#HR
M,CHT-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL
M($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA
M=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`875T:&]R("!-:6-H865L
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@
M("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO
M"F-L87-S($U)345?5FEE=V5R7W1G>B!E>'1E;F1S($U)345?5FEE=V5R('L*
M"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@
M=&%R(&9I;&4@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C
M;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M0V]M<')E<W,N<&AP)SL*"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI
M;65?<&%R="T^9V5T0V]N=&5N=',H*3L*"B`@("`@("`@+RH@3VYL>2!D96-O
M;7!R97-S(&=Z:7!P960@9FEL97,N("HO"B`@("`@("`@)'-U8G1Y<&4@/2`D
M=&AI<RT^;6EM95]P87)T+3YG9713=6)4>7!E*"D["B`@("`@("`@:68@*"@D
M<W5B='EP92`]/2`G>"UC;VUP<F5S<V5D+71A<B<I('Q\"B`@("`@("`@("`@
M("@D<W5B='EP92`]/2`G=&=Z)RD@?'P*("`@("`@("`@("`@*"1S=6)T>7!E
M(#T]("=X+71G>B<I('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G9WII
M<"<I('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G>"UG>FEP)RD@?'P*
M("`@("`@("`@("`@*"1S=6)T>7!E(#T]("=X+6=Z:7`M8V]M<')E<W-E9"<I
M('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G>"UG=&%R)RDI('L*("`@
M("`@("`@("`@)&=Z:7`@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L971O;B@G
M9WII<"<I.PH@("`@("`@("`@("`D8V]N=&5N=',@/2`D9WII<"T^9&5C;VUP
M<F5S<R@D8V]N=&5N=',I.PH@("`@("`@("`@("!I9B`H96UP='DH)&-O;G1E
M;G1S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!?*")5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(BD@+B`G/"]P<F4^
M)SL*("`@("`@("`@("`@?2!E;'-E:68@*&ES7V$H)&-O;G1E;G1S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N
M("1C;VYT96YT<RT^9V5T365S<V%G92@I("X@)SPO<')E/B<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D<W5B='EP92`]/2`G9WII
M<"<@?'P*("`@("`@("`@("`@)'-U8G1Y<&4@/3T@)W@M9WII<"<@?'P*("`@
M("`@("`@("`@)'-U8G1Y<&4@/3T@)W@M9WII<"UC;VUP<F5S<V5D)RD@>PH@
M("`@("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O34E-12]-86=I8RYP:'`G.PH@("`@("`@("`@("`D;6EM
M95]T>7!E(#T@34E-15]-86=I8SHZ86YA;'EZ941A=&$H)&-O;G1E;G1S+"!I
M<W-E="@D8V]N9ELG;6EM92==6R=M86=I8U]D8B==*2`_("1C;VYF6R=M:6UE
M)UU;)VUA9VEC7V1B)UT@.B!N=6QL*3L*("`@("`@("`@("`@:68@*"$D;6EM
M95]T>7!E*2!["B`@("`@("`@("`@("`@("`D;6EM95]T>7!E(#T@7R@B56YK
M;F]W;B(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`G/'!R
M93XG("X@7R@B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(BD@
M+B`D;6EM95]T>7!E("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`O
M*B!/8G1A:6X@=&AE(&QI<W0@;V8@9FEL97,O9&%T82!I;B!T:&4@=&%R(&9I
M;&4N("HO"B`@("`@("`@)'1A<B`]("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE
M=&]N*"=T87(G*3L*"B`@("`@("`@)'1A<D1A=&$@/2`D=&%R+3YD96-O;7!R
M97-S*"1C;VYT96YT<RD["B`@("`@("`@:68@*&ES7V$H)'1A<D1A=&$L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B`D
M=&%R1&%T82T^9V5T365S<V%G92@I("X@)SPO<')E/B<["B`@("`@("`@?0H*
M("`@("`@("`D9FEL94-O=6YT(#T@8V]U;G0H)'1A<D1A=&$I.PH*("`@("`@
M("!I;F-L=61E7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@)'1E
M>'0@(#T@)SQS=')O;F<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?
M*")#;VYT96YT<R!O9B!<(B5S7"(B*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T
M3F%M92@I*2D@+B`G.CPO<W1R;VYG/B<@+B`B7&XB.PH@("`@("`@("1T97AT
M("X]("<\=&%B;&4^/'1R/CQT9"!A;&EG;CTB;&5F="(^/'1T/CQS<&%N(&-L
M87-S/2)F:7AE9"(^)SL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL
M4W!A8V5S*%\H(D%R8VAI=F4@3F%M92(I("X@)SH@("<@+B`D=&AI<RT^;6EM
M95]P87)T+3YG971.86UE*"DI("X@(EQN(CL*("`@("`@("`D=&5X="`N/2!4
M97AT.CIH=&UL06QL4W!A8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE(BD@+B`G
M.B`G("X@<W1R;&5N*"1C;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B7&XB.PH@
M("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F:6QE0V]U
M;G0@(3T@,2D@/R!S<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&5S(BDL
M("1F:6QE0V]U;G0I(#H@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE
M(BDL("1F:6QE0V]U;G0I*3L*("`@("`@("`D=&5X="`N/2`B7&Y<;B(["B`@
M("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@("`@
M("`@("`@("`@("`@<W1R7W!A9"A?*")&:6QE($YA;64B*2P@("`@(#8R+"`G
M("<L(%-44E]0041?4DE'2%0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R
M7W!A9"A?*")!='1R:6)U=&5S(BDL("`@(#$U+"`G("<L(%-44E]0041?3$5&
M5"D@+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(E-I>F4B*2P@
M("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@
M("`@("`@("`@('-T<E]P860H7R@B36]D:69I960@1&%T92(I+"`Q.2P@)R`G
M+"!35%)?4$%$7TQ%1E0I"B`@("`@("`@("`@("`@("`@*2`N(")<;B(["@H@
M("`@("`@("1T97AT("X]('-T<E]R97!E870H)RTG+"`Q,#8I("X@(EQN(CL*
M"B`@("`@("`@9F]R96%C:"`H)'1A<D1A=&$@87,@)'9A;"D@>PH@("`@("`@
M("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@
M("`@("`@("`@("`@('-T<E]P860H)'9A;%LG;F%M92==+"`V,BP@)R`G+"!3
M5%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P
M860H)'9A;%LG871T<B==+"`Q-2P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D=F%L6R=S:7IE)UTL(#$P
M+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("`@
M("!S=')?<&%D*'-T<F9T:6UE*"(E9"TE8BTE62`E2#HE32(L("1V86Q;)V1A
M=&4G72DL(#$Y+"`G("<L(%-44E]0041?3$5&5"D*("`@("`@("`@("`@("`@
M("`@("`I("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@("1T97AT("X]('-T
M<E]R97!E870H)RTG+"`Q,#8I("X@(EQN(CL*("`@("`@("`D=&5X="`N/2`G
M/"]S<&%N/CPO='0^/"]T9#X\+W1R/CPO=&%B;&4^)SL*"B`@("`@("`@<F5T
M=7)N(&YL,F)R*"1T97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@8V]N=&5N="UT>7!E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]S;W5R8V4N
M<&AP````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-#<`,3`U,34T,S$P
M-C$`,#(R,C(T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?<V]U<F-E(&-L
M87-S(&ES(&$@8VQA<W,@9F]R(&%N>2!V:65W97(@=&AA="!W86YT<PH@*B!T
M;R!P<F]V:61E(&QI;F4@;G5M8F5R<R!T;R!E>'1E;F0N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<V]U<F-E+G!H<"QV(#$N
M.2XQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS
M"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%
M7U9I97=E<E]S;W5R8V4@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ
M"B`@("`@*B!!9&0@;&EN92!N=6UB97)S('1O(&$@8FQO8VL@;V8@8V]D92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;V1E("!4:&4@8V]D92!T
M;R!N=6UB97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;F5.=6UB97(H)&-O
M9&4L("1L:6YE8G)E86L@/2`B7&XB*0H@("`@>PH@("`@("`@("1L:6YE<R`]
M('-U8G-T<E]C;W5N="@D8V]D92P@)&QI;F5B<F5A:RD@*R`Q.PH@("`@("`@
M("1H=&UL(#T@)SQT86)L92!C;&%S<STB;&EN94YU;6)E<F5D(B!C96QL<W!A
M8VEN9STB,"(^/'1R/CQT:#XG.PH@("`@("`@(&9O<B`H)&P@/2`Q.R`D;"`\
M/2`D;&EN97,[("1L*RLI('L*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT
M9B@G/&$@:60](FPE<R(@:')E9CTB(VPE<R(^)7,\+V$^/&)R("\^)RP@)&PL
M("1L+"`D;"D@+B`B7&XB.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&AT
M;6P@+B`G/"]T:#X\=&0^)R`N("1C;V1E("X@)SPO=&0^/"]T<CX\+W1A8FQE
M/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N
M=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O
M=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E
M=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1N968N<&AP````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S0T,``Q,#4Q-30S,3`V,0`P,C$V-3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!-24U%7U9I97=E<E]T;F5F(&-L87-S(&%L;&]W<R!-4RU43D5&(&%T=&%C
M:&UE;G1S('1O(&)E(&1I<W!L87EE9"X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<"QV(#$N,3,N,3`N.2`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6
M:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W1N968@97AT96YD<R!-24U%
M7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R
M96YT('1N968@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@06YY('!A<F%M971E<G,@=&AE('9I97=E<B!M87D@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E
M;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]#;VUP
M<F5S<RYP:'`G.PH*("`@("`@("`D=&YE9B`]("9(;W)D95]#;VUP<F5S<SHZ
M<VEN9VQE=&]N*"=T;F5F)RD["@H@("`@("`@("1D871A(#T@)SQT86)L92!B
M;W)D97(](C$B/B<["B`@("`@("`@)&EN9F\@/2`D=&YE9BT^9&5C;VUP<F5S
M<R@D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I*3L*("`@("`@("!I
M9B`H96UP='DH)&EN9F\I('Q\(&ES7V$H)&EN9F\L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)&1A=&$@+CT@)SQT<CX\=&0^)R`N(%\H(DU3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB*2`N("<\+W1D/CPO
M='(^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%T82`N/2`G
M/'1R/CQT9#XG("X@7R@B3F%M92(I("X@)SPO=&0^/'1D/B<@+B!?*")-:6UE
M(%1Y<&4B*2`N("<\+W1D/CPO='(^)SL*("`@("`@("`@("`@9F]R96%C:"`H
M)&EN9F\@87,@)'!A<G0I('L*("`@("`@("`@("`@("`@("1D871A("X]("<\
M='(^/'1D/B<@+B`D<&%R=%LG;F%M92==("X@)SPO=&0^/'1D/B<@+B`D<&%R
M=%LG='EP92==("X@)R\G("X@)'!A<G1;)W-U8G1Y<&4G72`N("<\+W1D/CPO
M='(^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D9&%T82`N
M/2`G/"]T86)L93XG.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F
M('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'``````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#8V,#<`,3`U,34T,S$P-C$`,#(S,C,S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-O=7)C92YP:'`G.PH*+RHJ"B`J(%1H
M92!-24U%7U9I97=E<E]S<F-H:6=H;&ET92!C;&%S<R!R96YD97)S(&]U="!V
M87)I;W5S(&-O;G1E;G0@:6X@2%1-3`H@*B!F;W)M870@8GD@=7-I;F<@4V]U
M<F-E+6AI9VAL:6=H="X*("H*("H@4V]U<F-E+6AI9VAL:6=H=#H@:'1T<#HO
M+W=W=RYG;G4N;W)G+W-O9G1W87)E+W-R8RUH:6=H;&ET92\*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP
M:'`L=B`Q+C$T+C$P+C@@,C`P-B\P-B\P,2`P,SHP.#HU,R!C:'5C:R!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6
M:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W-R8VAI9VAL:71E(&5X=&5N
M9',@34E-15]6:65W97)?<V]U<F-E('L*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',@=7-I;F<@4V]U<F-E
M+6AI9VAL:6=H=`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!;GD@<&%R86UE=&5R<R!T:&4@=FEE=V5R(&UA>2!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!G;&]B86P@)&UI;65?9')I=F5R<SL*"B`@("`@
M("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E('1H92!P<F]G<F%M(&%C='5A;&QY
M(&5X:7-T<RX@*B\*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;)VQO8V%T:6]N)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;)VAO
M<F1E)UU;)W-R8VAI9VAL:71E)UU;)VQO8V%T:6]N)UTI("X@)SPO<')E/B<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<&]R87)Y(&9I;&5S
M(&9O<B!796)C<'`N("HO"B`@("`@("`@)'1M<&EN("`]($AO<F1E.CIG9714
M96UP1FEL92@G4W)C26XG*3L*("`@("`@("`D=&UP;W5T(#T@2&]R9&4Z.F=E
M=%1E;7!&:6QE*"=3<F-/=70G+"!F86QS92D["@H@("`@("`@("\J(%=R:71E
M('1H92!C;VYT96YT<R!O9B!O=7(@8G5F9F5R('1O('1H92!T96UP;W)A<GD@
M:6YP=70@9FEL92X@*B\*("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^;6EM
M95]P87)T+3YG971#;VYT96YT<R@I.PH@("`@("`@("1F:"`](&9O<&5N*"1T
M;7!I;BP@)W=B)RD["B`@("`@("`@9G=R:71E*"1F:"P@)&-O;G1E;G1S+"!S
M=')L96XH)&-O;G1E;G1S*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@
M("`@("\J($1E=&5R;6EN92!T:&4@;&%N9W5A9V4@9G)O;2!T:&4@;6EM92!T
M>7!E+B`J+PH@("`@("`@("1L86YG(#T@)R<["B`@("`@("`@<W=I=&-H("@D
M=&AI<RT^;6EM95]P87)T+3YG9714>7!E*"DI('L*("`@("`@("!C87-E("=T
M97AT+W@M:F%V82<Z"B`@("`@("`@("`@("1L86YG(#T@)VIA=F$G.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=&5X="]X+6-S<F,G.@H@
M("`@("`@(&-A<V4@)W1E>'0O>"UC*RMS<F,G.@H@("`@("`@(&-A<V4@)W1E
M>'0O8W!P)SH*("`@("`@("`@("`@)&QA;F<@/2`G8W!P)SL*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)V%P<&QI8V%T:6]N+W@M<&5R;"<Z
M"B`@("`@("`@("`@("1L86YG(#T@)W!E<FPG.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G87!P;&EC871I;VXO>"UP:'`G.@H@("`@("`@
M(&-A<V4@)W@M97AT96YS:6]N+W!H<',G.@H@("`@("`@(&-A<V4@)W@M97AT
M96YS:6]N+W!H<#-S)SH*("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]X+6AT
M='!D+7!H<"<Z"B`@("`@("`@8V%S92`G87!P;&EC871I;VXO>"UH='1P9"UP
M:'`S)SH*("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H<',G
M.@H@("`@("`@("`@("`D;&%N9R`]("=P:'`S)SL*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)V%P<&QI8V%T:6]N+W@M<'ET:&]N)SH*("`@
M("`@("`@("`@)&QA;F<@/2`G<'ET:&]N)SL*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`O+R`D;&%N9R`]("=P<F]L;V<G.PH@("`@("`@("`@
M("`O+R!B<F5A:SL*"B`@("`@("`@("`@("\O("1L86YG(#T@)V9L97@G.PH@
M("`@("`@("`@("`O+R!B<F5A:SL*"B`@("`@("`@("`@("\O("1L86YG(#T@
M)V-H86YG96QO9R<["B`@("`@("`@("`@("\O(&)R96%K.PH*("`@("`@("`@
M("`@+R\@)&QA;F<@/2`G<G5B>2<["B`@("`@("`@("`@("\O(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@+RH@17AE8W5T92!3;W5R8V4M2&EG:&QI=&4N
M("HO"B`@("`@("`@97AE8R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=S<F-H
M:6=H;&ET92==6R=L;V-A=&EO;B==("X@(B`M+7-R8RUL86YG("1L86YG("TM
M;W5T+69O<FUA="!X:'1M;"`M+6EN<'5T("1T;7!I;B`M+6]U='!U="`D=&UP
M;W5T(BD["B`@("`@("`@)')E<W5L=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D
M=&UP;W5T*3L*("`@("`@("!U;FQI;FLH)'1M<&]U="D["@H@("`@("`@("\J
M($5D=6-A=&5D($=U97-S(&%T('=H971H97(@=V4@87)E(&EN;&EN92!O<B!N
M;W0N("HO"B`@("`@("`@:68@*&AE861E<G-?<V5N="@I('Q\(&]B7V=E=%]L
M96YG=&@H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQI;F5.=6UB
M97(H)')E<W5L=',I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!5=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M
M;6]N+6AE861E<BYI;F,G*2`N"B`@("`@("`@("`@("`@("`D=&AI<RT^;&EN
M94YU;6)E<B@D<F5S=6QT<RD@+@H@("`@("`@("`@("`@("`@571I;#HZ8G5F
M9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC
M)RD["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M34E-12]6:65W97(O<&1F+G!H<```````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-3,Q`#$P-3$U-#,Q,#8Q`#`R,30V-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)
M345?5FEE=V5R7W!D9B!C;&%S<R!S:6UP;'D@;W5T<'5T<R!T:&4@4$1&(&9I
M;&4@=VET:"!T:&4@8V]N=&5N="UT>7!E"B`J("=A<'!L:6-A=&EO;B]P9&8G
M(&5N86)L:6YG('=E8B!B<F]W<V5R<R!W:71H(&$@4$1&('9I97=E<B!P;'5G
M:6X@=&\@=FEE=PH@*B!T:&4@4$1&(&9I;&4@:6YS:61E('1H92!B<F]W<V5R
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W!D
M9BYP:'`L=B`Q+C,N,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]P
M9&8@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE(&-O;G1E;G0M='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&-O;G1E;G0M='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@
M)V%P<&QI8V%T:6]N+W!D9B<["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O;V]O+G!H<```````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`W,C(Q`#$P-3$U-#,Q,#8Q`#`R,34Q,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($U)345?5FEE=V5R7V]O;R!C;&%S<R!R96YD97)S(&]U="!/<&5N3V9F
M:6-E+F]R9PH@*B!D;V-U;65N=',@:6X@2%1-3"!F;W)M870N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;V]O+G!H<"QV(#$N
M,30N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA<FMO
M($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!A=71H;W(@($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6
M:65W97)?;V]O(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@
M("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N="!D871A+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE
M=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=7-E7WAS
M;'0@/2!5=&EL.CIE>'1E;G-I;VY%>&ES=',H)WAS;'0G*2!\?"!F=6YC=&EO
M;E]E>&ES=',H)V1O;7AM;%]X<VQT7W-T>6QE<VAE971?9FEL92<I.PH@("`@
M("`@(&EF("@D=7-E7WAS;'0I('L*("`@("`@("`@("`@)'1M<&1I<B`](%5T
M:6PZ.F-R96%T951E;7!$:7(H=')U92D["B`@("`@("`@?0H*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R97-S+G!H<"<["B`@("`@("`@)'AM
M;%]T86=S("`](&%R<F%Y*"=T97AT.G`G+"`G=&%B;&4Z=&%B;&4@)RP@)W1A
M8FQE.G1A8FQE+7)O=R<L("=T86)L93IT86)L92UC96QL)RP@)W1A8FQE.FYU
M;6)E<BUC;VQU;6YS+7-P86YN960])RD["B`@("`@("`@)&AT;6Q?=&%G<R`]
M(&%R<F%Y*"=P)RP@)W1A8FQE(&)O<F1E<CTB,"(@8V5L;'-P86-I;F<](C$B
M(&-E;&QP861D:6YG/2(P(B`G+"`G='(@8F=C;VQO<CTB(V-C8V-C8R(G+"`G
M=&0G+"`G8V]L<W!A;CTG*3L*("`@("`@("`D>FEP(#T@)DAO<F1E7T-O;7!R
M97-S.CIS:6YG;&5T;VXH)WII<"<I.PH@("`@("`@("1L:7-T(#T@)'II<"T^
M9&5C;VUP<F5S<R@D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I+`H@
M("`@("`@("`@("!A<G)A>2@G86-T:6]N)R`]/B!(3U)$15]#3TU04D534U]:
M25!?3$E35"DI.PH@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1K97D@/3X@
M)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)V-O
M;G1E;G0N>&UL)R!\?`H@("`@("`@("`@("`@("`@)&9I;&5;)VYA;64G72`]
M/2`G<W1Y;&5S+GAM;"<@?'P*("`@("`@("`@("`@("`@("1F:6QE6R=N86UE
M)UT@/3T@)VUE=&$N>&UL)RD@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`D>FEP+3YD96-O;7!R97-S*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E
M;G1S*"DL"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V%C=&EO;B<@/3X@
M2$]21$5?0T]-4%)%4U-?6DE07T1!5$$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VEN9F\G("`@/3X@)&QI<W0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VME>2<@("`@/3X@)&ME>2DI.PH@("`@("`@("`@("`@("`@:68@
M*"1U<V5?>'-L="D@>PH@("`@("`@("`@("`@("`@("`@("1F<"`](&9O<&5N
M*"1T;7!D:7(@+B`D9FEL95LG;F%M92==+"`G=R<I.PH@("`@("`@("`@("`@
M("`@("`@(&9W<FET92@D9G`L("1C;VYT96YT*3L*("`@("`@("`@("`@("`@
M("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M9FEL95LG;F%M92==(#T]("=C;VYT96YT+GAM;"<I('L*("`@("`@("`@("`@
M("`@("`@("`D8V]N=&5N="`]('-T<E]R97!L86-E*"1X;6Q?=&%G<RP@)&AT
M;6Q?=&%G<RP@)&-O;G1E;G0I.PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D8V]N=&5N=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G
M>'-L="<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V1O;7AM;%]X<VQT7W-T>6QE<VAE
M971?9FEL92<I*2!["B`@("`@("`@("`@("\O(%5S92!$3TU834P*("`@("`@
M("`@("`@)'AS;'0@/2!D;VUX;6Q?>'-L=%]S='EL97-H965T7V9I;&4H9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+V]O;R]M86EN7VAT;6PN>'-L)RD["B`@("`@
M("`@("`@("1D;VT@(#T@9&]M>&UL7V]P96Y?9FEL92@D=&UP9&ER("X@)V-O
M;G1E;G0N>&UL)RD["B`@("`@("`@("`@("1R97-U;'0@/2!`)'AS;'0M/G!R
M;V-E<W,H)&1O;2P@87)R87DH)VUE=&%&:6QE55),)R`]/B`D=&UP9&ER("X@
M)VUE=&$N>&UL)RP@)W-T>6QE<T9I;&554DPG(#T^("1T;7!D:7(@+B`G<W1Y
M;&5S+GAM;"<L("=D:7-A8FQE2F%V82<@/3X@=')U92DI.PH@("`@("`@("`@
M("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D>'-L="T^<F5S=6QT
M7V1U;7!?;65M*"1R97-U;'0I+"`G551&+3@G+"!.3%,Z.F=E=$-H87)S970H
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@57-E(%A33%0*
M("`@("`@("`@("`@)'AS;'0@/2!X<VQT7V-R96%T92@I.PH@("`@("`@("`@
M("`D<F5S=6QT(#T@0'AS;'1?<')O8V5S<R@D>'-L="P@)'1M<&1I<B`N("=C
M;VYT96YT+GAM;"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&1I<FYA;64H7U]&24Q%7U\I("X@)R]O;V\O;6%I;E]H=&UL+GAS;"<L
M(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=M971A1FEL95523"<@/3X@)'1M<&1I<B`N("=M971A+GAM
M;"<L("=S='EL97-&:6QE55),)R`]/B`D=&UP9&ER("X@)W-T>6QE<RYX;6PG
M+"`G9&ES86)L94IA=F$G(#T^('1R=64I*3L*("`@("`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@>'-L=%]E<G)O
M<B@D>'-L="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@>'-L=%]F<F5E
M*"1X<VQT*3L*("`@("`@("`@("`@<F5T=7)N(%-T<FEN9SHZ8V]N=F5R=$-H
M87)S970H)')E<W5L="P@)U541BTX)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@34E-
M12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@
M=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,
M4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<V5C=7)I='DN
M<&AP`````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-3$T`#$P-3$U-#,Q,#8Q
M`#`R,C4W,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W-E8W5R:71Y(&-L
M87-S(&ES(&$@=W)A<'!E<B!U<V5D('1O(&QO860@=&AE(&%P<')O<')I871E
M"B`J($U)345?5FEE=V5R(&9O<B!S96-U<F4@;75L=&EP87)T(&UE<W-A9V5S
M("AD969I;F5D(&)Y(%)&0R`Q.#0W*2X@5&AI<PH@*B!C;&%S<R!H86YD;&5S
M(&UU;'1I<&%R="]S:6=N960@86YD(&UU;'1I<&%R="]E;F-R>7!T960@9&%T
M82X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S
M96-U<FET>2YP:'`L=B`Q+C8N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I
M97=E<E]S96-U<FET>2!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*
M("`@("`J(%-T;W)E<R!T:&4@34E-15]6:65W97(@;V8@=&AE('-P96-I9FEE
M9"!S96-U<FET>2!P<F]T;V-O;"X*("`@("`J"B`@("`@*B!`=F%R($U)345?
M5FEE=V5R"B`@("`@*B\*("`@('9A<B`D7W9I97=E<CL*"B`@("`O*BH*("`@
M("`J(%1H92`D;6EM95]P87)T(&-L87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF
M;W)M871I;VX@=&\@<F5N9&5R"B`@("`@*B!O=70L(&5N8V%P<W5L871E9"!I
M;B!A($U)345?4&%R="!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M("1P
M87)A;7,@;6EX960@(%1H92!P87)A;65T97)S("AI9B!A;GDI('1O('!A<W,@
M=&\@=&AE('5N9&5R;'EI;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!-24U%7U9I97=E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M4F5N9&5R:6YG(&]F('1H92!C;VYT96YT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@
M1V5T('1H92!A<'!R;W!R:6%T92!-24U%7U9I97=E<B!F;W(@=&AE('!R;W1O
M8V]L('-P96-I9FEE9"X@*B\*("`@("`@("!I9B`H(2@D=&AI<RT^7W)E<V]L
M=F56:65W97(H*2DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5N9&5R('5S:6YG('1H92!L;V%D960@34E-15]6:65W
M97(@;V)J96-T+B`J+PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9I97=E<BT^
M<F5N9&5R*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@8V]N=&5N="UT>7!E(&]F('1H92!6:65W97(@=7-E9"!T;R!V:65W
M('1H92!P87)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&-O
M;G1E;G0M='EP92!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@87!P<F]P<FEA=&4@34E-
M15]6:65W97(@9F]R('1H92!P<F]T;V-O;"!S<&5C:69I960N("HO"B`@("`@
M("`@:68@*"$H)'1H:7,M/E]R97-O;'9E5FEE=V5R*"DI*2!["B`@("`@("`@
M("`@(')E='5R;B`G87!P;&EC871I;VXO;V-T970M<W1R96%M)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]V:65W97(M
M/F=E=%1Y<&4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,
M;V%D(&$@34E-15]6:65W97(@86-C;W)D:6YG('1O('1H92!P<F]T;V-O;"!P
M87)A;65T97(@<W1O<F5D"B`@("`@*B!I;B!T:&4@34E-15]087)T('1O(')E
M;F1E<BX@268@=6YS=6-C97-S9G5L+"!T<GD@=&\@;&]A9"!A(&=E;F5R:6,*
M("`@("`J(&UU;'1I<&%R="!-24U%7U9I97=E<BX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W)E<V]L=F56:65W97(H*0H@("`@>PH@("`@("`@("1V
M:65W97(@/2!N=6QL.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]V:65W
M97(I*2!["B`@("`@("`@("`@("1P<F]T;V-O;"`]("1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=P<F]T;V-O;"<I.PH@("`@
M("`@("`@("!I9B`H96UP='DH)'!R;W1O8V]L*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1V
M:65W97(@/2`F34E-15]6:65W97(Z.F9A8W1O<GDH)'1H:7,M/FUI;65?<&%R
M="P@)'!R;W1O8V]L*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1V:65W97(I
M('Q\"B`@("`@("`@("`@("`@("`H4W1R:6YG.CIL;W=E<BAG971?8VQA<W,H
M)'9I97=E<BDI(#T]("=M:6UE7W9I97=E<E]D969A=6QT)RDI('L*("`@("`@
M("`@("`@("`@("1V:65W97(@/2`F34E-15]6:65W97(Z.F9A8W1O<GDH)'1H
M:7,M/FUI;65?<&%R="P@)'1H:7,M/FUI;65?<&%R="T^9V5T4')I;6%R>51Y
M<&4H*2`N("<O*B<I.PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1V:65W
M97(I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3Y?=FEE=V5R(#T@)'9I97=E<CL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%+U9I97=E<B]P:'`N<&AP````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(W,#4`,3`U,34T,S$P-C$`,#(Q-3$P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-O=7)C92YP:'`G.PH*
M+RHJ"B`J(%1H92!-24U%7U9I97=E<E]P:'`@8VQA<W,@<F5N9&5R<R!O=70@
M<WEN=&%X+6AI9VAL:6=H=&5D(%!(4"!C;V1E"B`J(&EN($A434P@9F]R;6%T
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W!H
M<"YP:'`L=B`Q+C(R+C$P+C@@,C`P-B\P-B\P,2`P,SHP.#HU,R!C:'5C:R!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@
M*B\*8VQA<W,@34E-15]6:65W97)?<&AP(&5X=&5N9',@34E-15]6:65W97)?
M<V]U<F-E('L*"B`@("`O*BH*("`@("`J(%)E;F1E<G,@;W5T('1H92!C;VYT
M96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY
M('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)')E<W5L=',@/2!T<FEM*'-T<E]R97!L86-E*&%R<F%Y
M*")<;B(L("<\8G(@+SXG*2P@87)R87DH)R<L(")<;B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!H:6=H;&EG:'1?<W1R:6YG*"1T
M:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DL('1R=64I*2D["@H@("`@
M("`@("\O($5D=6-A=&5D($=U97-S(&%T('=H971H97(@=V4@87)E(&EN;&EN
M92!O<B!N;W0N"B`@("`@("`@:68@*&AE861E<G-?<V5N="@I('Q\(&]B7V=E
M=%]L96YG=&@H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQI;F5.
M=6UB97(H)')E<W5L=',I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!5=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O
M8V]M;6]N+6AE861E<BYI;F,G*2`N"B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&EN94YU;6)E<B@D<F5S=6QT<RD@+@H@("`@("`@("`@("`@("`@571I;#HZ
M8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)RD["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W)I
M8VAT97AT+G!H<```````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-30S-P`Q,#4Q
M-30S,3`V,0`P,C(U-C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]R:6-H
M=&5X="!C;&%S<R!R96YD97)S(&]U="!(5$U,('1E>'0@9G)O;2!T97AT+W)I
M8VAT97AT"B`J(&-O;G1E;G0@=&%G<RP@*%)&0R`Q.#DV(%LW+C$N,UTI+@H@
M*@H@*B!!(&UI;FEM86P@<FEC:'1E>'0@:6UP;&5M96YT871I;VX@:7,@;VYE
M('1H870@<VEM<&QY(&-O;G9E<G1S("(\;'0^(B!T;PH@*B`B/"(L(&-O;G9E
M<G1S($-23$9S('1O(%-004-%+"!C;VYV97)T<R`\;FP^('1O(&$@;F5W;&EN
M92!A8V-O<F1I;F<@=&\*("H@;&]C86P@;F5W;&EN92!C;VYV96YT:6]N+"!R
M96UO=F5S(&5V97)Y=&AI;F<@8F5T=V5E;B!A(#QC;VUM96YT/B!C;VUM86YD
M"B`J(&%N9"!T:&4@;F5X="!B86QA;F-I;F<@/"]C;VUM96YT/B!C;VUM86YD
M+"!A;F0@<F5M;W9E<R!A;&P@;W1H97(*("H@;W1H97(@9F]R;6%T=&EN9R!C
M;VUM86YD<R`H86QL('1E>'0@96YC;&]S960@:6X@86YG;&4@8G)A8VME=',I
M+@H@*@H@*B!792!I;7!L96UE;G0@=&AE(&9O;&QO=VEN9R!T86=S.@H@*B`\
M8F]L9#XL(#QI=&%L:6,^+"`\9FEX960^+"`\<VUA;&QE<CXL(#QB:6=G97(^
M+"`\=6YD97)L:6YE/BP@/&-E;G1E<CXL"B`J(#QF;'5S:&QE9G0^+"`\9FQU
M<VAR:6=H=#XL(#QI;F1E;G0^+"`\<W5B<V-R:7!T/BP@/&5X8V5R<'0^+"`\
M<&%R86=R87!H/BP*("H@/'-I9VYA='5R93XL(#QC;VUM96YT/BP@/&YO+6]P
M/BP@/&QT/BP@/&YL/@H@*@H@*B!4:&4@9F]L;&]W:6YG('1A9W,@87)E(&EM
M<&QE;65N=&5D(&1I9F9E<F5N=&QY('1H86X@9&5S8W)I8F5D(&EN('1H92!2
M1D,*("H@*&1U92!T;R!L:6UI=&%T:6]N<R!I;B!(5$U,(&]U='!U="DZ"B`J
M(#QH96%D:6YG/B`M($]U='!U="!A<R!C96YT97)E9"P@8F]L9"!T97AT+@H@
M*B`\9F]O=&EN9SX@+2!/=71P=70@87,@8V5N=&5R960L(&)O;&0@=&5X="X*
M("H@/&YP/B`@("`@("T@3W5T<'5T(&%S('!A<F%G<F%P:"!B<F5A:RX*("H*
M("H@5&AE(&9O;&QO=VEN9R!T86=S(&%R92!.3U0@:6UP;&5M96YT960Z"B`J
M(#QI;F1E;G1R:6=H=#XL(#QO=71D96YT/BP@/&]U=&1E;G1R:6=H=#XL(#QS
M86UE<&%G93XL(#QI<V\M.#@U.2U8/BP*("H@/'5S+6%S8VEI/BP*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R:6-H=&5X="YP
M:'`L=B`Q+C0N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]R:6-H
M=&5X="!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E
M;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',@:6X@2%1-3"!F
M;W)M870N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N
M>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("@H)'1E>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG
M971#;VYT96YT<R@I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*'1R:6TH)'1E>'0I(#T]
M("<G*2!["B`@("`@("`@("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"@H@
M("`@("`@("\J(%5S92!S=')?:7)E<&QA8V4H*2!I9B!U<VEN9R!02%`@-2XP
M*RX@*B\*("`@("`@("`D:&%S7W-T<E]I<F5P;&%C92`](&9U;F-T:6]N7V5X
M:7-T<R@G<W1R7VER97!L86-E)RD["@H@("`@("`@("\J(%=E(&%D9"!S<&%C
M92!A="!T:&4@8F5G:6YN:6YG(&%N9"!E;F0@;V8@=&AE('-T<FEN9R!A<R!I
M="!W:6QL"B`@("`@("`@("H@;6%K92!S;VUE(')E9W5L87(@97AP<F5S<VEO
M;B!C:&5C:W,@;&%T97(@;75C:"!E87-I97(@*'-O('=E"B`@("`@("`@("H@
M9&]N)W0@:&%V92!T;R!W;W)R>2!A8F]U="!S=&%R="]E;F0@;V8@;&EN92!C
M:&%R86-T97)S*2X@*B\*("`@("`@("`D=&5X="`]("<@)R`N("1T97AT("X@
M)R`G.PH*("`@("`@("`O*B!296UO=F4@979E<GET:&EN9R!B971W965N(#QC
M;VUM96YT/B!T86=S+B`J+PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E
M*"<O/&-O;6UE;G0N*CXN*CQ<+V-O;6UE;G0^+U5I<R<L("<G+"`D=&5X="D[
M"@H@("`@("`@("\J(%)E;6]V92!A;GD@=6YR96-O9VYI>F5D('1A9W,@:6X@
M=&AE('1E>'0N("!792!D;VXG="!N965D(#QN;RUO<#X*("`@("`@("`@*B!I
M;B`D=&%G<R!S:6YC92!I="!D;V5S;B=T(&1O(&%N>71H:6YG(&%N>7=A>2X@
M($%L;"`\8V]M;65N=#X@=&%G<PH@("`@("`@("`J(&AA=F4@86QR96%D>2!B
M965N(')E;6]V960N("HO"B`@("`@("`@)'1A9W,@/2`G/&)O;&0^/&ET86QI
M8SX\9FEX960^/'-M86QL97(^/&)I9V=E<CX\=6YD97)L:6YE/CQC96YT97(^
M/&9L=7-H;&5F=#X\9FQU<VAR:6=H=#X\:6YD96YT/CQS=6)S8W)I<'0^/&5X
M8V5R<'0^/'!A<F%G<F%P:#X\<VEG;F%T=7)E/CQL=#X\;FP^)SL*("`@("`@
M("`D=&5X="`]('-T<FEP7W1A9W,H)'1E>'0L("1T86=S*3L*"B`@("`@("`@
M+RH@/&QT/B!B96-O;65S(&$@)SPG+B!#4DQ&(&)E8V]M97,@82!34$%#12X@
M*B\*("`@("`@("!I9B`H)&AA<U]S=')?:7)E<&QA8V4I('L*("`@("`@("`@
M("`@)'1E>'0@/2!S=')?:7)E<&QA8V4H87)R87DH)SQL=#XG+"`B7')<;B(I
M+"!A<G)A>2@G)FQT.R<L("<@)RDL("1T97AT*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92AA<G)A>2@G+SQL
M=#XO:2<L("(O7')<;B\B*2P@87)R87DH)R9L=#LG+"`G("<I+"`D=&5X="D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!792!T<GD@=&\@<')O=&5C="!A9V%I
M;G-T(&)A9"!S='5F9B!H97)E+B`J+PH@("`@("`@("1T97AT(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H)'1E>'0L($5.5%]154]415,L("1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$-H87)S970H*2D["@H@("`@("`@("\J(#QN;#X@8F5C;VUE<R!A
M(&YE=VQI;F4@*#QB<B`O/BD["B`@("`@("`@("H@/&YP/B!B96-O;65S(&$@
M<&%R86=R87!H(&)R96%K("@\<"`O/BDN("HO"B`@("`@("`@:68@*"1H87-?
M<W1R7VER97!L86-E*2!["B`@("`@("`@("`@("1T97AT(#T@<W1R7VER97!L
M86-E*&%R<F%Y*"<F;'0[;FPF9W0[)RP@)R9L=#MN<"9G=#LG*2P@87)R87DH
M)SQB<B`O/B<L("<\<"`O/B<I+"`D=&5X="D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H87)R87DH)R\H/SPA
M)FQT.RDF;'0[;FPN*B9G=#LO56ES)RP@)R\H/SPA)FQT.RDF;'0[;G`N*B9G
M=#LO56ES)RDL(&%R<F%Y*"<\8G(@+SXG+"`G/'`@+SXG*2P@)'1E>'0I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@3F]W(&-O;G9E<G0@=&AE(&MN;W=N('1A
M9W,@=&\@:'1M;"X@5')Y('1O(')E;6]V92!A;GD@=&%G"B`@("`@("`@("H@
M<&%R86UE=&5R<R!T;R!S=&]P('!E;W!L92!F<F]M('1R>6EN9R!T;R!P=6QL
M(&$@9F%S="!O;F4N("HO"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H
M)R\H/SPA)FQT.RDF;'0[8F]L9"XJ)F=T.R@N*BDF;'0[7"]B;VQD)F=T.R]5
M:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M=V5I9VAT.B!B;VQD(CY<,3PO<W!A
M;CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H
M/SPA)FQT.RDF;'0[:71A;&EC+BHF9W0[*"XJ*29L=#M<+VET86QI8R9G=#LO
M56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT+7-T>6QE.B!I=&%L:6,B/EPQ/"]S
M<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G
M+R@_/"$F;'0[*29L=#MF:7AE9"XJ)F=T.R@N*BDF;'0[7"]F:7AE9"9G=#LO
M56ES)RP@)SQF;VYT(&9A8V4](F9I>&5D(CY<,3PO9F]N=#XG+"`D=&5X="D[
M"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[
M<VUA;&QE<BXJ)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M<VEZ93H@
M<VUA;&QE<B(^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L
M86-E*"<O*#\\(29L=#LI)FQT.UPO<VUA;&QE<B9G=#LO56ES)RP@)SPO<W!A
M;CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H
M/SPA)FQT.RDF;'0[8FEG9V5R+BHF9W0[+U5I<R<L("<\<W!A;B!S='EL93TB
M9F]N="US:7IE.B!L87)G97(B/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]
M('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#M<+V)I9V=E<B9G=#LO56ES
M)RP@)SPO<W!A;CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H/SPA)FQT.RDF;'0[=6YD97)L:6YE+BHF9W0[*"XJ*29L=#M<
M+W5N9&5R;&EN929G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)T97AT+61E8V]R
M871I;VXZ('5N9&5R;&EN92(^7#$\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@
M("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V-E;G1E<BXJ
M)F=T.R@N*BDF;'0[7"]C96YT97(F9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)C
M96YT97(B/EPQ/"]D:78^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9L=7-H;&5F="XJ)F=T.R@N*BDF
M;'0[7"]F;'5S:&QE9G0F9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)L969T(CY<
M,3PO9&EV/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C
M92@G+R@_/"$F;'0[*29L=#MF;'5S:')I9VAT+BHF9W0[*"XJ*29L=#M<+V9L
M=7-H<FEG:'0F9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)R:6=H="(^7#$\+V1I
M=CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H
M/SPA)FQT.RDF;'0[:6YD96YT+BHF9W0[*"XJ*29L=#M<+VEN9&5N="9G=#LO
M56ES)RP@)SQB;&]C:W%U;W1E/EPQ/"]B;&]C:W%U;W1E/B<L("1T97AT*3L*
M("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#ME
M>&-E<G!T+BHF9W0[*"XJ*29L=#M<+V5X8V5R<'0F9W0[+U5I<R<L("<\8VET
M93Y<,3PO8VET93XG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H/SPA)FQT.RDF;'0[<W5B<V-R:7!T+BHF9W0[*"XJ*29L=#M<
M+W-U8G-C<FEP="9G=#LO56ES)RP@)SQS=6(^7#$\+W-U8CXG+"`D=&5X="D[
M"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[
M<W5P97)S8W)I<'0N*B9G=#LH+BHI)FQT.UPO<W5P97)S8W)I<'0F9W0[+U5I
M<R<L("<\<W5P/EPQ/"]S=7`^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@
M<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.VAE861I;F<N*B9G=#LH+BHI
M)FQT.UPO:&5A9&EN9R9G=#LO56ES)RP@)SQB<B`O/CQD:78@86QI9VX](F-E
M;G1E<B(@<W1Y;&4](F9O;G0M=V5I9VAT.B!B;VQD(CY<,3PO9&EV/CQB<B`O
M/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_
M/"$F;'0[*29L=#MF;V]T:6YG+BHF9W0[*"XJ*29L=#M<+V9O;W1I;F<F9W0[
M+U5I<R<L("<\8G(@+SX\9&EV(&%L:6=N/2)C96YT97(B('-T>6QE/2)F;VYT
M+7=E:6=H=#H@8F]L9"(^7#$\+V1I=CX\8G(@+SXG+"`D=&5X="D["B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[<&%R86=R
M87!H+BHF9W0[*"XJ*29L=#M<+W!A<F%G<F%P:"9G=#LO56ES)RP@)SQP/EPQ
M/"]P/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G
M+R@_/"$F;'0[*29L=#MS:6=N871U<F4N*B9G=#LH+BHI)FQT.UPO<VEG;F%T
M=7)E)F=T.R]5:7,G+"`G/&%D9')E<W,^7#$\+V%D9')E<W,^)RP@)'1E>'0I
M.PH*("`@("`@("`O*B!.;W<@=V4@<F5M;W9E('1H92!L96%D:6YG+W1R86EL
M:6YG('-P86-E('=E(&%D9&5D(&%T('1H92!S=&%R="X@*B\*("`@("`@("`D
M=&5X="`]('-U8G-T<B@D=&5X="P@,2P@+3$I.PH*("`@("`@("`O*B!7;W)D
M=W)A<"X@*B\*("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*")<="(L("<@
M("`@("`@("<L("1T97AT*3L*("`@("`@("`D=&5X="`]('-T<E]R97!L86-E
M*"<@("<L("<@)FYB<W`[)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<W1R
M7W)E<&QA8V4H(EQN("(L(")<;B9N8G-P.R(L("1T97AT*3L*("`@("`@("!I
M9B`H)'1E>'1;,%T@/3T@)R`G*2!["B`@("`@("`@("`@("1T97AT(#T@)R9N
M8G-P.R<@+B!S=6)S='(H)'1E>'0L(#$I.PH@("`@("`@('T*("`@("`@("`D
M=&5X="`](&YL,F)R*"1T97AT*3L*("`@("`@("`D=&5X="`]("<\<"!C;&%S
M<STB9FEX960B/B<@+B`D=&5X="`N("<\+W`^)SL*"B`@("`@("`@<F5T=7)N
M("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%
M(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T
M:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3
M.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<```````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#$S,0`Q,#4Q-30S,3`V,0`P,C(T-S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]E;G)I8VAE9"!C;&%S<R!R96YD
M97)S(&]U="!P;&%I;B!T97AT(&9R;VT*("H@96YR:6-H960@8V]N=&5N="!T
M86=S+"!A;&$@4D9#(#$X.38N"B`J"B`J($)Y(%)&0RP@=V4@;75S="!D;R!T
M:&4@;6EN:6UA;"!C;VYF;W)M86YC92!M96%S=7)E<R!O9CH@02!M:6YI;6%L
M"B`J('1E>'0O96YR:6-H960@:6UP;&5M96YT871I;VX@:7,@;VYE('1H870@
M8V]N=F5R=',@(CP\(B!T;R`B/"(L"B`J(')E;6]V97,@979E<GET:&EN9R!B
M971W965N(&$@/'!A<F%M/B!C;VUM86YD(&%N9"!T:&4@;F5X="!B86QA;F-I
M;F<*("H@/"]P87)A;3X@<F5M;W9E<R!A;&P@;W1H97(@9F]R;6%T=&EN9R!C
M;VUM86YD<R`H86QL('1E>'0@96YC;&]S960*("H@:6X@86YG;&4@8G)A8VME
M=',I+"!A;F0@;W5T<VED92!O9B`\;F]F:6QL/B!E;G9I<F]N;65N=',@8V]N
M=F5R=',*("H@86YY('-E<FEE<R!O9B!N($-23$9S('1O(&XM,2!#4DQ&<RP@
M86YD(&-O;G9E<G1S(&%N>2!L;VYE($-23$8*("H@<&%I<G,@=&\@4U!!0T4N
M"B`J"B`J(%=E(&1O;B=T('%U86QI9GD@87,@=V4@9&]N)W0@8W5R<F5N=&QY
M('1R86-K('1H92`\;F]F:6QL/@H@*B!E;G9I<F]N;65N="P@=&AA="!I<R!W
M92!D;R!#4DQ&(&-O;G9E<G-I;VX@979E;B!I9B`\;F]F:6QL/B!I<PH@*B!S
M<&5C:69I960@:6X@=&AE('1E>'0L(&)U="!W92=R92!C;&]S92!A="!L96%S
M="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E
M;G)I8VAE9"YP:'`L=B`Q+C(S+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HR-2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!%<FEC(%)O<W1E
M='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@17)I8R!2;W-T971T97(@/&5R:6,N
M<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@0'-I;F-E("`@2&]R
M9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!-24U%7U9I97=E<E]E;G)I8VAE9"!E>'1E;F1S($U)345?5FEE=V5R('L*
M"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@
M8V]N=&5N=',@:6X@2%1-3"!F;W)M870N(%1H90H@("`@("H@)&UI;65?<&%R
M="!C;&%S<R!V87)I86)L92!H87,@=&AE(&EN9F]R;6%T:6]N('1O(')E;F1E
M<B!O=70L"B`@("`@*B!E;F-A<'-U;&%T960@:6X@82!-24U%7U!A<G0@;V)J
M96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H*0H@("`@>PH@("`@
M("`@(&EF("@H)'1E>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT
M<R@I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*'1R:6TH)'1E>'0I(#T]("<G*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"@H@("`@("`@("\O
M(%=E(&%D9"!S<&%C92!A="!T:&4@8F5G:6YN:6YG(&%N9"!E;F0@;V8@=&AE
M('-T<FEN9R!A<R!I="!W:6QL"B`@("`@("`@+R\@;6%K92!S;VUE(')E9W5L
M87(@97AP<F5S<VEO;B!C:&5C:W,@;&%T97(@;75C:"!E87-I97(@*'-O('=E
M"B`@("`@("`@+R\@9&]N)W0@:&%V92!T;R!W;W)R>2!A8F]U="!S=&%R="]E
M;F0@;V8@;&EN92!C:&%R86-T97)S*0H@("`@("`@("1T97AT(#T@)R`G("X@
M)'1E>'0@+B`G("<["@H@("`@("`@("\O(%=E(&YE960@=&\@<')E<V5R=F4@
M/#P@=&%G<RP@<V\@;6%P('1H96T@=&\@87-C:6D@,2!O<B!A<V-I:2`R-34*
M("`@("`@("`O+R!792!M86ME('1H92!A<W-U;7!T:6]N(&AE<F4@=&AA="!T
M:&5R92!W;W5L9"!N979E<B!B92!A;B!A<V-I:0H@("`@("`@("\O(#$@:6X@
M86X@96UA:6PL('=H:6-H(&UA>2!N;W0@8F4@=F%L:60L(&)U="!S965M<R!R
M96%S;VYA8FQE+BXN"B`@("`@("`@+R\@87-C:6D@,C4U('=O=6QD('=O<FL@
M:68@9F]R('-O;64@<F5A<V]N('EO=2!D;VXG="!L:6ME(&%S8VEI(#$*("`@
M("`@("`O+R!A<V-I:2`P(&1O97,@3D]4('-E96T@=&\@=V]R:R!F;W(@=&AI
M<RP@=&AO=6=H($DG;2!N;W0@<W5R92!W:'D*("`@("`@("`D=&5X="`]('-T
M<E]R97!L86-E*"<\/"<L(&-H<B@Q*2P@)'1E>'0I.PH*("`@("`@("`O+R!2
M96UO=F4@86YY('5N<F5C;V=N:7IE9"!T86=S(&EN('1H92!T97AT("AV:6$@
M4D9#(&UI;FEM86P@<W!E8W,I"B`@("`@("`@+R\@86YY('1A9W,@=V4@:G5S
M="!D;VXG="!W86YT('1O(&EM<&QE;65N="!C86X@86QS;R!B92!R96UO=F5D
M(&AE<F4*("`@("`@("`O+R!.;W1E('1H870@=&AI<R!W:6QL(')E;6]V92!A
M;GD@:'1M;"!L:6YK<RP@8G5T('1H:7,@:7,@:6YT96YD960*("`@("`@("`D
M:6UP;&5M96YT961486=S(#T@)SQP87)A;3X\8F]L9#X\:71A;&EC/CQU;F1E
M<FQI;F4^/&9I>&5D/CQE>&-E<G!T/B<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G/'-M86QL97(^/&)I9V=E<CX\8V5N=&5R/CQC;VQO<CX\9F]N
M=&9A;6EL>3XG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@)SQF;'5S
M:&QE9G0^/&9L=7-H<FEG:'0^/&9L=7-H8F]T:#X\<&%R86EN9&5N=#XG.PH@
M("`@("`@("\O("1U;DEM<&QE;65N=&5D5&%G<R`]("<\;F]F:6QL/CQL86YG
M/B<["B`@("`@("`@)'1E>'0@/2!S=')I<%]T86=S*"1T97AT+"`D:6UP;&5M
M96YT961486=S*3L*"B`@("`@("`@+R\@<F5S=&]R92!T:&4@/#P@=&%G<R!A
M<R`\('1A9W,@;F]W+BXN"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92AC
M:'(H,2DL("<\/"<L("1T97AT*3L*("`@("`@("`O+R`D=&5X="`]('-T<E]R
M97!L86-E*&-H<B@R-34I+"`G/"<L("1T97AT*3L*"B`@("`@("`@+R\@1V5T
M(&-O;&]R('!A<F%M971E<G,@:6YT;R!A(&UO<F4@=7-E86)L92!F;W)M870N
M"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\\8V]L;W(^/'!A<F%M
M/BA;7&1A+69!+49=*RDL*%M<9&$M9D$M1ETK*2PH6UQD82UF02U&72LI/%PO
M<&%R86T^+U5I<R<L("<\8V]L;W(@<CU<,2!G/5PR(&(]7#,^)RP@)'1E>'0I
M.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O/&-O;&]R/CQP87)A
M;3XH<F5D?&)L=65\9W)E96Y\>65L;&]W?&-Y86Y\;6%G96YT87QB;&%C:WQW
M:&ET92D\7"]P87)A;3XO56ES)RP@)SQC;VQO<B!N/5PQ/B<L("1T97AT*3L*
M"B`@("`@("`@+R\@1V5T(&9O;G0@9F%M:6QY('!A<F%M971E<G,@:6YT;R!A
M(&UO<F4@=7-E86)L92!F;W)M870N"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\\9F]N=&9A;6EL>3X\<&%R86T^*%QW*RD\7"]P87)A;3XO56ES
M)RP@)SQF;VYT9F%M:6QY(&8]7#$^)RP@)'1E>'0I.PH*("`@("`@("`O+R!*
M=7-T(')E;6]V92!A;GD@<F5M86EN:6YG('!A<F%M971E<G,@+2T@=V4@=V]N
M)W0@=7-E"B`@("`@("`@+R\@=&AE;2X@06YY('1A9W,@=VET:"!P87)A;65T
M97)S('1H870@=V4@=V%N="!T;R!I;7!L96UE;G0*("`@("`@("`O+R!W:6QL
M(&AA=F4@=&\@8V]M92!B969O<F4@=&AI<R!3;VUE9&%Y('=E(&AO<&4@=&\@
M=7-E('1H97-E"B`@("`@("`@+R\@=&%G<R`H92YG+B!F;W(@/&-O;&]R/CQP
M87)A;3X@=&%G<RD*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+SQP
M87)A;3XN*CQ<+W!A<F%M/B]5:7,G+"`G)RP@)'1E>'0I.PH*("`@("`@("`O
M+R!3:6YG;&4@;&EN92!B<F5A:W,@8F5C;VUE('-P86-E<RP@9&]U8FQE(&QI
M;F4@8G)E86MS(&%R92!A"B`@("`@("`@+R\@<F5A;"!B<F5A:RX@5&AI<R!N
M965D<R!T;R!D;R`\;F]F:6QL/B!T<F%C:VEN9R!T;R!B90H@("`@("`@("\O
M(&-O;7!L:6%N="!B=70@=V4@9&]N)W0@=V%N="!T;R!D96%L('=I=&@@<W1A
M=&4@870@=&AI<PH@("`@("`@("\O('1I;64L('-O('=E(&9A:V4@:70@<V]M
M92!D87D@=V4@<VAO=6QD(')E=W)I=&4@=&AI<R!T;PH@("`@("`@("\O(&AA
M;F1L92`\;F]F:6QL/B!C;W)R96-T;'DN"B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\H6UY<;ETI7')<;BA;7EQR72DO)RP@)UPQ(%PR)RP@)'1E
M>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*%QR7&XI7')<
M;B\G+"`G7#$G+"`D=&5X="D["@H@("`@("`@("\O(%=E('1R>2!T;R!P<F]T
M96-T(&%G86EN<W0@8F%D('-T=69F(&AE<F4N"B`@("`@("`@)'1E>'0@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=&5X="P@14Y47U%53U1%4RP@)'1H:7,M/FUI
M;65?<&%R="T^9V5T0VAA<G-E="@I*3L*"B`@("`@("`@+R\@3F]W(&-O;G9E
M<G0@=&AE(&MN;W=N('1A9W,@=&\@:'1M;"X@5')Y('1O(')E;6]V92!A;GD@
M=&%G"B`@("`@("`@+R\@<&%R86UE=&5R<R!T;R!S=&]P('!E;W!L92!F<F]M
M('1R>6EN9R!T;R!P=6QL(&$@9F%S="!O;F4*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MB;VQD+BHF9W0[*"XJ*29L=#M<
M+V)O;&0F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N="UW96EG:'0Z(&)O
M;&0B/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MI=&%L:6,N*B9G=#LH+BHI)FQT.UPO
M:71A;&EC)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M<W1Y;&4Z(&ET
M86QI8R(^7#$\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.W5N9&5R;&EN92XJ)F=T.R@N*BDF
M;'0[7"]U;F1E<FQI;F4F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB=&5X="UD
M96-O<F%T:6]N.B!U;F1E<FQI;F4B/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@
M("`@("`D=&5X="`]('!R96=?<F5P;&%C95]C86QL8F%C:R@G+R@_/"$F;'0[
M*29L=#MC;VQO<B!R/2A;7&1A+69!+49=*RD@9STH6UQD82UF02U&72LI(&(]
M*%M<9&$M9D$M1ETK*29G=#LH+BHI)FQT.UPO8V]L;W(F9W0[+U5I<R<L(&%R
M<F%Y*"1T:&ES+"`G8V]L;W)I>F4G*2P@)'1E>'0I.PH@("`@("`@("1T97AT
M(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V-O;&]R(&X]*')E9'QB
M;'5E?&=R965N?'EE;&QO=WQC>6%N?&UA9V5N=&%\8FQA8VM\=VAI=&4I)F=T
M.R@N*BDF;'0[7"]C;VQO<B9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)C;VQO
M<CH@7#$B/EPR/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF;VYT9F%M:6QY)F=T.R@N*BDF
M;'0[7"]F;VYT9F%M:6QY)F=T.R]5:7,G+"`G7#$G+"`D=&5X="D["B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[9F]N=&9A
M;6EL>2!F/2A<=RLI)F=T.R@N*BDF;'0[7"]F;VYT9F%M:6QY)F=T.R]5:7,G
M+"`G/'-P86X@<W1Y;&4](F9O;G0M9F%M:6QY.B!<,2(^7#(\+W-P86X^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L
M=#LI)FQT.W-M86QL97(N*B9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT
M+7-I>F4Z('-M86QL97(B/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#M<+W-M86QL97(F9W0[+U5I<R<L
M("<\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L
M86-E*"<O*#\\(29L=#LI)FQT.V)I9V=E<BXJ)F=T.R]5:7,G+"`G/'-P86X@
M<W1Y;&4](F9O;G0M<VEZ93H@;&%R9V5R(CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[7"]B:6=G97(F
M9W0[+U5I<R<L("<\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@
M<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9I>&5D+BHF9W0[*"XJ*29L
M=#M<+V9I>&5D)F=T.R]5:7,G+"`G/&9O;G0@9F%C93TB9FEX960B/EPQ/"]F
M;VYT/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G
M+R@_/"$F;'0[*29L=#MC96YT97(N*B9G=#LH+BHI)FQT.UPO8V5N=&5R)F=T
M.R]5:7,G+"`G/&1I=B!A;&EG;CTB8V5N=&5R(CY<,3PO9&EV/B<L("1T97AT
M*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L
M=#MF;'5S:&QE9G0N*B9G=#LH+BHI)FQT.UPO9FQU<VAL969T)F=T.R]5:7,G
M+"`G/&1I=B!A;&EG;CTB;&5F="(^7#$\+V1I=CXG+"`D=&5X="D["B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[9FQU<VAR
M:6=H="XJ)F=T.R@N*BDF;'0[7"]F;'5S:')I9VAT)F=T.R]5:7,G+"`G/&1I
M=B!A;&EG;CTB<FEG:'0B/EPQ/"]D:78^)RP@)'1E>'0I.PH@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9L=7-H8F]T:"XJ
M)F=T.R@N*BDF;'0[7"]F;'5S:&)O=&@F9W0[+U5I<R<L("<\9&EV(&%L:6=N
M/2)J=7-T:69Y(CY<,3PO9&EV/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]
M('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MP87)A:6YD96YT+BHF9W0[
M*"XJ*29L=#M<+W!A<F%I;F1E;G0F9W0[+U5I<R<L("<\8FQO8VMQ=6]T93Y<
M,3PO8FQO8VMQ=6]T93XG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[97AC97)P="XJ)F=T.R@N*BDF;'0[
M7"]E>&-E<G!T)F=T.R]5:7,G+"`G/&)L;V-K<75O=&4^7#$\+V)L;V-K<75O
M=&4^)RP@)'1E>'0I.PH*("`@("`@("`O+R!297!L86-E(#P\('=I=&@@/"!N
M;W<@*&9R;VT@=')A;G-L871E9"!(5$U,(&9O<FTI+@H@("`@("`@("1T97AT
M(#T@<W1R7W)E<&QA8V4H)R9L=#LF;'0[)RP@)R9L=#LG+"`D=&5X="D["@H@
M("`@("`@("\O($YO=R!W92!R96UO=F4@=&AE(&QE861I;F<O=')A:6QI;F<@
M<W!A8V4@=V4@861D960@870@=&AE"B`@("`@("`@+R\@<W1A<G0N"B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R]>("@N*BD@)"]S)RP@)UPQ)RP@
M)'1E>'0I.PH*("`@("`@("`O+R!-86ME(%523',@8VQI8VMA8FQE+@H@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@
M("`@("`D=&5X="`](%1E>'1?1FEL=&5R.CIF:6QT97(H)'1E>'0L("=L:6YK
M=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@/3X@)TAO<F1E.CIE>'1E<FYA;%5R
M;"<I*3L*"B`@("`@("`@+R\@5V]R9'=R87`@+2T@;F]T92!T:&ES(&-O=6QD
M(&EM<&%C="!O;B!O=7(@86)O=F4@4D9#"B`@("`@("`@+R\@8V]M<&QI86YC
M92`J248J('=E(&AO;F]R960@;F]F:6QL('1A9W,@*'=H:6-H('=E(&1O;B=T
M"B`@("`@("`@+R\@>65T*2X*("`@("`@("`D=&5X="`]('-T<E]R97!L86-E
M*")<="(L("<@("`@("`@("<L("1T97AT*3L*("`@("`@("`D=&5X="`]('-T
M<E]R97!L86-E*"<@("<L("<@)FYB<W`[)RP@)'1E>'0I.PH@("`@("`@("1T
M97AT(#T@<W1R7W)E<&QA8V4H(EQN("(L(")<;B9N8G-P.R(L("1T97AT*3L*
M("`@("`@("!I9B`H)'1E>'1;,%T@/3T@)R`G*2!["B`@("`@("`@("`@("1T
M97AT(#T@)R9N8G-P.R<@+B!S=6)S='(H)'1E>'0L(#$I.PH@("`@("`@('T*
M("`@("`@("`D=&5X="`](&YL,F)R*"1T97AT*3L*("`@("`@("`D=&5X="`]
M("<\<"!C;&%S<STB9FEX960B/B<@+B`D=&5X="`N("<\+W`^)SL*"B`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@(&9U;F-T:6]N(&-O;&]R:7IE
M*"1C;VQO<G,I"B`@("!["B`@("`@("`@9F]R("@D:2`](#$[("1I(#P@-#L@
M)&DK*RD@>PH@("`@("`@("`@("`D8V]L;W)S6R1I72`]('-P<FEN=&8H)R4P
M,E@G+"!R;W5N9"AH97AD96,H)&-O;&]R<ULD:5TI("\@,C4U*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`G/'-P86X@<W1Y;&4](F-O;&]R.B`C)R`N
M("1C;VQO<G-;,5T@+B`D8V]L;W)S6S)=("X@)&-O;&]R<ULS72`N("<B/B<@
M+B`D8V]L;W)S6S1=("X@)SPO<W!A;CXG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R
M960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M
M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,S0T,``Q,#4Q-30S,3`V,0`P,C(S-38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!-24U%7U9I97=E<E]M<V5X8V5L(&-L87-S(')E;F1E<G,@;W5T($UI
M8W)O<V]F="!%>&-E;`H@*B!D;V-U;65N=',@:6X@2%1-3"!F;W)M870@8GD@
M=7-I;F<@=&AE('AL2'1M;"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP+'8@,2XR,"XQ,"XW
M(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E
M9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6
M:65W97)?;7-E>&-E;"!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*
M("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!D871A('5S:6YG('AL
M:'1M;"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY
M('!A<F%M<R!T:&ES(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!G;&]B86P@)&UI;65?9')I=F5R<SL*"B`@("`@("`@+RH@0VAE8VL@
M=&\@;6%K92!S=7)E('1H92!P<F]G<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)VUS97AC96PG75LG;&]C871I;VXG72DI('L*("`@("`@("`@("`@<F5T
M=7)N("<\<')E/B<@+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2XB*2P@)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-E>&-E;"==
M6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@
M)&1A=&$@/2`G)SL*("`@("`@("`D=&UP7WAL<R`]($AO<F1E.CIG971496UP
M1FEL92@G:&]R9&5?;7-E>&-E;"<I.PH*("`@("`@("`D9F@@/2!F;W!E;B@D
M=&UP7WAL<RP@)W<G*3L*("`@("`@("!F=W)I=&4H)&9H+"`D=&AI<RT^;6EM
M95]P87)T+3YG971#;VYT96YT<R@I*3L*("`@("`@("!F8VQO<V4H)&9H*3L*
M"B`@("`@("`@)&9H(#T@<&]P96XH)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M;7-E>&-E;"==6R=L;V-A=&EO;B==("X@(B`M;F@@)'1M<%]X;',@,CXF,2(L
M("=R)RD["B`@("`@("`@=VAI;&4@*"@D<F,@/2!F9V5T<R@D9F@L(#@Q.3(I
M*2D@>PH@("`@("`@("`@("`D9&%T82`N/2`D<F,["B`@("`@("`@?0H@("`@
M("`@('!C;&]S92@D9F@I.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E
M(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U9I97=E<B]S:6UP;&4N<&AP````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$S-3<`,3`U,34T,S$P-C$`,#(R,C$T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M34E-15]6:65W97)?<VEM<&QE(&-L87-S(')E;F1E<G,@;W5T('!L86EN('1E
M>'0@=VET:&]U="!A;GD*("H@;6]D:69I8V%T:6]N<RX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S:6UP;&4N<&AP+'8@,2XQ
M+C8N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)
M345?5FEE=V5R7W-I;7!L92!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!T>7!E(&]F('1H92!R96YD97)E
M9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!-24U%
M+71Y<&4@;V8@=&AE(&]U='!U="!C;VYT96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O<&QA
M:6XG.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%+U!A<G0N<&AP````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`Q,C,R,3$`,3`U,34T,S$P-C$`,#(P,S8R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PIR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN+TU)344N<&AP)SL*"B\J*@H@*B!4:&4@
M8VAA<F%C=&5R*',I('5S960@:6YT97)N86QL>2!F;W(@14],<RX*("HO"F1E
M9FEN92@G34E-15]005)47T5/3"<L(")<;B(I.PH*+RHJ"B`J(%1H92!C:&%R
M86-T97(@<W1R:6YG(&1E<VEG;F%T960@8GD@4D9#<R`X,C(O,C`T-2!T;R!D
M97-I9VYA=&4@14],<R!I;B!-24U%"B`J(&UE<W-A9V5S+@H@*B\*9&5F:6YE
M*"=-24U%7U!!4E1?4D9#7T5/3"<L(")<<EQN(BD["@HO*B!$969A=6QT($U)
M344@<&%R86UE=&5R<RX@*B\*"B\J*@H@*B!4:&4@9&5F875L="!-24U%(&-H
M87)A8W1E<B!S970N"B`J+PID969I;F4H)TU)345?1$5&055,5%]#2$%24T54
M)RP@)W5S+6%S8VEI)RD["@HO*BH*("H@5&AE(&1E9F%U;'0@34E-12!D97-C
M<FEP=&EO;BX*("HO"F1E9FEN92@G34E-15]$149!54Q47T1%4T-225!424].
M)RP@7R@B=6YN86UE9"(I*3L*"B\J*@H@*B!4:&4@9&5F875L="!-24U%(&1I
M<W!O<VET:6]N+@H@*B\*9&5F:6YE*"=-24U%7T1%1D%53%1?1$E34$]3251)
M3TXG+"`G:6YL:6YE)RD["@HO*BH*("H@5&AE(&1E9F%U;'0@34E-12!E;F-O
M9&EN9RX*("HO"F1E9FEN92@G34E-15]$149!54Q47T5.0T]$24Y')RP@)S=B
M:70G*3L*"B\J*@H@*B!4:&4@34E-15]087)T.CH@8VQA<W,@<')O=FED97,@
M82!W<F%P<&5R(&%R;W5N9"!-24U%('!A<G1S(&%N9"!M971H;V1S"B`J(&9O
M<B!D96%L:6YG('=I=&@@=&AE;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+U!A<G0N<&AP+'8@,2XQ-S<N-"XR,"`R,#`V+S`S+S`Y(#(Q
M.C4Y.C,Q(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)344*
M("HO"F-L87-S($U)345?4&%R="!["@H@("`@+RHJ"B`@("`@*B!4:&4@='EP
M92`H97@N.B!T97AT*2!O9B!T:&ES('!A<G0N"B`@("`@*B!097(@4D9#(#(P
M-#4L('1H92!D969A=6QT(&ES("=A<'!L:6-A=&EO;B<N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?='EP92`]("=A<'!L
M:6-A=&EO;B<["@H@("`@+RHJ"B`@("`@*B!4:&4@<W5B='EP92`H97@N.B!P
M;&%I;BD@;V8@=&AI<R!P87)T+@H@("`@("H@4&5R(%)&0R`R,#0U+"!T:&4@
M9&5F875L="!I<R`G;V-T970M<W1R96%M)RX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S=6)T>7!E(#T@)V]C=&5T+7-T
M<F5A;2<["@H@("`@+RHJ"B`@("`@*B!4:&4@8F]D>2!O9B!T:&4@<&%R="X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C
M;VYT96YT<R`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&1E<VER960@=')A
M;G-F97(@96YC;V1I;F<@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1R86YS9F5R16YC;V1I;F<@
M/2!-24U%7T1%1D%53%1?14Y#3T1)3D<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M8W5R<F5N="!T<F%N<V9E<B!E;F-O9&EN9R!O9B!T:&4@8V]N=&5N=',@;V8@
M=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V-U<G)E;G1%;F-O9&EN9R`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!3:&]U;&0@=&AE(&UE<W-A9V4@8F4@96YC;V1E9"!V:6$@-RUB:70_
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7V5N8V]D93=B:70@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE(&1E<V-R
M:7!T:6]N(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]D97-C<FEP=&EO;B`]("<G.PH*("`@("\J
M*@H@("`@("H@5&AE(&1I<W!O<VET:6]N(&]F('1H:7,@<&%R="`H:6YL:6YE
M(&]R(&%T=&%C:&UE;G0I+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V1I<W!O<VET:6]N(#T@34E-15]$149!54Q47T1)
M4U!/4TE424]..PH*("`@("\J*@H@("`@("H@5&AE(&1I<W!O<VET:6]N('!A
M<F%M971E<G,@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?9&ES<&]S:71I;VY087)A;65T97)S(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT('1Y<&4@<&%R
M86UE=&5R<R!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]C;VYT96YT5'EP95!A<F%M971E<G,@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE('-U8G!A<G1S(&]F('1H:7,@
M<&%R="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W!A<G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($EN9F]R;6%T
M:6]N+U-T871I<W1I8W,@;VX@=&AE('-U8G!A<G0N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]I;F9O<FUA=&EO;B`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;&ES="!O9B!#241S(&9O<B!T
M:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]C:61S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!-
M24U%($E$(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]M:6UE:60@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE('-E<75E;F-E('1O('5S92!A<R!%3TP@9F]R('1H:7,@<&%R
M="X*("`@("`J(%1H92!D969A=6QT(&ES(&-U<G)E;G1L>2!T;R!O=71P=70@
M=&AE($5/3"!S97%U96YC92!I;G1E<FYA;&QY(&%S"B`@("`@*B!J=7-T(")<
M;B(@:6YS=&5A9"!O9B!T:&4@8V%N;VYI8V%L(")<<EQN(B!R97%U:7)E9"!I
M;B!21D,@.#(R("8@,C`T-2X*("`@("`J(%1O(&)E(%)&0R!C;VUP;&%I;G0L
M('1H92!F=6QL(#Q#4CX\3$8^($5/3"!C;VUB:6YA=&EO;B!S:&]U;&0@8F4@
M=7-E9`H@("`@("H@=VAE;B!S96YD:6YG(&$@;65S<V%G92X*("`@("`J($ET
M(&ES(&YO="!C<G5C:6%L(&AE<F4@<VEN8V4@=&AE(%!(4"]014%2(&UA:6QI
M;F<@9G5N8W1I;VYS('=I;&P@:&%N9&QE"B`@("`@*B!T:&4@14],(&1E=&%I
M;',N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?96]L(#T@34E-15]005)47T5/3#L*"B`@("`O*BH*("`@("`J($EN=&5R
M;F%L(&-L87-S(&9L86=S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?9FQA9W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@4&%R="`M/B!)1"!M87!P:6YG(&-A8VAE+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:61M87`@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@56YI<75E($U)345?4&%R="!B;W5N9&%R>2!S=')I
M;F<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?8F]U;F1A<GD@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1&5F875L="!V
M86QU92!F;W(@=&AI<R!087)T)W,@<VEZ92X*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8GET97,@/2`P.PH*("`@("\J
M*@H@("`@("H@5&AE(&-O;G1E;G0M240@9F]R('1H:7,@<&%R="X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYT96YT
M:60@/2!N=6QL.PH*("`@("\J*@H@("`@("H@34E-15]087)T(&-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;65T>7!E("`@
M("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!P87)T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]N=&5N=',@("`@(%1H92!B;V1Y(&]F('1H92!P87)T+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@(%1H92!C:&%R86-T
M97(@<V5T(&]F('1H92!P87)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ES
M<&]S:71I;VX@(%1H92!C;VYT96YT(&1I<W!O<VET:6]N(&]F('1H92!P87)T
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96YC;V1I;F<@("`@(%1H92!C;VYT
M96YT(&5N8V]D:6YG(&]F('1H92!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@34E-15]087)T*"1M:6UE='EP92`](&YU;&PL("1C;VYT96YT<R`]
M(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@)&-H87)S970@/2!-24U%
M7T1%1D%53%1?0TA!4E-%5"P@)&1I<W!O<VET:6]N(#T@;G5L;"P*("`@("`@
M("`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2!N=6QL*0H@("`@>PH@("`@
M("`@("\J($-R96%T92!T:&4@=6YI<75E($U)345?4&%R="!B;W5N9&%R>2!S
M=')I;F<N("HO"B`@("`@("`@)'1H:7,M/E]G96YE<F%T94)O=6YD87)Y*"D[
M"@H@("`@("`@("\J(%1H92!C:&%R86-T97(@<V5T('-H;W5L9"!A;'=A>7,@
M8F4@<V5T+"!E=F5N(&EF('=E(&%R92!D96%L:6YG"B`@("`@("`@("H@=VET
M:"!#;VYT96YT+51Y<&5S(&]T:&5R('1H86X@=&5X="\J+B`J+PH@("`@("`@
M("1T:&ES+3YS971#:&%R<V5T*"1C:&%R<V5T*3L*"B`@("`@("`@:68@*"%I
M<U]N=6QL*"1M:6UE='EP92DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=%1Y
M<&4H)&UI;65T>7!E*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6QL
M*"1C;VYT96YT<RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G1S
M*"1C;VYT96YT<RP@)&5N8V]D:6YG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<U]N=6QL*"1D:7-P;W-I=&EO;BDI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=$1I<W!O<VET:6]N*"1D:7-P;W-I=&EO;BD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('1H92!C;VYT96YT+61I<W!O<VET:6]N
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M:7-P;W-I=&EO;B`@5&AE(&-O;G1E;G0M9&ES<&]S:71I;VX@=&\@<V5T("AI
M;FQI;F4@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M='1A8VAM96YT*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&ES<&]S:71I
M;VXH)&1I<W!O<VET:6]N*0H@("`@>PH@("`@("`@("1D:7-P;W-I=&EO;B`]
M(%-T<FEN9SHZ;&]W97(H)&1I<W!O<VET:6]N*3L*"B`@("`@("`@:68@*"@D
M9&ES<&]S:71I;VX@/3T@)VEN;&EN92<I('Q\("@D9&ES<&]S:71I;VX@/3T@
M)V%T=&%C:&UE;G0G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1I<W!O<VET
M:6]N(#T@)&1I<W!O<VET:6]N.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!T:&4@8V]N=&5N="UD:7-P;W-I=&EO;B!O9B!T:&ES('!A
M<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)T)W,@
M8V]N=&5N="UD:7-P;W-I=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1&ES<&]S:71I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1I
M<W!O<VET:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!N86UE
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE(%1H92!N86UE('1O('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M3F%M92@D;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^<V5T0V]N=&5N=%1Y
M<&5087)A;65T97(H)VYA;64G+"`D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@=&AE(&YA;64@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1D96-O9&4@("!-24U%(&1E8V]D92!D97-C<FEP
M=&EO;C\*("`@("`J($!P87)A;2!B;V]L96%N("1D969A=6QT("!)9B!T:&4@
M;F%M92!P87)A;65T97(@9&]E<VXG="!E>&ES="P@<VAO=6QD('=E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E('1H92!D969A=6QT(&YA
M;64@9G)O;2!T:&4@9&5S8W)I<'1I;VX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!P87)A;65T97(_"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!N86UE(&]F('1H92!P87)T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971.86UE*"1D96-O9&4@/2!F86QS92P@)&1E9F%U;'0@/2!F86QS
M92D*("`@('L*("`@("`@("`D;F%M92`]("1T:&ES+3YG971#;VYT96YT5'EP
M95!A<F%M971E<B@G;F%M92<I.PH*("`@("`@("!I9B`H)&1E9F%U;'0@)B8@
M96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("1N86UE(#T@<')E9U]R97!L
M86-E*"=\7%=\)RP@)U\G+"`D=&AI<RT^9V5T1&5S8W)I<'1I;VXH9F%L<V4L
M('1R=64I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D9&5C;V1E*2!["B`@
M("`@("`@("`@(')E='5R;B!T<FEM*$U)344Z.F1E8V]D92@D;F%M92DI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D;F%M93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&)O9'D@8V]N
M=&5N=',@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;G1E;G1S("!4:&4@<&%R="!B;V1Y+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D96YC;V1I;F<@(%1H92!C=7)R96YT(&5N8V]D:6YG(&]F('1H92!C
M;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N=&5N=',H)&-O
M;G1E;G1S+"`D96YC;V1I;F<@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?8V]N=&5N=',@/2`D8V]N=&5N=',["B`@("`@("`@)'1H:7,M/E]F;&%G
M<ULG8V]N=&5N='-3970G72`]('1R=64["B`@("`@("`@)'1H:7,M/E]C=7)R
M96YT16YC;V1I;F<@/2`H:7-?;G5L;"@D96YC;V1I;F<I*2`_("1T:&ES+3YG
M971#=7)R96YT16YC;V1I;F<H*2`Z($U)344Z.F5N8V]D:6YG*"1E;F-O9&EN
M9RP@34E-15]35%))3D<I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D('1O
M('1H92!B;V1Y(&-O;G1E;G1S(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE(&-O;G1E;G1S('1O(&%P
M<&5N9"!T;R!T:&4@8W5R<F5N="!P87)T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@8F]D>2X*("`@("`J($!P87)A;2!S=')I;F<@)&5N8V]D
M:6YG("!4:&4@8W5R<F5N="!E;F-O9&EN9R!O9B!T:&4@8V]N=&5N=',N($EF
M(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('-P96-I9FEE
M9"P@=VEL;"!T<GD@=&\@875T;R!D971E<FUI;F4@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@96YC;V1I;F<N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%P<&5N9$-O;G1E;G1S*"1C;VYT96YT<RP@)&5N8V]D:6YG(#T@
M;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T0V]N=&5N=',H)'1H:7,M
M/E]C;VYT96YT<R`N("1C;VYT96YT<RP@)&5N8V]D:6YG*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-L96%R<R!T:&4@8F]D>2!C;VYT96YT<R!O9B!T:&ES
M('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R0V]N=&5N=',H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?8V]N=&5N=',@/2`G)SL*("`@("`@("`D
M=&AI<RT^7V9L86=S6R=C;VYT96YT<U-E="==(#T@9F%L<V4["B`@("`@("`@
M)'1H:7,M/E]C=7)R96YT16YC;V1I;F<@/2!N=6QL.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!B;V1Y(&]F('1H92!P87)T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&)O9'D@;V8@=&AE('!A
M<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G1S*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G1S(&EN('-T<FEC="!21D,@
M.#(R("8@,C`T-2!O=71P=70@+2!N86UE;'DL(&%L;`H@("`@("H@;F5W;&EN
M97,@96YD('=I=&@@=&AE(&-A;F]N:6-A;"`\0U(^/$Q&/B!S97%U96YC92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N=&ER92!-24U%
M('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A;F]N:6-A;$-O;G1E
M;G1S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)E<&QA8V5%3TPH
M)'1H:7,M/E]C;VYT96YT<RP@34E-15]005)47U)&0U]%3TPI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5')A;G-F97(@96YC;V1E('1H92!C;VYT96YT<R`H
M=&\@=&AE('1R86YS9F5R(&5N8V]D:6YG(&ED96YT:69I960@=FEA"B`@("`@
M*B!G9714<F%N<V9E<D5N8V]D:6YG*"DI(&%N9"!S970@87,@=&AE('!A<G0G
M<R!N97<@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R86YS9F5R
M16YC;V1E0V]N=&5N=',H*0H@("`@>PH@("`@("`@("1C;VYT96YT<R`]("1T
M:&ES+3YT<F%N<V9E<D5N8V]D92@I.PH@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=$5N8V]D:6YG(#T@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R16YC;V1E
M)UT["B`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G1S*"1C;VYT96YT<RP@)'1H
M:7,M/E]C=7)R96YT16YC;V1I;F<I.PH@("`@("`@("1T:&ES+3YS9714<F%N
M<V9E<D5N8V]D:6YG*"1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1R86YS9F5R(&1E8V]D92!T:&4@8V]N=&5N=',@
M86YD('-E="!T:&5M(&%S('1H92!N97<@8V]N=&5N=',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1R86YS9F5R1&5C;V1E0V]N=&5N=',H*0H@("`@>PH@("`@
M("`@("1C;VYT96YT<R`]("1T:&ES+3YT<F%N<V9E<D1E8V]D92@I.PH@("`@
M("`@("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG(#T@)'1H:7,M/E]F;&%G<ULG
M;&%S=%1R86YS9F5R1&5C;V1E)UT["B`@("`@("`@)'1H:7,M/G-E=%1R86YS
M9F5R16YC;V1I;F<H)'1H:7,M/E]C=7)R96YT16YC;V1I;F<I.PH*("`@("`@
M("`O*B!$;VXG="!S970@8V]N=&5N=',@:68@=&AE>2!A<F4@96UP='DL(&)E
M8V%U<V4@=&AI<R!W:6QL(&1O('-T=69F"B`@("`@("`@("`@;&EK92!R97-E
M="!T:&4@:6YT97)N86P@8GET97,@9FEE;&0L(&5V96X@=&AO=6=H('=E('-H
M;W5L9&XG="!D;PH@("`@("`@("`@('1H870@*'1H92!U<V5R(&AA<R!T:&5I
M<B!R96%S;VYS('1O('-E="!T:&4@8GET97,@9FEE;&0@=&\@80H@("`@("`@
M("`@(&YO;BUZ97)O('9A;'5E('=I=&AO=70@<'5T=&EN9R!T:&4@8V]N=&5N
M=',@:6YT;R!T:&ES('!A<G0N("HO"B`@("`@("`@:68@*'-T<FQE;B@D8V]N
M=&5N=',I*2!["B`@("`@("`@("`@("1T:&ES+3YS971#;VYT96YT<R@D8V]N
M=&5N=',L("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&UI;65T>7!E(&]F('1H:7,@
M<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M:6UE='EP92`@
M5&AE(&UI;65T>7!E('1O('-E="`H97@N.B!T97AT+W!L86EN*2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T5'EP92@D;6EM971Y<&4I"B`@("!["B`@("`@
M("`@+RH@4D9#(#(P-#4Z($%N>2!E;G1I='D@=VET:"!U;G)E8V]G;FEZ960@
M96YC;V1I;F<@;75S="!B92!T<F5A=&5D"B`@("`@("`@("`@87,@:68@:70@
M:&%S(&$@0V]N=&5N="U4>7!E(&]F(")A<'!L:6-A=&EO;B]O8W1E="US=')E
M86TB"B`@("`@("`@("`@<F5G87)D;&5S<R!O9B!W:&%T('1H92!#;VYT96YT
M+51Y<&4@9FEE;&0@86-T=6%L;'D@<V%Y<RX@*B\*("`@("`@("!I9B`H)'1H
M:7,M/E]T<F%N<V9E<D5N8V]D:6YG(#T]("=X+75N:VYO=VXG*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@
M)W-E=%1Y<&4G(&9L86<N("HO"B`@("`@("`@)'1H:7,M/E]F;&%G<ULG<V5T
M5'EP92==(#T@=')U93L*"B`@("`@("`@;&ES="@D=&AI<RT^7W1Y<&4L("1T
M:&ES+3Y?<W5B='EP92D@/2!E>'!L;V1E*"<O)RP@4W1R:6YG.CIL;W=E<B@D
M;6EM971Y<&4I*3L*("`@("`@("!I9B`H*"1T>7!E(#T@34E-13HZ='EP92@D
M=&AI<RT^7W1Y<&4L($U)345?4U1224Y'*2DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]T>7!E(#T@)'1Y<&4["@H@("`@("`@("`@("`O*B!3970@=&AE(&)O
M=6YD87)Y('-T<FEN9R!F;W(@)VUU;'1I<&%R="\J)R!P87)T<RX@*B\*("`@
M("`@("`@("`@:68@*"1T>7!E(#T]("=M=6QT:7!A<G0G*2!["B`@("`@("`@
M("`@("`@("!I9B`H(21T:&ES+3YG971#;VYT96YT5'EP95!A<F%M971E<B@G
M8F]U;F1A<GDG*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971#
M;VYT96YT5'EP95!A<F%M971E<B@G8F]U;F1A<GDG+"`D=&AI<RT^7V=E;F5R
M871E0F]U;F1A<GDH*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^8VQE87)#;VYT96YT
M5'EP95!A<F%M971E<B@G8F]U;F1A<GDG*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("=X+75N
M:VYO=VXG.PH@("`@("`@("`@("`D=&AI<RT^8VQE87)#;VYT96YT5'EP95!A
M<F%M971E<B@G8F]U;F1A<GDG*3L*("`@("`@("!]"B`@("!]"@H@("`@("\J
M*@H@("`@("`J($=E="!T:&4@9G5L;"!-24U%($-O;G1E;G0M5'EP92!O9B!T
M:&ES('!A<G0N"B`@("`@("H*("`@("`@*B!`<&%R86T@8F]O;&5A;B`D8VAA
M<G-E="`@07!P96YD(&-H87)A8W1E<B!S970@:6YF;W)M871I;VX@=&\@=&AE
M(&5N9"!O9@H@("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M8V]N=&5N="!T>7!E(&EF('1H:7,@:7,@82!T97AT+RH@<&%R="X*("`@("`@
M*@H@("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6EM971Y<&4@;V8@=&AI
M<R!P87)T"B`@("`@("H@("`@("`@("`@("`@("`@("AE>"XZ('1E>'0O<&QA
M:6X[(&-H87)S970]=7,M87-C:6DI+@H@("`@("`J+PH@("`@(&9U;F-T:6]N
M(&=E=%1Y<&4H)&-H87)S970@/2!F86QS92D*("`@("!["B`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]T>7!E*2!\?"`A:7-S970H)'1H:7,M/E]S=6)T
M>7!E*2D@>PH@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("!]
M"B`@("`@("`@("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y5'EP92@I.PH@
M("`@("`@("`D='EP92`]("1P='EP92`N("<O)R`N("1T:&ES+3YG9713=6)4
M>7!E*"D["B`@("`@("`@(&EF("@D8VAA<G-E="`F)B`H)'!T>7!E(#T]("=T
M97AT)RDI('L*("`@("`@("`@("`@("1T>7!E("X]("<[(&-H87)S970])R`N
M("1T:&ES+3YG971#:&%R<V5T*"D["B`@("`@("`@('T*("`@("`@("`@<F5T
M=7)N("1T>7!E.PH@("`@('T*"B`@("`O*BH*("`@("`J($EF('1H92!S=6)T
M>7!E(&]F(&$@34E-12!P87)T(&ES('5N<F5C;V=N:7IE9"!B>2!A;B!A<'!L
M:6-A=&EO;BP@=&AE"B`@("`@*B!D969A=6QT('1Y<&4@<VAO=6QD(&)E('5S
M960@:6YS=&5A9"`H4V5E(%)&0R`R,#0V*2X@(%1H:7,@;65T:&]D"B`@("`@
M*B!R971U<FYS('1H92!D969A=6QT('-U8G1Y<&4@9F]R(&$@<&%R=&EC=6QA
M<B!P<FEM87)Y($U)344@5'EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&1E9F%U;'0@;6EM971Y<&4@;V8@=&AI<R!P87)T("AE>"XZ
M('1E>'0O<&QA:6XI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT
M5'EP92@I"B`@("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^9V5T4')I;6%R
M>51Y<&4H*2D@>PH@("`@("`@(&-A<V4@)W1E>'0G.@H@("`@("`@("`@("`O
M*B!21D,@,C`T-B`H-"XQ+C0I.B!T97AT('!A<G1S(&1E9F%U;'0@=&\@=&5X
M="]P;&%I;BX@*B\*("`@("`@("`@("`@<F5T=7)N("=T97AT+W!L86EN)SL*
M"B`@("`@("`@8V%S92`G;75L=&EP87)T)SH*("`@("`@("`@("`@+RH@4D9#
M(#(P-#8@*#4N,2XS*3H@;75L=&EP87)T('!A<G1S(&1E9F%U;'0@=&\@;75L
M=&EP87)T+VUI>&5D+B`J+PH@("`@("`@("`@("!R971U<FX@)VUU;'1I<&%R
M="]M:7AE9"<["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("\J(%)&
M0R`R,#0V("@T+C(L(#0N,RP@-"XT+"`T+C4N,RP@-2XR+C0I.B!A;&P@;W1H
M97)S(&1E9F%U;'0@=&\*("`@("`@("`@("`@("`@87!P;&EC871I;VXO;V-T
M970M<W1R96%M+B`J+PH@("`@("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N
M+V]C=&5T+7-T<F5A;2<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!P<FEM87)Y('1Y<&4@;V8@=&AI<R!P87)T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<')I;6%R>2!-24U%('1Y<&4@
M;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<FEM87)Y
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?='EP93L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<W5B='EP92!O9B!T:&ES('!A
M<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%('-U
M8G1Y<&4@;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713
M=6)4>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S=6)T>7!E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!C:&%R86-T97(@<V5T
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M:&%R<V5T("!4:&4@8VAA<F%C=&5R('-E="!O9B!T:&ES('!A<G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$-H87)S970H)&-H87)S970I"B`@("!["B`@
M("`@("`@)'1H:7,M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=C:&%R<V5T
M)RP@)&-H87)S970I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!C
M:&%R86-T97(@<V5T('1O('5S92!F;W(@;V8@=&AI<R!P87)T+B`@4F5T=7)N
M<R!A(&-H87)S970@9F]R"B`@("`@*B!A;&P@='EP97,@*&YO="!J=7-T("=T
M97AT+RHG*2!S:6YC92!W92!U<V4@=&AI<R!C:&%R<V5T('1O(&1E=&5R;6EN
M90H@("`@("H@:&]W('1O(&5N8V]D92!T97AT(&EN($U)344@:&5A9&5R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-H87)A8W1E<B!S
M970@;V8@=&AI<R!P87)T+B`@4F5T=7)N<R!N=6QL(&EF('1H97)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@:7,@;F\@8VAA<F%C=&5R('-E="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0VAA<G-E="@I"B`@("!["B`@("`@("`@)&-H
M87)S970@/2`D=&AI<RT^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V-H87)S
M970G*3L*("`@("`@("!R971U<FX@*&5M<'1Y*"1C:&%R<V5T*2D@/R!N=6QL
M(#H@)&-H87)S970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&1E
M<V-R:7!T:6]N(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D97-C<FEP=&EO;B`@5&AE(&1E<V-R:7!T:6]N(&]F('1H:7,@
M<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5S8W)I<'1I;VXH)&1E
M<V-R:7!T:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&5S8W)I<'1I;VX@
M/2!-24U%.CIE;F-O9&4H)&1E<V-R:7!T:6]N+"`D=&AI<RT^9V5T0VAA<G-E
M="@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@9&5S8W)I<'1I
M;VX@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1D96-O9&4@("!-24U%(&1E8V]D92!D97-C<FEP=&EO;C\*("`@("`J($!P
M87)A;2!B;V]L96%N("1D969A=6QT("!)9B!T:&4@;F%M92!P87)A;65T97(@
M9&]E<VXG="!E>&ES="P@<VAO=6QD('=E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@=7-E('1H92!D969A=6QT(&YA;64@9G)O;2!T:&4@9&5S
M8W)I<'1I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!P87)A
M;65T97(_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D97-C
M<FEP=&EO;B!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$1E<V-R:7!T:6]N*"1D96-O9&4@/2!F86QS92P@)&1E9F%U;'0@/2!F86QS
M92D*("`@('L*("`@("`@("`D9&5S8R`]("1T:&ES+3Y?9&5S8W)I<'1I;VX[
M"@H@("`@("`@(&EF("@D9&5F875L="`F)B!E;7!T>2@D9&5S8RDI('L*("`@
M("`@("`@("`@)&1E<V,@/2`D=&AI<RT^9V5T3F%M92@I.PH@("`@("`@("`@
M("!I9B`H96UP='DH)&1E<V,I*2!["B`@("`@("`@("`@("`@("`D9&5S8R`]
M($U)345?1$5&055,5%]$15-#4DE05$E/3CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"1D96-O9&4I('L*("`@("`@("`@("`@<F5T
M=7)N($U)344Z.F1E8V]D92@D9&5S8RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1D97-C.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@=')A;G-F97(@96YC;V1I;F<@=&\@=7-E(&9O
M<B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D96YC
M;V1I;F<@(%1H92!T<F%N<V9E<B!E;F-O9&EN9R!T;R!U<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%1R86YS9F5R16YC;V1I;F<H)&5N8V]D:6YG*0H@
M("`@>PH@("`@("`@(&EF("@H)&UI;65?96YC;V1I;F<@/2!-24U%.CIE;F-O
M9&EN9R@D96YC;V1I;F<L($U)345?4U1224Y'*2DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]T<F%N<V9E<D5N8V]D:6YG(#T@)&UI;65?96YC;V1I;F<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4D9#(#(P-#4Z($%N>2!E
M;G1I='D@=VET:"!U;G)E8V]G;FEZ960@96YC;V1I;F<@;75S="!B92!T<F5A
M=&5D"B`@("`@("`@("`@("`@(&%S(&EF(&ET(&AA<R!A($-O;G1E;G0M5'EP
M92!O9B`B87!P;&EC871I;VXO;V-T970M<W1R96%M(@H@("`@("`@("`@("`@
M("!R96=A<F1L97-S(&]F('=H870@=&AE($-O;G1E;G0M5'EP92!F:65L9"!A
M8W1U86QL>2!S87ES+B`J+PH@("`@("`@("`@("`D=&AI<RT^<V5T5'EP92@G
M87!P;&EC871I;VXO;V-T970M<W1R96%M)RD["B`@("`@("`@("`@("1T:&ES
M+3Y?=')A;G-F97)%;F-O9&EN9R`]("=X+75N:VYO=VXG.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A($U)344@<W5B<&%R="X*("`@
M("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("1M:6UE7W!A<G0@($%D9"!A
M($U)345?4&%R="!S=6)P87)T('1O('1H92!C=7)R96YT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($U)345?4&%R="X*("`@("`J($!P
M87)A;2!S=')I;F<@)&EN9&5X("`@("`@("`@5&AE(&EN9&5X(&]F('1H92!A
M9&1E9"!-24U%7U!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%!A<G0H
M)&UI;65?<&%R="P@)&EN9&5X(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!!
M9&0@=&AE('!A<G0@=&\@=&AE('!A<G1S(&QI<W0N("HO"B`@("`@("`@:68@
M*&ES7VYU;&PH)&EN9&5X*2D@>PH@("`@("`@("`@("!E;F0H)'1H:7,M/E]P
M87)T<RD["B`@("`@("`@("`@("1I9"`](&ME>2@D=&AI<RT^7W!A<G1S*2`K
M(#$["B`@("`@("`@("`@("1P='(@/2`F)'1H:7,M/E]P87)T<SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<'1R(#T@)B1T:&ES+3Y?<&%R=$9I
M;F0H)&EN9&5X+"`D=&AI<RT^7W!A<G1S+"!T<G5E*3L*("`@("`@("`@("`@
M:68@*"@D<&]S(#T@<W1R<G!O<R@D:6YD97@L("<N)RDI*2!["B`@("`@("`@
M("`@("`@("`D:60@/2!S=6)S='(H)&EN9&5X+"`D<&]S("L@,2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:60@/2`D:6YD97@[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@
M34E-12!)1"!I9B!I="!H87,@;F]T(&%L<F5A9'D@8F5E;B!S970N("HO"B`@
M("`@("`@:68@*"1M:6UE7W!A<G0M/F=E=$U)345)9"@I(#T]/2!N=6QL*2![
M"B`@("`@("`@("`@("1M:6UE7W!A<G0M/G-E=$U)345)9"@D:60I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE('!A<G0@;F]W+B`J+PH@("`@
M("`@("1P=');)&ED72`]("1M:6UE7W!A<G0["@H@("`@("`@("\J($-L96%R
M('1H92!)1"`M/B!087)T(&UA<'!I;F<@8V%C:&4N("HO"B`@("`@("`@)'1H
M:7,M/E]I9&UA<"`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@82!L:7-T(&]F(&%L;"!-24U%('-U8G!A<G1S+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F('1H92!-24U%7U!A<G0@<W5B
M<&%R=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<G1S*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]P87)T<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E(&$@<W!E8VEF:6,@34E-12!P87)T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@34E-15]087)T($E$('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)
M345?4&%R="!R97%U97-T960L(&]R(&9A;'-E(&EF('1H92!P87)T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@9&]E<VXG="!E>&ES="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%R="@D:60I"B`@("!["B`@("`@("`@)&UI;65I
M9"`]("1T:&ES+3YG971-24U%260H*3L*"B`@("`@("`@+RH@5&AI<R!W:6QL
M(&-O;G9E<G0@)R,N,"<@=&\@<VEM<&QY("<C)RP@=VAI8V@@:7,@:&]W('1H
M92!P87)T(&ES"B`@("`@("`@("H@:6YT97)N86QL>2!S=&]R960N("HO"B`@
M("`@("`@)'-E87)C:%]I9"`]("1I9#L*("`@("`@("!I9B`H*"1S='(@/2!S
M=')R8VAR*"1I9"P@)RXG*2D@)B8*("`@("`@("`@("`@*"1S='(@/3T@)RXP
M)RDI('L*("`@("`@("`@("`@)'-E87)C:%]I9"`]('-U8G-T<B@D<V5A<F-H
M7VED+"`P+"`M,BD["B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@=&AI
M<R!P87)T(&EF.@H@("`@("`@("`@(#$I(%1H97)E(&ES(&]N;'D@;VYE('!A
M<G0@*&4N9RX@=&AE($U)344@240@:7,@,"P@;W(@=&AE"B`@("`@("`@("`@
M("`@34E-12!)1"!I<R`Q(&%N9"!T:&5R92!A<F4@;F\@<W5B<&%R=',N"B`@
M("`@("`@("`@,BD@)&ED(&UA=&-H97,@=&AI<R!P87)T<R!-24U%($E$+B`J
M+PH@("`@("`@(&EF("@H)'-E87)C:%]I9"`]/2`P*2!\?`H@("`@("`@("`@
M("`H*"1S96%R8VA?:60@/3T@,2D@)B8@(6-O=6YT*"1T:&ES+3Y?<&%R=',I
M*2!\?`H@("`@("`@("`@("`H(65M<'1Y*"1M:6UE:60I("8F("@D<V5A<F-H
M7VED(#T]("1M:6UE:60I*2D@>PH@("`@("`@("`@("`D<&%R="`]("1T:&ES
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)T(#T@)'1H:7,M
M/E]P87)T1FEN9"@D:60L("1T:&ES+3Y?<&%R=',I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1P87)T("8F"B`@("`@("`@("`@("@D<V5A<F-H7VED("$]
M("1I9"D@)B8*("`@("`@("`@("`@*"1P87)T+3YG9714>7!E*"D@/3T@)VUE
M<W-A9V4O<F9C.#(R)RDI('L*("`@("`@("`@("`@)')E=%]P87)T(#T@571I
M;#HZ8VQO;F5/8FIE8W0H)'!A<G0I.PH@("`@("`@("`@("`D<F5T7W!A<G0M
M/E]P87)T<R`](&%R<F%Y*"D["B`@("`@("`@("`@(')E='5R;B`D<F5T7W!A
M<G0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F4@82!-24U%7U!A<G0@<W5B<&%R="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE($U)344@4&%R="!T
M;R!D96QE=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V95!A<G0H)&ED
M*0H@("`@>PH@("`@("`@(&EF("@H)'!T<B`]("8D=&AI<RT^7W!A<G1&:6YD
M*"1I9"P@)'1H:7,M/E]P87)T<RDI*2!["B`@("`@("`@("`@('5N<V5T*"1P
M='(I.PH@("`@("`@("`@("`D=&AI<RT^7VED;6%P(#T@87)R87DH*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!;'1E<B!A(&-U<G)E;G0@
M34E-12!S=6)P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("`@("`@("`@("`@5&AE($U)344@4&%R="!)1"!T;R!A;'1E<BX*("`@("`J
M($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R="`@5&AE($U)344@4&%R="!T
M;R!S=&]R92X*("`@("`J+PH@("`@9G5N8W1I;VX@86QT97)087)T*"1I9"P@
M)&UI;65?<&%R="D*("`@('L*("`@("`@("!I9B`H*"1P='(@/2`F)'1H:7,M
M/E]P87)T1FEN9"@D:60L("1T:&ES+3Y?<&%R=',I*2D@>PH@("`@("`@("`@
M("`D<'1R(#T@)&UI;65?<&%R=#L*("`@("`@("`@("`@)'1H:7,M/E]I9&UA
M<"`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1G5N8W1I;VX@=7-E9"!T;R!F:6YD(&$@<W!E8VEF:6,@34E-12!087)T(&)Y
M($E$+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@5&AE($U)345?4&%R="!)
M1"!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)B1P87)T<R`@("`@($$@
M;&ES="!O9B!-24U%7U!A<G0@;V)J96-T<RX*("`@("`J($!P87)A;2!B;V]L
M96%N("1R971A<G)A>2`@4F5T=7)N(&$@<&]I;G1E<B!T;R!T:&4@87)R87D@
M=&AA="!S=&]R97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*'=O=6QD('-T;W)E*2!T:&4@<&%R="!R871H97(@=&AA;B!T:&4@<&%R=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!I='-E;&8_"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9?<&%R=$9I;F0H)&ED+"`F)'!A<G1S+"`D<F5T
M87)R87D@/2!F86QS92D*("`@('L*("`@("`@("`O*B!0;VEN=&5R<R!D;VXG
M="!P97)S:7-T('1H<F]U9V@@<V5S<VEO;G,[('1H97)E9F]R92P@=V4@;75S
M="!M86ME"B`@("`@("`@("H@<W5R92!T:&%T('1H92!)9$UA<"!I<R!D97-T
M<F]Y960@870@=&AE(&5N9"!O9B!E86-H(')E<75E<W0N"B`@("`@("`@("H@
M2&]W(&-A;B!W92!D;R!T:&ES/R!792!C:&5C:R!T;R!S964@:68@)%]I9&UA
M<"!C;VYT86EN<R!A;B!A<G)A>0H@("`@("`@("`J(&]F($U)345?4&%R=',@
M;W(@86X@87)R87D@;V8@87)R87ES+B`J+PH@("`@("`@("1C:&5C:R`](')E
M<V5T*"1T:&ES+3Y?:61M87`I.PH@("`@("`@(&EF("AE;7!T>2@D8VAE8VLI
M('Q\("%I<U]A*"1C:&5C:RP@)TU)345?4&%R="<I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?:61M87`@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=&AI<RT^
M7V=E;F5R871E261-87`H)'1H:7,M/E]P87)T<RD["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)')E=&%R<F%Y*2!["B`@("`@("`@("`@(&EF("@D<&]S(#T@
M<W1R<G!O<R@D:60L("<N)RDI('L*("`@("`@("`@("`@("`@("1I9"`]('-U
M8G-T<B@D:60L(#`L("1P;W,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1P87)T<SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:61M87!;)&ED72DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:61M87!;)&ED73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R="`](&9A;'-E.PH@("`@
M("`@("`@("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1V5N97)A=&5S(&$@;6%P<&EN9R!O9B!-24U%7U!A<G1S('=I
M=&@@=&AE:7(@34E-12!)1',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D<&%R=',@($%N(&%R
M<F%Y(&]F($U)345?4&%R=',@=&\@;6%P+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5N97)A=&5)9$UA<"@F)'!A<G1S*0H@("`@>PH@("`@("`@(&EF("@A
M96UP='DH)'!A<G1S*2D@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K
M97ES*"1P87)T<RD@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@)'!T<B`]
M("8D<&%R='-;)&ME>5T["B`@("`@("`@("`@("`@("`D=&AI<RT^7VED;6%P
M6R1P='(M/F=E=$U)345)9"@I72`]("8D<'1R.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]G96YE<F%T94ED36%P*"1P='(M/E]P87)T<RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@:6YF
M;W)M871I;VX@86)O=70@=&AE($U)345?4&%R="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1L86)E;"`@5&AE(&EN9F]R;6%T:6]N(&QA8F5L+@H@
M("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@(%1H92!I;F9O<FUA=&EO;B!T
M;R!S=&]R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T26YF;W)M871I;VXH
M)&QA8F5L+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7VEN9F]R;6%T
M:6]N6R1L86)E;%T@/2`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E(&EN9F]R;6%T:6]N(&%B;W5T('1H92!-24U%7U!A<G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!I;F9O<FUA=&EO
M;B!L86)E;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@:6YF
M;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@4F5T
M=7)N<R!F86QS92!I9B`D;&%B96P@:7,@;F]T('-E="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T26YF;W)M871I;VXH)&QA8F5L*0H@("`@>PH@("`@("`@
M(')E='5R;B`H:7-S970H)'1H:7,M/E]I;F9O<FUA=&EO;ELD;&%B96Q=*2D@
M/R`D=&AI<RT^7VEN9F]R;6%T:6]N6R1L86)E;%T@.B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9"!A(&1I<W!O<VET:6]N('!A<F%M971E<B!T
M;R!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B
M96P@(%1H92!D:7-P;W-I=&EO;B!P87)A;65T97(@;&%B96PN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A("`@5&AE(&1I<W!O<VET:6]N('!A<F%M971E
M<B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$:7-P;W-I=&EO;E!A
M<F%M971E<B@D;&%B96PL("1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M9&ES<&]S:71I;VY087)A;65T97)S6R1L86)E;%T@/2`D9&%T83L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!A(&1I<W!O<VET:6]N('!A<F%M971E<B!F
M<F]M('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L
M86)E;"`@5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!L86)E;"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1A=&$@<F5Q=65S=&5D+@H@
M("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@)&QA8F5L
M(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I<W!O<VET
M:6]N4&%R86UE=&5R*"1L86)E;"D*("`@('L*("`@("`@("!R971U<FX@*&ES
M<V5T*"1T:&ES+3Y?9&ES<&]S:71I;VY087)A;65T97)S6R1L86)E;%TI*2`_
M("1T:&ES+3Y?9&ES<&]S:71I;VY087)A;65T97)S6R1L86)E;%T@.B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@<&%R86UE=&5R<R!F
M<F]M('1H92!#;VYT96YT+41I<W!O<VET:6]N(&AE861E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A;&P@=&AE('!A<F%M
M971E<G,*("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE(&5M<'1Y
M(&%R<F%Y(&EF(&YO('!A<F%M971E<G,@<V5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971!;&Q$:7-P;W-I=&EO;E!A<F%M971E<G,H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1I<W!O<VET:6]N4&%R86UE=&5R<SL*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9"!A(&-O;G1E;G0@='EP92!P87)A;65T
M97(@=&\@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&QA8F5L("!4:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R(&QA8F5L+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!D:7-P;W-I=&EO;B!P87)A
M;65T97(@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N=&5N=%1Y
M<&5087)A;65T97(H)&QA8F5L+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI
M<RT^7V-O;G1E;G14>7!E4&%R86UE=&5R<ULD;&%B96Q=(#T@)&1A=&$["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@82!C;VYT96YT('1Y<&4@<&%R
M86UE=&5R(&9R;VT@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&QA8F5L("!4:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R(&QA8F5L
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!D:7-P;W-I=&EO
M;B!P87)A;65T97(@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87)#
M;VYT96YT5'EP95!A<F%M971E<B@D;&%B96PI"B`@("!["B`@("`@("`@=6YS
M970H)'1H:7,M/E]C;VYT96YT5'EP95!A<F%M971E<G-;)&QA8F5L72D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!C;VYT96YT('1Y<&4@<&%R86UE
M=&5R(&9R;VT@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&QA8F5L("!4:&4@8V]N=&5N="!T>7!E('!A<F%M971E<B!L86)E;"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1A=&$@<F5Q=65S
M=&5D+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@
M)&QA8F5L(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O
M;G1E;G14>7!E4&%R86UE=&5R*"1L86)E;"D*("`@('L*("`@("`@("!R971U
M<FX@*&ES<V5T*"1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S6R1L86)E
M;%TI*2`_("1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S6R1L86)E;%T@
M.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@<&%R86UE
M=&5R<R!F<F]M('1H92!#;VYT96YT+51Y<&4@:&5A9&5R+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%L;"!T:&4@<&%R86UE
M=&5R<PH@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!T:&4@96UP='D@
M87)R87D@:68@;F\@<&%R86UE=&5R<R!S970N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%L;$-O;G1E;G14>7!E4&%R86UE=&5R<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&YE=R!S=')I;F<@=&\@=7-E(&9O
M<B!%3TQS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5O;"`@5&AE
M('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$5/3"@D96]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?96]L(#T@)&5O
M;#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<W1R:6YG('1O('5S
M92!F;W(@14],<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$5/3"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?96]L.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D('1H92!A<'!R;W!R:6%T92!-24U%
M(&AE861E<G,@9F]R('1H:7,@<&%R="!T;R!A;B!E>&ES=&EN9R!A<G)A>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&AE861E<G,@($%N(&%R<F%Y
M(&]F(&%N>2!O=&AE<B!H96%D97)S(&9O<B!T:&4@<&%R="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@:&5A9&5R<RP@=VET:"!T:&4@34E-
M12!H96%D97)S(&%D9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!H96%D97(H
M)&AE861E<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1E;VP@/2`D=&AI
M<RT^9V5T14],*"D["B`@("`@("`@)'!T>7!E(#T@)'1H:7,M/F=E=%!R:6UA
M<GE4>7!E*"D["B`@("`@("`@)'-T>7!E(#T@)'1H:7,M/F=E=%-U8E1Y<&4H
M*3L*"B`@("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@<V5T(&9O<B!T:&ES
M('!A<G0N("HO"B`@("`@("`@)&-H87)S970@/2`D=&AI<RT^9V5T0VAA<G-E
M="@I.PH*("`@("`@("`O*B!'970@=&AE($-O;G1E;G0M5'EP92`M('1H:7,@
M:7,@04Q705E3(')E<75I<F5D+B`J+PH@("`@("`@("1C='EP92`]("1T:&ES
M+3YG9714>7!E*'1R=64I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG971!
M;&Q#;VYT96YT5'EP95!A<F%M971E<G,H*2!A<R`D:V5Y(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`O*B!3:VEP('1H92!C:&%R<V5T(&ME>2!S:6YC92!T
M:&%T('=O=6QD(&AA=F4@86QR96%D>2!B965N"B`@("`@("`@("`@("`J(&%D
M9&5D('1O("1C='EP92!B>2!G9714>7!E*"DN("HO"B`@("`@("`@("`@(&EF
M("@D:V5Y(#T]("=C:&%R<V5T)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-T>7!E("X]("<[("<@
M+B`D:V5Y("X@)STB)R`N('-T<E]R97!L86-E*"<B)RP@)UPB)RP@34E-13HZ
M96YC;V1E*"1V86QU92P@)&-H87)S970I*2`N("<B)SL*("`@("`@("!]"B`@
M("`@("`@)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@34E-13HZ=W)A<$AE
M861E<G,H)T-O;G1E;G0M5'EP92<L("1C='EP92P@)&5O;"D["@H@("`@("`@
M("\J($=E="!T:&4@9&5S8W)I<'1I;VXL(&EF(&%N>2X@*B\*("`@("`@("!I
M9B`H*"1D97-C<FEP(#T@)'1H:7,M/F=E=$1E<V-R:7!T:6]N*"DI*2!["B`@
M("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+41E<V-R:7!T:6]N)UT@/2!-
M24U%.CIW<F%P2&5A9&5R<R@G0V]N=&5N="U$97-C<FEP=&EO;B<L($U)344Z
M.F5N8V]D92@D9&5S8W)I<"P@)&-H87)S970I+"`D96]L*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%)&0R`R,#0U(%LT72`M(&UE<W-A9V4O<F9C.#(R(&%N
M9"!M97-S86=E+W!A<G1I86P@<F5Q=6ER92!T:&4*("`@("`@("`@("!-24U%
M+59E<G-I;VX@:&5A9&5R(&]N;'D@:68@=&AE>2!T:&5M<V5L=F5S(&-L86EM
M('1O(&)E($U)344*("`@("`@("`@("!C;VUP;&EA;G0N("HO"B`@("`@("`@
M:68@*"@D<'1Y<&4@/3T@)VUE<W-A9V4G*2`F)@H@("`@("`@("`@("`H*"1S
M='EP92`]/2`G<F9C.#(R)RD@?'P@*"1S='EP92`]/2`G<&%R=&EA;"<I*2`F
M)@H@("`@("`@("`@("`H<W1R<&]S*"1T:&ES+3Y?8V]N=&5N=',L("=-24U%
M+59E<G-I;VXZ(#$N,"<I("$]/2!F86QS92DI('L*("`@("`@("`@("`@)&AE
M861E<G-;)TU)344M5F5R<VEO;B==(#T@)S$N,"<["B`@("`@("`@?0H*("`@
M("`@("`O*B!M97-S86=E+RH@<&%R=',@<F5Q=6ER92!N;R!A9&1I=&EO;F%L
M(&AE861E<B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H)'!T>7!E(#T]
M("=M97-S86=E)RD@>PH@("`@("`@("`@("!R971U<FX@)&AE861E<G,["B`@
M("`@("`@?0H*("`@("`@("`O*B!$;VXG="!S:&]W($-O;G1E;G0M1&ES<&]S
M:71I;VX@9F]R(&UU;'1I<&%R="!M97-S86=E<R!U;FQE<W,*("`@("`@("`@
M("!T:&5R92!I<R!A(&YA;64@<&%R86UE=&5R+B`J+PH@("`@("`@("1N86UE
M(#T@)'1H:7,M/F=E=$YA;64H*3L*("`@("`@("!I9B`H*"1P='EP92`A/2`G
M;75L=&EP87)T)RD@?'P@(65M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`D
M9&ES<"`]("1T:&ES+3YG971$:7-P;W-I=&EO;B@I.PH*("`@("`@("`@("`@
M+RH@061D(&%N>2!D:7-P;W-I=&EO;B!P87)A;65T97(@:6YF;W)M871I;VXL
M(&EF(&%V86EL86)L92X@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D;F%M
M92DI('L*("`@("`@("`@("`@("`@("1D:7-P("X]("<[("<@+B`G9FEL96YA
M;64](B<@+B!-24U%.CIE;F-O9&4H)&YA;64L("1C:&%R<V5T*2`N("<B)SL*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M
M1&ES<&]S:71I;VXG72`]($U)344Z.G=R87!(96%D97)S*"=#;VYT96YT+41I
M<W!O<VET:6]N)RP@)&1I<W`L("1E;VPI.PH@("`@("`@('T*"B`@("`@("`@
M+RH@061D('1R86YS9F5R(&5N8V]D:6YG(&EN9F]R;6%T:6]N+B`J+PH@("`@
M("`@("1H96%D97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D:6YG)UT@/2`D
M=&AI<RT^9V5T5')A;G-F97)%;F-O9&EN9R@I.PH*("`@("`@("`O*B!!9&0@
M8V]N=&5N="!)1"!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H(6ES7VYU
M;&PH)'1H:7,M/E]C;VYT96YT:60I*2!["B`@("`@("`@("`@("1H96%D97)S
M6R=#;VYT96YT+4E$)UT@/2`D=&AI<RT^7V-O;G1E;G1I9#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:&5A9&5R<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@96YT:7)E('!A<G0@:6X@34E-12!F;W)M870N($EN
M8VQU9&5S(&AE861E<G,@;VX@<F5Q=65S="X*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D:&5A9&5R<R`@26YC;'5D92!T:&4@34E-12!H96%D97)S
M/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!S=')I
M;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"1H96%D97)S(#T@
M=')U92D*("`@('L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH@
M("`@("`@("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y5'EP92@I.PH*("`@
M("`@("!I9B`H)&AE861E<G,I('L*("`@("`@("`@("`@)'1E>'0@/2`G)SL*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FAE861E<B@I(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)&ME>2`N("<Z
M("<@+B`D=F%L("X@)&5O;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&5X="`N/2`D96]L.PH@("`@("`@('T*"B`@("`@("`@+RH@06YY(&EN9F]R
M;6%T:6]N(&%B;W5T(&$@;65S<V%G92\J(&ES(&5M8F5D9&5D(&EN('1H92!M
M97-S86=E"B`@("`@("`@("`@8V]N=&5N=',@=&AE;7-E;&8N(%-I;7!L>2!O
M=71P=70@=&AE(&-O;G1E;G1S(&]F('1H92!P87)T"B`@("`@("`@("`@9&ER
M96-T;'D@86YD(')E='5R;BX@*B\*("`@("`@("!I9B`H)'!T>7!E(#T]("=M
M97-S86=E)RD@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1E>'0I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1E>'0@+B`D=&AI<RT^7V-O;G1E;G1S
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8V]N=&5N=',["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<W-E="@D=&5X="DI('L*("`@("`@("`@("`@)'1E>'0@
M+CT@)'1H:7,M/G1R86YS9F5R16YC;V1E*"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1E>'0@/2`D=&AI<RT^=')A;G-F97)%;F-O9&4H*3L*
M("`@("`@("!]"@H@("`@("`@("\J($1E86P@=VET:"!M=6QT:7!A<G0@;65S
M<V%G97,N("HO"B`@("`@("`@:68@*"1P='EP92`]/2`G;75L=&EP87)T)RD@
M>PH@("`@("`@("`@("`D8F]U;F1A<GD@/2!T<FEM*"1T:&ES+3YG971#;VYT
M96YT5'EP95!A<F%M971E<B@G8F]U;F1A<GDG*2P@)R(G*3L*("`@("`@("`@
M("`@:68@*"%S=')L96XH)'1H:7,M/E]C;VYT96YT<RDI('L*("`@("`@("`@
M("`@("`@("1T97AT("X]("=4:&ES(&UE<W-A9V4@:7,@:6X@34E-12!F;W)M
M870N)R`N("1E;VP["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/F=E=%!A<G1S*"D@87,@)'!A<G0I('L*("`@("`@("`@("`@
M("`@("1T97AT("X]("1E;VP@+B`G+2TG("X@)&)O=6YD87)Y("X@)&5O;#L*
M("`@("`@("`@("`@("`@("1O;&1%3TP@/2`D<&%R="T^9V5T14],*"D["B`@
M("`@("`@("`@("`@("`D<&%R="T^<V5T14],*"1E;VPI.PH@("`@("`@("`@
M("`@("`@)'1E>'0@+CT@)'!A<G0M/G1O4W1R:6YG*'1R=64I.PH@("`@("`@
M("`@("`@("`@)'!A<G0M/G-E=$5/3"@D;VQD14],*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&5X="`N/2`D96]L("X@)RTM)R`N("1B;W5N9&%R
M>2`N("<M+2<@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@96YC;V1E
M9"!P87)T(&EN('-T<FEC="!21D,@.#(R("8@,C`T-2!O=71P=70@+2!N86UE
M;'DL(&%L;`H@("`@("H@;F5W;&EN97,@96YD('=I=&@@=&AE(&-A;F]N:6-A
M;"`\0U(^/$Q&/B!S97%U96YC92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D:&5A9&5R<R`@26YC;'5D92!T:&4@34E-12!H96%D97)S/PH@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YT:7)E($U)344@<&%R
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@=&]#86YO;FEC86Q3=')I;F<H)&AE
M861E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1S=')I;F<@/2`D=&AI<RT^
M=&]3=')I;F<H)&AE861E<G,I.PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5P
M;&%C945/3"@D<W1R:6YG+"!-24U%7U!!4E1?4D9#7T5/3"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3:&]U;&0@=V4@;6%K92!S=7)E('1H92!M97-S86=E
M(&ES(&5N8V]D960@=FEA(#<M8FET("AE+F<N('1O(&%D:&5R90H@("`@("H@
M=&\@;6%I;"!D96QI=F5R>2!S=&%N9&%R9',@<W5C:"!A<R!21D,@,C@R,2D_
M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5S93=B:70@(%5S92`W
M+6)I="!E;F-O9&EN9S\*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R:6-T-V)I
M="@D=7-E-V)I="D*("`@('L*("`@("`@("`D=&AI<RT^7V5N8V]D93=B:70@
M/2`D=7-E-V)I=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@=')A
M;G-F97(@96YC;V1I;F<@9F]R('1H92!P87)T(&)A<V5D(&]N('1H92!U<V5R
M(')E<75E<W1E9`H@("`@("H@=')A;G-F97(@96YC;V1I;F<@86YD('1H92!C
M=7)R96YT(&-O;G1E;G1S(&]F('1H92!P87)T+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=')A;G-F97(M96YC;V1I;F<@;V8@=&AI<R!P
M87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714<F%N<V9E<D5N8V]D:6YG
M*"D*("`@('L*("`@("`@("`D96YC;V1I;F<@/2`D=&AI<RT^7W1R86YS9F5R
M16YC;V1I;F<["B`@("`@("`@)'!T>7!E(#T@)'1H:7,M/F=E=%!R:6UA<GE4
M>7!E*"D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@D=&AI<RT^9V5T
M14],*"DL("<@)RP@)'1H:7,M/E]C;VYT96YT<RD["@H@("`@("`@("\J($EF
M('1H97)E(&%R92!N;R!C;VYT96YT<RP@<F5T=7)N('=H871E=F5R('1H92!C
M=7)R96YT('9A;'5E(&]F"B`@("`@("`@("`@)%]T<F%N<V9E<D5N8V]D:6YG
M(&ES+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&5X="DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E;F-O9&EN9SL*("`@("`@("!]"@H@("`@("`@('-W:71C
M:"`H)'!T>7!E*2!["B`@("`@("`@8V%S92`G;65S<V%G92<Z"B`@("`@("`@
M("`@("\J(%)&0R`R,#0V(%LU+C(N,5T@+2!M97-S86=E+W)F8S@R,B!M97-S
M86=E<R!O;FQY(&%L;&]W(#=B:70L"B`@("`@("`@("`@("`@(#AB:70L(&%N
M9"!B:6YA<GD@96YC;V1I;F=S+B!)9B!T:&4@8W5R<F5N="!E;F-O9&EN9R!I
M<R!E:71H97(*("`@("`@("`@("`@("`@8F%S938T(&]R('$M<"P@<W=I=&-H
M(&ET('1O(#AB:70@:6YS=&5A9"X*("`@("`@("`@("`@("`@4D9#(#(P-#8@
M6S4N,BXR+"`U+C(N,RP@-2XR+C1=("T@06QL(&]T:&5R(&UE<W-A9V4O*B!M
M97-S86=E<PH@("`@("`@("`@("`@("!O;FQY(&%L;&]W(#=B:70@96YC;V1I
M;F=S+B`J+PH@("`@("`@("`@("`D96YC;V1I;F<@/2`H)'1H:7,M/F=E=%-U
M8E1Y<&4H*2`]/2`G<F9C.#(R)RD@/R`G.&)I="<@.B`G-V)I="<["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T97AT)SH*("`@("`@("`@
M("`@:68@*$U)344Z.FES.&)I="@D=&5X="DI('L*("`@("`@("`@("`@("`@
M("1E;F-O9&EN9R`]("@D=&AI<RT^7V5N8V]D93=B:70I(#\@)W%U;W1E9"UP
M<FEN=&%B;&4G(#H@)SAB:70G.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:"@B+R@_.EQN?%XI6UY<;EU[.3DY+'TH/SI<;GPD*2\B+"`D=&5X
M="DI('L*("`@("`@("`@("`@("`@("\J($EF('1H92!T97AT(&ES(&QO;F=E
M<B!T:&%N(#DY."!C:&%R86-T97)S(&)E='=E96X*("`@("`@("`@("`@("`@
M("`J(&QI;F5B<F5A:W,L('5S92!Q=6]T960M<')I;G1A8FQE(&5N8V]D:6YG
M('1O(&5N<W5R92!T:&4*("`@("`@("`@("`@("`@("`J('1E>'0@=VEL;"!N
M;W0@8F4@8VAO<'!E9"`H:2YE+B!B>2!S96YD;6%I;"!I9B!B96EN9R!S96YT
M"B`@("`@("`@("`@("`@("`@*B!A<R!M86EL('1E>'0I+B`J+PH@("`@("`@
M("`@("`@("`@)&5N8V]D:6YG(#T@)W%U;W1E9"UP<FEN=&%B;&4G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("!I9B`H34E-13HZ:7,X8FET*"1T97AT*2D@>PH@("`@
M("`@("`@("`@("`@)&5N8V]D:6YG(#T@*"1T:&ES+3Y?96YC;V1E-V)I="D@
M/R`G8F%S938T)R`Z("<X8FET)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\J($YE960@=&\@9&\@;VYE
M(&QA<W0@8VAE8VL@9F]R(&)I;F%R>2!D871A(&EF(&5N8V]D:6YG(&ES(#=B
M:70@;W(*("`@("`@("`@*B`X8FET+B`@268@=&AE(&UE<W-A9V4@8V]N=&%I
M;G,@82!.54Q,(&-H87)A8W1E<B!A="!A;&PL('1H92!M97-S86=E"B`@("`@
M("`@("H@35535"!B92!I;B!B:6YA<GD@9F]R;6%T+B!21D,@,C`T-B!;,BXW
M+"`R+C@L(#(N.5TN(%$M4"!A;F0@8F%S938T"B`@("`@("`@("H@8V%N(&AA
M;F1L92!B:6YA<GD@9&%T82!F:6YE('-O(&YO(&YE960@=&\@<W=I=&-H('1H
M;W-E(&5N8V]D:6YG<RX@*B\*("`@("`@("!I9B`H*"@D96YC;V1I;F<@/3T@
M)SAB:70G*2!\?"`H)&5N8V]D:6YG(#T]("<W8FET)RDI("8F"B`@("`@("`@
M("`@('!R96=?;6%T8V@H)R]<>#`P+R<L("1T97AT*2D@>PH@("`@("`@("`@
M("`D96YC;V1I;F<@/2`H)'1H:7,M/E]E;F-O9&4W8FET*2`_("=B87-E-C0G
M(#H@)V)I;F%R>2<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5N8V]D
M:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!C=7)R
M96YT(&5N8V]D:6YG(&]F('1H92!C;VYT96YT<R!I;B!T:&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N="!E;F-O
M9&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N=$5N8V]D:6YG
M*"D*("`@('L*("`@("`@("!R971U<FX@*&ES7VYU;&PH)'1H:7,M/E]C=7)R
M96YT16YC;V1I;F<I*2`_("1T:&ES+3Y?=')A;G-F97)%;F-O9&EN9R`Z("1T
M:&ES+3Y?8W5R<F5N=$5N8V]D:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@
M16YC;V1E<R!T:&4@8V]N=&5N=',@=VET:"!T:&4@<&%R="=S('1R86YS9F5R
M(&5N8V]D:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M96YC;V1E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<V9E<D5N
M8V]D92@I"B`@("!["B`@("`@("`@)&5N8V]D:6YG(#T@)'1H:7,M/F=E=%1R
M86YS9F5R16YC;V1I;F<H*3L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/
M3"@I.PH*("`@("`@("`O*B!3970@=&AE("=L87-T5')A;G-F97)%;F-O9&4G
M(&9L86<@<V\@=&AA="!T<F%N<V9E<D5N8V]D94-O;G1E;G1S*"D*("`@("`@
M("`@("!C86X@<V%V92!A(&-A;&P@=&\@9V5T5')A;G-F97)%;F-O9&EN9R@I
M+B`J+PH@("`@("`@("1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D5N8V]D
M92==(#T@)&5N8V]D:6YG.PH*("`@("`@("`O*B!)9B!C;VYT96YT<R!A<F4@
M96UP='DL(&]R(&-O;G1E;G1S(&%R92!A;')E861Y(&5N8V]D960@=&\@=&AE
M"B`@("`@("`@("`@8V]R<F5C="!E;F-O9&EN9RP@<F5T=7)N(&YO=RX@*B\*
M("`@("`@("!I9B`H(7-T<FQE;B@D=&AI<RT^7V-O;G1E;G1S*2!\?`H@("`@
M("`@("`@("`H)&5N8V]D:6YG(#T]("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT<SL*("`@
M("`@("!]"@H@("`@("`@('-W:71C:"`H)&5N8V]D:6YG*2!["B`@("`@("`@
M+RH@0F%S938T($5N8V]D:6YG.B!3964@4D9#(#(P-#4L('-E8W1I;VX@-BXX
M("HO"B`@("`@("`@8V%S92`G8F%S938T)SH*("`@("`@("`@("`@+RH@2V5E
M<&EN9R!T:&5S92!T=V\@;&EN97,@<V5P87)A=&4@<V5E;7,@=&\@=7-E(&UU
M8V@@;&5S<PH@("`@("`@("`@("`@("!M96UO<GD@=&AA;B!C;VUB:6YI;F<@
M=&AE;2`H87,@;V8@4$A0(#0N,RDN("HO"B`@("`@("`@("`@("1E;F-O9&5D
M7V-O;G1E;G1S(#T@8F%S938T7V5N8V]D92@D=&AI<RT^7V-O;G1E;G1S*3L*
M("`@("`@("`@("`@<F5T=7)N(&-H=6YK7W-P;&ET*"1E;F-O9&5D7V-O;G1E
M;G1S+"`W-BP@)&5O;"D["@H@("`@("`@("\J(%%U;W1E9"U0<FEN=&%B;&4@
M16YC;V1I;F<Z(%-E92!21D,@,C`T-2P@<V5C=&EO;B`V+C<@*B\*("`@("`@
M("!C87-E("=Q=6]T960M<')I;G1A8FQE)SH*("`@("`@("`@("`@)&]U='!U
M="`]($U)344Z.G%U;W1E9%!R:6YT86)L945N8V]D92@D=&AI<RT^7V-O;G1E
M;G1S+"`D96]L*3L*("`@("`@("`@("`@:68@*"@D96]L;&5N9W1H(#T@4W1R
M:6YG.CIL96YG=&@H)&5O;"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M<W5B<W1R*"1O=71P=70L(#`L("1E;VQL96YG=&@@*B`M,2D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)&]U='!U=#L*
M("`@("`@("`@("`@?0H*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)E<&QA8V5%3TPH)'1H:7,M/E]C;VYT96YT<RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5C;V1E<R!T:&4@8V]N
M=&5N=',@;V8@=&AE('!A<G0@=&\@96ET:&5R(&$@-V)I="!O<B`X8FET(&5N
M8V]D:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C
M;V1E9"!T97AT+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE
M(&5M<'1Y('-T<FEN9R!I9B!T:&5R92!I<R!N;R!T97AT('1O(&1E8V]D92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-F97)$96-O9&4H*0H@("`@>PH@
M("`@("`@("1E;F-O9&EN9R`]("1T:&ES+3YG971#=7)R96YT16YC;V1I;F<H
M*3L*"B`@("`@("`@+RH@268@=&AE(&-O;G1E;G1S(&%R92!E;7!T>2P@<F5T
M=7)N(&YO=RX@*B\*("`@("`@("!I9B`H(7-T<FQE;B@D=&AI<RT^7V-O;G1E
M;G1S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=L87-T5')A;G-F
M97)$96-O9&4G72`]("1E;F-O9&EN9SL*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8V]N=&5N=',["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1E
M;F-O9&EN9RD@>PH@("`@("`@(&-A<V4@)V)A<V4V-"<Z"B`@("`@("`@("`@
M("1M97-S86=E(#T@8F%S938T7V1E8V]D92@D=&AI<RT^7V-O;G1E;G1S*3L*
M("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C;V1E
M)UT@/2`G.&)I="<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=Q=6]T960M<')I;G1A8FQE)SH*("`@("`@("`@("`@)&UE<W-A9V4@/2!P
M<F5G7W)E<&QA8V4H(B\]7'(_7&XO(BP@)R<L("1T:&ES+3Y?8V]N=&5N=',I
M.PH@("`@("`@("`@("`D;65S<V%G92`]("1T:&ES+3YR97!L86-E14],*"1M
M97-S86=E*3L*("`@("`@("`@("`@)&UE<W-A9V4@/2!Q=6]T961?<')I;G1A
M8FQE7V1E8V]D92@D;65S<V%G92D["B`@("`@("`@("`@("1T:&ES+3Y?9FQA
M9W-;)VQA<W14<F%N<V9E<D1E8V]D92==(#T@*$U)344Z.FES.&)I="@D;65S
M<V%G92DI(#\@)SAB:70G(#H@)S=B:70G.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@+RH@4W5P<&]R="!F;W(@=75E;F-O9&5D(&5N8V]D:6YG("T@
M86QT:&]U9V@@;F]T(')E<75I<F5D(&)Y(%)&0W,L"B`@("`@("`@("`@<V]M
M92!M86EL97)S(&UA>2!S=&EL;"!E;F-O9&4@=&AI<R!W87DN("HO"B`@("`@
M("`@8V%S92`G=75E;F-O9&4G.@H@("`@("`@(&-A<V4@)W@M=75E;F-O9&4G
M.@H@("`@("`@(&-A<V4@)W@M=75E)SH*("`@("`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G8V]N=F5R=%]U=61E8V]D92<I*2!["B`@("`@("`@("`@
M("`@("`D;65S<V%G92`](&-O;G9E<G1?=75E;F-O9&4H)'1H:7,M/E]C;VYT
M96YT<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TUA:6PO;6EM941E8V]D92YP:'`G.PH@("`@("`@("`@
M("`@("`@)&9I;&5S(#T@)DUA:6Q?;6EM941E8V]D93HZ=75D96-O9&4H)'1H
M:7,M/E]C;VYT96YT<RD["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1F
M:6QE<ULP75LG9FEL961A=&$G73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TUA:6PO;6EM941E8V]D92YP:'`G.PH@("`@("`@
M("`@("`D9FEL97,@/2`F36%I;%]M:6UE1&5C;V1E.CIU=61E8V]D92@D=&AI
M<RT^7V-O;G1E;G1S*3L*("`@("`@("`@("`@)&UE<W-A9V4@/2`D9FEL97-;
M,%U;)V9I;&5D871A)UT["B`@("`@("`@("`@("1T:&ES+3Y?9FQA9W-;)VQA
M<W14<F%N<V9E<D1E8V]D92==(#T@)SAB:70G.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==*2`F)@H@("`@("`@
M("`@("`@("`@*"1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==
M("$]("1E;F-O9&EN9RDI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@
M)'1H:7,M/G)E<&QA8V5%3TPH)'1H:7,M/E]C;VYT96YT<RD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1T:&ES
M+3Y?8V]N=&5N=',["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C;V1E)UT@/2`D96YC;V1I;F<["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M
M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W!L:70@=&AE(&-O;G1E
M;G1S(&]F('1H92!C=7)R96YT(%!A<G0@:6YT;R!I=',@<F5S<&5C=&EV92!S
M=6)P87)T<RP*("`@("`J(&EF(&ET(&ES(&UU;'1I<&%R="!-24U%(&5N8V]D
M:6YG+B!5;FQI:V4@=&AE(&EM87!?*B@I(&9U;F-T:6]N<RP@=&AI<PH@("`@
M("H@=VEL;"!P<F5S97)V92!A;&P@34E-12!H96%D97(@:6YF;W)M871I;VXN
M"B`@("`@*@H@("`@("H@5&AE(&)O=6YD87)Y(&-O;G1E;G0M='EP92!P87)A
M;65T97(@;75S="!B92!S970@9F]R('1H:7,@9G5N8W1I;VX@=&\*("`@("`J
M('=O<FL@8V]R<F5C=&QY+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&4@8V]N=&5N=',@=V5R92!S=6-C97-S9G5L;'D@<W!L
M:70N"B`@("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF(&%N>2!E<G)O
M<B!O8V-U<G)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<W!L:71#;VYT96YT
M<R@I"B`@("!["B`@("`@("`@:68@*"$H)&)O=6YD87)Y(#T@)'1H:7,M/F=E
M=$-O;G1E;G14>7!E4&%R86UE=&5R*"=B;W5N9&%R>2<I*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(7-T
M<FQE;B@D=&AI<RT^7V-O;G1E;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/
M3"@I.PH@("`@("`@("1R971V86QU92`](&9A;'-E.PH*("`@("`@("!F;W)E
M86-H("AE>'!L;V1E*"1E;VPL("1T:&ES+3Y?8V]N=&5N=',I(&%S("1L:6YE
M*2!["B`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&QI;F4L("<M+2<@+B`D
M8F]U;F1A<GDI.PH@("`@("`@("`@("!I9B`H*"1P;W,@/3T](&9A;'-E*2`F
M)B!I<W-E="@D<&%R=%]P='(I*2!["B`@("`@("`@("`@("`@("`D9&%T85M=
M(#T@)&QI;F4["B`@("`@("`@("`@('T@96QS96EF("@D<&]S(#T]/2`P*2![
M"B`@("`@("`@("`@("`@("`D<F5T=F%L=64@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P87)T7W!T<BDI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<G1S6R1P87)T7W!T<ETM/G-E=$-O;G1E;G1S*&EM
M<&QO9&4H)&5O;"P@)&1A=&$I*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<G1S6R1P87)T7W!T<ETM/G-P;&ET0V]N=&5N=',H*3L*("`@("`@
M("`@("`@("`@("`@("!N97AT*"1T:&ES+3Y?<&%R=',I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R97-E="@D=&AI
M<RT^7W!A<G1S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9&%T82DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D9&%T82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D<&%R=%]P='(@/2!K
M97DH)'1H:7,M/E]P87)T<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5T=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!297!L86-E(&YE=VQI;F5S(&EN('1H:7,@<&%R="=S(&-O;G1E;G1S('=I
M=&@@=&AO<V4@<W!E8VEF:65D(&)Y(&5I=&AE<@H@("`@("H@=&AE(&=I=F5N
M(&YE=VQI;F4@<V5Q=65N8V4@;W(@=&AE('!A<G0G<R!C=7)R96YT($5/3"!S
M971T:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H
M92!T97AT('1O(')E<&QA8V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;VP@
M("!4:&4@14],('-E<75E;F-E('1O('5S92X@268@;F]T('!R97-E;G0L('5S
M97,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!P87)T)W,@8W5R
M<F5N="!%3TP@<V5T=&EN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('1E>'0@=VET:"!T:&4@;F5W;&EN97,@<F5P;&%C960@8GD@=&AE
M(&1E<VER960*("`@("`J("`@("`@("`@("`@("`@("!N97=L:6YE('-E<75E
M;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97!L86-E14],*"1T97AT+"`D
M96]L(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D96]L*2D@
M>PH@("`@("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"(O7'(_7&XO(BP@)&5O
M;"P@)'1E>'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!U
M;FEQ=64@34E-15]087)T(&)O=6YD87)Y('-T<FEN9R!G96YE<F%T960@9F]R
M('1H:7,@;V)J96-T+@H@("`@("H@5&AI<R!M87D@;F]T(&)E('1H92!B;W5N
M9&%R>2!S=')I;F<@=7-E9"!W:&5N(&)U:6QD:6YG('1H92!M97-S86=E"B`@
M("`@*B!S:6YC92!A('5S97(@9&5F:6YE9"`G8F]U;F1A<GDG($-O;G1E;G0M
M5'EP92!P87)A;65T97(@=VEL;"!O=F5R<FED90H@("`@("H@=&AI<R!V86QU
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N:7%U92!B
M;W5N9&%R>2!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5N:7%U
M94E$*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B;W5N9&%R>3L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T:&4@<VEZ92!O9B!A
M($U)345?4&%R="!A;F0@:71S(&-H:6QD(&UE;6)E<G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!3:7IE(&]F('1H92!-24U%7U!A<G0L(&EN
M(&)Y=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971">71E<R@I"B`@("![
M"B`@("`@("`@)&)Y=&5S(#T@,#L*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?9FQA9W-;)V-O;G1E;G1S4V5T)UTI("8F("1T:&ES+3Y?8GET97,I('L*
M("`@("`@("`@("`@)&)Y=&5S(#T@)'1H:7,M/E]B>71E<SL*("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/F=E=%!R:6UA<GE4>7!E*"D@/3T@)VUU;'1I<&%R
M="<I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E=%!A<G1S*"D@
M87,@)'!A<G0I('L*("`@("`@("`@("`@("`@("\J(%-K:7`@;75L=&EP87)T
M(&5N=')I97,@*'-I;F-E('1H:7,@;6%Y(')E<W5L="!I;B!D;W5B;&4*("`@
M("`@("`@("`@("`@("`@(&-O=6YT:6YG*2X@*B\*("`@("`@("`@("`@("`@
M(&EF("@D<&%R="T^9V5T4')I;6%R>51Y<&4H*2`A/2`G;75L=&EP87)T)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`K/2`D<&%R="T^9V5T0GET
M97,H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T4')I;6%R>51Y
M<&4H*2`]/2`G=&5X="<I('L*("`@("`@("`@("`@("`@("1B>71E<R`](%-T
M<FEN9SHZ;&5N9W1H*"1T:&ES+3Y?8V]N=&5N=',L("1T:&ES+3YG971#:&%R
M<V5T*"DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&)Y=&5S(#T@<W1R;&5N*"1T:&ES+3Y?8V]N=&5N=',I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)Y=&5S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@17AP;&EC:71L>2!S970@=&AE('-I>F4@*&EN(&)Y
M=&5S*2!O9B!T:&ES('!A<G0N(%1H:7,@=F%L=64@=VEL;"!O;FQY"B`@("`@
M*B!B92!R971U<FYE9"`H=FEA(&=E=$)Y=&5S*"DI(&EF('1H97)E(&%R92!N
M;R!C;VYT96YT<R!C=7)R96YT;'D@<V5T+@H@("`@("H@5&AI<R!F=6YC=&EO
M;B!I<R!U<V5F=6P@9F]R('-E='1I;F<@=&AE('-I>F4@;V8@=&AE('!A<G0@
M=VAE;B!T:&4*("`@("`J(&-O;G1E;G1S(&]F('1H92!P87)T(&%R92!N;W0@
M9G5L;'D@;&]A9&5D("AI+F4N(&-R96%T:6YG(&$@34E-15]087)T"B`@("`@
M*B!O8FIE8W0@9G)O;2!)34%0(&AE861E<B!I;F9O<FUA=&EO;B!W:71H;W5T
M(&QO861I;F<@=&AE(&1A=&$@;V8@=&AE"B`@("`@*B!P87)T*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8GET97,@(%1H92!S:7IE(&]F('1H
M:7,@<&%R="!I;B!B>71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0GET
M97,H)&)Y=&5S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8GET97,@/2`D8GET
M97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=70@=&AE('-I>F4@;V8@
M=&AI<R!-24U%7U!A<G0@:6X@2T(N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%-I>F4@;V8@=&AE($U)345?4&%R="P@:6X@<W1R:6YG(&9O<FUA
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VEZ92@I"B`@("!["B`@("`@
M("`@)&)Y=&5S(#T@)'1H:7,M/F=E=$)Y=&5S*"D["B`@("`@("`@:68@*&5M
M<'1Y*"1B>71E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1B>71E<SL*("`@
M("`@("!]"@H@("`@("`@("1L;V-A;&5I;F9O(#T@3DQ3.CIG971,;V-A;&5)
M;F9O*"D["B`@("`@("`@<F5T=7)N(&YU;6)E<E]F;W)M870H)&)Y=&5S("\@
M,3`R-"P@,BP@)&QO8V%L96EN9F];)V1E8VEM86Q?<&]I;G0G72P@)&QO8V%L
M96EN9F];)W1H;W5S86YD<U]S97`G72D["B`@("`@?0H*("`@("\J*@H@("`@
M("H@061D('1O('1H92!L:7-T(&]F($-)1',@9F]R('1H:7,@<&%R="X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-I9',@($$@;&ES="!O9B!-24U%
M($E$<R!O9B!T:&4@<&%R="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M2V5Y("T@34E-12!)1`H@("`@("H@("`@("`@("`@("`@("`@("`@("!686QU
M92`M($-)1"!F;W(@=&AE('!A<G0*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M0TE$*"1C:61S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7V-I
M9',@*ST@)&-I9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!L:7-T(&]F($-)1',@9F]R('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!#241S(&9O<B!T:&ES('!A<G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-)1$QI<W0H*0H@("`@>PH@("`@
M("`@(&%S;W)T*"1T:&ES+3Y?8VED<RP@4T]25%]35%))3D<I.PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-I9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S('1H92!#;VYT96YT+4E$(&AE861E<B!F;W(@=&AI<R!P87)T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&-I9"`@57-E('1H:7,@0TE$("AI
M9B!N;W0@86QR96%D>2!S970I+B`@16QS92P@9V5N97)A=&4@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!R86YD;VT@0TE$+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971#;VYT96YT240H)&-I9"`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)'1H:7,M/E]C;VYT96YT:60I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8V]N=&5N=&ED(#T@*&ES7VYU;&PH)&-I9"DI(#\@*&)A
M<V5?8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*2`N("=`)R`N("1?4T52
M5D526R=315)615)?3D%-12==*2`Z("1C:60["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-O;G1E;G1I9#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE($-O;G1E;G0M240@9F]R('1H:7,@<&%R="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($-O;G1E;G0M240@9F]R
M('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]N=&5N=$E$
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT:60["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!;'1E<B!T:&4@34E-12!)1"!O9B!T:&ES
M('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM96ED("!4
M:&4@34E-12!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T34E-14ED*"1M
M:6UE:60I"B`@("!["B`@("`@("`@)'1H:7,M/E]M:6UE:60@/2`D;6EM96ED
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@34E-12!)1"!O
M9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!-24U%($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-24U%260H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUI;65I9#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E;&%T:79E($U)344@240@;V8@
M=&AI<R!P87)T+@H@("`@("H@92YG+BP@:68@=&AE(&)A<V4@<&%R="!H87,@
M34E-12!)1"!O9B`R+"!A;F0@>6]U('=A;G0@=&AE(&9I<G-T"B`@("`@*B!S
M=6)P87)T(&]F('1H92!B87-E('!A<G0L('1H92!R96QA=&EV92!-24U%($E$
M(&ES(#(N,2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE
M(')E;&%T:79E('!A<G0@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!R96QA=&EV92!-24U%($E$+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971296QA=&EV94U)345)9"@D:60I"B`@("!["B`@("`@("`@)')E;"`]
M("1T:&ES+3YG971-24U%260H*3L*("`@("`@("!R971U<FX@*&5M<'1Y*"1R
M96PI*2`_("1I9"`Z("1R96P@+B`G+B<@+B`D:60["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@;6%P<&EN9R!O9B!A;&P@34E-12!)1',@=&\@
M=&AE:7(@8V]N=&5N="UT>7!E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!+15DZ($U)344@240L(%9!3%5%.B!#;VYT96YT('1Y<&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]N=&5N=%1Y<&5-87`H*0H@("`@>PH@("`@("`@
M("1M87`@/2!A<G)A>2@D=&AI<RT^9V5T34E-14ED*"D@/3X@)'1H:7,M/F=E
M=%1Y<&4H*2D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)T<R!A<R`D
M=F%L*2!["B`@("`@("`@("`@("1M87`@*ST@)'9A;"T^8V]N=&5N=%1Y<&5-
M87`H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1M87`["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@=6YI<75E(&)O=6YD87)Y('-T
M<FEN9R`H:68@;F]T(&%L<F5A9'D@9&]N92DN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!B;W5N9&%R>2!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G96YE
M<F%T94)O=6YD87)Y*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI
M<RT^7V)O=6YD87)Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)O=6YD87)Y
M(#T@)SU?)R`N(&)A<V5?8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F]U;F1A<GD["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O36%G:6,N<&AP````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`R,#4V-0`Q,#4Q-30S,3`V,0`P,C`U,#0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!-24U%7TUA9VEC.CH@8VQA<W,@<')O=FED97,@86X@:6YT
M97)F86-E('1O(&1E=&5R;6EN92!A"B`J($U)344@='EP92!F;W(@=F%R:6]U
M<R!C;VYT96YT+"!I9B!I="!P<F]V:61E9"!W:71H(&1I9F9E<F5N=`H@*B!L
M979E;',@;V8@:6YF;W)M871I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TU)344O34E-12]-86=I8RYP:'`L=B`Q+C4R+C@N,3(@,C`P-B\P,2\P,2`R
M,3HR.#HR-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!
M;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N
M:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!A=71H;W(@
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)
M344*("HO"F-L87-S($U)345?36%G:6,@>PH*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A(&-O<'D@;V8@=&AE($U)344@97AT96YS:6]N(&UA<"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@34E-12!E>'1E;G-I;VX@;6%P+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F7V=E=$UI;65%>'1E;G-I;VY-87`H*0H@("`@>PH@("`@("`@
M('-T871I8R`D;6EM95]E>'1E;G-I;VY?;6%P.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1M:6UE7V5X=&5N<VEO;E]M87`I*2!["B`@("`@("`@("`@(')E<75I
M<F4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+VUI;64N;6%P<&EN9RYP:'`G.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M:6UE7V5X=&5N<VEO;E]M87`[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8V]P>2!O9B!T:&4@
M34E-12!M86=I8R!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!-24U%(&UA9VEC
M(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9V5T36EM94UA9VEC1FEL
M92@I"B`@("!["B`@("`@("`@<W1A=&EC("1M:6UE7VUA9VEC.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1M:6UE7VUA9VEC*2D@>PH@("`@("`@("`@("!R97%U
M:7)E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]M:6UE+FUA9VEC+G!H<"<["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&UI;65?;6%G:6,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&-O;G9E<G0@82!F:6QE(&5X=&5N
M<VEO;B!T;R!A($U)344@='EP92P@8F%S960*("`@("`J(&]N('1H92!G;&]B
M86P@2&]R9&4@86YD(&%P<&QI8V%T:6]N('-P96-I9FEC(&-O;F9I9R!F:6QE
M<RX*("`@("`J"B`@("`@*B!)9B!W92!C86YN;W0@;6%P('1H92!F:6QE(&5X
M=&5N<VEO;B!T;R!A('-P96-I9FEC('1Y<&4L('1H96X*("`@("`J('=E(&9A
M;&P@8F%C:R!T;R!A(&-U<W1O;2!-24U%(&AA;F1L97(@)W@M97AT96YS:6]N
M+R1E>'0G+"!W:&EC:`H@("`@("H@8V%N(&)E('5S960@87,@82!N;W)M86P@
M34E-12!T>7!E(&EN=&5R;F%L;'D@=&AR;W5G:&]U="!(;W)D92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1E>'0@(%1H92!F:6QE(&5X=&5N<VEO
M;B!T;R!B92!M87!P960@=&\@82!-24U%('1Y<&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!-24U%('1Y<&4@;V8@=&AE(&9I;&4@97AT
M96YS:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'14;TU)344H)&5X="D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)&5X="DI('L*("`@("`@("`@("!R
M971U<FX@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&5X="`](%-T<FEN9SHZ;&]W97(H)&5X="D[
M"B`@("`@("`@("`@("1M87`@/2`F34E-15]-86=I8SHZ7V=E=$UI;65%>'1E
M;G-I;VY-87`H*3L*("`@("`@("`@("`@)'!O<R`](#`["B`@("`@("`@("`@
M('=H:6QE("@A:7-S970H)&UA<%LD97AT72D@)B8@)'!O<R`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&5X="P@)RXG*3L*
M("`@("`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@("1E>'0@/2!S=6)S='(H)&5X="P@)'!O<R`K(#$I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H:7-S970H)&UA<%LD97AT72DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D;6%P6R1E>'1=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("=X+65X=&5N<VEO;B\G("X@)&5X=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'0@
M=&\@8V]N=F5R="!A(&9I;&5N86UE('1O(&$@34E-12!T>7!E+"!B87-E9"!O
M;B!T:&4@9VQO8F%L($AO<F1E"B`@("`@*B!A;F0@87!P;&EC871I;VX@<W!E
M8VEF:6,@8V]N9FEG(&9I;&5S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&9I;&5N86UE("!4:&4@9FEL96YA;64@=&\@8F4@;6%P<&5D('1O(&$@
M34E-12!T>7!E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5N:VYO=VX@($AO
M=R!S:&]U;&0@=6YK;F]W;B!E>'1E;G-I;VYS(&)E(&AA;F1L960_($EF"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92P@=VEL;"!R971U
M<FX@)W@M97AT96YS:6]N+RHG('1Y<&5S+B`@268*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!F86QS92P@=VEL;"!R971U<FX@)V%P<&QI8V%T
M:6]N+V]C=&5T+7-T<F5A;2<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!-24U%('1Y<&4@;V8@=&AE(&9I;&5N86UE+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!F:6QE;F%M951O34E-12@D9FEL96YA;64L("1U;FMN;W=N
M(#T@=')U92D*("`@('L*("`@("`@("`D<&]S(#T@<W1R;&5N*"1F:6QE;F%M
M92D@*R`Q.PH@("`@("`@("1T>7!E(#T@)R<["@H@("`@("`@("1M87`@/2`F
M34E-15]-86=I8SHZ7V=E=$UI;65%>'1E;G-I;VY-87`H*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L*("`@("`@("`@("`@("1I(#P]("1M87!;)U]?34%84$52
M24]$7U\G72`F)@H@("`@("`@("`@("`@("`@('-T<G)P;W,H<W5B<W1R*"1F
M:6QE;F%M92P@,"P@)'!O<R`M(#$I+"`G+B<I("$]/2!F86QS93L*("`@("`@
M("`@("`@("1I*RLI('L*("`@("`@("`@("`@)'!O<R`]('-T<G)P;W,H<W5B
M<W1R*"1F:6QE;F%M92P@,"P@)'!O<R`M(#$I+"`G+B<I("L@,3L*("`@("`@
M("!]"B`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC.CIE>'14;TU)344H<W5B
M<W1R*"1F:6QE;F%M92P@)'!O<RDI.PH*("`@("`@("!I9B`H96UP='DH)'1Y
M<&4I('Q\"B`@("`@("`@("`@("@A)'5N:VYO=VX@)B8@*'-T<G!O<R@D='EP
M92P@)W@M97AT96YS:6]N)RD@(3T](&9A;'-E*2DI('L*("`@("`@("`@("`@
M<F5T=7)N("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D='EP93L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&-O;G9E<G0@82!-24U%
M('1Y<&4@=&\@82!F:6QE(&5X=&5N<VEO;BP@8F%S960*("`@("`J(&]N('1H
M92!G;&]B86P@2&]R9&4@86YD(&%P<&QI8V%T:6]N('-P96-I9FEC(&-O;F9I
M9R!F:6QE<RX*("`@("`J"B`@("`@*B!)9B!W92!C86YN;W0@;6%P('1H92!T
M>7!E('1O(&$@9FEL92!E>'1E;G-I;VXL('=E(')E='5R;B!F86QS92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4:&4@34E-12!T>7!E
M('1O(&)E(&UA<'!E9"!T;R!A(&9I;&4@97AT96YS:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!E>'1E;G-I;VX@;V8@=&AE
M($U)344@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@34E-151O17AT*"1T
M>7!E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D='EP92DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&ME>2`]
M(&%R<F%Y7W-E87)C:"@D='EP92P@34E-15]-86=I8SHZ7V=E=$UI;65%>'1E
M;G-I;VY-87`H*2D["B`@("`@("`@:68@*"1K97D@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(&QI<W0H)&UA:F]R+"`D;6EN;W(I(#T@97AP;&]D92@G+R<L
M("1T>7!E*3L*("`@("`@("`@("`@:68@*"1M86IO<B`]/2`G>"UE>'1E;G-I
M;VXG*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&UI;F]R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AS=')P;W,H)&UI;F]R+"`G>"TG*2`]
M/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D;6EN;W(L
M(#(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&ME>3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<V5S('9A<FEA;G1S(&]F
M('1H92!53DE8(")F:6QE(B!C;VUM86YD('1O(&%T=&5M<'0@=&\@9&5T97)M
M:6YE('1H90H@("`@("H@34E-12!T>7!E(&]F(&%N('5N:VYO=VX@9FEL92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@5&AE('!A
M=&@@=&\@=&AE(&9I;&4@=&\@86YA;'EZ92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&UA9VEC7V1B("!0871H('1O('1H92!M:6UE(&UA9VEC(&1A=&%B87-E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!T>7!E
M(&]F('1H92!F:6QE+B`@4F5T=7)N<R!F86QS92!I9B!T:&4@9FEL90H@("`@
M("H@("`@("`@("`@("`@("`@('1Y<&4@:7-N)W0@<F5C;V=N:7IE9"!O<B!A
M;B!E<G)O<B!H87!P96YE9"X*("`@("`J+PH@("`@9G5N8W1I;VX@86YA;'EZ
M949I;&4H)'!A=&@L("1M86=I8U]D8B`](&YU;&PI"B`@("!["B`@("`@("`@
M+RH@268@=&AE(%!(4"!-:6UE='EP92!E>'1E;G-I;VX@:7,@879A:6QA8FQE
M+"!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI
M<W1S*"=F:6QE:6YF;R<I*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D;6%G
M:6-?9&(I*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@0&9I;F9O7V]P96XH
M1DE,14E.1D]?34E-12D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<F5S(#T@0&9I;F9O7V]P96XH1DE,14E.1D]?34E-12P@)&UA
M9VEC7V1B*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)')E<RD@
M>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2!F:6YF;U]F:6QE*"1R97,L("1P
M871H*3L*("`@("`@("`@("`@("`@(&9I;F9O7V-L;W-E*"1R97,I.PH*("`@
M("`@("`@("`@("`@("\J(%)E;6]V92!A;GD@861D:71I;VYA;"!I;F9O<FUA
M=&EO;BX@*B\*("`@("`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"<[)RP@
M)RPG+"`G7%PP)RD@87,@)'-E<&%R871O<BD@>PH@("`@("`@("`@("`@("`@
M("`@("1P;W,@/2!S=')P;W,H)'1Y<&4L("1S97!A<F%T;W(I.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D='EP92`](')T<FEM*'-U8G-T<B@D='EP92P@,"P@
M)'!O<RDI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G?%Y;82UZ,"TY
M72LO6RXM82UZ,"TY72LD?&DG+"`D='EP92DI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1Y<&4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("A5=&EL.CIE>'1E;G-I;VY%
M>&ES=',H)VUI;65?;6%G:6,G*2D@>PH@("`@("`@("`@("!R971U<FX@=')I
M;2AM:6UE7V-O;G1E;G1?='EP92@D<&%T:"DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J(%5S92!A(&)U:6QT+6EN(&UA9VEC(&9I;&4N("HO
M"B`@("`@("`@("`@("1M:6UE7VUA9VEC(#T@)DU)345?36%G:6,Z.E]G971-
M:6UE36%G:6-&:6QE*"D["B`@("`@("`@("`@(&EF("@A*"1F<"`]($!F;W!E
M;B@D<&%T:"P@)W)B)RDI*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&UI;65?
M;6%G:6,@87,@)&]F9G-E="`]/B`D;V1A=&$I('L*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1O9&%T82!A<R`D;&5N9W1H(#T^("1L9&%T82D@>PH@("`@
M("`@("`@("`@("`@("`@($!F<V5E:R@D9G`L("1O9F9S970L(%-%14M?4T54
M*3L*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P(#T@0&9R96%D*"1F<"P@
M)&QE;F=T:"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D;&1A
M=&%;)&QO;VMU<%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9C;&]S
M92@D9G`I.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&QD871A
M6R1L;V]K=7!=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"@H@("`@
M+RHJ"B`@("`@*B!5<V5S('9A<FEA;G1S(&]F('1H92!53DE8(")F:6QE(B!C
M;VUM86YD('1O(&%T=&5M<'0@=&\@9&5T97)M:6YE('1H90H@("`@("H@34E-
M12!T>7!E(&]F(&%N('5N:VYO=VX@8GET92!S=')E86TN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@(%1H92!F:6QE(&1A=&$@=&\@
M86YA;'EZ92X*("`@("`J($!P87)A;2!S=')I;F<@)&UA9VEC7V1B("!0871H
M('1O('1H92!M:6UE(&UA9VEC(&1A=&%B87-E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@34E-12!T>7!E(&]F('1H92!F:6QE+B`@4F5T
M=7)N<R!F86QS92!I9B!T:&4@9FEL90H@("`@("H@("`@("`@("`@("`@("`@
M('1Y<&4@:7-N)W0@<F5C;V=N:7IE9"!O<B!A;B!E<G)O<B!H87!P96YE9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@86YA;'EZ941A=&$H)&1A=&$L("1M86=I
M8U]D8B`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@=&AE(%!(4"!-:6UE
M='EP92!E>'1E;G-I;VX@:7,@879A:6QA8FQE+"!U<V4@=&AA="X@*B\*("`@
M("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S*"=F:6QE:6YF;R<I*2![
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D;6%G:6-?9&(I*2!["B`@("`@("`@
M("`@("`@("`D<F5S(#T@0&9I;F9O7V]P96XH1DE,14E.1D]?34E-12D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S(#T@0&9I
M;F9O7V]P96XH1DE,14E.1D]?34E-12P@)&UA9VEC7V1B*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1Y
M<&4@/2!F:6YF;U]B=69F97(H)')E<RP@)&1A=&$I.PH@("`@("`@("`@("!F
M:6YF;U]C;&]S92@D<F5S*3L*"B`@("`@("`@("`@("\J(%)E;6]V92!A;GD@
M861D:71I;VYA;"!I;F9O<FUA=&EO;BX@*B\*("`@("`@("`@("`@)'!O<R`]
M('-T<G!O<R@D='EP92P@)SLG*3L*("`@("`@("`@("`@:68@*"1P;W,@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D='EP92`](')T<FEM*'-U8G-T
M<B@D='EP92P@,"P@)'!O<RDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1P;W,@/2!S=')P;W,H)'1Y<&4L("<L)RD["B`@("`@("`@("`@(&EF("@D
M<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2!R=')I
M;2AS=6)S='(H)'1Y<&4L(#`L("1P;W,I*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)'1Y<&4["B`@("`@("`@?0H*("`@("`@("`O*B!5
M<V4@82!B=6EL="UI;B!M86=I8R!F:6QE+B`J+PH@("`@("`@("1M:6UE7VUA
M9VEC(#T@)DU)345?36%G:6,Z.E]G971-:6UE36%G:6-&:6QE*"D["B`@("`@
M("`@9F]R96%C:"`H)&UI;65?;6%G:6,@87,@)&]F9G-E="`]/B`D;V1A=&$I
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&]D871A(&%S("1L96YG=&@@/3X@
M)&QD871A*2!["B`@("`@("`@("`@("`@("`D;&]O:W5P(#T@<W5B<W1R*"1D
M871A+"`D;V9F<V5T+"`D;&5N9W1H*3L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)&QD871A6R1L;V]K=7!=*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D;&1A=&%;)&QO;VMU<%T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O341.+G!H<```````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R,C<S,@`Q,#4Q-30S,3`V,0`P,C`Q,#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!-24U%7TU$3CHZ(&-L87-S(&EM<&QE;65N=',@365S<V%G92!$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VYS(&%S"B`J(&1E<V-R:6)E9"!B>2!21D,@,C(Y
M."X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`L
M=B`Q+C0N,3`N."`R,#`V+S`Q+S(T(#(Q.C,R.C4V('-L=7-A<GH@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8W5R96-A;G1I+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!C=7)E8V%N=&DN;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-10H@
M*B\*8VQA<W,@34E-15]-1$X@>PH*("`@("\J*@H@("`@("H@5&AE($U)345?
M2&5A9&5R<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!-24U%7TAE861E
M<G,*("`@("`J+PH@("`@=F%R("1?:&5A9&5R<SL*"B`@("`O*BH*("`@("`J
M(%1H92!T97AT(&]F('1H92!O<FEG:6YA;"!M97-S86=E+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUS9W1E>'0@/2!F
M86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!P87)A;2!-24U%7TAE861E<G,@)&UI;65?:&5A9&5R<R`@02!-24U%
M7TAE861E<G,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!-24U%7TU$
M3B@D;6EM95]H96%D97)S(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^
M7VAE861E<G,@/2`D;6EM95]H96%D97)S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@861D<F5S<R!T;R!R971U<FX@=&AE($U$3B!T;RX*
M("`@("`J(%)E='5R;G,@;G5L;"!I9B!N;R!-1$X@:7,@<F5Q=65S=&5D+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@861D<F5S<R!T;R!S
M96YD('1H92!-1$X@=&\N(%)E='5R;G,@;G5L;"!I9B!N;PH@("`@("H@("`@
M("`@("`@("`@("`@($U$3B!I<R!R97%U97-T960N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$U$3E)E='5R;D%D9'(H*0H@("`@>PH@("`@("`@("\J(%)&
M0R`R,CDX(%LR+C%=(')E<75I<F5S('1H92!$:7-P;W-I=&EO;BU.;W1I9FEC
M86EO;BU4;R!H96%D97(*("`@("`@("`@*B!F;W(@86X@341.('1O(&)E(&-R
M96%T960N("HO"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:&5A9&5R<RT^9V5T
M5F%L=64H)T1I<W!O<VET:6]N+4YO=&EF:6-A=&EO;BU4;R<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@27,@=7-E<B!I;G!U="!R97%U:7)E9"!T;R!S96YD
M('1H92!-1$X_"B`@("`@*B!%>'!L:6-I="!C;VYF:7)M871I;VX@:7,@;F5E
M9&5D(&EN('-O;64@8V%S97,@=&\@<')E=F5N="!M86EL(&QO;W!S"B`@("`@
M*B!A;F0@=&AE('5S92!O9B!-1$YS(&9O<B!M86EL(&)O;6)I;F<N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!)<R!E>'!L:6-I="!U<V5R(&EN
M<'5T(')E<75I<F5D('1O('-E;F0@=&AE($U$3C\*("`@("`J+PH@("`@9G5N
M8W1I;VX@=7-E<D-O;F9I<FUA=&EO;DYE961E9"@I"B`@("!["B`@("`@("`@
M)')E='5R;E]P871H(#T@)'1H:7,M/E]H96%D97)S+3YG971686QU92@G4F5T
M=7)N+5!A=&@G*3L*"B`@("`@("`@+RH@4D9#(#(R.3@@6S(N,5TZ($5X<&QI
M8VET(&-O;F9I<FUA=&EO;B!I<R!N965D960@:68@=&AE<F4@:7,@;F\*("`@
M("`@("`@*B!2971U<FXM4&%T:"!I;B!T:&4@:&5A9&5R+B!!;'-O+"`B:68@
M=&AE(&UE<W-A9V4@8V]N=&%I;G,@;6]R90H@("`@("`@("`J('1H86X@;VYE
M(%)E='5R;BU0871H(&AE861E<BP@=&AE(&EM<&QE;65N=&%T:6]N(&UA>2!;
M72!T<F5A="!T:&4*("`@("`@("`@*B!S:71U871I;VX@87,@82!F86EL=7)E
M(&]F('1H92!C;VUP87)I<V]N+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<F5T
M=7)N7W!A=&@I('Q\(&ES7V%R<F%Y*"1R971U<FY?<&%T:"DI('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E
M7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@)'!A<G-E<B`]("9N
M97<@36%I;%]21D,X,C(H*3L*"B`@("`@("`@+RH@4D9#(#(R.3@@6S(N,5TZ
M($5X<&QI8VET(&-O;F9I<FUA=&EO;B!I<R!N965D960@:68@=&AE<F4@:7,@
M;6]R90H@("`@("`@("`J('1H86X@;VYE(&1I<W1I;F-T(&%D9')E<W,@:6X@
M=&AE($1I<W!O<VET:6]N+4YO=&EF:6-A=&EO;BU4;PH@("`@("`@("`J(&AE
M861E<BX@*B\*("`@("`@("`D861D<E]A<G(@/2`D<&%R<V5R+3YP87)S94%D
M9')E<W-,:7-T*"1T:&ES+3YG971-1$Y2971U<FY!9&1R*"DL(&YU;&PL(&YU
M;&PL(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D861D<E]A<G(L("=014%2
M7T5R<F]R)RD@?'P@*&-O=6YT*"1A9&1R7V%R<BD@/B`Q*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J(%)&0R`R
M,CDX(%LR+C%=('-T871E<R!T:&%T(")-1$YS(%-(3U5,1"!.3U0@8F4@<V5N
M="!A=71O;6%T:6-A;&QY"B`@("`@("`@("H@:68@=&AE(&%D9')E<W,@:6X@
M=&AE($1I<W!O<VET:6]N+4YO=&EF:6-A=&EO;BU4;R!H96%D97(@9&EF9F5R
M<PH@("`@("`@("`J(&9R;VT@=&AE(&%D9')E<W,@:6X@=&AE(%)E='5R;BU0
M871H(&AE861E<BXB(%1H:7,@8V]M<&%R:7-O;B!I<PH@("`@("`@("`J(&-A
M<V4M<V5N<VET:79E(&9O<B!T:&4@;6%I;&)O>"!P87)T(&%N9"!C87-E+6EN
M<V5N<VET:79E(&9O<B!T:&4*("`@("`@("`@*B!H;W-T('!A<G0N("HO"B`@
M("`@("`@)')E=%]A<G(@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1R
M971U<FY?<&%T:"P@;G5L;"P@;G5L;"P@9F%L<V4I.PH@("`@("`@(&EF("@A
M:7-?82@D<F5T7V%R<BP@)U!%05)?17)R;W(G*2`F)@H@("`@("`@("`@("`H
M*"1A9&1R7V%R<ELP72T^;6%I;&)O>"`A/2`D<F5T7V%R<ELP72T^;6%I;&)O
M>"D@?'P*("`@("`@("`@("`@*%-T<FEN9SHZ;&]W97(H)&%D9')?87)R6S!=
M+3YH;W-T*2`A/2!3=')I;F<Z.FQO=V5R*"1R971?87)R6S!=+3YH;W-T*2DI
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5VAE;B!G
M96YE<F%T:6YG('1H92!-1$XL('-H;W5L9"!W92!R971U<FX@=&AE(&5N:71R
M92!T97AT(&]F('1H90H@("`@("H@;W)I9VEN86P@;65S<V%G93\@(%1H92!D
M969A=6QT(&ES(&YO("T@=V4@;VYL>2!R971U<FX@=&AE(&AE861E<G,@;V8*
M("`@("`J('1H92!O<FEG:6YA;"!M97-S86=E+B!)9B!T:&4@=&5X="!I<R!P
M87-S960@:6X@=FEA('1H:7,@;65T:&]D+"!W90H@("`@("H@=VEL;"!R971U
M<FX@=&AE(&5N=&ER92!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@(%1H92!T97AT(&]F('1H92!O<FEG:6YA;"!M97-S86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!O<FEG:6YA;$UE<W-A9V5497AT*"1T
M97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;7-G=&5X="`]("1T97AT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE($U$3B!A8V-O<F1I
M;F<@=&\@=&AE('-P96-I9FEC871I;VYS(&QI<W1E9"!I;B!21D,*("`@("`J
M(#(R.3@@6S-=+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1A8W1I
M;VX@("!787,@=&AI<R!-1$X@='EP92!A(')E<W5L="!O9B!A(&UA;G5A;"!A
M8W1I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!O;B!P87)T
M(&]F('1H92!U<V5R/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)'-E;F1I;F<@
M(%=A<R!T:&ES($U$3B!S96YT(&%S(&$@<F5S=6QT(&]F(&$@;6%N=6%L"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86-T:6]N(&]N('!A<G0@
M;V8@=&AE('5S97(_"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@
M5&AE('1Y<&4@;V8@86-T:6]N('!E<F9O<FUE9"!B>2!T:&4@=7-E<BX*("`@
M("`J(#QP<F4^"B`@("`@*B!097(@4D9#(#(R.3@@6S,N,BXV+C)=('1H92!F
M;VQL;W=I;F<@='EP97,@87)E('9A;&ED.@H@("`@("H@/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("`@
M("H@)V1I<W!L87EE9"<*("`@("`J("=D:7-P871C:&5D)PH@("`@("H@)W!R
M;V-E<W-E9"<*("`@("`J("=D96QE=&5D)PH@("`@("H@)V1E;FEE9"<*("`@
M("`J("=F86EL960G"B`@("`@*B`\+W!R93X*("`@("`J($!P87)A;2!A<G)A
M>2`D;6]D("`@("`@("!4:&4@;&ES="!O9B!M;V1I9FEC871I;VYS+@H@("`@
M("H@/'!R93X*("`@("`J(%!E<B!21D,@,C(Y."!;,RXR+C8N,UT@=&AE(&9O
M;&QO=VEN9R!M;V1I9FEC871I;VYS(&%R92!V86QI9#H*("`@("`J(#T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@("`@("H@)V5R<F]R)PH@("`@("H@)W=A<FYI;F<G"B`@
M("`@*B`G<W5P97)S961E9"<*("`@("`J("=E>'!I<F5D)PH@("`@("H@)VUA
M:6QB;W@M=&5R;6EN871E9"<*("`@("`J(#PO<')E/@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1E<G(@("`@("`@($EF("1T>7!E(&ES("=F86EL=64G(&]R("1M
M;V0@:7,@96ET:&5R("=E<G)O<B<*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!O<B`G=V%R;FEN9R<L('1H92!A9&1I=&EO;F%L(&EN9F]R;6%T
M:6]N('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@<')O=FED
M92X@($ME>2!I<R!T:&4@='EP92!O9B!M;V1I9FEC871I;VXL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@=F%L=64@:7,@=&AE('1E>'0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!0
M14%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5N97)A=&4H)&%C=&EO;BP@)'-E;F1I;F<L("1T>7!E+"`D;6]D(#T@
M87)R87DH*2P@)&5R<B`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]-24U%+TAE861E<G,N<&AP)SL*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+TU)344O365S<V%G92YP:'`G.PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@+RH@4V5T('5P
M('-O;64@=F%R:6%B;&5S('=E('5S92!L871E<BX@*B\*("`@("`@("`D:61E
M;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PH@("`@("`@("1F<F]M
M7V%D9'(@/2`D:61E;G1I='DM/F=E=$1E9F%U;'1&<F]M061D<F5S<R@I.PH*
M("`@("`@("`D=&\@/2`D=&AI<RT^9V5T341.4F5T=7)N061D<B@I.PH*("`@
M("`@("`D=6$@/2`D=&AI<RT^7VAE861E<G,M/F=E=$%G96YT2&5A9&5R*"D[
M"@H@("`@("`@("1O<FEG7W)E8VEP(#T@)'1H:7,M/E]H96%D97)S+3YG9716
M86QU92@G3W)I9VEN86PM4F5C:7!I96YT)RD["B`@("`@("`@:68@*"%E;7!T
M>2@D;W)I9U]R96-I<"D@)B8@:7-?87)R87DH)&]R:6=?<F5C:7`I*2!["B`@
M("`@("`@("`@("1O<FEG7W)E8VEP(#T@)&]R:6=?<F5C:7!;,%T["B`@("`@
M("`@?0H*("`@("`@("`D;7-G7VED(#T@)'1H:7,M/E]H96%D97)S+3YG9716
M86QU92@G365S<V%G92U)1"<I.PH*("`@("`@("`O*B!#<F5A=&4@=&AE($1I
M<W!O<VET:6]N(&9I96QD(&YO=R`H4D9#(#(R.3@@6S,N,BXV72DN("HO"B`@
M("`@("`@)&1I<W!O(#T@)T1I<W!O<VET:6]N.B`G("X*("`@("`@("`@("`@
M("`@("`H*"1A8W1I;VXI(#\@)VUA;G5A;"UA8W1I;VXG(#H@)V%U=&]M871I
M8RUA8W1I;VXG*2`N"B`@("`@("`@("`@("`@("`@)R\G("X*("`@("`@("`@
M("`@("`@("`H*"1S96YD:6YG*2`_("=-1$XM<V5N="UM86YU86QL>2<@.B`G
M341.+7-E;G0M875T;VUA=&EC86QL>2<I("X*("`@("`@("`@("`@("`@("`G
M.R`G("X*("`@("`@("`@("`@("`@("`D='EP93L*("`@("`@("!I9B`H(65M
M<'1Y*"1M;V0I*2!["B`@("`@("`@("`@("1D:7-P;R`N/2`G+R<@+B!I;7!L
M;V1E*"<L("<L("1M;V0I.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('5P
M('1H92!M86EL(&AE861E<G,N("HO"B`@("`@("`@)&US9U]H96%D97)S(#T@
M)FYE=R!-24U%7TAE861E<G,H*3L*("`@("`@("`D;7-G7VAE861E<G,M/F%D
M9$UE<W-A9V5)9$AE861E<B@I.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M06=E;G1(96%D97(H)'5A*3L*("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE
M861E<B@G1&%T92<L(&1A=&4H)W(G*2D["B`@("`@("`@)&US9U]H96%D97)S
M+3YA9&1(96%D97(H)T9R;VTG+"`D9G)O;5]A9&1R*3L*("`@("`@("`D;7-G
M7VAE861E<G,M/F%D9$AE861E<B@G5&\G+"`D=&AI<RT^9V5T341.4F5T=7)N
M061D<B@I*3L*("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@G4W5B
M:F5C="<L(%\H(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(I*3L*"B`@("`@
M("`@+RH@341.<R!A<F4@82!S=6)T>7!E(&]F("=M=6QT:7!A<G0O<F5P;W)T
M)RX@*B\*("`@("`@("`D;7-G(#T@)FYE=R!-24U%7TUE<W-A9V4H*3L*("`@
M("`@("`D;7-G+3YS9714>7!E*"=M=6QT:7!A<G0O<F5P;W)T)RD["B`@("`@
M("`@)&US9RT^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W)E<&]R="UT>7!E
M)RP@)V1I<W!O<VET:6]N+6YO=&EF:6-A=&EO;B<I.PH*("`@("`@("`O*B!4
M:&4@9FER<W0@<&%R="!I<R!A(&AU;6%N(')E861A8FQE(&UE<W-A9V4N("HO
M"B`@("`@("`@)'!A<G1?;VYE(#T@)FYE=R!-24U%7U!A<G0H)W1E>'0O<&QA
M:6XG*3L*("`@("`@("`D<&%R=%]O;F4M/G-E=$-H87)S970H3DQ3.CIG971#
M:&%R<V5T*"DI.PH@("`@("`@(&EF("@D='EP92`]/2`G9&ES<&QA>65D)RD@
M>PH@("`@("`@("`@("`D<&%R=%]O;F4M/G-E=$-O;G1E;G1S*'-P<FEN=&8H
M7R@B5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;E1H:7,@:7,@;F\@9W5A<F%N
M=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T
M;V]D+B(I+"`D=&AI<RT^7VAE861E<G,M/F=E=%9A;'5E*"=$871E)RDL("1T
M:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H)U1O)RDL("1T:&ES+3Y?:&5A9&5R
M<RT^9V5T5F%L=64H)U-U8FIE8W0G*2DI.PH@("`@("`@('T*("`@("`@("`O
M+R!43T1/.B!-97-S86=E<R!F;W(@;W1H97(@;F]T:69I8V%T:6]N('1Y<&5S
M+@H@("`@("`@("1M<V<M/F%D9%!A<G0H)'!A<G1?;VYE*3L*"B`@("`@("`@
M+RH@5&AE('-E8V]N9"!P87)T(&ES(&$@;6%C:&EN92UP87)S96%B;&4@9&5S
M8W)I<'1I;VXN("HO"B`@("`@("`@)'!A<G1?='=O(#T@)FYE=R!-24U%7U!A
M<G0H)VUE<W-A9V4O9&ES<&]S:71I;VXM;F]T:69I8V%T:6]N)RD["B`@("`@
M("`@)'!A<G1?='=O+3YS971#;VYT96YT<R@G4F5P;W)T:6YG+55!.B`G("X@
M)$=,3T)!3%-;)V-O;F8G75LG<V5R=F5R)UU;)VYA;64G72`N("<[("<@+B`D
M=6$@+B`B7&XB*3L*("`@("`@("!I9B`H(65M<'1Y*"1O<FEG7W)E8VEP*2D@
M>PH@("`@("`@("`@("`D<&%R=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"=/<FEG
M:6YA;"U296-I<&EE;G0Z(')F8S@R,CLG("X@)&]R:6=?<F5C:7`@+B`B7&XB
M*3L*("`@("`@("!]"B`@("`@("`@)'!A<G1?='=O+3YA<'!E;F1#;VYT96YT
M<R@G1FEN86PM4F5C:7!I96YT.B!R9F,X,C([)R`N("1F<F]M7V%D9'(@+B`B
M7&XB*3L*("`@("`@("!I9B`H(65M<'1Y*"1M<V=?:60I*2!["B`@("`@("`@
M("`@("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)T]R:6=I;F%L+4UE<W-A
M9V4M240Z(')F8S@R,CLG("X@)&US9U]I9"`N(")<;B(I.PH@("`@("`@('T*
M("`@("`@("`D<&%R=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"1D:7-P;R`N(")<
M;B(I.PH@("`@("`@(&EF("@H)'1Y<&4@/3T@)V9A:6QE9"<I("8F(&ES<V5T
M*"1E<G);)V9A:6QE9"==*2D@>PH@("`@("`@("`@("`D<&%R=%]T=V\M/F%P
M<&5N9$-O;G1E;G1S*"=&86EL=7)E.B`G("X@)&5R<ELG9F%I;&5D)UT@+B`B
M7&XB*3L*("`@("`@("!]"B`@("`@("`@:68@*&EN7V%R<F%Y*"=E<G)O<B<L
M("1M;V0I("8F(&ES<V5T*"1E<G);)V5R<F]R)UTI*2!["B`@("`@("`@("`@
M("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)T5R<F]R.B`G("X@)&5R<ELG
M97)R;W(G72`N(")<;B(I.PH@("`@("`@('T*("`@("`@("!I9B`H:6Y?87)R
M87DH)W=A<FYI;F<G+"`D;6]D*2`F)B!I<W-E="@D97)R6R=W87)N:6YG)UTI
M*2!["B`@("`@("`@("`@("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)U=A
M<FYI;F<Z("<@+B`D97)R6R=W87)N:6YG)UT@+B`B7&XB*3L*("`@("`@("!]
M"B`@("`@("`@)&US9RT^861D4&%R="@D<&%R=%]T=V\I.PH*("`@("`@("`O
M*B!4:&4@=&AI<F0@<&%R="!I<R!T:&4@=&5X="!O9B!T:&4@;W)I9VEN86P@
M;65S<V%G92X@(%)&0R`R,CDX(%LS70H@("`@("`@("`J(&%L;&]W<R!U<R!T
M;R!R971U<FX@;VYL>2!A('!O<G1I;VX@;V8@=&AE(&5N=&ER92!M97-S86=E
M("T@=&AI<PH@("`@("`@("`J(&ES(&QE9G0@=7`@=&\@=&AE('5S97(N("HO
M"B`@("`@("`@)'!A<G1?=&AR964@/2`F;F5W($U)345?4&%R="@G;65S<V%G
M92]R9F,X,C(G*3L*("`@("`@("`D<&%R=%]T:')E92T^<V5T0V]N=&5N=',H
M)'1H:7,M/E]H96%D97)S+3YT;U-T<FEN9R@I*3L*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?;7-G=&5X="DI('L*("`@("`@("`@("`@)'!A<G1?=&AR
M964M/F%P<&5N9$-O;G1E;G1S*")<;B(@+B`D=&AI<RT^7VUS9W1E>'0I.PH@
M("`@("`@('T*("`@("`@("`D;7-G+3YA9&1087)T*"1P87)T7W1H<F5E*3L*
M"B`@("`@("`@)&US9U]H96%D97)S+3YA9&1-24U%2&5A9&5R<R@D;7-G*3L*
M"B`@("`@("`@<F5T=7)N("1M<V<M/G-E;F0H)'1O+"`D;7-G7VAE861E<G,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@341.("AR96%D(')E8V5I
M<'0I(')E<75E<W0@:&5A9&5R<R!T;R!T:&4@34E-15](96%D97)S(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15](96%D97)S("8D:&5A9&]B
M("!4:&4@34E-15](96%D97)S(&]B:F5C="!T;R!A9&0@=&AE(&AE861E<G,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&\@("`@("`@("`@("`@5&AE(&%D9')E<W,@
M=&AE(')E8V5I<'0@<VAO=6QD(&)E(&UA:6QE9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9$U$3E)E<75E<W1(96%D97)S*"8D:&5A9&]B+"`D=&\I"B`@("!["B`@
M("`@("`@+RH@5&AI<R!I<R!T:&4@4D9#(#(R.3@@=V%Y(&]F(')E<75E<W1I
M;F<@82!R96-E:7!T+B`J+PH@("`@("`@("1H96%D;V(M/F%D9$AE861E<B@G
M1&ES<&]S:71I;VXM3F]T:69I8V%T:6]N+51O)RP@)'1O*3L*("`@('T*"GT*
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<```````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#4P-S``,3`U,34T
M,S$P-C$`,#(Q,C4T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+TUE<W-A9V4N<&AP)SL*"B\J*@H@*B!4:&4@;F%M92!O9B!T:&4@
M55),('!A<F%M971E<B!T:&%T(&AO;&1S('1H92!-24U%7T-O;G1E;G1S(&-A
M8VAE"B`J(&ED96YT:69I97(N"B`J+PID969I;F4H)TU)345?0T].5$5.5%-?
M0T%#2$4G+"`G;6EM96-A8VAE)RD["@HO*BH*("H@1&ES<&QA>2!A='1A8VAM
M96YT(&EN9F]R;6%T:6]N(&EN(&QI<W0@9F]R;6%T+@H@*B\*9&5F:6YE*"=-
M24U%7T-/3E1%3E137T1)4U!,05E?5%E015],25-4)RP@,"D["@HO*BH*("H@
M1&ES<&QA>2!A='1A8VAM96YT(&EN9F]R;6%T:6]N(&EN;&EN92!W:71H(&%T
M=&%C:&UE;G0N"B`J+PID969I;F4H)TU)345?0T].5$5.5%-?1$E34$Q!65]4
M65!%7TE.3$E.12<L(#$I.PH*+RHJ"B`J($1I<W!L87D@871T86-H;65N="!I
M;F9O<FUA=&EO;B!B;W1H(&EN(&QI<W0@9F]R;6%T(&%N9"!I;FQI;F4@=VET
M:`H@*B!A='1A8VAM96YT+@H@*B\*9&5F:6YE*"=-24U%7T-/3E1%3E137T1)
M4U!,05E?5%E015]"3U1()RP@,BD["@HO*BH*("H@5&AE($U)345?0V]N=&5N
M=',Z.B!C;&%S<R!C;VYT86EN<R!F=6YC=&EO;G,@<F5L871E9"!T;R!H86YD
M;&EN9R!T:&4@;W5T<'5T"B`J(&]F($U)344@8V]N=&5N="X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<"QV(#$N,3(Y
M+C0N,S4@,C`P-B\P-2\P-2`P,SHS,#HR,B!S;'5S87)Z($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@
M268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TU)344*("HO"F-L87-S($U)345?0V]N=&5N=',@>PH*("`@("\J*@H@("`@
M("H@5&AE($U)345?365S<V%G92!O8FIE8W0@9F]R('1H92!M97-S86=E+@H@
M("`@("H*("`@("`J($!V87(@34E-15]-97-S86=E"B`@("`@*B\*("`@('9A
M<B`D7VUE<W-A9V4["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-15]-97-S86=E
M(&]B:F5C="!W92!U<V4@=VAE;B!C86-H:6YG+@H@("`@("H*("`@("`J($!V
M87(@34E-15]-97-S86=E"B`@("`@*B\*("`@('9A<B`D7V-A8VAE;65S<V%G
M93L*"B`@("`O*BH*("`@("`J(%1H92!A='1A8VAM96YT<R!L:7-T+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?871C(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!M97-S86=E('!A<G1S(&QI
M<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]P87)T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@<W5M;6%R
M>2!P87)T<R!L:7-T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<W5M;6%R>2`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!4:&4@<W5M;6%R>2!T>7!E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7W-U;6UA<GE4>7!E(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J(%1H92!#86-H95]S97-S:6]N(&ED96YT:69I97(N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V5S<VEO
M;D-A8VAE240@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE($U)345?5FEE
M=V5R(&]B:F5C="!C86-H92X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W9I97=E<D-A8VAE(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J(%1H92!A='1A8VAM96YT(&1I<W!L87D@='EP92!T;R!U<V4N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7V1I<W!L87E4>7!E(#T@34E-15]#3TY414Y44U]$25-03$%97U194$5?0D]4
M2#L*"B`@("`O*BH*("`@("`J(%1H92!-24U%(&EN9&5X(&ME>2!T;R!U<V4N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M;6EM96ME>2`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@86-T:6]N240@
M=F%L=64@9F]R('9A<FEO=7,@86-T:6]N<RX*("`@("`J("=D;W=N;&]A9"<@
M("TM("!$;W=N;&]A9&EN9R!A('!A<G0O871T86-H;65N="X*("`@("`J("=V
M:65W)R`@("`@("TM("!6:65W:6YG(&$@<&%R="]A='1A8VAM96YT+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=FEE=TE$
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-H;W<@=&AE(&QI;FMS(&EN
M('1H92!S=6UM87)I97,_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7VQI;FMS(#T@=')U93L*"B`@("`O*BH*("`@("`J
M(%1H92!B87-E($U)345?0V]N=&5N=',@;V)J96-T+@H@("`@("H*("`@("`J
M($!V87(@34E-15]#;VYT96YT<PH@("`@("HO"B`@("!V87(@)%]B87-E(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@;65S<V%G92]R
M9F,X,C(@;&5V96QS(&QA8F5L960@87,@)V%T=&%C:&UE;G1S)R!O9B!T:&4*
M("`@("`J(&-U<G)E;G0@<&%R="X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G
M97(*("`@("`J+PH@("`@=F%R("1?871T86-H.#(R(#T@,#L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!-24U%
M7TUE<W-A9V4@)&UE<W-A9V5/8B`@5&AE(&]B:F5C="!T;R!W;W)K('=I=&@N
M"B`@("`@*B!`<&%R86T@87)R87D@)'9I97=)1"`@("`@("`@("`@(%1H92!A
M8W1I;VY)1"!V86QU97,@9F]R('9I97=I;F<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<&%R=',O871T86-H;65N=',N"B`@("`@
M*B!`<&%R86T@87)R87D@)B1C;VYT96YT<R`@("`@("`@($%R<F%Y(&-O;G1A
M:6YI;F<@82!S:6YG;&4@=F%L=64Z"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&$@<F5F97)E;F-E('1O('1H92!B87-E(&]B:F5C
M="X*("`@("`J("A4:&ES(&QA<W0@<&%R86UE=&5R(&YE961S('1O(&)E(&AA
M;F1L960@=FEA(&%N(&%R<F%Y(&)E8V%U<V4@4$A0(#P*("`@("`J("`U+C`@
M9&]E<VXG="!H86YD;&4@;W!T:6]N86P@<&]I;G1E<B!P87)A;65T97)S(&]T
M:&5R=VES92XI"B`@("`@*B\*("`@(&9U;F-T:6]N($U)345?0V]N=&5N=',H
M)&UE<W-A9V5/8BP@)'9I97=)1"`](&%R<F%Y*"DL("1C;VYT96YT<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]M97-S86=E(#T@)&UE<W-A
M9V5/8CL*("`@("`@("`D=&AI<RT^7V-A8VAE;65S<V%G92`](%5T:6PZ.F-L
M;VYE3V)J96-T*"1M97-S86=E3V(I.PH@("`@("`@("1T:&ES+3Y?=FEE=TE$
M(#T@)'9I97=)1#L*"B`@("`@("`@+RH@0W)E871E('1H92!P;VEN=&5R('1O
M('1H92!B87-E(&]B:F5C="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1C;VYT
M96YT<RDI('L*("`@("`@("`@("`@)'!T<B`](')E<V5T*"1C;VYT96YT<RD[
M"B`@("`@("`@("`@("1O;&1?<'1R(#T@)B1P='(M/F=E=$)A<V5/8FIE8W10
M='(H*3L*("`@("`@("`@("`@)'1H:7,M/E]B87-E(#T@)&]L9%]P='(["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@96YT
M:7)E(&)O9'D@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B!9;W4@<')O8F%B;'D@
M=V%N="!T;R!O=F5R<FED92!T:&ES(&9U;F-T:6]N(&EN(&%N>2!S=6)C;&%S
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@;V8@
M=&AE(&)O9'D@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$)O9'DH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUE<W-A
M9V4M/G1O4W1R:6YG*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!R87<@=&5X="!F;W(@;VYE('-E8W1I;VX@;V8@=&AE(&UE<W-A9V4N
M"B`@("`@*B!9;W4@<')O8F%B;'D@=V%N="!T;R!O=F5R<FED92!T:&ES(&9U
M;F-T:6]N(&EN(&%N>2!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"`@5&AE($E$(&]F('1H92!-24U%7U!A<G0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&]F('1H92!P87)T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971";V1Y4&%R="@D:60I"B`@("!["B`@
M("`@("`@:68@*"@D<&%R="`]("8D=&AI<RT^9V5T34E-15!A<G0H)&ED*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1P87)T+3YG971#;VYT96YT<R@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!-24U%7TUE
M<W-A9V4@;V)J96-T(&9O<B!T:&4@;6%I;"!M97-S86=E+@H@("`@("H*("`@
M("`J($!R971U<FX@34E-15]-97-S86=E("!!($U)345?365S<V%G92!O8FIE
M8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$U)345-97-S86=E*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M97-S86=E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1F5T8V@@82!P87)T(&]F(&$@34E-12!M97-S86=E+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9"`@5&AE($U)344@:6YD
M97@@;V8@=&AE('!A<G0@<F5Q=65S=&5D+@H@("`@("H*("`@("`J($!R971U
M<FX@34E-15]087)T("!4:&4@<F%W($U)344@<&%R="!A<VME9"!F;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971-24U%4&%R="@D:60I"B`@("!["B`@
M("`@("`@)'!A<G0@/2`D=&AI<RT^7VUE<W-A9V4M/F=E=%!A<G0H)&ED*3L*
M("`@("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96)U:6QD('1H92!-24U%7U!A<G0@<W1R=6-T=7)E(&]F(&$@;65S<V%G92X*
M("`@("`J(%EO=2!P<F]B86)L>2!W86YT('1O(&]V97)R:61E('1H:7,@9G5N
M8W1I;VX@:6X@86YY('-U8F-L87-S+@H@("`@("H*("`@("`J($!R971U<FX@
M34E-15]-97-S86=E("!!($U)345?365S<V%G92!O8FIE8W0@=VET:"!A;&P@
M;V8@=&AE(&)O9'D@=&5X=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('-T;W)E9"!I;B!T:&4@:6YD:79I9'5A;"!-24U%7U!A<G1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96)U:6QD365S<V%G92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?;65S<V%G93L*("`@('T*"B`@("`O*BH*("`@("`J
M($9E=&-H('!A<G0@;V8@82!-24U%(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&ED("`@5&AE($U)344@240@;V8@=&AE('!A<G0@
M<F5Q=65S=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;"`@268@=&AI
M<R!I<R!A(&AE861E<B!P87)T+"!S:&]U;&0@=V4@<F5T=7)N(&%L;"!T97AT
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@8F]D>3\*("`@
M("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%)A=TU)345087)T*"1I9"P@)&%L
M;"`](&9A;'-E*0H@("`@>PH@("`@("`@("1M:6UE7W!A<G0@/2`F)'1H:7,M
M/F=E=$U)345087)T*"1I9"D["B`@("`@("`@:68@*"%I<U]A*"1M:6UE7W!A
M<G0L("=-24U%7U!A<G0G*2D@>PH@("`@("`@("`@("`D;6EM95]P87)T(#T@
M;G5L;#L*("`@("`@("`@("`@<F5T=7)N("1M:6UE7W!A<G0["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!A;&P@=&5X="!I<R!R97%U97-T960L(&-H86YG
M92!T:&4@240@;F]W+B`J+PH@("`@("`@(&EF("@D86QL("8F("1M:6UE7W!A
M<G0M/F=E=$EN9F]R;6%T:6]N*"=H96%D97(G*2D@>PH@("`@("`@("`@("`D
M:60@/2!S=6)S='(H)&ED+"`P+"!S=')R<&]S*"1I9"P@)RXG*2D["B`@("`@
M("`@?0H*("`@("`@("`O*B!/;FQY('-E="!C;VYT96YT<R!I9B!T:&5R92!I
M<R!C=7)R96YT;'D@;F]N92!I;B!T:&4@34E-12!087)T+B`J+PH@("`@("`@
M(&EF("@A)&UI;65?<&%R="T^9V5T0V]N=&5N=',H*2D@>PH@("`@("`@("`@
M("`D;6EM95]P87)T+3YS971#;VYT96YT<R@D=&AI<RT^9V5T0F]D>5!A<G0H
M)&ED*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UI;65?<&%R=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H('!A<G0@;V8@82!-24U%(&UE
M<W-A9V4@86YD(&1E8V]D92!I="P@:68@:70@:7,@8F%S95\V-"!O<@H@("`@
M("H@<7!R:6YT(&5N8V]D960N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&ED("`@5&AE($U)344@240@;V8@=&AE('!A<G0@<F5Q=65S=&5D+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;"`@268@=&AI<R!I<R!A(&AE861E
M<B!P87)T+"!S:&]U;&0@=V4@<F5T=7)N(&%L;"!T97AT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!I;B!T:&4@8F]D>3\*("`@("`J"B`@("`@*B!`
M<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="!W:71H(&ET<R!C;VYT
M96YT<R!D96-O9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1&5C;V1E
M9$U)345087)T*"1I9"P@)&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("@H)&UI;65?<&%R="`]("8D=&AI<RT^9V5T4F%W34E-15!A<G0H)&ED+"`D
M86QL*2DI('L*("`@("`@("`@("`@)&UI;65?<&%R="T^=')A;G-F97)$96-O
M9&5#;VYT96YT<R@I.PH@("`@("`@("`@("`O+R!.;V]P+@H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1M:6UE7W!A<G0@/2!N=6QL.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&UI;65?<&%R=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@871T86-H;65N="!L:7-T("A(5$U,('1A8FQE
M(&9O<FUA="DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L
M:7-T(&]F(&%T=&%C:&UE;G1S(&9O<FUA='1E9"!I;G1O($A434PN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$%T=&%C:&UE;G1S*"D*("`@('L*("`@("`@
M("`D;7-G(#T@)R<["@H@("`@("`@("1A:V5Y<R`](&%R<F%Y7VME>7,H)'1H
M:7,M/E]A=&,I.PH@("`@("`@(&YA='-O<G0H)&%K97ES*3L*("`@("`@("!F
M;W)E86-H("@D86ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`D;7-G("X]
M("1T:&ES+3Y?87)R87E4;U1A8FQE4F]W*"1T:&ES+3Y?871C6R1K97E=*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;7-G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!M97-S86=E(&QI<W0@*$A434P@=&%B;&4@
M9F]R;6%T*2X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYE9G)A
M;64@(%-H;W5L9"!T:&4@;W5T<'5T(&)E(&1E<VEG;F5D(&9O<B!D:7-P;&%Y
M(&EN(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<VEN9VQE
M(&9R86UE/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;65S
M<V%G92!F;W)M871T960@:6YT;R!(5$U,+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971-97-S86=E*"1O;F5F<F%M92`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1M<V<@/2`G)SL*("`@("`@("`D;7-G0V]U;G0@/2!C;W5N="@D=&AI<RT^
M7W!A<G1S*3L*("`@("`@("`D<&%R=$1I<W!L87EE9"`](&9A;'-E.PH*("`@
M("`@("!I9B`H)&]N969R86UE*2!["B`@("`@("`@("`@("1M<V<@+CT@)SQS
M='EL92!T>7!E/2)T97AT+V-S<R(^+F]N969R('MP861D:6YG.C%P>#L@;6%R
M9VEN+6)O='1O;3HQ<'@[(&)O<F1E<CHQ<'@@9&%S:&5D(",P,&,[(&)A8VMG
M<F]U;F0Z(V5E9CL@8V]L;W(Z(S`P-GT\+W-T>6QE/B<@+B`B7&XB.PH@("`@
M("`@('T*"B`@("`@("`@+R\@5$]$3SH@5&5M<&]R87)Y(&AA8VL@=&\@9&ES
M<&QA>2!H96%D97(@:6YF;R!F;W(@82!M97-S86=E('=I=&@@;VYE"B`@("`@
M("`@+R\@34E-12!P87)T('1H870@8V%N;F]T(&)E(&1I<W!L87EE9"!I;FQI
M;F4N"B`@("`@("`@:68@*"$D;7-G0V]U;G0@?'P@*"1M<V=#;W5N="`]/2`Q
M("8F("%R97-E="@D=&AI<RT^7W!A<G1S*2DI('L*("`@("`@("`@("`@)'1H
M:7,M/G-E=%-U;6UA<GDH)'1H:7,M/E]M97-S86=E+"`G<&%R="<I.PH@("`@
M("`@("`@("`D;7-G0V]U;G0@/2`Q.PH@("`@("`@('T*("`@("`@("`@("`@
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)T<R!A<R`D:V5Y(#T^("1V
M86QU92D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]S=6UM87)Y
M6R1K97E=*2`F)@H@("`@("`@("`@("`@("`@*"@H)&US9T-O=6YT(#T](#$I
M("8F(&5M<'1Y*"1V86QU92DI('Q\("@D;7-G0V]U;G0@/B`Q*2DI('L*("`@
M("`@("`@("`@("`@("1M<V<@+CT@)SQT<CX\=&0^)SL*("`@("`@("`@("`@
M("`@(&EF("@D;VYE9G)A;64I('L*("`@("`@("`@("`@("`@("`@("`D;7-G
M("X]("<\=&%B;&4@8VQA<W,](F]N969R(CXG.PH@("`@("`@("`@("`@("`@
M("`@("1S=6UM87)Y(#T@)'1H:7,M/E]S=6UM87)Y6R1K97E=.PH@("`@("`@
M("`@("`@("`@("`@("1S=6UM87)Y(#T@87)R87E?;65R9V4H87)R87E?<W!L
M:6-E*"1S=6UM87)Y+"`P+"`Q*2P@87)R87E?<W!L:6-E*"1S=6UM87)Y+"`Q
M*2D["B`@("`@("`@("`@("`@("`@("`@)&US9R`N/2`D=&AI<RT^7V%R<F%Y
M5&]486)L95)O=R@D<W5M;6%R>2D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@)SQT86)L93XG.PH@("`@
M("`@("`@("`@("`@("`@("1M<V<@+CT@)'1H:7,M/E]A<G)A>51O5&%B;&52
M;W<H)'1H:7,M/E]S=6UM87)Y6R1K97E=*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1M<V<@+CT@)SPO=&%B;&4^/"]T9#X\+W1R/B<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D=F%L=64I
M*2!["B`@("`@("`@("`@("`@("`D;7-G("X]("<\='(^/'1D(&-L87-S/2)T
M97AT(CXG("X@)'9A;'5E("X@)SPO=&0^/"]T<CXG.PH@("`@("`@("`@("`@
M("`@)'!A<G1$:7-P;&%Y960@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H(21P87)T1&ES<&QA>65D*2!["B`@("`@("`@
M("`@("1M<V<@+CT@)SQT<CX\=&0@8VQA<W,](G1E>'0B(&%L:6=N/2)L969T
M(CX\96T^)R`N(%\H(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(I("X@)SPO96T^/"]T9#X\+W1R/B<["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*("`@
M("`J($5X<&%N9',@86X@87)R87D@:6YT;R!A('1A8FQE(')O=RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&%R<F%Y("!4:&4@87)R87D@=&\@97AP86YD+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@87)R87D@97AP86YD960@=&\@82!(
M5$U,('1A8FQE(')O=RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V%R<F%Y5&]4
M86)L95)O=R@D87)R87DI"B`@("!["B`@("`@("`@)'1E>'0@/2`G/'1R('9A
M;&EG;CTB;6ED9&QE(CXG.PH*("`@("`@("!F;W)E86-H("@D87)R87D@87,@
M)&5L96TI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D96QE;2DI('L*("`@
M("`@("`@("`@("`@("1T97AT("X]("(\=&0^)&5L96TF;F)S<#L\+W1D/EQN
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M97AT("X@(CPO='(^7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@9&%T82!F;W(@82!S<&5C:69I8R!-24U%(&EN9&5X+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("!4:&4@34E-12!I;F1E>"X*
M("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("!4:&4@9FEE;&0@=&\@<F5T
M=7)N("AM97-S86=E+"!A=&,L('-U;6UA<GDI"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!T97AT(&-U<G)E;G1L>2!S970@9F]R('1H870@
M:6YD97@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9&5X*"1I9"P@)&9I
M96QD*0H@("`@>PH@("`@("`@("1F:65L9"`]("=?)R`N("1F:65L9#L*("`@
M("`@("!I9B`H:7-?87)R87DH)'1H:7,M/B1F:65L9"D@)B8@87)R87E?:V5Y
M7V5X:7-T<R@D:60L("1T:&ES+3XD9FEE;&0I*2!["B`@("`@("`@("`@("1E
M;G1R>2`]("1T:&ES+3XD9FEE;&0["B`@("`@("`@("`@(')E='5R;B`D96YT
M<GE;)&ED73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S
M('1H92!M97-S86=E('1E>'0@86YD('-U;6UA<GD@9F]R(&$@<W!E8VEF:6,@
M34E-12!I;F1E>"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@
M5&AE($U)344@:6YD97@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94EN
M9&5X*"1I9"D*("`@('L*("`@("`@("!U;G-E="@D=&AI<RT^7W!A<G1S6R1I
M9%TI.PH@("`@("`@('5N<V5T*"1T:&ES+3Y?<W5M;6%R>5LD:61=*3L*("`@
M("`@("!U;G-E="@D=&AI<RT^7V%T8ULD:61=*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E=&5R;6EN92!I9B!W92!C86X@*&%N9"!K;F]W(&AO=R!T;RD@
M:6YL:6YE(&$@34E-12!087)T+@H@("`@("H*("`@("`J($!P87)A;2!-24U%
M7U!A<G0@)B1M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@<&%R="!C86X@8F4@
M:6YL:6YE9"X*("`@("`J("`@("`@("`@("`@("`@("`@1F%L<V4@:68@:70@
M8V%N;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y$:7-P;&%Y26YL:6YE
M*"8D;6EM95]P87)T*0H@("`@>PH@("`@("`@("1V:65W97(@/2`F)'1H:7,M
M/F=E=$U)3456:65W97(H)&UI;65?<&%R="D["@H@("`@("`@("\J($9I<G-T
M(&-H96-K.B!4:&4@34E-12!H96%D97)S(&%L;&]W('1H92!P87)T('1O(&)E
M(&EN;&EN960N"B`@("`@("`@("H@2&]W979E<BP@:68@=V4@87)E(&%L<F5A
M9'D@:6X@=FEE=R!M;V1E+"!T:&5N('=E(&-A;B!S:VEP('1H:7,*("`@("`@
M("`@*B!C:&5C:RX@*B\*("`@("`@("!I9B`H(21T:&ES+3YV:65W07-!='1A
M8VAM96YT*"D@)B8*("`@("`@("`@("`@*"1M:6UE7W!A<G0M/F=E=$1I<W!O
M<VET:6]N*"D@(3T@)VEN;&EN92<I("8F"B`@("`@("`@("`@("$D=FEE=V5R
M+3YF;W)C94EN;&EN959I97<H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!396-O;F0@8VAE8VL@*'-A=F4@
M=&AE(&UO<W0@97AP96YS:79E(&9O<B!L87-T*3H*("`@("`@("`@*B!#:&5C
M:R!T;R!S964@:68@=&AE(&1R:79E<B!I<R!S970@=&\@:6YL:6YE+B`J+PH@
M("`@("`@(')E='5R;B`H:7-?82@D=FEE=V5R+"`G34E-15]6:65W97(G*2`F
M)B`D=FEE=V5R+3YC86Y$:7-P;&%Y26YL:6YE*"DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T($U)345?5FEE=V5R(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!!($U)345?4&%R="!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U9I97=E<B`@5&AE
M($U)345?5FEE=V5R(&]B:F5C="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9G971-24U%5FEE=V5R*"8D;6EM95]P87)T*0H@
M("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@34E-15]087)T
M('1O('!R;V-E<W,N("HO"B`@("`@("`@:68@*&5M<'1Y*"1M:6UE7W!A<G0I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O5FEE=V5R
M+G!H<"<["@H@("`@("`@("1K97D@/2`D;6EM95]P87)T+3YG9715;FEQ=65)
M1"@I("X@)WPG("X@)&UI;65?<&%R="T^9V5T5'EP92@I.PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]V:65W97)#86-H95LD:V5Y72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]V:65W97)#86-H95LD:V5Y72`]("9-24U%7U9I97=E
M<CHZ9F%C=&]R>2@D;6EM95]P87)T*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7W9I97=E<D-A8VAE6R1K97E=.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!-24U%($-O;G1E;G0M5'EP92!O=71P=70@8GD@
M82!-24U%7U9I97=E<B!F;W(@82!P87)T:6-U;&%R"B`@("`@*B!-24U%7U!A
M<G0N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R
M="`@02!-24U%7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@34E-12!T>7!E(&]U='!U="!B>2!T:&4@34E-15]6:65W
M97(L(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$U)3456:65W97)4>7!E*"8D;6EM
M95]P87)T*0H@("`@>PH@("`@("`@(&EF("@H)'9I97=E<B`]("8D=&AI<RT^
M9V5T34E-159I97=E<B@D;6EM95]P87)T*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1V:65W97(M/F=E=%1Y<&4H*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@:V5Y('1O('5S92!F;W(@82!P87)T:6-U
M;&%R($U)345?4&%R="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!!
M($U)345?4&%R="!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;W9E
M<G)I9&4@("`@("!297-P96-T('1H92!-24U%(&ME>2!O=F5R<FED92!V86QU
M93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N:7%U92!I
M9&5N=&EF:65R(&]F('1H92!-24U%7U!A<G0N"B`@("`@*B`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!F86QS92!I9B!N;R!K97D@9F]U;F0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971-24U%2V5Y*"8D;6EM95]P87)T+"`D;W9E<G)I
M9&4@/2!T<G5E*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES+3YG971-24U%
M2V5Y3W9E<G)I9&4H*3L*"B`@("`@("`@:68@*"1O=F5R<FED92`F)B`A:7-?
M;G5L;"@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&ED(#T@)&UI;65?<&%R="T^9V5T34E-
M14ED*"D["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1I9"DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!-24U%(&ME
M>2!O=F5R<FED92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M($U)344@:V5Y(&]V97)R:61E("T@;G5L;"!I9B!N;R!O=F5R<FED92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T34E-14ME>4]V97)R:61E*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]M:6UE:V5Y.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!A;B!O=F5R<FED92!F;W(@=&AE($U)344@:V5Y+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;65K97D*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T34E-14ME>4]V97)R:61E*"1M:6UE:V5Y(#T@;G5L
M;"D*("`@('L*("`@("`@("`D=&AI<RT^7VUI;65K97D@/2`D;6EM96ME>3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!D:7-P;&%Y(&QI;FMS
M(&9O<B!T:&4@<W5M;6%R:65S/PH@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1S:&]W("!3:&]W('1H92!S=6UM87)Y(&QI;FMS/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S:&]W4W5M;6%R>4QI;FMS*"1S:&]W(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H(6ES7VYU;&PH)'-H;W<I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?;&EN:W,@/2`D<VAO=SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7VQI;FMS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N
M9&5R(&$@34E-12!087)T+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A
M<G0@)B1M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;F1E<DU)345087)T*"8D;6EM95]P87)T*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<DU)345087)T*"1M
M:6UE7W!A<G0L(&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!-24U%(%!A<G0@871T86-H;65N="!I;F9O+@H@("`@("H*("`@("`J($!P
M87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<DU)345!='1A8VAM
M96YT26YF;R@F)&UI;65?<&%R="D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]R96YD97)-24U%4&%R="@D;6EM95]P87)T+"!T<G5E*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;F1E<B!-24U%(%!A<G0@9&%T82X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M34E-15]087)T("8D;6EM95]P87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D871T86-H;65N="`@("!296YD97(@34E-
M12!087)T(&%T=&%C:&UE;G0@:6YF;S\*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]R96YD97)-24U%4&%R="@F)&UI;65?<&%R="P@)&%T=&%C:&UE;G0@
M/2!F86QS92D*("`@('L*("`@("`@("`O*B!'970@=&AE($U)345?5FEE=V5R
M(&]B:F5C="!F;W(@=&AI<R!-24U%('!A<G0@*B\*("`@("`@("`D=FEE=V5R
M(#T@)B1T:&ES+3YG971-24U%5FEE=V5R*"1M:6UE7W!A<G0I.PH@("`@("`@
M(&EF("@A:7-?82@D=FEE=V5R+"`G34E-15]6:65W97(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D;7-G(#T@)R<[
M"@H@("`@("`@("1M:6UE7W!A<G0M/G1R86YS9F5R1&5C;V1E0V]N=&5N=',H
M*3L*"B`@("`@("`@+RH@268@=&AI<R!I<R!A('1E>'0O*B!P87)T+"!!3D0@
M=&AE('1E>'0@:7,@:6X@82!D:69F97)E;G0@8VAA<F%C=&5R"B`@("`@("`@
M("H@<V5T('1H86X@=&AE(&)R;W=S97(L(&-O;G9E<G0@=&\@=&AE(&-U<G)E
M;G0@8VAA<F%C=&5R('-E="X*("`@("`@("`@*B!!9&1I=&EO;F%L;'DL(&EF
M('1H92!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@551&+3@L(&=I=F4@=&AE
M"B`@("`@("`@("H@=7-E<B!A(&QI;FL@=&\@;W!E;B!T:&4@<&%R="!I;B!A
M(&YE=R!W:6YD;W<@=VET:"!T:&4@8V]R<F5C=`H@("`@("`@("`J(&-H87)A
M8W1E<B!S970N("HO"B`@("`@("`@)&-H87)S970@/2`D;6EM95]P87)T+3YG
M971#:&%R<V5T*"D["B`@("`@("`@:68@*"1C:&%R<V5T*2!["B`@("`@("`@
M("`@("1C:&%R<V5T7W5P<&5R(#T@4W1R:6YG.CIU<'!E<B@D8VAA<G-E="D[
M"B`@("`@("`@("`@(&EF("@H)&-H87)S971?=7!P97(@(3T@)U53+4%30TE)
M)RD@)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^=FEE=T%S071T86-H;65N
M="@I*2!["B`@("`@("`@("`@("`@("`D9&5F875L=%]C:&%R<V5T(#T@4W1R
M:6YG.CIU<'!E<BA.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("`@
M("!I9B`H)&-H87)S971?=7!P97(@(3T@)&1E9F%U;'1?8VAA<G-E="D@>PH@
M("`@("`@("`@("`@("`@("`@("1M:6UE7W!A<G0M/G-E=$-O;G1E;G1S*%-T
M<FEN9SHZ8V]N=F5R=$-H87)S970H)&UI;65?<&%R="T^9V5T0V]N=&5N=',H
M*2P@)&-H87)S970L("1D969A=6QT7V-H87)S970I*3L*("`@("`@("`@("`@
M("`@("`@("`D;6EM95]P87)T+3YS971#:&%R<V5T*"1D969A=6QT7V-H87)S
M970I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9&5F875L=%]C:&%R<V5T
M("$]("=55$8M."<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-T871U
M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT
M9BA?*")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB*2P@:'1M;'-P96-I86QC
M:&%R<R@D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W!R:6YT9BA?*"))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(BDL("1T:&ES+3YL:6YK
M5FEE=TI3*"1M:6UE7W!A<G0L("=V:65W7V%T=&%C:"<L(%\H(F-L:6-K(&AE
M<F4B*2DI"B`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1M<V<@/2`D=&AI<RT^9F]R;6%T4W1A='5S37-G*"1S
M=&%T=7,L(&YU;&PL(&9A;'-E*2`N("1M<V<["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D=FEE=V5R+3YS971-24U%4&%R="@D;6EM95]P87)T*3L*
M("`@("`@("`D<&%R86US(#T@87)R87DH)B1T:&ES*3L*("`@("`@("!I9B`H
M)&%T=&%C:&UE;G0I('L*("`@("`@("`@("`@)&US9R`N/2`D=FEE=V5R+3YR
M96YD97)!='1A8VAM96YT26YF;R@D<&%R86US*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;7-G("X]("1V:65W97(M/G)E;F1E<B@D<&%R86US
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;7-G.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0G5I;&0@=&AE(&UE<W-A9V4@9&5C:61I;F<@=VAA="!-
M24U%(%!A<G1S('1O('-H;W<N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!&86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I
M;&1-97-S86=E*"D*("`@('L*("`@("`@("`D=&AI<RT^7V%T8R`](&%R<F%Y
M*"D["B`@("`@("`@)'1H:7,M/E]P87)T<R`](&%R<F%Y*"D["B`@("`@("`@
M)'1H:7,M/E]S=6UM87)Y(#T@87)R87DH*3L*"B`@("`@("`@:68@*"%I<U]A
M*"1T:&ES+3Y?;65S<V%G92P@)TU)345?365S<V%G92<I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($YO=R!D
M:7-P;&%Y('1H92!P87)T<RX@*B\*("`@("`@("`D;6EM95]P87)T(#T@)'1H
M:7,M/E]M97-S86=E+3YG971"87-E4&%R="@I.PH@("`@("`@("1T:&ES+3YB
M=6EL9$UE<W-A9V5087)T*"1M:6UE7W!A<G0I.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%!R;V-E<W-E<R!A($U)345?
M4&%R="!A;F0@<W1O<F5S('1H92!D:7-P;&%Y(&EN9F]R;6%T:6]N(&EN('1H
M92!I;G1E<FYA;`H@("`@("H@8VQA<W,@=F%R:6%B;&5S+@H@("`@("H*("`@
M("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A
M<G0@;V)J96-T('1O('!R;V-E<W,N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!R96YD97)E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!B=6EL9$UE<W-A9V5087)T*"8D;6EM95]P87)T*0H@("`@>PH@("`@("`@
M("1M<V<@/2`G)SL*"B`@("`@("`@+RH@268@=V4@8V%N)W0@9&ES<&QA>2!T
M:&4@<&%R="!I;FQI;F4L(&%D9"!I="!T;R!T:&4@871T86-H;65N=`H@("`@
M("`@("`@(&QI<W0N($EF('1H92!-24U%($E$(&]F('1H92!C=7)R96YT('!A
M<G0@:7,@)S`G+"!T:&5N(&9O<F-E(&$*("`@("`@("`@("!R96YD97(@;V8@
M=&AE('!A<G0@*'-I;F-E(&ET(&ES('1H92!B87-E('!A<G0@86YD+"!W:71H
M;W5T"B`@("`@("`@("`@871T96UP=&EN9R!T;R!R96YD97(L('1H92!M97-S
M86=E('=I;&P@04Q705E3(&%P<&5A<B!E;7!T>2X@*B\*("`@("`@("!I9B`H
M(21T:&ES+3YC86Y$:7-P;&%Y26YL:6YE*"1M:6UE7W!A<G0I("8F"B`@("`@
M("`@("`@("@D;6EM95]P87)T+3YG971-24U%260H*2`A/2`P*2D@>PH@("`@
M("`@("`@("`O*B!.;W0@9&ES<&QA>6EN9R!I;FQI;F4[(&%D9"!T;R!T:&4@
M871T86-H;65N=',@;&ES="X@*B\*("`@("`@("`@("`@:68@*"@D=&AI<RT^
M7V1I<W!L87E4>7!E(#T]($U)345?0T].5$5.5%-?1$E34$Q!65]465!%7TQ)
M4U0I('Q\"B`@("`@("`@("`@("`@("`H)'1H:7,M/E]D:7-P;&%Y5'EP92`]
M/2!-24U%7T-/3E1%3E137T1)4U!,05E?5%E015]"3U1(*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=%-U;6UA<GDH)&UI;65?<&%R="P@)V%T=&%C
M:&UE;G0G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H*"1T:&ES
M+3Y?9&ES<&QA>51Y<&4@/3T@34E-15]#3TY414Y44U]$25-03$%97U194$5?
M24Y,24Y%*2!\?`H@("`@("`@("`@("`@("`@*"1T:&ES+3Y?9&ES<&QA>51Y
M<&4@/3T@34E-15]#3TY414Y44U]$25-03$%97U194$5?0D]42"DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS9713=6UM87)Y*"1M:6UE7W!A<G0L("=P
M87)T)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-H96-K('1O
M('-E92!I9B!A;GD@871T86-H;65N="!I;F9O<FUA=&EO;B!C86X@8F4@<F5N
M9&5R960@8GD*("`@("`@("`@("`@("`@=&AE($U)345?5FEE=V5R+B`J+PH@
M("`@("`@("`@("`D;7-G(#T@)'1H:7,M/G)E;F1E<DU)345!='1A8VAM96YT
M26YF;R@D;6EM95]P87)T*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;7-G
M*2D@>PH@("`@("`@("`@("`@("`@)&ME>2`]("1T:&ES+3Y?9V5T34E-14ME
M>2@D;6EM95]P87)T*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R='-;
M)&ME>5T@/2`D;7-G.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&US9R`]("1T:&ES+3YR96YD97)-24U%4&%R="@D;6EM
M95]P87)T*3L*("`@("`@("`@("`@)&ME>2`]("1T:&ES+3Y?9V5T34E-14ME
M>2@D;6EM95]P87)T*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V%T=&%C
M:#@R,BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)T<ULD:V5Y72`]
M("1M<V<["B`@("`@("`@("`@('T*("`@("`@("`@("`@+RH@4V]M92!-24U%
M7U9I97=E<G,@<V5T('1H92!S=6UM87)Y(&)Y('1H96UE;'9E<RP@<V\@;VYL
M>0H@("`@("`@("`@("`@*B!A9&0@=&\@871T86-H;65N="]I;FQI;F4@;&ES
M=',@:68@;F]T:&EN9R!H87,@8F5E;B!S970*("`@("`@("`@("`@("H@87,@
M;V8@>65T+B`J+PH@("`@("`@("`@("!I9B`H*"@D;6EM95]P87)T+3YG9714
M>7!E*"D@(3T@)VUU;'1I<&%R="]M:7AE9"<I('Q\"B`@("`@("`@("`@("`@
M("`@(65M<'1Y*"1M<V<I*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y*"1K
M97DI("8F"B`@("`@("`@("`@("`@("`A)'1H:7,M/F=E=$EN9&5X*"1K97DL
M("=S=6UM87)Y)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9713=6UM
M87)Y*"1M:6UE7W!A<G0L("=P87)T)RD["B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]A='1A8V@X,C(@)B8*("`@("`@("`@("`@("`@("`@("`H*"1T
M:&ES+3Y?9&ES<&QA>51Y<&4@/3T@34E-15]#3TY414Y44U]$25-03$%97U19
M4$5?3$E35"D@?'P*("`@("`@("`@("`@("`@("`@("`H)'1H:7,M/E]D:7-P
M;&%Y5'EP92`]/2!-24U%7T-/3E1%3E137T1)4U!,05E?5%E015]"3U1(*2DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4W5M;6%R>2@D;6EM
M95]P87)T+"`G871T86-H;65N="<I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&UI;65?<&%R="T^
M9V5T26YF;W)M871I;VXH)VAE861E<B<I*2!["B`@("`@("`@("`@("\J($EF
M('1H:7,@:7,@;65S<V%G92]R9F,X,C(@<&%R="P@86YD(&ET(&ES(&UA<FME
M9"!A<R!A;@H@("`@("`@("`@("`@*B!A='1A8VAM96YT+"!W92!N965D('1O
M(&QE="!F=71U<F4@8V%L;',@=&\@8G5I;&1-97-S86=E4&%R="@I"B`@("`@
M("`@("`@("`J(&MN;W<@=&AA="!I="!S:&]U;&0@;6%R:R!E;6)E9&1E9"!P
M87)T<R!A<R!N;W0@=FEE=V%B;&4*("`@("`@("`@("`@("H@:6YL:6YE+B`J
M+PH@("`@("`@("`@("`D:6YC<F5M96YT7S@R,B`](&9A;'-E.PH@("`@("`@
M("`@("!I9B`H*"1M:6UE7W!A<G0M/F=E=%1Y<&4H*2`]/2`G;65S<V%G92]R
M9F,X,C(G*2`F)@H@("`@("`@("`@("`@("`@*"1M:6UE7W!A<G0M/F=E=$1I
M<W!O<VET:6]N*"D@/3T@)V%T=&%C:&UE;G0G*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A='1A8V@X,C(K*SL*("`@("`@("`@("`@("`@("1I;F-R
M96UE;G1?.#(R(#T@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M9F]R96%C:"`H)&UI;65?<&%R="T^9V5T4&%R=',H*2!A<R`D<&%R="D@>PH@
M("`@("`@("`@("`@("`@)&US9R`N/2`D=&AI<RT^8G5I;&1-97-S86=E4&%R
M="@D<&%R="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D:6YC
M<F5M96YT7S@R,BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1A8V@X
M,C(M+3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@=FEE=VEN9R!T
M:&ES('!A9V4@87,@86X@871T86-H;65N="!T:')O=6=H('9I97<N<&AP/PH@
M("`@("H@5&AI<R!M971H;V0@8V%N(&%L<V\@8F4@8V%L;&5D('9I82!-24U%
M7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"DN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'!O<'5P("!)9B!T<G5E+"!A;'-O(&-H96-K(&EF
M('=E(&%R92!V:65W:6YG(&%T=&%C:&UE;G0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@:6X@<&]P=7`@=FEE=R!W:6YD;W<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('=E(&%R92!V:65W:6YG('1H
M:7,@<&%R="!A<R!A;B!A='1A8VAM96YT"B`@("`@*B`@("`@("`@("`@("`@
M("`@('1H<F]U9V@@=FEE=RYP:'`N"B`@("`@*B\*("`@(&9U;F-T:6]N('9I
M97=!<T%T=&%C:&UE;G0H)'!O<'5P(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M<F5T=7)N("@H<W1R<&]S*"1?4T525D526R=02%!?4T5,1B==+"`G=FEE=RYP
M:'`G*2`A/3T@9F%L<V4I("8F"B`@("`@("`@("`@("`@("`H(21P;W!U<"!\
M?"!5=&EL.CIG971&;W)M1&%T82@G<&]P=7!?=FEE=R<I*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S(&$@<W5M;6%R>2!E;G1R>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!4:&4@34E-15]0
M87)T(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@("`@
M("`@(%1H92!S=6UM87)Y(&-A8VAE('1O('5S92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T4W5M;6%R>2@F)&UI;65?<&%R="P@)'1Y<&4I"B`@("!["B`@
M("`@("`@:68@*"1T>7!E(#T]("=A='1A8VAM96YT)RD@>PH@("`@("`@("`@
M("`D8V%C:&4@/2`F)'1H:7,M/E]A=&,["B`@("`@("`@?2!E;'-E:68@*"1T
M>7!E(#T]("=P87)T)RD@>PH@("`@("`@("`@("`D8V%C:&4@/2`F)'1H:7,M
M/E]S=6UM87)Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$U)345+
M97DH)&UI;65?<&%R="D["@H@("`@("`@("1T:&ES+3Y?<W5M;6%R>51Y<&4@
M/2`D='EP93L*("`@("`@("`D<W5M;6%R>2`]("1T:&ES+3YP87)T4W5M;6%R
M>2@D;6EM95]P87)T+"!N=6QL*3L*("`@("`@("`D=&AI<RT^7W-U;6UA<GE4
M>7!E(#T@;G5L;#L*"B`@("`@("`@:68@*"%E;7!T>2@D<W5M;6%R>2DI('L*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<G1S6R1K97E=*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)T<ULD:V5Y72`](&YU;&P[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-A8VAE6R1K97E=(#T@)'-U
M;6UA<GD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A;B!A<G)A>2!S=6UM87)I>FEN9R!A('!A<G0@;V8@82!-24U%(&UE<W-A
M9V4N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R
M="`@5&AE($U)345?4&%R="!T;R!S=6UM87)I>F4N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D9W5E<W,@("`@("`@("!)<R!T:&ES(&$@=&5M<&]R87)Y(&=U
M97-S960M='EP92!P87)T/PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!S=6UM87)Y(&]F('1H92!P87)T+@H@("`@("H@("`@("`@("`@("`@
M("`@6S!=(#T@26-O;@H@("`@("H@("`@("`@("`@("`@("`@6S%=(#T@24U!
M4"!)1`H@("`@("H@("`@("`@("`@("`@("`@6S)=(#T@1&5S8W)I<'1I;VX*
M("`@("`J("`@("`@("`@("`@("`@(%LS72`]($U)344@5'EP90H@("`@("H@
M("`@("`@("`@("`@("`@6S1=(#T@4VEZ90H@("`@("H@("`@("`@("`@("`@
M("`@6S5=(#T@1&]W;FQO860@;&EN:R]I8V]N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('!A<G13=6UM87)Y*"8D;6EM95]P87)T+"`D9W5E<W,@/2!F86QS92D*
M("`@('L*("`@("`@("`D871T86-H;65N="`]("@D;6EM95]P87)T+3YG971$
M:7-P;W-I=&EO;B@I(#T]("=A='1A8VAM96YT)RD["B`@("`@("`@)&)Y=&5S
M(#T@)&UI;65?<&%R="T^9V5T0GET97,H*3L*("`@("`@("`D9&5S8W)I<'1I
M;VX@/2!H=&UL<W!E8VEA;&-H87)S*"1M:6UE7W!A<G0M/F=E=$1E<V-R:7!T
M:6]N*'1R=64L('1R=64I*3L*("`@("`@("`D<W5M;6%R>2`](&%R<F%Y*"D[
M"B`@("`@("`@)'1Y<&4@/2!H=&UL<W!E8VEA;&-H87)S*"1M:6UE7W!A<G0M
M/F=E=%1Y<&4H*2D["B`@("`@("`@)'9I97=E<B`]("8D=&AI<RT^9V5T34E-
M159I97=E<B@D;6EM95]P87)T*3L*("`@("`@("!I9B`H(21V:65W97(I('L*
M("`@("`@("`@("`@<F5T=7)N("1S=6UM87)Y.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4F5T=7)N(&EF('=E('-T:6QL(&1I9&XG="!F:6YD(&$@;F%T:79E
M(&UI;64@=FEE=V5R"B`@("`@("`@("H@9F]R(&$@9W5E<W-E9"!M:6UE('1Y
M<&4N("HO"B`@("`@("`@:68@*"1G=65S<R`F)B!I<U]A*"1V:65W97(L("=-
M24U%7U9I97=E<E]D969A=6QT)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S
M=6UM87)Y.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H92!-24U%(&ED
M(&EN9&5X+B`J+PH@("`@("`@("1I9"`]("1T:&ES+3Y?9V5T34E-14ME>2@D
M;6EM95]P87)T*3L*"B`@("`@("`@+RH@26-O;B!C;VQU;6XN("HO"B`@("`@
M("`@)'-U;6UA<GE;72`]($AO<F1E.CII;6<H)'9I97=E<BT^9V5T26-O;B@D
M='EP92DL(&YU;&PL(&YU;&PL("<G*3L*"B`@("`@("`@+RH@3G5M8F5R(&-O
M;'5M;BX@*B\*("`@("`@("!I9B`H*"1T:&ES+3Y?9&ES<&QA>51Y<&4@/3T@
M34E-15]#3TY414Y44U]$25-03$%97U194$5?0D]42"D@)B8*("`@("`@("`@
M("`@(6ES7VYU;&PH)'1H:7,M/E]S=6UM87)Y5'EP92DI('L*("`@("`@("`@
M("`@)'-U;6UA<GE;72`]("<\82!I9#TB;6EM95]C;VYT96YT<U\G("X@)'1H
M:7,M/E]S=6UM87)Y5'EP92`N("=?)R`N("1I9"`N("<B(&AR968](B-M:6UE
M7V-O;G1E;G1S7R<@+B`H*"1T:&ES+3Y?<W5M;6%R>51Y<&4@/3T@)V%T=&%C
M:&UE;G0G*2`_)W!A<G0G(#H@)V%T=&%C:&UE;G0G*2`N("=?)R`N("1I9"`N
M("<B/B<@+B`D:60@+B`G/"]A/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'-U;6UA<GE;72`]("1I9#L*("`@("`@("!]"@H@("`@("`@("\J
M($YA;64O=&5X="!P87)T(&-O;'5M;BX@*B\*("`@("`@("!I9B`H(21T:&ES
M+3Y?;&EN:W,@?'P*("`@("`@("`@("`@*"$D871T86-H;65N="`F)B!E;7!T
M>2@D8GET97,I*2`@?'P*("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?=FEE
M=TE$6R=V:65W)UTI('Q\"B`@("`@("`@("`@(&ES7V$H)'9I97=E<BP@)TU)
M345?5FEE=V5R7V1E9F%U;'0G*2D@>PH@("`@("`@("`@("`D<W5M;6%R>5M=
M(#T@)&1E<V-R:7!T:6]N.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1P87)A;5]A<G)A>2`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("@D9W5E
M<W,@/3T]('1R=64I('L*("`@("`@("`@("`@("`@("1P87)A;5]A<G)A>5LG
M8W1Y<&4G72`]("1T>7!E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S
M=6UM87)Y6UT@/2`D=&AI<RT^;&EN:U9I97=*4R@D;6EM95]P87)T+"`D=&AI
M<RT^7W9I97=)1%LG=FEE=R==+"`D9&5S8W)I<'1I;VXL(&YU;&PL(&YU;&PL
M("1P87)A;5]A<G)A>2D["B`@("`@("`@?0H*("`@("`@("`O*B!-24U%('1Y
M<&4@8V]L=6UN+B`J+PH@("`@("`@(&EF("@D9W5E<W,I('L*("`@("`@("`@
M("`@)'-U;6UA<GE;72`]("<\96T^)R`N('-P<FEN=&8H7R@B5FEE=R!A<R`E
M<R(I+"`D='EP92D@+B`G/"]E;3XG.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1S=6UM87)Y6UT@/2`G6R<@+B`D='EP92`N("==)SL*("`@("`@
M("!]"@H@("`@("`@("\J(%-I>F4@0V]L=6UN+B`J+PH@("`@("`@("1S:7IE
M(#T@)&UI;65?<&%R="T^9V5T4VEZ92AT<G5E*3L*("`@("`@("!I9B`H(65M
M<'1Y*"1B>71E<RD@)B8*("`@("`@("`@("`@*"1M:6UE7W!A<G0M/F=E=$-U
M<G)E;G1%;F-O9&EN9R@I(#T]("=B87-E-C0G*2D@>PH@("`@("`@("`@("`O
M*B!&<F]M(%)&0R`R,#0U(%LV+CA=.B`B+BXN=&AE(&5N8V]D960@9&%T82!A
M<F4@8V]N<VES=&5N=&QY"B`@("`@("`@("`@("`@(&]N;'D@86)O=70@,S,@
M<&5R8V5N="!L87)G97(@=&AA;B!T:&4@=6YE;F-O9&5D(&1A=&$N(B`J+PH@
M("`@("`@("`@("`D<VEZ92`](&YU;6)E<E]F;W)M870H;6%X*"@H)&)Y=&5S
M("H@,"XW-2D@+R`Q,#(T*2P@,2DI.PH@("`@("`@("`@("`D<W5M;6%R>5M=
M(#T@)SQA8W)O;GEM('1I=&QE/2(G("X@7R@B07!P<F]X:6UA=&4@4VEZ92(I
M("X@)R(^)R`N('-P<FEN=&8H7R@B)7,@2T(B*2P@)'-I>F4I("X@)SPO86-R
M;VYY;3XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=6UM87)Y
M6UT@/2!S<')I;G1F*%\H(B5S($M"(BDL("1S:7IE*3L*("`@("`@("!]"@H@
M("`@("`@("\J($1O=VYL;V%D(&-O;'5M;BX@*B\*("`@("`@("!I9B`H(21T
M:&ES+3Y?;&EN:W,@?'P*("`@("`@("`@("`@:7-?;G5L;"@D<VEZ92D@?'P*
M("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?=FEE=TE$6R=D;W=N;&]A9"==
M*2D@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@;G5L;#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@)'1H:7,M/FQI;FM6
M:65W*"1M:6UE7W!A<G0L("1T:&ES+3Y?=FEE=TE$6R=D;W=N;&]A9"==+"!(
M;W)D93HZ:6UG*"=D;W=N;&]A9"YP;F<G+"!?*")$;W=N;&]A9"(I+"!N=6QL
M+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI
M+"!A<G)A>2@G:G-T97AT)R`]/B!S<')I;G1F*%\H(D1O=VYL;V%D("5S(BDL
M("1M:6UE7W!A<G0M/F=E=$1E<V-R:7!T:6]N*'1R=64L('1R=64I*2DL('1R
M=64I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE($U)344@5'EP92!I
M<R!A<'!L:6-A=&EO;B]O8W1E="US=')E86TL('1R>2!T;R!U<V4*("`@("`@
M("`@("!T:&4@9FEL92!E>'1E;G-I;VX@=&\@9&5T97)M:6YE('1H92!A8W1U
M86P@34E-12!T>7!E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7VQI;FMS("8F
M"B`@("`@("`@("`@("$D9W5E<W,@)B8*("`@("`@("`@("`@(6ES7VYU;&PH
M)'-I>F4I("8F"B`@("`@("`@("`@("@D='EP92`]/2`G87!P;&EC871I;VXO
M;V-T970M<W1R96%M)RD@?'P*("`@("`@("`@("`@*"1T>7!E(#T]("=A<'!L
M:6-A=&EO;B]B87-E-C0G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+TUA9VEC+G!H<"<["B`@("`@("`@("`@
M("1N97=?='EP92`]($U)345?36%G:6,Z.F9I;&5N86UE5&]-24U%*$U)344Z
M.F1E8V]D92@D;6EM95]P87)T+3YG971.86UE*"DI*3L*("`@("`@("`@("`@
M:68@*"1N97=?='EP92`A/2`G87!P;&EC871I;VXO;V-T970M<W1R96%M)RD@
M>PH@("`@("`@("`@("`@("`@)'1E;7!?<&%R="`]("1M:6UE7W!A<G0["B`@
M("`@("`@("`@("`@("`D=&5M<%]P87)T+3YS9714>7!E*"1N97=?='EP92D[
M"B`@("`@("`@("`@("`@("`D<W5M;6%R>2`](&%R<F%Y7VUA<"@*("`@("`@
M("`@("`@("`@("`@("!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L("=R971U
M<FX@96UP='DH)&(I(#\@)&$@.B`D82`N(%PG/&)R("\^7"<@+B`D8CLG*2P*
M("`@("`@("`@("`@("`@("`@("`D<W5M;6%R>2P*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<&%R=%-U;6UA<GDH)'1E;7!?<&%R="P@=')U92DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-U;6UA
M<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(%523"!T;R!T
M:&4@=FEE=RYP:'`@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]0
M87)T("8D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!V:65W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%C=&EO;DE$("`@("`@5&AE($%C
M=&EO;DE$('1O('!E<F9O<FTN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@("`@("`@("!!(&QI<W0@;V8@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R
M<R!T:&%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M965D('1O(&)E('!A<W-E9"!T;R!V:65W+G!H<"X@*&ME>2`]"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE*0H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&1L;V%D("`@("`@("`@4VAO=6QD('=E(&=E;F5R871E
M(&$@9&]W;FQO860@;&EN:S\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(%523"!T;R!V:65W+G!H<"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=7)L5FEE=R@F)&UI;65?<&%R="P@)&%C=&EO;DE$+"`D<&%R86US(#T@87)R
M87DH*2P@)&1L;V%D(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@1V5T('1H
M92!-24U%($E$(&9O<B!T:&ES('!A<G0N("HO"B`@("`@("`@)&ED(#T@*&ES
M<V5T*"1P87)A;7-;)VED)UTI*2`_("1P87)A;7-;)VED)UT@.B`D;6EM95]P
M87)T+3YG971-24U%260H*3L*"B`@("`@("`@+RH@061D('1H92!N96-E<W-A
M<GD@;&]C86P@<&%R86UE=&5R<RX@*B\*("`@("`@("`D<&%R86US6R=A8W1I
M;VY)1"==(#T@)&%C=&EO;DE$.PH@("`@("`@("1P87)A;7-;)VED)UT@/2`D
M:60["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1P87)A;7,L("1T
M:&ES+3YC86-H94E$55),4&%R86TH*2D["@H@("`@("`@(&EF("@D9&QO860I
M('L*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CID;W=N;&]A9%5R;"@D;6EM
M95]P87)T+3YG971.86UE*'1R=64L('1R=64I+"`D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G=FEE=RYP:'`G*2P@)'!A<F%M
M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5R;#L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E(&$@;&EN:R!T;R!T:&4@=FEE=RYP:'`@
M<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P
M87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!V:65W+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&%C=&EO;DE$("`@("`@5&AE(&%C=&EO;DE$('9A;'5E
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@("`@("`@5&AE(&QI
M;FL@=&5X="X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@
M($$@;&ES="!O9B!A9&1I=&EO;F%L('!A<F%M971E<G,N"B`@("`@*B`@("=C
M;&%S<R<@("`@("`@+2`@5&AE($-34R!C;&%S<R!T;R!U<V4N"B`@("`@*B`@
M("=J<W1E>'0G("`@("`@+2`@5&AE($I3('1E>'0@=&\@=7-E+@H@("`@("H@
M("`G=FEE=W!A<F%M<R<@("T@($$@;&ES="!O9B!A;GD@861D:71I;VYA;"!P
M87)A;65T97)S('1H870@;F5E9"!T;R!B90H@("`@("H@("`@("`@("`@("`@
M("`@("`@('!A<W-E9"!T;R!V:65W+G!H<"X*("`@("`J($!P87)A;2!B;V]L
M96%N("1D;&]A9"`@("`@("`@(%-H;W5L9"!W92!G96YE<F%T92!A(&1O=VYL
M;V%D(&QI;FL_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@2%1-
M3"!H<F5F(&QI;FL@=&\@=FEE=RYP:'`N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI;FM6:65W*"8D;6EM95]P87)T+"`D86-T:6]N240L("1T97AT+"`D<&%R
M86US(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("1D;&]A9"`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG8VQA
M<W,G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG8VQA<W,G72`](&YU;&P[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG:G-T97AT
M)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)VIS=&5X="==(#T@)'1E>'0[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG=FEE=W!A
M<F%M<R==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=V:65W<&%R86US)UT@
M/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1D;&]A9"D@>PH@
M("`@("`@("`@("`D=VEN9&]W(#T@;G5L;#L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=VEN9&]W(#T@)W9I97=?)R`N(&%B<RAC<F,S,BAM:6-R
M;W1I;64H*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N($AO<F1E.CIL
M:6YK*"1T:&ES+3YU<FQ6:65W*"1M:6UE7W!A<G0L("1A8W1I;VY)1"P@)'!A
M<F%M<ULG=FEE=W!A<F%M<R==+"`D9&QO860I+"`D<&%R86US6R=J<W1E>'0G
M72P@)'!A<F%M<ULG8VQA<W,G72P@)'=I;F1O=RD@+B`D=&5X="`N("<\+V$^
M)SL*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E(&$@:F%V87-C<FEP
M="!L:6YK('1O('1H92!V:65W+G!H<"!P86=E+@H@("`@("H*("`@("`J($!P
M87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J
M96-T('1O('9I97<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D86-T:6]N240@
M("`@("!4:&4@06-T:6]N240@=&\@<&5R9F]R;2X*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@("`@("`@("`@(%1H92!L:6YK('1E>'0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1J<W1E>'0@("`@("`@("!4:&4@2F%V87-C<FEP="!L
M:6YK('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<W,@("`@("`@("`@
M("!4:&4@0U-3(&-L87-S('1O('5S92X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("`@("`@("`@($$@;&ES="!O9B!A;GD@861D:71I;VYA;"!P87)A
M;65T97)S('1H870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YE960@=&\@8F4@<&%S<V5D('1O('9I97<N<&AP+B`H:V5Y(#T*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YA;64I"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D=VED9V5T("`@("`@("!)9B!T<G5E('5S92!(
M;W)D93HZ=VED9V5T*"D@=&\@9V5N97)A=&4L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!(;W)D93HZ;&EN:R@I(&]T:&5R=VES92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!(5$U,(&AR968@;&EN
M:R!T;R!V:65W+G!H<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;&EN:U9I97=*
M4R@F)&UI;65?<&%R="P@)&%C=&EO;DE$+"`D=&5X="P@)&IS=&5X="`](&YU
M;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("1C<W,@/2!N=6QL+"`D<&%R
M86US(#T@87)R87DH*2P@)'=I9&=E="`](&9A;'-E*0H@("`@>PH@("`@("`@
M("\J($EF('9I97=I;F<@=FEA('9I97<N<&AP+"!W92!D;VXG="!W86YT(&$@
M2E,@;&EN:RX@*B\*("`@("`@("!I9B`H)'1H:7,M/G9I97=!<T%T=&%C:&UE
M;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQI;FM6:65W*"1M
M:6UE7W!A<G0L("1A8W1I;VY)1"P@)'1E>'0L("1P87)A;7,I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&5M<'1Y*"1J<W1E>'0I*2!["B`@("`@("`@("`@
M("1J<W1E>'0@/2!S<')I;G1F*%\H(E9I97<@)7,B*2P@)&UI;65?<&%R="T^
M9V5T1&5S8W)I<'1I;VXH=')U92P@=')U92DI.PH@("`@("`@('T*("`@("`@
M("`D<&%R86US6R=P;W!U<%]V:65W)UT@/2`Q.PH*("`@("`@("`D=7)L(#T@
M)'1H:7,M/G5R;%9I97<H)&UI;65?<&%R="P@)&%C=&EO;DE$+"`D<&%R86US
M*3L*"B`@("`@("`@:68@*"$H)&ED(#T@)&UI;65?<&%R="T^9V5T34E-14ED
M*"DI*2!["B`@("`@("`@("`@("1I9"`](&%B<RAC<F,S,BAS97)I86QI>F4H
M)&UI;65?<&%R="DI*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=VED9V5T
M*2!["B`@("`@("`@("`@(')E='5R;B!(;W)D93HZ=VED9V5T*"<C)RP@)&IS
M=&5X="P@)&-S<RP@;G5L;"P@(G9I97<H)R(@+B`D=7)L("X@(B<L("<B("X@
M)&ED("X@(B<I.R!R971U<FX@9F%L<V4[(BP@)'1E>'0I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@G(R<L("1J
M<W1E>'0L("1C<W,L(&YU;&PL(")V:65W*"<B("X@)'5R;"`N("(G+"`G(B`N
M("1I9"`N("(G*3L@<F5T=7)N(&9A;'-E.R(I("X@)'1E>'0@+B`G/"]A/B<[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4')I;G1S(&]U="!T
M:&4@<W1A='5S(&UE<W-A9V4@9F]R(&$@9VEV96X@34E-12!087)T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@("`@5&AE(&UE<W-A9V4@
M=&\@;W5T<'5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6UG("`@("!!;B!I
M;6%G92!L:6YK('1O(&%D9"!T;R!T:&4@8F5G:6YN:6YG(&]F('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!M97-S86=E+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'!R:6YT("!/=71P=70@=&AI<R!M97-S86=E('=H96X@
M:6X@82!P<FEN="!V:65W/PH@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@
M("!!;B!O<'1I;VYA;"!S='EL92!F;W(@=&AE('-T871U<R!B;W@N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@<W1A='5S
M(&UE<W-A9V4@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!F;W)M8713
M=&%T=7--<V<H)&US9RP@)&EM9R`](&YU;&PL("1P<FEN=&%B;&4@/2!T<G5E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&%S<R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;7-G*2D@>PH@("`@("`@
M("`@("`D;7-G(#T@87)R87DH)&US9RD["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!W92!A<F4@=FEE=VEN9R!A<R!A;B!A='1A8VAM96YT+"!D;VXG="!P
M<FEN="!(5$U,(&-O9&4N("HO"B`@("`@("`@:68@*"1T:&ES+3YV:65W07-!
M='1A8VAM96YT*"DI('L*("`@("`@("`@("`@<F5T=7)N(&EM<&QO9&4H(EQN
M(BP@)&US9RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8VQA
M<W,I*2!["B`@("`@("`@("`@("1C;&%S<R`]("=M:6UE4W1A='5S365S<V%G
M92<["B`@("`@("`@?0H@("`@("`@("1T97AT(#T@)SQT86)L92!C;&%S<STB
M)R`N("1C;&%S<R`N("<B/B<["@H@("`@("`@("\J($EF(&YO(&EM86=E+"!S
M:6UP;'D@<')I;G0@;W5T('1H92!M97-S86=E+B`J+PH@("`@("`@(&EF("AI
M<U]N=6QL*"1I;6<I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M<V<@87,@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)SQT<CX\=&0^)R`N
M("1V86P@+B`G/"]T9#X\+W1R/B<@+B`B7&XB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1E>'0@+CT@)SQT<CX\=&0@
M=F%L:6=N/2)M:61D;&4B/B<@+B`D:6UG("X@)R9N8G-P.SPO=&0^)SL*("`@
M("`@("`@("`@)'1E>'0@+CT@)SQT9#XG.PH*("`@("`@("`@("`@:68@*&-O
M=6YT*"1M<V<I(#T](#$I('L*("`@("`@("`@("`@("`@("1T97AT("X]("1M
M<V=;,%T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=&5X="`N/2`G/'1A8FQE/B<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M;7-G(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2`G
M/'1R/CQT9#XG("X@)'9A;"`N("<\+W1D/CPO='(^)R`N(")<;B(["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&5X="`N/2`G/"]T86)L
M93XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T97AT("X]("<\+W1D
M/CPO='(^)R`N(")<;B(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E
M>'0@+B`G/"]T86)L93XG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&$@<&]I;G1E<B!T;R!T:&4@8F%S92!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@4F5T=7)N<R!A('!O:6YT97(@=&\@=&AE(&)A<V4@
M;V)J96-T+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!I
M9B!T:&5R92!I<R!N;R!B87-E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=$)A<V5/8FIE8W10='(H*0H@("`@>PH@("`@("`@(&EF("AI<U]N
M=6QL*"1T:&ES+3Y?8F%S92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V)A<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H
M92!-24U%7T-O;G1E;G1S.CH@;V)J96-T('1O(&)E(&-A8VAE9"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("!4:&4@8V%C:&4@3TE$+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M861D0V%C:&4H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?
M<V5S<VEO;D-A8VAE240I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5S<VEO
M;D-A8VAE240@/2`D=&AI<RT^7V-R96%T94-A8VAE240H*3L*("`@("`@("`@
M("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G
M7V%D9$-A8VAE4VAU=&1O=VXG*2D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/E]S97-S:6]N0V%C:&5)1#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@82!U;FEQ=64@8V%C:&4@240@9F]R('1H:7,@;V)J96-T
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!!('5N:7%U92!C86-H92!)1"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-R96%T94-A8VAE240H*0H@("`@>PH@("`@("`@(')E
M='5R;B!M9#4H;6EC<F]T:6UE*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V%V97,@82!C;W!Y(&]F('1H92!-24U%7T-O;G1E;G1S(&]B:F5C="!A="!T
M:&4@96YD(&]F(&$@<F5Q=65S="X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$-A8VAE4VAU=&1O=VXH
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B
M:F5C=',N<&AP)SL*("`@("`@("`D8V%C:&4@/2`F2&]R9&5?4V5S<VEO;D]B
M:F5C=',Z.G-I;F=L971O;B@I.PH*("`@("`@("`O*B!$;VXG="!S879E('1H
M92!-24U%7U9I97=E<B!C86-H960@;V)J96-T<R!S:6YC92!T:&5R92!I<R!N
M;R!E87-Y"B`@("`@("`@("`@=V%Y('1O(')E9V5N97)A=&4@=&AE;2!O;B!C
M86-H92!R96QO860N("HO"B`@("`@("`@)'1H:7,M/E]V:65W97)#86-H92`]
M(&%R<F%Y*"D["@H@("`@("`@("\J($-O<'D@=&AE($U)345?365S<V%G92!C
M86-H92!O8FIE8W0@=&\@=&AE(%]M97-S86=E('9A<FEA8FQE+B`J+PH@("`@
M("`@("1T:&ES+3Y?;65S<V%G92`]("1T:&ES+3Y?8V%C:&5M97-S86=E.PH*
M("`@("`@("`D8V%C:&4M/G-T;W)E*"1T:&ES+3Y?<V5S<VEO;D-A8VAE240L
M("1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-A
M8VAE9"!-24U%7T-O;G1E;G1S.CH@;V)J96-T+@H@("`@("H@5&AI<R!F=6YC
M=&EO;B!S:&]U;&0@8F4@8V%L;&5D('-T871I8V%L;'D@92YG+CH*("`@("`J
M("1P='(@/2`F34E-15]#;VYT96YT<SHZ9V5T0V%C:&4H*2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C86-H96ED("!4:&4@8V%C:&4@240@=&\@
M=7-E+B`@268@96UP='DL('=I;&P@=7-E('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@8V%C:&4@240@;&]C871E9"!I;B!T:&4@55),('!A
M<F%M971E<B!N86UE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M34E-15]#3TY414Y44U]#04-(12X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)
M345?0V]N=&5N=',@(%1H92!-24U%7T-O;G1E;G1S(&]B:F5C="P@;W(@;G5L
M;"!I9B!I="!D;V5S(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$-A8VAE*"1C86-H
M96ED(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D8V%C:&5I
M9"DI('L*("`@("`@("`@("`@)&-A8VAE:60@/2!5=&EL.CIG971&;W)M1&%T
M82A-24U%7T-/3E1%3E137T-!0TA%*3L*("`@("`@("!]"@H@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@("`@
M("`D8V%C:&4@/2`F2&]R9&5?4V5S<VEO;D]B:F5C=',Z.G-I;F=L971O;B@I
M.PH@("`@("`@("1C;VYT96YT<R`]("8D8V%C:&4M/G%U97)Y*"1C86-H96ED
M*3L*("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@061D('1H92!C=7)R96YT(&]B:F5C="!T;R!T:&4@8V%C:&4L(&%N
M9"!R971U<FX@=&AE(&-A8VAE(&ED96YT:69I97(*("`@("`J('1O(&)E('5S
M960@:6X@55),<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M<&%R86UE=&5R(&ME>2]V86QU92!S970@=&\@=7-E(&EN(%523',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-A8VAE24154DQ087)A;2@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*$U)345?0T].5$5.5%-?0T%#2$4@/3X@)'1H:7,M
M/E]A9&1#86-H92@I*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12](96%D97)S+G!H<```````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4P,#,P`#$P-3$U-#,Q,#8Q`#`R
M,3`R-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE(&1E<V-R:7!T:6]N(&]F($AO<F1E('1O('5S
M92!I;B!T:&4@)U5S97(M06=E;G0Z)R!H96%D97(N"B`J+PID969I;F4H)TA/
M4D1%7T%'14Y47TA%041%4B<L("=(;W)D92!!<'!L:6-A=&EO;B!&<F%M97=O
M<FL@,RXQ)RD["@HO*BH*("H@5&AE($U)345?2&5A9&5R<SHZ(&-L87-S(&-O
M;G1A:6YS(&=E;F5R:6,@9G5N8W1I;VYS(')E;&%T960@=&\*("H@:&%N9&QI
M;F<@=&AE(&AE861E<G,@;V8@;6%I;"!M97-S86=E<RX*("H*("H@5&AE(&1E
M9F%U;'0@8VAA<F%C=&5R('-E="!T;R!U<V4@9F]R(&AE861E<G,@<VAO=6QD
M(&)E(&1E9FEN960@:6X@=&AE"B`J('9A<FEA8FQE("1'3$]"04Q36R=M:6UE
M7VAE861E<G,G75LG9&5F875L=%]C:&%R<V5T)UT@*&1E9F%U;'1S('1O(%53
M+4%30TE)"B`J('!E<B!21D,@,C`T-2DN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<"QV(#$N,CDN,3`N,C`@,C`P-B\P
M-"\Q-2`Q-SHR-#HQ.2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-10H@*B\*
M8VQA<W,@34E-15](96%D97)S('L*"B`@("`O*BH*("`@("`J(%1H92!I;G1E
M<FYA;"!H96%D97)S(&%R<F%Y+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!#86-H960@;W5T<'5T(&]F('1H92!-24U%7U-T<G5C='5R93HZ
M<&%R<V5-24U%2&5A9&5R<R@I(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A;&Q(96%D97)S.PH*("`@("\J
M*@H@("`@("H@0V%C:&5D(&]U='!U="!O9B!T:&4@:6UA<%]F971C:&AE861E
M<B@I(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?:&5A9&5R5&5X=#L*"B`@("`O*BH*("`@("`J(%1H92!H
M96%D97(@;V)J96-T(')E='5R;F5D(&9R;VT@:6UA<%]H96%D97)I;F9O*"DN
M"B`@("`@*@H@("`@("H@0'9A<B!S=&1#;&%S<PH@("`@("HO"B`@("!V87(@
M)%]H96%D97)/8FIE8W0["@H@("`@+RHJ"B`@("`@*B!4:&4@:6YT97)N86P@
M9FQA9W,@87)R87DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]F;&%G<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4
M:&4@57-E<BU!9V5N="!S=')I;F<@=&\@=7-E+@H@("`@("H@5$A)4R!604Q5
M12!32$]53$0@0D4@3U9%4E))1$5.($)9($%,3"!354)#3$%34T53+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%G96YT
M(#T@2$]21$5?04=%3E1?2$5!1$52.PH*("`@("\J*@H@("`@("H@5&AE('-E
M<75E;F-E('1O('5S92!A<R!%3TP@9F]R('1H92!H96%D97)S+@H@("`@("H@
M5&AE(&1E9F%U;'0@:7,@8W5R<F5N=&QY('1O(&]U='!U="!T:&4@14],('-E
M<75E;F-E(&EN=&5R;F%L;'D@87,*("`@("`J(&IU<W0@(EQN(B!I;G-T96%D
M(&]F('1H92!C86YO;FEC86P@(EQR7&XB(')E<75I<F5D(&EN(%)&0R`X,C(@
M)B`R,#0U+@H@("`@("H@5&\@8F4@4D9#(&-O;7!L86EN="P@=&AE(&9U;&P@
M/$-2/CQ,1CX@14],(&-O;6)I;F%T:6]N('-H;W5L9"!B92!U<V5D"B`@("`@
M*B!W:&5N('-E;F1I;F<@82!M97-S86=E+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5O;"`](")<;B(["@H@("`@+RHJ
M"B`@("`@*B!4:&4@:6YD97@@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VEN9&5X.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&EN9&5X("!4:&4@;65S<V%G92!I;F1E>"!T;R!P87)S92!H
M96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!-24U%7TAE861E<G,H)&EN
M9&5X(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7VEN9&5X(#T@)&EN
M9&5X.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC
M92!T;R!A(&-U<G)E;G1L>2!O<&5N($E-05`@<W1R96%M+@H@("`@("H@5$A)
M4R!604Q512!32$]53$0@0D4@3U9%4E))1$5.($)9($%,3"!354)#3$%34T53
M+@H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R8V4@($%N($E-05`@<F5S
M;W5R8V4@<W1R96%M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7V=E=%-T<F5A
M;2@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!F=6QL(&QI<W0@;V8@:&5A9&5R<R!F<F]M
M('1H92!I;6%P7V9E=&-H:&5A9&5R*"D@9G5N8W1I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%-E92!I;6%P7V9E=&-H:&5A9&5R*"DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$AE861E<E1E>'0H*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7VEN9&5X*2`F)B!E;7!T>2@D=&AI
M<RT^7VAE861E<E1E>'0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R
M5&5X="`]($!I;6%P7V9E=&-H:&5A9&5R*"1T:&ES+3Y?9V5T4W1R96%M*"DL
M("1T:&ES+3Y?:6YD97@L($947U5)1"D["B`@("`@("`@("`@(&EF("@A96UP
M='DH)$=,3T)!3%-;)VUI;65?:&5A9&5R<R==6R=D969A=6QT7V-H87)S970G
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R5&5X="`](%-T
M<FEN9SHZ8V]N=F5R=$-H87)S970H)'1H:7,M/E]H96%D97)497AT+"`D1TQ/
M0D%,4ULG;6EM95]H96%D97)S)UU;)V1E9F%U;'1?8VAA<G-E="==*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:&5A9&5R5&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M9G5L;"!L:7-T(&]F(&AE861E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&1E8V]D92`@1&5C;V1E('1H92!H96%D97)S/PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%-E92!-24U%7U-T<G5C='5R93HZ<&%R<V5-
M24U%2&5A9&5R<R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!;&Q(96%D
M97)S*"1D96-O9&4@/2!T<G5E*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O34E-12]3=')U8W1U<F4N<&AP)SL*"B`@("`@("`@:68@*"%I
M<U]N=6QL*"1T:&ES+3Y?:6YD97@I("8F(&5M<'1Y*"1T:&ES+3Y?86QL2&5A
M9&5R<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]A;&Q(96%D97)S(#T@34E-
M15]3=')U8W1U<F4Z.G!A<G-E34E-14AE861E<G,H)'1H:7,M/F=E=$AE861E
M<E1E>'0H*2P@)&1E8V]D92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/E]A;&Q(96%D97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!H96%D97(@;V)J96-T(&9R;VT@:6UA<%]H96%D97)I;F9O*"DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@4V5E(&EM87!?:&5A
M9&5R:6YF;R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(96%D97)/8FIE
M8W0H*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7VEN9&5X
M*2`F)B!E;7!T>2@D=&AI<RT^7VAE861E<D]B:F5C="DI('L*("`@("`@("`@
M("`@)'-T<F5A;2`]("1T:&ES+3Y?9V5T4W1R96%M*"D["B`@("`@("`@("`@
M("1T:&ES+3Y?:&5A9&5R3V)J96-T(#T@0&EM87!?:&5A9&5R:6YF;R@D<W1R
M96%M+"!`:6UA<%]M<V=N;R@D<W1R96%M+"`D=&AI<RT^7VEN9&5X*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97)/8FIE8W0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!T:&4@:&5A9&5R(&%R<F%Y
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1D96-O9&4@($U)344@
M9&5C;V1E('1H92!H96%D97)S/PH@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL
M9$AE861E<G,H)&1E8V]D92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7VAE861E<G,I*2!["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H<F]U9V@@=&AE(&QI<W0@
M;V8@86QL(&AE861E<G,N("HO"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E
M=$%L;$AE861E<G,H)&1E8V]D92D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@("1T:&ES+3YA9&1(96%D97(H)&ME>2P@)'9A;"D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@=&AE(&9L86=S(&%R<F%Y
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9$9L86=S*"D*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?9FQA9W,I*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@24U!4"!H
M96%D97(@;V)J96-T+B`J+PH@("`@("`@("1O8B`]("1T:&ES+3YG971(96%D
M97)/8FIE8W0H*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D;V(I*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%5N<V5E
M;B!F;&%G("HO"B`@("`@("`@:68@*"@D;V(M/E5N<V5E;B`]/2`G52<I('Q\
M("@D;V(M/E)E8V5N="`]/2`G3B<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M9FQA9W-;)W5N<V5E;B==(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("\J
M(%)E8V5N="!F;&%G("HO"B`@("`@("`@:68@*"@D;V(M/E)E8V5N="`]/2`G
M3B<I('Q\("@D;V(M/E)E8V5N="`]/2`G4B<I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9FQA9W-;)W)E8V5N="==(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@("\J($%N<W=E<F5D(&9L86<@*B\*("`@("`@("!I9B`H)&]B+3Y!;G-W
M97)E9"`]/2`G02<I('L*("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG86YS
M=V5R960G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!$<F%F="!F
M;&%G("HO"B`@("`@("`@:68@*&ES<V5T*"1O8BT^1')A9G0I("8F("@D;V(M
M/D1R869T(#T]("=8)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG
M9')A9G0G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!&;&%G9V5D
M(&9L86<@*B\*("`@("`@("!I9B`H)&]B+3Y&;&%G9V5D(#T]("=&)RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=F;&%G9V5D)UT@/2!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@1&5L971E9"!F;&%G("HO"B`@("`@("`@
M:68@*"1O8BT^1&5L971E9"`]/2`G1"<I('L*("`@("`@("`@("`@)'1H:7,M
M/E]F;&%G<ULG9&5L971E9"==(#T@=')U93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!I;G1E<FYA;"!H96%D97(@87)R
M87D@:6X@87)R87D@9F]R;6%T+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!H96%D97)S(&EN(&%R<F%Y(&9O<FUA="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=&]!<G)A>2@I"B`@("!["B`@("`@("`@)')E='5R;E]A<G)A
M>2`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&5A9&5R
M<R!A<R`D;V(I('L*("`@("`@("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH
M*3L*("`@("`@("`@("`@)&AE861E<B`]("1O8ELG:&5A9&5R)UT["B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D;V);)W9A;'5E)UTI*2!["B`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M+TU)344N<&AP)SL*("`@("`@("`@("`@("`@("1R971U<FY?87)R87E;)&AE
M861E<ET@/2!-24U%.CIW<F%P2&5A9&5R<R@D:&5A9&5R+"!R97-E="@D;V);
M)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@(&YE>'0H)&]B6R=V86QU92==
M*3L*("`@("`@("`@("`@("`@('=H:6QE("AL:7-T*"PD=F%L*2`](&5A8V@H
M)&]B6R=V86QU92==*2D@>PH@("`@("`@("`@("`@("`@("`@("1R971U<FY?
M87)R87E;)&AE861E<ET@+CT@)&5O;"`N("1H96%D97(@+B`G.B`G("X@34E-
M13HZ=W)A<$AE861E<G,H)&AE861E<BP@)'9A;"P@)&5O;"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<F5T=7)N7V%R<F%Y6R1H96%D97)=(#T@)&]B6R=V86QU92==.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R;E]A
M<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN=&5R
M;F%L(&AE861E<B!A<G)A>2!I;B!S=')I;F<@9F]R;6%T+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@:&5A9&5R<R!I;B!S=')I;F<@9F]R
M;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@
M("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH*3L*("`@("`@("`D=&5X="`]
M("<G.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAE861E<G,@87,@)&]B
M*2!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&]B6R=V86QU92==*2D@
M>PH@("`@("`@("`@("`@("`@)&]B6R=V86QU92==(#T@87)R87DH)&]B6R=V
M86QU92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D
M;V);)W9A;'5E)UT@87,@)&5N=')Y*2!["B`@("`@("`@("`@("`@("`D=&5X
M="`N/2`D;V);)VAE861E<B==("X@)SH@)R`N("1E;G1R>2`N("1E;VP["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X="`N
M("1E;VP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@)U)E
M8V5I=F5D)R!H96%D97(@9F]R('1H92!796(@8G)O=W-E<BT^2&]R9&4@:&]P
M"B`@("`@*B`H871T96UP=',@=&\@8V]N9F]R;2!T;R!G=6ED96QI;F5S(&EN
M(%)&0R`R.#(Q*2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4F5C96EV961(
M96%D97(H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG2%14
M4%]87T9/4E=!4D1%1%]&3U(G72DI('L*("`@("`@("`@("`@+RH@5&AI<R!I
M;F1I8V%T97,@=&AE('5S97(@:7,@8V]N;F5C=&EN9R!T:')O=6=H(&$@<')O
M>'DN("HO"B`@("`@("`@("`@("1R96UO=&5?<&%T:"`](&5X<&QO9&4H)RPG
M+"`D7U-%4E9%4ELG2%144%]87T9/4E=!4D1%1%]&3U(G72D["B`@("`@("`@
M("`@("1R96UO=&5?861D<B`]("1R96UO=&5?<&%T:%LP73L*("`@("`@("`@
M("`@)')E;6]T92`]($!G971H;W-T8GEA9&1R*"1R96UO=&5?861D<BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E;6]T95]A9&1R(#T@)%]3
M15)615);)U)%34]415]!1$12)UT["B`@("`@("`@("`@(&EF("AE;7!T>2@D
M7U-%4E9%4ELG4D5-3U1%7TA/4U0G72DI('L*("`@("`@("`@("`@("`@("1R
M96UO=&4@/2!`9V5T:&]S=&)Y861D<B@D<F5M;W1E7V%D9'(I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E;6]T92`]("1?4T52
M5D526R=214U/5$5?2$]35"==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@("1R96-E:79E9"`]("=F<F]M("<@+B`D<F5M;W1E("X@)R`H)SL*
M"B`@("`@("`@:68@*"%E;7!T>2@D7U-%4E9%4ELG4D5-3U1%7TE$14Y4)UTI
M*2!["B`@("`@("`@("`@("1R96-E:79E9"`N/2`D7U-%4E9%4ELG4D5-3U1%
M7TE$14Y4)UT@+B`G0"<@+B`D<F5M;W1E("X@)R`G.PH@("`@("`@('T@96QS
M96EF("@D<F5M;W1E("$]("1?4T525D526R=214U/5$5?041$4B==*2!["B`@
M("`@("`@("`@("1R96-E:79E9"`N/2`D<F5M;W1E("X@)R`G.PH@("`@("`@
M('T*("`@("`@("`D<F5C96EV960@+CT@)ULG("X@)')E;6]T95]A9&1R("X@
M)UTI("<["@H@("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG
M<V5R=F5R)UU;)VYA;64G72DI('L*("`@("`@("`@("`@)'-E<G9E<E]N86UE
M(#T@)$=,3T)!3%-;)V-O;F8G75LG<V5R=F5R)UU;)VYA;64G73L*("`@("`@
M("!](&5L<V5I9B`H(65M<'1Y*"1?4T525D526R=315)615)?3D%-12==*2D@
M>PH@("`@("`@("`@("`D<V5R=F5R7VYA;64@/2`D7U-%4E9%4ELG4T525D52
M7TY!344G73L*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1?4T525D526R=(
M5%107TA/4U0G72DI('L*("`@("`@("`@("`@)'-E<G9E<E]N86UE(#T@)%]3
M15)615);)TA45%!?2$]35"==.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1S97)V97)?;F%M92`]("=U;FMN;W=N)SL*("`@("`@("!]"B`@("`@
M("`@)')E8V5I=F5D("X]("=B>2`G("X@)'-E<G9E<E]N86UE("X@)R`H2&]R
M9&4@34E-12!L:6)R87)Y*2!W:71H($A45%`[("<["@H@("`@("`@("1R96-E
M:79E9"`N/2!D871E*"=R)RD["@H@("`@("`@("1T:&ES+3YA9&1(96%D97(H
M)U)E8V5I=F5D)RP@)')E8V5I=F5D*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E('1H92`G365S<V%G92U)1"<@:&5A9&5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1-97-S86=E261(96%D97(H*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO34E-12YP
M:'`G.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)TUE<W-A9V4M240G+"!-
M24U%.CIG96YE<F%T94UE<W-A9V5)1"@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E;F5R871E('1H92`G4F5S96YT)R!H96%D97)S("AC;VYF;W)M<R!T
M;R!G=6ED96QI;F5S(&EN"B`@("`@*B!21D,@,C@R,B!;,RXV+C9=*2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<F]M("!4:&4@861D<F5S<R!T
M;R!U<V4@9F]R("=297-E;G0M1G)O;2<N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T;R`@("!4:&4@861D<F5S<R!T;R!U<V4@9F]R("=297-E;G0M5&\G+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1297-E;G1(96%D97)S*"1F<F]M+"`D
M=&\I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B]-24U%+G!H<"<["@H@("`@("`@("\J(%=E(&1O;B=T('-E
M="!297-E;G0M4V5N9&5R+"!297-E;G0M0V,L(&]R(%)E<V5N="U"8V,N("HO
M"B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G4F5S96YT+41A=&4G+"!D871E
M*"=R)RDI.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U)E<V5N="U&<F]M
M)RP@)&9R;VTI.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U)E<V5N="U4
M;R<L("1T;RD["B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G4F5S96YT+4UE
M<W-A9V4M240G+"!-24U%.CIG96YE<F%T94UE<W-A9V5)1"@I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E;F5R871E(&1E;&EV97)Y(')E8V5I<'0@:&5A
M9&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;R`@5&AE(&%D
M9')E<W,@=&AE(')E8V5I<'0@<VAO=6QD(&)E(&UA:6QE9"!T;RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D1&5L:79E<GE296-E:7!T2&5A9&5R<R@D=&\I
M"B`@("!["B`@("`@("`@+RH@5&AI<R!I<R!O;&0@<V5N9&UA:6P@*'!R92TX
M+C<I(&)E:&%V:6]R+B`J+PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U)E
M='5R;BU296-E:7!T+51O)RP@)'1O*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E('1H92!U<V5R(&%G96YT(&1E<V-R:7!T:6]N(&AE861E<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D06=E;G1(96%D97(H*0H@("`@>PH@
M("`@("`@("1T:&ES+3YA9&1(96%D97(H)U5S97(M06=E;G0G+"`D=&AI<RT^
M7V%G96YT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S
M97(@86=E;G0@9&5S8W)I<'1I;VX@:&5A9&5R+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=7-E<B!A9V5N="!H96%D97(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$%G96YT2&5A9&5R*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]A9V5N=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9"!A(&AE861E<B!T;R!T:&4@:&5A9&5R(&%R<F%Y+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE(&AE861E<B!N86UE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("!4:&4@:&5A9&5R('9A;'5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1(96%D97(H)&AE861E<BP@)'9A;'5E
M*0H@("`@>PH@("`@("`@("1H96%D97(@/2!T<FEM*"1H96%D97(I.PH@("`@
M("`@("1L8TAE861E<B`](%-T<FEN9SHZ;&]W97(H)&AE861E<BD["@H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]H96%D97)S6R1L8TAE861E<ETI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=(#T@87)R
M87DH*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]H96%D97)S6R1L8TAE
M861E<EU;)VAE861E<B==(#T@)&AE861E<CL*("`@("`@("`D=&AI<RT^7VAE
M861E<G-;)&QC2&5A9&5R75LG=F%L=64G72`]("1V86QU93L*("`@("`@("`D
M=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R75LG7V%L=&5R)UT@/2!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A(&AE861E<B!F<F]M('1H
M92!H96%D97(@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:&5A9&5R("!4:&4@:&5A9&5R(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V94AE861E<B@D:&5A9&5R*0H@("`@>PH@("`@("`@("1H96%D97(@
M/2!T<FEM*"1H96%D97(I.PH@("`@("`@("1L8TAE861E<B`](%-T<FEN9SHZ
M;&]W97(H)&AE861E<BD["B`@("`@("`@=6YS970H)'1H:7,M/E]H96%D97)S
M6R1L8TAE861E<ETI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&$@=F%L
M=64@9F]R(&$@<&%R=&EC=6QA<B!H96%D97(@3TY,62!I9B!T:&%T(&AE861E
M<B!I<R!S970N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R
M("!4:&4@:&5A9&5R(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU
M92`@(%1H92!H96%D97(@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF('9A;'5E('=A<R!S970L(&9A;'-E(&EF(&YO="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5F%L=64H)&AE861E<BP@)'9A;'5E
M*0H@("`@>PH@("`@("`@("1L8TAE861E<B`](%-T<FEN9SHZ;&]W97(H)&AE
M861E<BD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULD;&-(
M96%D97)=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)&QC2&5A
M9&5R75LG=F%L=64G72`]("1V86QU93L*("`@("`@("`@("`@)'1H:7,M/E]H
M96%D97)S6R1L8TAE861E<EU;)U]A;'1E<B==(#T@=')U93L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(')E='5R;B!T:&4@:&5A9&5R(&EN('1H92!C;W)R96-T
M(&-A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4
M:&4@:&5A9&5R('1O('-E87)C:"!F;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!V86QU92!F;W(@=&AE(&=I=F5N(&AE861E<BX*("`@
M("`J("`@("`@("`@("`@("`@("!)9B!T:&4@:&5A9&5R(&ES(&YO="!F;W5N
M9"P@<F5T=7)N<R!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713=')I
M;F<H)&AE861E<BD*("`@('L*("`@("`@("`D;&-(96%D97(@/2!3=')I;F<Z
M.FQO=V5R*"1H96%D97(I.PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M
M/E]H96%D97)S6R1L8TAE861E<ETI*2`_("1T:&ES+3Y?:&5A9&5R<ULD;&-(
M96%D97)=6R=H96%D97(G72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T('1O(')E='5R;B!T:&4@=F%L=64@9F]R(&$@9VEV96X@:&5A
M9&5R+@H@("`@("H@5&AE(&9O;&QO=VEN9R!H96%D97(@9FEE;&1S(&-A;B!O
M;FQY(&AA=F4@,2!E;G1R>2P@<V\@:68@9'5P;&EC871E"B`@("`@*B!E;G1R
M:65S(&5X:7-T+"!T:&4@9FER<W0@=F%L=64@=VEL;"!B92!U<V5D.@H@("`@
M("H@("`J(%1O+"!&<F]M+"!#8RP@0F-C+"!$871E+"!396YD97(L(%)E<&QY
M+71O+"!-97-S86=E+4E$+"!);BU297!L>2U4;RP*("`@("`J("`@("!2969E
M<F5N8V5S+"!3=6)J96-T("A21D,@,C@R,B!;,RXV72D*("`@("`J("`@*B!!
M;&P@3&ES="!(96%D97)S("A21D,@,C,V.2!;,UTI"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4:&4@:&5A9&5R('1O('-E87)C:"!F
M;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('9A;'5E(&9O
M<B!T:&4@9VEV96X@:&5A9&5R+@H@("`@("H@("`@("`@("`@("`@("`@268@
M=&AE(&AE861E<B!I<R!N;W0@9F]U;F0L(')E='5R;G,@;G5L;"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5F%L=64H)&AE861E<BD*("`@('L*("`@("`@
M("`D:&5A9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULD:&5A9&5R72DI('L*("`@("`@
M("`@("`@)'-I;F=L92`](&%R<F%Y*"=T;R<L("=F<F]M)RP@)V-C)RP@)V)C
M8R<L("=D871E)RP@)W-E;F1E<B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5P;'DM=&\G+"`G;65S<V%G92UI9"<L("=I;BUR97!L>2UT;R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5F97)E;F-E<R<L("=S
M=6)J96-T)RP@)W@M<')I;W)I='DG*3L*("`@("`@("`@("`@)'-I;F=L92`]
M(&%R<F%Y7VUE<F=E*"1S:6YG;&4L(&%R<F%Y7VME>7,H)'1H:7,M/FQI<W1(
M96%D97)S*"DI*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?
M:&5A9&5R<ULD:&5A9&5R75LG=F%L=64G72D@)B8*("`@("`@("`@("`@("`@
M(&EN7V%R<F%Y*"1H96%D97(L("1S:6YG;&4I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]H96%D97)S6R1H96%D97)=6R=V86QU92==6S!=
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:&5A9&5R<ULD:&5A9&5R75LG=F%L=64G73L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($AA<R!T:&4@:&5A
M9&5R(&)E96X@86QT97)E9"!F<F]M('1H92!O<FEG:6YA;#\*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@=&\@86YA
M;'EZ92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE(&AE861E<B!H87,@8F5E;B!A;'1E<F5D+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A;'1E<F5D2&5A9&5R*"1H96%D97(I"B`@("!["B`@("`@("`@)&QC
M2&5A9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*("`@("`@("!R971U
M<FX@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=*2D@/R`D=&AI
M<RT^7VAE861E<G-;)&QC2&5A9&5R75LG7V%L=&5R)UT@.B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1R86YS9F]R;7,@82!(96%D97(@=F%L=64@
M=7-I;F<@=&AE(&QI<W0@;V8@9G5N8W1I;VYS('!R;W9I9&5D+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE(&AE861E<B!T;R!A
M;'1E<BX*("`@("`J($!P87)A;2!M:7AE9"`D9G5N8W,@("`@02!F=6YC=&EO
M;BP@;W(@86X@87)R87D@;V8@9G5N8W1I;VYS+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!4:&4@9G5N8W1I;VYS('=I;&P@8F4@<&5R9F]R;65D
M(&9R;VT@<FEG:'0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M;&5F="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5F%L=65">49U;F-T:6]N
M*"1H96%D97(L("1F=6YC<RD*("`@('L*("`@("`@("`D:&5A9&5R(#T@4W1R
M:6YG.CIL;W=E<B@D:&5A9&5R*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1F
M=6YC<RDI('L*("`@("`@("`@("`@)&9U;F-S(#T@87)R87E?<F5V97)S92@D
M9G5N8W,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F=6YC<R`]
M(&%R<F%Y*"1F=6YC<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]H96%D97)S6R1H96%D97)=*2D@>PH@("`@("`@("`@("`D=F%L
M(#T@)'1H:7,M/F=E=%9A;'5E*"1H96%D97(I.PH@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'9A;"DI('L*("`@("`@("`@("`@("`@("1V86P@/2!I;7!L
M;V1E*")<;B(L("1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1F=6YC<R!A<R`D9G5N8RD@>PH@("`@("`@("`@("`@("`@)'9A
M;"`](&-A;&Q?=7-E<E]F=6YC*"1F=6YC+"`D=F%L*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^<V5T5F%L=64H)&AE861E<BP@)'9A;"D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&%N>2!-24U%
M(&AE861E<G,@<F5Q=6ER960@9F]R('1H92!-24U%7U!A<G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@5&AE($U)345?
M4&%R="!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$U)345(96%D
M97)S*"8D;6EM95]P87)T*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1M:6UE
M7W!A<G0M/FAE861E<BAA<G)A>2@I*2!A<R`D:&5A9"`]/B`D=F%L*2!["B`@
M("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H)&AE860L("1V86PI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;&ES="!O
M9B!A9&1R97-S97,@9F]R(&$@:&5A9&5R(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&]B<R`@06X@87)R87D@;V8@:&5A9&5R(&]B:F5C
M=',@*%-E92!I;6%P7VAE861E<FEN9F\H*0H@("`@("H@("`@("`@("`@("`@
M("`@("`@(&9O<B!T:&4@;V)J96-T('-T<G5C='5R92DN"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@;V)J96-T<RX*("`@("`J
M(#QP<F4^"B`@("`@*B!/8FIE8W0@96QE;65N=',Z"B`@("`@*B`G861D<F5S
M<R<@("`M("!&=6QL(&%D9')E<W,*("`@("`J("=H;W-T)R`@("`@("T@($AO
M<W0@;F%M90H@("`@("H@)VEN;F5R)R`@("`@+2`@5')I;6UE9"P@8F%R92!A
M9&1R97-S"B`@("`@*B`G<&5R<V]N86PG("`M("!097)S;VYA;"!S=')I;F<*
M("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!9&1R97-S
M97-&<F]M3V)J96-T*"1O8G,I"B`@("!["B`@("`@("`@)')E=$%R<F%Y(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;V)S*2!\?"!E;7!T
M>2@D;V)S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E=$%R<F%Y.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)&]B<R!A<R`D;V(I('L*("`@("`@
M("`@("`@+RH@16YS=7)E('=E)W)E('=O<FMI;F<@=VET:"!I;FET:6%L:7IE
M9"!V86QU97,N("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D;V(M/G!E<G-O
M;F%L*2D@>PH@("`@("`@("`@("`@("`@)&]B+3YP97)S;VYA;"`]($U)344Z
M.F1E8V]D92@D;V(M/G!E<G-O;F%L*3L*("`@("`@("`@("`@("`@(&EF("@H
M<W5B<W1R*"1O8BT^<&5R<V]N86PL(#`L(#$I(#T]("<B)RD@)B8*("`@("`@
M("`@("`@("`@("`@("`H<W5B<W1R*"1O8BT^<&5R<V]N86PL("TQ*2`]/2`G
M(B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&]B+3YP97)S;VYA;"`]('-U
M8G-T<B@D;V(M/G!E<G-O;F%L+"`Q+"`M,2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;V(M/G!E
M<G-O;F%L(#T@)R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AI
M<W-E="@D;V(M/FUA:6QB;W@I*2!["B`@("`@("`@("`@("`@("`O*B!$;VXG
M="!P<F]C97-S(&EN=F%L:60@861D<F5S<V5S+B`J+PH@("`@("`@("`@("`@
M("`@:68@*'-T<G!O<R@D;V(M/FUA:6QB;W@L("=53D584$5#5$5$7T1!5$%?
M049415)?041$4D534R<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@
M("`@('-T<G!O<R@D;V(M/FUA:6QB;W@L("=)3E9!3$E$7T%$1%)%4U,G*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1O8BT^;6%I;&)O>"`]("<G.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O8BT^:&]S="DI('L*("`@("`@("`@("`@
M("`@("1O8BT^:&]S="`]("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!'96YE<F%T92!T:&4@;F5W(&]B:F5C="X@*B\*("`@("`@("`@("`@
M)&YE=T]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`@("`@)&YE=T]B+3YA
M9&1R97-S(#T@34E-13HZ861D<D]B:F5C=#)3=')I;F<H)&]B+"!A<G)A>2@G
M=6YD:7-C;&]S960M<F5C:7!I96YT<T`G+"`G56YD:7-C;&]S960@<F5C:7!I
M96YT<T`G*2D["B`@("`@("`@("`@("1N97=/8BT^:&]S="`]("1O8BT^:&]S
M=#L*("`@("`@("`@("`@)&YE=T]B+3YI;FYE<B`]($U)344Z.G1R:6U%;6%I
M;$%D9')E<W,H34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S*"1O8BT^;6%I;&)O
M>"P@)&]B+3YH;W-T+"`G)RDI.PH@("`@("`@("`@("`D;F5W3V(M/G!E<G-O
M;F%L(#T@)&]B+3YP97)S;VYA;#L*"B`@("`@("`@("`@("1R971!<G)A>5M=
M(#T@)B1N97=/8CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T07)R
M87D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L:7-T(&]F
M('9A;&ED(&UA:6QI;F<@;&ES="!H96%D97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!L:7-T(&]F('9A;&ED(&UA:6QI;F<@;&ES="!H
M96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T2&5A9&5R<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`O*B!21D,@
M,C,V.2`J+PH@("`@("`@("`@("`G;&ES="UH96QP)R`@("`@("`@(#T^("!?
M*"),:7-T+4AE;'`B*2P*("`@("`@("`@("`@)VQI<W0M=6YS=6)S8W)I8F4G
M("`]/B`@7R@B3&ES="U5;G-U8G-C<FEB92(I+`H@("`@("`@("`@("`G;&ES
M="US=6)S8W)I8F4G("`@(#T^("!?*"),:7-T+5-U8G-C<FEB92(I+`H@("`@
M("`@("`@("`G;&ES="UO=VYE<B<@("`@("`@(#T^("!?*"),:7-T+4]W;F5R
M(BDL"B`@("`@("`@("`@("=L:7-T+7!O<W0G("`@("`@("`@/3X@(%\H(DQI
M<W0M4&]S="(I+`H@("`@("`@("`@("`G;&ES="UA<F-H:79E)R`@("`@(#T^
M("!?*"),:7-T+4%R8VAI=F4B*2P*("`@("`@("`@("`@+RH@4D9#(#(Y,3D@
M*B\*("`@("`@("`@("`@)VQI<W0M:60G("`@("`@("`@("`]/B`@7R@B3&ES
M="U)9"(I"B`@("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J($1O(&%N
M>2!M86EL:6YG(&QI<W0@:&5A9&5R<R!E>&ES=#\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@86YY(&UA:6QI;F<@;&ES="!H96%D
M97)S(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T2&5A9&5R<T5X
M:7-T*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^;&ES=$AE861E
M<G,H*2!A<R`D=F%L(#T^("1S='(I('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?:&5A9&5R<ULD=F%L72DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@;F5W
M('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D96]L("!4:&4@<W1R:6YG('1O('5S92!F;W(@14],<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T14],*"1E;VPI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]E;VP@/2`D96]L.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!S=')I;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<W1R:6YG('1O('5S92!F;W(@14],<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T14],*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]E;VP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!F;&%G('-T871U<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;&%G("!)<R!T:&ES(&9L86<@<V5T/PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@1FQA9W,Z(')E8V5N="P@=6YS965N+"!A;G-W97)E9"P@9')A
M9G0L(&EM<&]R=&%N="P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!F;&%G(&AA<R!B965N('-E="P@9F%L<V4@:68@;F]T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971&;&%G*"1F;&%G*0H@("`@>PH@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]F;&%G<UM3=')I;F<Z.FQO=V5R*"1F
M;&%G*5TI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('!R:6UA<GD@9G)O;2!A9&1R
M97-S("AF:7)S="!A9&1R97-S(&EN('1H92!&<F]M.B!H96%D97(I+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G)O;2!A9&1R97-S("AU
M<V5R0&AO<W0I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&<F]M061D<F5S
M<R@I"B`@("!["B`@("`@("`@:68@*"$H)&]B(#T@)'1H:7,M/F=E=$]B*"=F
M<F]M)RDI*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["@H@("`@
M("`@(')E='5R;B!T<FEM*$U)344Z.G1R:6U%;6%I;$%D9')E<W,H34E-13HZ
M<F9C.#(R5W)I=&5!9&1R97-S*"1O8ELP72T^;6%I;&)O>"P@*&ES<V5T*"1O
M8ELP72T^:&]S="DI(#\@)&]B6S!=+3YH;W-T(#H@)R<L("<G*2DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T(&$@:&5A9&5R(&9R;VT@=&AE(&AE861E
M<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'1O9&\@4F5P;&%C92!W:71H(&=E
M=$]B*"D@9G)O;2!)35`G<R!)35!?2&5A9&5R<R!F;W(@2&]R9&4@-"XP+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("`@(%1H92!O8FIE
M8W0@9FEE;&0@=&\@<F5T<FEE=F4@*'-E90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@:6UA<%]H96%D97)I;F9O*"D@9F]R('1H92!L:7-T(&]F
M(&9I96QD<RDN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C;V1E("!3:&]U
M;&0@=&AE(')E='5R;B!V86QU92!B92!-24U%(&1E8V]D960_"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!)="!W:6QL(&]N;'D@8F4@9&5C;V1E
M9"!I9B!I="!I<R!N;W0@86X@;V)J96-T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!I='-E;&8N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(&9I96QD(')E<75E<W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T3V(H)&9I96QD+"`D9&5C;V1E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)&1A=&$@/2!A<G)A>2@I.PH*("`@("`@("`D;V(@/2`D=&AI<RT^9V5T2&5A
M9&5R3V)J96-T*"D["B`@("`@("`@:68@*"%I<U]O8FIE8W0H)&]B*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)&]B+3XD9FEE;&0I*2!["B`@("`@("`@("`@("1D871A(#T@
M)&]B+3XD9FEE;&0["B`@("`@("`@("`@(&EF("@A96UP='DH)&1E8V]D92D@
M)B8@(6ES7V]B:F5C="@D9&%T82D@)B8@(6ES7V%R<F%Y*"1D871A*2D@>PH@
M("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%+G!H<"<[
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1'3$]"04Q36R=M:6UE7VAE
M861E<G,G75LG9&5F875L=%]C:&%R<V5T)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1A=&$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A+"`D
M1TQ/0D%,4ULG;6EM95]H96%D97)S)UU;)V1E9F%U;'1?8VAA<G-E="==*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D871A(#T@34E-
M13HZ9&5C;V1E*"1D871A*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("AI<U]S=')I;F<H)&1A=&$I*2`_('-T<G1R*"1D871A
M+"`B7'0B+"`G("<I(#H@)&1A=&$["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O34E-12]3=')U8W1U<F4N<&AP````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,#8T`#$P-3$U-#,Q,#8Q`#`R,30V-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]-97-S86=E
M+G!H<"<["G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4&%R
M="YP:'`G.PIR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M+TU)344N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)
M344O4W1R=6-T=7)E+G!H<"QV(#$N.#<N,3`N,3D@,C`P-B\P-2\P-"`Q.#HP
M,SHR-2!S;'5S87)Z($5X<"`D"B`J"B`J(%1H92!-24U%7U-T<G5C='5R93HZ
M(&-L87-S('!R;W9I9&5S(&UE=&AO9',@9F]R(&1E86QI;F<@=VET:"!-24U%
M(&UA:6PN"B`J"B`J(%1H92!D969A=6QT(&-H87)A8W1E<B!S970@=&\@=7-E
M(&9O<B!M97-S86=E<R!S:&]U;&0@8F4@9&5F:6YE9"!I;B!T:&4*("H@=F%R
M:6%B;&4@)$=,3T)!3%-;)VUI;65?<W1R=6-T=7)E)UU;)V1E9F%U;'1?8VAA
M<G-E="==("AD969A=6QT<R!T;R!54RU!4T-)20H@*B!P97(@4D9#(#(P-#4I
M+@H@*@H@*B!43T1/.B!#;VYV97)T('1O($]/"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO
M<F1E7TU)344*("HO"F-L87-S($U)345?4W1R=6-T=7)E('L*"B`@("`O*BH*
M("`@("`J($=I=F5N('1H92!R97-U;'1S(&]F(&EM87!?9F5T8VAS=')U8W1U
M<F4H*2P@<&%R<V4@=&AE('-T<G5C='5R90H@("`@("H@;V8@=&AE(&UE<W-A
M9V4L(&9I9W5R:6YG(&]U="!C;W)R96-T(&)O9'EP87)T(&YU;6)E<G,L(&5T
M8RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1D0VQA<W,@)&)O9'D@(%1H92!R
M97-U;'0@;V8@:6UA<%]F971C:'-T<G5C='5R92@I+@H@("`@("H*("`@("`J
M($!R971U<FX@)DU)345?365S<V%G92`@5&AE(&UE<W-A9V4@<&%R<V5D(&EN
M=&\@82!-24U%7TUE<W-A9V4@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F<&%R<V4H)&)O9'DI"B`@("!["B`@("`@("`@)&US9T]B(#T@)FYE=R!-
M24U%7TUE<W-A9V4H*3L*("`@("`@("`D;7-G3V(M/F%D9%!A<G0H34E-15]3
M=')U8W1U<F4Z.E]P87)S92@D8F]D>2DI.PH@("`@("`@("1M<V=/8BT^8G5I
M;&1-97-S86=E*"D["@H@("`@("`@("1P='(@/2!A<G)A>2@F)&US9T]B*3L*
M("`@("`@("!-24U%7U-T<G5C='5R93HZ7V%D9$UU;'1I<&%R=$EN9F\H)'!T
M<BD["@H@("`@("`@(')E='5R;B`D;7-G3V(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!':79E;B!T:&4@<F5S=6QT<R!O9B!I;6%P7V9E=&-H<W1R=6-T=7)E
M*"DL('!A<G-E('1H92!S=')U8W1U<F4*("`@("`J(&]F('1H92!M97-S86=E
M+"!F:6=U<FEN9R!O=70@8V]R<F5C="!B;V1Y<&%R="!N=6UB97)S+"!E=&,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T9$-L87-S("1B;V1Y("!4:&4@<F5S=6QT(&]F(&EM87!?9F5T
M8VAS=')U8W1U<F4H*2X*("`@("`J($!P87)A;2!S=')I;F<@)')E9B`@("`@
M5&AE(&-U<G)E;G0@8F]D>7!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!-
M24U%7U!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)E]P87)S92@D8F]D>2P@)')E9B`](#`I"B`@("!["B`@("`@("`@
M<W1A=&EC("1M97-S86=E+"`D;75L=&EP87)T.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1M97-S86=E*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]($U)344Z
M.G1Y<&4H)VUE<W-A9V4G*3L*("`@("`@("`@("`@)&UU;'1I<&%R="`]($U)
M344Z.G1Y<&4H)VUU;'1I<&%R="<I.PH@("`@("`@('T*"B`@("`@("`@)&UI
M;65?<&%R="`]("9N97<@34E-15]087)T*"D["@H@("`@("`@("\J(%1O<"!M
M=6QT:7!A<G1S(&1O;B=T(&=E="!T:&5I<B!O=VX@;&EN92X@*B\*("`@("`@
M("!I9B`H96UP='DH)')E9BD@)B8*("`@("`@("`@("`@*"%I<W-E="@D8F]D
M>2T^='EP92D@?'P@*"1B;V1Y+3YT>7!E("$]("1M=6QT:7!A<G0I*2D@>PH@
M("`@("`@("`@("`D<F5F(#T@,3L*("`@("`@("!]"@H@("`@("`@($U)345?
M4W1R=6-T=7)E.CI?<V5T26YF;R@D8F]D>2P@)&UI;65?<&%R="P@)')E9BD[
M"@H@("`@("`@(&EF("AI<W-E="@D8F]D>2T^='EP92D@)B8@*"1B;V1Y+3YT
M>7!E(#T]("1M97-S86=E*2`F)@H@("`@("`@("`@("`D8F]D>2T^:69S=6)T
M>7!E("8F("@D8F]D>2T^<W5B='EP92`]/2`G4D9#.#(R)RDI('L*("`@("`@
M("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*"1R968@+B`G+C`G*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6EM95]P87)T+3YS971-24U%
M260H)')E9BD["B`@("`@("`@?0H*("`@("`@("`O*B!$96%L('=I=&@@;75L
M=&EP87)T(&1A=&$N("HO"B`@("`@("`@:68@*&ES<V5T*"1B;V1Y+3YP87)T
M<RDI('L*("`@("`@("`@("`@)'-U8E]I9"`](#$["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1B;V1Y+3YP87)T<R!A<R`D<W5B7W!A<G0I('L*("`@("`@("`@
M("`@("`@("\J($%R92!W92!D96%L:6YG('=I=&@@82!M=6QT:7!A<G0@;65S
M<V%G93\@*B\*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8F]D>2T^='EP
M92D@)B8@*"1B;V1Y+3YT>7!E(#T]("1M97-S86=E*2`F)@H@("`@("`@("`@
M("`@("`@("`@(&ES<V5T*"1S=6)?<&%R="T^='EP92D@)B8@*"1S=6)?<&%R
M="T^='EP92`]/2`D;75L=&EP87)T*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1S=6)?<F5F(#T@)')E9CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'-U8E]R968@/2`H96UP='DH)')E9BDI(#\@
M)'-U8E]I9"`Z("1R968@+B`G+B<@+B`D<W5B7VED.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&UI;65?<&%R="T^861D4&%R="A-24U%
M7U-T<G5C='5R93HZ7W!A<G-E*"1S=6)?<&%R="P@)'-U8E]R968I+"`D<W5B
M7VED*RLI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&UI;65?<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@
M;6EM92!P87)T(&9R;VT@:6UA<%]F971C:'-T<G5C='5R92@I+"!M=6YG92!I
M="!I;G1O(&$*("`@("`J('5S969U;"!F;W)M(&%N9"!M86ME('-U<F4@=&AA
M="!A;GD@<&%R86UE=&5R<R!W:&EC:"!A<F4@;6ES<VEN9PH@("`@("H@87)E
M(&=I=F5N(&1E9F%U;'0@=F%L=65S+@H@("`@("H*("`@("`J(%1O('-P96-I
M9GD@=&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E="P@9&5F:6YE('1H92!G;&]B
M86P@=F%R:6%B;&4*("`@("`J("1'3$]"04Q36R=M:6UE7W-T<G5C=71R92==
M6R=D969A=6QT7V-H87)S970G72X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1D0VQA<W,@)'!A<G0@(%1H
M92!O<FEG:6YA;"!P87)T(&EN9F\N"B`@("`@*B!`<&%R86T@34E-15]087)T
M("8D;V(@($$@34E-15]087)T(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I
M;F<@)')E9B`@("`@5&AE($E$(&]F('1H:7,@<&%R="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E=$EN9F\H)'!A<G0L("8D;V(L("1R968I"B`@("!["B`@
M("`@("`@+RH@4W1O<F4@0V]N=&5N="UT>7!E(&EN9F]R;6%T:6]N+B`J+PH@
M("`@("`@("1P<FEM87)Y7W1Y<&4@/2`H:7-S970H)'!A<G0M/G1Y<&4I*2`_
M(%-T<FEN9SHZ;&]W97(H)'!A<G0M/G1Y<&4I(#H@34E-13HZ='EP92@G=&5X
M="<I.PH@("`@("`@("1S96-?='EP92`]("@D<&%R="T^:69S=6)T>7!E("8F
M("1P87)T+3YS=6)T>7!E*2`_(%-T<FEN9SHZ;&]W97(H)'!A<G0M/G-U8G1Y
M<&4I(#H@)W@M=6YK;F]W;B<["B`@("`@("`@)&]B+3YS9714>7!E*"1P<FEM
M87)Y7W1Y<&4@+B`G+R<@+B`D<V5C7W1Y<&4I.PH*("`@("`@("`O*B!3970@
M=')A;G-F97(@96YC;V1I;F<N("HO"B`@("`@("`@:68@*&ES<V5T*"1P87)T
M+3YE;F-O9&EN9RDI('L*("`@("`@("`@("`@)&5N8V]D:6YG(#T@)'!A<G0M
M/F5N8V]D:6YG.PH@("`@("`@("`@("`D;V(M/G-E=%1R86YS9F5R16YC;V1I
M;F<H)&5N8V]D:6YG*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M96YC;V1I;F<@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('1R
M86YS9F5R(&1I<W!O<VET:6]N+B`J+PH@("`@("`@("1O8BT^<V5T1&ES<&]S
M:71I;VXH*"1P87)T+3YI9F1I<W!O<VET:6]N*2`_(%-T<FEN9SHZ;&]W97(H
M)'!A<G0M/F1I<W!O<VET:6]N*2`Z($U)345?1$5&055,5%]$25-03U-)5$E/
M3BD["@H@("`@("`@("\J($EF("=B;V1Y)R!I<R!S970L('-E="!A<R!T:&4@
M8V]N=&5N=',@;V8@=&AE('!A<G0N("HO"B`@("`@("`@:68@*&ES<V5T*"1P
M87)T+3YB;V1Y*2D@>PH@("`@("`@("`@("`D;V(M/G-E=$-O;G1E;G1S*"1P
M87)T+3YB;V1Y+"`D96YC;V1I;F<I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@)V)Y=&5S)R!I<R!S970L('-T;W)E(&%S(&EN9F]R;6%T:6]N('9A<FEA
M8FQE+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R="T^8GET97,I*2!["B`@
M("`@("`@("`@("1O8BT^<V5T0GET97,H)'!A<G0M/F)Y=&5S*3L*("`@("`@
M("!]"@H@("`@("`@("\J(%-E="!T:&4@<&%R="=S(&ED96YT:69I8V%T:6]N
M('-T<FEN9RP@:68@879A:6QA8FQE+B`J+PH@("`@("`@(&EF("@A96UP='DH
M)')E9BD@)B8@)'!A<G0M/FEF:60I('L*("`@("`@("`@("`@)&]B+3YS971#
M;VYT96YT240H)'!A<G0M/FED*3L*("`@("`@("!]"@H@("`@("`@("\J($=O
M('1H<F]U9V@@=&AE(&-O;G1E;G0M='EP92!P87)A;65T97)S+"!I9B!A;GDN
M("HO"B`@("`@("`@9F]R96%C:"`H34E-15]3=')U8W1U<F4Z.E]G971087)A
M;65T97)S*"1P87)T+"`Q*2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@:68@*"1K97D@/3T@)V-H87)S970G*2!["B`@("`@("`@("`@("`@("`D
M;V(M/G-E=$-H87)S970H)'9A;"D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;V(M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"1K
M97DL("1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!3970@=&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E="X@*B\*("`@("`@("!I
M9B`H*"1O8BT^9V5T0VAA<G-E="@I(#T]("=U<RUA<V-I:2<I("8F"B`@("`@
M("`@("`@(&ES<V5T*"1'3$]"04Q36R=M:6UE7W-T<G5C='5R92==6R=D969A
M=6QT7V-H87)S970G72DI('L*("`@("`@("`@("`@)&]B+3YS971#:&%R<V5T
M*"1'3$]"04Q36R=M:6UE7W-T<G5C='5R92==6R=D969A=6QT7V-H87)S970G
M72D["B`@("`@("`@?0H*("`@("`@("`O*B!';R!T:')O=6=H('1H92!D:7-P
M;W-I=&EO;B!P87)A;65T97)S+"!I9B!A;GDN("HO"B`@("`@("`@9F]R96%C
M:"`H34E-15]3=')U8W1U<F4Z.E]G971087)A;65T97)S*"1P87)T+"`R*2!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&]B+3YS971$:7-P;W-I
M=&EO;E!A<F%M971E<B@D:V5Y+"`D=F%L*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%-E="!T:&4@;F%M92X@*B\*("`@("`@("!I9B`H)&]B+3YG971#;VYT
M96YT5'EP95!A<F%M971E<B@G9FEL96YA;64G*2D@>PH@("`@("`@("`@("`D
M;V(M/G-E=$YA;64H)&]B+3YG971#;VYT96YT5'EP95!A<F%M971E<B@G9FEL
M96YA;64G*2D["B`@("`@("`@?2!E;'-E:68@*"1O8BT^9V5T1&ES<&]S:71I
M;VY087)A;65T97(H)V9I;&5N86UE)RDI('L*("`@("`@("`@("`@)&]B+3YS
M971.86UE*"1O8BT^9V5T1&ES<&]S:71I;VY087)A;65T97(H)V9I;&5N86UE
M)RDI.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('1H92!D97-C<FEP=&EO
M;BX@*B\*("`@("`@("!I9B`H:7-S970H)'!A<G0M/F1E<V-R:7!T:6]N*2D@
M>PH@("`@("`@("`@("`D;V(M/G-E=$1E<V-R:7!T:6]N*"1P87)T+3YD97-C
M<FEP=&EO;BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&%L;"!P87)A;65T97)S(&9O<B!A(&=I=F5N('!O<G1I;VX@;V8@82!M97-S
M86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=&1#;&%S<R`D<&%R="`@5&AE(&]R:6=I;F%L('!A<G0@
M:6YF;RX*("`@("`J($!P87)A;2!I;G1E9V5R("1T>7!E("`@5&AE('!A<F%M
M971E<B!T>7!E('1O(')E=')I979E+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`Q(#T@8V]N=&5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`R(#T@9&ES<&]S:71I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<G)A>2!O9B!P87)A;65T97(@:V5Y+W9A;'5E('!A:7)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4&%R86UE=&5R<R@D<&%R="P@)'1Y
M<&4I"B`@("!["B`@("`@("`@)'!A<F%M7VQI<W0@/2!A<G)A>2@I.PH*("`@
M("`@("!I9B`H)'1Y<&4@/3T@,2D@>PH@("`@("`@("`@("`D<'1Y<&4@/2`G
M<&%R86UE=&5R<R<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T](#(I('L*
M("`@("`@("`@("`@)'!T>7!E(#T@)V1P87)A;65T97)S)SL*("`@("`@("!]
M"B`@("`@("`@)'!E>&ES=',@/2`G:68G("X@)'!T>7!E.PH*("`@("`@("!I
M9B`H)'!A<G0M/B1P97AI<W1S*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1P
M87)T+3XD<'1Y<&4@87,@)'!A<F%M*2!["B`@("`@("`@("`@("`@("`D<&%R
M86TM/G9A;'5E(#T@<W1R7W)E<&QA8V4H87)R87DH(EQT(BP@)UPB)RDL(&%R
M<F%Y*"<@)RP@)R(G*2P@)'!A<F%M+3YV86QU92D["@H@("`@("`@("`@("`@
M("`@)')E<R`]($U)344Z.F1E8V]D95)&0S(R,S$H)'!A<F%M+3YA='1R:6)U
M=&4@+B`G/2<@+B`D<&%R86TM/G9A;'5E*3L*("`@("`@("`@("`@("`@(&EF
M("@D<F5S*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3YA='1R:6)U
M=&4@/2`D<F5S6R=A='1R:6)U=&4G73L*("`@("`@("`@("`@("`@("`@("`D
M<&%R86TM/G9A;'5E(#T@)')E<ULG=F%L=64G73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1F:65L9"`](%-T<FEN9SHZ;&]W97(H)'!A
M<F%M+3YA='1R:6)U=&4I.PH@("`@("`@("`@("`@("`@:68@*"1F:65L9"`]
M/2`G='EP92<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H*"1T>7!E(#T@
M34E-13HZ='EP92@D<&%R86TM/G9A;'5E*2DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M7VQI<W1;)W1Y<&4G72`]("1T>7!E.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M7VQI<W1;)&9I96QD72`]("1P87)A;2T^
M=F%L=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<&%R86U?;&ES=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@<W!E8VEA;"!I;F9O<FUA=&EO;B!F;W(@8V5R
M=&%I;B!-24U%('1Y<&5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)'!A<G1S("!4:&4@;&ES
M="!O9B!P87)T<R!C;VYT86EN960@=VET:&EN('1H92!M=6QT:7!A<G0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*B!`<&%R
M86T@87)R87D@)&EN9F\@("`@26YF;W)M871I;VX@86)O=70@=&AE(&UU;'1I
M<&%R="!S=')U8W1U<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1-=6QT
M:7!A<G1);F9O*"8D<&%R=',L("1I;F9O(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'!A<G1S*2D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1P87)T
M<RD@87,@)&ME>2D@>PH@("`@("`@("`@("`D<'1R(#T@)B1P87)T<ULD:V5Y
M73L*("`@("`@("`@("`@)&YE=U]I;F9O(#T@)&EN9F\["@H@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F];)V%L="==*2D@>PH@("`@("`@("`@("`@("`@
M)'!T<BT^<V5T26YF;W)M871I;VXH)V%L=&5R;F%T:79E)RP@*&ES7VYU;&PH
M)&EN9F];)V%L="==*2D@/R`G+2<@.B`D:6YF;ULG86QT)UTI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG<F5L871E9"==
M*2D@>PH@("`@("`@("`@("`@("`@)'!T<BT^<V5T26YF;W)M871I;VXH)W)E
M;&%T961?<&%R="<L("1I;F9O6R=R96QA=&5D)UTM/F=E=$U)345)9"@I*3L*
M("`@("`@("`@("`@("`@(&EF("@D:60@/2`D<'1R+3YG971#;VYT96YT240H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;F9O6R=R96QA=&5D)UTM/F%D
M9$-)1"AA<G)A>2@D<'1R+3YG971-24U%260H*2`]/B`D:60I*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S
M970H)&EN9F];)W)F8S@R,B==*2D@>PH@("`@("`@("`@("`@("`@)'!T<BT^
M<V5T26YF;W)M871I;VXH)W)F8S@R,E]P87)T)RP@)&EN9F];)W)F8S@R,B==
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<W=I=&-H("@D<'1R+3YG
M9714>7!E*"DI('L*("`@("`@("`@("`@8V%S92`G;75L=&EP87)T+V%L=&5R
M;F%T:79E)SH*("`@("`@("`@("`@("`@("1N97=?:6YF;ULG86QT)UT@/2`D
M<'1R+3YG971-24U%260H*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G;75L=&EP87)T+W)E;&%T960G.@H@("`@("`@("`@
M("`@("`@)&YE=U]I;F9O6R=R96QA=&5D)UT@/2`F)'!T<CL*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;65S<V%G92]R9F,X
M,C(G.@H@("`@("`@("`@("`@("`@)&YE=U]I;F9O6R=R9F,X,C(G72`]("1P
M='(M/F=E=$U)345)9"@I.PH@("`@("`@("`@("`@("`@)'!T<BT^<V5T26YF
M;W)M871I;VXH)VAE861E<B<L('1R=64I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@($U)345?4W1R=6-T=7)E
M.CI?861D375L=&EP87)T26YF;R@D<'1R+3Y?<&%R=',L("1N97=?:6YF;RD[
M"B`@("`@("`@?0H@("`@?0H*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(&)U:6QD(&$@34E-15]-97-S86=E(&]B:F5C="!F<F]M(&$@=&5X="!M97-S
M86=E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T
M97AT(&]F('1H92!-24U%(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!-24U%7TUE<W-A9V4@($$@34E-15]-97-S86=E(&]B:F5C="P@;W(@9F%L
M<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9P87)S951E>'1-
M24U%365S<V%G92@D=&5X="D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M)TUA:6PO;6EM941E8V]D92YP:'`G.PH*("`@("`@("`O*B!3970@=7`@=&AE
M(&]P=&EO;G,@9F]R('1H92!M:6UE1&5C;V1E(&-L87-S+B`J+PH@("`@("`@
M("1D96-O9&5?87)G<R`](&%R<F%Y*"D["B`@("`@("`@)&1E8V]D95]A<F=S
M6R=I;F-L=61E7V)O9&EE<R==(#T@=')U93L*("`@("`@("`D9&5C;V1E7V%R
M9W-;)V1E8V]D95]B;V1I97,G72`](&9A;'-E.PH@("`@("`@("1D96-O9&5?
M87)G<ULG9&5C;V1E7VAE861E<G,G72`](&9A;'-E.PH*("`@("`@("`D;6EM
M941E8V]D92`]("9N97<@36%I;%]M:6UE1&5C;V1E*"1T97AT+"!-24U%7U!!
M4E1?14],*3L*("`@("`@("!I9B`H(2@D<W1R=6-T=7)E(#T@)&UI;65$96-O
M9&4M/F1E8V]D92@D9&5C;V1E7V%R9W,I*2D@>PH@("`@("`@("`@("`D;65S
M<V%G92`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J
M(%!U="!T:&4@;V)J96-T(&EN=&\@:6UA<%]P87)S97-T<G5C='5R92@I(&9O
M<FTN("HO"B`@("`@("`@("`@($U)345?4W1R=6-T=7)E.CI?8V]N=F5R=$UI
M;65$96-O9&5$871A*"1S=')U8W1U<F4I.PH*("`@("`@("`@("`@)&UE<W-A
M9V4@/2!-24U%7U-T<G5C='5R93HZ<&%R<V4H)'-T<G5C='5R92D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&UE<W-A9V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYV97)T('1H92!O=71P=70@9G)O;2!M:6UE1&5C;V1E.CID
M96-O9&4H*2!I;G1O(&$@<W1R=6-T=7)E('1H870*("`@("`J(&UA=&-H97,@
M:6UA<%]F971C:'-T<G5C='5R92@I(&]U='!U="X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1D0VQA<W,@
M)B1O8B`@5&AE(&]U='!U="!F<F]M(&UI;65$96-O9&4Z.F1E8V]D92@I+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=$UI;65$96-O9&5$871A*"8D
M;V(I"B`@("!["B`@("`@("`@+RH@4')I;6%R>2!C;VYT96YT+71Y<&4N("HO
M"B`@("`@("`@)&]B+3YT>7!E(#T@:6YT=F%L*$U)344Z.G1Y<&4H)&]B+3YC
M='EP95]P<FEM87)Y*2D["@H@("`@("`@("\J(%-E8V]N9&%R>2!C;VYT96YT
M+71Y<&4N("HO"B`@("`@("`@:68@*&ES<V5T*"1O8BT^8W1Y<&5?<V5C;VYD
M87)Y*2D@>PH@("`@("`@("`@("`D;V(M/G-U8G1Y<&4@/2!3=')I;F<Z.G5P
M<&5R*"1O8BT^8W1Y<&5?<V5C;VYD87)Y*3L*("`@("`@("`@("`@)&]B+3YI
M9G-U8G1Y<&4@/2`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O
M8BT^:69S=6)T>7!E(#T@,#L*("`@("`@("!]"@H@("`@("`@("\J($-O;G1E
M;G0@=')A;G-F97(@96YC;V1I;F<N("HO"B`@("`@("`@:68@*&ES<V5T*"1O
M8BT^:&5A9&5R<ULG8V]N=&5N="UT<F%N<V9E<BUE;F-O9&EN9R==*2D@>PH@
M("`@("`@("`@("`D;V(M/F5N8V]D:6YG(#T@34E-13HZ96YC;V1I;F<H)&]B
M+3YH96%D97)S6R=C;VYT96YT+71R86YS9F5R+65N8V]D:6YG)UTI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0V]N=&5N="UT>7!E(&%N9"!$:7-P;W-I=&EO
M;B!P87)A;65T97)S+B`J+PH@("`@("`@("1P87)A;5]T>7!E<R`](&%R<F%Y
M("@G8W1Y<&5?<&%R86UE=&5R<R<@/3X@)W!A<F%M971E<G,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9%]P87)A;65T97)S)R`]/B`G9'!A
M<F%M971E<G,G*3L*("`@("`@("!F;W)E86-H("@D<&%R86U?='EP97,@87,@
M)'!A<F%M7VME>2`]/B`D<&%R86U?=F%L=64I('L*("`@("`@("`@("`@)&EF
M7W9A<B`]("=I9B<@+B`D<&%R86U?=F%L=64["B`@("`@("`@("`@(&EF("AI
M<W-E="@D;V(M/B1P87)A;5]K97DI*2!["B`@("`@("`@("`@("`@("`D;V(M
M/B1I9E]V87(@/2`Q.PH@("`@("`@("`@("`@("`@)&]B+3XD<&%R86U?=F%L
M=64@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&]B+3XD
M<&%R86U?:V5Y(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M("`@("1N97=/8B`]("9N97<@<W1D0VQA<W,["B`@("`@("`@("`@("`@("`@
M("`@)&YE=T]B+3YA='1R:6)U=&4@/2`D:V5Y.PH@("`@("`@("`@("`@("`@
M("`@("1N97=/8BT^=F%L=64@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7W!U<V@H)&]B+3XD<&%R86U?=F%L=64L("1N97=/8BD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;V(M/B1I9E]V87(@/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!#;VYT96YT+41I<W!O<VET:6]N+B`J+PH@("`@("`@
M(&EF("AI<W-E="@D;V(M/FAE861E<G-;)V-O;G1E;G0M9&ES<&]S:71I;VXG
M72DI('L*("`@("`@("`@("`@)&]B+3YI9F1I<W!O<VET:6]N(#T@,3L*("`@
M("`@("`@("`@)&AD<B`]("1O8BT^:&5A9&5R<ULG8V]N=&5N="UD:7-P;W-I
M=&EO;B==.PH@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1H9'(L("<[)RD[
M"B`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@)&AD<B`]('-U8G-T<B@D:&1R+"`P+"`D<&]S*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D;V(M/F1I<W!O<VET:6]N(#T@)&AD<CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(M/FEF9&ES<&]S:71I;VX@
M/2`P.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N=&5N="U)1"X@*B\*("`@
M("`@("!I9B`H:7-S970H)&]B+3YH96%D97)S6R=C;VYT96YT+6ED)UTI*2![
M"B`@("`@("`@("`@("1O8BT^:69I9"`](#$["B`@("`@("`@("`@("1O8BT^
M:60@/2`D;V(M/FAE861E<G-;)V-O;G1E;G0M:60G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D;V(M/FEF:60@/2`P.PH@("`@("`@('T*"B`@
M("`@("`@+RH@1V5T(&9I;&4@<VEZ92`H:68@)V)O9'DG('1E>'0@:7,@<V5T
M*2X@*B\*("`@("`@("!I9B`H:7-S970H)&]B+3YB;V1Y*2D@>PH@("`@("`@
M("`@("`D;V(M/F)Y=&5S(#T@<W1R;&5N*"1O8BT^8F]D>2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!0<F]C97-S('!A<G1S(&%L<V\N("HO"B`@("`@("`@
M:68@*&ES<V5T*"1O8BT^<&%R=',I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*&%R<F%Y7VME>7,H)&]B+3YP87)T<RD@87,@)&ME>2D@>PH@("`@("`@("`@
M("`@("`@34E-15]3=')U8W1U<F4Z.E]C;VYV97)T36EM941E8V]D941A=&$H
M)&]B+3YP87)T<ULD:V5Y72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@86X@87)R87D@8V]N<VES=&EN
M9R!O9B!-24U%(&AE861E<B]V86QU92!P86ER<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1H96%D97)S("`@("!!('1E>'0@<W1R:6YG(&-O;G1A
M:6YI;F<@=&AE(&AE861E<G,@*&4N9RX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]U='!U="!F<F]M(&EM87!?9F5T8VAH96%D97(H*2DN
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C;V1E("`@("!3:&]U;&0@=&AE
M(&AE861E<G,@8F4@9&5C;V1E9#\*("`@("`J($!P87)A;2!B;V]L96%N("1L
M;W=E<F-A<V4@(%-H;W5L9"!T:&4@:V5Y<R!B92!I;B!L;W=E<F-A<V4_"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@8V]N<VES=&EN
M9R!O9B!T:&4@:&5A9&5R(&YA;64@87,@=&AE(&ME>2!A;F0*("`@("`J("`@
M("`@("`@("`@("`@('1H92!H96%D97(@=F%L=64@87,@=&AE('9A;'5E+@H@
M("`@("H@("`@("`@("`@("`@("`@02!H96%D97(@=VET:"!M=6QT:7!L92!E
M;G1R:65S('=I;&P@8F4@<W1O<F5D(&EN"B`@("`@*B`@("`@("`@("`@("`@
M("`G=F%L=64G(&%S(&%N(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M87)S94U)345(96%D97)S*"1H96%D97)S+"`D9&5C;V1E(#T@=')U92P@)&QO
M=V5R8V%S92`](&9A;'-E*0H@("`@>PH@("`@("`@("1H96%D97(@/2`G)SL*
M("`@("`@("`D;V(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("AE>'!L
M;V1E*")<;B(L("1H96%D97)S*2!A<R`D=F%L*2!["B`@("`@("`@("`@(&EF
M("@D9&5C;V1E*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@34E-13HZ9&5C
M;V1E*"1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"(O7BA;7EQS72LI7#HH+BHI+R(L("1V86PL("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`@("`@)'9A;"`]('1R:6TH)&UA=&-H97-;,ETI.PH@
M("`@("`@("`@("`@("`@)&AE861E<B`]("1M871C:&5S6S%=.PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1O8ELD:&5A9&5R72DI('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O8ELD:&5A9&5R72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1E;7`@/2`D;V);)&AE861E<ET["B`@
M("`@("`@("`@("`@("`@("`@("`@("1O8ELD:&5A9&5R72`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O8ELD:&5A9&5R75M=(#T@)'1E
M;7`["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("1O8ELD:&5A9&5R75M=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1V86P@/2`G("<@+B!T<FEM*"1V86PI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1H96%D97(I
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]B6R1H96%D97)=*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;V);)&AE861E
M<ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&5N9"@D;V);)&AE861E
M<ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`D;V);)&AE861E<EU;:V5Y
M*"1O8ELD:&5A9&5R72E=("X]("1V86P["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&]B6R1H96%D97)=
M("X]("1V86P["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;V);)&AE861E<ET@
M/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@*"1L;W=E<F-A<V4I(#\@87)R87E?8VAA
M;F=E7VME>5]C87-E*"1O8BP@0T%315],3U=%4BD@.B`D;V(["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U9I97=E<BYP:'``````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,S8S,#,`,3`U,34T,S$P-C$`,#(P-S(R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M34E-15]6:65W97(Z.B!C;&%S<R!P<F]V:61E<R!A;B!A8G-T<F%C=&5D(&EN
M=&5R9F%C92!T;PH@*B!R96YD97(@;W5T($U)344@='EP97,@:6YT;R!(5$U,
M(&9O<FUA="X@($ET(&1E<&5N9',@;VX@80H@*B!S970@;V8@34E-15]6:65W
M97)?*B!D<FEV97)S('=H:6-H(&AA;F1L92!T:&4@86-T=6%L(')E;F1E<FEN
M9RP*("H@86YD(&%L<V\@82!C;VYF:6=U<F%T:6]N(&9I;&4@=&\@;6%P($U)
M344@='EP97,@=&\@9')I=F5R<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<BYP:'`L=B`Q+C8T+C$P+C$P(#(P,#8O,#4O,#4@
M,#,Z,S`Z,C,@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI
M;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA
M9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R('L*
M"B`@("`O*BH*("`@("`J(%1H92!-24U%7U!A<G0@;V)J96-T('1O(')E;F1E
M<BX*("`@("`J"B`@("`@*B!`=F%R($U)345?4&%R=`H@("`@("HO"B`@("!V
M87(@)&UI;65?<&%R=#L*"B`@("`O*BH*("`@("`J($-O;F9I9W5R871I;VX@
M<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7V-O;F8@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@9V5T
M1')I=F5R(&-A8VAE+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?9')I=F5R0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@1F]R8V4@=FEE=VEN9R!O9B!A('!A<G0@:6YL:6YE+"!R96=A<F1L
M97-S(&]F('1H92!#;VYT96YT+41I<W!O<VET:6]N"B`@("`@*B!O9B!T:&4@
M34E-12!087)T+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]F;W)C96EN;&EN92`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@34E-15]6:65W97)?
M*B!O8FIE8W0@8F%S960@;VX@=&AE"B`@("`@*B!T>7!E(&]F($U)345?4&%R
M="!P87-S960@;VYT;R!I="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]0
M87)T("8D;6EM95]P87)T("!2969E<F5N8V4@=&\@82!-24U%7U!A<G0@;V)J
M96-T('=I=&@@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;F9O<FUA=&EO;B!T;R!B92!R96YD97)E9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&UI;65?='EP92`@("`@(%5S92!T:&ES($U)344@='EP92!I
M;G-T96%D(&]F('1H92!T>7!E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=&]R960@:6X@=&AE("1M:6UE7W!A<G0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!-24U%7U9I97=E<B`@5&AE($U)345?5FEE=V5R(&]B
M:F5C="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"8D;6EM95]P87)T+"`D;6EM95]T>7!E(#T@;G5L;"D*("`@
M('L*("`@("`@("`O*B!#:&5C:R!T:&%T('=E(&AA=F4@82!V86QI9"!-24U%
M7U!A<G0@;V)J96-T("HO"B`@("`@("`@:68@*"%I<U]A*"1M:6UE7W!A<G0L
M("=-24U%7U!A<G0G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`O*B!$971E<FUI;F4@9')I=F5R('1Y<&4@9G)O
M;2!T:&4@34E-12!T>7!E("HO"B`@("`@("`@:68@*&5M<'1Y*"1M:6UE7W1Y
M<&4I*2!["B`@("`@("`@("`@("1M:6UE7W1Y<&4@/2`D;6EM95]P87)T+3YG
M9714>7!E*"D["B`@("`@("`@("`@(&EF("AE;7!T>2@D;6EM95]T>7!E*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D=FEE=V5R(#T@9F%L<V4["@H@("`@("`@
M("\J(%-P87=N('1H92!R96QE=F%N="!D<FEV97(L(&%N9"!R971U<FX@:70@
M*&]R(&9A;'-E(&]N(&9A:6QU<F4I("HO"B`@("`@("`@:68@*"@D;V(@/2!-
M24U%7U9I97=E<CHZ:6YC;'5D941R:79E<B@D;6EM95]T>7!E*2DI('L*("`@
M("`@("`@("`@)&-L87-S(#T@*"@D;V(M/FUO9'5L92`]/2`G:&]R9&4G*2`_
M("<G(#H@)&]B+3YM;V1U;&4@+B`G7R<I("X@)TU)345?5FEE=V5R7R<@+B`D
M;V(M/F1R:79E<CL*("`@("`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA
M<W,I*2!["B`@("`@("`@("`@("`@("`D=FEE=V5R(#T@)FYE=R`D8VQA<W,H
M)&UI;65?<&%R="P@)$=,3T)!3%-;)VUI;65?9')I=F5R<R==6R1O8BT^;6]D
M=6QE75LD;V(M/F1R:79E<ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'9I97=E<CL*("`@('T*"B`@("`O*BH*("`@("`J
M($EN8VQU9&4@=&AE(&-O9&4@9F]R('1H92!R96QE=F%N="!D<FEV97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM95]T>7!E("!4:&4@0V]N
M=&5N="UT>7!E(&]F('1H92!P87)T('1O(&)E(')E;F1E<F5D+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1D0VQA<W,@(%-E92!-24U%7T1R:79E<CHZ9V5T
M1')I=F5R*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN8VQU9&5$<FEV97(H
M)&UI;65?='EP92D*("`@('L*("`@("`@("`O+R!43T1/.B!"0R`M('-W:71C
M:"!T;R!R97%U:7)E7V]N8V4@9F]R($AO<F1E(#0N,#L@9&]N)W0@;F5E9"`D
M8V]N9FEG.PH@("`@("`@("\O("`@("`@(&1O;B=T(&YE960@=&\@;6%K92!S
M=7)E('1H92`R('9A<FEA8FQE<R!A<F4@=6YS970N"B`@("`@("`@<W1A=&EC
M("1C;VYF:6<@/2!F86QS93L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*
M("`@("`@("`D87!P(#T@)')E9VES=')Y+3YG971!<'`H*3L*"B`@("`@("`@
M:68@*"$D8V]N9FEG*2!["B`@("`@("`@("`@("1'3$]"04Q36R=M:6UE7V1R
M:79E<G,G72`]("1'3$]"04Q36R=M:6UE7V1R:79E<G-?;6%P)UT@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=F:6QE
M<F]O="<L("=H;W)D92<I("X@)R]C;VYF:6<O;6EM95]D<FEV97)S+G!H<"<[
M"B`@("`@("`@("`@(&EF("@D87!P("$]("=H;W)D92<I('L*("`@("`@("`@
M("`@("`@("1B87-E(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P
M<"D["B`@("`@("`@("`@("`@("!I9B`H:7-?<F5A9&%B;&4H)&)A<V4@+B`G
M+V-O;F9I9R]M:6UE7V1R:79E<G,N<&AP)RDI('L*("`@("`@("`@("`@("`@
M("`@("!R97%U:7)E("1B87-E("X@)R]C;VYF:6<O;6EM95]D<FEV97)S+G!H
M<"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)$=,3T)!3%-;)VUI;65?9')I=F5R<R==(#T@)&UI;65?9')I=F5R<SL*
M("`@("`@("`@("`@)$=,3T)!3%-;)VUI;65?9')I=F5R<U]M87`G72`]("1M
M:6UE7V1R:79E<G-?;6%P.PH@("`@("`@("`@("`D8V]N9FEG(#T@=')U93L*
M("`@("`@("!]"@H@("`@("`@("\J($9I9W5R92!T:&4@8V]R<F5C="!D<FEV
M97(@9F]R('1H:7,@34E-12!T>7!E+B!)9B!T:&5R92!I<R!N;PH@("`@("`@
M("`@(&%P<&QI8V%T:6]N+7-P96-I9FEC(&UO9'5L92P@82!G96YE<F%L($AO
M<F1E(&]N92!W:6QL(&%T=&5M<'0@=&\*("`@("`@("`@("!B92!U<V5D+B`J
M+PH@("`@("`@(&EF("@H)&]B(#T@34E-15]6:65W97(Z.F=E=$1R:79E<B@D
M;6EM95]T>7!E+"`D<F5G:7-T<GDM/F=E=$%P<"@I*2DI('L*("`@("`@("`@
M("`@+RH@26YC;'5D92!T:&4@8VQA<W,N("HO"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92!-24U%7U9I97=E<CHZ<F5S;VQV941R:79E<B@D;V(M/F1R:79E
M<BP@)&]B+3YM;V1U;&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O
M8CL*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R(&9O<B!-24U%
M7U9I97=E<@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE
M7W!A<G0@(%)E9F5R96YC92!T;R!A($U)345?4&%R="!O8FIE8W0@=VET:"!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN9F]R
M;6%T:6]N('1O(&)E(')E;F1E<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!-
M24U%7U9I97=E<B@F)&UI;65?<&%R="P@)&-O;F8@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1T:&ES+3YM:6UE7W!A<G0@/2`F)&UI;65?<&%R=#L*("`@
M("`@("`D=&AI<RT^7V-O;F8@/2`D8V]N9CL*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@=&AE($U)345?4&%R="!O8FIE8W0@9F]R('1H92!C;&%S<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!2
M969E<F5N8V4@=&\@82!-24U%7U!A<G0@;V)J96-T('=I=&@@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;B!T
M;R!B92!R96YD97)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T34E-15!A
M<G0H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@)'1H:7,M/FUI;65?<&%R
M="`]("8D;6EM95]P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!-24U%('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N("!4:&ES
M(&-A;B!B90H@("`@("H@;W9E<G)I9&1E;B!B>2!T:&4@:6YD:79I9'5A;"!D
M<FEV97)S+"!D97!E;F1I;F<@;VX@=VAA="!F;W)M870*("`@("`J('1H97D@
M;W5T<'5T(&EN+B!">2!D969A=6QT+"!I="!P87-S97,@=&AR;W5G:"!T:&4@
M34E-12!T>7!E(&]F"B`@("`@*B!T:&4@;V)J96-T+"!O<B!R97!L86-E<R!C
M=7-T;VT@97AT96YS:6]N('1Y<&5S('=I=&@*("`@("`J("=T97AT+W!L86EN
M)R!T;R!L970@=&AE(&)R;W=S97(@9&\@82!B97-T+6=U97-S(')E;F1E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@34E-12UT>7!E(&]F('1H
M92!O=71P=70@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP
M92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM:6UE7W!A<G0M/F=E=%!R
M:6UA<GE4>7!E*"D@/3T@)W@M97AT96YS:6]N)RD@>PH@("`@("`@("`@("!R
M971U<FX@)W1E>'0O<&QA:6XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;6EM95]P87)T+3YG9714>7!E*'1R=64I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<F5N
M9&5R960@=F5R<VEO;B!O9B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J(%-H
M;W5L9"!B92!O=F5R<FED9&5N(&)Y(&EN9&EV:61U86P@9')I=F5R<R!T;R!P
M97)F;W)M(&-U<W1O;2!T87-K<RX*("`@("`J(%1H92`D;6EM95]P87)T(&-L
M87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I;VX@=&\@<F5N9&5R+`H@
M("`@("H@96YC87!S=6QA=&5D(&EN(&$@34E-15]087)T(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M<R`@06YY(&]P=&EO;F%L
M('!A<F%M971E<G,@=&AI<R!D<FEV97(@;F5E9',@870*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!R=6YT:6UE+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!296YD97)E9"!V97)S:6]N(&]F('1H92!O8FIE8W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N
M=',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T97AT+VAT;6P@
M;W5T<'5T('5S960@87,@86QT97)N871I=F4@;W5T<'5T('=H96X@=&AE(&9U
M;&QY"B`@("`@*B!R96YD97)E9"!O8FIE8W0@8V%N;F]T("AO<B!S:&]U;&0@
M;F]T*2!B92!D:7-P;&%Y960N("!&;W(@97AA;7!L92P*("`@("`J('1H:7,@
M9G5N8W1I;VX@<VAO=6QD(&)E('5S960@9F]R($U)344@871T86-H;65N=',@
M=&AA="!C86YN;W0@8F4*("`@("`J('9I97=E9"!I;FQI;F4L('=H97)E('1H
M92!U<V5R(&UA>2!B92!G:79E;B!O<'1I;VYS(&]N(&AO=R!T;R!V:65W"B`@
M("`@*B!T:&4@871T86-H;65N="X*("`@("`J(%-H;W5L9"!B92!O=F5R<FED
M9&5N(&)Y(&EN9&EV:61U86P@9')I=F5R<R!T;R!P97)F;W)M(&-U<W1O;2!T
M87-K<RX*("`@("`J(%1H92`D;6EM95]P87)T(&-L87-S('9A<FEA8FQE(&AA
M<R!T:&4@:6YF;W)M871I;VX@=&\@<F5N9&5R+`H@("`@("H@96YC87!S=6QA
M=&5D(&EN(&$@34E-15]087)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)'!A<F%M<R`@06YY(&]P=&EO;F%L('!A<F%M971E<G,@=&AI
M<R!D<FEV97(@;F5E9',@870*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!R=6YT:6UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!497AT
M+VAT;6P@<F5N9&5R960@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<D%T=&%C:&UE;G1);F9O*"D*("`@('L*("`@('T*"B`@("`O
M*BH*("`@("`J($-A;B!T:&ES(&1R:79E<B!R96YD97(@=&AE('1H92!D871A
M(&EN;&EN93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AE(&1R:79E<B!C86X@9&ES<&QA>2!I;FQI;F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-A;D1I<W!L87E);FQI;F4H*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^9V5T0V]N9FEG4&%R86TH)VEN;&EN92<I*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!':79E;B!A(&1R:79E<B!A;F0@86X@87!P;&EC871I;VXL('1H:7,@<F5T
M=7)N<R!T:&4@9G5L;'D*("`@("`J('%U86QI9FEE9"!F:6QE<WES=&5M('!A
M=&@@=&\@=&AE(&1R:79E<B!S;W5R8V4@9FEL92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D<FEV97(@($1R:79E<B!N86UE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D87!P("`@("!!<'!L:6-A=&EO;B!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!&:6QE<WES=&5M('!A=&@@;V8@=&AE
M(&1R:79E<B]A<'!L:6-A=&EO;B!Q=65R:65D+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R97-O;'9E1')I=F5R*"1D<FEV97(@/2`G9&5F875L="<L("1A<'`@
M/2`G:&]R9&4G*0H@("`@>PH@("`@("`@(&EF("@D87!P(#T]("=H;W)D92<I
M('L*("`@("`@("`@("`@<F5T=7)N(&1I<FYA;64H7U]&24Q%7U\I("X@)R]6
M:65W97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YA<'!L
M:6-A=&EO;G-;)&%P<%U;)V9I;&5R;V]T)UT@+B`G+VQI8B]-24U%+U9I97=E
M<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!':79E;B!A;B!I;G!U="!-24U%('1Y<&4@86YD(&$@;6]D
M=6QE(&YA;64L('1H:7,@9G5N8W1I;VX*("`@("`J(')E<V]L=F5S(&ET(&EN
M=&\@82!S<&5C:69I8R!O=71P=70@9')I=F5R('=H:6-H(&-A;B!H86YD;&4@
M:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM951Y<&4@($U)
M344@='EP92!T;R!R97-O;'9E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D
M=6QE("`@($UO9'5L92!I;B!W:&EC:"!T;R!S96%R8V@@9F]R('1H92!D<FEV
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@3V)J96-T('=I
M=&@@=&AE(&9O;&QO=VEN9R!I=&5M<SH*("`@("`J(#QP<F4^"B`@("`@*B`G
M9')I=F5R)R`@+2T@($YA;64@;V8@9')I=F5R("AE+F<N("=E;G-C<FEP="<I
M"B`@("`@*B`G97AA8W0G("`@+2T@(%=A<R!T:&4@9')I=F5R(&%N9"!E>&%C
M="!M871C:#\@*'1R=64O9F%L<V4I"B`@("`@*B`G;6]D=6QE)R`@+2T@(%1H
M92!M;V1U;&4@8V]N=&%I;FEN9R!D<FEV97(@*&4N9RX@)VAO<F1E)RD*("`@
M("`J(#PO<')E/@H@("`@("H@4F5T=7)N<R!F86QS92!I9B!D<FEV97(@8V]U
M;&0@;F]T(&)E(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$<FEV
M97(H)&UI;654>7!E+"`D;6]D=6QE(#T@)VAO<F1E)RD*("`@('L*("`@("`@
M("!G;&]B86P@)&UI;65?9')I=F5R<RP@)&UI;65?9')I=F5R<U]M87`["@H@
M("`@("`@("1C86-H94YA;64@/2`D;6EM951Y<&4@+B`G?"<@+B`D;6]D=6QE
M.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M/E]D
M<FEV97)#86-H95LD8V%C:&5.86UE72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9')I=F5R0V%C:&5;)&-A8VAE3F%M95T["B`@("`@("`@?0H*
M("`@("`@("`D9')I=F5R(#T@)R<["B`@("`@("`@)&5X86-T1')I=F5R(#T@
M9F%L<V4["@H@("`@("`@(&QI<W0H)'!R:6UA<GE?='EP92P@*2`](&5X<&QO
M9&4H)R\G+"`D;6EM951Y<&4L(#(I.PH@("`@("`@("1A;&Q3=6(@/2`D<')I
M;6%R>5]T>7!E("X@)R\J)SL*"B`@("`@("`@+RH@268@=&AE(&UO9'5L92!D
M;V5S;B=T(&5X:7-T(&EN("1M:6UE7V1R:79E<G-?;6%P+"!C:&5C:R!F;W(*
M("`@("`@("`@("!(;W)D92!V:65W97)S+B`J+PH@("`@("`@(&EF("@A:7-S
M970H)&UI;65?9')I=F5R<U]M87!;)&UO9'5L95TI("8F("1M;V1U;&4@(3T@
M)VAO<F1E)RD@>PH@("`@("`@("`@("!R971U<FX@34E-15]6:65W97(Z.F=E
M=$1R:79E<B@D;6EM951Y<&4L("=H;W)D92<I.PH@("`@("`@('T*"B`@("`@
M("`@)&1R(#T@)B1M:6UE7V1R:79E<G-;)&UO9'5L95T["B`@("`@("`@)&UA
M<"`]("8D;6EM95]D<FEV97)S7VUA<%LD;6]D=6QE73L*"B`@("`@("`@+RH@
M268@86X@;W9E<G)I9&4@97AI<W1S(&9O<B!T:&ES($U)344@='EP92P@=&AE
M;B!U<V4@=&AA="`J+PH@("`@("`@(&EF("AI<W-E="@D;6%P6R=O=F5R<FED
M97,G75LD;6EM951Y<&5=*2D@>PH@("`@("`@("`@("`D9')I=F5R(#T@)&UA
M<%LG;W9E<G)I9&5S)UU;)&UI;654>7!E73L*("`@("`@("`@("`@)&5X86-T
M1')I=F5R(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)&UA<%LG
M;W9E<G)I9&5S)UU;)&%L;%-U8ETI*2!["B`@("`@("`@("`@("1D<FEV97(@
M/2`D;6%P6R=O=F5R<FED97,G75LD86QL4W5B73L*("`@("`@("`@("`@)&5X
M86-T1')I=F5R(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)&UA
M<%LG<F5G:7-T97)E9"==*2D@>PH@("`@("`@("`@("`O*B!)=&5R871E('1H
M<F]U9V@@=&AE(&QI<W0@;V8@<F5G:7-T97)E9"!D<FEV97)S+"!A;F0@<V5E
M(&EF"B`@("`@("`@("`@("`@('1H:7,@34E-12!T>7!E(&5X:7-T<R!I;B!T
M:&4@34E-12!T>7!E<R!T:&%T('1H97D@8VQA:6T@=&\*("`@("`@("`@("`@
M("`@:&%N9&QE+B!)9B!T:&4@9')I=F5R(&AA;F1L97,@:70L('1H96X@87-S
M:6=N(&ET(&%S('1H90H@("`@("`@("`@("`@("!R96YD97)I;F<@9')I=F5R
M+B!)9B!W92!F:6YD(&$@9V5N97)I8R!H86YD;&5R+"!K965P(&ET97)A=&EN
M9PH@("`@("`@("`@("`@("!T;R!S964@:68@=V4@8V%N(&9I;F0@82!S<&5C
M:69I8R!H86YD;&5R+B`J+PH@("`@("`@("`@("!F;W)E86-H("@D;6%P6R=R
M96=I<W1E<F5D)UT@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&EN
M7V%R<F%Y*"1M:6UE5'EP92P@)&1R6R1V86Q=6R=H86YD;&5S)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&1R:79E<B`]("1V86P["B`@("`@("`@("`@
M("`@("`@("`@)&5X86-T1')I=F5R(#T@=')U93L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@96QS96EF("AI;E]A<G)A
M>2@D86QL4W5B+"`D9');)'9A;%U;)VAA;F1L97,G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D9')I=F5R(#T@)'9A;#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@=&AI<R!I
M<R!A;B!A<'!L:6-A=&EO;B!S<&5C:69I8R!M;V1U;&4L(&%N9"!A;B!E>&%C
M="!M871C:"!W87,*("`@("`@("`@("!N;W0@9F]U;F0L('-E87)C:"!F;W(@
M82!(;W)D92UW:61E('-P96-I9FEC(&1R:79E<BX@3VYL>2!U<V4@=&AE"B`@
M("`@("`@("`@2&]R9&4M<W!E8VEF:6,@9')I=F5R(&EF(&ET(&ES($Y/5"!T
M:&4@)V1E9F%U;'0G(&1R:79E<B!!3D0@=&AE"B`@("`@("`@("`@2&]R9&4@
M9')I=F5R(&ES(&%N(&5X86-T(&UA=&-H+B`J+PH@("`@("`@(&EF("@A)&5X
M86-T1')I=F5R("8F("1M;V1U;&4@(3T@)VAO<F1E)RD@>PH@("`@("`@("`@
M("`D;V(@/2!-24U%7U9I97=E<CHZ9V5T1')I=F5R*"1M:6UE5'EP92P@)VAO
M<F1E)RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D9')I=F5R*2!\?`H@("`@
M("`@("`@("`@("`@*"@D;V(M/F1R:79E<B`A/2`G9&5F875L="<I("8F("1O
M8BT^97AA8W0I*2!["B`@("`@("`@("`@("`@("`D9')I=F5R(#T@)&]B+3YD
M<FEV97(["B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)VAO<F1E)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE("=D969A
M=6QT)R!D<FEV97(@97AI<W1S(&EN('1H:7,@;6]D=6QE+"!F86QL(&)A8VL@
M=&\@=&AA="X@*B\*("`@("`@("!I9B`H96UP='DH)&1R:79E<BD@)B8*("`@
M("`@("`@("`@0&ES7V9I;&4H34E-15]6:65W97(Z.G)E<V]L=F5$<FEV97(H
M)V1E9F%U;'0G+"`D;6]D=6QE*2DI('L*("`@("`@("`@("`@)&1R:79E<B`]
M("=D969A=6QT)SL*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D9')I
M=F5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1R:79E<D-A8VAE6R1C86-H
M94YA;65=(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(@/2!N97<@<W1D0VQA<W,[
M"B`@("`@("`@("`@("1O8BT^9')I=F5R(#T@)&1R:79E<CL*("`@("`@("`@
M("`@)&]B+3YE>&%C="`@/2`D97AA8W1$<FEV97(["B`@("`@("`@("`@("1O
M8BT^;6]D=6QE(#T@)&UO9'5L93L*("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D<FEV97)#86-H95LD
M8V%C:&5.86UE72`]("1O8CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)&]B.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=I
M=F5N(&$@34E-12!T>7!E+"!T:&ES(&9U;F-T:6]N('=I;&P@<F5T=7)N(&%N
M(&%P<')O<')I871E"B`@("`@*B!I8V]N+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&UI;654>7!E("!4:&4@34E-12!T>7!E('1H870@=V4@;F5E
M9"!A;B!I8V]N(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(%523"!T;R!T:&4@87!P<F]P<FEA=&4@:6-O;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T26-O;B@D;6EM951Y<&4I"B`@("!["B`@("`@("`@)&%P
M<"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H*3L*("`@("`@("`D
M;V(@/2!-24U%7U9I97=E<CHZ7V=E=$EC;VXH)&UI;654>7!E+"`D87!P*3L*
M"B`@("`@("`@:68@*"1O8B`]/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H
M)&%P<"`A/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`D;V)(;W)D92`]
M($U)345?5FEE=V5R.CI?9V5T26-O;B@D;6EM951Y<&4L("=H;W)D92<I.PH@
M("`@("`@("`@("`@("`@<F5T=7)N("@D;V)(;W)D92`]/3T@;G5L;"D@/R!N
M=6QL(#H@)&]B2&]R9&4M/G5R;#L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"@D;V(M/FUA=&-H("$]/2`P*2`F)B`H)&%P<"`A/2`G
M:&]R9&4G*2D@>PH@("`@("`@("`@("`D;V)(;W)D92`]($U)345?5FEE=V5R
M.CI?9V5T26-O;B@D;6EM951Y<&4L("=H;W)D92<I.PH@("`@("`@("`@("!I
M9B`H)&]B+3YM871C:"`A/3T@;G5L;"`F)B`D;V(M/FUA=&-H(#P]("1O8DAO
M<F1E+3YM871C:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1O8BT^=7)L
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1O8DAO<F1E+3YU<FP["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)&]B+3YU<FP["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:6YP=70@34E-12!T>7!E(&%N
M9"!M;V1U;&4L('1H:7,@9G5N8W1I;VX@<F5T=7)N<R!T:&4*("`@("`J(%52
M3"!O9B!A;B!I8V]N('1H870@8V%N(&)E(&%S<V]C:6%T960@=VET:"!I=`H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&UI;654>7!E("!-24U%('1Y<&4@=&\@9V5T('1H92!I
M8V]N(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L87-S("!U<FPZ
M("`@55),('1O(&%N(&EC;VXL(&]R(&YU;&P@:68@;F]N90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O=6QD(&)E(&9O=6YD+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@97AA8W0Z($AO=R!E>&%C="!T:&4@;6%T8V@@
M:7,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@,"`]/B`G97AA
M8W0G+"`Q(#T^("=P<FEM87)Y)RP*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`R(#T^("=D<FEV97(G+"`S(#T^("=D969A=6QT)PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&YU;&PN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]G971)8V]N*"1M:6UE5'EP92P@)&UO9'5L92`]("=H;W)D
M92<I"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@
M("`@("1O8B`]($U)345?5FEE=V5R.CIG971$<FEV97(H)&UI;654>7!E+"`D
M;6]D=6QE*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D;V(I*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2AF86QS92P@;G5L;"D["B`@("`@("`@?0H@
M("`@("`@("1D<FEV97(@/2`D;V(M/F1R:79E<CL*"B`@("`@("`@;&ES="@D
M<')I;6%R>5]T>7!E+"D@/2!E>'!L;V1E*"<O)RP@)&UI;654>7!E+"`R*3L*
M("`@("`@("`D86QL4W5B(#T@)'!R:6UA<GE?='EP92`N("<O*B<["B`@("`@
M("`@)')E=$]B(#T@)FYE=R!S=&1#;&%S<R@I.PH@("`@("`@("1R971/8BT^
M;6%T8V@@/2!N=6QL.PH@("`@("`@("1R971/8BT^=7)L(#T@;G5L;#L*"B`@
M("`@("`@+RH@268@=&AE(&UO9'5L92!D;V5S;B=T(&5X:7-T(&EN("1M:6UE
M7V1R:79E<G,L(')E='5R;B!N;W<N("HO"B`@("`@("`@:68@*"%I<W-E="@D
M;6EM95]D<FEV97)S6R1M;V1U;&5=*2D@>PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("`@("`@)&1R(#T@)B1M:6UE7V1R:79E<G-;
M)&UO9'5L95T["@H@("`@("`@("\J($EF(&$@<W!E8VEF:6,@:6-O;B!F;W(@
M=&AI<R!D<FEV97(@86YD(&UI;65T>7!E(&ES(&1E9FEN960L"B`@("`@("`@
M("`@=&AE;B!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H:7-S970H)&1R6R1D
M<FEV97)=6R=I8V]N<R==*2D@>PH@("`@("`@("`@("`D:6-O;F1R(#T@)B1M
M:6UE7V1R:79E<G-;)&UO9'5L95U;)&1R:79E<EU;)VEC;VYS)UT["B`@("`@
M("`@("`@("1I8V]N3&ES="`](&%R<F%Y*"1M:6UE5'EP92`]/B`P+"`D86QL
M4W5B(#T^(#$L("=D969A=6QT)R`]/B`R*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)&EC;VY,:7-T(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1I8V]N9');)&ME>5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E=$]B+3YU<FP@/2`D:6-O;F1R6R1K97E=.PH@("`@("`@("`@
M("`@("`@("`@("1R971/8BT^;6%T8V@@/2`D=F%L.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!4<GD@=&\@=7-E(&$@9&5F875L="!I
M8V]N(&EF(&YO;F4@86QR96%D>2!O8G1A:6YE9"X@*B\*("`@("`@("!I9B`H
M:7-?;G5L;"@D<F5T3V(M/G5R;"D@)B8@:7-S970H)&1R6R=D969A=6QT)UTI
M*2!["B`@("`@("`@("`@("1D<B`]("8D;6EM95]D<FEV97)S6R1M;V1U;&5=
M6R=D969A=6QT)UT["B`@("`@("`@("`@(&EF("AI<W-E="@D9');)VEC;VYS
M)UU;)V1E9F%U;'0G72DI('L*("`@("`@("`@("`@("`@("1R971/8BT^=7)L
M(#T@)&1R6R=D969A=6QT)UU;)VEC;VYS)UU;)V1E9F%U;'0G73L*("`@("`@
M("`@("`@("`@("1R971/8BT^;6%T8V@@/2`S.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)')E=$]B+3YU<FPI*2![
M"B`@("`@("`@("`@("1R971/8BT^=7)L(#T@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E=$EM86=E1&ER*"1M;V1U;&4I("X@)R]M:6UE+R<@+B`D<F5T3V(M
M/G5R;#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T3V(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R86-T97(@<V5T('5S
M960@9F]R('1H92!6:65W97(N"B`@("`@*B!3:&]U;&0@8F4@;W9E<G)I9&1E
M;B!B>2!I;F1I=FED=6%L(&1R:79E<G,@=&\@<&5R9F]R;2!C=7-T;VT@=&%S
M:W,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C:&%R86-T
M97(@<V5T('5S960@8GD@=&AI<R!6:65W97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$-H87)S970H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M;6EM95]P87)T+3YG971#:&%R<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@82!C;VYF:6=U<F%T:6]N('!A<F%M971E<B!F;W(@=&AE(&-U
M<G)E;G0@=FEE=V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M<F%M("!4:&4@<&%R86UE=&5R(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE('9A;'5E(&]F('1H92!P87)A;65T97([(')E='5R;G,@
M;G5L;"!I9B!T:&4@<&%R86UE=&5R"B`@("`@*B`@("`@("`@("`@("`@("!D
M;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYF:6=0
M87)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T=7)N("AI<W-E="@D=&AI
M<RT^7V-O;F9;)'!A<F%M72DI(#\@)'1H:7,M/E]C;VYF6R1P87)A;5T@.B!N
M=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4VAO=6QD('=E(&9O<F-E('9I
M97=I;F<@;V8@=&AI<R!-24U%(%!A<G0@:6YL:6YE+"!R96=A<F1L97-S(&]F
M('1H90H@("`@("H@0V]N=&5N="U$:7-P;W-I=&EO;B!O9B!T:&4@34E-12!0
M87)T/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@1F]R8V4@=FEE
M=VEN9R!I;FQI;F4_"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<F-E26YL:6YE
M5FEE=R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9F]R8V5I;FQI
M;F4["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<```````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(T,C0Q`#$P-3$U-#,Q,#8Q`#`R,3`T,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]087)T+G!H<"<["@HO*BH*
M("H@5&AE($U)345?365S<V%G93HZ(&-L87-S('!R;W9I9&5S(&UE=&AO9',@
M9F]R(&-R96%T:6YG(&%N9"!M86YI<'5L871I;F<*("H@34E-12!E;6%I;"!M
M97-S86=E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP+'8@,2XW-BXQ,"XQ,B`R,#`V+S`Q+S`Q(#(Q.C(X.C(T(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@
M($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PIC;&%S<R!-
M24U%7TUE<W-A9V4@97AT96YD<R!-24U%7U!A<G0@>PH*("`@("\J*@H@("`@
M("H@2&%S('1H92!M97-S86=E(&)E96X@<&%R<V5D('9I82!B=6EL9$UE<W-A
M9V4H*3\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?8G5I;&0@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!S97)V
M97(@=&\@9&5F875L="!U;G%U86QI9FEE9"!A9&1R97-S97,@=&\N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9&5F875L
M=%-E<G9E<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B`M
M(&-R96%T97,@82!N97<@34E-12!E;6%I;"!M97-S86=E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'1397)V97(@(%1H92!S97)V97(@
M=&\@9&5F875L="!U;G%U86QI9FEE9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@861D<F5S<V5S('1O+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!-24U%7TUE<W-A9V4H)&1E9F%U;'1397)V97(@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<U]N=6QL*"1D969A=6QT4V5R=F5R*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V1E9F%U;'1397)V97(@/2`D7U-%4E9%4ELG4T52
M5D527TY!344G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^7V1E9F%U;'1397)V97(@/2`D9&5F875L=%-E<G9E<CL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!-24U%7TUE<W-A9V4@
M;V)J96-T(&9R;VT@82!-24U%7U!A<G0@;V)J96-T+@H@("`@("H@5&AI<R!F
M=6YC=&EO;B!C86X@8F4@8V%L;&5D('-T871I8V%L;'D@=FEA.@H@("`@("H@
M("`@34E-15]-97-S86=E.CIC;VYV97)T34E-15!A<G0H*3L*("`@("`J"B`@
M("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!4:&4@34E-15]0
M87)T(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)'-E<G9E<B`@("`@
M("`@(%1H92!S97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<F5S<V5S('1O+@H@
M("`@("H*("`@("`J($!R971U<FX@34E-15]-97-S86=E("!4:&4@;F5W($U)
M345?365S<V%G92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9C;VYV
M97)T34E-15!A<G0H)B1M:6UE7W!A<G0L("1S97)V97(@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A)&UI;65?<&%R="T^9V5T34E-14ED*"DI('L*("`@
M("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*#$I.PH@("`@("`@('T*
M"B`@("`@("`@)&UI;65?;65S<V%G92`]("9N97<@34E-15]-97-S86=E*"1S
M97)V97(I.PH@("`@("`@("1M:6UE7VUE<W-A9V4M/F%D9%!A<G0H)&UI;65?
M<&%R="D["B`@("`@("`@)&UI;65?;65S<V%G92T^8G5I;&1-97-S86=E*"D[
M"@H@("`@("`@(')E='5R;B`D;6EM95]M97-S86=E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5N9',@=&AI<R!M97-S86=E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&5M86EL("`@(%1H92!A9&1R97-S(&QI<W0@=&\@<V5N
M9"!T;RX*("`@("`J($!P87)A;2!M:7AE9"`F)&AE861E<G,@(%1H92!-24U%
M7TAE861E<G,@;V)J96-T(&AO;&1I;F<@=&AI<R!M97-S86=E)W,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<G,L(&]R(&$@:&%S:"!W
M:71H(&AE861E<BT^=F%L=64@;6%P<&EN9W,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D<FEV97(@("!4:&4@36%I;"!D<FEV97(@=&\@=7-E("AS:6YC92!(
M;W)D92`S+C`N-"DN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("!!
M;GD@<&%R86UE=&5R<R!N96-E<W-A<GD@9F]R('1H92!-86EL(&1R:79E<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@*'-I;F-E($AO<F1E(#,N
M,"XT*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E;F0H)&5M86EL+"`F)&AE861E<G,L("1D<FEV97(@/2!N=6QL+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8[
M"B`@("`@("`@<W1A=&EC("1M86EL97(["@H@("`@("`@(&EF("@A:7-S970H
M)&UA:6QE<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+G!H
M<"<["B`@("`@("`@("`@(&EF("@A:7-S970H)&1R:79E<BDI('L*("`@("`@
M("`@("`@("`@("1D<FEV97(@/2`D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G73L*
M("`@("`@("`@("`@("`@("1P87)A;7,@/2`D8V]N9ELG;6%I;&5R)UU;)W!A
M<F%M<R==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1M86EL97(@/2!-
M86EL.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@
M("`@("`@)&US9R`]("1T:&ES+3YT;U-T<FEN9R@I.PH@("`@("`@(&EF("AI
M<U]O8FIE8W0H)&AE861E<G,I*2!["B`@("`@("`@("`@("1H96%D97)!<G)A
M>2`]("1T:&ES+3YE;F-O9&4H)&AE861E<G,M/G1O07)R87DH*2P@)'1H:7,M
M/F=E=$-H87)S970H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&AE861E<D%R<F%Y(#T@)'1H:7,M/F5N8V]D92@D:&5A9&5R<RP@)'1H:7,M
M/F=E=$-H87)S970H*2D["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U
M<F4@=&AE(&UE<W-A9V4@:&%S(&$@=')A:6QI;F<@;F5W;&EN92X@*B\*("`@
M("`@("!I9B`H<W5B<W1R*"1M<V<L("TQ*2`A/2`B7&XB*2!["B`@("`@("`@
M("`@("1M<V<@+CT@(EQN(CL*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@
M/2`D;6%I;&5R+3YS96YD*$U)344Z.F5N8V]D94%D9')E<W,H)&5M86EL*2P@
M)&AE861E<D%R<F%Y+"`D;7-G*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2`F)@H@("`@("`@("`@("`D8V]N9ELG;6%I;&5R
M)UU;)W1Y<&4G72`]/2`G<V5N9&UA:6PG*2!["B`@("`@("`@("`@("\O($EN
M=&5R<')E="!R971U<FX@=F%L=65S(&%S(&1E9FEN960@:6X@+W5S<B]I;F-L
M=61E+W-Y<V5X:71S+F@*("`@("`@("`@("`@<W=I=&-H("@D<F5S=6QT+3YG
M971#;V1E*"DI('L*("`@("`@("`@("`@8V%S92`V-#H@+R\@15A?55-!1T4*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(I("X@)R`H-C0I)SL*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`V-3H@+R\@15A?1$%4
M04524@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@
M7R@B9&%T82!F;W)M870@97)R;W(B*2`N("<@*#8U*2<["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-C8Z("\O($587TY/24Y0
M550*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H
M(F-A;FYO="!O<&5N(&EN<'5T(BD@+B`G("@V-BDG.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8W.B`O+R!%6%].3U5315(*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F%D
M9')E<W-E92!U;FMN;W=N(BD@+B`G("@V-RDG.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#8X.B`O+R!%6%].3TA/4U0*("`@
M("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(FAO<W0@
M;F%M92!U;FMN;W=N(BD@+B`G("@V."DG.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E(#8Y.B`O+R!%6%]53D%604E,04),10H@
M("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B<V5R
M=FEC92!U;F%V86EL86)L92(I("X@)R`H-CDI)SL*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W,#H@+R\@15A?4T]&5%=!4D4*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(BD@+B`G("@W,"DG.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<Q.B`O+R!%6%]/4T52
M4@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B
M<WES=&5M(&5R<F]R(BD@+B`G("@W,2DG.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E(#<R.B`O+R!%6%]/4T9)3$4*("`@("`@
M("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<B*2`N("<@*#<R*2<["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-S,Z("\O($587T-!3E1#
M4D5!5`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@
M7R@B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(I("X@)R`H-S,I)SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W-#H@+R\@
M15A?24]%4E(*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@
M)R`N(%\H(FEN<'5T+V]U='!U="!E<G)O<B(I("X@)R`H-S0I)SL*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W-3H@+R\@15A?
M5$5-4$9!24P*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@
M)R`N(%\H(G1E;7!O<F%R>2!F86EL=7)E(BD@+B`G("@W-2DG.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<V.B`O+R!%6%]0
M4D]43T-/3`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G
M("X@7R@B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(BD@+B`G("@W-BDG.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<W.B`O
M+R!%6%].3U!%4DT*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(G!E<FUI<W-I;VX@9&5N:65D(BD@+B`G("@W-RDG.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<X.B`O+R!%
M6%]#3TY&24<*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@
M)R`N(%\H(F-O;F9I9W5R871I;VX@97)R;W(B*2`N("<@*#<X*2<["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-SDZ("\O($58
M7TY/5$9/54Y$"B`@("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ
M("<@+B!?*")E;G1R>2!N;W0@9F]U;F0B*2`N("<@*#<Y*2<["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("`D97)R;W(@/2`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1A:V4@82!S970@;V8@:&5A9&5R<R!A;F0@;6%K92!S=7)E('1H
M97D@87)E(&5N8V]D960@<')O<&5R;'DN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1H96%D97)S("`@5&AE(&AE861E<G,@=&\@96YC;V1E+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@
M=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A<G)A
M>2!O9B!E;F-O9&5D(&AE861E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N
M8V]D92@D:&5A9&5R<RP@)&-H87)S970I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]-24U%+G!H<"<["@H@("`@("`@("1A9&1R97-S2V5Y
M<R`](&%R<F%Y*"=4;R<L("=#8R<L("="8V,G+"`G1G)O;2<I.PH@("`@("`@
M(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("!I9B`H:6Y?87)R87DH)&ME>2P@)&%D9')E<W-+97ES*2D@>PH@("`@
M("`@("`@("`@("`@)'1E>'0@/2!-24U%.CIE;F-O9&5!9&1R97-S*"1V86PL
M("1C:&%R<V5T+"`D=&AI<RT^7V1E9F%U;'1397)V97(I.PH@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)'1E>'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("`D=&5X="`]("1V86P["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&5X="`]
M($U)344Z.F5N8V]D92@D=F%L+"`D8VAA<G-E="D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&AE861E<G-;)&ME>5T@/2!-24U%.CIW<F%P2&5A9&5R
M<R@D:V5Y+"`D=&5X="P@)'1H:7,M/F=E=$5/3"@I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D:&5A9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9"!T:&4@<')O<&5R('-E="!O9B!-24U%(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92!T;R!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&AE861E<G,@(%1H92!H96%D97)S('1O(&%D9"!T:&4@34E-12!H96%D
M97)S('1O+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!F=6QL
M('-E="!O9B!H96%D97)S(&EN8VQU9&EN9R!-24U%(&AE861E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&AE861E<B@D:&5A9&5R<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@+RH@4&5R(%)&0R`R,#0U(%LT72P@=&AI<R!-55-4(&%P
M<&5A<B!I;B!T:&4@;65S<V%G92!H96%D97)S+B`J+PH@("`@("`@("1H96%D
M97)S6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH*("`@("`@("!I9B`H)'1H
M:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIH96%D
M97(H)&AE861E<G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YE;F-O9&4H)'1H:7,M/FAE861E<B@D:&5A9&5R<RDL("1T:&ES+3YG971#
M:&%R<V5T*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@96YT:7)E(&UE<W-A9V4@8V]N=&5N=',L(&EN8VQU9&EN9R!H
M96%D97)S+"!A<R!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&5N8V]D960L(&=E;F5R871E9"!M97-S86=E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3Y?8G5I;&0I('L*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ=&]3
M=')I;F<H9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YT;U-T<FEN9R@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($)U:6QD(&UE<W-A9V4@9G)O;2!C=7)R96YT(&-O;G1E;G1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!B=6EL9$UE<W-A9V4H*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7V)U:6QD*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V9L86=S6R=S9714>7!E
M)UTI*2!["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W!A<G1S*2`^
M(#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9714>7!E*"=M=6QT:7!A
M<G0O;6EX960G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\J($-O<'D@=&AE(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-I;F=L92!P
M87)T('1O('1H92!C=7)R96YT"B`@("`@("`@("`@("`@("`@("!B87-E('!A
M<G0N("HO"B`@("`@("`@("`@("`@("!I9B`H*"1O8E9A<G,@/2!G971?;V)J
M96-T7W9A<G,H<F5S970H)'1H:7,M/E]P87)T<RDI*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1O8E9A<G,@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@8G5I;&0@
M9FQA9R!N;W<N("HO"B`@("`@("`@)'1H:7,M/E]B=6EL9"`]('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&%L;"!-24U%('-U
M8G!A<G1S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y
M(&]F('1H92!-24U%7U!A<G0@<W5B<&%R=',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!A<G1S*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]B=6EL
M9"D@>PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIG971087)T<R@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YB=6EL9$UE<W-A
M9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971087)T<R@I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8F%S
M92!P87)T(&]F('1H92!M97-S86=E+B!4:&ES(&9U;F-T:6]N(&1O97,@3D]4
M"B`@("`@*B!R971U<FX@82!R969E<F5N8V4@=&\@;6%K92!S=7)E('1H870@
M=&AE('=H;VQE($U)345?365S<V%G90H@("`@("H@;V)J96-T(&ES;B=T(&%C
M8VED96YT86QL>2!M;V1I9FEE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)
M345?365S<V%G92`@5&AE(&)A<V4@34E-15]087)T(&]F('1H92!M97-S86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"87-E4&%R="@I"B`@("!["B`@
M("`@("`@)'1H:7,M/F)U:6QD365S<V%G92@I.PH@("`@("`@(')E='5R;B`D
M=&AI<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&$@<W!E8VEF
M:6,@34E-12!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("!4:&4@34E-15]087)T($E$('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="!R97%U97-T960L(&]R(&9A
M;'-E(&EF('1H92!P87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@9&]E
M<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!A<G0H)&ED
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V)U:6QD*2!["B`@("`@("`@
M("`@("1P87)T(#T@<&%R96YT.CIG971087)T*"1I9"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/F)U:6QD365S<V%G92@I.PH@("`@
M("`@("`@("`D<&%R="`]("1T:&ES+3YG971087)T*"1I9"D["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]A*"1P87)T+"`G34E-15]-97-S86=E)RDI('L*
M("`@("`@("`@("`@)&YE=W!A<G0@/2`F;F5W($U)345?4&%R="@I.PH@("`@
M("`@("`@("`D<VMI<"`](&%R<F%Y*"=?8G5I;&0G+"`G7V1E9F%U;'1397)V
M97(G*3L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<RAG971?;V)J
M96-T7W9A<G,H)'!A<G0I*2!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("`O
M*B!)9VYO<F4@;&]C86P@=F%R:6%B;&5S('1H870@87)E;B=T(&$@<&%R="!O
M9B!T:&4@;W)I9VEN86P*("`@("`@("`@("`@("`@("`J(&-L87-S+B`J+PH@
M("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D:V5Y+"`D<VMI<"DI('L*
M("`@("`@("`@("`@("`@("`@("`D;F5W<&%R="T^)&ME>2`]("8D<&%R="T^
M)&ME>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@)&YE=W!A<G0["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("1P87)T.PH@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+VUI;64N;6%P<&EN9RYP:'``````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3,S-#``,3`U,34T,S$P-C$`,#(R
M,#0R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@82!M87!P:6YG(&]F
M(&-O;6UO;B!F:6QE(&5X=&5N<VEO;G,@=&\*("H@34E-12!T>7!E<RX@270@
M:&%S(&)E96X@875T;VUA=&EC86QL>2!G96YE<F%T960@9G)O;2!T:&4*("H@
M:&]R9&4O<V-R:7!T<R]M:6UE7VUA<'!I;F<@9&ER96-T;W)Y+@H@*@H@*B!!
M3$P@8VAA;F=E<R!S:&]U;&0@8F4@;6%D92!T;R!H;W)D92]S8W)I<'1S+VUI
M;65?;6%P<&EN9R]M:6UE+G1Y<&5S+FAO<F1E"B`J(&]R(&5L<V4@=&AE>2!W
M:6QL(&)E(&QO<W0@=VAE;B!T:&ES(&9I;&4@:7,@<F5G96YE<F%T960N"B`J
M"B`J($%N>2!U;FMN;W=N(&9I;&4@97AT96YS:6]N<R!W:6QL(&%U=&]M871I
M8V%L;'D@8F4@;6%P<&5D('1O"B`J("=X+65X=&5N<VEO;B\\97AT/B<@=VAE
M<F4@/&5X=#X@:7,@=&AE('5N:VYO=VX@9FEL92!E>'1E;G-I;VXN"B`J"B`J
M($!P86-K86=E($AO<F1E7TU)344*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+VUI;64N;6%P<&EN9RYP:'`L=B`Q+C$Q+C(N,R`R,#`V+S`R
M+S$P(#$P.C,W.C,S(&IA;B!%>'`@)`H@*@H@*B!'96YE<F%T960Z(#`R+S$P
M+S`V(#`P.C$X.C0U(&)Y('-L=7-A<GH@;VX@8FEG=V]R;2YC=7)E8V%N=&DN
M;W)G"B`J+PHD;6EM95]E>'1E;G-I;VY?;6%P(#T@87)R87DH"B=?7TU!6%!%
M4DE/1%]?)R`]/B`G,2<L"B`@("`G,V1S)R`@("`@("`@("`@/3X@)VEM86=E
M+W@M,V1S)RP*("`@("="3$5.1"<@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UB;&5N9&5R)RP*("`@("=#)R`@("`@("`@("`@("`]/B`G=&5X="]X+6,K
M*W-R8R<L"B`@("`G0U-33"<@("`@("`@("`@/3X@)W1E>'0O8W-S)RP*("`@
M("=.4U8G("`@("`@("`@("`]/B`G=FED96\O>"UN<W8G+`H@("`@)U!!4C(G
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!A<C(G+`H@("`@)UA-)R`@
M("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G6B<@("`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M8V]M<')E<W,G+`H@("`@)V$G("`@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%R8VAI=F4G+`H@("`@)V%B=R<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%B:7=O<F0G+`H@("`@)V%B
M=RY#4D%32$5$)R`@(#T^("=A<'!L:6-A=&EO;B]X+6%B:7=O<F0G+`H@("`@
M)V%B=RYG>B<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%B:7=O<F0G+`H@
M("`@)V%C,R<@("`@("`@("`@(#T^("=A=61I;R]A8S,G+`H@("`@)V%D8B<@
M("`@("`@("`@(#T^("=T97AT+W@M861A<W)C)RP*("`@("=A9',G("`@("`@
M("`@("`]/B`G=&5X="]X+6%D87-R8R<L"B`@("`G869M)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UA9FTG+`H@("`@)V%G)R`@("`@("`@
M("`@(#T^("=I;6%G92]X+6%P<&QI>"UG<F%P:&EC<R<L"B`@("`G86DG("`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+VEL;'5S=')A=&]R)RP*("`@("=A
M:68G("`@("`@("`@("`]/B`G875D:6\O>"UA:69F)RP*("`@("=A:69C)R`@
M("`@("`@("`]/B`G875D:6\O>"UA:69F)RP*("`@("=A:69F)R`@("`@("`@
M("`]/B`G875D:6\O>"UA:69F)RP*("`@("=A;"<@("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UP97)L)RP*("`@("=A<FHG("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UA<FHG+`H@("`@)V%S)R`@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6%P<&QI>"US<')E861S:&5E="<L"B`@("`G87-C)R`@
M("`@("`@("`@/3X@)W1E>'0O<&QA:6XG+`H@("`@)V%S9B<@("`@("`@("`@
M(#T^("=V:61E;R]X+6US+6%S9B<L"B`@("`G87-P)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M87-P)RP*("`@("=A<W@G("`@("`@("`@("`]/B`G
M=FED96\O>"UM<RUA<V8G+`H@("`@)V%T;VTG("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]A=&]M*WAM;"<L"B`@("`G874G("`@("`@("`@("`@/3X@)V%U
M9&EO+V)A<VEC)RP*("`@("=A=FDG("`@("`@("`@("`]/B`G=FED96\O>"UM
M<W9I9&5O)RP*("`@("=A=R<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UA<'!L:7@M=V]R9"<L"B`@("`G8F%K)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M=')A<V@G+`H@("`@)V)C<&EO)R`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6)C<&EO)RP*("`@("=B9&8G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UF;VYT+6)D9B<L"B`@("`G8FEB)R`@("`@("`@("`@/3X@
M)W1E>'0O>"UB:6)T97@G+`H@("`@)V)I;B<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@)V)L96YD)R`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6)L96YD97(G+`H@("`@)V)L96YD97(G("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+6)L96YD97(G+`H@("`@)V)M<"<@("`@("`@
M("`@(#T^("=I;6%G92]B;7`G+`H@("`@)V)Z)R`@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6)Z:7`G+`H@("`@)V)Z,B<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6)Z:7`G+`H@("`@)V,G("`@("`@("`@("`@(#T^("=T
M97AT+W@M8W-R8R<L"B`@("`G8RLK)R`@("`@("`@("`@/3X@)W1E>'0O>"UC
M*RMS<F,G+`H@("`@)V-C)R`@("`@("`@("`@(#T^("=T97AT+W@M8RLK<W)C
M)RP*("`@("=C9&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UN971C
M9&8G+`H@("`@)V-D<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N
M8V]R96PM9')A=R<L"B`@("`G8V5R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M>#4P.2UC82UC97)T)RP*("`@("=C97)T)R`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UX-3`Y+6-A+6-E<G0G+`H@("`@)V-G:2<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6-G:2<L"B`@("`G8V=M)R`@("`@("`@
M("`@/3X@)VEM86=E+V-G;2<L"B`@("`G8VAM)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M8VAM)RP*("`@("=C:')T)R`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UK8VAA<G0G+`H@("`@)V-L87-S)R`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6IA=F$G+`H@("`@)V-L<R<@("`@("`@("`@(#T^("=T
M97AT+W@M=&5X)RP*("`@("=C<&EO)R`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UC<&EO)RP*("`@("=C<&EO+F=Z)R`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UC<&EO+6-O;7!R97-S960G+`H@("`@)V-P<"<@("`@("`@("`@(#T^
M("=T97AT+W@M8RLK<W)C)RP*("`@("=C<'0G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO;6%C+6-O;7!A8W1P<F\G+`H@("`@)V-R="<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+7@U,#DM8V$M8V5R="<L"B`@("`G8W,G("`@
M("`@("`@("`@/3X@)W1E>'0O>"UC<VAA<G`G+`H@("`@)V-S:"<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6-S:"<L"B`@("`G8W-S)R`@("`@("`@
M("`@/3X@)W1E>'0O8W-S)RP*("`@("=C<W8G("`@("`@("`@("`]/B`G=&5X
M="]X+6-O;6UA+7-E<&%R871E9"UV86QU97,G+`H@("`@)V-U<B<@("`@("`@
M("`@(#T^("=I;6%G92]X+7=I;BUB:71M87`G+`H@("`@)V-X>"<@("`@("`@
M("`@(#T^("=T97AT+W@M8RLK<W)C)RP*("`@("=D)R`@("`@("`@("`@("`]
M/B`G=&5X="]X+61S<F,G+`H@("`@)V1A="<@("`@("`@("`@(#T^("=V:61E
M;R]M<&5G)RP*("`@("=D8F8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UD8F%S92<L"B`@("`G9&,G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M9&,M<F]M)RP*("`@("=D8VPG("`@("`@("`@("`]/B`G=&5X="]X+61C
M;"<L"B`@("`G9&-M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+V1I8V]M
M)RP*("`@("=D8W(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UD:7)E
M8W1O<B<L"B`@("`G9&5B)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M9&5B)RP*("`@("=D97(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UX
M-3`Y+6-A+6-E<G0G+`H@("`@)V1E<VMT;W`G("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+61E<VMT;W`G+`H@("`@)V1I82<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+61I82UD:6%G<F%M)RP*("`@("=D:69F)R`@("`@("`@("`]
M/B`G=&5X="]X+7!A=&-H)RP*("`@("=D:7(G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UD:7)E8W1O<B<L"B`@("`G9&IV)R`@("`@("`@("`@/3X@
M)VEM86=E+W9N9"YD:G9U)RP*("`@("=D:G9U)R`@("`@("`@("`]/B`G:6UA
M9V4O=FYD+F1J=G4G+`H@("`@)V1L;"<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]O8W1E="US=')E86TG+`H@("`@)V1M9R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@)V1M<R<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@)V1O8R<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]M<W=O<F0G+`H@("`@)V1S;"<@("`@
M("`@("`@(#T^("=T97AT+W@M9'-L)RP*("`@("=D=&0G("`@("`@("`@("`]
M/B`G=&5X="]X+61T9"<L"B`@("`G9'9I)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9'9I)RP*("`@("=D=V<G("`@("`@("`@("`]/B`G:6UA9V4O
M=FYD+F1W9R<L"B`@("`G9'AF)R`@("`@("`@("`@/3X@)VEM86=E+W9N9"YD
M>&8G+`H@("`@)V1X<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61I
M<F5C=&]R)RP*("`@("=E9V]N)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UE9V]N)RP*("`@("=E;"<@("`@("`@("`@("`]/B`G=&5X="]X+65M86-S
M+6QI<W`G+`H@("`@)V5P<R<@("`@("`@("`@(#T^("=I;6%G92]X+65P<R<L
M"B`@("`G97!S9B<@("`@("`@("`@/3X@)VEM86=E+W@M97!S)RP*("`@("=E
M<'-I)R`@("`@("`@("`]/B`G:6UA9V4O>"UE<',G+`H@("`@)V5T:&5M92<@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+64M=&AE;64G+`H@("`@)V5T>"<@
M("`@("`@("`@(#T^("=T97AT+W@M<V5T97AT)RP*("`@("=E>&4G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UM<RUD;W,M97AE8W5T86)L92<L"B`@
M("`G97HG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+V%N9')E=RUI;G-E
M="<L"B`@("`G9B<@("`@("`@("`@("`@/3X@)W1E>'0O>"UF;W)T<F%N)RP*
M("`@("=F:6<G("`@("`@("`@("`]/B`G:6UA9V4O>"UX9FEG)RP*("`@("=F
M:71S)R`@("`@("`@("`]/B`G:6UA9V4O>"UF:71S)RP*("`@("=F;&%C)R`@
M("`@("`@("`]/B`G875D:6\O>"UF;&%C)RP*("`@("=F;&,G("`@("`@("`@
M("`]/B`G=FED96\O>"UF;&EC)RP*("`@("=F;&DG("`@("`@("`@("`]/B`G
M=FED96\O>"UF;&EC)RP*("`@("=F;'<G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UK:79I;R<L"B`@("`G9F\G("`@("`@("`@("`@/3X@)W1E>'0O
M>"UX<VQF;R<L"B`@("`G9S,G("`@("`@("`@("`@/3X@)VEM86=E+V9A>"UG
M,R<L"B`@("`G9V(G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9V%M
M96)O>2UR;VTG+`H@("`@)V=C<F0G("`@("`@("`@(#T^("=T97AT+V1I<F5C
M=&]R>2<L"B`@("`G9V5N)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M9V5N97-I<RUR;VTG+`H@("`@)V=G)R`@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+7-M<RUR;VTG+`H@("`@)V=I9B<@("`@("`@("`@(#T^("=I;6%G
M92]G:68G+`H@("`@)V=L861E)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6=L861E)RP*("`@("=G;6\G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UG971T97AT+71R86YS;&%T:6]N)RP*("`@("=G;F,G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UG;G5C87-H)RP*("`@("=G;G5C87-H)R`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UG;G5C87-H)RP*("`@("=G;G5M97)I8R<@
M("`@("`]/B`G87!P;&EC871I;VXO>"UG;G5M97)I8R<L"B`@("`G9W)A)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9W)A<&AI=&4G+`H@("`@)V=R
M86TG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]S<F=S)RP*("`@("=G<GAM
M;"<@("`@("`@("`]/B`G87!P;&EC871I;VXO<W)G<RMX;6PG+`H@("`@)V=S
M9B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M='EP93$G+`H@
M("`@)V=S;2<@("`@("`@("`@(#T^("=A=61I;R]X+6=S;2<L"B`@("`G9W1A
M<B<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9W1A<B<L"B`@("`G9WHG
M("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9WII<"<L"B`@("`G:"<@
M("`@("`@("`@("`@/3X@)W1E>'0O>"UC:&1R)RP*("`@("=H*RLG("`@("`@
M("`@("`]/B`G=&5X="]X+6-H9'(G+`H@("`@)VAD9B<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6AD9B<L"B`@("`G:&@G("`@("`@("`@("`@/3X@
M)W1E>'0O>"UC*RMH9'(G+`H@("`@)VAP)R`@("`@("`@("`@(#T^("=T97AT
M+W@M8VAD<B<L"B`@("`G:'!G;"<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W9N9"YH<"UH<&=L)RP*("`@("=H<7@G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO;6%C+6)I;FAE>#0P)RP*("`@("=H<R<@("`@("`@("`@("`]/B`G
M=&5X="]X+6AA<VME;&PG+`H@("`@)VAT;2<@("`@("`@("`@(#T^("=T97AT
M+VAT;6PG+`H@("`@)VAT;6PG("`@("`@("`@(#T^("=T97AT+VAT;6PG+`H@
M("`@)VEC8B<@("`@("`@("`@(#T^("=I;6%G92]X+6EC8B<L"B`@("`G:6-E
M)R`@("`@("`@("`@/3X@)W@M8V]N9F5R96YC92]X+6-O;VQT86QK)RP*("`@
M("=I8V\G("`@("`@("`@("`]/B`G:6UA9V4O>"UI8V\G+`H@("`@)VEC<R<@
M("`@("`@("`@(#T^("=T97AT+V-A;&5N9&%R)RP*("`@("=I9&PG("`@("`@
M("`@("`]/B`G=&5X="]X+6ED;"<L"B`@("`G:65F)R`@("`@("`@("`@/3X@
M)VEM86=E+VEE9B<L"B`@("`G:69B)R`@("`@("`@("`@/3X@)W1E>'0O8V%L
M96YD87(G+`H@("`@)VEF9B<@("`@("`@("`@(#T^("=I;6%G92]X+6EF9B<L
M"B`@("`G:6=E<R<@("`@("`@("`@/3X@)VUO9&5L+VEG97,G+`H@("`@)VEG
M<R<@("`@("`@("`@(#T^("=M;V1E;"]I9V5S)RP*("`@("=I;&)M)R`@("`@
M("`@("`]/B`G:6UA9V4O>"UI;&)M)RP*("`@("=I<V\G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UC9"UI;6%G92<L"B`@("`G:70G("`@("`@("`@
M("`@/3X@)V%U9&EO+W@M:70G+`H@("`@)VIA<B<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6IA<B<L"B`@("`G:F%V82<@("`@("`@("`@/3X@)W1E
M>'0O>"UJ879A)RP*("`@("=J;F<G("`@("`@("`@("`]/B`G:6UA9V4O>"UJ
M;F<G+`H@("`@)VIN;'`G("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IA
M=F$M:FYL<"UF:6QE)RP*("`@("=J<#(G("`@("`@("`@("`]/B`G:6UA9V4O
M:G!E9S(P,#`G+`H@("`@)VIP9R<@("`@("`@("`@(#T^("=I;6%G92]J<&5G
M)RP*("`@("=J<&4G("`@("`@("`@("`]/B`G:6UA9V4O:G!E9R<L"B`@("`G
M:G!E9R<@("`@("`@("`@/3X@)VEM86=E+VIP96<G+`H@("`@)VIP<B<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IB=6EL9&5R+7!R;VIE8W0G+`H@
M("`@)VIP>"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IB=6EL9&5R
M+7!R;VIE8W0G+`H@("`@)VIS)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6IA=F%S8W)I<'0G+`H@("`@)VMA<B<@("`@("`@("`@(#T^("=A=61I
M;R]M:61I)RP*("`@("=K87)B;VXG("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UK87)B;VXG+`H@("`@)VMD96QN:R<@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+61E<VMT;W`G+`H@("`@)VMF;R<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6MF;W)M=6QA)RP*("`@("=K:6PG("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UK:6QL=7-T<F%T;W(G+`H@("`@)VMO;B<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+6MO;G1O=7(G+`H@("`@)VMP;2<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6MP;W9M;V1E;&5R)RP*("`@("=K<'(G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK<')E<V5N=&5R)RP*("`@
M("=K<'0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK<')E<V5N=&5R
M)RP*("`@("=K<F$G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK<FET
M82<L"B`@("`G:W-P)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W-P
M<F5A9"<L"B`@("`G:W5D)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M:W5G87(G+`H@("`@)VMW9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6MW;W)D)RP*("`@("=K=W0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UK=V]R9"<L"B`@("`G;&$G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M<VAA<F5D+6QI8G)A<GDM;&$G+`H@("`@)VQA=&5X)R`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6QA=&5X)RP*("`@("=L:&$G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UL:&$G+`H@("`@)VQH<R<@("`@("`@("`@(#T^
M("=T97AT+W@M;&ET97)A=&4M:&%S:V5L;"<L"B`@("`G;&AZ)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M;&AZ)RP*("`@("=L;V<G("`@("`@("`@
M("`]/B`G=&5X="]X+6QO9R<L"B`@("`G;'1X)R`@("`@("`@("`@/3X@)W1E
M>'0O>"UT97@G+`H@("`@)VQW;R<@("`@("`@("`@(#T^("=I;6%G92]X+6QW
M;R<L"B`@("`G;'=O8B<@("`@("`@("`@/3X@)VEM86=E+W@M;'=O)RP*("`@
M("=L=W,G("`@("`@("`@("`]/B`G:6UA9V4O>"UL=W,G+`H@("`@)VQY>"<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6QY>"<L"B`@("`G;'IH)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;&AA)RP*("`@("=L>F\G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UL>F]P)RP*("`@("=M)R`@("`@
M("`@("`@("`]/B`G=&5X="]X+6]B:F-S<F,G+`H@("`@)VTQ-2<@("`@("`@
M("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G;3-U)R`@("`@("`@("`@/3X@
M)V%U9&EO+W@M;7!E9W5R;"<L"B`@("`G;31A)R`@("`@("`@("`@/3X@)V%U
M9&EO+W@M;31A)RP*("`@("=M-'4G("`@("`@("`@("`]/B`G=FED96\O=FYD
M+FUP96=U<FPG+`H@("`@)VUA;B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+71R;V9F+6UA;B<L"B`@("`G;6%T:&UL)R`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+VUA=&AM;"MX;6PG+`H@("`@)VUD)R`@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6=E;F5S:7,M<F]M)RP*("`@("=M92<@("`@("`@("`@
M("`]/B`G=&5X="]X+71R;V9F+6UE)RP*("`@("=M97-H)R`@("`@("`@("`]
M/B`G;6]D96PO;65S:"<L"B`@("`G;6=P)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M;6%G:6-P;VEN="<L"B`@("`G;6ED)R`@("`@("`@("`@/3X@
M)V%U9&EO+VUI9&DG+`H@("`@)VUI9&DG("`@("`@("`@(#T^("=A=61I;R]M
M:61I)RP*("`@("=M:68G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM
M:68G+`H@("`@)VUK=B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6UA
M=')O<VMA)RP*("`@("=M;2<@("`@("`@("`@("`]/B`G=&5X="]X+71R;V9F
M+6UM)RP*("`@("=M;6PG("`@("`@("`@("`]/B`G=&5X="]M871H;6PG+`H@
M("`@)VUN9R<@("`@("`@("`@(#T^("=V:61E;R]X+6UN9R<L"B`@("`G;6]C
M)R`@("`@("`@("`@/3X@)W1E>'0O>"UM;V,G+`H@("`@)VUO9"<@("`@("`@
M("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G;6]O=B<@("`@("`@("`@/3X@
M)W9I9&5O+W%U:6-K=&EM92<L"B`@("`G;6]V)R`@("`@("`@("`@/3X@)W9I
M9&5O+W%U:6-K=&EM92<L"B`@("`G;6]V:64G("`@("`@("`@/3X@)W9I9&5O
M+W@M<V=I+6UO=FEE)RP*("`@("=M<#(G("`@("`@("`@("`]/B`G=FED96\O
M;7!E9R<L"B`@("`G;7`S)R`@("`@("`@("`@/3X@)V%U9&EO+VUP96<G+`H@
M("`@)VUP92<@("`@("`@("`@(#T^("=V:61E;R]M<&5G)RP*("`@("=M<&5G
M)R`@("`@("`@("`]/B`G=FED96\O;7!E9R<L"B`@("`G;7!G)R`@("`@("`@
M("`@/3X@)W9I9&5O+VUP96<G+`H@("`@)VUP9V$G("`@("`@("`@(#T^("=A
M=61I;R]M<&5G)RP*("`@("=M<R<@("`@("`@("`@("`]/B`G=&5X="]X+71R
M;V9F+6US)RP*("`@("=M<V@G("`@("`@("`@("`]/B`G;6]D96PO;65S:"<L
M"B`@("`G;7-O9"<@("`@("`@("`@/3X@)VEM86=E+W@M;7-O9"<L"B`@("`G
M;7-X)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;7-X+7)O;2<L"B`@
M("`G;71M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M;6]D)RP*("`@("=M>'4G
M("`@("`@("`@("`]/B`G=FED96\O=FYD+FUP96=U<FPG+`H@("`@)VXV-"<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6XV-"UR;VTG+`H@("`@)VYB
M)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]M871H96UA=&EC82<L"B`@
M("`G;F,G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;F5T8V1F)RP*
M("`@("=N97,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UN97,M<F]M
M)RP*("`@("=N<W8G("`@("`@("`@("`]/B`G=FED96\O>"UN<W8G+`H@("`@
M)V\G("`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6]B:F5C="<L"B`@
M("`G;V)J)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=&=I9B<L"B`@
M("`G;V1A)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+V]D82<L"B`@("`G
M;V1B)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N
M9&]C=6UE;G0N9&%T86)A<V4G+`H@("`@)V]D8R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+F-H87)T)RP*("`@
M("=O9&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P
M96YD;V-U;65N="YF;W)M=6QA)RP*("`@("=O9&<G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YG<F%P:&EC<R<L
M"B`@("`G;V1I)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I
M<RYO<&5N9&]C=6UE;G0N:6UA9V4G+`H@("`@)V]D;2<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+G1E>'0M;6%S
M=&5R)RP*("`@("=O9'`G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+F]A<VES+F]P96YD;V-U;65N="YP<F5S96YT871I;VXG+`H@("`@)V]D<R<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M
M96YT+G-P<F5A9'-H965T)RP*("`@("=O9'0G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YT97AT)RP*("`@("=O
M9V<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO;V=G)RP*("`@("=O;&0G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT<F%S:"<L"B`@("`G;VQE
M;R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;VQE;R<L"B`@("`G;V]T
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C
M=6UE;G0N=&5X="<L"B`@("`G;W1G)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N9W)A<&AI8W,M=&5M<&QA=&4G
M+`H@("`@)V]T:"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S
M:7,N;W!E;F1O8W5M96YT+G1E>'0M=V5B)RP*("`@("=O='`G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YP<F5S
M96YT871I;VXM=&5M<&QA=&4G+`H@("`@)V]T<R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+G-P<F5A9'-H965T
M+71E;7!L871E)RP*("`@("=O='0G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YT97AT+71E;7!L871E)RP*("`@
M("=P)R`@("`@("`@("`@("`]/B`G=&5X="]X+7!A<V-A;"<L"B`@("`G<#$R
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&MC<S$R)RP*("`@("=P
M-W,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<&MC<S<M<VEG;F%T=7)E
M)RP*("`@("=P87(R)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP87(R
M)RP*("`@("=P87,G("`@("`@("`@("`]/B`G=&5X="]X+7!A<V-A;"<L"B`@
M("`G<&%T8V@G("`@("`@("`@/3X@)W1E>'0O>"UP871C:"<L"B`@("`G<&)M
M)R`@("`@("`@("`@/3X@)VEM86=E+W@M<&]R=&%B;&4M8FET;6%P)RP*("`@
M("=P8V0G("`@("`@("`@("`]/B`G:6UA9V4O>"UP:&]T;RUC9"<L"B`@("`G
M<&-F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UP8V8G+`H@
M("`@)W!C9BY:)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M='EP
M93$G+`H@("`@)W!C;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N
M:'`M<&-L)RP*("`@("=P9&(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M=FYD+G!A;&TG+`H@("`@)W!D9B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]P9&8G+`H@("`@)W!E;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+7@U,#DM8V$M8V5R="<L"B`@("`G<&5R;"<@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M<&5R;"<L"B`@("`G<&9A)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9F]N="UT>7!E,2<L"B`@("`G<&9B)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M9F]N="UT>7!E,2<L"B`@("`G<&9X)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M<&MC<S$R)RP*("`@("=P9VTG("`@("`@
M("`@("`]/B`G:6UA9V4O>"UP;W)T86)L92UG<F%Y;6%P)RP*("`@("=P9VXG
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UC:&5S<RUP9VXG+`H@("`@
M)W!G<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]P9W`G+`H@("`@)W!H
M<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!H<"<L"B`@("`G<&AP
M,R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&AP)RP*("`@("=P:'`T
M)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP:'`G+`H@("`@)W!I8W0G
M("`@("`@("`@(#T^("=I;6%G92]X+7!I8W0G+`H@("`@)W!I8W0Q)R`@("`@
M("`@(#T^("=I;6%G92]X+7!I8W0G+`H@("`@)W!I8W0R)R`@("`@("`@(#T^
M("=I;6%G92]X+7!I8W0G+`H@("`@)W!L)R`@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+7!E<FPG+`H@("`@)W!L<R<@("`@("`@("`@(#T^("=A=61I
M;R]X+7-C<&QS)RP*("`@("=P;2<@("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UP97)L)RP*("`@("=P;F<G("`@("`@("`@("`]/B`G:6UA9V4O<&YG
M)RP*("`@("=P;FTG("`@("`@("`@("`]/B`G:6UA9V4O>"UP;W)T86)L92UA
M;GEM87`G+`H@("`@)W!O)R`@("`@("`@("`@(#T^("=T97AT+W@M9V5T=&5X
M="UT<F%N<VQA=&EO;B<L"B`@("`G<&]T)R`@("`@("`@("`@/3X@)W1E>'0O
M>"UG971T97AT+71R86YS;&%T:6]N+71E;7!L871E)RP*("`@("=P<&TG("`@
M("`@("`@("`]/B`G:6UA9V4O>"UP;W)T86)L92UP:7AM87`G+`H@("`@)W!P
M<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;7,M<&]W97)P;VEN
M="<L"B`@("`G<'!T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM
M<RUP;W=E<G!O:6YT)RP*("`@("=P<'HG("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+FUS+7!O=V5R<&]I;G0G+`H@("`@)W!S)R`@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]P;W-T<V-R:7!T)RP*("`@("=P<RYG>B<@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UG>G!O<W1S8W)I<'0G+`H@("`@)W!S
M9"<@("`@("`@("`@(#T^("=I;6%G92]X+7!S9"<L"B`@("`G<'-F)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UL:6YU>"UP<V8G+`H@("`@
M)W!S:60G("`@("`@("`@(#T^("=A=61I;R]P<G,N<VED)RP*("`@("=P=R<@
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP=R<L"B`@("`G<'DG("`@
M("`@("`@("`@/3X@)W1E>'0O>"UP>71H;VXG+`H@("`@)W!Y8R<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+7!Y=&AO;BUB>71E8V]D92<L"B`@("`G
M<'EO)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<'ET:&]N+6)Y=&5C
M;V1E)RP*("`@("=Q:68G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UQ
M=R<L"B`@("`G<70G("`@("`@("`@("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L
M"B`@("`G<71V<B<@("`@("`@("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L"B`@
M("`G<F$G("`@("`@("`@("`@/3X@)V%U9&EO+W@M<&XM<F5A;&%U9&EO)RP*
M("`@("=R86TG("`@("`@("`@("`]/B`G875D:6\O>"UP;BUR96%L875D:6\G
M+`H@("`@)W)A<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7)A<B<L
M"B`@("`G<F%S)R`@("`@("`@("`@/3X@)VEM86=E+W@M8VUU+7)A<W1E<B<L
M"B`@("`G<F1F)R`@("`@("`@("`@/3X@)W1E>'0O<F1F)RP*("`@("=R96HG
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UR96IE8W0G+`H@("`@)W)G
M8B<@("`@("`@("`@(#T^("=I;6%G92]X+7)G8B<L"B`@("`G<FQE)R`@("`@
M("`@("`@/3X@)VEM86=E+W)L92<L"B`@("`G<FTG("`@("`@("`@("`@/3X@
M)V%U9&EO+W@M<&XM<F5A;&%U9&EO)RP*("`@("=R;V9F)R`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UT<F]F9B<L"B`@("`G<G!M)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M<G!M)RP*("`@("=R<W,G("`@("`@("`@("`]
M/B`G=&5X="]R<W,G+`H@("`@)W)T9B<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]R=&8G+`H@("`@)W)T>"<@("`@("`@("`@(#T^("=T97AT+W)I8VAT
M97AT)RP*("`@("=S,VTG("`@("`@("`@("`]/B`G875D:6\O>"US,VTG+`H@
M("`@)W-A;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%M:7!R;R<L
M"B`@("`G<V-M)R`@("`@("`@("`@/3X@)W1E>'0O>"US8VAE;64G+`H@("`@
M)W-D82<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES
M:6]N+F1R87<G+`H@("`@)W-D8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N<W1A<F1I=FES:6]N+F-A;&,G+`H@("`@)W-D9"<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+FEM<')E<W,G+`H@
M("`@)W-D<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I
M=FES:6]N+FEM<')E<W,G+`H@("`@)W-D<R<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+F-H87)T)RP*("`@("=S9'<G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYW<FET
M97(G+`H@("`@)W-G:2<@("`@("`@("`@(#T^("=I;6%G92]X+7-G:2<L"B`@
M("`G<V=L)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV
M:7-I;VXN=W)I=&5R)RP*("`@("=S9VTG("`@("`@("`@("`]/B`G=&5X="]S
M9VUL)RP*("`@("=S9VUL)R`@("`@("`@("`]/B`G=&5X="]S9VUL)RP*("`@
M("=S:"<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"US:&5L;'-C<FEP
M="<L"B`@("`G<VAA<B<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VAA
M<B<L"B`@("`G<VAT;6PG("`@("`@("`@/3X@)W1E>'0O:'1M;"<L"B`@("`G
M<VEA9R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VEA9R<L"B`@("`G
M<VED)R`@("`@("`@("`@/3X@)V%U9&EO+W!R<RYS:60G+`H@("`@)W-I:R<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71R87-H)RP*("`@("=S:6QO
M)R`@("`@("`@("`]/B`G;6]D96PO;65S:"<L"B`@("`G<VET)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W-T=69F:70G+`H@("`@)W-K9"<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-K;2<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-K<"<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-K="<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-L:R<@("`@("`@
M("`@(#T^("=T97AT+W-P<F5A9'-H965T)RP*("`@("=S;60G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYM86EL)RP*("`@
M("=S;68G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I
M<VEO;BYM871H)RP*("`@("=S;6DG("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO<VUI;"<L"B`@("`G<VUI;"<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W-M:6PG+`H@("`@)W-M;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]S
M;6EL)RP*("`@("=S;7,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"US
M;7,M<F]M)RP*("`@("=S;F0G("`@("`@("`@("`]/B`G875D:6\O8F%S:6,G
M+`H@("`@)W-O)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7-H87)E
M9&QI8B<L"B`@("`G<W!D)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M9F]N="US<&5E9&\G+`H@("`@)W-P;"<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+69U='5R97-P;&%S:"<L"B`@("`G<W%L)R`@("`@("`@("`@/3X@
M)W1E>'0O>"US<6PG+`H@("`@)W-R8R<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+7=A:7,M<V]U<F-E)RP*("`@("=S=&,G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO=FYD+G-U;BYX;6PN8V%L8RYT96UP;&%T92<L"B`@("`G
M<W1D)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F1R
M87<N=&5M<&QA=&4G+`H@("`@)W-T:2<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]V;F0N<W5N+GAM;"YI;7!R97-S+G1E;7!L871E)RP*("`@("=S=&TG
M("`@("`@("`@("`]/B`G875D:6\O>"US=&TG+`H@("`@)W-T=R<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET97(N=&5M<&QA
M=&4G+`H@("`@)W-T>2<@("`@("`@("`@(#T^("=T97AT+W@M=&5X)RP*("`@
M("=S=6XG("`@("`@("`@("`]/B`G:6UA9V4O>"US=6XM<F%S=&5R)RP*("`@
M("=S=C1C<&EO)R`@("`@("`]/B`G87!P;&EC871I;VXO>"US=C1C<&EO)RP*
M("`@("=S=C1C<F,G("`@("`@("`]/B`G87!P;&EC871I;VXO>"US=C1C<F,G
M+`H@("`@)W-V9R<@("`@("`@("`@(#T^("=I;6%G92]S=F<K>&UL)RP*("`@
M("=S=V8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"US:&]C:W=A=F4M
M9FQA<V@G+`H@("`@)W-X8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V
M;F0N<W5N+GAM;"YC86QC)RP*("`@("=S>&0G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+G-U;BYX;6PN9')A=R<L"B`@("`G<WAG)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYG;&]B86PG
M+`H@("`@)W-X:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N
M+GAM;"YI;7!R97-S)RP*("`@("=S>&TG("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+G-U;BYX;6PN;6%T:"<L"B`@("`G<WAW)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<B<L"B`@("`G<WEL
M:R<@("`@("`@("`@/3X@)W1E>'0O<W!R96%D<VAE970G+`H@("`@)W0G("`@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71R;V9F)RP*("`@("=T87(G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT87(G+`H@("`@)W1A<BY:
M)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71A<GHG+`H@("`@)W1A<BYB
M>B<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z:7`M8V]M<')E<W-E9"UT
M87(G+`H@("`@)W1A<BYB>C(G("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z
M:7`M8V]M<')E<W-E9"UT87(G+`H@("`@)W1A<BYG>B<@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6-O;7!R97-S960M=&%R)RP*("`@("=T87(N;'IO)R`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UT>F\G+`H@("`@)W1C;"<@("`@("`@
M("`@(#T^("=T97AT+W@M=&-L)RP*("`@("=T97@G("`@("`@("`@("`]/B`G
M=&5X="]X+71E>"<L"B`@("`G=&5X:2<@("`@("`@("`@/3X@)W1E>'0O>"UT
M97AI;F9O)RP*("`@("=T97AI;F9O)R`@("`@("`]/B`G=&5X="]X+71E>&EN
M9F\G+`H@("`@)W1G82<@("`@("`@("`@(#T^("=I;6%G92]X+71G82<L"B`@
M("`G=&=Z)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M8V]M<')E<W-E
M9"UT87(G+`H@("`@)W1H96UE)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+71H96UE)RP*("`@("=T:68G("`@("`@("`@("`]/B`G:6UA9V4O=&EF9B<L
M"B`@("`G=&EF9B<@("`@("`@("`@/3X@)VEM86=E+W1I9F8G+`H@("`@)W1K
M)R`@("`@("`@("`@(#T^("=T97AT+W@M=&-L)RP*("`@("=T;W)R96YT)R`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UB:71T;W)R96YT)RP*("`@("=T<B<@
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT<F]F9B<L"B`@("`G=',G
M("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;&EN9W5I<W0G+`H@("`@
M)W1S=B<@("`@("`@("`@(#T^("=T97AT+W1A8BUS97!A<F%T960M=F%L=65S
M)RP*("`@("=T=&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UF;VYT
M+71T9B<L"B`@("`G='AT)R`@("`@("`@("`@/3X@)W1E>'0O<&QA:6XG+`H@
M("`@)W1Z;R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71Z;R<L"B`@
M("`G=6DG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9&5S:6=N97(G
M+`H@("`@)W5I;"<@("`@("`@("`@(#T^("=T97AT+W@M=6EL)RP*("`@("=U
M;'0G("`@("`@("`@("`]/B`G875D:6\O>"UM;V0G+`H@("`@)W5N:2<@("`@
M("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G=7)I)R`@("`@("`@("`@
M/3X@)W1E>'0O>"UU<FDG+`H@("`@)W5R;"<@("`@("`@("`@(#T^("=T97AT
M+W@M=7)I)RP*("`@("=U<W1A<B<@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UU<W1A<B<L"B`@("`G=F-D)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M8V1L:6YK)RP*("`@("=V8V8G("`@("`@("`@("`]/B`G=&5X="]D:7)E
M8W1O<GDG+`H@("`@)W9C<R<@("`@("`@("`@(#T^("=T97AT+V-A;&5N9&%R
M)RP*("`@("=V8W0G("`@("`@("`@("`]/B`G=&5X="]D:7)E8W1O<GDG+`H@
M("`@)W9F8B<@("`@("`@("`@(#T^("=T97AT+V-A;&5N9&%R)RP*("`@("=V
M;V(G("`@("`@("`@("`]/B`G=FED96\O;7!E9R<L"B`@("`G=F]C)R`@("`@
M("`@("`@/3X@)V%U9&EO+W@M=F]C)RP*("`@("=V;W(G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYW<FET97(G+`H@("`@
M)W9R;6PG("`@("`@("`@(#T^("=M;V1E;"]V<FUL)RP*("`@("=V<V0G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G9I<VEO)RP*("`@("=V>&UL
M)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO=F]I8V5X;6PK>&UL)RP*("`@
M("=W878G("`@("`@("`@("`]/B`G875D:6\O>"UW878G+`H@("`@)W=A>"<@
M("`@("`@("`@(#T^("=A=61I;R]X+6US+7=A>"<L"B`@("`G=V(Q)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<75A='1R;W!R;R<L"B`@("`G=V(R
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<75A='1R;W!R;R<L"B`@
M("`G=V(S)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<75A='1R;W!R
M;R<L"B`@("`G=V)M<"<@("`@("`@("`@/3X@)VEM86=E+W9N9"YW87`N=V)M
M<"<L"B`@("`G=V)X;6PG("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YW
M87`N=V)X;6PG+`H@("`@)W=K,2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)W=K,R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)W=K-"<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)W=K
M<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G
M+`H@("`@)W=M)R`@("`@("`@("`@(#T^("=V:61E;R]X+6US+7=M)RP*("`@
M("=W;6$G("`@("`@("`@("`]/B`G875D:6\O>"UM<RUW;6$G+`H@("`@)W=M
M9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6US+7=M9"<L"B`@("`G
M=VUF)R`@("`@("`@("`@/3X@)VEM86=E+W@M=VUF)RP*("`@("=W;6PG("`@
M("`@("`@("`]/B`G=&5X="]V;F0N=V%P+G=M;"<L"B`@("`G=VUL8R<@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YW87`N=VUL8R<L"B`@("`G=VUL
M<R<@("`@("`@("`@/3X@)W1E>'0O=FYD+G=A<"YW;6QS8W)I<'0G+`H@("`@
M)W=M;'-C)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N=V%P+G=M;'-C
M<FEP=&,G+`H@("`@)W=M=B<@("`@("`@("`@(#T^("=V:61E;R]X+6US+7=M
M=B<L"B`@("`G=VUX)R`@("`@("`@("`@/3X@)W9I9&5O+W@M;7,M=VUX)RP*
M("`@("=W;7HG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM<RUW;7HG
M+`H@("`@)W=P9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N=V]R
M9'!E<F9E8W0G+`H@("`@)W=P9R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+7=P9R<L"B`@("`G=W)I)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M;7-W<FET92<L"B`@("`G=W)L)R`@("`@("`@("`@/3X@)VUO9&5L+W9R
M;6PG+`H@("`@)W=V>"<@("`@("`@("`@(#T^("=V:61E;R]X+6US+7=V>"<L
M"B`@("`G>&%C)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9VYU8V%S
M:"<L"B`@("`G>&)E;"<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M>&)E
M;"<L"B`@("`G>&)M)R`@("`@("`@("`@/3X@)VEM86=E+W@M>&)I=&UA<"<L
M"B`@("`G>&-F)R`@("`@("`@("`@/3X@)VEM86=E+W@M>&-F)RP*("`@("=X
M8V8N8GHR)R`@("`@("`]/B`G:6UA9V4O>"UC;VUP<F5S<V5D+7AC9B<L"B`@
M("`G>&-F+F=Z)R`@("`@("`@/3X@)VEM86=E+W@M8V]M<')E<W-E9"UX8V8G
M+`H@("`@)WAH="<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X:'1M;"MX
M;6PG+`H@("`@)WAH=&UL)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X:'1M
M;"MX;6PG+`H@("`@)WAI)R`@("`@("`@("`@(#T^("=A=61I;R]X+7AI)RP*
M("`@("=X;&$G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X
M8V5L)RP*("`@("=X;&,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+FUS+65X8V5L)RP*("`@("=X;&0G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;&PG("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;&TG("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;',G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;'0G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@
M("=X;'<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L
M)RP*("`@("=X;2<@("`@("`@("`@("`]/B`G875D:6\O>"UX;2<L"B`@("`G
M>&UI)R`@("`@("`@("`@/3X@)W1E>'0O>"UX;6DG+`H@("`@)WAM;"<@("`@
M("`@("`@(#T^("=T97AT+WAM;"<L"B`@("`G>'!M)R`@("`@("`@("`@/3X@
M)VEM86=E+W@M>'!I>&UA<"<L"B`@("`G>'-L)R`@("`@("`@("`@/3X@)W1E
M>'0O>"UX<VQT)RP*("`@("=X<VQF;R<@("`@("`@("`]/B`G=&5X="]X+7AS
M;&9O)RP*("`@("=X<VQT)R`@("`@("`@("`]/B`G=&5X="]X+7AS;'0G+`H@
M("`@)WAU;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;6]Z:6QL
M82YX=6PK>&UL)RP*("`@("=X=V0G("`@("`@("`@("`]/B`G:6UA9V4O>"UX
M=VEN9&]W9'5M<"<L"B`@("`G>'EZ)R`@("`@("`@("`@/3X@)V-H96UI8V%L
M+W@M>'EZ)RP*("`@("=Z86)W)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UA8FEW;W)D)RP*("`@("=Z:7`G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>FEP)RP*("`@("=Z;V\G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UZ;V\G+`H@("`@)S$R,R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V
M;F0N;&]T=7,M,2TR+3,G+`H@("`@)S8V.2<@("`@("`@("`@(#T^("=A=61I
M;R]X+6UO9"<**3L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+VUI;64N;6%G:6,N<&AP````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C<T,S4`,3`U,34T,S$P-C$`,#(Q
M-3`Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!$871A(&9I;&4@=7-E9"!B>2!-24U%7TUA9VEC.CHN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]M:6UE+FUA9VEC
M+G!H<"QV(#$N-2`R,#`T+S`S+S(P(#(R.C0U.C,W(&IA;B!%>'`@)`H@*@H@
M*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PHD;6EM95]M86=I8ULP75LS,%U;
M(EPQ-#5<,38V7#$T,5PQ-31<-#!<-#)<,30U7#$W,%PQ-#5<,30S7#0P7#4W
M7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U
M,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP
M97)L)SL*)&UI;65?;6%G:6-;,%U;,C1=6R)<,30U7#$V-EPQ-#%<,34T7#0P
M7#0R7#$T-5PQ-S!<,30U7#$T,UPT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X
M+7!E<FPG.PHD;6EM95]M86=I8ULP75LR,UU;(EPQ,#-<,34W7#$U-5PQ-35<
M,34W7#$U-EPT,%PQ-C-<,38U7#$T,EPQ-#1<,34Q7#$V,EPQ-#5<,30S7#$V
M-%PQ-3=<,38R7#$U,5PQ-#5<,38S7#<R7#0P(ET@/2`G=&5X="]X+7!A=&-H
M)SL*)&UI;65?;6%G:6-;,%U;,C-=6R)<-S5<-S1<,34T7#$U,5PQ-C-<,38T
M7#<V7#$U-EPW-%PQ-C!<,38R7#$U-UPQ-C1<,34W7#$T,UPQ-3=<,34T7#0P
M7#$T,EPQ-#)<,34V7#4U7#$U-2)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD
M;6EM95]M86=I8ULP75LR,EU;(EPQ,#%<,3$U7#$P,5PQ,39<,3`T7#$P,5PW
M,EPT,%PQ,C1<,3`Q7#$R,%PQ,#5<,3(S7#$R-%PQ,#%<,3(R7#$R-%PT,%PQ
M,#1<,3`Q7#$R-%PQ,#4B72`]("=A<'!L:6-A=&EO;B]X+6%M86YD82UH96%D
M97(G.PHD;6EM95]M86=I8ULP75LR,EU;(EPQ,#=<,3`V7#8Q7#$R,%PQ,#%<
M,3(T7#$P,UPQ,3!<-C%<-C!<-C!<-C!<,3$Q7#$P-%PT,UPV,%PV,%PV,%PV
M,%PV,%PV,EPV,")=(#T@)V%U9&EO+W@M9W5S+7!A=&-H)SL*)&UI;65?;6%G
M:6-;,%U;,C)=6R)<,3`W7#$P-EPV,5PQ,C!<,3`Q7#$R-%PQ,#-<,3$P7#8Q
M7#8Q7#8P7#8P7#$Q,5PQ,#1<-#-<-C!<-C!<-C!<-C!<-C!<-C)<-C`B72`]
M("=A=61I;R]X+6=U<RUP871C:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S
M7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<
M-3=<,30R7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC
M871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#$Q7#4W
M7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U
M,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA
M=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S
M7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W
M7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI
M;65?;6%G:6-;,%U;,C)=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<
M,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U
M7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I
M8ULP75LR,EU;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W
M7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$V-%PQ-#-<,38S7#$U
M,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,C)=
M6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q
M7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]("=A
M<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,C)=6R)<-#-<-#%<
M-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO
M;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#0P7#4W7#$V
M-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ
M-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG
M.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V
M,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$V
M,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M<&5R;"<["B1M:6UE
M7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$U
M-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,38T7#$T,UPQ
M-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD;6EM95]M86=I8ULP
M75LR,5U;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T
M,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C-<,34P(ET@/2`G
M87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT
M,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W
M7#$T,EPQ-3%<,34V7#4W7#$W,EPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO
M>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PT,%PU-UPQ-C5<
M,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V
M7#4W7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM
M95]M86=I8ULP75LR,5U;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ
M-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$W,EPQ-C-<
M,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR
M,5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<
M,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U,")=(#T@)V%P
M<&QI8V%T:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PU
M-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ
M-3%<,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M
M87=K)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<-3=<,38U7#$V,UPQ
M-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ
M-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE
M7VUA9VEC6S!=6S(Q75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ
M-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<
M,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;
M,C%=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q
M7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A
M<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S(P75LB7#$T-5PQ
M-C9<,30Q7#$U-%PT,%PT,EPQ-#5<,3<P7#$T-5PQ-#-<-#!<-3=<,30R7#$U
M,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP
M97)L)SL*)&UI;65?;6%G:6-;,%U;,C!=6R)<-#-<-#%<,3%<-3=<,38U7#$V
M,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP75LR
M,%U;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ
M-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-#4B72`]("=T97AT+W-C
M<FEP="<["B1M:6UE7VUA9VEC6S!=6S(P75LB7#0S7#0Q7#4W7#$V-5PQ-C-<
M,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<
M,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G
M:6-;,%U;,C!=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ
M-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-S)<,38S7#$U,")=(#T@
M)V%P<&QI8V%T:6]N+W@M>G-H)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<,3`S
M7#$V,EPQ-#5<,30Q7#$V-%PQ-3%<,38V7#$T-5PT,%PQ,C9<,34W7#$U,5PQ
M-#-<,30U7#0P7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%U9&EO+W@M=F]C)SL*
M)&UI;65?;6%G:6-;,%U;,3E=6R)<-#%<-S1<,30Q7#$V,EPQ-#-<,34P7#<V
M7#$U-EPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<
M,3`U(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=6S$Y
M75LB7#0Q7#<T7#$T,5PQ-C)<,30S7#$U,%PW-EPQ-39<,3,W7#$S-UPQ,S=<
M,3,W7#$S-UPQ,S=<,3,W7#$S-UPV-EPV-%PQ,#4B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<-#-<-#%<-3=<,38U7#$V
M,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP75LQ
M.%U;(EPQ,#9<,34Q7#$Q-%PQ-#5<,3(S7#$V-%PQ,#%<,38R7#$R-%PQ-#9<
M,3$Q7#$U-%PQ,#5<,38S7#$R-%PQ-#%<,3(R7#$V-")=(#T@)W1E>'0O>"UA
M<'!L92UB:6YS8VEI)SL*)&UI;65?;6%G:6-;,%U;,3A=6R)<-#-<-#%<-#!<
M-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-C1<
M,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA
M9VEC6S!=6S$X75LB7#0U7#0Q7#$R,%PQ,C-<-35<,3`Q7#$T-%PQ-3=<,30R
M7#$T-5PQ,#9<,34W7#$U-EPQ-C1<-35<-C%<-39<-C`B72`]("=F;VYT+W1Y
M<&4Q)SL*)&UI;65?;6%G:6-;,%U;,3==6R)<-#-<-#%<-3=<,38U7#$V,UPQ
M-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-C1<,30S7#$V,UPQ-3`B
M72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S$V75LB
M7#$P-5PQ-S!<,38T7#$T-5PQ-39<,30T7#$T-5PQ-#1<-#!<,3$U7#$U-UPQ
M-#1<,38U7#$U-%PQ-#5<-S(B72`]("=A=61I;R]X+69T,BUM;V0G.PHD;6EM
M95]M86=I8ULP75LQ-EU;(EPQ,C-<,38T7#$T,5PQ-C)<,38T7#$P-EPQ-3=<
M,34V7#$V-%PQ,35<,30U7#$V-%PQ-C)<,34Q7#$T,UPQ-C,B72`]("=F;VYT
M+W@M<W5N;W,M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S$V75LB7#0S7#0Q7#$Q
M7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$T-UPQ-#%<,38W
M7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;
M,39=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<
M-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD
M;6EM95]M86=I8ULP75LQ-EU;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU
M-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A
M=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT,UPT,5PT,%PU
M-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ
M-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$V
M75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W
M7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI
M;65?;6%G:6-;,%U;,39=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<
M,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I
M;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,39=6R)<-S1<,3$U7#$T,5PQ
M-3-<,30U7#$V,EPQ,#1<,34Q7#$T,UPQ-C1<,34Q7#$U-UPQ-39<,30Q7#$V
M,EPQ-S$B72`]("=A<'!L:6-A=&EO;B]X+69R86UE;6%K97(G.PHD;6EM95]M
M86=I8ULP75LQ-EU;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R7#$R,UPQ-#-<
M,38R7#$T-5PQ-#5<,34V7#$P-EPQ-3=<,34V7#$V-")=(#T@)V9O;G0O>"UF
M<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<-#-<-#%<,3%<-3=<
M,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,30Q7#$V-UPQ-3,B72`]
M("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$U75LB7#0S
M7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ
M-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP
M75LQ-5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M
M:6UE7VUA9VEC6S!=6S$U75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T
M,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N
M+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<-#-<-#%<-3=<,38U7#$V
M,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G
M87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,31=6R)<-#%<
M-S1<,30Q7#$V,EPQ-#-<,34P7#<V7#$U-EPQ-#1<,30U7#$T,EPQ-3%<,30Q
M7#$U-B)=(#T@)V%P<&QI8V%T:6]N+W@M9'!K9R<["B1M:6UE7VUA9VEC6S!=
M6S$T75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W
M7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M
M86=I8ULP75LQ-%U;(EPW-%PT,5PQ,#1<,3$W7#$P,UPQ,C1<,3,Q7#$R,%PQ
M,#5<-#!<,3$P7#$R-%PQ,35<,3$T(ET@/2`G=&5X="]H=&UL)SL*)&UI;65?
M;6%G:6-;,%U;,31=6R)<-S1<-#%<,30T7#$U-UPQ-#-<,38T7#$W,5PQ-C!<
M,30U7#0P7#$U,%PQ-C1<,34U7#$U-")=(#T@)W1E>'0O:'1M;"<["B1M:6UE
M7VUA9VEC6S!=6S$S75LB7#$P-UPQ,3%<,3$U7#$R,%PT,%PQ,#=<,38R7#$T
M,5PQ-#1<,34Q7#$T-5PQ-39<,38T(ET@/2`G87!P;&EC871I;VXO>"UG:6UP
M+6=R861I96YT)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<,3(R7#$T-5PQ-C1<
M,38U7#$V,EPQ-39<-35<,3(P7#$T,5PQ-C1<,34P7#<R(ET@/2`G;65S<V%G
M92]R9F,X,C(G.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PQ,5PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO
M;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<,3%<-3=<,30R
M7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO
M>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PQ,5PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X
M+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#$Q7#4W7#$T,EPQ
M-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M
M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#$Q7#4W7#$T,EPQ
M-3%<,34V7#4W7#$V-%PQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M
M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<-3=<,30R7#$U
M,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"US
M:"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#0P7#4W7#$T,EPQ-3%<
M,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K
M)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<-3=<,30R7#$U,5PQ
M-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG
M.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG
M.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<[
M"B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#$Q7#4W7#$T,EPQ-3%<,34V
M7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM
M95]M86=I8ULP75LQ,5U;(EPT,UPT,5PQ,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ
M-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G
M:6-;,%U;,3%=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,34S7#$V
M,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE7VUA9VEC6S!=
M6S$Q75LB7#0S7#0Q7#0P7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S
M(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,5U;
M(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#-<,38S7#$U,")=(#T@
M)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<
M-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<,34S7#$V,UPQ-3`B72`]("=A<'!L
M:6-A=&EO;B]X+6MS:"<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#4W
M7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U,")=(#T@)V%P<&QI8V%T
M:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT,5PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X
M+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#4W7#$T,EPQ-3%<
M,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K
M)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<
M-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*
M)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<-3=<
M,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD;6EM
M95]M86=I8ULP75LQ,%U;(EPQ,#)<,34Q7#$V-%PQ-35<,30Q7#$V,%PQ-#9<
M,34Q7#$U-%PQ-#4B72`]("=I;6%G92]U;FMN;W=N)SL*)&UI;65?;6%G:6-;
M,%U;,3!=6R)<,3(S7#$R-%PQ,#%<,3(R7#$R-%PQ,#9<,3$W7#$Q-EPQ,C1<
M-#`B72`]("=F;VYT+W@M8F1F)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<
M-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,38R7#$T,R)=(#T@)W1E>'0O<V-R
M:7!T)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<,3%<-3=<,30R7#$U
M,5PQ-39<-3=<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M<V@G.PHD;6EM
M95]M86=I8ULP75LQ,%U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ
M-C)<,30S(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP75LQ,%U;
M(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<,34P(ET@/2`G87!P
M;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S$P75LB7#0S7#0Q7#4W
M7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO
M>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT,5PU-UPQ-#)<,34Q
M7#$U-EPU-UPQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*
M)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<-3=<
M,34S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE7VUA
M9VEC6S!=6S$P75LB7#<T7#$Q-5PQ-#%<,34S7#$T-5PQ-C)<,3`V7#$U,5PQ
M-31<,30U(ET@/2`G87!P;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?
M;6%G:6-;,%U;.5U;(EPQ,C)<,30U7#$T,UPQ-#5<,34Q7#$V-EPQ-#5<,30T
M7#<R(ET@/2`G;65S<V%G92]R9F,X,C(G.PHD;6EM95]M86=I8ULP75LY75LB
M7#$R,UPQ-C1<,30Q7#$V,EPQ-C1<,3`V7#$U-UPQ-39<,38T(ET@/2`G9F]N
M="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M86=I8ULP75LY75LB7#(Q,5PQ,31<
M,3,R7#$Q-UPP7#$U7#$R7#,R7#$R(ET@/2`G87!P;&EC871I;VXO9&%T82<[
M"B1M:6UE7VUA9VEC6S!=6SE=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<-3=<
M,38R7#$T,R)=(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;.5U;
M(EPT,UPT,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<,34P(ET@/2`G87!P;&EC
M871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-35<,38R7#$U-UPQ
M-35<-C%<,30V7#$V,UPU-5PV,")=(#T@)V%P<&QI8V%T:6]N+W@M9FEL97-Y
M<W1E;2<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-S1<,3`R7#$U-UPQ-3=<,34S
M7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%P<&QI8V%T:6]N+W@M9G)A;65M86ME
M<B<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,3$W7#$U-EPQ-31<,3<Q7#0P7#$U
M,5PQ-39<-#`B72`]("=T97AT+W@M<&%T8V@G.PHD;6EM95]M86=I8ULP75LX
M75LB7#$T-UPQ-3%<,34U7#$V,%PT,%PQ-S!<,30S7#$T-B)=(#T@)V%P<&QI
M8V%T:6]N+W@M9VEM<"UI;6%G92<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,34U
M7#$V,UPQ-#=<,30S7#$T,5PQ-C1<-C!<-C$B72`]("=A<'!L:6-A=&EO;B]X
M+6QO8V%L92<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,S)<,30Q7#$V,EPQ-#-<
M,34P7#$U,5PQ-C9<,30U(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6SA=6R)<-#%<-S1<,3(P7#$P-%PQ,#9<-S9<-#%<,34V(ET@
M/2`G87!P;&EC871I;VXO>"UP<F]F)SL*)&UI;65?;6%G:6-;,%U;.%U;(EPW
M-%PQ,35<,3$Q7#$P-EPQ,#9<,34Q7#$U-%PQ-#4B72`]("=A<'!L:6-A=&EO
M;B]X+69R86UE;6%K97(G.PHD;6EM95]M86=I8ULP75LW75LB7#$P,5PQ-C)<
M,38T7#$U,5PQ-#-<,34T7#$T-2)=(#T@)VUE<W-A9V4O;F5W<R<["B1M:6UE
M7VUA9VEC6S!=6S==6R)<,3(P7#$P,UPQ,#1<,3,W7#$Q-UPQ,C!<,3`Q(ET@
M/2`G>"]X+7!H;W1O+6-D+6]V97)F:65W+69I;&4G.PHD;6EM95]M86=I8ULP
M75LW75LB7#,U,5PU-%PQ7#$Q,EPQ,#%<,3$U7#$Q(ET@/2`G87!P;&EC871I
M;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S==6R)<-#%<-S1<,30Q7#$V,EPQ
M-#-<,34P7#<V(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC
M6S!=6S==6R)<-S)<-#!<,38S7#$U,%PQ-#5<,34T7#$U-")=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LV75LB7#$Q-EPQ-C5<,3`V
M7#$U,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA
M9VEC6S!=6S9=6R)<,3$V7#,V-5PQ,#9<,S4Q7#$U-%PS-#4B72`]("=A<'!L
M:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPV,%PV-UPV,%PV
M-UPV,%PV,2)=(#T@)V%P<&QI8V%T:6]N+W@M8W!I;R<["B1M:6UE7VUA9VEC
M6S!=6S9=6R)<-C!<-C=<-C!<-C=<-C!<-C(B72`]("=A<'!L:6-A=&EO;B]X
M+6-P:6\G.PHD;6EM95]M86=I8ULP75LV75LB7#8P7#8W7#8P7#8W7#8P7#8W
M(ET@/2`G87!P;&EC871I;VXO>"UC<&EO)SL*)&UI;65?;6%G:6-;,%U;-EU;
M(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R(ET@/2`G87!P;&EC871I;VXO>"UF
M<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPW-%PQ,C1<,3$Q7#$R
M-%PQ,31<,3`U(ET@/2`G=&5X="]H=&UL)SL*)&UI;65?;6%G:6-;,%U;-EU;
M(EPW-%PQ-C1<,34Q7#$V-%PQ-31<,30U(ET@/2`G=&5X="]H=&UL)SL*)&UI
M;65?;6%G:6-;,%U;-5U;(EPP7#%<,%PP7#`B72`]("=F;VYT+W1T9B<["B1M
M:6UE7VUA9VEC6S!=6S5=6R)<,%PT7#,V7#(Q,EPR,#`B72`]("=A<'!L:6-A
M=&EO;B]C;W)E)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#)<,3`Q7#$P,EPQ
M,S%<,3$T(ET@/2`G;65S<V%G92]X+6=N=2UR;6%I;"<["B1M:6UE7VUA9VEC
M6S!=6S5=6R)<,3`R7#$P-5PQ,#=<,3$Q7#$Q-B)=(#T@)V%P<&QI8V%T:6]N
M+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#-<,34W7#$V,EPQ-#5<
M,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?
M;6%G:6-;,%U;-5U;(EPQ,#1<-C%<-39<-C!<,34B72`]("=F;VYT+W@M<W!E
M961O)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#9<,38R7#$U-UPQ-35<-S(B
M72`]("=M97-S86=E+W)F8S@R,B<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,3$U
M7#$P,5PQ,C-<,3,W7#$R-2)=(#T@)V%U9&EO+W@M;75L=&EM871E+6UO9"<[
M"B1M:6UE7VUA9VEC6S!=6S5=6R)<,3(P7#$Q-UPQ,S9<,3(Q7#$T,")=(#T@
M)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I8ULP75LU75LB7#$R,%PQ
M-#%<,38T7#$U,%PW,B)=(#T@)VUE<W-A9V4O;F5W<R<["B1M:6UE7VUA9VEC
M6S!=6S5=6R)<,3,P7#$V,EPQ-#5<,30V7#<R(ET@/2`G;65S<V%G92]N97=S
M)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ-#1<,34Q7#$T-EPQ-#9<-#`B72`]
M("=T97AT+W@M<&%T8V@G.PHD;6EM95]M86=I8ULP75LU75LB7#(R-5PV-%PV
M,EPV,EPS,S8B72`]("=A<'!L:6-A=&EO;B]X+6QO8V%L92<["B1M:6UE7VUA
M9VEC6S!=6S5=6R)<,S,V7#8R7#8R7#8T7#(R-2)=(#T@)V%P<&QI8V%T:6]N
M+W@M;&]C86QE)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ,3!<,3`U7#$P
M,5PQ,#0B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I8ULP75LU75LB7#<T
M7#$Q,%PQ,C1<,3$U7#$Q-")=(#T@)W1E>'0O:'1M;"<["B1M:6UE7VUA9VEC
M6S!=6S5=6R)<-S1<,34P7#$T-5PQ-#%<,30T(ET@/2`G=&5X="]H=&UL)SL*
M)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ-3!<,38T7#$U-5PQ-30B72`]("=T
M97AT+VAT;6PG.PHD;6EM95]M86=I8ULP75LU75LB7#<U7#<T7#$T,5PQ-C)<
M-S8B72`]("=A<'!L:6-A=&EO;B]X+6%R)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPP7#!<,%PS,30B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#!<-")=(#T@)V9O;G0O>"US
M;F8G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#$P-R)=(#T@)V%P<&QI
M8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<
M,%PQ7#$Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,5PQ,34B72`]("=A<'!L:6-A=&EO
M;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP
M7#%<,3$W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD
M;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#(P,2)=(#T@)V%P<&QI8V%T:6]N
M+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#(P
M-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB
M7#!<,%PQ7#(V,R)=(#T@)W9I9&5O+VUP96<G.PHD;6EM95]M86=I8ULP75LT
M75LB7#!<,%PQ7#(W,B)=(#T@)W9I9&5O+VUP96<G.PHD;6EM95]M86=I8ULP
M75LT75LB7#!<,%PQ7#8B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M
M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#(P,5PQ-30B72`]("=A
M<'!L:6-A=&EO;B]X+6%P;"UW;W)K<W!A8V4G.PHD;6EM95]M86=I8ULP75LT
M75LB7#!<,%PS-S=<,30U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I
M;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PS-S=<,34U(ET@/2`G87!P
M;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#-<,S0W
M(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#!<,%PS7#,V,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T
M86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#$T-%PQ-C-<-38B
M72`]("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PQ7#(R
M7#$R-R)=(#T@)V%P<&QI8V%T:6]N+V-O<F4G.PHD;6EM95]M86=I8ULP75LT
M75LB7#!<,C)<,S(V7#(P-R)=(#T@)VEM86=E+W@Q,2<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,%PS7#(S,UPS-34B72`]("=A<'!L:6-A=&EO;B]D871A)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPP7#-<,C,S7#,U-B)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#!<-5PR-EPP(ET@/2`G
M87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PU7#(V
M7#<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPP7#5<-C%<,30R(ET@/2`G87!P;&EC871I;VXO>"UD8B<["B1M:6UE7VUA
M9VEC6S!=6S1=6R)<,%PV7#(U7#$T,2)=(#T@)V%P<&QI8V%T:6]N+W@M9&(G
M.PHD;6EM95]M86=I8ULP75LT75LB7#$P,UPQ,C1<,3$U7#$P-B)=(#T@)V%U
M9&EO+W@M8VUF)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,#5<,3$U7#$Q-UPQ
M,#0B72`]("=A=61I;R]X+65M;V0G.PHD;6EM95]M86=I8ULP75LT75LB7#$P
M-EPQ,#9<,3$Q7#$Q-")=(#T@)V9O;G0O='1F)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPQ,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M=F9O;G0G.PHD;6EM
M95]M86=I8ULP75LT75LB7#$P-UPQ,#1<,3`R7#$Q-2)=(#T@)V%P<&QI8V%T
M:6]N+W@M9V1B;2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3`W7#$Q,5PQ,#9<
M-S`B72`]("=I;6%G92]G:68G.PHD;6EM95]M86=I8ULP75LT75LB7#$P7#$V
M7#$R7#$W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,3$P7#$R,%PQ,#%<,3$S(ET@/2`G87!P;&EC871I;VXO9&%T82<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$Q7#$Q,5PQ,39<-C$B72`]("=I;6%G
M92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,3%<,3$Q7#4R7#`B72`]
M("=I;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,31<,3`T7#$Q
M,%PQ-3$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F;VYT+W1Y<&4Q)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPQ,35<,3$U7#!<-3(B72`]("=I;6%G92]T:69F)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPQ,35<,3$W7#$R-EPQ,3$B72`]("=V:61E
M;R]X+7-G:2UM;W9I92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$U7#$R-%PQ
M-3!<,30T(ET@/2`G875D:6\O;6ED:2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,3$U7#(T-UPS-39<,S4P(ET@/2`G9F]N="]X+6AP+7=I;F1O=W,G.PHD;6EM
M95]M86=I8ULP75LT75LB7#$Q-EPQ,C1<,3(R7#$Q,R)=(#T@)V%U9&EO+W@M
M;75L=&ET<F%C:R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3(P7#$Q,UPS7#0B
M72`]("=A<'!L:6-A=&EO;B]Z:7`G.PHD;6EM95]M86=I8ULP75LT75LB7#$R
M,EPQ,3%<,3`V7#$P-B)=(#T@)V%U9&EO+W@M=V%V)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPQ,C)<,30Q7#$V,EPT,2)=(#T@)V%P<&QI8V%T:6]N+W@M<F%R
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C-<,3(Q7#$R,UPQ,3`B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C1<,3`Q
M7#$P-%PQ,C,B72`]("=A<'!L:6-A=&EO;B]X+71A9',M9V%M92<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,3(U7#$P,UPV,EPS,B)=(#T@)V%P<&QI8V%T:6]N
M+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#$R-5PQ,39<-C!<-C4B72`]
M("=A=61I;R]X+6UI:VUO9"UU;FDG.PHD;6EM95]M86=I8ULP75LT75LB7#$R
M7#$W7#$P7#$V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,3,Q7#(T-EPQ-3)<,C(U(ET@/2`G>"]X+6EM86=E+7-U;BUR
M87-T97(G.PHD;6EM95]M86=I8ULP75LT75LB7#$T-5PS-S=<,%PP(ET@/2`G
M87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,34P7#$V
M,UPQ-3%<-C$B72`]("=I;6%G92]X+6IP96<M<')O<')I971A<GDG.PHD;6EM
M95]M86=I8ULP75LT75LB7#$V7#$P7#$W7#$R(ET@/2`G87!P;&EC871I;VXO
M9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3<W7#$P-5PQ,31<,3`V(ET@
M/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#$W7#$R7#$V7#$P(ET@/2`G87!P;&EC871I;VXO9&%T82<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,5PQ,S!<-#%<,C0V(ET@/2`G87!P;&EC
M871I;VXO8V]R92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,5PQ-#9<,30S7#$V
M,")=(#T@)V9O;G0O>"UP8V8G.PHD;6EM95]M86=I8ULP75LT75LB7#(Q,5PQ
M,C!<,3$V7#$P-R)=(#T@)VEM86=E+W@M<&YG)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPR,UPQ,C=<,C,R7#,Q-B)=(#T@)V%P<&QI8V%T:6]N+W@M9V1B;2<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$P-")=(#T@)V9O;G0O
M>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR,UPQ-S)<-3%<
M,3`W(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M86=I8ULP75LT
M75LB7#(S7#$W,EPU,5PQ,C`B72`]("=F;VYT+W@M<W5N;W,M;F5W<R<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$R,2)=(#T@)V9O;G0O>"US
M=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR-%PR7#$S,5PS,2)=
M(#T@)V9O;G0O>"UL:6)G<G@G.PHD;6EM95]M86=I8ULP75LT75LB7#(V,%PV
M,5PV,UPQ-#`B72`]("=A<'!L:6-A=&EO;B]X+6)O;W1A8FQE)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPR7#$P7#%<,3`B72`]("=A<'!L:6-A=&EO;B]X+65X
M96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,%PQ7#8B
M72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA
M9VEC6S!=6S1=6R)<,EPQ,%PQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U
M=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,%PS-S=<,30U
M(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#)<,3)<,5PQ,")=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T
M86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$R7#%<-R)=(#T@
M)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPR7#$R7#,W-UPQ-#4B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A
M<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,UPQ7#$P(ET@/2`G
M87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP
M75LT75LB7#)<,3-<,5PQ,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L
M92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$S7#%<,34B72`]("=A
M<'!L:6-A=&EO;B]X+6QI8G)A<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,EPQ,UPQ7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3-<,5PV(ET@/2`G87!P;&EC871I
M;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,UPQ
M7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#$P(ET@/2`G87!P;&EC871I;VXO>"UE
M>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,31<,5PQ
M,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPR7#$T7#%<,30B72`]("=A<'!L:6-A=&EO;B]X+6QI
M<W`G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,31<,5PQ-2)=(#T@)V%P<&QI
M8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR
M7#$T7#%<,38B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A<GDM9FEL92<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#8B72`]("=A<'!L:6-A=&EO;B]X
M+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ
M7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,EPQ-%PS-S=<,30U(ET@/2`G87!P;&EC871I;VXO
M>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C!<,5PQ
M,")=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPR7#(P7#%<,3,B72`]("=A<'!L:6-A=&EO;B]X+65X
M96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR,%PQ7#$U
M(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#)<,C!<,5PQ-B)=(#T@)V%P<&QI8V%T:6]N+W@M;&EB<F%R
M>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P7#%<-B)=(#T@)V%P
M<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB
M7#)<,C!<,5PW(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PQ,")=(#T@)V%P<&QI8V%T
M:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR
M7#(T7#%<,3,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ7#$U(ET@/2`G87!P;&EC871I
M;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ
M7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#)<,C1<,5PV(ET@/2`G87!P;&EC871I;VXO>"UO8FIE
M8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ7#<B72`]("=A
M<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,S8Q7#8P7#$P,%PR-S,B72`]("=I;6%G92]X+6-M=2UR87-T97(G
M.PHD;6EM95]M86=I8ULP75LT75LB7#,V-EPS-C9<,S8V7#,V-B)=(#T@)V%P
M<&QI8V%T:6]N+W@M<&,M9FQO<'!Y)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPS
M-S=<,3`V7#$Q-UPQ,38B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPT,5PW-%PQ-#%<,38R(ET@/2`G87!P;&EC871I;VXO>"UA<B<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<,3%<-3<B72`]("=T97AT+W-C
M<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<-#!<-3<B72`]("=T
M97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-3)<,3(S7#$R-%PQ
M,#$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPU,EPU,EPU,EPT,")=(#T@)W1E>'0O>"UP871C:"<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<-39<,38R7#$T,5PS-S4B72`]("=A=61I;R]X+7!N+7)E86QA
M=61I;R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-39<,38S7#$U-EPQ-#0B72`]
M("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-C%<,30S7#$V
M-UPT,")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT
M75LB7#8Q7#(W-EPP7#`B72`]("=T97AT+W9N9"YM<RUW;W)D)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPV,EPV,EPV-UPW,")=(#T@)V%P<&QI8V%T:6]N+V1A
M=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#<T7#$Q-5PQ,35<,3$T(ET@/2`G
M87!P;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPW-%PQ-#%<,38R7#<V(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE
M7VUA9VEC6S!=6S-=6R)<,3`R7#$S,EPQ-3`B72`]("=A<'!L:6-A=&EO;B]X
M+6)Z:7`R)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ,#9<,3`Q7#$R,B)=(#T@
M)V%U9&EO+VUO9"<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,3$U7#$R-%PQ,34B
M72`]("=A=61I;R]X+6UU;'1I=')A8VLG.PHD;6EM95]M86=I8ULP75LS75LB
M7#$R,UPQ,#)<,3$Q(ET@/2`G875D:6\O>"US8FDG.PHD;6EM95]M86=I8ULP
M75LS75LB7#$R-%PQ,3=<,3`S(ET@/2`G875D:6\O>"UT;V,G.PHD;6EM95]M
M86=I8ULP75LS75LB7#$R7#$P-UPQ,30B72`]("=A<'!L:6-A=&EO;B]D871A
M)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ-#9<,34T7#$T,R)=(#T@)V%P<&QI
M8V%T:6]N+W@M9F]N="<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,30V7#$U-%PQ
M-#8B72`]("=F;VYT+W@M9FEG;&5T)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPS
M,UPQ,#5<,S,B72`]("=I;6%G92]X+7!C;"UH<"<["B1M:6UE7VUA9VEC6S!=
M6S-=6R)<,S-<,30S7#,S(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6S-=6R)<,S<W7#,W-UPQ-S0B72`]("=A<'!L:6-A=&EO;B]D
M871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPS-S=<,S<W7#$W-B)=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB7#,W-UPS-S=<
M,3<W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S-=
M6R)<-#-<-#%<-#`B72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=
M6S-=6R)<-#-<-#%<-3<B72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC
M6S!=6S-=6R)<-%PT-5PT,2)=(#T@)V%P<&QI8V%T:6]N+W!O<W1S8W)I<'0G
M.PHD;6EM95]M86=I8ULP75LS75LB7#4U7#$U,%PU-2)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB7#8Q7#$T,UPQ-C<B72`]
M("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPP7#`B
M72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA
M9VEC6S!=6S)=6R)<,3`R7#$Q-2)=(#T@)VEM86=E+W@M8FUP)SL*)&UI;65?
M;6%G:6-;,%U;,EU;(EPQ,#)<,3,R(ET@/2`G87!P;&EC871I;VXO>"UB>FEP
M)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,3%<,3`S(ET@/2`G:6UA9V4O>"UI
M8V\G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q,EPQ,38B72`]("=A=61I;R]X
M+38V.2UM;V0G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q-5PQ,S(B72`]("=A
M<'!L:6-A=&EO;B]X+6US+61O<RUE>&5C=71A8FQE)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPQ,C!<-C$B72`]("=I;6%G92]X+7!O<G1A8FQE+6)I=&UA<"<[
M"B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8R(ET@/2`G:6UA9V4O>"UP;W)T
M86)L92UG<F%Y;6%P)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,C!<-C,B72`]
M("=I;6%G92]X+7!O<G1A8FQE+7!I>&UA<"<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,3(P7#8T(ET@/2`G:6UA9V4O>"UP;W)T86)L92UB:71M87`G.PHD;6EM
M95]M86=I8ULP75LR75LB7#$R,%PV-2)=(#T@)VEM86=E+W@M<&]R=&%B;&4M
M9W)A>6UA<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8V(ET@/2`G:6UA
M9V4O>"UP;W)T86)L92UP:7AM87`G.PHD;6EM95]M86=I8ULP75LR75LB7#$U
M,5PQ-#8B72`]("=A=61I;R]X+38V.2UM;V0G.PHD;6EM95]M86=I8ULP75LR
M75LB7#$V,5PS,#<B72`]("=A<'!L:6-A=&EO;B]X+6-P:6\G.PHD;6EM95]M
M86=I8ULP75LR75LB7#$V-EPS-S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*
M)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$Q,")=(#T@)V%P<&QI8V%T:6]N+W@M
M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$Q,2)=
M(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPQ7#$R-")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM
M95]M86=I8ULP75LR75LB7#%<,3(U(ET@/2`G87!P;&EC871I;VXO>"UE>&5C
M=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,38P(ET@/2`G
M87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP
M75LR75LB7#%<,38Q(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I
M;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,3<U(ET@/2`G87!P;&EC871I
M;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<
M,3<W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM
M95]M86=I8ULP75LR75LB7#%<,C`B72`]("=A<'!L:6-A=&EO;B]X+65X96-U
M=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,5PR,#,B72`]("=A
M<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,5PR,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE
M)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#(Q,")=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#(Q
M-R)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I
M8ULP75LR75LB7#%<,C(T(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE
M+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C(W(ET@/2`G87!P;&EC
M871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB
M7#%<,S,R(ET@/2`G>"]X+6EM86=E+7-G:2<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,5PS-B)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,5PV(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD
M;6EM95]M86=I8ULP75LR75LB7#,P-UPQ-C$B72`]("=A<'!L:6-A=&EO;B]X
M+6)C<&EO)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS,3-<-2)=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,U,EPQ-#`B72`]
M("=A<'!L:6-A=&EO;B]X+6%R:B<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S8W
M7#$S,2)=(#T@)V9O;G0O>"UT97@G.PHD;6EM95]M86=I8ULP75LR75LB7#,V
M-UPR,#,B72`]("=F;VYT+W@M=&5X)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS
M-C=<,S$R(ET@/2`G9F]N="]X+71E>"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<
M,S9<,2)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE7VUA9VEC6S!=6S)=6R)<
M,S<U7#$V-B)=(#T@)V%P<&QI8V%T:6]N+W@M;'IH)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPS-S9<,38V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,S<W7#$T-2)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G
M.PHD;6EM95]M86=I8ULP75LR75LB7#,W-UPQ-34B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-S=<,38V(ET@/2`G87!P
M;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S<W7#,S,")=
M(#T@)VEM86=E+VIP96<G.PHD;6EM95]M86=I8ULP75LR75LB7#,W-UPS-R)=
M(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W
M7#(Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M9WII<"<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,S=<,C,U(ET@/2`G87!P;&EC871I;VXO8V]M<')E<W,G.PHD;6EM
M95]M86=I8ULP75LR75LB7#,W7#(S-B)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G
M.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(S-R)=(#T@)V%P<&QI8V%T:6]N
M+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(T,")=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#,V(ET@/2`G
M87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S=<,S<B
M72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS
M-UPS-S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;
M,EU;(EPT-5PT,2)=(#T@)V%P<&QI8V%T:6]N+W!O<W1S8W)I<'0G.PHD;6EM
M95]M86=I8ULP75LR75LB7#1<-C8B72`]("=F;VYT+VQI;G5X+7!S9B<["B1M
M:6UE7VUA9VEC6S!=6S)=6R)<-3=<-3<B72`]("=T97AT+V-P<"<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<-5PQ(ET@/2`G87!P;&EC871I;VXO>"UL;V-A;&4G
M.PHD;6EM95]M86=I8ULP75LR75LB7#9<,2)=(#T@)V%P<&QI8V%T:6]N+W@M
M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPV7#(B72`]
M("=A<'!L:6-A=&EO;B]X+6%L86XM861V96YT=7)E+6=A;64G.PHD;6EM95]M
M86=I8ULP75LR75LB7#=<,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L
M92UF:6QE)SL*)&UI;65?;6%G:6-;,5U;,UU;(EPQ,C!<,3$V7#$P-R)=(#T@
M)VEM86=E+W@M<&YG)SL*)&UI;65?;6%G:6-;,5U;,UU;(EPQ,C=<,3(P7#$P
M,R)=(#T@)V%P<&QI8V%T:6]N+W9N9"YW;W)D<&5R9F5C="<["B1M:6UE7VUA
M9VEC6S)=6S9=6R)<-35<,34T7#$U,%PV-%PV,%PU-2)=(#T@)V%P<&QI8V%T
M:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#$T
M-%PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;
M-5U;(EPU-5PQ-31<,34P7#8P7#4U(ET@/2`G87!P;&EC871I;VXO>"UL:&$G
M.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-3!<-C%<-34B72`]("=A
M<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=6R)<-35<,34T
M7#$U,%PV,EPU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G
M:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8S7#4U(ET@/2`G87!P;&EC871I;VXO
M>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-3!<-C1<-34B
M72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=6R)<
M-35<,34T7#$U,%PV-5PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI
M;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,3<R7#$V,UPU-2)=(#T@)V%P<&QI
M8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,3<R
M7#8T7#4U(ET@/2`G87!P;&EC871I;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR
M75LU75LB7#4U7#$U-%PQ-S)<-C5<-34B72`]("=A<'!L:6-A=&EO;B]X+6QH
M82<["B1M:6UE7VUA9VEC6S)=6S)=6R)<,%PR,2)=(#T@)V9O;G0O>"UT97@M
M=&9M)SL*)&UI;65?;6%G:6-;,EU;,EU;(EPP7#(R(ET@/2`G9F]N="]X+71E
M>"UT9FTG.PHD;6EM95]M86=I8ULT75LT75LB7#$U-5PQ-#1<,30Q7#$V-")=
M(#T@)W9I9&5O+W%U:6-K=&EM92<["B1M:6UE7VUA9VEC6S1=6S1=6R)<,34U
M7#$U-UPQ-3=<,38V(ET@/2`G=FED96\O<75I8VMT:6UE)SL*)&UI;65?;6%G
M:6-;-%U;-%U;(EPQ-C!<,34Q7#$V,%PQ-#4B72`]("=A<'!L:6-A=&EO;B]D
M871A)SL*)&UI;65?;6%G:6-;-%U;-%U;(EPQ-C!<,38R7#$U-UPQ-#8B72`]
M("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;-%U;,EU;(EPR-3=<
M,C$B72`]("=V:61E;R]F;&DG.PHD;6EM95]M86=I8ULT75LR75LB7#(U-UPR
M,B)=(#T@)W9I9&5O+V9L8R<["B1M:6UE7VUA9VEC6S9=6S$X75LB7#0U7#0Q
M7#$R,%PQ,C-<-35<,3`Q7#$T-%PQ-3=<,30R7#$T-5PQ,#9<,34W7#$U-EPQ
M-C1<-35<-C%<-39<-C`B72`]("=F;VYT+W1Y<&4Q)SL*)&UI;65?;6%G:6-;
M-UU;,C)=6R)<,S4W7#(P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P
M7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P(ET@/2`G87!P;&EC871I
M;VXO8V]R92<["B1M:6UE7VUA9VEC6S==6S1=6R)<,%PQ,#5<,3`W7#$P,2)=
M(#T@)V9O;G0O>"UD;W,G.PHD;6EM95]M86=I8ULW75LT75LB7#!<,3(V7#$Q
M,5PQ,#0B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G:6-;.%U;-%U;(EPR
M,UPQ-S)<-3-<,3`U(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M
M86=I8ULX75LT75LB7#(S7#$W,EPU,UPQ,3`B72`]("=F;VYT+W@M<W5N;W,M
M;F5W<R<["B1M:6UE7VUA9VEC6S$P75LR-5U;(EPT,UPT,%PQ,C1<,34P7#$U
M,5PQ-C-<-#!<,34Q7#$V,UPT,%PQ-#%<-#!<,38S7#$U,%PQ-#5<,34T7#$U
M-%PT,%PQ-#%<,38R7#$T,UPQ-3!<,34Q7#$V-EPQ-#4B72`]("=A<'!L:6-A
M=&EO;B]X+7-H87(G.PHD;6EM95]M86=I8ULR,%U;-%U;(EPQ,#=<,3$Q7#$Q
M-5PQ,C`B72`]("=A<'!L:6-A=&EO;B]X+6=I;7`M8G)U<V@G.PHD;6EM95]M
M86=I8ULR,%U;-%U;(EPQ,#=<,3(P7#$P,5PQ,C0B72`]("=A<'!L:6-A=&EO
M;B]X+6=I;7`M<&%T=&5R;B<["B1M:6UE7VUA9VEC6S(P75LT75LB7#,W-5PS
M,#1<,C0W7#,S-")=(#T@)V%P<&QI8V%T:6]N+W@M>F]O)SL*)&UI;65?;6%G
M:6-;,C%=6SA=6R)<-#%<,3(S7#$P,UPQ,C)<,3`U7#$P,5PQ,35<-#$B72`]
M("=A=61I;R]X+7-T,BUM;V0G.PHD;6EM95]M86=I8ULR-%U;-%U;(EPP7#!<
M,S4R7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M9'5M<"<["B1M:6UE7VUA9VEC
M6S(T75LT75LB7#!<,%PS-3)<,34T(ET@/2`G87!P;&EC871I;VXO>"UD=6UP
M)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<,%PP7#,U,EPQ-34B72`]("=A<'!L
M:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<,%PP7#,U,EPQ
M-38B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;-C5=6S1=
M6R)<,3`V7#$P-EPQ,3%<,3$T(ET@/2`G9F]N="]T=&8G.PHD;6EM95]M86=I
M8ULV-5U;-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F;VYT+W1Y<&4Q)SL*
M)&UI;65?;6%G:6-;,C4W75LX75LB7#$V-5PQ-C-<,38T7#$T,5PQ-C)<-#!<
M-#!<-C`B72`]("=A<'!L:6-A=&EO;B]X+6=T87(G.PHD;6EM95]M86=I8ULR
M-3==6S9=6R)<,38U7#$V,UPQ-C1<,30Q7#$V,EPV,")=(#T@)V%P<&QI8V%T
M:6]N+W@M=&%R)SL*)&UI;65?;6%G:6-;,#<W-%U;,EU;(EPS,S)<,C<V(ET@
M/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<
M,3`S7#$P-%PW,%PV,2)=(#T@)V%U9&EO+W@M;VMT86QY>F5R+6UO9"<["B1M
M:6UE7VUA9VEC6S$P.#!=6S1=6R)<,3`V7#$Q-%PQ,C1<-C0B72`]("=A=61I
M;R]X+7-T87)T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<
M,3$U7#0Q7#$Q,UPT,2)=(#T@)V%U9&EO+W@M<')O=')A8VME<BUM;V0G.PHD
M;6EM95]M86=I8ULQ,#@P75LT75LB7#$Q-5PU-EPQ,3-<-38B72`]("=A=61I
M;R]X+7!R;W1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPQ
M,3=<,3$S7#$R-%PQ,#$B72`]("=A=61I;R]X+6]K=&%L>7IE<BUM;V0G.PHD
M;6EM95]M86=I8ULQ,#@P75LT75LB7#8Q7#8V7#$P,UPQ,38B72`]("=A=61I
M;R]X+71A:V5T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<
M-C-<-C)<,3`S7#$Q-B)=(#T@)V%U9&EO+W@M=&%K971R86-K97(M;6]D)SL*
M)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPV-%PQ,#-<,3$P7#$Q-B)=(#T@)V%U
M9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;
M(EPV-EPQ,#-<,3$P7#$Q-B)=(#T@)V%U9&EO+W@M9F%S='1R86-K97(M;6]D
M)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPW,%PQ,#-<,3$P7#$Q-B)=(#T@
M)V%U9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,C`T.%U;
M-UU;(EPQ,C!<,3`S7#$P-%PQ,S=<,3$Q7#$R,%PQ,3$B72`]("=X+W@M<&AO
M=&\M8V0M<&%C:RUF:6QE)SL*)&UI;65?;6%G:6-;,C`X,%U;,CE=6R)<,3$U
M7#$U,5PQ-#-<,38R7#$U-UPQ-C-<,34W7#$T-EPQ-C1<-#!<,3`U7#$W,%PQ
M-#-<,30U7#$U-%PT,%PV-5PU-EPV,%PT,%PQ,C=<,34W7#$V,EPQ-3-<,38S
M7#$U,%PQ-#5<,30U7#$V-")=(#T@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E
M;"<["B1M:6UE7VUA9VEC6S(P.#!=6S(W75LB7#$Q-5PQ-3%<,30S7#$V,EPQ
M-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R-UPQ-3=<,38R7#$T-%PT,%PV-EPU
M-EPV,%PT,%PQ,#1<,34W7#$T,UPQ-C5<,34U7#$T-5PQ-39<,38T(ET@/2`G
M=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC6S(P.#!=6S(V75LB7#$P
M-%PQ-3=<,30S7#$V-5PQ-35<,30U7#$U-EPQ-C1<,34W7#0P7#$Q-5PQ-3%<
M,30S7#$V,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R-UPQ-3=<,38R7#$T
M-%PT,%PV-B)=(#T@)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I8ULR
M,3$R75LY75LB7#$Q-5PQ,C-<,3(W7#$U-UPQ-C)<,30T7#$P-%PQ-3=<,30S
M(ET@/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC6S(Q,31=6S5=
M6R)<,3`R7#$U,5PQ-#9<,30V7#8U(ET@/2`G87!P;&EC871I;VXO=FYD+FUS
M+65X8V5L)SL*)&UI;65?;6%G:6-;-#`Y.%U;-UU;(EPQ,#1<,3$W7#$R,UPQ
M,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G:6-;
M-C@Q-3@T.#!=6S)=6R)<,C-<,3<W(ET@/2`G87!P;&EC871I;VXO>"UF:6QE
M<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<,C-<,C$W(ET@
M/2`G87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q
M-3@T.#!=6S)=6R)<-#1<,34P(ET@/2`G87!P;&EC871I;VXO>"UF:6QE<WES
M=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<-#1<,3<P(ET@/2`G
M87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-S`W-SDY
M-C!=6S)=6R)<,S4W7#$R,R)=(#T@)V%P<&QI8V%T:6]N+W@M;&EN=7@M97AT
M,F9S)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4
M97AT+P``````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-C$`,#$W,30S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+P``````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,0`P,C`S-S``
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<```````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V,3<Q`#$P
M-3$U-#,Q,#8Q`#`R-#,Q-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J($AI
M9VAL:6=H=',@<75O=&5D(&UE<W-A9V5S('=I=&@@9&EF9F5R96YT(&-O;&]R
M<R!F;W(@=&AE(&1I9F9E<F5N="!Q=6]T:6YG"B`J(&QE=F5L<RX*("H*("H@
M0U-3(&-L87-S(&YA;65S(&-A;&QE9"`B<75O=&5D,2(@+BXN(")Q=6]T961[
M)&-S<TQE=F5L<WTB(&UU<W0@8F4@<')E<V5N="X*("H@5&AE('1E>'0@=&\@
M8F4@<&%S<V5D(&EN(&UU<W0@:&%V92!A;')E861Y(&)E96X@<&%S<V5D('1H
M<F]U9V@*("H@:'1M;'-P96-I86QC:&%R<R@I+@H@*@H@*B!087)A;65T97)S
M.@H@*B`\<')E/@H@*B`G8VET96)L;V-K)R`@+2T@1&ES<&QA>2!C:71E(&)L
M;V-K<S\@1&5F875L=',@=&\@=')U92X*("H@)V-S<TQE=F5L<R<@("TM($YU
M;6)E<B!O9B!D969I;F5D($-34R!C;&%S<R!N86UE<RX@1&5F875L=',@=&\@
M-2X*("H@)VAI9&5";&]C:W,G("TM($AI9&4@<75O=&5D('1E>'0@8FQO8VMS
M(&)Y(&1E9F%U;'0_($1E9F%U;'1S('1O(&9A;'-E+@H@*B`\+W!R93X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`L=B`Q+C8N."XQ-B`R,#`V+S`X+S$V(#$V.C4V.C`P
M('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8W5R96-A;G1I+F]R9SX*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&-U<F5C86YT:2YO<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]H:6=H
M;&EG:'1Q=6]T97,@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@
M("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@
M("=C:71E8FQO8VLG(#T^('1R=64L"B`@("`@("`@)V-S<TQE=F5L<R<@/3X@
M-2P*("`@("`@("`G:&ED94)L;V-K<R<@/3X@9F%L<V4*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<F%Y(&)E9F]R
M92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL
M=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D
M:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D
M=&5X="D*("`@('L*("`@("`@("`O*B!486-K(&$@;F5W;&EN92!O;G1O('1H
M92!B96=I;FYI;F<@;V8@=&AE('-T<FEN9R!S;R!T:&%T('=E"B`@("`@("`@
M("H@8V]R<F5C=&QY(&AI9VAL:6=H="!W:&5N('1H92!F:7)S="!C:&%R86-T
M97(@:6X@=&AE('-T<FEN9R!I<R!A"B`@("`@("`@("H@<75O=&4@8VAA<F%C
M=&5R+B`J+PH@("`@("`@(')E='5R;B`B7&XD=&5X="(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R
M;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S
M:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@
M("`@("`@("\J(%)E;6]V92!E>'1R82!S<&%C97,@8F5F;W)E('%U;W1E9"!T
M97AT(&%S('1H92!#4U,@9F]R;6%T=&EN9R!W:6QL"B`@("`@("`@("H@875T
M;VUA=&EC86QL>2!A9&0@82!B:70@;V8@<W!A8V4@9F]R('5S+B`J+PH@("`@
M("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG8VET96)L;V-K)UTI('L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^(&%R<F%Y*"(O/&)R(%PO
M/EQS*EQN7',J/&)R(%PO/EQS*EQN7',J*"@F9W0[7',_*2LI+VTB(#T^("(\
M8G(@+SY<;EQ<,2(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A
M>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@
M;F5C97-S87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT
M(&%F=&5R('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!P;W-T4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("`O*B!)<R!T:&5R
M92!A(&)L86YK(&QI;F4H<RD@8F5F;W)E('1H92!C=7)R96YT(&QI;F4_("HO
M"B`@("`@("`@)&)L86YK;&EN92`](&9A;'-E.PH*("`@("`@("`O*B!5<V4@
M8VET92!B;&]C:W,@=&\@9&ES<&QA>2!T:&4@9&EF9F5R96YT('%U;W1I;F<@
M;&5V96QS/R`J+PH@("`@("`@("1C8B`]("1T:&ES+3Y?<&%R86US6R=C:71E
M8FQO8VLG73L*"B`@("`@("`@+RH@0VET92!L979E;"!B969O<F4@<&%R<VEN
M9R!T:&4@8W5R<F5N="!L:6YE+B`J+PH@("`@("`@("1Q;&5V96P@/2`P.PH*
M("`@("`@("`O*B!'96YE<F%T960@;W5T<'5T+B`J+PH@("`@("`@("1T97AT
M7V]U="`]("<G.PH*("`@("`@("`O*B!!9&0@<VAO=R]H:61E('1O9V=L97,@
M9F]R('=H;VQE('%U;W1E(&)L;V-K<RX@*B\*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C95]C86QL8F%C:R@G+RA<;BDH*"`J*"9G=#M<<S\I*R@_(2`_
M)F=T.RDN*C\I*%QN?"0I*#\A("HH)F=T.R`_*2LI*2]S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D=&AI<RP@)U]A
M9&11=6]T951O9V=L97,G*2P@)'1E>'0I.PH*("`@("`@("`O*B!087)S92!T
M97AT(&QI;F4@8GD@;&EN92X@*B\*("`@("`@("!F;W)E86-H("AE>'!L;V1E
M*")<;B(L("1T97AT*2!A<R`D;&EN92D@>PH@("`@("`@("`@("`O*B!#:71E
M(&QE=F5L(&]F(&-U<G)E;G0@;&EN92X@*B\*("`@("`@("`@("`@)&-L979E
M;"`]("1C;&]S96QE=F5L(#T@,#L*("`@("`@("`@("`@)&UA=&-H97,@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`O*B!$;R!W92!H879E(&$@8VET871I;VX@
M;&EN93\@*B\*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',J*"@F
M9W0[7',_*2LI+VTG+"`D;&EN92P@)&UA=&-H97,I*2!["B`@("`@("`@("`@
M("`@("`O*B!#;W5N="!N=6UB97(@;V8@/B!C:&%R86-T97)S(#T^(&-I=&4@
M;&5V96P@*B\*("`@("`@("`@("`@("`@("1C;&5V96P@/2`D8VQO<V5L979E
M;"`](&-O=6YT*'!R96=?<W!L:70H)R\F9W0[7',_+R<L("1M871C:&5S6S%=
M*2D@+2`Q.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&-B("8F
M(&ES<V5T*"1M871C:&5S6S%=*2D@>PH@("`@("`@("`@("`@("`@+RH@4W1R
M:7`@86QL(#X@8VAA<F%C=&5R<RX@*B\*("`@("`@("`@("`@("`@("1L:6YE
M(#T@<W5B<W1R*"1L:6YE+"!3=')I;F<Z.FQE;F=T:"@D;6%T8VAE<ULQ72DI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)<R!T:&ES(&-I=&4@
M;&5V96P@;&]W97(@=&AA;B!T:&4@8W5R<F5N="!L979E;#\@*B\*("`@("`@
M("`@("`@:68@*"1C;&5V96P@/"`D<6QE=F5L*2!["B`@("`@("`@("`@("`@
M("`O*B!3=')I<"!M;W)E('1H86X@;VYE(&)L86YK(&QI;F4@:6X@9G)O;G0@
M;V8@=&AE(&-I=&4*("`@("`@("`@("`@("`@("`J(&)L;V-K<RX@*B\*("`@
M("`@("`@("`@("`@(&EF("@D8FQA;FML:6YE*2!["B`@("`@("`@("`@("`@
M("`@("`@=VAI;&4@*"@D8G)?<W1R(#T@<W5B<W1R*"1T97AT7V]U="P@+3<I
M*2`]/2`B/&)R("\^7&XB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M97AT7V]U="`]('-U8G-T<B@D=&5X=%]O=70L(#`L("TW*3L*("`@("`@("`@
M("`@("`@("`@("!].PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@+RH@061D('%U;W1E(&)L;V-K(&5N9"!T86=S(&9O<B!E86-H(&-I=&4@
M;&5V96PN("HO"B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@)&-L979E;#L@
M)&D@/"`D<6QE=F5L.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)'1E
M>'1?;W5T("X]("@D8V(I(#\@)SPO9&EV/B<@.B`G/"]F;VYT/B<["B`@("`@
M("`@("`@("`@("`@("`@+2TD8VQO<V5L979E;#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("\J(%-T<FEP('1R86EL:6YG(&QI;F4@8G)E
M86L@:68@=7-I;F<@8VET92!B;&]C:W,L('=E(&%L<F5A9'D*("`@("`@("`@
M("`@("`@("`J(&AA=F4@82!D:78@=&%G+B`J+PH@("`@("`@("`@("`@("`@
M:68@*"1C8B`F)B!P<F5G7VUA=&-H*"<O7#QB<B!<+SXD+R<L("1L:6YE*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1L:6YE(#T@<W5B<W1R*"1L:6YE+"`P
M+"`M-BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("\J($ES('1H
M:7,@8VET92!L979E;"!H:6=H97(@=&AA;B!T:&4@8W5R<F5N="!L979E;#\@
M*B\*("`@("`@("`@("`@?2!E;'-E:68@*"1C;&5V96P@/B`D<6QE=F5L*2![
M"B`@("`@("`@("`@("`@("`O*B!3=')I<"!M;W)E('1H86X@;VYE(&)L86YK
M(&QI;F4@:6X@9G)O;G0@;V8@=&AE(&-I=&4*("`@("`@("`@("`@("`@("`J
M(&)L;V-K<RX@*B\*("`@("`@("`@("`@("`@(&EF("@D8FQA;FML:6YE*2![
M"B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"@D8G)?<W1R(#T@<W5B<W1R
M*"1T97AT7V]U="P@+3<I*2`]/2`B/&)R("\^7&XB*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T97AT7V]U="`]('-U8G-T<B@D=&5X=%]O=70L(#`L
M("TW*3L*("`@("`@("`@("`@("`@("`@("!].PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@9F]R("@D:2`]("1Q;&5V96P[("1I(#P@)&-L
M979E;#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("\J($%D9"!Q=6]T
M92!B;&]C:R!S=&%R="!T86=S(&9O<B!E86-H(&-I=&4@;&5V96PN("HO"B`@
M("`@("`@("`@("`@("`@("`@)'1E>'1?;W5T("X]("@D8V(I(#\@)SQD:78@
M8VQA<W,](F-I=&%T:6]N("<@.B`G/&9O;G0@8VQA<W,](B<["B`@("`@("`@
M("`@("`@("`@("`@)'1E>'1?;W5T("X]("=Q=6]T960G("X@*"@D:2`E("1T
M:&ES+3Y?<&%R86US6R=C<W-,979E;',G72D@*R`Q*2`N("<B/B<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-O
M=6YT(&)L86YK(&QI;F5S+B`J+PH@("`@("`@("`@("`D8FQA;FML:6YE(#T@
M*"1L:6YE(#T]("<\8G(@+SXG*3L*"B`@("`@("`@("`@("1T97AT7V]U="`N
M/2`D;&EN92`N(")<;B(["B`@("`@("`@("`@("1Q;&5V96P@/2`D8VQE=F5L
M.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E(&%L;"!D:78O9F]N
M="!T86=S(&%R92!C;&]S960N("HO"B`@("`@("`@:68@*"1C;&]S96QE=F5L
M(#X@,"D@>PH@("`@("`@("`@("`D=&5X=%]O=70@/2!P<F5G7W)E<&QA8V4H
M)R\\7"]D:78^)"\G+"!S=')?<F5P96%T*"@D8V(I(#\@)SPO9&EV/B<@.B`G
M/"]F;VYT/B<L("1C;&]S96QE=F5L*2`N("<\+V1I=CXG+"`D=&5X=%]O=70I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5M;W9E('1H92!L96%D:6YG(&YE
M=VQI;F4@=V4@861D960@86)O=F4L(&EF(&ET)W,@<W1I;&P@=&AE<F4N("HO
M"B`@("`@("`@:68@*"1T97AT7V]U=%LP72`]/2`B7&XB*2!["B`@("`@("`@
M("`@("1T97AT7V]U="`]('-U8G-T<B@D=&5X=%]O=70L(#$I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T97AT7V]U=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@;&EN:W,@=&\@<VAO=R!A;F0@:&ED92!Q=6]T960@8FQO
M8VMS+"!H:61I;F<@=&AE;2!B>2!D969A=6QT(&EF"B`@("`@*B!T:&4@)VAI
M9&5";&]C:W,G('!A<F%M971E<B!I<R!T<G5E+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;6%T
M8VAE<R`@5&AE(&UA=&-H97,@9G)O;2!T:&4@<F5G97AP+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?861D475O=&54;V=G;&5S*"1M871C:&5S*0H@("`@>PH@
M("`@("`@('-T871I8R`D:2`](#`["@H@("`@("`@("\J($1O;B=T('1O9V=L
M92!S;6%L;"!B;&]C:W,[(&1O97-N)W0@<')O=FED92!A(%5)(&)E;F5F:70@
M86YD(&QO;VMS"B`@("`@("`@("H@86YN;WEI;F<N("HO"B`@("`@("`@)&QI
M;F5S(#T@<W5B<W1R7V-O=6YT*"1M871C:&5S6S!=+"`B7&XB*3L*("`@("`@
M("!I9B`H)&QI;F5S(#P@."D@>PH@("`@("`@("`@("!R971U<FX@)&UA=&-H
M97-;,%T["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL
M92@G:&ED96%B;&4N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("!(;W)D
M93HZ861D4V-R:7!T1FEL92@G<75O=&5";&]C:W,N:G,G+"`G:&]R9&4G*3L*
M"B`@("`@("`@)'1E>'0@/2`G)SL*("`@("`@("!I9B`H)'1H:7,M/E]P87)A
M;7-;)V-I=&5B;&]C:R==*2!["B`@("`@("`@("`@("1T97AT(#T@)SQB<B`O
M/B<["B`@("`@("`@?3L*("`@("`@("`D=&5X="`N/2`G/&1I=B!I9#TB<71?
M)R`N("1I("X@)R(^)R`N"B`@("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@
M)R<L("=W:61G970@=&]G9VQE<75O=&4G+"`G)RP@)W1O9V=L95%U;W1E0FQO
M8VLH7"<G("X@)&D@+B`G7"<L(%PG)R`N("1L:6YE<R`N("=<)RD[(')E='5R
M;B!F86QS93LG+"`G)RP@)R<L(&%R<F%Y*"=S='EL92<@/3X@)V9O;G0M<VEZ
M93HW,"4G*2D@+@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)VAI9&5"
M;&]C:W,G72`_('-P<FEN=&8H7R@B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L
M:6YE<UTB*2P@)&QI;F5S*2`Z(%\H(EM(:61E(%%U;W1E9"!497AT72(I*2`N
M"B`@("`@("`@("`@("<\+V$^/"]D:78^/&1I=B!I9#TB<6)?)R`N("1I("X@
M)R(G("X@*"1T:&ES+3Y?<&%R86US6R=H:61E0FQO8VMS)UT@/R`G('-T>6QE
M/2)D:7-P;&%Y.FYO;F4[(B<@.B`G)RD@+B`G/B<@+B`D;6%T8VAE<ULP72`N
M("<\+V1I=CXG.PH*("`@("`@("`D:2LK.PH*("`@("`@("!R971U<FX@)'1E
M>'0["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E
M<B]X<W,N<&AP````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<V,C4`
M,3`U,34T,S$P-C$`,#(Q-S(V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&9I;'1E<B!A='1E
M;7!T<R!T;R!M86ME($A434P@<V%F92!F;W(@=FEE=VEN9RX@250@25,@3D]4
M(%!%4D9%0U0N($EF"B`J('EO=2!E;F%B;&4@2%1-3"!V:65W:6YG+"!Y;W4@
M87)E(&]P96YI;F<@82!S96-U<FET>2!H;VQE+B!7:71H('1H92!C=7)R96YT
M"B`J('-T871E(&]F('1H92!W96(L($D@8F5L:65V92!T:&%T('1H92!B97-T
M('=E(&-A;B!D;R!I<R!T;R!M86ME('-U<F4@=&AA=`H@*B!P96]P;&4@*DM.
M3U<J($A434P@:7,@82!S96-U<FET>2!H;VQE+"!C;&5A;B!U<"!W:&%T('=E
M(&-A;BP@86YD(&QE879E(&ET"B`J(&%T('1H870N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]X<W,N<&AP+'8@,2XQ+C(N
M,R`R,#`V+S`R+S`Y(#$V.C0P.C0Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A8VMA9V4@
M2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?>'-S(&5X=&5N9',@
M5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R('!A<F%M971E
M<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]P87)A;7,@/2!A<G)A>2@G8F]D>5]O;FQY)R`]/B!T<G5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)W)E<&QA8V4G(#T^("=84U-#;&5A;F5D)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("=S=')I<%]S='EL97,G(#T^('1R
M=64I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L
M86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!A
M='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS
M*"D*("`@('L*("`@("`@("`D<&%T=&5R;G,@/2!A<G)A>2@I.PH*("`@("`@
M("`O*B!296UO=F5S($A434P@8V]M;65N=',@*&EN8VQU9&EN9R!S;VUE('-C
M<FEP=',@)B!S='EL97,I+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M
M<ULG<W1R:7!?<W1Y;&5S)UTI('L*("`@("`@("`@("`@)'!A='1E<FYS6R<O
M/"$M+2XJ/RTM/B]S)UT@/2`G)SL*("`@("`@("!]"@H@("`@("`@("\J($-H
M86YG92!S<&%C92!E;G1I=&EE<R!T;R!S<&%C92!C:&%R86-T97)S+B`J+PH@
M("`@("`@("1P871T97)N<ULG+R8C*'@P*C(P?#`J,S(I.S\O:2==(#T@)R`G
M.PH*("`@("`@("`O*B!.=6ME(&YO;BUP<FEN=&%B;&4@8VAA<F%C=&5R<R`H
M82!P;&%Y(&EN('1H<F5E(&%C=',I+B`J+PH*("`@("`@("`O*B!2=6QE(#$I
M+B!296UO=F4@86QL(&-O;G1R;VP@8VAA<F%C=&5R<RX@*B\*("`@("`@("`O
M+R1D871A(#T@<')E9U]R97!L86-E*"<O6UQX,#`M7'@P.%QX,&4M7'@Q9ETO
M)RP@)R<L("1D871A*3L*"B`@("`@("`@+RH@4G5L92`Q*2X@268@=V4@:&%V
M92!A('-E;6EC;VQO;BP@:70@:7,@9&5T97)M:6YI<W1I8V%L;'D@9&5T96-T
M86)L90H@("`@("`@("`J(&%N9"!F:7AA8FQE+"!W:71H;W5T(&EN=')O9'5C
M:6YG(&-O;&QA=&5R86P@9&%M86=E+B`J+PH@("`@("`@("1P871T97)N<ULG
M+R8C>#\P*BA;.4$M1%U\,5LP+3-=*3LO:2==(#T@)R9N8G-P.R<["@H@("`@
M("`@("\J(%)U;&4@,BDN($AE>"!N=6UB97)S("AU<W5A;&QY(&AA=FEN9R!A
M;B!X('!R969I>"D@87)E(&%L<V\*("`@("`@("`@*B!D971E<FUI;FES=&EC
M+"!E=F5N(&EF('=E(&1O;B=T(&AA=F4@=&AE('-E;6DN($YO=&4@=&AA="!S
M;VUE"B`@("`@("`@("H@8G)O=W-E<G,@=VEL;"!T<F5A="`F(V$@;W(@)B,P
M82!A<R!A(&AE>"!N=6UB97(@979E;B!W:71H;W5T('1H92!X"B`@("`@("`@
M("H@<')E9FEX.R!H96YC92`O>#\O('=H:6-H('=I;&P@8V]V97(@=&AO<V4@
M8V%S97,@:6X@=&AI<R!R=6QE+B`J+PH@("`@("`@("1P871T97)N<ULG+R8C
M>#\P*ELY02U$72A;7C`M.4$M1EU\)"DO:2==(#T@)R9N8G-P7%PQ)SL*"B`@
M("`@("`@+RH@4G5L92`S*2X@1&5C:6UA;"!N=6UB97)S('=I=&AO=70@=')A
M:6QI;F<@<V5M:6-O;&]N<RX@5&AE('!R;V)L96T*("`@("`@("`@*B!I<R!T
M:&%T('-O;64@8G)O=W-E<G,@=VEL;"!I;G1E<G!R970@)B,Q,&$@87,@(EQN
M82(L('-O;64@87,*("`@("`@("`@*B`B)B-X,3!A(B!S;R!W92!H879E('1O
M(&-L96%N('1H92`F(S$P('1O(&)E('-A9F4@9F]R('1H92`B7&YA(B!C87-E
M"B`@("`@("`@("H@870@=&AE(&5X<&5N<V4@;V8@;6%N9VQI;F<@82!V86QI
M9"!E;G1I='D@:6X@;W1H97(@8V%S97,N("A3;VQU=&EO;@H@("`@("`@("`J
M(&9O<B!V86QI9"!(5$U,(&%U=&AO<G,Z(&%L=V%Y<R!U<V4@=&AE('-E;6EC
M;VQO;BXI("HO"B`@("`@("`@)'!A='1E<FYS6R<O)B,P*B@Y?#%;,"TS72DH
M6UXP+3E=?"0I+VDG72`]("<F;F)S<%Q<,B<["@H@("`@("`@("\J(%)E;6]V
M92!O=F5R;'D@;&]N9R!N=6UE<FEC(&5N=&ET:65S+B`J+PH@("`@("`@("1P
M871T97)N<ULG+R8C>#\P*ELP+3E!+49=>S8L?3L_+VDG72`]("<F;F)S<#LG
M.PH*("`@("`@("`O*B!296UO=F4@979E<GET:&EN9R!O=71S:61E(&]F(&%N
M9"!I;F-L=61I;F<@=&AE(#QB;V1Y/B!T86<N("HO"B`@("`@("`@:68@*"1T
M:&ES+3Y?<&%R86US6R=B;V1Y7V]N;'DG72D@>PH@("`@("`@("`@("`D<&%T
M=&5R;G-;)R\N*CQB;V1Y6UX^72H^+W-I)UT@/2`G)SL*("`@("`@("`@("`@
M)'!A='1E<FYS6R<O/%PO8F]D>3XN*B]S:2==(#T@)R<["B`@("`@("`@?0H*
M("`@("`@("`O*B!'970@86QL(&%T=')I8G5T93TB:F%V87-C<FEP=#IF;V\H
M*2(@=&%G<RX@5&AI<R!I<R!E<W-E;G1I86QL>2!T:&4*("`@("`@("`@*B!R
M96=E>"`O*#U\=7)L7"@I*"(_*5M>/ETJ<V-R:7!T.B\@8G5T(&5X<&%N9&5D
M('1O(&-A=&-H(&-A;6]U9FQA9V4*("`@("`@("`@*B!W:71H('-P86-E<R!A
M;F0@96YT:71I97,N("HO"B`@("`@("`@)'!R96<@/2`G+R@H)B,P*C8Q.S]\
M)B-X,"HS1#L_?#TI?"<@+@H@("`@("`@("`@("`@("`@)R@H=7PF(S`J.#4[
M/WPF(W@P*C4U.S]\)B,P*C$Q-SL_?"8C>#`J-S4[/RE<<RHG("X*("`@("`@
M("`@("`@("`@("<H<GPF(S`J.#([/WPF(W@P*C4R.S]\)B,P*C$Q-#L_?"8C
M>#`J-S([/RE<<RHG("X*("`@("`@("`@("`@("`@("<H;'PF(S`J-S8[/WPF
M(W@P*C1C.S]\)B,P*C$P.#L_?"8C>#`J-F,[/RE<<RHG("X*("`@("`@("`@
M("`@("`@("<H7"@I*2E<<RHG("X*("`@("`@("`@("`@("`@("<H)B,P*C,T
M.S]\)B-X,"HR,CL_?")\)B,P*C,Y.S]\)B-X,"HR-SL_?%PG*3\G("X*("`@
M("`@("`@("`@("`@("=;7CY=*EQS*B<@+@H@("`@("`@("`@("`@("`@)RAS
M?"8C,"HX,SL_?"8C>#`J-3,[/WPF(S`J,3$U.S]\)B-X,"HW,SL_*5QS*B<@
M+@H@("`@("`@("`@("`@("`@)RAC?"8C,"HV-SL_?"8C>#`J-#,[/WPF(S`J
M.3D[/WPF(W@P*C8S.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G*')\)B,P
M*C@R.S]\)B-X,"HU,CL_?"8C,"HQ,30[/WPF(W@P*C<R.S\I7',J)R`N"B`@
M("`@("`@("`@("`@("`G*&E\)B,P*C<S.S]\)B-X,"HT.3L_?"8C,"HQ,#4[
M/WPF(W@P*C8Y.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G*'!\)B,P*C@P
M.S]\)B-X,"HU,#L_?"8C,"HQ,3([/WPF(W@P*C<P.S\I7',J)R`N"B`@("`@
M("`@("`@("`@("`G*'1\)B,P*C@T.S]\)B-X,"HU-#L_?"8C,"HQ,38[/WPF
M(W@P*C<T.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G*#I\)B,P*C4X.S]\
M)B-X,"HS83L_*2]I)SL*("`@("`@("`D<&%T=&5R;G-;)'!R96==(#T@)UPQ
M7#@G("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G73L*"B`@("`@("`@+RH@
M1V5T(&%L;"!O;CQF;V\^/2)B87(H*2(N($Y%5D52(&%L;&]W('1H97-E+B`J
M+PH@("`@("`@("1P871T97)N<ULG+RA;7',B7"==*R<@+@H@("`@("`@("`@
M("`@("`@("`G*&]\)B,P*C<Y.S]\)B,P*C1F.S]\)B,P*C$Q,3L_?"8C,"HV
M9CL_*2<@+@H@("`@("`@("`@("`@("`@("`G*&Y\)B,P*C<X.S]\)B,P*C1E
M.S]\)B,P*C$Q,#L_?"8C,"HV93L_*2<@+@H@("`@("`@("`@("`@("`@("`G
M7'<K*5QS*CTO:2==(#T@)UPQ)R`N("1T:&ES+3Y?<&%R86US6R=R97!L86-E
M)UT@+B`G/2<["@H@("`@("`@("\J(%)E;6]V92!A;&P@<V-R:7!T<R!S:6YC
M92!T:&5Y(&UI9VAT(&EN=')O9'5C92!G87)B86=E(&EF('1H97D@87)E"B`@
M("`@("`@("H@;F]T('%U;W1E9"!P<F]P97)L>2X@*B\*("`@("`@("`D<&%T
M=&5R;G-;)WP\<V-R:7!T6UX^72H^+BH_/"]S8W)I<'0^?&ES)UT@/2`G/"<@
M+B`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==("X@)U]S8W)I<'0@+SXG.PH*
M("`@("`@("`O*B!'970@86QL('1A9W,@=&AA="!M:6=H="!C875S92!T<F]U
M8FQE("T@/&]B:F5C=#XL(#QE;6)E9#XL(#QB87-E/BP*("`@("`@("`@*B!E
M=&,N($UE=&$@<F5F<F5S:&5S(&%N9"!I9G)A;65S+"!T;V\N("HO"B`@("`@
M("`@)&UA;&EC:6]U<R`](&%R<F%Y*`H@("`@("`@("`@("`G+SPH6UX^82UZ
M72HI)R`N"B`@("`@("`@("`@("<H<WPF(S`J.#,[/WPF(W@P*C4S.S]\)B,P
M*C$Q-3L_?"8C>#`J-S,[/RE<<RHG("X*("`@("`@("`@("`@)RAC?"8C,"HV
M-SL_?"8C>#`J-#,[/WPF(S`J.3D[/WPF(W@P*C8S.S\I7',J)R`N"B`@("`@
M("`@("`@("<H<GPF(S`J.#([/WPF(W@P*C4R.S]\)B,P*C$Q-#L_?"8C>#`J
M-S([/RE<<RHG("X*("`@("`@("`@("`@)RAI?"8C,"HW,SL_?"8C>#`J-#D[
M/WPF(S`J,3`U.S]\)B-X,"HV.3L_*5QS*B<@+@H@("`@("`@("`@("`G*'!\
M)B,P*C@P.S]\)B-X,"HU,#L_?"8C,"HQ,3([/WPF(W@P*C<P.S\I7',J)R`N
M"B`@("`@("`@("`@("<H='PF(S`J.#0[/WPF(W@P*C4T.S]\)B,P*C$Q-CL_
M?"8C>#`J-S0[/RE<<RHO:2<L"@H@("`@("`@("`@("`G+SPH6UX^82UZ72HI
M)R`N"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J-#4[/WPF(S`J,3`Q
M.S]\)B,P*C8U.S\I7',J)R`N"B`@("`@("`@("`@("<H;7PF(S`J-S<[/WPF
M(S`J-&0[/WPF(S`J,3`Y.S]\)B,P*C9D.S\I7',J)R`N"B`@("`@("`@("`@
M("<H8GPF(S`J-C8[/WPF(S`J-#([/WPF(S`J.3@[/WPF(S`J-C([/RE<<RHG
M("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT-3L_?"8C,"HQ,#$[
M/WPF(S`J-C4[/RE<<RHG("X*("`@("`@("`@("`@)RAD?"8C,"HV.#L_?"8C
M,"HT-#L_?"8C,"HQ,#`[/WPF(S`J-C0[/RE<<RHO:2<L"@H@("`@("`@("`@
M("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H>'PF(S`J.#@[/WPF
M(S`J-3@[/WPF(S`J,3(P.S]\)B,P*C<X.S\I7',J)R`N"B`@("`@("`@("`@
M("<H;7PF(S`J-S<[/WPF(S`J-&0[/WPF(S`J,3`Y.S]\)B,P*C9D.S\I7',J
M)R`N"B`@("`@("`@("`@("<H;'PF(S`J-S8[/WPF(W@P*C1C.S]\)B,P*C$P
M.#L_?"8C>#`J-F,[/RE<<RHO:2<L"@H@("`@("`@("`@("`G+SPH6UX^82UZ
M72HI)R`N"B`@("`@("`@("`@("<H8GPF(S`J-C8[/WPF(S`J-#([/WPF(S`J
M.3@[/WPF(S`J-C([/RE<<RHG("X*("`@("`@("`@("`@)RAA?"8C,"HV-3L_
M?"8C,"HT,3L_?"8C,"HY-SL_?"8C,"HV,3L_*5QS*B<@+@H@("`@("`@("`@
M("`G*'-\)B,P*C@S.S]\)B-X,"HU,SL_?"8C,"HQ,34[/WPF(W@P*C<S.S\I
M7',J)R`N"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J-#4[/WPF(S`J
M,3`Q.S]\)B,P*C8U.S\I7',J)R`N"B`@("`@("`@("`@("=;7FQI;F5=+VDG
M+`H*("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@+@H@("`@("`@("`@("`G
M*&U\)B,P*C<W.S]\)B,P*C1D.S]\)B,P*C$P.3L_?"8C,"HV9#L_*5QS*B<@
M+@H@("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P*C$P,3L_
M?"8C,"HV-3L_*5QS*B<@+@H@("`@("`@("`@("`G*'1\)B,P*C@T.S]\)B-X
M,"HU-#L_?"8C,"HQ,38[/WPF(W@P*C<T.S\I7',J)R`N"B`@("`@("`@("`@
M("<H87PF(S`J-C4[/WPF(S`J-#$[/WPF(S`J.3<[/WPF(S`J-C$[/RE<<RHO
M:2<L"@H@("`@("`@("`@("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@
M("<H:GPF(S`J-S0[/WPF(S`J-&$[/WPF(S`J,3`V.S]\)B,P*C9A.S\I7',J
M)R`N"B`@("`@("`@("`@("<H87PF(S`J-C4[/WPF(S`J-#$[/WPF(S`J.3<[
M/WPF(S`J-C$[/RE<<RHG("X*("`@("`@("`@("`@)RAV?"8C,"HX-CL_?"8C
M,"HU-CL_?"8C,"HQ,3@[/WPF(S`J-S8[/RE<<RHG("X*("`@("`@("`@("`@
M)RAA?"8C,"HV-3L_?"8C,"HT,3L_?"8C,"HY-SL_?"8C,"HV,3L_*5QS*B]I
M)RP*"B`@("`@("`@("`@("<O/"A;7CYA+7I=*BDG("X*("`@("`@("`@("`@
M)RAO?"8C,"HW.3L_?"8C,"HT9CL_?"8C,"HQ,3$[/WPF(S`J-F8[/RE<<RHG
M("X*("`@("`@("`@("`@)RAB?"8C,"HV-CL_?"8C,"HT,CL_?"8C,"HY.#L_
M?"8C,"HV,CL_*5QS*B<@+@H@("`@("`@("`@("`G*&I\)B,P*C<T.S]\)B,P
M*C1A.S]\)B,P*C$P-CL_?"8C,"HV83L_*5QS*B<@+@H@("`@("`@("`@("`G
M*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P*C$P,3L_?"8C,"HV-3L_*5QS*B<@
M+@H@("`@("`@("`@("`G*&-\)B,P*C8W.S]\)B-X,"HT,SL_?"8C,"HY.3L_
M?"8C>#`J-C,[/RE<<RHG("X*("`@("`@("`@("`@)RAT?"8C,"HX-#L_?"8C
M>#`J-30[/WPF(S`J,3$V.S]\)B-X,"HW-#L_*5QS*B]I)RP*"B`@("`@("`@
M("`@("<O/"A;7CYA+7I=*BDG("X*("`@("`@("`@("`@)RAI?"8C,"HW,SL_
M?"8C>#`J-#D[/WPF(S`J,3`U.S]\)B-X,"HV.3L_*5QS*B<@+@H@("`@("`@
M("`@("`G*&9\)B,P*C<P.S]\)B,P*C0V.S]\)B,P*C$P,CL_?"8C,"HV-CL_
M*5QS*B<@+@H@("`@("`@("`@("`G*')\)B,P*C@R.S]\)B-X,"HU,CL_?"8C
M,"HQ,30[/WPF(W@P*C<R.S\I7',J)R`N"B`@("`@("`@("`@("<H87PF(S`J
M-C4[/WPF(S`J-#$[/WPF(S`J.3<[/WPF(S`J-C$[/RE<<RHG("X*("`@("`@
M("`@("`@)RAM?"8C,"HW-SL_?"8C,"HT9#L_?"8C,"HQ,#D[/WPF(S`J-F0[
M/RE<<RHG("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT-3L_?"8C
M,"HQ,#$[/WPF(S`J-C4[/RE<<RHO:2<I.PH*("`@("`@("!F;W)E86-H("@D
M;6%L:6-I;W5S(&%S("1P871T97)N*2!["B`@("`@("`@("`@("1P871T97)N
M<ULD<&%T=&5R;ET@/2`G/"<@+B`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==
M("X@)U]T86<G.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]M;65N="!O=70@
M<W1Y;&4O;&EN:R!T86=S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M
M<ULG<W1R:7!?<W1Y;&5S)UTI('L*("`@("`@("`@("`@)'!A='1E<FYS6R<O
M7',K<W1Y;&5<<RH]+VDG72`]("<@)R`N("1T:&ES+3Y?<&%R86US6R=R97!L
M86-E)UT@+B`G/2<["B`@("`@("`@("`@("1P871T97)N<ULG?#QS='EL95M>
M/ETJ/B@_.EQS*CQ<(2TM*2I\:2==(#T@)SPA+2TG.PH@("`@("`@("`@("`D
M<&%T=&5R;G-;)WPH/SHM+3Y<<RHI*CPO<W1Y;&4^?&DG72`]("<M+3XG.PH@
M("`@("`@("`@("`D<&%T=&5R;G-;)WPH/&QI;FM;7CY=*CXI?&DG72`]("<\
M(2TM("0Q("TM/B<["B`@("`@("`@?0H*("`@("`@("`O*B!!(&9E=R!O=&AE
M<B!M871C:&5S+B`J+PH@("`@("`@("1P871T97)N<ULG?#PH6UX^72HI)GLN
M*GTH6UX^72HI/GPG72`]("<\)GL[?5PS/B<["B`@("`@("`@)'!A='1E<FYS
M6R=\/"A;7CY=*BEM;V-H83HH6UX^72HI/GQI)UT@/2`G/%PQ)R`N("1T:&ES
M+3Y?<&%R86US6R=R97!L86-E)UT@+B`G.EPR/B<["B`@("`@("`@)'!A='1E
M<FYS6R=\/"A;7CY=*BEB:6YD:6YG.BA;7CY=*BD^?&DG72`]("<\7#$G("X@
M)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G72`N("<Z7#(^)SL*"B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1P871T97)N<RD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O8VQE86YA<V-I:2YP:'``````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`U,38S`#$P-3$U-#,Q,#8Q`#`R,S$W-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@4F5M;W9E<R!S;VUE(&-O;6UO;B!E;G1I=&EE<R!A;F0@:&EG:"UA<V-I
M:2!O<B!O=&AE<G=I<V4@;F]N<W1A;F1A<F0*("H@8VAA<F%C=&5R<R!C;VUM
M;VX@:6X@=&5X="!P87-T960@9G)O;2!-:6-R;W-O9G0@5V]R9"!I;G1O(&$@
M8G)O=W-E<BX*("H*("H@5&AI<R!F=6YC=&EO;B!S:&]U;&0@3D]4(&)E('5S
M960@;VX@;F]N+4%30TE)('1E>'0[(&ET(&UA>2!A;F0@<')O8F%B;'D*("H@
M=VEL;"!B=71C:&5R(&]T:&5R(&-H87)A8W1E<B!S971S(&EN9&5S8W)I;6EN
M871E;'DN("!5<V4@:70@;VYL>2!T;R!C;&5A;@H@*B!54RU!4T-)22`H-RUB
M:70I('1E>'0@=VAI8V@@>6]U('-U<W!E8W0@*&]R(&MN;W<I(&UA>2!H879E
M(&EN=F%L:60@;W(*("H@;F]N+7!R:6YT:6YG(&-H87)A8W1E<G,@:6X@:70N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]C
M;&5A;F%S8VEI+G!H<"QV(#$N,RXR+C0@,C`P-B\P,2\P,2`R,3HR.#HS."!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E
M>'1?1FEL=&5R7V-L96%N87-C:6D@97AT96YD<R!497AT7T9I;'1E<B!["@H@
M("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<GD@8F5F
M;W)E(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@8F5F;W)E('1H92!F
M:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M
M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F50<F]C97-S
M*"1T97AT*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O?"A;7B-=
M*BDC+BHO)RP@)'1E>'0L("1R96=S*2D@>PH@("`@("`@("`@("`D=&5X="`]
M("1R96=S6S%=.PH*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&5X="DI('L*
M("`@("`@("`@("`@("`@("1T97AT(#T@)'1E>'0@+B`B7&XB.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@
M<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R
M;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@
M("`@>PH@("`@("`@("\J(%)E;6]V92!C;VYT<F]L(&-H87)A8W1E<G,N("HO
M"B`@("`@("`@)')E9V5X<"`](&%R<F%Y*"<O6UQX,#`M7'@Q9ETK+R<@/3X@
M)R<I.PH*("`@("`@("`O*B!4:&4@)Y(G(&5N=')Y(&UA>2!L;V]K('=R;VYG
M+"!D97!E;F1I;F<@;VX@>6]U<B!E9&ET;W(L"B`@("`@("`@("H@8G5T(&ET
M)W,@;F]T("T@=&AA="=S(&YO="!R96%L;'D@82!S:6YG;&4@<75O=&4N("HO
M"B`@("`@("`@)')E<&QA8V4@/2!A<G)A>2AC:'(H,34P*2`]/B`G+2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("!C:'(H,38W*2`]/B`G*B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G@;<G(#T^("<J)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@(">%)R`]/B`G+BXN)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@(">1)R`]/B`B)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
MDB<@/3X@(B<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)Y,G(#T^("<B
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@(">4)R`]/B`G(B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`GE2<@/3X@)RHG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)Y8G(#T^("<M)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@(">7)R`]/B`G+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`GGR<@
M/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$T-SD[)R`]
M/B`G+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V,34W,CLG(#T^
M("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S8Q-3DT.R<@/3X@
M)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$V-#`[)R`]/B`G
M+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V,38R,SLG(#T^("<M
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S8Q-C`W.R<@/3X@)RHG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$U-3,[)R`]/B`G*B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V,34U.#LG(#T^("<J)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("<F(S@R,C8[)R`]/B`G*B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G)B,Y-C4X.R<@/3X@)SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=R96=E>'`G(#T^("1R96=E>'`L("=R97!L86-E)R`]/B`D<F5P;&%C92D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I
M;'1E<B]W;W)D<RYP:'``````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,Q
M,3$`,3`U,34T,S$P-C$`,#(R,C,P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!&:6QT97)S('1H92!G
M:79E;B!T97AT(&)A<V5D(&]N('1H92!W;W)D<R!F;W5N9"!I;B!A('=O<F0@
M;&ES=`H@*B!F:6QE+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!W
M;W)D<U]F:6QE("`M+2!&:6QE;F%M92!C;VYT86EN:6YG('1H92!W;W)D<R!T
M;R!R97!L86-E+@H@*B!R97!L86-E;65N="`M+2!4:&4@<F5P;&%C96UE;G0@
M<W1R:6YG+B`@1&5F875L=',@=&\@(BHJ*BHJ(BX*("H@/"]P<F4^"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]W;W)D<RYP
M:'`L=B`Q+C(N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@
M*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?
M=V]R9',@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&
M:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=R97!L86-E;65N="<@
M/3X@)RHJ*BHJ)RD["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W
M:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1R96=E>'`@/2!A<G)A>2@I.PH*
M("`@("`@("!I9B`H0&ES7W)E861A8FQE*"1T:&ES+3Y?<&%R86US6R=W;W)D
M<U]F:6QE)UTI*2!["B`@("`@("`@("`@("\J(%)E860@=&AE(&9I;&4@86YD
M(&ET97)A=&4@=&AR;W5G:"!T:&4@;&EN97,N("HO"B`@("`@("`@("`@("1L
M:6YE<R`](&9I;&4H)'1H:7,M/E]P87)A;7-;)W=O<F1S7V9I;&4G72D["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@
M("`@("`@("`@+RH@4W1R:7`@=VAI=&5S<&%C92!A;F0@8V]M;65N=',N("HO
M"B`@("`@("`@("`@("`@("`D;&EN92`]('1R:6TH)&QI;F4I.PH@("`@("`@
M("`@("`@("`@)&QI;F4@/2!P<F5G7W)E<&QA8V4H)WPC+BHD?"<L("<G+"`D
M;&EN92D["@H@("`@("`@("`@("`@("`@+RH@1FEL=&5R('1H92!T97AT+B`J
M+PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D;&EN92DI('L*("`@("`@
M("`@("`@("`@("`@("`D<F5G97AP6R(O*%QB*%QW*BDD;&EN95QB?%QB)&QI
M;F4H7'<J*5QB*2]I(ET@/2`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C96UE;G0G
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1R96=E>'`I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O
M<G-T+G!H<```````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S4V`#$P
M-3$U-#,Q,#8Q`#`R,3<Q-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=497AT+W)E4U0N
M<&AP)SL*<F5Q=6ER95]O;F-E("=497AT+W)E4U0O1F]R;6%T=&5R+G!H<"<[
M"@HO*BH*("H@5&AE(%1E>'1?1FEL=&5R7W)S=#HZ(&-L87-S(&-O;G9E<G1S
M(')E4W1R=6-T=7)E9%1E>'0@=&\@2%1-3"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+W)S="YP:'`L=B`Q+CDN,3`N-"`R
M,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC
M;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI
M8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!(;W)D95]4
M97AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]R<W0@97AT96YD<R!497AT7T9I
M;'1E<B!["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E
M<W-A<F%Y(&%F=&5R(&%P<&QY:6YG('1H92!F:6QT97(*("`@("`J('!A='1E
M<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T
M97AT(&%F=&5R('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P;W-T4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("`D9&]C=6UE
M;G0@/2`F5&5X=%]R95-4.CIP87)S92@D=&5X="D["B`@("`@("`@)&9O<FUA
M='1E<B`]("9497AT7W)E4U1?1F]R;6%T=&5R.CIF86-T;W)Y*"=H=&UL)RD[
M"B`@("`@("`@<F5T=7)N("1F;W)M871T97(M/F9O<FUA="@D9&]C=6UE;G0L
M($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@('T*"GT*````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&
M:6QT97(O<W!A8V4R:'1M;"YP:'``````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T
M,C(W`#$P-3$U-#,Q,#8Q`#`R,S$T-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE('-P86-E,FAT
M;6P@9FEL=&5R(&-O;G9E<G1S(&AO<FEZ;VYT86P@=VAI=&5S<&%C92!T;R!(
M5$U,(&-O9&4N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J(&5N8V]D
M92`@("`@+2T@2%1-3"!E;F-O9&4@=&AE('1E>'0_("!$969A=6QT<R!T;R!F
M86QS92X*("H@8VAA<G-E="`@("`M+2!#:&%R<V5T(&]F('1H92!T97AT+B`@
M1&5F875L=',@=&\@25-/+3@X-3DM,2X*("H@96YC;V1E7V%L;"`M+2!297!L
M86-E(&%L;"!S<&%C97,@=VET:"`F;F)S<#L_("!$969A=6QT<R!T;R!F86QS
M92X*("H@/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]S<&%C93)H=&UL+G!H<"QV(#$N,2XQ,"XU(#(P,#8O,#$O
M,#$@,C$Z,C@Z,S@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q($UA
M=&AI974@07)N;VQD(#QA<FY?;6%T0&-L=6(M:6YT97)N970N9G(^"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($UA=&AI974@07)N;VQD(#QA
M<FY?;6%T0&-L=6(M:6YT97)N970N9G(^"B`J($!P86-K86=E($AO<F1E7U1E
M>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W-P86-E,FAT;6P@97AT96YD<R!4
M97AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W!A<F%M<R`](&%R<F%Y*"=E;F-O9&4G(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)V-H87)S970G(#T^("=)4T\M.#@U.2TQ)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("=E;F-O9&5?86QL)R`]/B!F86QS92D[
M"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<GD@
M8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@8F5F;W)E('1H
M92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F50<F]C
M97-S*"1T97AT*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG
M96YC;V1E)UTI('L*("`@("`@("`@("`@)'1E>'0@/2!`:'1M;'-P96-I86QC
M:&%R<R@D=&5X="P@14Y47T-/35!!5"P@)'1H:7,M/E]P87)A;7-;)V-H87)S
M970G72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P;&%C92!P
M871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N
M<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N<R@I"B`@
M("!["B`@("`@("`@)')E<&QA8V4@/2!A<G)A>2@B7'0B(#T^("<F;F)S<#L@
M)FYB<W`[("9N8G-P.R`F;F)S<#L@)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("<@("<@/3X@)R9N8G-P.R`G*3L*("`@("`@("!R971U<FX@87)R87DH
M)W)E<&QA8V4G(#T^("1R97!L86-E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@869T97(@87!P;'EI;F<@
M=&AE(&9I;'1E<B!P871T97)N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@=&5X="!A9G1E<B!T:&4@9FEL=&5R:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<&]S=%!R;V-E<W,H)'1E>'0I"B`@("![
M"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("`G+"`G("9N8G-P.R<L
M("1T97AT*3L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V5N8V]D95]A
M;&PG72D@>PH@("`@("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"<@)RP@
M)R9N8G-P.R<L("1T97AT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O5&5X="]&:6QT97(O<VEM<&QE;6%R:W5P+G!H<```````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,3$U`#$P-3$U-#,Q,#8Q`#`R,S8P-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M2&EG:&QI9VAT<R!S:6UP;&4@;6%R:W5P(&%S('5S960@:6X@96UA:6QS(&]R
M('5S96YE="!P;W-T:6YG<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+W-I;7!L96UA<FMU<"YP:'`L=B`Q+C$N,3`N-2`R
M,#`V+S`W+S(T(#$U.C4T.C4T('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W-I;7!L96UA<FMU
M<"!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!H87-H('=I=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9710871T97)N<R@I"B`@("!["B`@("`@("`@)')E9V5X<"`]
M(&%R<F%Y*`H@("`@("`@("`@("`O+R!";VQD+@H@("`@("`@("`@("`G+RA>
M?%QS?"9N8G-P.WP\8G(@7"\^*2A<*EM>*EQS72M<*BDH7'-\)FYB<W`[?#QB
M<GQ<+BDO:2<@/3X@)UPQ/'-T<F]N9SY<,CPO<W1R;VYG/EPS)RP*"B`@("`@
M("`@("`@("\O(%5N9&5R;&EN92X*("`@("`@("`@("`@)R\H7GQ<<WPF;F)S
M<#M\/&)R(%PO/BDH7UM>7UQS72M?*2A<<WPF;F)S<#M\/&)R?%PN*2]I)R`]
M/B`G7#$\=3Y<,CPO=3Y<,R<L"@H@("`@("`@("`@("`O+R!)=&%L:6,N"B`@
M("`@("`@("`@("<[*%Y\7'-\)FYB<W!<.WP\8G(@+SXI*"];7B]<<UTK+RDH
M7'-\)FYB<W!<.WP\8G)\7"XI.VDG(#T^("=<,3QE;3Y<,CPO96T^7#,G*3L*
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1R96=E>'`I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]D:6US
M:6=N871U<F4N<&AP````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-C,`,3`U,34T
M,S$P-C$`,#(S-3<U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!$:7-P;&%Y<R!M97-S86=E('-I9VYA
M='5R97,@;6%R:V5D(&)Y(&$@)RTM("<@:6X@=&AE('-T>6QE(&]F('1H90H@
M*B!#4U,@8VQA<W,@(G-I9VYA='5R92(N($-L87-S(&YA;65S(&EN<VED92!T
M:&4@<VEG;F%T=7)E(&%R90H@*B!P<F5F:7AE9"!W:71H(")S:6=N871U<F4M
M(BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V1I;7-I9VYA='5R92YP:'`L=B`Q+C(N,3`N-B`R,#`V+S`X+S$W(#$R.C(Y
M.C4U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA
M<W,@5&5X=%]&:6QT97)?9&EM<VEG;F%T=7)E(&5X=&5N9',@5&5X=%]&:6QT
M97(@>PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S
M87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL=&5R"B`@("`@*B!P871T97)N
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X
M="!A9G1E<B!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<&]S=%!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@("`@)'!A<G1S(#T@
M<')E9U]S<&QI="@G?"A<;BTM7',J*#QB<B`O/BD_7'(_7&XI?"<L("1T97AT
M+"`R+"!04D5'7U-03$E47T1%3$E-7T-!4%154D4I.PH@("`@("`@(&EF("AC
M;W5N="@D<&%R=',I(#X@,RD@>PH@("`@("`@("`@("`D=&5X="`](&%R<F%Y
M7W-H:69T*"1P87)T<RD["B`@("`@("`@("`@("1T97AT("X]("<\<W!A;B!C
M;&%S<STB<VEG;F%T=7)E(CXG("X@)'!A<G1S6S!=.PH@("`@("`@("`@("`D
M=&5X="`N/2!P<F5G7W)E<&QA8V4H)WQC;&%S<STB*%M>(ETK*2)\)RP@)V-L
M87-S/2)S:6=N871U<F4M7#$B)RP@)'!A<G1S6S)=*3L*("`@("`@("`@("`@
M)'1E>'0@+CT@)SPO<W!A;CXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T97AT.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V)B8V]D92YP:'``````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,3`W,P`Q,#4Q-30S,3`V,0`P,C(S,38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G2&]R9&4N<&AP)SL*"B\J*@H@*B!4:&4@5&5X=%]&:6QT97)?
M8F)C;V1E.CH@8VQA<W,@9FEN9',@8F)C;V1E+7-T>6QE(&UA<FMU<"`H<V5E
M(&)E;&]W*2!I;B!A"B`J(&)L;V-K(&]F('1E>'0@86YD('1U<FYS(&ET(&EN
M=&\@2%1-3"X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R93X*("H@96YT:71I
M97,@+2T@268@=')U92!B969O<F4@<F5P;&%C:6YG(&)B8V]D92!W:71H($A4
M34P@=&%G<RP@86YY($A434P*("H@("`@("`@("`@("`@96YT:71I97,@=VEL
M;"!B92!R97!L86-E9"X*("H@/"]P<F4^"B`J"B`J(%-U<'!O<G1E9"!B8F-O
M9&4Z"B`J(#QP<F4^"B`J("`@("!;8EU";VQD(%1E>'1;+V)="B`J("`@("!;
M:5U)=&%L:6-S(%1E>'1;+VE="B`J("`@("!;=5U5;F1E<FQI;F5D(%1E>'1;
M+W5="B`J("`@("!;<75O=&5=475O=&5D(%1E>'1;+W%U;W1E70H@*B`@("`@
M6V-E;G1E<EU#96YT97)E9"!497AT6R]C96YT97)="B`J"B`J("`@("!,:7-T
M(&]F(&ET96US"B`J("`@("!;;&ES=%T*("H@("`@(%LJ72!)=&5M(&]N90H@
M*B`@("`@6RI=($ET96T@='=O"B`J("`@("!;+VQI<W1="B`J"B`J("`@("!.
M=6UB97)E9"!L:7-T"B`J("`@("!;;G5M;&ES=%T*("H@("`@(%LJ72!)=&5M
M(&]N90H@*B`@("`@6RI=($ET96T@='=O"B`J("`@("!;+VYU;6QI<W1="B`J
M"B`J("`@("!;=7)L76AT='`Z+R]W=W<N:&]R9&4N;W)G6R]U<FQ=("T^($QI
M;FL@=&\@=&AE(&%D9')E<W,@=7-I;F<@=&AE"B`J("`@("`@("`@861D<F5S
M<R!I='-E;&8@9F]R('1H92!T97AT+B`@66]U(&-A;B!S<&5C:69Y('1H92!P
M<F]T;V-O;#H@:'1T<"!O<@H@*B`@("`@("`@(&AT='!S(&%N9"!T:&4@<&]R
M="X*("H@("`@(%MU<FQ==W=W+FAO<F1E+F]R9ULO=7)L72`M/B!,:6YK('1O
M('1H92!A9&1R97-S('5S:6YG('1H92!A9&1R97-S"B`J("`@("`@("`@:71S
M96QF(&9O<B!T:&4@=&5X="X@(%EO=2!C86X@<W!E8VEF>2!T:&4@<&]R="X@
M(%1H92!P<F]T;V-O;"!I<R!B>0H@*B`@("`@("`@(&1E9F%U;'0@:'1T<"X*
M("H@("`@(%MU<FP]:'1T<#HO+W=W=RYH;W)D92YO<F==3&EN:R!T;R!(;W)D
M95LO=7)L72`M/B!,:6YK('1O('1H92!A9&1R97-S"B`J("`@("`@("`@=7-I
M;F<@(DQI;FL@=&\@2&]R9&4B(&9O<B!T:&4@=&5X="X@(%EO=2!C86X@<W!E
M8VEF>2!T:&4@<')O=&]C;VPZ"B`J("`@("`@("`@:'1T<"!O<B!H='1P<R!A
M;F0@=&AE('!O<G0N"B`J("`@("!;=7)L/7=W=RYH;W)D92YO<F==3&EN:R!T
M;R!(;W)D95LO=7)L72`M/B!,:6YK('1O('1H92!A9&1R97-S('5S:6YG"B`J
M("`@("`@("`@(DQI;FL@=&\@2&]R9&4B(&9O<B!T:&4@=&5X="X@(%EO=2!C
M86X@<W!E8VEF>2!T:&4@<&]R="X@(%1H90H@*B`@("`@("`@('!R;W1O8V]L
M(&ES(&)Y(&1E9F%U;'0@:'1T<`H@*B`@("`@6V5M86EL76-P961R:6YA8VE`
M>6%H;V\N97-;+V5M86EL72`M/B!S971S(&$@;6%I;'1O(&QI;FLN"B`J("`@
M("!;96UA:6P]8W!E9')I;F%C:4!Y86AO;RYE<UU-86EL('1O($-A<FQO<ULO
M96UA:6Q=("T^(%-E=',@82!M86EL=&\@;&EN:PH@*B`@("`@("`@(&%N9"!T
M:&4@=&5X="!I<R`B36%I;"!T;R!#87)L;W,B+@H@*B`\+W!R93X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V)B8V]D92YP
M:'`L=B`Q+C@N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-A<FQO<R!0961R:6YA8VD@/&-P
M961R:6YA8VE`>6%H;V\N97,^"B`J"B`J($5M86EL('9A;&ED871I;VX@8F%S
M960@;VX@0VAU8VL@2&%G96YB=6-H)W,*("H@36%I;%]21D,X,C(Z.FES5F%L
M:61);F5T061D<F5S<RX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-A
M<FQO<R!0961R:6YA8VD@/&-P961R:6YA8VE`>6%H;V\N97,^"B`J($!P86-K
M86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7V)B8V]D92!E
M>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E<B!P
M87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?<&%R86US(#T@87)R87DH)V5N=&ET:65S)R`]/B!F86QS92D[
M"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<GD@
M8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@8F5F;W)E('1H
M92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F50<F]C
M97-S*"1T97AT*0H@("`@>PH@("`@"6EF("@D=&AI<RT^7W!A<F%M<ULG96YT
M:71I97,G72D@>PH@("`@("`@("`@("`D=&5X="`]($!H=&UL<W!E8VEA;&-H
M87)S*"1T97AT*3L*("`@(`E]"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P;&%C
M92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T
M97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N<R@I
M"B`@("!["B`@("`))')E<&QA8V4@/2!A<G)A>2@*("`@(`D@("`@)UMI72<@
M/3X@)SQE;3XG+"`G6R]I72<@/3X@)SPO96T^)RP*("`@("`@("`@("`@)UMU
M72<@/3X@)SQU/B<L("=;+W5=)R`]/B`G/"]U/B<L"B`@("`@("`@("`@("=;
M8ETG(#T^("<\<W1R;VYG/B<L("=;+V)=)R`]/B`G/"]S=')O;F<^)RP*("`@
M("`@("`@("`@)UMC96YT97)=)R`]/B`G/&-E;G1E<CXG+"`G6R]C96YT97)=
M)R`]/B`G/"]C96YT97(^)RP*("`@("`@("`@("`@)UMQ=6]T95TG(#T^("<\
M8FQO8VMQ=6]T93XG+"`G6R]Q=6]T95TG(#T^("<\+V)L;V-K<75O=&4^)RP*
M("`@("`@("`@("`@)UML:7-T72<@/3X@)SQU;#XG+"`G6R]L:7-T72<@/3X@
M)SPO=6P^)RP*("`@("`@("`@("`@)UMN=6UL:7-T72<@/3X@)SQO;#XG+"`G
M6R]N=6UL:7-T72<@/3X@)SPO;VP^)RP*("`@("`@("`@("`@)ULJ72<@/3X@
M)SQL:3XG*3L*"B`@("`@("`@+RH@5VAE;B!C:&5C:VEN9R!54DQS('=E('9A
M;&ED871E('!A<G0@;V8@=&AE;2P@8G5T(&ET(&ES('5P"B`@("`@("`@("H@
M=&\@=&AE('5S97(@=&\@=W)I=&4@=&AE;2!C;W)R96-T;'D@*&EN('!A<G1I
M8W5L87(@=&AE"B`@("`@("`@("H@<75E<GD@<W1R:6YG*2X@0V]N8V5R;FEN
M9R!M86EL<R!W92!U<V4@=&AE(')E9W5L87(*("`@("`@("`@*B!E>'!R97-S
M:6]N(&EN($UA:6Q?4D9#.#(R)W,@:7-686QI9$EN971!9&1R97-S*"D@9G5N
M8W1I;VXL"B`@("`@("`@("H@<VQI9VAT;'D@;6]D:69I960N("HO"B`@("`@
M("`@)')E9V5X<"`](&%R<F%Y*`H@("`@("`@("`@("`B(UQ;=7)L7%TH*&AT
M='!\:'1T<',I.B\O*%MA+7I!+5I<9%U;7'<M72HI*%PN6V$M>D$M6EQD75M<
M=RU=*BDK*#HH7&0K*2D_*"\H6UX\/ETK*2DJ*5Q;+W5R;%Q=(U4B(#T^"B`@
M("`@("`@("`@($AO<F1E.CIL:6YK*"(D,2(L("(D,2(I("X@(B0Q/"]A/B(L
M"@H@("`@("`@("`@("`B(UQ;=7)L7#TH*&AT='!\:'1T<',I.B\O*%MA+7I!
M+5I<9%U;7'<M72HI*%PN6V$M>D$M6EQD75M<=RU=*BDK*#HH7&0K*2D_*"\H
M6UX\/ETK*2DJ*5Q=*%M>/#Y=*RE<6R]U<FQ<72-5(B`]/@H@("`@("`@("`@
M("!(;W)D93HZ;&EN:R@B)#$B+"`B)#$B*2`N("(D.3PO83XB+`H*("`@("`@
M("`@("`@(B-<6W5R;%Q=*"A;82UZ02U:7&1=6UQW+5TJ*2A<+EMA+7I!+5I<
M9%U;7'<M72HI*R@Z*%QD*RDI/R@O*%M>/#Y=*RDI*BE<6R]U<FQ<72-5(B`]
M/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B:'1T<#HO+R0Q(BP@(FAT='`Z
M+R\D,2(I("X@(B0Q/"]A/B(L"@H@("`@("`@("`@("`B(UQ;=7)L7#TH*%MA
M+7I!+5I<9%U;7'<M72HI*%PN6V$M>D$M6EQD75M<=RU=*BDK*#HH7&0K*2D_
M*"\H6UX\/ETK*2DJ*5Q=*%M>/#Y=*RE<6R]U<FQ<72-5(B`]/@H@("`@("`@
M("`@("!(;W)D93HZ;&EN:R@B:'1T<#HO+R0Q(BP@(FAT='`Z+R\D,2(I("X@
M(B0X/"]A/B(L"@H@("`@("`@("`@("`B(UQ;96UA:6Q<72@H6RHK(2XF7",D
M?%PG7%PE7"\P+3EA+7I!+5I>7V![?3T_?CHM72LI0"@H6S`M.6$M>D$M6BU=
M*UPN*2M;,"TY82UZ02U:77LR+#1]*2E<6R]E;6%I;%Q=(U4B(#T^"B`@("`@
M("`@("`@($AO<F1E.CIL:6YK*")M86EL=&\Z)#$B+"`B;6%I;'1O.B0Q(BD@
M+B`B)#$\+V$^(BP*"B`@("`@("`@("`@("(C7%ME;6%I;%P]*"A;*BLA+B9<
M(R1\7"=<7"5<+S`M.6$M>D$M6EY?8'M]/3]^.BU=*RE`*"A;,"TY82UZ02U:
M+5TK7"XI*ULP+3EA+7I!+5I=>S(L-'TI*5Q=*%M>/#Y=*RE<6R]E;6%I;%Q=
M(U4B(#T^"B`@("`@("`@("`@($AO<F1E.CIL:6YK*")M86EL=&\Z)#$B+"`B
M;6%I;'1O.B0Q(BD@+B`B)#4\+V$^(@H@("`@("`@("D["@H@("`@("`@(')E
M='5R;B!A<G)A>2@G<F5P;&%C92<@/3X@)')E<&QA8V4L("=R96=E>'`G(#T^
M("1R96=E>'`I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]L:6YK=7)L<RYP:'``````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4R,38`,3`U,34T,S$P-C$`,#(R-S0U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@5&5X=%]&:6QT97)?;&EN:W5R;',Z.B!C;&%S<R!T=7)N
M<R!A;&P@55),<R!I;B!T:&4@=&5X="!I;G1O(&AY<&5R;&EN:W,N"B`J"B`J
M(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J('1A<F=E="`@("TM(%1H92!L:6YK
M('1A<F=E="X@($1E9F%U;'1S('1O(%]B;&%N:RX*("H@8VQA<W,@("`@+2T@
M5&AE($-34R!C;&%S<R!O9B!T:&4@9V5N97)A=&5D(&QI;FMS+B`@1&5F875L
M=',@=&\@;F]N92X*("H@;F]F;VQL;W<@+2T@5VAE=&AE<B!T;R!S970@=&AE
M("=R96P](FYO9F]L;&]W(B<@871T<FEB=71E(&]N(&QI;FMS+@H@*B!C87!I
M=&%L("`M+2!G96YE<F%T92!U<'!E<F-A<V4@/$$^('1A9W,@<V\@>6]U(&-A
M;B!K;F]W('=H:6-H('1A9W,@>6]U(&IU<W0*("H@("`@("`@("`@("`@9V5N
M97)A=&5D+B`@1&5F875L=',@=&\@9F%L<V4N"B`J(&-A;&QB86-K("TM($%N
M(&]P=&EO;F%L(&-A;&QB86-K(&9U;F-T:6]N('1H870@=&AE(%523"!I<R!P
M87-S960@=&AR;W5G:`H@*B`@("`@("`@("`@("!B969O<F4@8F5I;F<@<V5T
M(&%S('1H92!H<F5F(&%T=')I8G5T92X@($UU<W0@8F4@82!S=')I;F<@=VET
M:`H@*B`@("`@("`@("`@("!T:&4@9G5N8W1I;VX@;F%M92P@=&AE(&9U;F-T
M:6]N(&UU<W0@=&%K92!T:&4@;W)I9VEN86P@87,@=&AE"B`J("`@("`@("`@
M("`@(&9I<G-T(&%N9"!O;FQY('!A<F%M971E<BX*("H@/"]P<F4^"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]L:6YK=7)L
M<RYP:'`L=B`Q+C$Q+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!4>6QE<B!#;VQB97)T(#QT
M>6QE<BUH;W)D96UL0&-O;&)E<G1S+G5S/@H@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!4>6QE<B!#;VQB97)T(#QT>6QE<BUH;W)D96UL
M0&-O;&)E<G1S+G5S/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!4
M97AT7T9I;'1E<E]L:6YK=7)L<R!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@
M("`O*BH*("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH
M)W1A<F=E="<@/3X@)U]B;&%N:R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G8VQA<W,G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)VYO
M9F]L;&]W)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("=C
M87!I=&%L)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("=C
M86QL8F%C:R<@/3X@;G5L;"D["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A
M;GD@8V]D92!N96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@
M<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@
M5&AE('1E>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7W!A<F%M<ULG8V%P:71A;"==*2!["B`@("`@("`@("`@("1T
M97AT(#T@<W1R7W)E<&QA8V4H87)R87DH)SPO03XG+"`G/$$G*2P@87)R87DH
M)SPO83XG+"`G/&$G*2P@)'1E>'0I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA
M<V@@=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D82`]("1T:&ES+3Y?<&%R
M86US6R=C87!I=&%L)UT@/R`G02<@.B`G82<["@H@("`@("`@("1C;&%S<R`]
M("1T:&ES+3Y?<&%R86US6R=C;&%S<R==.PH@("`@("`@(&EF("@A96UP='DH
M)&-L87-S*2D@>PH@("`@("`@("`@("`D8VQA<W,@/2`G(&-L87-S/2(G("X@
M)&-L87-S("X@)R(G.PH@("`@("`@('T*("`@("`@("`D;F]F;VQL;W<@/2`D
M=&AI<RT^7W!A<F%M<ULG;F]F;VQL;W<G72`_("<@<F5L/2)N;V9O;&QO=R(G
M(#H@)R<["@H@("`@("`@("1U<FP@/2`D=&AI<RT^7W!A<F%M<ULG8V%L;&)A
M8VLG72`_("=<)R`N("<@+B`D=&AI<RT^7W!A<F%M<ULG8V%L;&)A8VLG72`N
M("<H7"<D,%PG*2`N(%PG)R`Z("<D,"<["@H@("`@("`@("1R96=E>'`@/2!A
M<G)A>2@G?"A<=RLI.B\O*%M>7',B/%TJ6UQW*R,_+R8]72E\92<@/3X*("`@
M("`@("`@("`@("`@("`@("`@("`@)UPG/"<@+B`D82`N("<@:')E9CTB)R`N
M("1U<FP@+B`G(B<@+B`D;F]F;VQL;W<@+B`G('1A<F=E=#TB7V)L86YK(B<@
M+B`D8VQA<W,@+B`G/B0P/"\G("X@)&$@+B`G/EPG)RD["@H@("`@("`@(')E
M='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+V5M86EL<RYP:'``````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,#0P,``Q,#4Q-30S,3`V,0`P,C(S-#,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!497AT
M7T9I;'1E<E]E;6%I;',Z.B!C;&%S<R!F:6YD<R!E;6%I;"!A9&1R97-S97,@
M:6X@82!B;&]C:R!O9B!T97AT(&%N9`H@*B!T=7)N<R!T:&5M(&EN=&\@;&EN
M:W,N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J(&%L=V%Y<U]M86EL
M=&\@+2T@268@=')U92P@82!M86EL=&\Z(&QI;FL@:7,@9V5N97)A=&5D(&%L
M=V%Y<RX@($]N;'D@:68@;F\*("H@("`@("`@("`@("`@("`@("!M86EL+V-O
M;7!O<V4@<F5G:7-T<GD@05!)(&UE=&AO9"!E>&ES=',@;W1H97)W:7-E+@H@
M*B!C;&%S<R`@("`@("`@("TM($-34R!C;&%S<R!O9B!T:&4@9V5N97)A=&5D
M(#QA/B!T86<N("!$969A=6QT<R!T;R!N;VYE+@H@*B`\+W!R93X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`L=B`Q+C$U+C$P+C@@,C`P-B\P,B\Q-R`R,#HP-3HT.2!C:'5C:R!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V(%1Y;&5R($-O;&)E<G0@/'1Y
M;&5R+6AO<F1E;6Q`8V]L8F5R=',N=7,^"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@5'EL97(@0V]L8F5R="`\='EL97(M:&]R9&5M;$!C
M;VQB97)T<RYU<SX*("H@0&%U=&AO<B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT
M7T9I;'1E<E]E;6%I;',@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ
M"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=A;'=A
M>7-?;6%I;'1O)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("=C;&%S<R<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8V%P
M:71A;%]T86=S)R`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["@H@("`@("`@("1C;&%S<R`](&5M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=C;&%S<R==*2`_("<G(#H@)R!C;&%S<STB)R`N("1T:&ES+3Y?<&%R86US
M6R=C;&%S<R==("X@)R(G.PH@("`@("`@("1T86<@/2`D=&AI<RT^7W!A<F%M
M<ULG8V%P:71A;%]T86=S)UT@/R`G02<@.B`G82<["@H@("`@("`@("1R96=E
M>'`@/2`\/#Q%3U(*("`@("`@("`@("`@+PH@("`@("`@("`@("`C(%9E<G-I
M;VX@,3H@;6%I;'1O.B!L:6YK<R!W:71H(&%N>2!V86QI9"!E;6%I;"!C:&%R
M86-T97)S+@H@("`@("`@("`@("`C(%!A='1E<FX@,3H@3W5T;&]O:R!P87)E
M;G1H97-I>F5S(&EN('-Q87)E(&)R86-K971S"B`@("`@("`@("`@("A<6UQS
M*BD_"B`@("`@("`@("`@(",@4&%T=&5R;B`R.B!M86EL=&\Z('!R;W1O8V]L
M('!R969I>`H@("`@("`@("`@("`H;6%I;'1O.EQS/RD*("`@("`@("`@("`@
M(R!0871T97)N(#,Z(&5M86EL(&%D9')E<W,*("`@("`@("`@("`@*%M>7'-<
M/R(\72HI"B`@("`@("`@("`@(",@4&%T=&5R;B`T('1O(#8Z($]P=&EO;F%L
M('!A<F%M971E<G,*("`@("`@("`@("`@*"A</RDH6UY<<R(\72I;7'<K(S]<
M+R8]72DI/PH@("`@("`@("`@("`C(%!A='1E<FX@-SH@0VQO<VEN9R!/=71L
M;V]K('-Q=6%R92!B<F%C:V5T"B`@("`@("`@("`@("@H/R@Q*5QS*EQ=*2D*
M"B`@("`@("`@("`@('P*("`@("`@("`@("`@(R!697)S:6]N(#(@4&%T=&5R
M;B`X.B!S:6UP;&4@96UA:6P@861D<F5S<V5S+@H@("`@("`@("`@("`H7&);
M7'<M*RX]72M`6RU!+5HP+3DN72I;02U:,"TY72D*("`@("`@("`@("`@(R!0
M871T97)N(#D@=&\@,3$Z($]P=&EO;F%L('!A<F%M971E<G,*("`@("`@("`@
M("`@*"A</RDH6UY<<R(\72I;7'<K(S]<+R8]72DI/PH*("`@("`@("`@("`@
M+V5I>`I%3U(["@H@("`@("`@(&EF("AI<U]A*"1R96=I<W1R>2P@)U)E9VES
M=')Y)RD@)B8*("`@("`@("`@("`@)')E9VES=')Y+3YH87--971H;V0H)VUA
M:6PO8V]M<&]S92<I("8F"B`@("`@("`@("`@("$D=&AI<RT^7W!A<F%M<ULG
M86QW87ES7VUA:6QT;R==*2!["B`@("`@("`@("`@("\J($EF('=E(&AA=F4@
M82!M86EL+V-O;7!O<V4@<F5G:7-T<GD@;65T:&]D+"!U<V4@:70N("HO"B`@
M("`@("`@("`@("1R97!L86-E;65N="`]("=497AT7T9I;'1E<E]E;6%I;',Z
M.F-A;&QB86-K*%PG)R`N("1T86<@+@H@("`@("`@("`@("`@("`@)UPG+"!<
M)R<@+B`D8VQA<W,@+B`G7"<L(%PG)#%<)RP@7"<D,EPG+"!<)R0S7"<L(%PG
M)#1<)RP@7"<D-EPG+"!<)R0W7"<L(%PG)#A<)RP@7"<D.5PG+"!<)R0Q,5PG
M*2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@3W1H97)W:7-E
M+"!G96YE<F%T92!A('-T86YD87)D(&UA:6QT;SH@86YD(&QE="!T:&4*("`@
M("`@("`@("`@("H@8G)O=W-E<B!H86YD;&4@:70N("HO"B`@("`@("`@("`@
M("1R97!L86-E;65N="`](#P\/$5/4`H@("`@("`@("`@("`@("`@)R0X)R`]
M/3T@)R<@/PH*("`@("`@("`@("`@("`@("<D,20R/"1T86<D8VQA<W,@:')E
M9CTB;6%I;'1O.B0S)#0B('1I=&QE/2(G("X@<W!R:6YT9BA?*").97<@365S
M<V%G92!T;R`E<R(I+"!H=&UL<W!E8VEA;&-H87)S*"<D,R<I*2`N"B`@("`@
M("`@("`@("`@("`G(CXD,R0T/"\D=&%G/B0W)R`Z"@H@("`@("`@("`@("`@
M("`@)SPD=&%G)&-L87-S(&AR968](FUA:6QT;SHD."0Y(B!T:71L93TB)R`N
M('-P<FEN=&8H7R@B3F5W($UE<W-A9V4@=&\@)7,B*2P@:'1M;'-P96-I86QC
M:&%R<R@G)#@G*2D@+@H@("`@("`@("`@("`@("`@)R(^)#@D.3PO)'1A9SXG
M"D5/4#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G97AP
M)R`]/B!A<G)A>2@D<F5G97AP(#T^("1R97!L86-E;65N="DI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&-A;&QB86-K*"1T86<L("1C;&%S<RP@)&)R86-K970Q
M+"`D<')O=&]C;VPL("1E;6%I;"P@)&%R9W-?;&]N9RP*("`@("`@("`@("`@
M("`@("`@("`@("1A<F=S+"`D8G)A8VME=#(L("1E;6%I;#(L("1A<F=S7VQO
M;F<R+"`D87)G<S(I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D96UA:6PR
M*2D@>PH@("`@("`@("`@("`D87)G<R`]("1A<F=S,CL*("`@("`@("`@("`@
M)&5M86EL(#T@)&5M86EL,CL*("`@("`@("`@("`@)&%R9W-?;&]N9R`]("1A
M<F=S7VQO;F<R.PH@("`@("`@('T*("`@("`@("`D97AT<F$@/2!C86QL7W5S
M97)?9G5N8RAC<F5A=&5?9G5N8W1I;VXH)R1A)RP@)R1P/6%R<F%Y*"D[9F]R
M96%C:"@D82!A<R`D8BE[)&(]97AP;&]D92@B/2(L)&(L,BD[)'!;)&);,%U=
M/4`D8ELQ73M]<F5T=7)N("1P.R<I+"!E>'!L;V1E*"<F)RP@)&%R9W,I*3L*
M("`@("`@("`D=7)L(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)VUA
M:6PO8V]M<&]S92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*&%R<F%Y*"=T;R<@/3X@)&5M86EL*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A*2D[
M"B`@("`@("`@)'5R;"`]('-T<E]R97!L86-E*"<F86UP.R<L("<F)RP@)'5R
M;"D["B`@("`@("`@:68@*'-U8G-T<B@D=7)L+"`P+"`Q,2D@/3T@)VIA=F%S
M8W)I<'0Z)RD@>PH@("`@("`@("`@("`D:')E9B`]("<C)SL*("`@("`@("`@
M("`@)&]N8VQI8VL@/2`G(&]N8VQI8VL](B<@+B!S=6)S='(H)'5R;"P@,3$I
M("X@)R(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H<F5F(#T@
M)'5R;#L*("`@("`@("`@("`@)&]N8VQI8VL@/2`G)SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8G)A8VME=#$@+B`D<')O=&]C;VP@+B`G/"<@+B`D
M=&%G("X@)&-L87-S("X@)R!H<F5F/2(G("X*("`@("`@("`@("`@)&AR968@
M+B`G(B!T:71L93TB)R`N('-P<FEN=&8H7R@B3F5W($UE<W-A9V4@=&\@)7,B
M*2P@:'1M;'-P96-I86QC:&%R<R@D96UA:6PI*2`N("<B)R`N"B`@("`@("`@
M("`@("1O;F-L:6-K("X@)SXG("X@:'1M;'-P96-I86QC:&%R<R@D96UA:6PI
M("X@)&%R9W-?;&]N9R`N("<\+R<@+B`D=&%G("X@)SXG("X@)&)R86-K970R
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O
M96YV:7)O;FUE;G0N<&AP````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S`W`#$P
M-3$U-#,Q,#8Q`#`R,S0T-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@4F5P;&%C97,@;V-C=7)E;F-E
M<R!O9B`E5D%2)2!W:71H(%9!4BP@:68@5D%2(&5X:7-T<R!I;B!T:&4@=V5B
M<V5R=F5R)W,*("H@96YV:7)O;FUE;G0N("!)9VYO<F5S(&%L;"!T97AT(&%F
M=&5R(&$@)R,G(&-H87)A8W1E<B`H<VAE;&PM<W1Y;&4*("H@8V]M;65N=',I
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96YV:7)O;FUE;G0N<&AP+'8@,2XS+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HS
M."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S
M(%1E>'1?1FEL=&5R7V5N=FER;VYM96YT(&5X=&5N9',@5&5X=%]&:6QT97(@
M>PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L86-E
M('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!A='1E
M<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS*"D*
M("`@('L*("`@("`@("`D<F5G97AP(#T@87)R87DH)R]>(RXJ)%QN+VTG(#T^
M("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`G+UXH6UXC72HI(RXJ)"]M
M)R`]/B`G)#$G+`H@("`@("`@("`@("`@("`@("`@("`@("`G+R4H6T$M6F$M
M>E]=*RDE+V4G(#T^("=G971E;G8H(B0Q(BDG*3L*("`@("`@("!R971U<FX@
M87)R87DH)W)E9V5X<"<@/3X@)')E9V5X<"D["B`@("!]"@I]````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:'1M;#)T97AT+G!H<```````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V
M,3,P`#$P-3$U-#,Q,#8Q`#`R,S`S,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D
M92]3=')I;F<N<&AP)SL*"B\J*@H@*B!486ME<R!(5$U,(&%N9"!C;VYV97)T
M<R!I="!T;R!F;W)M871T960L('!L86EN('1E>'0N"B`J"B`J(%!A<F%M971E
M<G,Z"B`J(#QP<F4^"B`J(&-H87)S970@+2T@5&AE(&-H87)S970@=&\@=7-E
M(&9O<B!H=&UL7V5N=&ET>5]D96-O9&4H*2!C86QL<RX*("H@=VED=&@@("`M
M+2!4:&4@=W)A<'!I;F<@=VED=&@N"B`J('=R87`@("`@+2T@5VAE=&AE<B!T
M;R!W<F%P('1H92!T97AT(&]R(&YO="X*("H@/"]P<F4^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M+'8@,2XT+C$P+C$R(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F]N($%B97)N871H>2`\:F]N0&-H
M=6=G;G5T="YC;VT^"B`J($]R:6=I;F%L('-O=7)C93H@:'1T<#HO+W=W=RYC
M:'5G9VYU='0N8V]M+VAT;6PR=&5X="YP:'`*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F]N($%B97)N871H>2`\:F]N0&-H=6=G;G5T
M="YC;VT^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]4
M97AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]H=&UL,G1E>'0@97AT96YD<R!4
M97AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W!A<F%M<R`](&%R<F%Y*"=C:&%R<V5T)R`]/B!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)W=I9'1H)R`]/B`W,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("=W<F%P)R`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J($5X
M96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@8F5F;W)E(&%P<&QY:6YG('1H
M92!F:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@5&AE('1E>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D7VAT;6PR=&5X=%]S=&%T93L*"B`@("`@("`@:68@
M*&ES7VYU;&PH)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72`](&ES<V5T*"1'3$]"
M04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72D@/R`D1TQ/0D%,4ULG7TA/
M4D1%7U-44DE.1U]#2$%24T54)UT@.B`G25-/+3@X-3DM,2<["B`@("`@("`@
M?0H*("`@("`@("`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:TQI<W0G72`]("<G
M.PH@("`@("`@("1?:'1M;#)T97AT7W-T871E6R=L:6YK0V]U;G0G72`](#`[
M"@H@("`@("`@(')E='5R;B!T<FEM*"1T97AT*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P;&%C92!P871T97)N<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N<R!H87-H+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N<R@I"B`@("!["B`@("`@
M("`@)')E9V5X<"`](&%R<F%Y*`H@("`@("`@("`@("`O+R!.;VXM;&5G86P@
M8V%R<FEA9V4@<F5T=7)N+@H@("`@("`@("`@("`G+UQR+R<@/3X@)R<L"@H@
M("`@("`@("`@("`O+R!,96%D:6YG(&%N9"!T<F%I;&EN9R!W:&ET97-P86-E
M+@H@("`@("`@("`@("`G+UY<<RHH+BH_*5QS*B0O;2<@/3X@)UPQ)RP*"B`@
M("`@("`@("`@("\O($YO<FUA;&EZ92`\8G(^+@H@("`@("`@("`@("`G+SQB
M<EM>/ETJ/BA;7EQN72DO:2<@/3X@(CQB<CY<;EQ<,2(L"@H@("`@("`@("`@
M("`O+R!.97=L:6YE<R!A;F0@=&%B<RX*("`@("`@("`@("`@)R];7&Y<=%TK
M+R<@/3X@)R`G+`H*("`@("`@("`@("`@+R\@/'-C<FEP=#YS("TM('=H:6-H
M('-T<FEP7W1A9W,H*2!S=7!P;W-E9&QY(&AA<R!P<F]B;&5M<R!W:71H+@H@
M("`@("`@("`@("`G+SQS8W)I<'1;7CY=*CXN*C\\7"]S8W)I<'0^+VDG(#T^
M("<G+`H*("`@("`@("`@("`@+R\@/'-T>6QE/G,@+2T@=VAI8V@@<W1R:7!?
M=&%G<R@I('-U<'!O<V5D;'D@:&%S('!R;V)L96US('=I=&@N"B`@("`@("`@
M("`@("<O/'-T>6QE6UX^72H^+BH_/%PO<W1Y;&4^+VDG(#T^("<G+`H*("`@
M("`@("`@("`@+R\@0V]M;65N=',@+2T@=VAI8V@@<W1R:7!?=&%G<R@I(&UI
M9VAT(&AA=F4@82!P<F]B;&5M('=I=&@N"B`@("`@("`@("`@("\O("\O)R\\
M(2TM("XJ("TM/B\G(#T^("<G+`H*("`@("`@("`@("`@+R\@:#$@+2!H,PH@
M("`@("`@("`@("`G+SQH6S$R,UU;7CY=*CXH+BL_*3Q<+VA;,3(S73X@/R]I
M92<@/3X@)W-T<G1O=7!P97(H(EQN7&XB("X@7"=<,5PG("X@(EQN7&XB*2<L
M"@H@("`@("`@("`@("`O+R!H-"`M(&@V"B`@("`@("`@("`@("<O/&A;-#4V
M75M>/ETJ/B@N*S\I/%PO:%LT-39=/B`_+VEE)R`]/B`G=6-W;W)D<R@B7&Y<
M;B(@+B!<)UPQ7"<@+B`B7&Y<;B(I)RP*"B`@("`@("`@("`@("\O(#QP/@H@
M("`@("`@("`@("`G+SQP6UX^72H^(#\O:2<@/3X@(EQN7&X@("(L"@H@("`@
M("`@("`@("`O+R`\8G(^"B`@("`@("`@("`@("<O/&)R6UX^72H^(#\O:2<@
M/3X@(EQN(BP*"B`@("`@("`@("`@("\O(#QB/@H@("`@("`@("`@("`G+SQB
M6UX^72H^*"XK/RD\7"]B/B]I92<@/3X@)W-T<G1O=7!P97(H7"=<,5PG*2<L
M"@H@("`@("`@("`@("`O+R`\<W1R;VYG/@H@("`@("`@("`@("`G+SQS=')O
M;F=;7CY=*CXH+BL_*3Q<+W-T<F]N9SXO:64G(#T^("=S=')T;W5P<&5R*%PG
M7#%<)RDG+`H@("`@("`@("`@("`G+SQS<&%N7%QS*W-T>6QE/2)F;VYT+7=E
M:6=H=#I<7',J8F]L9"XJ(CXH+BL_*3Q<+W-P86X^+VEE)R`]/B`G<W1R=&]U
M<'!E<BA<)UPQ7"<I)RP*"B`@("`@("`@("`@("\O(#QI/@H@("`@("`@("`@
M("`G+SQI6UX^72H^*"XK/RD\7"]I/B]I)R`]/B`G+UQ<,2\G+`H*("`@("`@
M("`@("`@+R\@/&5M/@H@("`@("`@("`@("`G+SQE;5M>/ETJ/B@N*S\I/%PO
M96T^+VDG(#T^("<O7%PQ+R<L"@H@("`@("`@("`@("`O+R`\=3X*("`@("`@
M("`@("`@)R\\=5M>/ETJ/B@N*S\I/%PO=3XO:2<@/3X@)U]<7#%?)RP*"B`@
M("`@("`@("`@("\O(#QU;#XO/&]L/B!A;F0@/"]U;#XO/"]O;#X*("`@("`@
M("`@("`@)R\H/"AU?&\I;%M>/ETJ/GP@/SQ<+RAU?&\I;#XI(#\O:2<@/3X@
M(EQN7&XB+`H*("`@("`@("`@("`@+R\@/&QI/@H@("`@("`@("`@("`G+R`_
M/&QI6UX^72H^+VDG(#T^(")<;B`@*B`B+`H*("`@("`@("`@("`@+R\@/&$@
M:')E9CTB(CX*("`@("`@("`@("`@)R\\82!H<F5F/2(H6UXB72LI(EM>/ETJ
M/B@N*S\I/%PO83XO:64G(#T^("=497AT7T9I;'1E<E]H=&UL,G1E>'0Z.E]B
M=6EL9$QI;FM,:7-T*"1'3$]"04Q36R)?:'1M;#)T97AT7W-T871E(EU;(FQI
M;FM#;W5N=")=+"!<)UPQ7"<L(%PG7#)<)RDG+`H*("`@("`@("`@("`@+R\@
M/&AR/@H@("`@("`@("`@("`G+SQH<EM>/ETJ/B`_+VDG(#T^(")<;BTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(L"@H@("`@("`@("`@("`O+R`\=&%B
M;&4^(&%N9"`\+W1A8FQE/@H@("`@("`@("`@("`G+R@\=&%B;&5;7CY=*CY\
M(#\\7"]T86)L93XI(#\O:2<@/3X@(EQN7&XB+`H*("`@("`@("`@("`@+R\@
M/'1R/@H@("`@("`@("`@("`G+R`_/'1R6UX^72H^(#\O:2<@/3X@(EQN7'0B
M+`H*("`@("`@("`@("`@+R\@/'1D/B!A;F0@/"]T9#X*("`@("`@("`@("`@
M)R\@/SQT9%M>/ETJ/B@N*S\I/%PO=&0^(#\O:2<@/3X@)UPQ)R`N(")<=%QT
M(BP*("`@("`@("`@("`@)R]<=%QT/%PO='(^+VDG(#T^("<G+`H*("`@("`@
M("`@("`@+R\@96YT:71I97,*("`@("`@("`@("`@)R\F;F)S<#LO:2<@/3X@
M)R`G+`H@("`@("`@("`@("`G+R9T<F%D93LO:2<@/3X@)RAT;2DG+`H@("`@
M("`@("`@("`G+R8C*%QD*RD[+V4G(#T^("=3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*%1E>'1?1FEL=&5R7VAT;6PR=&5X=#HZ7VEN=#)U=&8X*%PG7#%<)RDL
M(")55$8M."(L("(G("X@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72`N("<B
M*2<L"@H@("`@("`@("`@("`O+R!3;VUE(&UA:6QE<G,@*&4N9RX@2&]T;6%I
M;"D@=7-E('1H92!F;VQL;W=I;F<@9&EV('1A9R!A<R!A('=A>0H@("`@("`@
M("`@("`O+R!T;R!D969I;F4@82!B;&]C:R!O9B!T97AT+@H@("`@("`@("`@
M("`G+SQD:78@8VQA<W,]<G1E/B@N*S\I/%PO9&EV/B`_+VDG(#T^("=<,2<@
M+B`B7&XB"B`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E
M>'`G(#T^("1R96=E>'`I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T
M97,@86YY(&-O9&4@;F5C97-S87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL
M=&5R"B`@("`@*B!P871T97)N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@=&5X="!A9G1E<B!T:&4@9FEL=&5R:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<&]S=%!R;V-E<W,H)'1E>'0I"B`@("![
M"B`@("`@("`@9VQO8F%L("1?:'1M;#)T97AT7W-T871E.PH*("`@("`@("`O
M*B!3=')I<"!A;GD@;W1H97(@2%1-3"!T86=S+B`J+PH@("`@("`@("1T97AT
M(#T@<W1R:7!?=&%G<R@D=&5X="D["@H@("`@("`@("\J($-O;G9E<G0@:'1M
M;"!E;G1I=&EE<RX@*B\*("`@("`@("`D=&5X="`]($!H=&UL7V5N=&ET>5]D
M96-O9&4H)'1E>'0L($5.5%]154]415,L("1T:&ES+3Y?<&%R86US6R=C:&%R
M<V5T)UTI.PH*("`@("`@("`O*B!"<FEN9R!D;W=N(&YU;6)E<B!O9B!E;7!T
M>2!L:6YE<R!T;R`R(&UA>"X@*B\*("`@("`@("`D=&5X="`]('!R96=?<F5P
M;&%C92@B+UQN6ULZ<W!A8V4Z75TK7&XO(BP@(EQN7&XB+"`D=&5X="D["B`@
M("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H(B];7&Y=>S,L?2\B+"`B7&Y<
M;B(L("1T97AT*3L*"B`@("`@("`@+RH@5W)A<"!T:&4@=&5X="!T;R!A(')E
M861A8FQE(&9O<FUA="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;
M)W=R87`G72D@>PH@("`@("`@("`@("`D=&5X="`]('=O<F1W<F%P*"1T97AT
M+"`D=&AI<RT^7W!A<F%M<ULG=VED=&@G72D["B`@("`@("`@?0H*("`@("`@
M("`O*B!!9&0@;&EN:R!L:7-T+B`J+PH@("`@("`@(&EF("@A96UP='DH)%]H
M=&UL,G1E>'1?<W1A=&5;)VQI;FM,:7-T)UTI*2!["B`@("`@("`@("`@("1T
M97AT("X](")<;EQN(B`N(%\H(DQI;FMS(BD@+B`B.EQN(B`N('-T<E]R97!E
M870H)RTG+"!3=')I;F<Z.FQE;F=T:"A?*"),:6YK<R(I*2`K(#$I("X@(EQN
M(B`N("1?:'1M;#)T97AT7W-T871E6R=L:6YK3&ES="==.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@551&+3@@8VAA<F%C=&5R('-E<75E;F-E(&]F(&$@56YI
M8V]D92!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;G5M
M("!!(%5N:6-O9&4@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!55$8M."!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I
M;G0R=71F."@D;G5M*0H@("`@>PH@("`@("`@(&EF("@D;G5M(#P@,3(X*2![
M"B`@("`@("`@("`@(')E='5R;B!C:'(H)&YU;2D["B`@("`@("`@?0H@("`@
M("`@(&EF("@D;G5M(#P@,C`T."D@>PH@("`@("`@("`@("!R971U<FX@8VAR
M*"@D;G5M(#X^(#8I("L@,3DR*2`N(&-H<B@H)&YU;2`F(#8S*2`K(#$R."D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D;G5M(#P@-C4U,S8I('L*("`@("`@
M("`@("`@<F5T=7)N(&-H<B@H)&YU;2`^/B`Q,BD@*R`R,C0I("X@8VAR*"@H
M)&YU;2`^/B`V*2`F(#8S*2`K(#$R."D@+@H@("`@("`@("`@("`@("`@8VAR
M*"@D;G5M("8@-C,I("L@,3(X*3L*("`@("`@("!]"B`@("`@("`@:68@*"1N
M=6T@/"`R,#DW,34R*2!["B`@("`@("`@("`@(')E='5R;B!C:'(H*"1N=6T@
M/CX@,3@I("L@,C0P*2`N(&-H<B@H*"1N=6T@/CX@,3(I("8@-C,I("L@,3(X
M*2`N"B`@("`@("`@("`@("`@("!C:'(H*"@D;G5M(#X^(#8I("8@-C,I("L@
M,3(X*2`N(&-H<B@H)&YU;2`F(#8S*2`K(#$R."D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`G)SL*("`@('T*"B`@("`O*BH*("`@("`J($AE;'!E<B!F
M=6YC=&EO;B!C86QL960@8GD@<')E9U]R97!L86-E*"D@;VX@;&EN:R!R97!L
M86-E;65N="X*("`@("`J"B`@("`@*B!-86EN=&%I;G,@86X@:6YT97)N86P@
M;&ES="!O9B!L:6YK<R!T;R!B92!D:7-P;&%Y960@870@=&AE(&5N9`H@("`@
M("H@;V8@=&AE('1E>'0L('=I=&@@;G5M97)I8R!I;F1I8V5S('1O('1H92!O
M<FEG:6YA;"!P;VEN="!I;B!T:&4*("`@("`J('1E>'0@=&AE>2!A<'!E87)E
M9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;&EN:U]C;W5N="`@0V]U;G1E<B!T<F%C:VEN
M9R!C=7)R96YT(&QI;FL@;G5M8F5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&QI;FL@("`@("`@(%523"!O9B!T:&4@;&EN:RX*("`@("`J($!P87)A;2!S
M=')I;F<@("1D:7-P;&%Y("`@("!087)T(&]F('1H92!T97AT('1O(&%S<V]C
M:6%T92!N=6UB97(@=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&QI;FL@<F5P;&%C96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]B=6EL9$QI;FM,:7-T*"1L:6YK7V-O=6YT+"`D;&EN:RP@)&1I<W!L87DI
M"B`@("!["B`@("`@("`@9VQO8F%L("1?:'1M;#)T97AT7W-T871E.PH*("`@
M("`@("`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:T-O=6YT)UTK*SL*("`@("`@
M("`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:TQI<W0G72`N/2`G6R<@+B`D7VAT
M;6PR=&5X=%]S=&%T95LG;&EN:T-O=6YT)UT@+B`B72`D;&EN:UQN(CL*("`@
M("`@("!R971U<FX@)&1I<W!L87D@+B`G6R<@+B`D7VAT;6PR=&5X=%]S=&%T
M95LG;&EN:T-O=6YT)UT@+B`G72<["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<B]E;6]T:6-O;G,N<&AP````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3`T-S8`,3`U,34T,S$P-C$`,#(S,3`V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO
M<F1E+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?1FEL=&5R7V5M;W1I8V]N<SHZ
M(&-L87-S(&9I;F1S(&5M;W1I8V]N('-T<FEN9W,@*"`Z*2P@971C+BD@:6X@
M80H@*B!B;&]C:R!O9B!T97AT(&%N9"!T=7)N<R!T:&5M(&EN=&\@:6UA9V4@
M;&EN:W,N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J(&5N=&ET:65S
M("TM($EF('1R=64@=&AE(&AT;6P@96YT:71Y('9E<G-I;VYS(&]F('1H92!P
M871T97)N<R!W:6QL(&)E('5S960N"B`J(#PO<')E/@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UO=&EC;VYS+G!H<"QV
M(#$N,3<N,3`N,3`@,C`P-B\P-R\R-"`P-#HT.#HQ-R!S;'5S87)Z($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K
M;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED
M(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA<FMO
M($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($AO<F1E7U1E
M>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7V5M;W1I8V]N<R!E>'1E;F1S(%1E
M>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E<B!P87)A;65T97)S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<&%R86US(#T@87)R87DH)V5N=&ET:65S)R`]/B!F86QS92D["@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@
M("`@("1R96=E>'`@/2!A<G)A>2@I.PH@("`@("`@("1I8V]N<&%T:"`]("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`N("<O
M96UO=&EC;VYS)SL*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H('!O<W-I8FQE
M('-T<FEN9R!E;6]T:6-O;G,@86YD(&-O;G9E<G0@=&\@9W)A<&AI8W,N("HO
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E=$EC;VYS*"D@87,@)'-T<FEN
M9R`]/B`D:6-O;BD@>PH@("`@("`@("`@("`D8F5G7W!A='1E<FX@/2`G*%Y\
M7',I)SL*("`@("`@("`@("`@)&5N9%]P871T97)N(#T@)R@_/5QS*2<["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG96YT:71I97,G72D@>PH@
M("`@("`@("`@("`@("`@)'-T<FEN9R`](&AT;6QS<&5C:6%L8VAA<G,H)'-T
M<FEN9RD["B`@("`@("`@("`@("`@("`D8F5G7W!A='1E<FX@/2`G*%Y\7'-\
M/&)R("\^?"9N8G-P.RDG.PH@("`@("`@("`@("`@("`@)&5N9%]P871T97)N
M(#T@)R@_/5QS?#QB<B`O/GPF;F)S<#LI)SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+RH@0VAE8VL@9F]R(&$@<VUI;&5Y(&5I=&AE<B!I;6UE9&EA
M=&5L>2!A="!T:&4@<W1A<G0@;V8@82!L:6YE(&]R"B`@("`@("`@("`@("`J
M(&9O;&QO=VEN9R!A('-P86-E+B!5<V4@>WT@87,@=&AE('!R96<@9&5L:6UI
M=&5R<R!A<R!T:&ES(&ES(&YO=`H@("`@("`@("`@("`@*B!F;W5N9"!I;B!A
M;GD@<VUI;&5Y+B`J+PH@("`@("`@("`@("`D<F5G97AP6R=[)R`N("1B96=?
M<&%T=&5R;B`N('!R96=?<75O=&4H)'-T<FEN9RD@+B`D96YD7W!A='1E<FX@
M+B`G?2==(#T@)UQ<,2<@+B!(;W)D93HZ:6UG*"1I8V]N("X@)RYP;F<G+"`D
M<W1R:6YG+"!A<G)A>2@G86QI9VXG(#T^("=M:61D;&4G+"`G=&ET;&4G(#T^
M("1S=')I;F<I+"`D:6-O;G!A=&@I("X@*"@D=&AI<RT^7W!A<F%M<ULG96YT
M:71I97,G72D@/R`G7%PR)R`Z("<G*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@96UO=&EC;VYS(&%N9"!N
M86UE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N<R!H
M87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971)8V]N<R@I"B`@("!["B`@
M("`@("`@+RH@3&ES="!C;VUP;&5X('-T<FEN9W,@8F5F;W)E('-I;7!L97(@
M;VYE<RP@;W1H97)W:7-E(&9O<B!E>&%M<&QE(#HH*`H@("`@("`@("`J('=O
M=6QD(&)E(&UA=&-H960@86=A:6YS="`Z*"!B969O<F4@.B@H(&ES(&9O=6YD
M+B`J+PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@)SHO)R`]
M/B`G9G)U<W1R871E9"<L("<Z+2\G(#T^("=F<G5S=')A=&5D)RP*("`@("`@
M("`@("`@+R\@)SHJ/B<@/3X@)V)L=7-H)RP*("`@("`@("`@("`@)SIE)R`]
M/B`G9&ES87!P;VEN=&5D)RP*("`@("`@("`@("`@)STZ*20G(#T^("=M<G0G
M+`H@("`@("`@("`@("`G(WPG(#T^("=H86YG;W9E<B<L("<C+7PG(#T^("=H
M86YG;W9E<B<L"B`@("`@("`@("`@("<Z+4`G(#T^("=S:&]U="<L"B`@("`@
M("`@("`@("<Z*"@G(#T^("=B:6=F<F]W;B<L("<Z0R<@/3X@)V)I9V9R;W=N
M)RP*("`@("`@("`@("`@)SI3)R`]/B`G9&%Z960G+"`G.BU3)R`]/B`G9&%Z
M960G+`H@("`@("`@("`@("`G6$`G(#T^("=A;F=R>2<L"B`@("`@("`@("`@
M("=8*"<@/3X@)VUA9"<L"B`@("`@("`@("`@("\O("<^.BDG(#T^("=D979I
M;"<L("<^.BTI)R`]/B`G9&5V:6PG+`H@("`@("`@("`@("`O+R`G/CIP)R`]
M/B`G9&5V:6QT;VYG=64G+"`G/CHM<"<@/3X@)V1E=FEL=&]N9W5E)RP*("`@
M("`@("`@("`@+R\@)SXZ<"<@/3X@)W)A<W!B97)R>2<L("<^.E`G(#T^("=R
M87-P8F5R<GDG+`H@("`@("`@("`@("`O+R`G)BDG(#T^("=P=6YK)RP*("`@
M("`@("`@("`@+R\@)R9P)R`]/B`G<'5N:W1O;F=U92<L"B`@("`@("`@("`@
M("\O("<])BDG(#T^("=P=6YK;6]H87=K)RP*("`@("`@("`@("`@)SI=)R`]
M/B`G9W)I;B<L"B`@("`@("`@("`@("<C6R<@/3X@)VAU<G0G+"`G(R@G(#T^
M("=H=7)T)RP@)R,M6R<@/3X@)VAU<G0G+"`G(RTH)R`]/B`G:'5R="<L"B`@
M("`@("`@("`@("<Z3R<@/3X@)V5M8F%R<F%S<V5D)RP@)SHM3R<@/3X@)V5M
M8F%R<F%S<V5D)RP*("`@("`@("`@("`@)SI;)R`]/B`G<V%D)RP*("`@("`@
M("`@("`@+R\@)SXZ0"<@/3X@)V5N<F%G960G+`H@("`@("`@("`@("`O+R`G
M.B8G(#T^("=A;FYO>65D)RP*("`@("`@("`@("`@)STH)R`]/B`G=V]R<FEE
M9"<L("<]+2@G(#T^("=W;W)R:65D)RP*("`@("`@("`@("`@)SI\/2<@/3X@
M)W9A;7!I<F4G+`H@("`@("`@("`@("`G.BTH)R`]/B`G9G)O=VXG+`H@("`@
M("`@("`@("`G.D0G(#T^("=B:6=G<FEN)RP*("`@("`@("`@("`@)S@I)R`]
M/B`G8V]O;"<L"B`@("`@("`@("`@("\O($EN($5N9VQI<V@L(#A032!O8V-U
M<G,@<W5F9FEC:65N=&QY(&]F=&5N('1O('-P96-I9FEC86QL>0H@("`@("`@
M("`@("`O+R!S96%R8V@@9F]R(&%N9"!E>&-L=61E"B`@("`@("`@("`@("<X
M<"@_/"%;36U=7',K*2<@/3X@)V-O;VQT;VYG=64G+"`O+R`G.-XG(#T^("=C
M;V]L=&]N9W5E)RP*("`@("`@("`@("`@)SA$)R`]/B`G8V]O;&=R:6XG+`H@
M("`@("`@("`@("`G.G`G(#T^("=T;VYG=65O=70G+"`G.E`G(#T^("=T;VYG
M=65O=70G+"`O+R`G.MXG(#T^("=T;VYG=65O=70G+`H@("`@("`@("`@("`G
M/SHH)R`]/B`G8V]N9G5S960G+"`G)2TH)R`]/B`G8V]N9G5S960G+`H@("`@
M("`@("`@("`O+R`G.BDF)R`]/B`G;&]V92<L"B`@("`@("`@("`@("=/.RTI
M)R`]/B`G86YG96QW:6YK)RP*("`@("`@("`@("`@)SM=)R`]/B`G=VEN:V=R
M:6XG+`H@("`@("`@("`@("`G.W`G(#T^("=W:6YK=&]N9W5E)RP@)SM0)R`]
M/B`G=VEN:W1O;F=U92<L("\O("<[WB<@/3X@)W=I;FMT;VYG=64G+`H@("`@
M("`@("`@("`G.GPG(#T^("=I;F1I9F9E<F5N="<L("<Z+7PG(#T^("=I;F1I
M9F9E<F5N="<L"B`@("`@("`@("`@("<A?"<@/3X@)W1I<F5D)RP@)R$M22<@
M/3X@)W1I<F5D)RP*("`@("`@("`@("`@)WQ))R`]/B`G87-L965P)RP@)WPM
M22<@/3X@)V%S;&5E<"<L"B`@("`@("`@("`@("=/.BDG(#T^("=A;F=E;"<L
M("=/.BTI)R`]/B`G86YG96PG+`H@("`@("`@("`@("`G3SLI)R`]/B`G86YG
M96QW:6YK)RP*("`@("`@("`@("`@)SLM*2<@/3X@)W=I;FLG+`H@("`@("`@
M("`@("`G.B,I)R`]/B`G8VQO=VXG+"`G.F\I)R`]/B`G8VQO=VXG+`H@("`@
M("`@("`@("`G.BDG(#T^("=S;6EL92<L"B`@("`@("`@("`@("<[*2<@/3X@
M)W=I;FLG+`H@("`@("`@("`@("`G.BTI)R`]/B`G<VUI;&4G+`H@("`@("`@
M("`@("`G.D`G(#T^("=S:&]U="<L"B`@("`@("`@("`@("<Z*"<@/3X@)V9R
M;W=N)RP*("`@("`@("`I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W1A
M8G,R<W!A8V5S+G!H<```````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4P,P`Q,#4Q
M-30S,3`V,0`P,C,S,3``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!497AT7T9I;'1E<E]T86)S
M,G-P86-E<SHZ(&-O;G9E<G1S('1A8G,@:6YT;R!S<&%C97,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]T86)S,G-P86-E
M<RYP:'`L=B`Q+C,N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E
M($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W1A8G,R<W!A8V5S
M(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R
M('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G=&%B<W1O<"<@/3X@."P@)V)R
M96%K8VAA<B<@/3X@(EQN(BD["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A
M;GD@8V]D92!N96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@
M<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@
M5&AE('1E>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@("1L
M:6YE<R`](&5X<&QO9&4H)'1H:7,M/E]P87)A;7-;)V)R96%K8VAA<B==+"`D
M=&5X="D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&QI;F5S
M*3L@)&DK*RD@>PH@("`@("`@("`@("!W:&EL92`H*"1P;W,@/2!S=')P;W,H
M)&QI;F5S6R1I72P@(EQT(BDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@)&Y?<W!A8V4@/2`D=&AI<RT^7W!A<F%M<ULG=&%B<W1O<"==("T@*"1P
M;W,@)2`D=&AI<RT^7W!A<F%M<ULG=&%B<W1O<"==*3L*("`@("`@("`@("`@
M("`@("1N97=?<W1R(#T@<W1R7W)E<&5A="@G("<L("1N7W-P86-E*3L*("`@
M("`@("`@("`@("`@("1L:6YE<ULD:5T@/2!S=6)S=')?<F5P;&%C92@D;&EN
M97-;)&E=+"`D;F5W7W-T<BP@)'!O<RP@,2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H(EQN(BP@)&QI;F5S*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O=&5X=#)H=&UL+G!H<```````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$R-#8W`#$P-3$U-#,Q,#8Q`#`R,S`T,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E("=(;W)D92YP:'`G.PH*+RHJ"B`J(%1U<FX@=&5X="!I;G1O
M($A434P@=VET:"!V87)Y:6YG(&QE=F5L<R!O9B!P87)S:6YG+B`@1F]R(&YO
M(&AT;6P*("H@=VAA='-O979E<BP@=7-E(&AT;6QS<&5C:6%L8VAA<G,H*2!I
M;G-T96%D+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!P87)S96QE
M=F5L("TM(%1H92!P87)S96QE=F5L(&]F('1H92!O=71P=70N(%-E92!T:&4@
M;&ES="!O9B!C;VYS=&%N=',@8F5L;W<N"B`J(&-H87)S970@("`@+2T@5&AE
M(&-H87)S970@=&\@=7-E(&9O<B!H=&UL<W!E8VEA;&-H87)S*"D@8V%L;',N
M"B`J(&-L87-S("`@("`@+2T@5&AE($-34R!C;&%S<R!N86UE(&9O<B!T:&4@
M;&EN:W,N"B`J(&YO9F]L;&]W("`@+2T@5VAE=&AE<B!T;R!S970@=&AE("=R
M96P](FYO9F]L;&]W(B<@871T<FEB=71E(&]N(&QI;FMS+@H@*B!C86QL8F%C
M:R`@("TM($%N(&]P=&EO;F%L(&-A;&QB86-K(&9U;F-T:6]N('1H870@=&AE
M(%523"!I<R!P87-S960@=&AR;W5G:`H@*B`@("`@("`@("`@("`@(&)E9F]R
M92!B96EN9R!S970@87,@=&AE(&AR968@871T<FEB=71E+B`@375S="!B92!A
M('-T<FEN9R!W:71H"B`J("`@("`@("`@("`@("`@=&AE(&9U;F-T:6]N(&YA
M;64L('1H92!F=6YC=&EO;B!M=7-T('1A:V4@=&AE(&]R:6=I;F%L(&%S('1H
M90H@*B`@("`@("`@("`@("`@(&9I<G-T(&%N9"!O;FQY('!A<F%M971E<BX*
M("H@/"]P<F4^"B`J"B`J(#QP<F4^"B`J($QI<W0@;V8@=F%L:60@8V]N<W1A
M;G1S(&9O<B!T:&4@<&%R<V4@;&5V96PZ"B`J("TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`J(%1%6%1?2%1-3%]005-3
M5$A252`@("`@("`@/2`@3F\@86-T:6]N+B!087-S+71H<F]U9V@N($EN8VQU
M9&5D(&9O<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;7!L
M971E;F5S<RX*("H@5$585%](5$U,7U-93E1!6"`@("`@("`@("`]("!!;&QO
M=R!F=6QL(&AT;6PL(&%L<V\@9&\@;&EN92UB<F5A:W,L"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:6XM;&EN:6YG+"!S>6YT87@M<&%R<VEN
M9RX*("H@5$585%](5$U,7TU)0U)/("`@("`@("`@("`]("!-:6-R;R!H=&UL
M("AO;FQY(&QI;F4M8G)E86MS+"!I;BUL:6YE(&QI;FMI;F<I+@H@*B!415A4
M7TA434Q?34E#4D]?3$E.2U523"`@(#T@($UI8W)O(&AT;6P@*&]N;'D@;&EN
M92UB<F5A:W,L(&EN+6QI;F4@;&EN:VEN9PH@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]F(%523%-S.R!N;R!E;6%I;"!A9&1R97-S97,@87)E
M(&QI;FME9"DN"B`J(%1%6%1?2%1-3%].3TA434P@("`@("`@("`@/2`@3F\@
M:'1M;"`H86QL('-T<FEP<&5D+"!O;FQY(&QI;F4M8G)E86MS*0H@*B!415A4
M7TA434Q?3D](5$U,7TY/0E)%04L@(#T@($YO(&AT;6P@=VAA='-O979E<BP@
M;F\@;&EN92!B<F5A:W,@861D960N"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@26YC;'5D960@9F]R(&-O;7!L971E;F5S<RX*("H@/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]T
M97AT,FAT;6PN<&AP+'8@,2XT+C(N-B`R,#`V+S`R+S$W(#(P.C`U.C0Y(&-H
M=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E
M<E]T97AT,FAT;6P@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@
M("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=C:&%R<V5T
M)R`]/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V-L87-S)R`]
M/B`G9FEX960G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)VYO9F]L;&]W
M)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("=C86QL8F%C
M:R<@/3X@)TAO<F1E.CIE>'1E<FYA;%5R;"<I.PH*("`@("\J*@H@("`@("H@
M17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R92!A<'!L>6EN9R!T
M:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*
M("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==(#T@
M:7-S970H)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==*2`_("1'
M3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72`Z("=)4T\M.#@U.2TQ
M)SL*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&]U="!O;B!S:6UP;&4@
M8V%S97,N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=P87)S96QE
M=F5L)UT@/3T@5$585%](5$U,7U!!4U-42%)5*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&5X=#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R
M86US6R=P87)S96QE=F5L)UT@/3T@5$585%](5$U,7TY/2%1-3%].3T)214%+
M*2!["B`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R<R@D=&5X
M="P@14Y47T-/35!!5"P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@
M("`@("`@?0H*("`@("`@("`O*B!$;R!I;BUL:6YI;F<@;V8@:'1T<#HO+WAX
M>"YX>'@@=&\@;&EN:RP@>'AX0'AX>"YX>'@@=&\@96UA:6PL('!A<G0*("`@
M("`@("`@*B!O;F4N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=P
M87)S96QE=F5L)UT@/"!415A47TA434Q?3D](5$U,*2!["B`@("`@("`@("`@
M("\J($UA:V4@<W5R92!T:&%T('1H92!O<FEG:6YA;"!M97-S86=E(&1O97-N
M)W0@8V]N=&%I;B!A;GD@8V%P:71A;`H@("`@("`@("`@("`@*B`\+T$^('1A
M9W,@;W(@;W!E;B`\03X@=&%G<R`L('-O('=E(&-A;B!A<W-U;64@=V4@9V5N
M97)A=&5D"B`@("`@("`@("`@("`J('1H96TN("HO"B`@("`@("`@("`@("1T
M97AT(#T@<W1R7W)E<&QA8V4H87)R87DH)SPO03XG+"`G/$$G*2P@87)R87DH
M)SPO83XG+"`G/&$G*2P@)'1E>'0I.PH@("`@("`@("`@("`D9FEL=&5R7V%R
M<F%Y(#T@87)R87DH)VQI;FMU<FQS)RD["B`@("`@("`@("`@("1F:6QT97)?
M<&%R86US(#T@87)R87DH87)R87DH)V-A;&QB86-K)R`]/B`D=&AI<RT^7W!A
M<F%M<ULG8V%L;&)A8VLG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;F]F;VQL;W<G(#T^("1T:&ES+3Y?<&%R86US6R=N
M;V9O;&QO=R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C87!I=&%L)R`]/B!T<G5E*2D["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W!A<F%M<ULG<&%R<V5L979E;"==(#P@5$585%](5$U,7TU)0U)/
M7TQ)3DM54DPI('L*("`@("`@("`@("`@("`@("1F:6QT97)?87)R87E;72`]
M("=E;6%I;',G.PH@("`@("`@("`@("`@("`@)&9I;'1E<E]P87)A;7-;72`]
M(&%R<F%Y*"=C87!I=&%L7W1A9W,G(#T^('1R=64I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T97AT(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D=&5X
M="P@)&9I;'1E<E]A<G)A>2P@)&9I;'1E<E]P87)A;7,I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@1F]R(&QE=F5L(%1%6%1?2%1-3%]-24-23RP@5$585%](
M5$U,7TY/2%1-3"P@<W1A<G0@=VET:`H@("`@("`@("`J(&AT;6QS<&5C:6%L
M8VAA<G,H*2X@*B\*("`@("`@("`D=&5X="`]($!H=&UL<W!E8VEA;&-H87)S
M*"1T97AT+"!%3E1?0T]-4$%4+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==
M*3L*"B`@("`@("`@+RH@1&\@:6XM;&EN:6YG(&]F(&AT='`Z+R]X>'@N>'AX
M('1O(&QI;FLL('AX>$!X>'@N>'AX('1O(&5M86EL+"!P87)T"B`@("`@("`@
M("H@='=O+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%R<V5L
M979E;"==(#P@5$585%](5$U,7TY/2%1-3"D@>PH@("`@("`@("`@("`D<WEN
M=&%X(#T@87)R87DH"B`@("`@("`@("`@("`@("`G)FQT.T$@:')E9CTF<75O
M=#LG(#T^("<\82<@+B`H96UP='DH)'1H:7,M/E]P87)A;7-;)V-L87-S)UTI
M(#\@)R<@.B`G(&-L87-S/2(G("X@)'1H:7,M/E]P87)A;7-;)V-L87-S)UT@
M+B`G(B<I("X@)R!H<F5F/2(G+`H@("`@("`@("`@("`@("`@)R9Q=6]T.R!R
M96P])G%U;W0[)R`]/B`G(B!R96P](B<L"B`@("`@("`@("`@("`@("`G)G%U
M;W0[('1I=&QE/29Q=6]T.R<@/3X@)R(@=&ET;&4](B<L"B`@("`@("`@("`@
M("`@("`G)G%U;W0[('1A<F=E=#TF<75O=#M?8FQA;FLF<75O=#LF9W0[)R`@
M/3X@)R(@=&%R9V5T/2)?8FQA;FLB/B<L"B`@("`@("`@("`@("`@("`G)G%U
M;W0[(&]N8VQI8VL])G%U;W0[)R`]/B`G(B!O;F-L:6-K/2(G+`H@("`@("`@
M("`@("`@("`@)UPG*3LF<75O=#LF9W0[)R`]/B`G7"<I.R(^)RP*("`@("`@
M("`@("`@("`@("<F<75O=#LF9W0[)R`]/B`@)R(^)RP*("`@("`@("`@("`@
M("`@("\J($]N;'D@<F5C;VYV97)T(&-A<&ET86P@+T$@=&%G<R`M('1H92!O
M;F5S('=E(&=E;F5R871E9"X@*B\*("`@("`@("`@("`@("`@("<F;'0[+T$F
M9W0[)R`]/B`G/"]A/B<*("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@
M("`D=&5X="`]('-T<E]R97!L86-E*&%R<F%Y7VME>7,H)'-Y;G1A>"DL("1S
M>6YT87@L("1T97AT*3L*("`@("`@("`@("`@)'1E>'0@/2!497AT7T9I;'1E
M<CHZ9FEL=&5R*"1T97AT+"`G<W!A8V4R:'1M;"<I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@1&\@=&AE(&)L86YK+6QI;F4@+2TM/B`\8G(@+SX@<W5B<W1I
M='5T:6]N+B`@179E<GEB;V1Y(&=E=',@=&AI<SL*("`@("`@("`@*B!I9B!Y
M;W4@9&]N)W0@=V%N="!E=F5N('1H870L(&IU<W0@<V%V92!T:&4@:'1M;'-P
M96-I86QC:&%R<R@I"B`@("`@("`@("H@=F5R<VEO;B!O9B!T:&4@:6YP=70N
M("HO"B`@("`@("`@)'1E>'0@/2!N;#)B<B@D=&5X="D["@H@("`@("`@(')E
M='5R;B`D=&5X=#L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(N
M<&AP````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-30U`#$P
M-3$U-#,Q,#8Q`#`R,3$P-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M"@ID969I;F4H)U1%6%1?2%1-3%]005-35$A252<L(#`I.PID969I;F4H)U1%
M6%1?2%1-3%]364Y405@G+"`Q*3L*9&5F:6YE*"=415A47TA434Q?34E#4D\G
M+"`R*3L*9&5F:6YE*"=415A47TA434Q?34E#4D]?3$E.2U523"<L(#,I.PID
M969I;F4H)U1%6%1?2%1-3%].3TA434PG+"`T*3L*9&5F:6YE*"=415A47TA4
M34Q?3D](5$U,7TY/0E)%04LG+"`U*3L*"B\J*@H@*B!497AT7T9I;'1E<CHZ
M(&ES(&$@<&%R96YT(&-L87-S(&9O<B!D969I;FEN9R!S=&%C:V%B;&4@=&5X
M="!F:6QT97)S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(N<&AP+'8@,2XQ-2XR+CD@,C`P-B\P-2\Q,2`Q.3HT.3HQ-"!C
M:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E
M>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I
M;'1E<B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&%T('1H92!F:6QT97(@:6YS=&%N
M8V4@;F5E9',N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?1FEL=&5R*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@87)R87E?;65R9V4H)'1H:7,M/E]P87)A;7,L("1P87)A;7,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@07!P;&EE<R!A('-E="!O9B!P871T97)N<R!T
M;R!A(&)L;V-K(&]F('1E>'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@("`@5&AE('1E>'0@=&\@9FEL=&5R+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P871T97)N<R`@5&AE(&%R<F%Y(&]F('!A='1E<FYS('1O(&9I
M;'1E<B!W:71H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M=')A;G-F;W)M960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL=&5R
M*"1T97AT+"`D9FEL=&5R<R`](&%R<F%Y*"DL("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&9I;'1E<G,I*2!["B`@
M("`@("`@("`@("1F:6QT97)S(#T@87)R87DH)&9I;'1E<G,I.PH@("`@("`@
M("`@("`D<&%R86US(#T@87)R87DH)'!A<F%M<RD["B`@("`@("`@?0H*("`@
M("`@("!F;W)E86-H("@D9FEL=&5R<R!A<R`D;G5M(#T^("1F:6QT97(I('L*
M("`@("`@("`@("`@)&9I;'1E<D]B(#T@5&5X=%]&:6QT97(Z.F9A8W1O<GDH
M)&9I;'1E<BP@:7-S970H)'!A<F%M<ULD;G5M72D@/R`D<&%R86US6R1N=6U=
M(#H@87)R87DH*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1F:6QT97)/8BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1F:6QT
M97)/8BT^9V5T365S<V%G92@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1P871T97)N<R`]("1F:6QT97)/8BT^9V5T4&%T=&5R;G,H*3L*"B`@("`@
M("`@("`@("\J(%!R92UP<F]C97-S:6YG+B`J+PH@("`@("`@("`@("`D=&5X
M="`]("1F:6QT97)/8BT^<')E4')O8V5S<R@D=&5X="D["@H@("`@("`@("`@
M("`O*B!S=')?<F5P;&%C92@I('-I;7!L92!P871T97)N<RX@*B\*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P871T97)N<ULG<F5P;&%C92==*2D@>PH@("`@
M("`@("`@("`@("`@)&9R;VT@/2!A<G)A>5]K97ES*"1P871T97)N<ULG<F5P
M;&%C92==*3L*("`@("`@("`@("`@("`@("1T;R`](&%R<F%Y7W9A;'5E<R@D
M<&%T=&5R;G-;)W)E<&QA8V4G72D["B`@("`@("`@("`@("`@("`D=&5X="`]
M('-T<E]R97!L86-E*"1F<F]M+"`D=&\L("1T97AT*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@<')E9U]R97!L86-E(&-O;7!L97@@<&%T=&5R
M;G,N("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%T=&5R;G-;)W)E9V5X
M<"==*2D@>PH@("`@("`@("`@("`@("`@)&9R;VT@/2!A<G)A>5]K97ES*"1P
M871T97)N<ULG<F5G97AP)UTI.PH@("`@("`@("`@("`@("`@)'1O(#T@87)R
M87E?=F%L=65S*"1P871T97)N<ULG<F5G97AP)UTI.PH@("`@("`@("`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)&9R;VTL("1T;RP@)'1E>'0I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!0;W-T+7!R;V-E<W-I;F<N
M("HO"B`@("`@("`@("`@("1T97AT(#T@)&9I;'1E<D]B+3YP;W-T4')O8V5S
M<R@D=&5X="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A
M<F%Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R"B`@("`@*B!P871T97)N
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X
M="!B969O<F4@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('!R95!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET
M:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A
M='1E<FYS*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@
M869T97(@87!P;'EI;F<@=&AE(&9I;'1E<@H@("`@("H@<&%T=&5R;G,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@869T
M97(@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O
M<W10<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&5X=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O
M;F-R971E(%1E>'1?9FEL=&5R(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D
M9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4
M:&4@='EP92!O9B!C;VYC<F5T92!497AT7T9I;'1E<B!S=6)C;&%S<R!T;PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@5&AI<R!I<R!B
M87-E9"!O;B!T:&4@9FEL=&5R(&1R:79E<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("@D9')I=F5R*2X@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@
M:6YC;'5D960N($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R
M:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL@:6X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=(&9O<B!T:&4@<W5B
M8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C
M;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R
M86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!497AT7T9I;'1E<B`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E
M=&4@5&5X=%]&:6QT97(@:6YS=&%N8V4L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@
M("`@(&QI<W0H)&1I<BP@)&1R:79E<BD@/2`D9')I=F5R.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E;7!T>2@D9&ER*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)&1I<B`N("<O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@
M("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N
M("<O1FEL=&5R+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+T9I;'1E<B\G
M("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]497AT+T9I;'1E<B\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=4
M97AT7T9I;'1E<E\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI
M<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&9I;'1E<B`]("9N97<@)&-L
M87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M:6QT97(@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F
M("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9FEL=&5R.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,3`V,0`P,3<Q,38`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O5')E92]H=&UL+G!H<```````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#0R,3(U`#$P-3$U-#,Q,#8Q`#`R,#4W-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($AO<F1E7U1R965?:'1M;#HZ(&-L87-S(&5X=&5N9',@=&AE
M($AO<F1E7U1R964@8VQA<W,@=&\@<')O=FED90H@*B!(5$U,('-P96-I9FEC
M(')E;F1E<FEN9R!F=6YC=&EO;G,N"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1R964O5')E92]H=&UL+G!H<"QV
M(#$N-3$N,BXQ,B`R,#`V+S`Q+S$U(#$V.C,S.C(Y(&-H=6-K($5X<"`D"B`J
M"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M($!P86-K86=E($AO<F1E7U1R964*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M+PIC;&%S<R!(;W)D95]4<F5E7VAT;6P@97AT96YD<R!(;W)D95]4<F5E('L*
M"B`@("`O*BH*("`@("`J($EM86=E(&1I<F5C=&]R>2!L;V-A=&EO;BX*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?
M9&ER(#T@)R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI
M8R!F;W(@82!L:6YE+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VEM9U]L:6YE(#T@)VQI;F4N<&YG)SL*"B`@("`O*BH*
M("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&)L86YK+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]B
M;&%N:R`]("=B;&%N:RYP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T
M<F5E(&=R87!H:6,@9F]R(&$@:F]I;BX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?:F]I;B`]("=J;VEN+G!N9R<[
M"@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!B
M;W1T;VT@:F]I;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]I;6=?:F]I;E]B;W1T;VT@/2`G:F]I;F)O='1O;2YP;F<G
M.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@
M<&QU<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]I;6=?<&QU<R`]("=P;'5S+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$
M969A=6QT('1R964@9W)A<&AI8R!F;W(@82!B;W1T;VT@<&QU<RX*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?<&QU
M<U]B;W1T;VT@/2`G<&QU<V)O='1O;2YP;F<G.PH*("`@("\J*@H@("`@("H@
M1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@<&QU<R!O;FQY+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]P;'5S
M7V]N;'D@/2`G<&QU<V]N;'DN<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U
M;'0@=')E92!G<F%P:&EC(&9O<B!A(&UI;G5S+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]M:6YU<R`]("=M:6YU
M<RYP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@
M9F]R(&$@8F]T=&]M(&UI;G5S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7VEM9U]M:6YU<U]B;W1T;VT@/2`G;6EN=7-B
M;W1T;VTN<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P
M:&EC(&9O<B!A(&UI;G5S(&]N;'DN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?:6UG7VUI;G5S7V]N;'D@/2`G;6EN=7-O
M;FQY+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI
M8R!F;W(@82!N=6QL(&]N;'DN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?:6UG7VYU;&Q?;VYL>2`]("=N=6QL;VYL>2YP
M;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R
M(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7VEM9U]F;VQD97(@/2`G9F]L9&5R+G!N9R<["@H@("`@+RHJ
M"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@86X@;W!E;B!F;VQD
M97(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?:6UG7V9O;&1E<E]O<&5N(#T@)V9O;&1E<F]P96XN<&YG)SL*"B`@("`O
M*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&QE868N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG
M7VQE868@/2`G;&5A9BYP;F<G.PH*("`@("\J*@H@("`@("H@5$]$3PH@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;F]D97,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;F]D95]P;W,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?9')O<&QI;F4@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0W5R<F5N="!V86QU92!O9B!T:&4@86QT('1A9R!C
M;W5N="X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?86QT7V-O=6YT(#T@,#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U1R965?:'1M;"@D=')E
M95]N86UE+"`D<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?
M5')E92@D=')E95]N86UE+"`D<&%R86US*3L*"B`@("`@("`@)'1H:7,M/E]I
M;6=?9&ER(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H
M;W)D92<I("X@)R]T<F5E)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T
M871I8R`@268@=')U92!T:&4@=')E92!N;V1E<R!C86XG="!B92!E>'!A;F1E
M9"!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-O;&QA<'-E
M9"!A;F0@=&AE('1R964@9V5T<R!R96YD97)E9"!E>'!A;F1E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@8V]D92!O9B!T:&4@
M<F5N9&5R960@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5')E92@D
M<W1A=&EC(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]S=&%T:6,@
M/2`D<W1A=&EC.PH@("`@("`@("1T:&ES+3Y?8G5I;&1);F1E;G1S*"1T:&ES
M+3Y?<F]O=%]N;V1E<RD["@H@("`@("`@("1T<F5E(#T@)'1H:7,M/E]B=6EL
M9$AE861E<B@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F]O=%]N;V1E
M<R!A<R`D;F]D95]I9"D@>PH@("`@("`@("`@("`D=')E92`N/2`D=&AI<RT^
M7V)U:6QD5')E92@D;F]D95]I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=')E93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K('1H92!C=7)R
M96YT(&5N=FER;VYM96YT('1O('-E92!I9B!W92!C86X@<F5N9&5R('1H92!(
M5$U,"B`@("`@*B!T<F5E+B!(5$U,(&ES(&%L=V%Y<R!R96YD97)A8FQE+"!A
M="!L96%S="!U;G1I;"!W92!A9&0@80H@("`@("H@<&AP+6=T:R!T<F5E(&)A
M8VME;F0L(&EN('=H:6-H(&-A<V4@=&AI<R!I;7!L96UE;G1A=&EO;B!W:6QL
M"B`@("`@*B!A8W1U86QL>2!N965D(&$@8F]D>2X*("`@("`J"B`@("`@*B!`
M<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R
M(&]R(&YO="!T:&ES(%1R964Z.B!B86-K96YD('=I;&P@9G5N8W1I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES4W5P<&]R=&5D*"D*("`@('L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M:G5S="!T:&4@2E,@;F]D92!D969I;FET:6]N<R!A<R!A('-T<FEN9RX@5&AI
M<R!I<R!A"B`@("`@*B!N;RUO<"!F;W(@=&AE($A434P@<F5N9&5R97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<DYO9&5$969I;FET:6]N<R@I"B`@
M("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!(5$U,(&-O
M9&4@9F]R(&$@:&5A9&5R(')O=RP@:68@;F5C97-S87)Y+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@2%1-3"!C;V1E(&]F('1H92!H96%D97(@<F]W(&]R(&%N(&5M
M<'1Y('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD2&5A9&5R
M*"D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?:&5A9&5R*2D@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D
M:'1M;"`]("<\9&EV)SL*("`@("`@("`O*B!)9B!U<VEN9R!A;'1E<FYA=&EN
M9R!R;W<@<VAA9&EN9RP@=V]R:R!O=70@8V]R<F5C=`H@("`@("`@("`J('-H
M861E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=A;'1E<FYA
M=&4G*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G(&-L87-S/2)I=&5M)R`N
M("1T:&ES+3Y?86QT7V-O=6YT("X@)R(G.PH@("`@("`@("`@("`D=&AI<RT^
M7V%L=%]C;W5N="`](#$@+2`D=&AI<RT^7V%L=%]C;W5N=#L*("`@("`@("!]
M"B`@("`@("`@)&AT;6P@+CT@)SXG.PH*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7VAE861E<B!A<R`D:&5A9&5R*2!["B`@("`@("`@("`@("1H=&UL("X]
M("<\9&EV(&-L87-S/2)L969T1FQO870G.PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1H96%D97);)V-L87-S)UTI*2!["B`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`G("<@+B`D:&5A9&5R6R=C;&%S<R==.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1H=&UL("X]("<B)SL*"B`@("`@("`@("`@("1S='EL92`]
M("<G.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1H96%D97);)W=I9'1H)UTI
M*2!["B`@("`@("`@("`@("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@+B`D:&5A
M9&5R6R=W:61T:"==("X@)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A96UP='DH)&AE861E<ELG86QI9VXG72DI('L*("`@("`@("`@("`@
M("`@("1S='EL92`N/2`G=&5X="UA;&EG;CHG("X@)&AE861E<ELG86QI9VXG
M72`N("<[)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1S='EL92DI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<@<W1Y;&4]
M(B<@+B`D<W1Y;&4@+B`G(B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&AT;6P@+CT@)SXG.PH@("`@("`@("`@("`D:'1M;"`N/2!E;7!T>2@D:&5A
M9&5R6R=H=&UL)UTI(#\@)R9N8G-P.R<@.B`D:&5A9&5R6R=H=&UL)UT["B`@
M("`@("`@("`@("1H=&UL("X]("<\+V1I=CXG.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1H=&UL("X@)SPO9&EV/B<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296-U<G-I=F4@9G5N8W1I;VX@=&\@=V%L:R!T:')O=6=H('1H92!T
M<F5E(&%R<F%Y(&%N9"!B=6EL9"!T:&4@;W5T<'5T+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YO9&5?:60@(%1H92!.;V1E($E$+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=')E92!R96YD97)I;F<N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]B=6EL9%1R964H)&YO9&5?:60I"B`@("!["B`@("`@("`@)&]U='!U
M="`]("1T:&ES+3Y?8G5I;&1,:6YE*"1N;V1E7VED*3L*"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*2`F
M)@H@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD
M960G72D@>PH@("`@("`@("`@("`D;G5M7W-U8FYO9&5S(#T@8V]U;G0H)'1H
M:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI.PH@("`@("`@("`@
M("!F;W(@*"1C(#T@,#L@)&,@/"`D;G5M7W-U8FYO9&5S.R`D8RLK*2!["B`@
M("`@("`@("`@("`@("`D8VAI;&1?;F]D95]I9"`]("1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=C:&EL9')E;B==6R1C73L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;F]D95]P;W-;)&-H:6QD7VYO9&5?:61=(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;F]D95]P;W-;)&-H:6QD7VYO9&5?:61=
M6R=P;W,G72`]("1C("L@,3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D
M95]P;W-;)&-H:6QD7VYO9&5?:61=6R=C;W5N="==(#T@)&YU;5]S=6)N;V1E
M<SL*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]B=6EL9%1R
M964H)&-H:6QD7VYO9&5?:60I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($9U;F-T:6]N('1O(&-R96%T92!A('-I;F=L92!L:6YE(&]F('1H92!T<F5E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YO9&5?:60@(%1H92!.;V1E($E$+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@;&EN92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD3&EN92@D;F]D95]I9"D*("`@('L*
M("`@("`@("`D8VQA<W-.86UE(#T@)W1R9652;W<G.PH@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-L87-S)UTI*2!["B`@
M("`@("`@("`@("1C;&%S<TYA;64@+CT@)R`G("X@)'1H:7,M/E]N;V1E<ULD
M;F]D95]I9%U;)V-L87-S)UT["B`@("`@("`@?0H@("`@("`@("\J($EF('5S
M:6YG(&%L=&5R;F%T:6YG(')O=R!S:&%D:6YG+"!W;W)K(&]U="!C;W)R96-T
M"B`@("`@("`@("H@<VAA9&4N("HO"B`@("`@("`@:68@*"1T:&ES+3YG971/
M<'1I;VXH)V%L=&5R;F%T92<I*2!["B`@("`@("`@("`@("1C;&%S<TYA;64@
M+CT@)R!I=&5M)R`N("1T:&ES+3Y?86QT7V-O=6YT.PH@("`@("`@("`@("`D
M=&AI<RT^7V%L=%]C;W5N="`](#$@+2`D=&AI<RT^7V%L=%]C;W5N=#L*("`@
M("`@("!]"@H@("`@("`@("1L:6YE(#T@)SQD:78@8VQA<W,](B<@+B`D8VQA
M<W-.86UE("X@)R(^)SL*"B`@("`@("`@+RH@268@=V4@:&%V92!H96%D97)S
M+"!T<F%C:R!W:&EC:"!L;V=I8V%L(")C;VQU;6XB('=E)W)E(&EN"B`@("`@
M("`@("H@9F]R(&%N>2!G:79E;B!C96QL(&]F(&-O;G1E;G0N("HO"B`@("`@
M("`@)&-O;'5M;B`](#`["@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYO
M9&5S6R1N;V1E7VED75LG97AT<F$G75M(3U)$15]44D5%7T585%)!7TQ%1E1=
M*2D@>PH@("`@("`@("`@("`D97AT<F$@/2`D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG97AT<F$G75M(3U)$15]44D5%7T585%)!7TQ%1E1=.PH@("`@("`@
M("`@("`D8TUA>"`](&-O=6YT*"1E>'1R82D["B`@("`@("`@("`@(&9O<B`H
M)&,@/2`P.R`D8R`\("1C36%X.R`D8RLK*2!["B`@("`@("`@("`@("`@("`D
M<W1Y;&4@/2`G)SL*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7VAE861E<ELD8V]L=6UN75LG=VED=&@G72DI('L*("`@("`@("`@("`@("`@
M("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@+B`D=&AI<RT^7VAE861E<ELD8V]L
M=6UN75LG=VED=&@G72`N("<[)SL*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D;&EN92`N/2`G/&1I=B!C;&%S<STB;&5F=$9L;V%T(B<[
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1S='EL92DI('L*("`@("`@
M("`@("`@("`@("`@("`D;&EN92`N/2`G('-T>6QE/2(G("X@)'-T>6QE("X@
M)R(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QI;F4@
M+CT@)SXG("X@)&5X=')A6R1C72`N("<\+V1I=CXG.PH*("`@("`@("`@("`@
M("`@("1C;VQU;6XK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)'-T>6QE(#T@)R<["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A
M9&5R6R1C;VQU;6Y=6R=W:61T:"==*2D@>PH@("`@("`@("`@("`D<W1Y;&4@
M+CT@)W=I9'1H.B<@+B`D=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G
M72`N("<[)SL*("`@("`@("!]"B`@("`@("`@)&QI;F4@+CT@)SQD:78@8VQA
M<W,](FQE9G1&;&]A="(G.PH@("`@("`@(&EF("@A96UP='DH)'-T>6QE*2D@
M>PH@("`@("`@("`@("`D;&EN92`N/2`G('-T>6QE/2(G("X@)'-T>6QE("X@
M)R(G.PH@("`@("`@('T*("`@("`@("`D;&EN92`N/2`G/B<["@H@("`@("`@
M(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=M=6QT:6QI;F4G*2D@>PH@("`@("`@
M("`@("`D;&EN92`N/2`G/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX\='(^/'1D
M/B<["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@)'1H:7,M/E]S=&%T
M:6,@/R`Q(#H@,#L@)&D@/"`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD
M96YT)UT[("1I*RLI('L*("`@("`@("`@("`@)&QI;F4@+CT@)SQI;6<@<W)C
M/2(G("X@)'1H:7,M/E]I;6=?9&ER("X@)R\G.PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]D<F]P;&EN95LD:5T@)B8@)'1H:7,M/F=E=$]P=&EO;B@G;&EN
M97,G+"!F86QS92P@=')U92DI('L*("`@("`@("`@("`@("`@("1L:6YE("X]
M("1T:&ES+3Y?:6UG7VQI;F4@+B`G(B`G"B`@("`@("`@("`@("`@("`@("`@
M+B`G86QT/2)\)FYB<W`[)FYB<W`[)FYB<W`[(B`G.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI;F4@+CT@)'1H:7,M/E]I;6=?
M8FQA;FL@+B`G(B`G"B`@("`@("`@("`@("`@("`@("`@+B`G86QT/2(F;F)S
M<#LF;F)S<#LF;F)S<#LB("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&QI;F4@+CT@)VAE:6=H=#TB,C`B('=I9'1H/2(R,"(@<W1Y;&4](G9E<G1I
M8V%L+6%L:6=N.FUI9&1L92(@+SXG.PH@("`@("`@('T*("`@("`@("`D;&EN
M92`N/2`D=&AI<RT^7W-E=$YO9&54;V=G;&4H)&YO9&5?:60I("X@)'1H:7,M
M/E]S971.;V1E26-O;B@D;F]D95]I9"D["B`@("`@("`@:68@*"1T:&ES+3YG
M971/<'1I;VXH)VUU;'1I;&EN92<I*2!["B`@("`@("`@("`@("1L:6YE("X]
M("<\+W1D/CQT9#XG.PH@("`@("`@('T*("`@("`@("`D;&EN92`N/2`D=&AI
M<RT^7W-E=$QA8F5L*"1N;V1E7VED*3L*"B`@("`@("`@:68@*"1T:&ES+3YG
M971/<'1I;VXH)VUU;'1I;&EN92<I*2!["B`@("`@("`@("`@("1L:6YE("X]
M("<\+W1D/CPO='(^/"]T86)L93XG.PH@("`@("`@('T*"B`@("`@("`@)&QI
M;F4@+CT@)SPO9&EV/B<["B`@("`@("`@)&-O;'5M;BLK.PH*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V5X=')A)UU;2$]2
M1$5?5%)%15]%6%1205]224=(5%TI*2!["B`@("`@("`@("`@("1E>'1R82`]
M("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'1R82==6TA/4D1%7U12145?
M15A44D%?4DE'2%1=.PH@("`@("`@("`@("`D8TUA>"`](&-O=6YT*"1E>'1R
M82D["B`@("`@("`@("`@(&9O<B`H)&,@/2`P.R`D8R`\("1C36%X.R`D8RLK
M*2!["B`@("`@("`@("`@("`@("`D<W1Y;&4@/2`G)SL*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@
M+B`D=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G72`N("<[)SL*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D;&EN92`N/2`G/&1I
M=B!C;&%S<STB;&5F=$9L;V%T(B<["B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1S='EL92DI('L*("`@("`@("`@("`@("`@("`@("`D;&EN92`N/2`G
M('-T>6QE/2(G("X@)'-T>6QE("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&QI;F4@+CT@)SXG("X@)&5X=')A6R1C72`N("<\
M+V1I=CXG.PH*("`@("`@("`@("`@("`@("1C;VQU;6XK*SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L:6YE("X@(CPO9&EV
M/EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&QA8F5L(&]N
M('1H92!T<F5E(&QI;F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F]D95]I9"`@5&AE($YO
M9&4@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L86)E
M;"!F;W(@=&AE('1R964@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=$QA8F5L*"1N;V1E7VED*0H@("`@>PH@("`@("`@("1N(#T@)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%T["@H@("`@("`@("1O=71P=70@/2`G/'-P86XG.PH@
M("`@("`@(&EF("@A96UP='DH)&Y;)V]N8VQI8VLG72DI('L*("`@("`@("`@
M("`@)&]U='!U="`N/2`G(&]N8VQI8VL](B<@+B`D;ELG;VYC;&EC:R==("X@
M)R(G.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T("X]("<^)SL*"B`@("`@
M("`@)&QA8F5L(#T@)&Y;)VQA8F5L)UT["B`@("`@("`@:68@*"%E;7!T>2@D
M;ELG=7)L)UTI*2!["B`@("`@("`@("`@("1T87)G970@/2`G)SL*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D;ELG=&%R9V5T)UTI*2!["B`@("`@("`@("`@
M("`@("`D=&%R9V5T(#T@)R!T87)G970](B<@+B`D;ELG=&%R9V5T)UT@+B`G
M(B<["B`@("`@("`@("`@('T@96QS96EF("@D=&%R9V5T(#T@)'1H:7,M/F=E
M=$]P=&EO;B@G=&%R9V5T)RDI('L*("`@("`@("`@("`@("`@("1T87)G970@
M/2`G('1A<F=E=#TB)R`N("1T87)G970@+B`G(B<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&]U='!U="`N/2`G/&$G("X@*"%E;7!T>2@D;ELG=7)L
M8VQA<W,G72D@/R`G(&-L87-S/2(G("X@)&Y;)W5R;&-L87-S)UT@+B`G(B<@
M.B`G)RD@+B`G(&AR968](B<@+B`D;ELG=7)L)UT@+B`G(B<@+B`D=&%R9V5T
M("X@)SXG("X@)&QA8F5L("X@)SPO83XG.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1O=71P=70@+CT@)&QA8F5L.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O=71P=70@+B`G/"]S<&%N/B<["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!N;V1E('1O9V=L92!O;B!T:&4@=')E92!L:6YE
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YO9&5?:60@(%1H92!.;V1E($E$+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;F]D92!T;V=G;&4@9F]R('1H
M92!T<F5E(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971.;V1E5&]G
M9VQE*"1N;V1E7VED*0H@("`@>PH@("`@("`@("1L:6YK7W-T87)T(#T@)R<[
M"@H@("`@("`@(&EF("@H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N
M="==(#T](#`I("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`O*B!4;W`@
M;&5V96P@;F]D92!W:71H(&-H:6QD<F5N+B`J+PH@("`@("`@("`@("`D=&AI
M<RT^7V1R;W!L:6YE6S!=(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7W-T871I8RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@
M9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M
M/E]I;6=?8FQA;FL["B`@("`@("`@("`@("`@("`D86QT(#T@)R9N8G-P.R9N
M8G-P.R9N8G-P.R<["B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7VYO
M9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@("`@("`@("`@("`@("`@
M)&EM9R`]("1T:&ES+3Y?:6UG7VUI;G5S7V]N;'D["B`@("`@("`@("`@("`@
M("`D86QT(#T@)RTG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7W!L=7-?;VYL>3L*("`@("`@("`@
M("`@("`@("1A;'0@/2`G*R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^7W-T871I8RD@>PH@("`@("`@("`@("`@("`@)'5R;"`]
M(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ<V5L9E5R;"@I+"!(3U)$15]4
M4D5%7U1/1T=,12`N("1T:&ES+3Y?:6YS=&%N8V4L("1N;V1E7VED*3L*("`@
M("`@("`@("`@("`@("1L:6YK7W-T87)T(#T@2&]R9&4Z.FQI;FLH)'5R;"D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H*"1T:&ES+3Y?;F]D
M97-;)&YO9&5?:61=6R=I;F1E;G0G72`A/2`P*2`F)@H@("`@("`@("`@("`A
M:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI*2![
M"B`@("`@("`@("`@("\J($YO9&4@=VET:&]U="!C:&EL9')E;BX@*B\*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?;F]D95]P;W-;)&YO9&5?:61=6R=P;W,G
M72`\("1T:&ES+3Y?;F]D95]P;W-;)&YO9&5?:61=6R=C;W5N="==*2!["B`@
M("`@("`@("`@("`@("`O*B!.;W0@;&%S="!N;V1E+B`J+PH@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@9F%L<V4L('1R
M=64I*2!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG
M7VIO:6X["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("=\+2<["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@
M/2`D=&AI<RT^7VEM9U]B;&%N:SL*("`@("`@("`@("`@("`@("`@("`D86QT
M(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1R;W!L:6YE6R1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=I;F1E;G0G75T@/2!T<G5E.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+RH@3&%S="!N;V1E+B`J+PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@9F%L<V4L
M('1R=64I*2!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?
M:6UG7VIO:6Y?8F]T=&]M.PH@("`@("`@("`@("`@("`@("`@("1A;'0@/2`G
M8"TG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?8FQA;FL["B`@("`@("`@("`@("`@
M("`@("`@)&%L="`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D<F]P;&EN95LD=&AI
M<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UU=(#T@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]N;V1E
M<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@("\J($YO
M9&4@=VET:"!C:&EL9')E;BX@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M;F]D95]P;W-;)&YO9&5?:61=6R=P;W,G72`\("1T:&ES+3Y?;F]D95]P;W-;
M)&YO9&5?:61=6R=C;W5N="==*2!["B`@("`@("`@("`@("`@("`O*B!.;W0@
M;&%S="!N;V1E+B`J+PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^9V5T
M3W!T:6]N*"=L:6YE<R<L(&9A;'-E+"!T<G5E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]B;&%N:SL*("`@("`@("`@("`@
M("`@("`@("`D86QT(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]S=&%T:6,I('L*("`@("`@("`@
M("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?:F]I;CL*("`@("`@("`@
M("`@("`@("`@("`D86QT(#T@)WPM)SL*("`@("`@("`@("`@("`@('T@96QS
M96EF("@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@
M("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]M:6YU<SL*
M("`@("`@("`@("`@("`@("`@("`D86QT(#T@)RTG.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M
M/E]I;6=?<&QU<SL*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)RLG.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D<F]P
M;&EN95LD=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UU=(#T@=')U
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($QA
M<W0@;F]D92X@*B\*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/F=E=$]P
M=&EO;B@G;&EN97,G+"!F86QS92P@=')U92DI('L*("`@("`@("`@("`@("`@
M("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?8FQA;FL["B`@("`@("`@("`@("`@
M("`@("`@)&%L="`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?<W1A=&EC*2!["B`@("`@("`@("`@
M("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VIO:6Y?8F]T=&]M.PH@("`@
M("`@("`@("`@("`@("`@("1A;'0@/2`G8"TG.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'!A;F1E9"==
M*2!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VUI
M;G5S7V)O='1O;3L*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)RTG.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M:6UG(#T@)'1H:7,M/E]I;6=?<&QU<U]B;W1T;VT["B`@("`@("`@("`@("`@
M("`@("`@)&%L="`]("<K)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9')O<&QI;F5;)'1H:7,M/E]N;V1E<ULD;F]D95]I
M9%U;)VEN9&5N="==72`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/E]S=&%T:6,I('L*("`@("`@("`@("`@("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G-E;&95<FPH*2P@2$]2
M1$5?5%)%15]43T='3$4@+B`D=&AI<RT^7VEN<W1A;F-E+"`D;F]D95]I9"D[
M"B`@("`@("`@("`@("`@("`D;&EN:U]S=&%R="`]($AO<F1E.CIL:6YK*"1U
M<FPI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@5&]P(&QE=F5L(&YO9&4@=VET:"!N;R!C:&EL9')E;BX@*B\*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&EC*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T
M:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@
M("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?;G5L;%]O;FQY.PH@("`@
M("`@("`@("`@("`@)&%L="`]("<F;F)S<#LF;F)S<#LG.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG
M7V)L86YK.PH@("`@("`@("`@("`@("`@)&%L="`]("<F;F)S<#LF;F)S<#LF
M;F)S<#LG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9')O
M<&QI;F5;,%T@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@("1L:6YK7V5N
M9"`]("@D;&EN:U]S=&%R="D@/R`G/"]A/B<@.B`G)SL*"B`@("`@("`@)&EM
M9R`]("1L:6YK7W-T87)T("X@)SQI;6<@<W)C/2(G("X@)'1H:7,M/E]I;6=?
M9&ER("X@)R\G("X@)&EM9R`N("<B)PH@("`@("`@("`@("`N("AI<W-E="@D
M86QT*2`_("<@86QT/2(G("X@)&%L="`N("<B)R`Z("<G*0H@("`@("`@("`@
M("`N("<@:&5I9VAT/2(R,"(@=VED=&@](C(P(B!S='EL93TB=F5R=&EC86PM
M86QI9VXZ;6ED9&QE(B!B;W)D97(](C`B("\^)PH@("`@("`@("`@("`N("1L
M:6YK7V5N9#L*"B`@("`@("`@<F5T=7)N("1I;6<["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!I8V]N(&9O<B!T:&4@;F]D92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N;V1E7VED("!4:&4@3F]D92!)1"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&YO9&4@:6-O;B!F;W(@=&AE('1R964@;&EN92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$YO9&5)8V]N*"1N;V1E7VED*0H@
M("`@>PH@("`@("`@("1I;6=?9&ER(#T@:7-S970H)'1H:7,M/E]N;V1E<ULD
M;F]D95]I9%U;)VEC;VYD:7(G72D@/R`D=&AI<RT^7VYO9&5S6R1N;V1E7VED
M75LG:6-O;F1I<B==(#H@)'1H:7,M/E]I;6=?9&ER.PH@("`@("`@(&EF("@D
M:6UG7V1I<BD@>PH@("`@("`@("`@("`D:6UG7V1I<B`N/2`G+R<["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I
M9%U;)VEC;VXG72DI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M;F]D97-;)&YO9&5?:61=6R=I8V]N)UTI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@+RH@3F]D92!H
M87,@82!U<V5R(&1E9FEN960@:6-O;BX@*B\*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I8V]N;W!E;B==*2`F)@H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V5X<&%N
M9&5D)UTI('L*("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VYO9&5S
M6R1N;V1E7VED75LG:6-O;F]P96XG73L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED
M75LG:6-O;B==.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+RH@57-E('-T86YD87)D(&EC;VX@<V5T+B`J+PH@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD
M<F5N)UTI*2!["B`@("`@("`@("`@("`@("`O*B!.;V1E('=I=&@@8VAI;&1R
M96XN("HO"B`@("`@("`@("`@("`@("`D:6UG(#T@*"1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=E>'!A;F1E9"==*2`_("1T:&ES+3Y?:6UG7V9O;&1E<E]O
M<&5N(#H@)'1H:7,M/E]I;6=?9F]L9&5R.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+RH@3&5A9B!N;V1E("AN;R!C:&EL9')E;BDN
M("HO"B`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?;&5A9CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&EM9W1X="`]("<\
M:6UG('-R8STB)R`N("1I;6=?9&ER("X@)&EM9R`N("<B)SL*"B`@("`@("`@
M+RH@1&]E<R!T:&4@;F]D92!H879E('5S97(@9&5F:6YE9"!A;'0@=&5X=#\@
M*B\*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;
M)VEC;VYA;'0G72DI('L*("`@("`@("`@("`@)&EM9W1X="`N/2`G(&%L=#TB
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;
M)VEC;VYA;'0G72D@+B`G(B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EM9W1X="`N("<@+SXG.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5')E92]S
M96QE8W0N<&AP````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V
M-C`Q`#$P-3$U-#,Q,#8Q`#`R,3$P-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U1R
M965?<V5L96-T.CH@8VQA<W,@97AT96YD<R!T:&4@2&]R9&5?5')E92!C;&%S
M<R!T;R!P<F]V:61E"B`J(#QO<'1I;VX^('1A9R!R96YD97)I;F<N"B`J"B`J
M($-O<'ER:6=H="`R,#`U+3(P,#8@0F5N($-H879E="`\8F5N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1R964O
M5')E92]S96QE8W0N<&AP+'8@,2XR+C(N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C0P
M(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!"96X@0VAA=F5T(#QB96Y`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]4<F5E"B`J($!S:6YC92`@($AO
M<F1E(#,N,0H@*B\*8VQA<W,@2&]R9&5?5')E95]S96QE8W0@97AT96YD<R!(
M;W)D95]4<F5E('L*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VYO9&5S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!(;W)D95]4<F5E7W-E;&5C="@D=')E95]N86UE+"`D<&%R86US
M*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?5')E92@D=')E95]N86UE
M+"`D<&%R86US*3L*("`@("`@("`D=&AI<RT^7W-T871I8R`]('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T<F5E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!C;V1E(&]F('1H92!R
M96YD97)E9"!T<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714<F5E*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V)U:6QD26YD96YT<R@D=&AI<RT^7W)O
M;W1?;F]D97,I.PH*("`@("`@("`D=')E92`]("<G.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?<F]O=%]N;V1E<R!A<R`D;F]D95]I9"D@>PH@("`@("`@
M("`@("`D=')E92`N/2`D=&AI<RT^7V)U:6QD5')E92@D;F]D95]I9"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=')E93L*("`@('T*"B`@("`O*BH*
M("`@("`J($-H96-K<R!T:&4@8W5R<F5N="!E;G9I<F]N;65N="!T;R!S964@
M:68@=V4@8V%N(')E;F1E<B!T:&4@2%1-3"!T<F5E+@H@("`@("H@2%1-3"!I
M<R!A;'=A>7,@<F5N9&5R86)L92P@870@;&5A<W0@=6YT:6P@=V4@861D(&$@
M<&AP+6=T:R!T<F5E"B`@("`@*B!B86-K96YD+"!I;B!W:&EC:"!C87-E('1H
M:7,@:6UP;&5M96YT871I;VX@=VEL;"!A8W1U86QL>2!N965D(&$@8F]D>2X*
M("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&ES(%1R964Z.B!B86-K96YD('=I
M;&P@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4W5P<&]R=&5D
M*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@:G5S="!T:&4@2E,@;F]D92!D969I;FET:6]N<R!A
M<R!A('-T<FEN9RX@5&AI<R!I<R!A(&YO+6]P(&9O<@H@("`@("H@=&AE('-E
M;&5C="!R96YD97)E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R3F]D
M941E9FEN:71I;VYS*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@861D:71I;VYA;"!P87)A;65T97)S('1O(&$@;F]D92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@5&AE('5N:7%U92!N;V1E(&ED
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!O=&AE<B!P87)A
M;65T97)S('1O('-E="X*("`@("`J(#QP<F4^"B`@("`@*B!S96QE8W1E9"`M
M+2`@5VAE=&AE<B!T:&ES(&YO9&4@:7,@<V5L96-T960*("`@("`J(#PO<')E
M/@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1.;V1E4&%R86US*"1I9"P@)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D
M<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@87)R87DH)'!A<F%M
M<RD["B`@("`@("`@?0H*("`@("`@("`D86QL;W=E9"`](&%R<F%Y*"=S96QE
M8W1E9"<I.PH*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;5]I
M9"`]/B`D<&%R86U?=F%L*2!["B`@("`@("`@("`@("\J(%-E="!O;FQY(&%L
M;&]W960@86YD(&YO;BUN=6QL('!A<F%M<RX@*B\*("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*"1P87)A;5]I9"P@)&%L;&]W960I("8F("%I<U]N=6QL*"1P
M87)A;5]V86PI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1I
M9%U;)'!A<F%M7VED72`]("1P87)A;5]V86P["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-I=F4@9G5N8W1I
M;VX@=&\@=V%L:R!T:')O=6=H('1H92!T<F5E(&%R<F%Y(&%N9"!B=6EL9"!T
M:&4@;W5T<'5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YO9&5?:60@(%1H92!.;V1E($E$
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=')E92!R96YD
M97)I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9%1R964H)&YO9&5?
M:60I"B`@("!["B`@("`@("`@)'-E;&5C=&5D(#T@)'1H:7,M/E]N;V1E<ULD
M;F]D95]I9%U;)W-E;&5C=&5D)UT@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G
M(#H@)R<["@H@("`@("`@("1O=71P=70@/2`G/&]P=&EO;B!V86QU93TB)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)&YO9&5?:60I("X@)R(G("X@)'-E;&5C=&5D
M("X@)SXG("X*("`@("`@("`@("`@<W1R7W)E<&5A="@G)FYB<W`[)FYB<W`[
M)RP@*&EN="DD=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UTI("X@
M:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG;&%B
M96PG72D@+@H@("`@("`@("`@("`G/"]O<'1I;VX^)SL*"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*2`F
M)@H@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD
M960G72D@>PH@("`@("`@("`@("`D;G5M7W-U8FYO9&5S(#T@8V]U;G0H)'1H
M:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI.PH@("`@("`@("`@
M("!F;W(@*"1C(#T@,#L@)&,@/"`D;G5M7W-U8FYO9&5S.R`D8RLK*2!["B`@
M("`@("`@("`@("`@("`D8VAI;&1?;F]D95]I9"`]("1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=C:&EL9')E;B==6R1C73L*("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@)'1H:7,M/E]B=6EL9%1R964H)&-H:6QD7VYO9&5?:60I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U
M=#L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O
M:F%V87-C<FEP="YP:'``````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,S$T-P`Q,#4Q-30S,3`V,0`P,C(P,#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]4
M<F5E7VIA=F%S8W)I<'0Z.B!C;&%S<R!E>'1E;F1S('1H92!(;W)D95]4<F5E
M(&-L87-S('1O('!R;W9I9&4*("H@:F%V87-C<FEP="!S<&5C:69I8R!R96YD
M97)I;F<@9G5N8W1I;VYS+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]4<F5E+U1R964O:F%V87-C<FEP="YP:'`L
M=B`Q+C,T+C(N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C0P(&IA;B!%>'`@)`H@*@H@
M*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`
M<&%C:V%G92!(;W)D95]4<F5E"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*
M8VQA<W,@2&]R9&5?5')E95]J879A<V-R:7!T(&5X=&5N9',@2&]R9&5?5')E
M92!["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@<V]U<F-E(&9O
M<B!T:&4@=')E92!D871A+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W-O=7)C95]N86UE(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J(%1H92!N86UE(&]F('1H92!T87)G970@96QE;65N="!T;R!O=71P
M=70@=&AE(&IA=F%S8W)I<'0@=')E92X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]O<'1I;VYS7VYA;64@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('1A<F=E="!E;&5M96YT
M('1O(&]U='!U="!T:&4@:F%V87-C<FEP="!T<F5E+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=%]N86UE(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7U1R965?:F%V87-C<FEP="@D=')E95]N86UE+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!P87)E;G0Z.DAO<F1E
M7U1R964H)'1R965?;F%M92P@)'!A<F%M<RD["@H@("`@("`@(&EF("@A:7-S
M970H)$=,3T)!3%-;)V)R;W=S97(G72DI('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]"<F]W<V5R+G!H<"<["B`@("`@("`@("`@("1'3$]"
M04Q36R=B<F]W<V5R)UT@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@82!J879A<V-R:7!T('-E<W-I
M;VX@<W1A=&4N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?=7-E<V5S<VEO;B`F
M)@H@("`@("`@("`@("!I<W-E="@D7T-/3TM)15LD=&AI<RT^7VEN<W1A;F-E
M("X@)U]E>'!A;F1E9"==*2D@>PH@("`@("`@("`@("`O*B!296UO=F4@(F5X
M<"(@<')E9FEX(&9R;VT@8V]O:VEE('9A;'5E+B`J+PH@("`@("`@("`@("`D
M;F]D97,@/2!E>'!L;V1E*"<L)RP@<W5B<W1R*"1?0T]/2TE%6R1T:&ES+3Y?
M:6YS=&%N8V4@+B`G7V5X<&%N9&5D)UTL(#,I*3L*"B`@("`@("`@("`@("\J
M($UA:V4@<W5R92!T:&5R92!A<F4@;F\@<')E=FEO=7,@;F]D97,@<W1O<F5D
M(&EN('1H90H@("`@("`@("`@("`@*B!S97-S:6]N+B`J+PH@("`@("`@("`@
M("`D7U-%4U-)3TY;)VAO<F1E7W1R964G75LD=&AI<RT^7VEN<W1A;F-E75LG
M97AP86YD960G72`](&%R<F%Y*"D["@H@("`@("`@("`@("`O*B!3879E(&YO
M9&5S('1O('1H92!S97-S:6]N+B`J+PH@("`@("`@("`@("!F;W)E86-H("@D
M;F]D97,@87,@)&ED*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VAO
M<F1E7W1R964G75LD=&AI<RT^7VEN<W1A;F-E75LG97AP86YD960G75LD:61=
M(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'-T871I8R`@268@=')U92!T:&4@=')E92!N;V1E<R!C
M86XG="!B92!E>'!A;F1E9"!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;&QA<'-E9"!A;F0@=&AE('1R964@9V5T<R!R96YD97)E9"!E
M>'!A;F1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A4
M34P@8V]D92!O9B!T:&4@<F5N9&5R960@=')E92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5')E92@D<W1A=&EC(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S=&%T:6,@/2`D<W1A=&EC.PH@("`@("`@("1T:&ES+3Y?<V]U
M<F-E7VYA;64@/2`G;E\G("X@)'1H:7,M/E]I;G-T86YC93L*("`@("`@("`D
M=&AI<RT^7VAE861E<E]N86UE(#T@)VA?)R`N("1T:&ES+3Y?:6YS=&%N8V4[
M"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS7VYA;64@/2`G;U\G("X@)'1H:7,M
M/E]I;G-T86YC93L*("`@("`@("`D=&AI<RT^7W1A<F=E=%]N86UE(#T@)W1?
M)R`N("1T:&ES+3Y?:6YS=&%N8V4["B`@("`@("`@)'1H:7,M/E]B=6EL9$EN
M9&5N=',H)'1H:7,M/E]R;V]T7VYO9&5S*3L*"B`@("`@("`@)'1R964@/2`D
M=&AI<RT^7V=E=%1R9653;W5R8V4H*2`N"B`@("`@("`@("`@("`G/&1I=B!I
M9#TB)R`N("1T:&ES+3Y?=&%R9V5T7VYA;64@+B`G(CX\+V1I=CXG("X*("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T5')E94EN:70H*3L*"B`@("`@("`@2&]R
M9&4Z.F%D9%-C<FEP=$9I;&4H)W1R964N:G,G+"`G:&]R9&4G*3L*("`@("`@
M("!R971U<FX@)'1R964["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T
M:&4@8W5R<F5N="!E;G9I<F]N;65N="!T;R!S964@:68@=V4@8V%N(')E;F1E
M<B!T:&4@2%1-3`H@("`@("H@=')E92X@5V4@8VAE8VL@9F]R($1/32!S=7!P
M;W)T(&EN('1H92!B<F]W<V5R+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H
M:7,@5')E93HZ(&)A8VME;F0@=VEL;"!F=6YC=&EO;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-3=7!P;W)T960H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=D;VTG*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@:G5S="!T:&4@2E,@;F]D92!D969I
M;FET:6]N<R!A<R!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE($IA=F%S8W)I<'0@;F]D92!A<G)A>2!D969I;FET:6]N<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R3F]D941E9FEN:71I;VYS*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V)U:6QD26YD96YT<R@D=&AI<RT^7W)O
M;W1?;F]D97,I.PH*("`@("`@("`D;F]D94IS(#T@)R<["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]N;V1E<R!A<R`D;F]D95]I9"`]/B`D;F]D92D@>PH@
M("`@("`@("`@("`D;F]D94IS("X]("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE
M;G0H<W!R:6YT9B@G)7-;7"<E<UPG72<L("=N7R<@+B`D=&AI<RT^7VEN<W1A
M;F-E+"`D;F]D95]I9"DL("1N;V1E*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;F]D94IS("X@)'1H:7,M/E]I;G-T86YC92`N("<N<F5N9&5R5')E
M92AR;V]T7VYO9&5S*3LG.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T
M<R!T:&4@9&%T82!F;W(@=&AE('1R964@87,@82!J879A<V-R:7!T(&%R<F%Y
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T5')E95-O=7)C92@I"B`@("!["B`@("`@("`@9VQO8F%L
M("1B<F]W<V5R.PH*("`@("`@("`D:G,@(#T@)SQS8W)I<'0@='EP93TB=&5X
M="]J879A<V-R:7!T(CXG("X@(EQN(CL*("`@("`@("`D:G,@+CT@)W9A<B!E
M>'1R84-O;'-,969T(#T@)R`N("1T:&ES+3Y?97AT<F%?8V]L<U]L969T("X@
M(CM<;B(["B`@("`@("`@)&IS("X]("=V87(@97AT<F%#;VQS4FEG:'0@/2`G
M("X@)'1H:7,M/E]E>'1R85]C;VQS7W)I9VAT("X@(CM<;B(["B`@("`@("`@
M)&IS("X]("=V87(@)R`N("1T:&ES+3Y?<V]U<F-E7VYA;64@+B`G(#T@;F5W
M($%R<F%Y*"D[)R`N(")<;B(["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M;F]D97,@87,@)&YO9&5?:60@/3X@)&YO9&4I('L*("`@("`@("`@("`@)&IS
M("X]("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE;G0H<W!R:6YT9B@G)7-;7"<E
M<UPG72<L("1T:&ES+3Y?<V]U<F-E7VYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)R;W=S97(M
M/F5S8V%P94I30V]D92AA9&1S;&%S:&5S*"1N;V1E7VED*2DI+"`D;F]D92D[
M"B`@("`@("`@?0H@("`@("`@("1J<R`N/2`D=&AI<RT^7V=E=$IS07)R87E%
M;&5M96YT*"1T:&ES+3Y?:&5A9&5R7VYA;64L("1T:&ES+3Y?:&5A9&5R*3L*
M("`@("`@("`D:G,@+CT@)'1H:7,M/E]G971*<T%R<F%Y16QE;65N="@D=&AI
M<RT^7V]P=&EO;G-?;F%M92P@)'1H:7,M/E]O<'1I;VYS*3L*("`@("`@("`D
M:G,@+CT@)SPO<V-R:7!T/B<@+B`B7&XB.PH*("`@("`@("!R971U<FX@)&IS
M.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!T:&4@:F%V87-C<FEP
M="!T;R!I;FET:6%L:7-E('1H92!T<F5E+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5')E94EN:70H
M*0H@("`@>PH@("`@("`@("1J<R`@/2`G/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/B<@+B`B7&XB.PH@("`@("`@("1J<R`N/2!S<')I;G1F*"<E
M,21S(#T@;F5W($AO<F1E7U1R964H7"<E,21S7"<I.R<@+B`B7&XB+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YS=&%N8V4I.PH*("`@("`@
M("`D:G,@+CT@)'1H:7,M/E]G971*<T%R<F%Y16QE;65N="@G<F]O=%]N;V1E
M<R<L("1T:&ES+3Y?<F]O=%]N;V1E<RD["@H@("`@("`@("1J<R`N/2!S<')I
M;G1F*"(E<RYR96YD97)4<F5E*')O;W1?;F]D97,L("5S*3M<;CPO<V-R:7!T
M/EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN<W1A;F-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A=&EC(#\@)W1R
M=64G(#H@)V9A;'-E)RD["@H@("`@("`@(')E='5R;B`D:G,["B`@("!]"@H@
M("`@9G5N8W1I;VX@7V=E=$IS07)R87E%;&5M96YT*"1V87(L("1V86QU92D*
M("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@
M("`@("`D:G,@/2`D=F%R("X@)R`](&YE=R!!<G)A>2@I.R<@+B`B7&XB.PH@
M("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D:V5Y*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1N97=687(@/2`D=F%R("X@)ULG("X@)&ME>2`N
M("==)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)&YE=U9A<B`]("1V87(@+B`G6UPG)R`N("1K97D@+B`G7"==)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1J<R`N/2`D=&AI
M<RT^7V=E=$IS07)R87E%;&5M96YT*"1N97=687(L("1V86PI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D:G,["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1V87(@+B`B(#T@)R(@+B!A9&1S;&%S
M:&5S*"1V86QU92D@+B`B)SM<;B(["B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y<'0O````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#8Q`#`Q-S,R,``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]#<GEP="]S;6EM92YP:'``````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`Q-#0U,C$`,3`U,34T,S$P-C$`,#(Q,30W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TAO<F1E+T-R>7!T+G!H<"<["@HO*BH*("H@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!P<F]V:61E<R!A(&9R86UE=V]R:R!F;W(@2&]R9&4@87!P
M;&EC871I;VYS('1O"B`J(&EN=&5R86-T('=I=&@@=&AE($]P96Y34TP@;&EB
M<F%R>2!A;F0@:6UP;&5M96YT(%,O34E-12X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP+'8@,2XT.2XR+C$R(#(P,#8O
M,#(O,#,@,34Z-3(Z-34@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?0W)Y<'0*("HO"F-L87-S($AO<F1E7T-R
M>7!T7W-M:6UE(&5X=&5N9',@2&]R9&5?0W)Y<'0@>PH*("`@("\J*@H@("`@
M("H@3V)J96-T($ED96YT:69E<G,@=&\@;F%M92!A<G)A>2X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]I9',@/2!A<G)A
M>2@*("`@("`@("`G,BXU+C0N,R<@/3X@)T-O;6UO;DYA;64G+`H@("`@("`@
M("<R+C4N-"XT)R`]/B`G4W5R;F%M92<L"B`@("`@("`@)S(N-2XT+C8G(#T^
M("=#;W5N=')Y)RP*("`@("`@("`G,BXU+C0N-R<@/3X@)TQO8V%T:6]N)RP*
M("`@("`@("`G,BXU+C0N."<@/3X@)U-T871E3W)0<F]V:6YC92<L"B`@("`@
M("`@)S(N-2XT+CDG(#T^("=3=')E971!9&1R97-S)RP*("`@("`@("`G,BXU
M+C0N,3`G(#T^("=/<F=A;FES871I;VXG+`H@("`@("`@("<R+C4N-"XQ,2<@
M/3X@)T]R9V%N:7-A=&EO;F%L56YI="<L"B`@("`@("`@)S(N-2XT+C$R)R`]
M/B`G5&ET;&4G+`H@("`@("`@("<R+C4N-"XR,"<@/3X@)U1E;&5P:&]N94YU
M;6)E<B<L"B`@("`@("`@)S(N-2XT+C0R)R`]/B`G1VEV96Y.86UE)RP*"B`@
M("`@("`@)S(N-2XR.2XQ-"<@/3X@)VED+6-E+7-U8FIE8W1+97E)9&5N=&EF
M:65R)RP*"B`@("`@("`@)S(N-2XR.2XQ-"<@/3X@)VED+6-E+7-U8FIE8W1+
M97E)9&5N=&EF:65R)RP*("`@("`@("`G,BXU+C(Y+C$U)R`]/B`G:60M8V4M
M:V5Y57-A9V4G+`H@("`@("`@("<R+C4N,CDN,3<G(#T^("=I9"UC92US=6)J
M96-T06QT3F%M92<L"B`@("`@("`@)S(N-2XR.2XQ.2<@/3X@)VED+6-E+6)A
M<VEC0V]N<W1R86EN=',G+`H@("`@("`@("<R+C4N,CDN,S$G(#T^("=I9"UC
M92U#4DQ$:7-T<FEB=71I;VY0;VEN=',G+`H@("`@("`@("<R+C4N,CDN,S(G
M(#T^("=I9"UC92UC97)T:69I8V%T95!O;&EC:65S)RP*("`@("`@("`G,BXU
M+C(Y+C,U)R`]/B`G:60M8V4M875T:&]R:71Y2V5Y261E;G1I9FEE<B<L"B`@
M("`@("`@)S(N-2XR.2XS-R<@/3X@)VED+6-E+65X=$ME>55S86=E)RP*"B`@
M("`@("`@)S$N,BXX-#`N,3$S-30Y+C$N.2XQ)R`]/B`G16UA:6PG+`H@("`@
M("`@("<Q+C(N.#0P+C$Q,S4T.2XQ+C$N,2<@/3X@)U)3045N8W)Y<'1I;VXG
M+`H@("`@("`@("<Q+C(N.#0P+C$Q,S4T.2XQ+C$N,B<@/3X@)VUD,E=I=&A2
M4T%%;F-R>7!T:6]N)RP*("`@("`@("`G,2XR+C@T,"XQ,3,U-#DN,2XQ+C0G
M(#T^("=M9#5W:71H4E-!16YC<GEP=&EO;B<L"B`@("`@("`@)S$N,BXX-#`N
M,3$S-30Y+C$N,2XU)R`]/B`G4TA!+3%7:71H4E-!16YC<GEP=&EO;B<L"B`@
M("`@("`@)S$N,BXX-#`N,3`P-#`N-"XS)R`]/B`G:60M9'-A+7=I=&@M<VAA
M+3$G+`H*("`@("`@("`G,2XS+C8N,2XU+C4N-RXS+C(G(#T^("=I9%]K<%]C
M;&EE;G1!=71H)RP*"B`@("`@("`@)S(N,38N.#0P+C$N,3$S-S,P+C$N,2<@
M/3X@)VYE='-C87!E+6-E<G0M='EP92<L"B`@("`@("`@)S(N,38N.#0P+C$N
M,3$S-S,P+C$N,B<@/3X@)VYE='-C87!E+6)A<V4M=7)L)RP*("`@("`@("`G
M,BXQ-BXX-#`N,2XQ,3,W,S`N,2XS)R`]/B`G;F5T<V-A<&4M<F5V;V-A=&EO
M;BUU<FPG+`H@("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ+C0G(#T^("=N
M971S8V%P92UC82UR979O8V%T:6]N+75R;"<L"B`@("`@("`@)S(N,38N.#0P
M+C$N,3$S-S,P+C$N-R<@/3X@)VYE='-C87!E+6-E<G0M<F5N97=A;"UU<FPG
M+`H@("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ+C@G(#T^("=N971S8V%P
M92UC82UP;VQI8WDM=7)L)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N
M,2XQ,B<@/3X@)VYE='-C87!E+7-S;"US97)V97(M;F%M92<L"B`@("`@("`@
M)S(N,38N.#0P+C$N,3$S-S,P+C$N,3,G(#T^("=N971S8V%P92UC;VUM96YT
M)RP*("`@("D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R(&%R<F%Y
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=T96UP)R`]/B!,;V-A
M=&EO;B!O9B!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!(;W)D95]#<GEP=%]S;6EM92@D<&%R86US*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?=&5M<&1I<B`]("1P87)A;7-;)W1E;7`G73L*("`@('T*"B`@
M("`O*BH*("`@("`J(%9E<FEF>2!A('!A<W-P:')A<V4@9F]R(&$@9VEV96X@
M<')I=F%T92!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I
M=F%T95]K97D@(%1H92!U<V5R)W,@<')I=F%T92!K97DN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P87-S<&AR87-E("`@5&AE('5S97(G<R!P87-S<&AR87-E
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E
M(&]N('9A;&ED('!A<W-P:')A<V4L(&9A;'-E(&]N(&EN=F%L:60*("`@("`J
M("`@("`@("`@("`@("`@("`@<&%S<W!H<F%S92X*("`@("`J("`@("`@("`@
M("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!V97)I9GE087-S<&AR87-E*"1P<FEV871E7VME>2P@
M)'!A<W-P:')A<V4I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'!A<W-P
M:')A<V4I*2!["B`@("`@("`@("`@("1R97,@/2!O<&5N<W-L7W!K97E?9V5T
M7W!R:79A=&4H)'!R:79A=&5?:V5Y*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<F5S(#T@;W!E;G-S;%]P:V5Y7V=E=%]P<FEV871E*"1P<FEV
M871E7VME>2P@)'!A<W-P:')A<V4I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&ES7W)E<V]U<F-E*"1R97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M16YC<GEP="!T97AT('5S:6YG(%,O34E-12X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@96YC<GEP=&5D+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE
M961E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!3964@=&AE(&EN9&EV:61U86P@7V5N8W)Y<'0J*"D@9G5N8W1I;VYS
M(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!P87)A;65T
M97(@<F5Q=6ER96UE;G1S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@96YC<GEP=&5D(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@
M("`@4F5T=7)N<R!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@96YC<GEP="@D=&5X="P@)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R(&%V86EL86)I;&ET>2!O
M9B!/<&5N4U-,(%!(4"!E>'1E;G-I;VXN("HO"B`@("`@("`@)&]P96YS<VP@
M/2`D=&AI<RT^8VAE8VM&;W)/<&5N4U-,*"D["B`@("`@("`@:68@*&ES7V$H
M)&]P96YS<VPL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1O<&5N<W-L.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1P87)A
M;7-;)W1Y<&4G72DI('L*("`@("`@("`@("`@:68@*"1P87)A;7-;)W1Y<&4G
M72`]/3T@)VUE<W-A9V4G*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]E;F-R>7!T365S<V%G92@D=&5X="P@)'!A<F%M<RD["B`@("`@("`@
M("`@('T@96QS96EF("@D<&%R86US6R=T>7!E)UT@/3T]("=S:6=N871U<F4G
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]E;F-R>7!T4VEG
M;F%T=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'0@=&5X="!V:6$@4R]-
M24U%+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@
M=&5X="!T;R!B92!S;6EM92!D96-R>7!T960N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!D96-R>7!T
M:6]N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%-E92!T:&4@:6YD
M:79I9'5A;"!?9&5C<GEP="HH*2!F=6YC=&EO;G,@9F]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@=&AE('!A<F%M971E<B!R97%U:7)E;65N=',N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@
M;65S<V%G92X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?
M17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M96-R>7!T*"1T97AT+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`O*B!#:&5C:R!F;W(@879A:6QA8FEL:71Y(&]F($]P96Y34TP@4$A0(&5X
M=&5N<VEO;BX@*B\*("`@("`@("`D;W!E;G-S;"`]("1T:&ES+3YC:&5C:T9O
M<D]P96Y34TPH*3L*("`@("`@("!I9B`H:7-?82@D;W!E;G-S;"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]P96YS<VP["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG='EP92==*2D@>PH@
M("`@("`@("`@("!I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G;65S<V%G92<I
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E8W)Y<'1-97-S
M86=E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?2!E;'-E:68@*"@D
M<&%R86US6R=T>7!E)UT@/3T]("=S:6=N871U<F4G*2!\?`H@("`@("`@("`@
M("`@("`@("`@("`@*"1P87)A;7-;)W1Y<&4G72`]/3T@)V1E=&%C:&5D+7-I
M9VYA='5R92<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D
M96-R>7!T4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%9E<FEF>2!A('-I
M9VYA='5R92!U<VEN9R!V:6$@4R]-24U%+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@(%1H92!M=6QT:7!A<G0O<VEG;F5D(&1A=&$@=&\@
M8F4@=F5R:69I960N"B`@("`@*B!`<&%R86T@;6EX960@)&-E<G1S("!%:71H
M97(@82!S:6YG;&4@;W(@87)R87D@;V8@<F]O="!C97)T:69I8V%T97,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@3V)J96-T('=I=&@@=&AE
M(&9O;&QO=VEN9R!E;&5M96YT<SH*("`@("`J("`@("`@("`@("`@("`@("`@
M("=R97-U;'0G("T^(%)E='5R;G,@=')U92!O;B!S=6-C97-S.PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@97)R;W(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`G8V5R="<@
M+3X@5&AE(&-E<G1I9FEC871E(&]F('1H92!S:6=N97(@<W1O<F5D"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&UE<W-A9V4@
M*&EN(%!%32!F;W)M870I+@H@("`@("H@("`@("`@("`@("`@("`@("`@)V5M
M86EL)R`M/B!4:&4@96UA:6P@;V8@=&AE('-I9VYI;F<@<&5R<V]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!V97)I9GDH)'1E>'0L("1C97)T<RD*("`@('L*
M("`@("`@("`O*B!#:&5C:R!F;W(@879A:6QA8FEL:71Y(&]F($]P96Y34TP@
M4$A0(&5X=&5N<VEO;BX@*B\*("`@("`@("`D;W!E;G-S;"`]("1T:&ES+3YC
M:&5C:T9O<D]P96Y34TPH*3L*("`@("`@("!I9B`H:7-?82@D;W!E;G-S;"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]P96YS<VP[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!F;W(@
M:6YP=70O;W5T<'5T+B`J+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E
M871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@("`@)&]U='!U="`]
M("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["@H@("`@
M("`@("\J(%=R:71E('1E>'0@=&\@9FEL92`J+PH@("`@("`@("1F<"`](&9O
M<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G=R:71E*"1F<"P@)'1E>'0I
M.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`D<F]O=%]C97)T<R`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V5R=',I*2!["B`@
M("`@("`@("`@("1C97)T<R`](&%R<F%Y*"1C97)T<RD["B`@("`@("`@?0H@
M("`@("`@(&9O<F5A8V@@*"1C97)T<R!A<R`D9FEL92D@>PH@("`@("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D
M<F]O=%]C97)T<UM=(#T@)&9I;&4["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1O8B`]("9N97<@<W1D0VQA<W,["@H@("`@("`@(&EF("@A
M96UP='DH)')O;W1?8V5R=',I*2!["B`@("`@("`@("`@("1R97-U;'0@/2!O
M<&5N<W-L7W!K8W,W7W9E<FEF>2@D:6YP=70L(#`L("1O=71P=70L("1R;V]T
M7V-E<G1S*3L*("`@("`@("`@("`@+RH@365S<V%G92!V97)I9FEE9"`J+PH@
M("`@("`@("`@("!I9B`H)')E<W5L="`]/3T@=')U92D@>PH@("`@("`@("`@
M("`@("`@)&]B+3YR97-U;'0@/2!T<G5E.PH@("`@("`@("`@("`@("`@)&]B
M+3YC97)T(#T@9FEL95]G971?8V]N=&5N=',H)&]U='!U="D["B`@("`@("`@
M("`@("`@("`D;V(M/F5M86EL(#T@)'1H:7,M/F=E=$5M86EL1G)O;4ME>2@D
M;V(M/F-E<G0I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1O8CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@5')Y(&%G86EN('=I=&AO
M=70@=F5R9GEI;F<@=&AE('-I9VYE<B=S(&-E<G0@*B\*("`@("`@("`D<F5S
M=6QT(#T@;W!E;G-S;%]P:V-S-U]V97)I9GDH)&EN<'5T+"!02T-3-U].3U9%
M4DE&62P@)&]U='!U="D["@H@("`@("`@(&EF("@H)')E<W5L="`]/3T@=')U
M92D@?'P@*"1R97-U;'0@/3T]("TQ*2D@>PH@("`@("`@("`@("`D;V(M/G)E
M<W5L="`](%!%05(Z.G)A:7-E17)R;W(H7R@B365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@=F5R:69I960N(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&]B+3YR97-U;'0@/2!014%2.CIR
M86ES945R<F]R*%\H(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("!]"@H@("`@("`@("1O8BT^8V5R="`](&9I;&5?9V5T
M7V-O;G1E;G1S*"1O=71P=70I.PH@("`@("`@("1O8BT^96UA:6P@/2`D=&AI
M<RT^9V5T16UA:6Q&<F]M2V5Y*"1O8BT^8V5R="D["@H@("`@("`@(')E='5R
M;B`D;V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R86-T('1H92!C;VYT
M96YT<R!F<F]M('-I9VYE9"!3+TU)344@9&%T82X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A("`@("!4:&4@<VEG;F5D(%,O34E-12!D871A
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W-L<&%T:"`@5&AE('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8V]N=&5N=',@96UB961D960@:6X@=&AE('-I9VYE9"!D871A
M+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@97AT<F%C=%-I9VYE9$-O
M;G1E;G1S*"1D871A+"`D<W-L<&%T:"D*("`@('L*("`@("`@("`D<&EP97-?
M9&5S8R`](&%R<F%Y*`H@("`@("`@("`@("`P(#T^(&%R<F%Y*"=P:7!E)RP@
M)W(G*2P*("`@("`@("`@("`@,2`]/B!A<G)A>2@G<&EP92<L("=W)RD*("`@
M("`@("`I.PH*("`@("`@("`D9G`@/2!P<F]C7V]P96XH)'-S;'!A=&@@+B`G
M('-M:6UE("UV97)I9GD@+6YO=F5R:69Y("UN;V-H86EN)RP@)'!I<&5S7V1E
M<V,L("1P:7!E<RD["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D9G`I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@
M("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`O*B`D<&EP97-;,%T@/3X@
M=W)I=&5A8FQE(&AA;F1L92!C;VYN96-T960@=&\@8VAI;&0@<W1D:6X*("`@
M("`@("`@("`D<&EP97-;,5T@/3X@<F5A9&%B;&4@:&%N9&QE(&-O;FYE8W1E
M9"!T;R!C:&EL9"!S=&1O=70@*B\*("`@("`@("!F=W)I=&4H)'!I<&5S6S!=
M+"`D9&%T82D["B`@("`@("`@9F-L;W-E*"1P:7!E<ULP72D["@H@("`@("`@
M('=H:6QE("@A9F5O9B@D<&EP97-;,5TI*2!["B`@("`@("`@("`@("1O=71P
M=70@+CT@9F=E=',H)'!I<&5S6S%=+"`Q,#(T*3L*("`@("`@("!]"B`@("`@
M("`@9F-L;W-E*"1P:7!E<ULQ72D["B`@("`@("`@<')O8U]C;&]S92@D9G`I
M.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-I9VX@82!-24U%7U!A<G0@=7-I;F<@4R]-24U%+@H@("`@("H*("`@
M("`J($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R="`@5&AE($U)345?4&%R
M="!O8FIE8W0@=&\@<VEG;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("`@("`@("`@5&AE('!A<F%M971E<G,@<F5Q=6ER960@9F]R('-I9VYI;F<N
M"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T
M(&]B:F5C="!T:&%T(&ES('-I9VYE9"X*("`@("`J("`@("`@("`@("`@("`@
M("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'!A
M<F%M<RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O
M4&%R="YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]3
M=')U8W1U<F4N<&AP)SL*"B`@("`@("`@+RH@4VEG;B!T:&4@<&%R="!A<R!A
M(&UE<W-A9V4@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3YE;F-R>7!T
M*"1M:6UE7W!A<G0M/G1O0V%N;VYI8V%L4W1R:6YG*"DL("1P87)A;7,I.PH*
M("`@("`@("`O*B!"<F5A:R!T:&4@<F5S=6QT(&EN=&\@:71S(&-O;7!O;F5N
M=',@*B\*("`@("`@("`D;6EM95]M97-S86=E(#T@34E-15]3=')U8W1U<F4Z
M.G!A<G-E5&5X=$U)345-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)'-M
M:6UE7W-I9VX@/2`D;6EM95]M97-S86=E+3YG971087)T*#(I.PH@("`@("`@
M("1S;6EM95]S:6=N+3YS971$97-C<FEP=&EO;BA?*")3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4B*2D["B`@("`@("`@)'-M:6UE7W-I9VXM/G1R
M86YS9F5R1&5C;V1E0V]N=&5N=',H*3L*("`@("`@("`D<VUI;65?<VEG;BT^
M<V5T5')A;G-F97)%;F-O9&EN9R@G8F%S938T)RD["@H@("`@("`@("1S;6EM
M95]P87)T(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R="]S:6=N960G*3L*
M("`@("`@("`D<VUI;65?<&%R="T^<V5T0V]N=&5N=',H)U1H:7,@:7,@82!C
M<GEP=&]G<F%P:&EC86QL>2!S:6=N960@;65S<V%G92!I;B!-24U%(&9O<FUA
M="XG("X@(EQN(BD["B`@("`@("`@)'-M:6UE7W!A<G0M/F%D9%!A<G0H)&UI
M;65?<&%R="D["B`@("`@("`@)'-M:6UE7W!A<G0M/F%D9%!A<G0H)'-M:6UE
M7W-I9VXI.PH@("`@("`@("1S;6EM95]P87)T+3YS971#;VYT96YT5'EP95!A
M<F%M971E<B@G<')O=&]C;VPG+"`G87!P;&EC871I;VXO<&MC<S<M<VEG;F%T
M=7)E)RD["B`@("`@("`@)'-M:6UE7W!A<G0M/G-E=$-O;G1E;G14>7!E4&%R
M86UE=&5R*"=M:6-A;&<G+"`G<VAA,2<I.PH*("`@("`@("!R971U<FX@)'-M
M:6UE7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@34E-
M15]087)T('5S:6YG(%,O34E-12X*("`@("`J"B`@("`@*B!`<&%R86T@34E-
M15]087)T("1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J96-T('1O(&5N
M8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@("`@(%1H
M92!P87)A;65T97)S(')E<75I<F5D(&9O<B!E;F-R>7!T:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@34E-15]087)T("!!($U)345?4&%R="!O8FIE8W0@
M=&AA="!I<R!E;F-R>7!T960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E;F-R>7!T34E-15!A<G0H)&UI;65?<&%R="P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%
M+U!A<G0N<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O
M4W1R=6-T=7)E+G!H<"<["@H@("`@("`@("\J(%-I9VX@=&AE('!A<G0@87,@
M82!M97-S86=E("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^96YC<GEP
M="@D;6EM95]P87)T+3YT;T-A;F]N:6-A;%-T<FEN9R@I+"`D<&%R86US*3L*
M("`@("`@("!I9B`H:7-?82@D;65S<V%G92P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&UE<W-A9V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!"<F5A:R!T:&4@<F5S=6QT(&EN=&\@:71S(&-O;7!O;F5N=',@*B\*
M("`@("`@("`D;6EM95]M97-S86=E(#T@34E-15]3=')U8W1U<F4Z.G!A<G-E
M5&5X=$U)345-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)'-M:6UE7W!A
M<G0@/2`D;6EM95]M97-S86=E+3YG971"87-E4&%R="@I.PH@("`@("`@("1S
M;6EM95]P87)T+3YS971$97-C<FEP=&EO;BA?*")3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4B*2D["B`@("`@("`@)'-M:6UE7W!A<G0M/G1R86YS9F5R1&5C
M;V1E0V]N=&5N=',H*3L*("`@("`@("`D<VUI;65?<&%R="T^<V5T5')A;G-F
M97)%;F-O9&EN9R@G8F%S938T)RD["B`@("`@("`@)'-M:6UE7W!A<G0M/G-E
M=$1I<W!O<VET:6]N*"=I;FQI;F4G*3L*"B`@("`@("`@+RH@0GD@9&5F875L
M="P@96YC<GEP="@I('!R;V1U8V5S(&$@;65S<V%G92!W:71H('1Y<&4*("`@
M("`@("`@*B`G87!P;&EC871I;VXO>"UP:V-S-RUM:6UE)R!A;F0@;F\@)W-M
M:6UE+71Y<&4G('!A<F%M971E<BX@4&5R"B`@("`@("`@("H@4D9#(#(S,3$L
M('1H92!M;W)E(&-O<G)E8W0@34E-12!T>7!E(&ES("=A<'!L:6-A=&EO;B]P
M:V-S-RUM:6UE)PH@("`@("`@("`J(&%N9"!T:&4@<VUI;64M='EP92!S:&]U
M;&0@8F4@)V5N=F5L;W!E9"UD871A)RX@*B\*("`@("`@("`D<VUI;65?<&%R
M="T^<V5T5'EP92@G87!P;&EC871I;VXO<&MC<S<M;6EM92<I.PH@("`@("`@
M("1S;6EM95]P87)T+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G<VUI;64M
M='EP92<L("=E;G9E;&]P960M9&%T82<I.PH*("`@("`@("!R971U<FX@)'-M
M:6UE7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@;65S
M<V%G92!I;B!3+TU)344@9F]R;6%T('5S:6YG(&$@<'5B;&EC(&ME>2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@96YC<GEP=&5D+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE
M961E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J(#QP<F4^"B`@("`@*B!087)A
M;65T97)S.@H@("`@("H@/3T]/3T]/3T]/3T*("`@("`J("=T>7!E)R`@("`]
M/B`@)VUE<W-A9V4G("A215%525)%1"D*("`@("`J("=P=6)K97DG("`]/B`@
M<'5B;&EC(&ME>2X@*%)%455)4D5$*0H@("`@("H@)V5M86EL)R`@(#T^("!%
M+6UA:6P@861D<F5S<R!O9B!R96-I<&EE;G0N($EF(&YO="!P<F5S96YT+"!O
M<B!N;W0@9F]U;F0*("`@("`J("`@("`@("`@("`@("`@:6X@=&AE('!U8FQI
M8R!K97DL('1H92!F:7)S="!E+6UA:6P@861D<F5S<R!F;W5N9"!I;B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@:V5Y('=I;&P@8F4@=7-E9"!I;G-T96%D
M+B`H3W!T:6]N86PI"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!M97-S86=E+@H@("`@("H@("`@
M("`@("`@("`@("`@(%)E='5R;B!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N8W)Y<'1-97-S86=E*"1T97AT
M+"`D<&%R86US*0H@("`@>PH@("`@("`@("1E;6%I;"`](&YU;&P["@H@("`@
M("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J+PH@("`@
M("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M
M<"!F:6QE<R!F;W(@:6YP=70O;W5T<'5T+B`J+PH@("`@("`@("1I;G!U="`]
M("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@
M("`@)&]U='!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M
M:6UE)RD["@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@9FEL92X@*B\*
M("`@("`@("`D9G`Q(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F
M<'5T<R@D9G`Q+"`D=&5X="D["B`@("`@("`@9F-L;W-E*"1F<#$I.PH*("`@
M("`@("!I9B`H:7-S970H)'!A<F%M<ULG96UA:6PG72DI('L*("`@("`@("`@
M("`@)&5M86EL(#T@)'!A<F%M<ULG96UA:6PG73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D96UA:6P@/2`D=&AI<RT^9V5T16UA:6Q&<F]M2V5Y
M*"1P87)A;7-;)W!U8FME>2==*3L*("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)&5M86EL*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!%;F-R>7!T('1H92!D;V-U;65N
M="X@*B\*("`@("`@("!I9B`H;W!E;G-S;%]P:V-S-U]E;F-R>7!T*"1I;G!U
M="P@)&]U='!U="P@)'!A<F%M<ULG<'5B:V5Y)UTL(&%R<F%Y*"=4;R<@/3X@
M)&5M86EL*2DI('L*("`@("`@("`@("`@)')E<W5L="`](&9I;&5?9V5T7V-O
M;G1E;G1S*"1O=71P=70I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1R97-U
M;'0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]F:7A#;VYT
M96YT5'EP92@D<F5S=6QT+"`G96YC<GEP="<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6=N(&$@;65S<V%G92!I
M;B!3+TU)344@9F]R;6%T('5S:6YG(&$@<')I=F%T92!K97DN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E('-I9VYE9"X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R
M('-I9VYI;F<N"B`@("`@*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@
M("`J(#T]/3T]/3T]/3T]"B`@("`@*B`G8V5R=',G("`@("`@(#T^("!!9&1I
M=&EO;F%L('-I9VYI;F<@8V5R=',@*$]P=&EO;F%L*0H@("`@("H@)W!A<W-P
M:')A<V4G("`]/B`@4&%S<W!H<F%S92!F;W(@:V5Y("A215%525)%1"D*("`@
M("`J("=P<FEV:V5Y)R`@("`@/3X@(%!R:79A=&4@:V5Y("A215%525)%1"D*
M("`@("`J("=P=6)K97DG("`@("`@/3X@(%!U8FQI8R!K97D@*%)%455)4D5$
M*0H@("`@("H@)W-I9W1Y<&4G("`@("`]/B`@1&5T97)M:6YE('1H92!S:6=N
M871U<F4@='EP92!T;R!U<V4N("A/<'1I;VYA;"D*("`@("`J("`@("`@("`@
M("`@("`@("`@("=C;&5A<G1E>'0G("`M+2`@36%K92!A(&-L96%R('1E>'0@
M<VEG;F%T=7)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`G9&5T86-H)R`@
M("`@+2T@($UA:V4@82!D971A8VAE9"!S:6=N871U<F4@*$1%1D%53%0I"B`@
M("`@*B`G='EP92<@("`@("`@(#T^("`G<VEG;F%T=7)E)R`H4D5154E2140I
M"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('-I9VYE9"!M97-S86=E+@H@("`@("H@("`@("`@("`@("`@("`@(%)E
M='5R;B!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V5N8W)Y<'13:6=N871U<F4H)'1E>'0L("1P87)A;7,I"B`@
M("!["B`@("`@("`@+RH@0VAE8VL@9F]R('-E8W5R92!C;VYN96-T:6]N+B`J
M+PH@("`@("`@("1S96-U<F5?8VAE8VL@/2`D=&AI<RT^<F5Q=6ER95-E8W5R
M94-O;FYE8W1I;VXH*3L*("`@("`@("!I9B`H:7-?82@D<V5C=7)E7V-H96-K
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<V5C=7)E
M7V-H96-K.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(')E<75I
M<F5D('!A<F%M971E<G,N("HO"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US
M6R=P=6)K97DG72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1P87)A;7-;)W!R
M:79K97DG72D@?'P*("`@("`@("`@("`@(6%R<F%Y7VME>5]E>&ES=',H)W!A
M<W-P:')A<V4G+"`D<&%R86US*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!F;W(@:6YP=70O;W5T<'5T
M+V-E<G1I9FEC871E<RX@*B\*("`@("`@("`D:6YP=70@/2`D=&AI<RT^7V-R
M96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I.PH@("`@("`@("1O=71P=70@
M/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I.PH@("`@
M("`@("1C97)T<R`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M
M:6UE)RD["@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@=&5M<&]R87)Y
M(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*
M("`@("`@("!F<'5T<R@D9G`L("1T97AT*3L*("`@("`@("!F8VQO<V4H)&9P
M*3L*"B`@("`@("`@+RH@4W1O<F4@861D:71I;VYA;"!C97)T<R!I;B!T96UP
M;W)A<GD@9FEL92X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)V-E
M<G1S)UTI*2!["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1C97)T<RP@)W<K
M)RD["B`@("`@("`@("`@(&9P=71S*"1F<"P@)'!A<F%M<ULG8V5R=',G72D[
M"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@1&5T97)M:6YE('1H92!S:6=N871U<F4@='EP92!T;R!U<V4N("HO"B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W-I9W1Y<&4G72D@)B8@*"1P87)A
M;7-;)W-I9W1Y<&4G72`]/2`G8VQE87)T97AT)RDI('L*("`@("`@("`@("`@
M)&9L86=S(#T@4$M#4S=?5$585#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D9FQA9W,@/2!02T-3-U]$151!0TA%1#L*("`@("`@("!]"@H@("`@
M("`@("1P<FEV:V5Y(#T@*&ES7VYU;&PH)'!A<F%M<ULG<&%S<W!H<F%S92==
M*2D@/R`D<&%R86US6R=P<FEV:V5Y)UT@.B!A<G)A>2@D<&%R86US6R=P<FEV
M:V5Y)UTL("1P87)A;7-;)W!A<W-P:')A<V4G72D["@H@("`@("`@(&EF("AE
M;7!T>2@D<&%R86US6R=C97)T<R==*2D@>PH@("`@("`@("`@("`D<F5S(#T@
M;W!E;G-S;%]P:V-S-U]S:6=N*"1I;G!U="P@)&]U='!U="P@)'!A<F%M<ULG
M<'5B:V5Y)UTL("1P<FEV:V5Y+"!A<G)A>2@I+"`D9FQA9W,I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R97,@/2!O<&5N<W-L7W!K8W,W7W-I
M9VXH)&EN<'5T+"`D;W5T<'5T+"`D<&%R86US6R=P=6)K97DG72P@)'!R:79K
M97DL(&%R<F%Y*"DL("1F;&%G<RP@)&-E<G1S*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`D9&%T82`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1O=71P=70I.PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V9I>$-O;G1E;G14>7!E*"1D871A+"`G<VEG;F%T=7)E)RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&%N(%,O34E-12!E;F-R>7!T960@
M;65S<V%G92!U<VEN9R!A('!R:79A=&4O<'5B;&EC(&ME>7!A:7(*("`@("`J
M(&%N9"!A('!A<W-H<')A<V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T
M97AT('1O(&)E(&1E8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I;VXN"B`@
M("`@*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]/3T]
M/3T]"B`@("`@*B`G='EP92<@("`@("`@(#T^("`G;65S<V%G92<@*%)%455)
M4D5$*0H@("`@("H@)W!U8FME>2<@("`@("`]/B`@<'5B;&EC(&ME>2X@*%)%
M455)4D5$*0H@("`@("H@)W!R:79K97DG("`@("`]/B`@<')I=F%T92!K97DN
M("A215%525)%1"D*("`@("`J("=P87-S<&AR87-E)R`@/3X@(%!A<W-P:')A
M<V4@9F]R($ME>2X@*%)%455)4D5$*0H@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@;65S<V%G92X*
M("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J
M96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C<GEP=$UE
M<W-A9V4H)'1E>'0L("1P87)A;7,I"B`@("!["B`@("`@("`@+RH@0VAE8VL@
M9F]R('-E8W5R92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1S96-U<F5?8VAE
M8VL@/2`D=&AI<RT^<F5Q=6ER95-E8W5R94-O;FYE8W1I;VXH*3L*("`@("`@
M("!I9B`H:7-?82@D<V5C=7)E7V-H96-K+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<V5C=7)E7V-H96-K.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0VAE8VL@9F]R(')E<75I<F5D('!A<F%M971E<G,N("HO"B`@
M("`@("`@:68@*"%I<W-E="@D<&%R86US6R=P=6)K97DG72D@?'P*("`@("`@
M("`@("`@(6ES<V5T*"1P87)A;7-;)W!R:79K97DG72D@?'P*("`@("`@("`@
M("`@(6%R<F%Y7VME>5]E>&ES=',H)W!A<W-P:')A<V4G+"`D<&%R86US*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92XB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@
M=&5M<"!F:6QE<R!F;W(@:6YP=70O;W5T<'5T+B`J+PH@("`@("`@("1I;G!U
M="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@
M("`@("`@)&]U='!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E
M+7-M:6UE)RD["@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@9FEL92X@
M*B\*("`@("`@("`D9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@
M(&9P=71S*"1F<"P@=')I;2@D=&5X="DI.PH@("`@("`@(&9C;&]S92@D9G`I
M.PH*("`@("`@("`D<')I=FME>2`]("AI<U]N=6QL*"1P87)A;7-;)W!A<W-P
M:')A<V4G72DI(#\@)'!A<F%M<ULG<')I=FME>2==(#H@87)R87DH)'!A<F%M
M<ULG<')I=FME>2==+"`D<&%R86US6R=P87-S<&AR87-E)UTI.PH@("`@("`@
M(&EF("AO<&5N<W-L7W!K8W,W7V1E8W)Y<'0H)&EN<'5T+"`D;W5T<'5T+"`D
M<&%R86US6R=P=6)K97DG72P@)'!R:79K97DI*2!["B`@("`@("`@("`@(')E
M='5R;B!F:6QE7V=E=%]C;VYT96YT<R@D;W5T<'5T*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-I9VX@86YD($5N8W)Y<'0@82!-24U%7U!A<G0@
M=7-I;F<@4R]-24U%+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@
M)&UI;65?<&%R="`@(%1H92!-24U%7U!A<G0@;V)J96-T('1O('-I9VX@86YD
M(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'-I9VY?<&%R86US("`@
M("!4:&4@<&%R86UE=&5R<R!R97%U:7)E9"!F;W(@<VEG;FEN9RX@4V5E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?96YC<GEP=%-I
M9VYA='5R92@I+@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;F-R>7!T7W!A<F%M
M<R`@5&AE('!A<F%M971E<G,@<F5Q=6ER960@9F]R(&5N8W)Y<'1I;VXN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!3964@7V5N8W)Y
M<'1-97-S86=E*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@
M($$@34E-15]087)T(&]B:F5C="!T:&%T(&ES('-I9VYE9"!A;F0@96YC<GEP
M=&5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%
M<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VEG;D%N9$5N
M8W)Y<'1-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A;7,@/2!A<G)A
M>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YC
M<GEP=%]P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EN8VQU9&5?
M;VYC92`G2&]R9&4O34E-12]087)T+G!H<"<["@H@("`@("`@("1P87)T(#T@
M)'1H:7,M/G-I9VY-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A;7,I
M.PH@("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"B`@("`@("`@)'!A
M<G0@/2`D=&AI<RT^96YC<GEP=$U)345087)T*"1P87)T+"`D96YC<GEP=%]P
M87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E
M<G0@82!014T@9F]R;6%T(&-E<G1I9FEC871E('1O(')E861A8FQE($A434P@
M=F5R<VEO;@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-E<G0@("!0
M14T@9F]R;6%T(&-E<G1I9FEC871E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@($A434P@9&5T86EL:6YG('1H92!C97)T:69I8V%T92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V5R=%1O2%1-3"@D8V5R="D*("`@('L*("`@("`@
M("`O*B!#;VUM;VX@1FEE;&1S("HO"B`@("`@("`@)&9I96QD;F%M97,@/2!A
M<G)A>2@*("`@("`@("`@("`@)T5M86EL)R`]/B!?*")%;6%I;"!!9&1R97-S
M(BDL"B`@("`@("`@("`@("=#;VUM;VY.86UE)R`]/B!?*")#;VUM;VX@3F%M
M92(I+`H@("`@("`@("`@("`G3W)G86YI<V%T:6]N)R`]/B!?*")/<F=A;FES
M871I;VXB*2P*("`@("`@("`@("`@)T]R9V%N:7-A=&EO;F%L56YI="<@/3X@
M7R@B3W)G86YI<V%T:6]N86P@56YI="(I+`H@("`@("`@("`@("`G0V]U;G1R
M>2<@/3X@7R@B0V]U;G1R>2(I+`H@("`@("`@("`@("`G4W1A=&5/<E!R;W9I
M;F-E)R`]/B!?*")3=&%T92!O<B!0<F]V:6YC92(I+`H@("`@("`@("`@("`G
M3&]C871I;VXG(#T^(%\H(DQO8V%T:6]N(BDL"B`@("`@("`@("`@("=3=')E
M971!9&1R97-S)R`]/B!?*")3=')E970@061D<F5S<R(I+`H@("`@("`@("`@
M("`G5&5L97!H;VYE3G5M8F5R)R`]/B!?*")496QE<&AO;F4@3G5M8F5R(BDL
M"B`@("`@("`@("`@("=3=7)N86UE)R`]/B!?*")3=7)N86UE(BDL"B`@("`@
M("`@("`@("=':79E;DYA;64G(#T^(%\H(D=I=F5N($YA;64B*0H@("`@("`@
M("D["@H@("`@("`@("\J($YE='-C87!E($5X=&5N<VEO;G,@*B\*("`@("`@
M("`D9FEE;&1N86UE<R`K/2!A<G)A>2@*("`@("`@("`@("`@)VYE='-C87!E
M+6-E<G0M='EP92<@/3X@7R@B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(I
M+`H@("`@("`@("`@("`G;F5T<V-A<&4M8F%S92UU<FPG(#T^(%\H(DYE='-C
M87!E($)A<V4@55),(BDL"B`@("`@("`@("`@("=N971S8V%P92UR979O8V%T
M:6]N+75R;"<@/3X@7R@B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB*2P*("`@
M("`@("`@("`@)VYE='-C87!E+6-A+7)E=F]C871I;VXM=7)L)R`]/B!?*").
M971S8V%P92!#02!2979O8V%T:6]N(%523"(I+`H@("`@("`@("`@("`G;F5T
M<V-A<&4M8V5R="UR96YE=V%L+75R;"<@/3X@7R@B3F5T<V-A<&4@4F5N97=A
M;"!54DPB*2P*("`@("`@("`@("`@)VYE='-C87!E+6-A+7!O;&EC>2UU<FPG
M(#T^(%\H(DYE='-C87!E($-!('!O;&EC>2!54DPB*2P*("`@("`@("`@("`@
M)VYE='-C87!E+7-S;"US97)V97(M;F%M92<@/3X@7R@B3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE(BDL"B`@("`@("`@("`@("=N971S8V%P92UC;VUM96YT
M)R`]/B!?*").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(BD*("`@("`@
M("`I.PH*("`@("`@("`O*B!8-3DP=C,@17AT96YS:6]N<R`J+PH@("`@("`@
M("1F:65L9&YA;65S("L](&%R<F%Y*`H@("`@("`@("`@("`G:60M8V4M97AT
M2V5Y57-A9V4G(#T^(%\H(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B*2P*
M("`@("`@("`@("`@)VED+6-E+6)A<VEC0V]N<W1R86EN=',G(#T^(%\H(E@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<R(I+`H@("`@("`@("`@("`G:60M8V4M
M<W5B:F5C=$%L=$YA;64G(#T^(%\H(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64B*2P*("`@("`@("`@("`@)VED+6-E+7-U8FIE8W1+97E)9&5N
M=&EF:65R)R`]/B!?*")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(I
M+`H@("`@("`@("`@("`G:60M8V4M8V5R=&EF:6-A=&50;VQI8VEE<R<@/3X@
M7R@B0V5R=&EF:6-A=&4@4&]L:6-I97,B*2P*("`@("`@("`@("`@)VED+6-E
M+4-23$1I<W1R:6)U=&EO;E!O:6YT<R<@/3X@7R@B0U),($1I<W1R:6)U=&EO
M;B!0;VEN=',B*2P*("`@("`@("`@("`@)VED+6-E+6ME>55S86=E)R`]/B!?
M*")+97D@57-A9V4B*0H@("`@("`@("D["@H@("`@("`@("1C97)T7V1E=&%I
M;',@/2`D=&AI<RT^<&%R<V5#97)T*"1C97)T*3L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1C97)T7V1E=&%I;',I*2!["B`@("`@("`@("`@(')E='5R;B`G
M/'!R92!C;&%S<STB9FEX960B/B<@+B!?*")5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS(BD@+B`G/"]P<F4^)SL*("`@("`@("!]"B`@
M("`@("`@)&-E<G1I9FEC871E(#T@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A
M=&4G73L*"B`@("`@("`@)'1E>'0@/2`G/'!R92!C;&%S<STB9FEX960B/B<[
M"@H@("`@("`@("\J(%-U8FIE8W0@*&$O:R]A($-E<G1I9FEC871E($]W;F5R
M*2`J+PH@("`@("`@(&EF("AI<W-E="@D8V5R=&EF:6-A=&5;)W-U8FIE8W0G
M72DI('L*("`@("`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H(D-E
M<G1I9FEC871E($]W;F5R(BD@+B`B.CPO<W1R;VYG/EQN(CL*"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1C97)T:69I8V%T95LG<W5B:F5C="==(&%S("1K97D@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9I96QD
M;F%M97-;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@
M<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"`D9FEE;&1N86UE<ULD
M:V5Y72P@)'9A;'5E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[
M*B5S.B`E<UQN(BP@)&ME>2P@)'9A;'5E*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`N/2`B7&XB.PH@("`@
M("`@('T*"B`@("`@("`@+RH@27-S=65R("HO"B`@("`@("`@:68@*&ES<V5T
M*"1C97)T:69I8V%T95LG:7-S=65R)UTI*2!["B`@("`@("`@("`@("1T97AT
M("X]("(\<W1R;VYG/B(@+B!?*"))<W-U97(B*2`N("(Z/"]S=')O;F<^7&XB
M.PH*("`@("`@("`@("`@9F]R96%C:"`H)&-E<G1I9FEC871E6R=I<W-U97(G
M72!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1F:65L9&YA;65S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@)&9I
M96QD;F%M97-;)&ME>5TL("1V86QU92D["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N
M8G-P.R9N8G-P.RHE<SH@)7-<;B(L("1K97DL("1V86QU92D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1E>'0@+CT@
M(EQN(CL*("`@("`@("!]"@H@("`@("`@("\J($1A=&5S("`J+PH@("`@("`@
M("1T97AT("X]("(\<W1R;VYG/B(@+B!?*")686QI9&ET>2(I("X@(CH\+W-T
M<F]N9SY<;B(["B`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB
M<W`[)7,Z("5S7&XB+"!?*").;W0@0F5F;W)E(BDL('-T<F9T:6UE*"(E>"`E
M6"(L("1C97)T:69I8V%T95LG=F%L:61I='DG75LG;F]T8F5F;W)E)UTI*3L*
M("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@)7-<
M;B(L(%\H(DYO="!!9G1E<B(I+"!S=')F=&EM92@B)7@@)5@B+"`D8V5R=&EF
M:6-A=&5;)W9A;&ED:71Y)UU;)VYO=&%F=&5R)UTI*3L*("`@("`@("`D=&5X
M="`N/2`B7&XB.PH*("`@("`@("`O*B!#97)T:69I8V%T92!/=VYE<B`M(%!U
M8FQI8R!+97D@26YF;R`J+PH@("`@("`@("1T97AT("X]("(\<W1R;VYG/B(@
M+B!?*")0=6)L:6,@2V5Y($EN9F\B*2`N("(Z/"]S=')O;F<^7&XB.PH@("`@
M("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@
M7R@B4'5B;&EC($ME>2!!;&=O<FET:&TB*2P@)&-E<G1I9FEC871E6R=S=6)J
M96-T4'5B;&EC2V5Y26YF;R==6R=A;&=O<FET:&TG72D["B`@("`@("`@:68@
M*"1C97)T:69I8V%T95LG<W5B:F5C=%!U8FQI8TME>4EN9F\G75LG86QG;W)I
M=&AM)UT@/3T@)W)S845N8W)Y<'1I;VXG*2!["B`@("`@("`@("`@(&EF("A5
M=&EL.CIE>'1E;G-I;VY%>&ES=',H)V)C;6%T:"<I*2!["B`@("`@("`@("`@
M("`@("`D;6]D=6QU<R`]("1C97)T:69I8V%T95LG<W5B:F5C=%!U8FQI8TME
M>4EN9F\G75LG<W5B:F5C=%!U8FQI8TME>2==6R=M;V1U;'5S)UT["B`@("`@
M("`@("`@("`@("`D;6]D=6QU<U]H97@@/2`G)SL*("`@("`@("`@("`@("`@
M('=H:6QE("@D;6]D=6QU<R`A/2`G,"<I('L*("`@("`@("`@("`@("`@("`@
M("`D;6]D=6QU<U]H97@@/2!D96-H97@H8F-M;V0H)&UO9'5L=7,L("<Q-B<I
M*2`N("1M;V1U;'5S7VAE>#L*("`@("`@("`@("`@("`@("`@("`D;6]D=6QU
M<R`](&)C9&EV*"1M;V1U;'5S+"`G,38G+"`P*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("!I9B`H*'-T<FQE;B@D;6]D=6QU<U]H97@I
M(#X@-C0I("8F"B`@("`@("`@("`@("`@("`@("`@*'-T<FQE;B@D;6]D=6QU
M<U]H97@I(#P@,3(X*2D@>PH@("`@("`@("`@("`@("`@("`@('-T<E]P860H
M)&UO9'5L=7-?:&5X+"`Q,C@L("<P)RP@4U127U!!1%]224=(5"D["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H*'-T<FQE;B@D;6]D=6QU<U]H97@I(#X@
M,3(X*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("AS=')L96XH)&UO
M9'5L=7-?:&5X*2`\(#(U-BDI('L*("`@("`@("`@("`@("`@("`@("!S=')?
M<&%D*"1M;V1U;'5S7VAE>"P@,C4V+"`G,"<L(%-44E]0041?4DE'2%0I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T97AT("X]("(F
M;F)S<#LF;F)S<#LB("X@<W!R:6YT9BA?*")24T$@4'5B;&EC($ME>2`H)60@
M8FET*2(I+"!S=')L96XH)&UO9'5L=7-?:&5X*2`J(#0I("X@(CI<;B(["@H@
M("`@("`@("`@("`@("`@)&UO9'5L=7-?<W1R(#T@)R<["B`@("`@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&UO9'5L=7-?:&5X*3L@
M)&D@*ST@,BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@H)&D@)2`S,BD@
M/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;6]D=6QU<U]S='(@
M+CT@(EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[(CL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&UO
M9'5L=7-?<W1R("X]('-U8G-T<B@D;6]D=6QU<U]H97@L("1I+"`R*2`N("<Z
M)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D=&5X="`N
M/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE<SH@)7-<;B(L
M(%\H(DUO9'5L=7,B*2P@)&UO9'5L=7-?<W1R*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)FYB
M<W`[)FYB<W`[)7,Z("5S7&XB+"!?*")%>'!O;F5N="(I+"`D8V5R=&EF:6-A
M=&5;)W-U8FIE8W10=6)L:6-+97E);F9O)UU;)W-U8FIE8W10=6)L:6-+97DG
M75LG<'5B;&EC17AP;VYE;G0G72D["B`@("`@("`@?0H@("`@("`@("1T97AT
M("X](")<;B(["@H@("`@("`@("\J(%@U,#EV,R!E>'1E;G-I;VYS("HO"B`@
M("`@("`@:68@*&ES<V5T*"1C97)T:69I8V%T95LG97AT96YS:6]N<R==*2D@
M>PH@("`@("`@("`@("`D=&5X="`N/2`B/'-T<F]N9SXB("X@7R@B6#4P.78S
M(&5X=&5N<VEO;G,B*2`N("(Z/"]S=')O;F<^7&XB.PH*("`@("`@("`@("`@
M9F]R96%C:"`H)&-E<G1I9FEC871E6R=E>'1E;G-I;VYS)UT@87,@)&ME>2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@7R@B56YS=7!P
M;W)T960@17AT96YS:6]N(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&9I96QD;F%M97-;)&ME>5TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[
M)7,Z7&XF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE<UQN(BP@)&9I96QD;F%M
M97-;)&ME>5TL('=O<F1W<F%P*"1V86QU92P@-#`L(")<;B9N8G-P.R9N8G-P
M.R9N8G-P.R9N8G-P.R(I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB
M<W`[)7,Z7&XF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE<UQN(BP@)&ME>2P@
M=V]R9'=R87`H)'9A;'5E+"`V,"P@(EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB
M<W`[(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D=&5X="`N/2`B7&XB.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0V5R=&EF:6-A=&4@1&5T86EL<R`J+PH@("`@("`@("1T97AT("X]("(\<W1R
M;VYG/B(@+B!?*")#97)T:69I8V%T92!$971A:6QS(BD@+B`B.CPO<W1R;VYG
M/EQN(CL*("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE
M<SH@)61<;B(L(%\H(E9E<G-I;VXB*2P@)&-E<G1I9FEC871E6R=V97)S:6]N
M)UTI.PH@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S
M.B`E9%QN(BP@7R@B4V5R:6%L($YU;6)E<B(I+"`D8V5R=&EF:6-A=&5;)W-E
M<FEA;$YU;6)E<B==*3L*"B`@("`@("`@9F]R96%C:"`H)&-E<G1?9&5T86EL
M<ULG9FEN9V5R<')I;G1S)UT@87,@)&AA<V@@/3X@)&9I;F=E<G!R:6YT*2![
M"B`@("`@("`@("`@("1L86)E;"`]('-P<FEN=&8H7R@B)7,@1FEN9V5R<')I
M;G0B*2P@4W1R:6YG.CIU<'!E<B@D:&%S:"DI.PH@("`@("`@("`@("`D9FEN
M9V5R<')I;G1?<W1R(#T@)R<["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\('-T<FQE;B@D9FEN9V5R<')I;G0I.R`D:2`K/2`R*2!["B`@("`@("`@
M("`@("`@("`D9FEN9V5R<')I;G1?<W1R("X]('-U8G-T<B@D9FEN9V5R<')I
M;G0L("1I+"`R*2`N("<Z)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SI<;B9N8G-P.R9N8G-P
M.R9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R5S7&XB+"`D;&%B96PL("1F:6YG
M97)P<FEN=%]S='(I.PH@("`@("`@('T*("`@("`@("`D=&5X="`N/2!S<')I
M;G1F*"(F;F)S<#LF;F)S<#LE<SH@)7-<;B(L(%\H(E-I9VYA='5R92!!;&=O
M<FET:&TB*2P@)&-E<G1?9&5T86EL<ULG<VEG;F%T=7)E06QG;W)I=&AM)UTI
M.PH@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B(L
M(%\H(E-I9VYA='5R92(I*3L*"B`@("`@("`@)'-I9U]S='(@/2`G)SL*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&-E<G1?9&5T86EL<ULG
M<VEG;F%T=7)E)UTI.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@H)&D@)2`Q
M-BD@/3T@,"D@>PH@("`@("`@("`@("`@("`@)'-I9U]S='(@+CT@(EQN)FYB
M<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[(CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<VEG7W-T<B`N/2!S<')I;G1F*"(E,#)X.B(L
M(&]R9"@D8V5R=%]D971A:6QS6R=S:6=N871U<F4G75LD:5TI*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&5X="`N("1S:6=?<W1R("X@(EQN/"]P
M<F4^(CL*("`@('T*"B`@("`O*BH*("`@("`J($5X=')A8W0@=&AE(&-O;G1E
M;G1S(&]F(&$@4$5-(&9O<FUA="!C97)T:69I8V%T92!T;R!A;B!A<G)A>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C97)T("!014T@9F]R;6%T
M(&-E<G1I9FEC871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R
M87D@8V]N=&%I;FEN9R!A;&P@97AT<F%C=&%B;&4@:6YF;W)M871I;VX@86)O
M=70*("`@("`J("`@("`@("`@("`@("`@('1H92!C97)T:69I8V%T92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<&%R<V5#97)T*"1C97)T*0H@("`@>PH@("`@
M("`@("1C97)T7W-P;&ET(#T@<')E9U]S<&QI="@G+R@M+2TM+2@H0D5'24XI
M?"A%3D0I*2!#15)4249)0T%412TM+2TM*2\G+"`D8V5R="D["B`@("`@("`@
M:68@*"%I<W-E="@D8V5R=%]S<&QI=%LQ72DI('L*("`@("`@("`@("`@)')A
M=U]C97)T(#T@8F%S938T7V1E8V]D92@D8V5R="D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)')A=U]C97)T(#T@8F%S938T7V1E8V]D92@D8V5R
M=%]S<&QI=%LQ72D["B`@("`@("`@?0H*("`@("`@("`D8V5R=%]D871A(#T@
M)'1H:7,M/E]P87)S94%33B@D<F%W7V-E<G0I.PH@("`@("`@(&EF("@A:7-?
M87)R87DH)&-E<G1?9&%T82D@?'P@*"1C97)T7V1A=&%;,%T@/3T@)U5.2TY/
M5TXG*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D8V5R=%]D971A:6QS(#T@87)R87DH*3L*("`@("`@("`D8V5R
M=%]D971A:6QS6R=F:6YG97)P<FEN=',G75LG;60U)UT@/2!M9#4H)')A=U]C
M97)T*3L*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S*"=M:&%S
M:"<I*2!["B`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V9I;F=E<G!R:6YT
M<R==6R=S:&$Q)UT@/2!B:6XR:&5X*&UH87-H*$U(05-(7U-(03$L("1R87=?
M8V5R="DI.PH@("`@("`@('T*"B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R
M=&EF:6-A=&4G75LG97AT96YS:6]N<R==(#T@87)R87DH*3L*("`@("`@("`D
M8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V97)S:6]N)UT@/2`D8V5R
M=%]D871A6S%=6S!=6S%=6S!=6S%=("L@,3L*("`@("`@("`D8V5R=%]D971A
M:6QS6R=C97)T:69I8V%T92==6R=S97)I86Q.=6UB97(G72`]("1C97)T7V1A
M=&%;,5U;,%U;,5U;,5U;,5T["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R
M=&EF:6-A=&4G75LG<VEG;F%T=7)E)UT@/2`D8V5R=%]D871A6S%=6S!=6S%=
M6S)=6S%=6S!=6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)VES<W5E<B==(#T@)&-E<G1?9&%T85LQ75LP75LQ75LS75LQ73L*
M("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET
M>2==(#T@)&-E<G1?9&%T85LQ75LP75LQ75LT75LQ73L*("`@("`@("`D8V5R
M=%]D971A:6QS6R=C97)T:69I8V%T92==6R=S=6)J96-T)UT@/2!`)&-E<G1?
M9&%T85LQ75LP75LQ75LU75LQ73L*("`@("`@("`D8V5R=%]D971A:6QS6R=C
M97)T:69I8V%T92==6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==(#T@)&-E<G1?
M9&%T85LQ75LP75LQ75LV75LQ73L*"B`@("`@("`@)&-E<G1?9&5T86EL<ULG
M<VEG;F%T=7)E06QG;W)I=&AM)UT@/2`D8V5R=%]D871A6S%=6S%=6S%=6S!=
M6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;)W-I9VYA='5R92==(#T@)&-E
M<G1?9&%T85LQ75LR75LQ73L*"B`@("`@("`@+R\@:7-S=65R"B`@("`@("`@
M)&ES<W5E<B`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-E<G1?9&5T
M86EL<ULG8V5R=&EF:6-A=&4G75LG:7-S=65R)UT@87,@)'9A;'5E*2!["B`@
M("`@("`@("`@("1I<W-U97);)'9A;'5E6S%=6S%=6S!=6S%=72`]("1V86QU
M95LQ75LQ75LQ75LQ73L*("`@("`@("!]"B`@("`@("`@)&-E<G1?9&5T86EL
M<ULG8V5R=&EF:6-A=&4G75LG:7-S=65R)UT@/2`D:7-S=65R.PH*("`@("`@
M("`O+R!S=6)J96-T"B`@("`@("`@)'-U8FIE8W0@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W-U
M8FIE8W0G72!A<R`D=F%L=64I('L*("`@("`@("`@("`@)'-U8FIE8W1;)'9A
M;'5E6S%=6S%=6S!=6S%=72`]("1V86QU95LQ75LQ75LQ75LQ73L*("`@("`@
M("!]"B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG<W5B
M:F5C="==(#T@)'-U8FIE8W0["@H@("`@("`@("\O('9A;&ED:71Y"B`@("`@
M("`@)'9A;',@/2`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI
M9&ET>2==.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;
M)W9A;&ED:71Y)UT@/2!A<G)A>2@I.PH@("`@("`@("1C97)T7V1E=&%I;'-;
M)V-E<G1I9FEC871E)UU;)W9A;&ED:71Y)UU;)VYO=&)E9F]R92==(#T@)'9A
M;'-;,%U;,5T["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G
M75LG=F%L:61I='DG75LG;F]T869T97(G72`]("1V86QS6S%=6S%=.PH@("`@
M("`@(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A
M;&ED:71Y)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1Y96%R
M(#T@<W5B<W1R*"1V86PL(#`L(#(I.PH@("`@("`@("`@("`D;6]N=&@@/2!S
M=6)S='(H)'9A;"P@,BP@,BD["B`@("`@("`@("`@("1D87D@/2!S=6)S='(H
M)'9A;"P@-"P@,BD["B`@("`@("`@("`@("1H;W5R(#T@<W5B<W1R*"1V86PL
M(#8L(#(I.PH@("`@("`@("`@("`D;6EN=71E(#T@<W5B<W1R*"1V86PL(#@L
M(#(I.PH@("`@("`@("`@("!I9B`H*"1V86Q;,3%=(#T]("<M)RD@?'P@*"1V
M86Q;.5T@/3T@)RLG*2D@>PH@("`@("`@("`@("`@("`@+R\@:&%N9&QE('1I
M;64@>F]N92!O9F9S970@:&5R90H@("`@("`@("`@("`@("`@)'-E8V]N9',@
M/2`P.PH@("`@("`@("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D=F%L
M6S$Q72D@/3T@)UHG*2!["B`@("`@("`@("`@("`@("`D<V5C;VYD<R`](#`[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V5C;VYD
M<R`]('-U8G-T<B@D=F%L+"`Q,"P@,BD["B`@("`@("`@("`@("`@("!I9B`H
M*"1V86Q;,3%=(#T]("<M)RD@?'P@*"1V86Q;.5T@/3T@)RLG*2D@>PH@("`@
M("`@("`@("`@("`@("`@("\O(&AA;F1L92!T:6UE('IO;F4@;V9F<V5T(&AE
M<F4*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET>2==6R1K
M97E=(#T@;6MT:6UE("@D:&]U<BP@)&UI;G5T92P@)'-E8V]N9',L("1M;VYT
M:"P@)&1A>2P@)'EE87(I.PH@("`@("`@('T*"B`@("`@("`@+R\@4W!L:70@
M=&AE(%!U8FQI8R!+97D@:6YT;R!C;VUP;VYE;G1S+@H@("`@("`@("1S=6)J
M96-T4'5B;&EC2V5Y26YF;R`](&%R<F%Y*"D["B`@("`@("`@)'-U8FIE8W10
M=6)L:6-+97E);F9O6R=A;&=O<FET:&TG72`]("1C97)T7V1E=&%I;'-;)V-E
M<G1I9FEC871E)UU;)W-U8FIE8W10=6)L:6-+97E);F9O)UU;,%U;,5U;,%U;
M,5T["B`@("`@("`@:68@*"1S=6)J96-T4'5B;&EC2V5Y26YF;ULG86QG;W)I
M=&AM)UT@/3T@)W)S845N8W)Y<'1I;VXG*2!["B`@("`@("`@("`@("1S=6)J
M96-T4'5B;&EC2V5Y(#T@)'1H:7,M/E]P87)S94%33B@D8V5R=%]D971A:6QS
M6R=C97)T:69I8V%T92==6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==6S%=6S%=
M*3L*("`@("`@("`@("`@)'-U8FIE8W10=6)L:6-+97E);F9O6R=S=6)J96-T
M4'5B;&EC2V5Y)UU;)VUO9'5L=7,G72`]("1S=6)J96-T4'5B;&EC2V5Y6S%=
M6S!=6S%=.PH@("`@("`@("`@("`D<W5B:F5C=%!U8FQI8TME>4EN9F];)W-U
M8FIE8W10=6)L:6-+97DG75LG<'5B;&EC17AP;VYE;G0G72`]("1S=6)J96-T
M4'5B;&EC2V5Y6S%=6S%=6S%=.PH@("`@("`@('T*("`@("`@("`D8V5R=%]D
M971A:6QS6R=C97)T:69I8V%T92==6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==
M(#T@)'-U8FIE8W10=6)L:6-+97E);F9O.PH*("`@("`@("!I9B`H:7-S970H
M)&-E<G1?9&%T85LQ75LP75LQ75LW72D@)B8*("`@("`@("`@("`@:7-?87)R
M87DH)&-E<G1?9&%T85LQ75LP75LQ75LW75LQ72DI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&-E<G1?9&%T85LQ75LP75LQ75LW75LQ72!A<R`D97AT*2![
M"B`@("`@("`@("`@("`@("`D;VED(#T@)&5X=%LQ75LP75LQ73L*("`@("`@
M("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N
M<VEO;G,G75LD;VED72`]("1E>'1;,5U;,5T["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1I(#T@.3L*("`@("`@("!W:&EL92`H:7-S970H
M)&-E<G1?9&%T85LQ75LP75LQ75LD:5TI*2!["B`@("`@("`@("`@("1O:60@
M/2`D8V5R=%]D871A6S%=6S!=6S%=6R1I75LQ75LP75LQ73L*("`@("`@("`@
M("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==
M6R1O:61=(#T@)&-E<G1?9&%T85LQ75LP75LQ75LD:5U;,5U;,5T["B`@("`@
M("`@("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D8V5R
M=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UT@87,@)&]I
M9"`]/B`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H)&]I9"D@>PH@("`@
M("`@("`@("!C87-E("=N971S8V%P92UB87-E+75R;"<Z"B`@("`@("`@("`@
M(&-A<V4@)VYE='-C87!E+7)E=F]C871I;VXM=7)L)SH*("`@("`@("`@("`@
M8V%S92`G;F5T<V-A<&4M8V$M<F5V;V-A=&EO;BUU<FPG.@H@("`@("`@("`@
M("!C87-E("=N971S8V%P92UC97)T+7)E;F5W86PM=7)L)SH*("`@("`@("`@
M("`@8V%S92`G;F5T<V-A<&4M8V$M<&]L:6-Y+75R;"<Z"B`@("`@("`@("`@
M(&-A<V4@)VYE='-C87!E+7-S;"US97)V97(M;F%M92<Z"B`@("`@("`@("`@
M(&-A<V4@)VYE='-C87!E+6-O;6UE;G0G.@H@("`@("`@("`@("`@("`@)'9A
M;"`]("1T:&ES+3Y?<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@
M("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;
M)&]I9%T@/2`D=F%L6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=I9"UC92US=6)J96-T06QT3F%M92<Z"B`@("`@("`@
M("`@("`@("`D=F%L(#T@)'1H:7,M/E]P87)S94%33B@D=F%L6S%=*3L*("`@
M("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X
M=&5N<VEO;G,G75LD;VED72`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'9A;%LQ72!A<R`D;F%M92D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS
M:6]N<R==6R1O:61=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8V5R
M=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@
M+CT@)RP@)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N
M<R==6R1O:61=("X]("1N86UE6S%=.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=N971S8V%P
M92UC97)T+71Y<&4G.@H@("`@("`@("`@("`@("`@)'9A;"`]("1T:&ES+3Y?
M<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@("`D=F%L(#T@;W)D
M*"1V86Q;,5TI.PH@("`@("`@("`@("`@("`@)&YE=U9A;"`]("<G.PH*("`@
M("`@("`@("`@("`@(&EF("@D=F%L("8@,'@X,"D@>PH@("`@("`@("`@("`@
M("`@("`@("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G4U-,(&-L:65N
M="<@.B`G+"!34TP@8VQI96YT)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@D=F%L("8@,'@T,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G4U-,('-E<G9E<B<@
M.B`G+"!34TP@<V5R=F5R)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("@D=F%L("8@,'@R,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G4R]-24U%)R`Z("<L(%,O
M34E-12<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M)'9A;"`F(#!X,3`I('L*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X]
M(&5M<'1Y*"1N97=686PI(#\@)T]B:F5C="!3:6=N:6YG)R`Z("<L($]B:F5C
M="!3:6=N:6YG)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("@D=F%L("8@,'@P-"D@>PH@("`@("`@("`@("`@("`@("`@("1N97=6
M86P@+CT@96UP='DH)&YE=U9A;"D@/R`G4U-,($-!)R`Z("<L(%-33"!#02<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)'9A;"`F
M(#!X,#(I('L*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X](&5M<'1Y
M*"1N97=686PI(#\@)U,O34E-12!#02<@.B`G+"!3+TU)344@0T$G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@)B`P>#`Q
M*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T>2@D;F5W
M5F%L*2`_("=/8FIE8W0@4VEG;FEN9R!#02<@.B`G+"!/8FIE8W0@4VEG;FEN
M9R!#02<["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&-E
M<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=
M(#T@)&YE=U9A;#L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G:60M8V4M97AT2V5Y57-A9V4G.@H@("`@("`@("`@("`@("`@
M)'9A;"`]("1T:&ES+3Y?<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@
M("`@("`D=F%L(#T@)'9A;%LQ73L*"B`@("`@("`@("`@("`@("`D;F5W5F%L
M(#T@)R<["B`@("`@("`@("`@("`@("!I9B`H)'9A;%LP75LQ72`A/2`G<V5Q
M=65N8V4G*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;"`](&%R<F%Y*"1V
M86PI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=F%L(#T@)'9A;%LQ75LQ73L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1V86P@87,@)'5S86=E*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1U<V%G95LQ72`]/2`G:61?:W!?8VQI96YT
M075T:"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E
M;7!T>2@D;F5W5F%L*2`_("=43%,@5V5B($-L:65N="!!=71H96YT:6-A=&EO
M;B<@.B`G+"!43%,@5V5B($-L:65N="!!=71H96YT:6-A=&EO;B<["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&YE=U9A;"`N/2!E;7!T>2@D;F5W5F%L*2`_("1U<V%G95LQ72`Z("<L
M("<@+B`D=7-A9V5;,5T["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R
M=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@)&YE=U9A;#L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:60M8V4M
M<W5B:F5C=$ME>4ED96YT:69I97(G.@H@("`@("`@("`@("`@("`@)'9A;"`]
M("1T:&ES+3Y?<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@("`D
M=F%L(#T@)'9A;%LQ73L*"B`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)R<[
M"@H@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1V
M86PI.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!S
M<')I;G1F*"(E,#)X.B(L(&]R9"@D=F%L6R1I72DI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A
M=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@)&YE=U9A;#L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:60M8V4M875T:&]R
M:71Y2V5Y261E;G1I9FEE<B<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H
M:7,M/E]P87)S94%33B@D=F%L6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D
M=F%L6S!=(#T]("=S=')I;F<G*2!["B`@("`@("`@("`@("`@("`@("`@)'9A
M;"`]("1V86Q;,5T["@H@("`@("`@("`@("`@("`@("`@("1N97=686P@/2`G
M)SL*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L
M96XH)'9A;"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE
M=U9A;"`N/2!S<')I;G1F*"(E,#)X.B(L(&]R9"@D=F%L6R1I72DI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8V5R=%]D
M971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2`D
M;F5W5F%L.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I
M;VYS)UU;)&]I9%T@/2!?*")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G:60M8V4M8F%S:6-#;VYS=')A:6YT<R<Z"B`@("`@("`@
M("`@(&-A<V4@)V1E9F%U;'0G.@H@("`@("`@("`@("`@("`@)&-E<G1?9&5T
M86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@7R@B
M56YS=7!P;W)T960@17AT96YS:6]N(BD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C
M97)T7V1E=&%I;',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O
M('!A<G-E($%33BXQ(&9O<FUA=&5D(&1A=&$N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T
M82`@05-.+C$@9F]R;6%T960@9&%T80H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%R<F%Y(&-O;G1A:6YE9"!T:&4@97AT<F%C=&5D('9A;'5E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E05-.*"1D871A*0H@("`@>PH@
M("`@("`@("1R97-U;'0@/2!A<G)A>2@I.PH*("`@("`@("!W:&EL92`H<W1R
M;&5N*"1D871A*2`^(#$I('L*("`@("`@("`@("`@)&-L87-S(#T@;W)D*"1D
M871A6S!=*3L*("`@("`@("`@("`@<W=I=&-H("@D8VQA<W,I('L*("`@("`@
M("`@("`@8V%S92`P>#,P.@H@("`@("`@("`@("`@("`@+R\@4V5Q=65N8V4*
M("`@("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@("`@("`@
M("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;&5N
M("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`]("1L96X@
M)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P.PH@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L96X@/#P@."D@
M?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-E<75E;F-E7V1A
M=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI.PH@("`@("`@
M("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D
M;&5N*3L*"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@)'1H:7,M/E]P87)S
M94%33B@D<V5Q=65N8V5?9&%T82D["B`@("`@("`@("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1V86QU97,I('Q\(&ES7W-T<FEN9R@D=F%L=65S6S!=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=F%L=65S*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S97%U96YC95]V
M86QU97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1V86Q;,%T@/3T@)V5X=&5N<VEO;B<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-E<75E;F-E7W9A;'5E<ULG97AT
M96YS:6]N<R==6UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1S97%U96YC95]V86QU97-;
M)&DK*UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=S
M97%U96YC92<L("1S97%U96YC95]V86QU97,I.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#!X,S$Z"B`@("`@("`@("`@("`@
M("`O+R!3970@;V8*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;
M,5TI.PH@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@
M("`@(&EF("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@("1B
M>71E<R`]("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@("1L96X@
M/2`P.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B
M>71E<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&5N(#T@
M*"1L96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'-E<75E;F-E7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L
M96XI.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@
M*R`D8GET97,@*R`D;&5N*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`]
M(&%R<F%Y*"=S970G+"`D=&AI<RT^7W!A<G-E05-.*"1S97%U96YC95]D871A
M*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M,'@P,3H*("`@("`@("`@("`@("`@("\O($)O;VQE86X@='EP90H@("`@("`@
M("`@("`@("`@)&)O;VQE86Y?=F%L=64@/2`H;W)D*"1D871A6S)=*2`]/2`P
M>&9F*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`S
M*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=B;V]L96%N
M)RP@)&)O;VQE86Y?=F%L=64I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E(#!X,#(Z"B`@("`@("`@("`@("`@("`O+R!);G1E
M9V5R('1Y<&4*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI
M.PH@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@
M(&EF("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E
M<R`]("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P
M.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E
M<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L
M96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1I
M;G1E9V5R7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI
M.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D
M8GET97,@*R`D;&5N*3L*"B`@("`@("`@("`@("`@("`D=F%L=64@/2`P.PH@
M("`@("`@("`@("`@("`@:68@*"1L96X@/#T@-"D@>PH@("`@("`@("`@("`@
M("`@("`@("\J($UE=&AO9"!W;W)K<R!F:6YE(&9O<B!S;6%L;"!I;G1E9V5R
M<R`J+PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T
M<FQE;B@D:6YT96=E<E]D871A*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2`H)'9A;'5E(#P\(#@I('P@;W)D*"1I;G1E9V5R
M7V1A=&%;)&E=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($UE=&AO9"!W
M;W)K<R!F;W(@87)B:71R87)Y(&QE;F=T:"!I;G1E9V5R<R`J+PH@("`@("`@
M("`@("`@("`@("`@(&EF("A5=&EL.CIE>'1E;G-I;VY%>&ES=',H)V)C;6%T
M:"<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\('-T<FQE;B@D:6YT96=E<E]D871A*3L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@8F-A9&0H8F-M=6PH)'9A;'5E
M+"`R-38I+"!O<F0H)&EN=&5G97)?9&%T85LD:5TI*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("TQ.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1R97-U;'1;72`](&%R<F%Y*"=I;G1E9V5R*"<@+B`D;&5N("X@)RDG+"`D
M=F%L=64I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E(#!X,#,Z"B`@("`@("`@("`@("`@("`O+R!":71S=')I;F<@='EP90H@
M("`@("`@("`@("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@
M("`@("`@("`D8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@
M)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F
M(#!X,&8["B`@("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\
M(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8FET<W1R:6YG7V1A
M=&$@/2!S=6)S='(H)&1A=&$L(#,@*R`D8GET97,L("1L96XI.PH@("`@("`@
M("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D
M;&5N*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=B:70@
M<W1R:6YG)RP@)&)I='-T<FEN9U]D871A*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`P>#`T.@H@("`@("`@("`@("`@("`@
M+R\@3V-T971S=')I;F<@='EP90H@("`@("`@("`@("`@("`@)&QE;B`](&]R
M9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@("`@
M("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@("`@
M("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@("`@
M("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D;V-T96-T<W1R:6YG7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@
M*R`D8GET97,L("1L96XI.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S
M='(H)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N*3L*("`@("`@("`@("`@("`@
M("1R97-U;'1;72`](&%R<F%Y*"=O8W1E="!S=')I;F<G+"`D;V-T96-T<W1R
M:6YG7V1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E(#!X,#4Z"B`@("`@("`@("`@("`@("`O+R!.=6QL('1Y<&4*("`@
M("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R*3L*("`@("`@
M("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=N=6QL)RP@;G5L;"D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P-CH*
M("`@("`@("`@("`@("`@("\O($]B:F5C="!I9&5N=&EF:65R('1Y<&4*("`@
M("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@("`@("`@("`@
M("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;&5N("8@
M,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`]("1L96X@)B`P
M>#!F.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P.PH@("`@("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L96X@/#P@."D@?"!O
M<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&]I9%]D871A(#T@<W5B
M<W1R*"1D871A+"`R("L@)&)Y=&5S+"`D;&5N*3L*("`@("`@("`@("`@("`@
M("1D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S("L@)&QE;BD["@H@
M("`@("`@("`@("`@("`@+R\@56YP86-K('1H92!/240*("`@("`@("`@("`@
M("`@("1P;&%I;B`@/2!F;&]O<BAO<F0H)&]I9%]D871A6S!=*2`O(#0P*3L*
M("`@("`@("`@("`@("`@("1P;&%I;B`N/2`G+B<@+B!O<F0H)&]I9%]D871A
M6S!=*2`E(#0P.PH*("`@("`@("`@("`@("`@("1V86QU92`](#`["B`@("`@
M("`@("`@("`@("`D:2`](#$["B`@("`@("`@("`@("`@("!W:&EL92`H)&D@
M/"!S=')L96XH)&]I9%]D871A*2D@>PH@("`@("`@("`@("`@("`@("`@("1V
M86QU92`]("1V86QU92`\/"`W.PH@("`@("`@("`@("`@("`@("`@("1V86QU
M92`]("1V86QU92!\("AO<F0H)&]I9%]D871A6R1I72D@)B`P>#=F*3L*"B`@
M("`@("`@("`@("`@("`@("`@:68@*"$H;W)D*"1O:61?9&%T85LD:5TI("8@
M,'@X,"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!L86EN("X]("<N
M)R`N("1V86QU93L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M,#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)&DK*SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]O:61S6R1P;&%I;ETI*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E<W5L=%M=(#T@87)R87DH)V]I9"<L("1T:&ES+3Y?;VED<ULD
M<&QA:6Y=*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)V]I9"<L("1P;&%I;BD["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E(#!X,3(Z"B`@("`@("`@("`@(&-A<V4@,'@Q,SH*("`@
M("`@("`@("`@8V%S92`P>#$T.@H@("`@("`@("`@("!C87-E(#!X,34Z"B`@
M("`@("`@("`@(&-A<V4@,'@Q-CH*("`@("`@("`@("`@8V%S92`P>#@Q.@H@
M("`@("`@("`@("!C87-E(#!X.#`Z"B`@("`@("`@("`@("`@("`O+R!#:&%R
M86-T97(@<W1R:6YG('1Y<&4*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H
M)&1A=&%;,5TI.PH@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@
M("`@("`@("`@(&EF("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1B>71E<R`]("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@
M("1L96X@/2`P.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1B>71E<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;&5N(#T@*"1L96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'-T<FEN9U]D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S
M+"`D;&5N*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A
M+"`R("L@)&)Y=&5S("L@)&QE;BD["B`@("`@("`@("`@("`@("`D<F5S=6QT
M6UT@/2!A<G)A>2@G<W1R:6YG)RP@)'-T<FEN9U]D871A*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#$W.@H@("`@("`@
M("`@("`@("`@+R\@5&EM92!T>7!E<PH@("`@("`@("`@("`@("`@)&QE;B`]
M(&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@
M("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@
M("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@
M("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D=&EM95]D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y
M=&5S+"`D;&5N*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D
M871A+"`R("L@)&)Y=&5S("L@)&QE;BD["B`@("`@("`@("`@("`@("`D<F5S
M=6QT6UT@/2!A<G)A>2@G=71C=&EM92<L("1T:6UE7V1A=&$I.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X.#(Z"B`@("`@
M("`@("`@("`@("`O+R!8-3`Y=C,@97AT96YS:6]N<S\*("`@("`@("`@("`@
M("`@("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@("`@("`@("`@("`@("`@)&)Y
M=&5S(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;&5N("8@,'@X,"D@>PH@
M("`@("`@("`@("`@("`@("`@("1B>71E<R`]("1L96X@)B`P>#!F.PH@("`@
M("`@("`@("`@("`@("`@("1L96X@/2`P.PH@("`@("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;&5N(#T@*"1L96X@/#P@."D@?"!O<F0H)&1A=&%;
M)&D@*R`R72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'-E<75E;F-E7V1A=&$@/2!S=6)S='(H
M)&1A=&$L(#(@*R`D8GET97,L("1L96XI.PH@("`@("`@("`@("`@("`@)&1A
M=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N*3L*("`@("`@
M("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=E>'1E;G-I;VXG+"`G6#4P
M.78S(&5X=&5N<VEO;G,G*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`]
M("1T:&ES+3Y?<&%R<V5!4TXH)'-E<75E;F-E7V1A=&$I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X83`Z"B`@("`@("`@
M("`@(&-A<V4@,'AA,SH*("`@("`@("`@("`@("`@("\O($5X=&5N<VEO;G,*
M("`@("`@("`@("`@("`@("1E>'1E;G-I;VY?9&%T82`]('-U8G-T<B@D9&%T
M82P@,"P@,BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T
M82P@,BD["B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G97AT
M96YS:6]N)RP@9&5C:&5X*"1E>'1E;G-I;VY?9&%T82DI.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X938Z"B`@("`@("`@
M("`@("`@("`D97AT96YS:6]N7V1A=&$@/2!S=6)S='(H)&1A=&$L(#`L(#$I
M.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#$I.PH@
M("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)V5X=&5N<VEO;B<L
M(&1E8VAE>"@D97AT96YS:6]N7V1A=&$I*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`P>&$Q.@H@("`@("`@("`@("`@("`@
M)&5X=&5N<VEO;E]D871A(#T@<W5B<W1R*"1D871A+"`P+"`Q*3L*("`@("`@
M("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`V*3L*("`@("`@("`@
M("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=E>'1E;G-I;VXG+"!D96-H97@H
M)&5X=&5N<VEO;E]D871A*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`O+R!5;FMN;W=N
M"B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G54Y+3D]73B<L
M(&1E8VAE>"@D9&%T82DI.PH@("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@*&-O=6YT*"1R97-U;'0I(#X@,2D@/R`D<F5S
M=6QT(#H@87)R87E?<&]P*"1R97-U;'0I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5C<GEP="!A;B!3/TU)344@<VEG;F5D(&UE<W-A9V4@=7-I;F<@82!P
M=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X="!T;R!B
M92!V97)I9FEE9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@
M<&%R86UE=&5R<R!N965D960@9F]R('9E<FEF:6-A=&EO;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('9E<FEF:6-A=&EO;B!M97-S86=E
M+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-R>7!T
M4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=?9&5C<GEP=%-I9VYA='5R92@I("<@+B!?
M*")N;W0@>65T(&EM<&QE;65N=&5D(BDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAE8VL@9F]R('1H92!P<F5S96YC92!O9B!T:&4@3W!E;E-33"!E>'1E
M;G-I;VX@=&\@4$A0+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M4F5T=7)N<R!T<G5E(&EF('1H92!O<&5N<W-L(&5X=&5N<VEO;B!I<R!A=F%I
M;&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@(%)E='5R;G,@82!014%2
M7T5R<F]R(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM&;W)/
M<&5N4U-,*"D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X
M:7-T<R@G;W!E;G-S;"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F
M;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(BDI.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($5X=')A8W0@=&AE(&5M86EL(&%D
M9')E<W,@9G)O;2!A('!U8FQI8R!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:V5Y("!4:&4@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@4F5T=7)N<R!T:&4@96UA:6P@861D<F5S<RP@;W(@
M;G5L;"!I9B!N;VYE(&ES(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971%;6%I;$9R;VU+97DH)&ME>2D*("`@('L*("`@("`@("`D:V5Y7VEN9F\@
M/2!O<&5N<W-L7W@U,#E?<&%R<V4H)&ME>2D["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1K97E?:6YF;RD@)B8@:7-S970H)&ME>5]I;F9O6R=S=6)J96-T)UTI
M*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D:V5Y7VEN9F];)W-U8FIE8W0G
M75LG16UA:6PG72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D:V5Y7VEN
M9F];)W-U8FIE8W0G75LG16UA:6PG73L*("`@("`@("`@("`@?2!E;'-E:68@
M*&ES<V5T*"1K97E?:6YF;ULG<W5B:F5C="==6R=E;6%I;$%D9')E<W,G72DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D:V5Y7VEN9F];)W-U8FIE8W0G
M75LG96UA:6Q!9&1R97-S)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N
M=F5R="!A(%!+0U,@,3(@96YC<GEP=&5D(&-E<G1I9FEC871E('!A8VMA9V4@
M:6YT;R!A('!R:79A=&4@:V5Y+`H@("`@("H@<'5B;&EC(&ME>2P@86YD(&%N
M>2!A9&1I=&EO;F%L(&ME>7,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@(%1H92!02T-3(#$R(&1A=&$N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!P87)S:6YG
M+@H@("`@("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]
M/3T]/3T]/0H@("`@("H@)W-S;'!A=&@G(#T^(%1H92!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2X@*%)%455)4D5$*0H@("`@("H@)W!A<W-W;W)D)R`]
M/B!4:&4@<&%S<W=O<F0@=&\@=7-E('1O(&1E8W)Y<'0@=&AE(&1A=&$N("A/
M<'1I;VYA;"D*("`@("`J("=N97=P87-S=V]R9"<@/3X@5&AE('!A<W-W;W)D
M('1O('5S92!T;R!E;F-R>7!T('1H92!P<FEV871E(&ME>2X*("`@("`J("`@
M("`@("`@("`@("`@("`@*$]P=&EO;F%L*0H@("`@("H@/"]P<F4^"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@06X@;V)J96-T+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@)W!R:79A=&4G("T@(%1H92!P<FEV871E(&ME
M>2!I;B!014T@9F]R;6%T+@H@("`@("H@("`@("`@("`@("`@("`@("`@)W!U
M8FQI8R<@("T@(%1H92!P=6)L:6,@:V5Y(&EN(%!%32!F;W)M870N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`G8V5R=',G("`@+2`@06X@87)R87D@;V8@
M861D:71I;VYA;"!C97)T<RX*("`@("`J("`@("`@("`@("`@("`@("`@(%)E
M='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<&%R<V502T-3,3)$871A*"1P:V-S,3(L("1P87)A;7,I"B`@("!["B`@
M("`@("`@+RH@0VAE8VL@9F]R(&%V86EL86)I;&ET>2!O9B!/<&5N4U-,(%!(
M4"!E>'1E;G-I;VXN("HO"B`@("`@("`@)&]P96YS<VP@/2`D=&AI<RT^8VAE
M8VM&;W)/<&5N4U-,*"D["B`@("`@("`@:68@*&ES7V$H)&]P96YS<VPL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O<&5N<W-L.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=S<VQP871H
M)UTI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*("`@("`@
M("`D<W-L<&%T:"`](&5S8V%P97-H96QL8VUD*"1P87)A;7-;)W-S;'!A=&@G
M72D["@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U="]O
M=71P=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP
M1FEL92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T<'5T(#T@)'1H:7,M
M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@("`@("`@)&]B
M(#T@)FYE=R!S=&1#;&%S<SL*"B`@("`@("`@+RH@5W)I=&4@=&5X="!T;R!F
M:6QE("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@
M("`@("!F=W)I=&4H)&9P+"`D<&MC<S$R*3L*("`@("`@("!F8VQO<V4H)&9P
M*3L*"B`@("`@("`@+RH@17AT<F%C="!T:&4@<')I=F%T92!K97D@9G)O;2!T
M:&4@9FEL92!F:7)S="X@*B\*("`@("`@("`D8VUD;&EN92`]("1S<VQP871H
M("X@)R!P:V-S,3(@+6EN("<@+B`D:6YP=70@+B`G("UO=70@)R`N("1O=71P
M=70@+B`G("UN;V-E<G1S)SL*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG
M<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)&-M9&QI;F4@+CT@)R`M<&%S
M<VEN('-T9&EN)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=N
M97=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`@("`@)&-M9&QI;F4@+CT@
M)R`M<&%S<V]U="!S=&1I;B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D8VUD;&EN92`N/2`G("UN;V1E<R<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&9D(#T@<&]P96XH)&-M9&QI;F4L("=W)RD["B`@
M("`@("`@("`@(&9W<FET92@D9F0L("1P87)A;7-;)W!A<W-W;W)D)UT@+B`B
M7&XB*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=N97=P87-S
M=V]R9"==*2D@>PH@("`@("`@("`@("`@("`@9G=R:71E*"1F9"P@)'!A<F%M
M<ULG;F5W<&%S<W=O<F0G72`N(")<;B(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@('!C;&]S92@D9F0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C;61L:6YE("X]("<@+6YO9&5S)SL*("`@("`@("`@("`@97AE8R@D
M8VUD;&EN92D["B`@("`@("`@?0H@("`@("`@("1O8BT^<')I=F%T92`]('1R
M:6TH9FEL95]G971?8V]N=&5N=',H)&]U='!U="DI.PH@("`@("`@(&EF("AE
M;7!T>2@D;V(M/G!R:79A=&4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E!A<W-W;W)D(&EN8V]R<F5C="(I+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('!U
M8FQI8R!K97D@;F5X="X@*B\*("`@("`@("`D8VUD;&EN92`]("1S<VQP871H
M("X@)R!P:V-S,3(@+6EN("<@+B`D:6YP=70@+B`G("UO=70@)R`N("1O=71P
M=70@+B`G("UN;VME>7,@+6-L8V5R=',G.PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D8VUD;&EN92`N
M/2`G("UP87-S:6X@<W1D:6XG.PH@("`@("`@("`@("`D9F0@/2!P;W!E;B@D
M8VUD;&EN92P@)W<G*3L*("`@("`@("`@("`@9G=R:71E*"1F9"P@)'!A<F%M
M<ULG<&%S<W=O<F0G72`N(")<;B(I.PH@("`@("`@("`@("!P8VQO<V4H)&9D
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E>&5C*"1C;61L:6YE
M*3L*("`@("`@("!]"B`@("`@("`@)&]B+3YP=6)L:6,@/2!T<FEM*&9I;&5?
M9V5T7V-O;G1E;G1S*"1O=71P=70I*3L*"B`@("`@("`@+RH@17AT<F%C="!T
M:&4@<'5B;&EC(&ME>2!N97AT+B`J+PH@("`@("`@("1C;61L:6YE(#T@)'-S
M;'!A=&@@+B`G('!K8W,Q,B`M:6X@)R`N("1I;G!U="`N("<@+6]U="`G("X@
M)&]U='!U="`N("<@+6YO:V5Y<R`M8V%C97)T<R<["B`@("`@("`@:68@*&ES
M<V5T*"1P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1C;61L
M:6YE("X]("<@+7!A<W-I;B!S=&1I;B<["B`@("`@("`@("`@("1F9"`]('!O
M<&5N*"1C;61L:6YE+"`G=R<I.PH@("`@("`@("`@("!F=W)I=&4H)&9D+"`D
M<&%R86US6R=P87-S=V]R9"==("X@(EQN(BD["B`@("`@("`@("`@('!C;&]S
M92@D9F0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5X96,H)&-M
M9&QI;F4I.PH@("`@("`@('T*("`@("`@("`D;V(M/F-E<G1S(#T@=')I;2AF
M:6QE7V=E=%]C;VYT96YT<R@D;W5T<'5T*2D["@H@("`@("`@(')E='5R;B`D
M;V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@0V]N=&5N="U4>7!E('!A
M<F%M971E<G,@4$A0)W,@;W!E;G-S;%]P:V-S-U\J(&9U;F-T:6]N<R!R971U
M<FX@87)E"B`@("`@*B!D97!R96-A=&5D+B`@1FEX('1H97-E(&AE861E<G,@
M=&\@=&AE(&-O<G)E8W0@;VYE<R`H<V5E(%)&0R`R,S$Q*2X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@4$M#4S<@9&%T82X*("`@("`J($!P87)A;2!S=')I
M;F<@)'1Y<&4@($ES('1H:7,@)VUE<W-A9V4G(&]R("=S:6=N871U<F4G(&1A
M=&$_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!02T-3-R!D
M871A('=I=&@@=&AE(&-O<G)E8W0@0V]N=&5N="U4>7!E('!A<F%M971E<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V9I>$-O;G1E;G14>7!E*"1T97AT+"`D
M='EP92D*("`@('L*("`@("`@("!I9B`H)'1Y<&4@/3T@)VUE<W-A9V4G*2![
M"B`@("`@("`@("`@("1F<F]M(#T@)V%P<&QI8V%T:6]N+W@M<&MC<S<M;6EM
M92<["B`@("`@("`@("`@("1T;R`]("=A<'!L:6-A=&EO;B]P:V-S-RUM:6UE
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G)O;2`]("=A<'!L
M:6-A=&EO;B]X+7!K8W,W+7-I9VYA='5R92<["B`@("`@("`@("`@("1T;R`]
M("=A<'!L:6-A=&EO;B]P:V-S-RUS:6=N871U<F4G.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@<W1R7W)E<&QA8V4H)T-O;G1E;G0M5'EP93H@)R`N("1F
M<F]M+"`G0V]N=&5N="U4>7!E.B`G("X@)'1O+"`D=&5X="D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#<GEP="]P9W`N<&AP
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-#8R,#8`,3`U
M,34T,S$P-C$`,#(P-C(U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T-R>7!T
M+G!H<"<["@HO*BH*("H@07)M;W(@2&5A9&5R($QI;F5S("T@1G)O;2!21D,@
M,C0T,`H@*@H@*B`@06X@07)M;W(@2&5A9&5R($QI;F4@8V]N<VES=',@;V8@
M=&AE(&%P<')O<')I871E(&AE861E<B!L:6YE('1E>'0*("H@('-U<G)O=6YD
M960@8GD@9FEV92`H-2D@9&%S:&5S("@G+2<L(#!X,D0I(&]N(&5I=&AE<B!S
M:61E(&]F('1H92!H96%D97(*("H@(&QI;F4@=&5X="X@5&AE(&AE861E<B!L
M:6YE('1E>'0@:7,@8VAO<V5N(&)A<V5D('5P;VX@=&AE('1Y<&4@;V8@9&%T
M82!T:&%T"B`J("!I<R!B96EN9R!E;F-O9&5D(&EN($%R;6]R+"!A;F0@:&]W
M(&ET(&ES(&)E:6YG(&5N8V]D960N($AE861E<B!L:6YE('1E>'1S"B`J("!I
M;F-L=61E('1H92!F;VQL;W=I;F<@<W1R:6YG<SH*("H*("H@($%L;"!!<FUO
M<B!(96%D97(@3&EN97,@87)E('!R969I>&5D('=I=&@@)U!'4"<N"B`J"B`J
M("!4:&4@07)M;W(@5&%I;"!,:6YE(&ES(&-O;7!O<V5D(&EN('1H92!S86UE
M(&UA;FYE<B!A<R!T:&4@07)M;W(@2&5A9&5R"B`J("!,:6YE+"!E>&-E<'0@
M=&AE('-T<FEN9R`B0D5'24XB(&ES(')E<&QA8V5D(&)Y('1H92!S=')I;F<@
M(D5.1"XB"B`J+PH*+RHJ(%5S960@9F]R('-I9VYE9"P@96YC<GEP=&5D+"!O
M<B!C;VUP<F5S<V5D(&9I;&5S+B`J+PID969I;F4H)U!'4%]!4DU/4E]-15-3
M04=%)RP@,2D["@HO*BH@57-E9"!F;W(@<VEG;F5D(&9I;&5S+B`J+PID969I
M;F4H)U!'4%]!4DU/4E]324=.141?34534T%'12<L(#(I.PH*+RHJ(%5S960@
M9F]R(&%R;6]R:6YG('!U8FQI8R!K97ES+B`J+PID969I;F4H)U!'4%]!4DU/
M4E]054),24-?2T59)RP@,RD["@HO*BH@57-E9"!F;W(@87)M;W)I;F<@<')I
M=F%T92!K97ES+B`J+PID969I;F4H)U!'4%]!4DU/4E]04DE6051%7TM%62<L
M(#0I.PH*+RHJ"B`J(%5S960@9F]R(&1E=&%C:&5D('-I9VYA='5R97,L(%!'
M4"]-24U%('-I9VYA='5R97,L(&%N9"!N871U<F5S(&9O;&QO=VEN9PH@*B!C
M;&5A<G-I9VYE9"!M97-S86=E<RX*("HO"F1E9FEN92@G4$=07T%234]27U-)
M1TY!5%5212<L(#4I.PH*+RHJ(%)E9W5L87(@=&5X="!C;VYT86EN960@:6X@
M86X@4$=0(&UE<W-A9V4N("HO"F1E9FEN92@G4$=07T%234]27U1%6%0G+"`V
M*3L*"@HO*BH@5&AE(&1E9F%U;'0@<'5B;&EC(%!'4"!K97ES97)V97(@=&\@
M=7-E+B`J+PID969I;F4H)U!'4%]+15E315)615)?4%5"3$E#)RP@)W=W=VME
M>7,N<&=P+FYE="<I.PH*+RHJ"B`J(%1H92!N=6UB97(@;V8@=&EM97,@=&AE
M(&ME>7-E<G9E<B!R969U<V5S(&-O;FYE8W1I;VX@8F5F;W)E(&%N(&5R<F]R
M(&ES"B`J(')E='5R;F5D+@H@*B\*9&5F:6YE*"=01U!?2T594T525D527U)%
M1E5312<L(#,I.PH*+RHJ"B`J(%1H92!N=6UB97(@;V8@<V5C;VYD<R!T:&%T
M(%!(4"!W:6QL(&%T=&5M<'0@=&\@8V]N;F5C="!T;R!T:&4@:V5Y<V5R=F5R
M"B`J(&)E9F]R92!I="!W:6QL('-T;W`@<')O8V5S<VEN9R!T:&4@<F5Q=65S
M="X*("HO"F1E9FEN92@G4$=07TM%65-%4E9%4E]424U%3U54)RP@,3`I.PH*
M"B\J*@H@*B!(;W)D95]#<GEP=%]P9W`Z.B!P<F]V:61E<R!A(&9R86UE=V]R
M:R!F;W(@2&]R9&4@87!P;&EC871I;VYS('1O(&EN=&5R86-T"B`J('=I=&@@
M=&AE($=.52!0<FEV86-Y($=U87)D('!R;V=R86T@*")';G501R(I+B`@1VYU
M4$<@:6UP;&5M96YT<R!T:&4@3W!E;E!'4`H@*B!S=&%N9&%R9"`H4D9#(#(T
M-#`I+@H@*@H@*B!';G501R!796)S:71E.B!H='1P.B\O=W=W+F=N=7!G+F]R
M9R\*("H*("H@5&AI<R!C;&%S<R!H87,@8F5E;B!D979E;&]P960@=VET:"P@
M86YD(&ES(&]N;'D@9W5A<F%N=&5E9"!T;R!W;W)K('=I=&@L"B`J(%9E<G-I
M;VX@,2XR,2!O<B!A8F]V92!O9B!';G501RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<"QV(#$N.#4N,BXQ-2`R,#`V+S`W
M+S(P(#`Y.C`R.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-R>7!T"B`J+PIC;&%S
M<R!(;W)D95]#<GEP=%]P9W`@97AT96YD<R!(;W)D95]#<GEP="!["@H@("`@
M+RHJ"B`@("`@*B!3=')I;F=S(&EN(&%R;6]R(&AE861E<B!L:6YE<R!U<V5D
M('1O(&1I<W1I;F=U:7-H(&)E='=E96X@=&AE(&1I9F9E<F5N=`H@("`@("H@
M='EP97,@;V8@4$=0(&1E8W)Y<'1I;VXO96YC<GEP=&EO;BX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%R;6]R(#T@87)R
M87DH"B`@("`@("`@)TU%4U-!1T4G("`@("`@("`@("`@/3X@(%!'4%]!4DU/
M4E]-15-304=%+`H@("`@("`@("=324=.140@34534T%'12<@("`@(#T^("!0
M1U!?05)-3U)?4TE'3D5$7TU%4U-!1T4L"B`@("`@("`@)U!50DQ)0R!+15D@
M0DQ/0TLG("`@/3X@(%!'4%]!4DU/4E]054),24-?2T59+`H@("`@("`@("=0
M4DE6051%($M%62!"3$]#2R<@(#T^("!01U!?05)-3U)?4%))5D%415]+15DL
M"B`@("`@("`@)U-)1TY!5%5212<@("`@("`@("`@/3X@(%!'4%]!4DU/4E]3
M24=.05154D4*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@;&ES="!O9B!0
M1U`@:&%S:"!A;&=O<FET:&US("AF<F]M(%)&0R`S,34V*2X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VAA<VA!;&<@/2!A
M<G)A>2@*("`@("`@("`Q("`]/B`@)W!G<"UM9#4G+`H@("`@("`@(#(@(#T^
M("`G<&=P+7-H83$G+`H@("`@("`@(#,@(#T^("`G<&=P+7)I<&5M9#$V,"<L
M"B`@("`@("`@-2`@/3X@("=P9W`M;60R)RP*("`@("`@("`V("`]/B`@)W!G
M<"UT:6=E<C$Y,B<L"B`@("`@("`@-R`@/3X@("=P9W`M:&%V86PM-2TQ-C`G
M+`H@("`@("`@(#@@(#T^("`G<&=P+7-H83(U-B<L"B`@("`@("`@.2`@/3X@
M("=P9W`M<VAA,S@T)RP*("`@("`@("`Q,"`]/B`@)W!G<"US:&$U,3(G+`H@
M("`@*3L*"B`@("`O*BH*("`@("`J($=N=5!'('!R;V=R86T@;&]C871I;VXO
M8V]M;6]N(&]P=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]G;G5P9SL*"B`@("`O*BH*("`@("`J($9I;&5N86UE
M(&]F('1H92!T96UP;W)A<GD@<'5B;&EC(&ME>7)I;F<N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<'5B;&EC2V5Y<FEN
M9SL*"B`@("`O*BH*("`@("`J($9I;&5N86UE(&]F('1H92!T96UP;W)A<GD@
M<')I=F%T92!K97ER:6YG+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W!R:79A=&5+97ER:6YG.PH*("`@("\J*@H@("`@
M("H@5&AE(&5X:7-T96YC92!O9B!T:&ES('!R;W!E<G1Y(&EN9&EC871E<R!T
M:&%T(&UU;'1I<&QE(')E8VEP:65N=`H@("`@("H@96YC<GEP=&EO;B!I<R!A
M=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!D97!R96-A=&5D"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D;75L=&EP;&5296-I<&EE;G1%;F-R>7!T
M:6]N(#T@=')U93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!087)A;65T97(@87)R
M87D@8V]N=&%I;FEN9R!T:&4@<&%T:"!T;R!T:&4@1VYU4$<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!B:6YA<GD@*&ME>2`]("=P<F]G<F%M)RD@
M86YD('1O(&$@=&5M<&]R87)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@9&ER96-T;W)Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]#<GEP
M=%]P9W`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]T96UP9&ER(#T@571I;#HZ8W)E871E5&5M<$1I<BAT<G5E+"`D<&%R86US
M6R=T96UP)UTI.PH*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<')O9W)A
M;2==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%
M<G)O<BA?*")4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB*2DL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T
M:&4@;&]C871I;VX@;V8@1VYU4$<@86YD('-E="!C;VUM;VX@;W!T:6]N<RX@
M*B\*("`@("`@("`D=&AI<RT^7V=N=7!G(#T@87)R87DH"B`@("`@("`@("`@
M("1P87)A;7-;)W!R;V=R86TG72P*("`@("`@("`@("`@)RTM;F\M='1Y)RP*
M("`@("`@("`@("`@)RTM;F\M<V5C;65M+7=A<FYI;F<G+`H@("`@("`@("`@
M("`G+2UN;RUO<'1I;VYS)RP*("`@("`@("`@("`@)RTM;F\M9&5F875L="UK
M97ER:6YG)RP*("`@("`@("`@("`@)RTM<75I970G+`H@("`@("`@("`@("`G
M+2UY97,G+`H@("`@("`@("`@("`G+2UH;VUE9&ER("<@+B`D=&AI<RT^7W1E
M;7!D:7(*("`@("`@("`I.PH*("`@("`@("!I9B`H<W5B<W1R*%!(4%]/4RP@
M,"P@,RD@(3T@)U=)3B<I('L*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D
M=&AI<RT^7V=N=7!G+"`G3$%.1ST@.R<I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E<R!A('!E<G-O;F%L(%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@8V]M8FEN871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F5A;&YA;64@("`@5&AE(&YA;64@=&\@=7-E(&9O<B!T:&4@
M:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96UA:6P@("`@("`@5&AE(&5M
M86EL('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<W-P:')A<V4@(%1H92!P87-S<&AR87-E('1O('5S92!F;W(@=&AE(&ME
M>2X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UE;G0@("`@(%1H92!C;VUM
M96YT('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1K97EL96YG=&@@(%1H92!K97EL96YG=&@@=&\@=7-E(&9O<B!T:&4@:V5Y
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&-O;G-I
M<W1I;F<@;V8@=&AE('!U8FQI8R!K97D@86YD('1H92!P<FEV871E"B`@("`@
M*B`@("`@("`@("`@("`@("!K97DL(&]R(%!%05)?17)R;W(@;VX@97)R;W(N
M"B`@("`@*B`\<')E/@H@("`@("H@4F5T=7)N(&%R<F%Y.@H@("`@("H@2V5Y
M("`@("`@("`@("`@5F%L=64*("`@("`J("TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM"B`@("`@*B`G<'5B;&EC)R`@(#T^("!0=6)L:6,@2V5Y"B`@("`@
M*B`G<')I=F%T92<@(#T^("!0<FEV871E($ME>0H@("`@("H@/"]P<F4^"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E2V5Y*"1R96%L;F%M92P@)&5M
M86EL+"`D<&%S<W!H<F%S92P@)&-O;6UE;G0@/2`G)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("1K97EL96YG=&@@/2`Q,#(T*0H@("`@>PH@("`@("`@
M("\J($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN96-T:6]N
M*"D["B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C:SL*("`@
M("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S('1O(&AO;&0@
M=&AE(&=E;F5R871E9"!K97ES+B`J+PH@("`@("`@("1P=6)?9FEL92`]("1T
M:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@("1S
M96-R971?9FEL92`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G
M<"<I.PH*("`@("`@("`O*B!#<F5A=&4@=&AE(&-O;F9I9R!F:6QE(&YE8V5S
M<V%R>2!F;W(@1VYU4$<@=&\@<G5N(&EN(&)A=&-H(&UO9&4N("HO"B`@("`@
M("`@+RH@5$]$3SH@4V%N:71I>F4@:6YP=70L($UO<F4@=7-E<B!C=7-T;VUI
M>F%B;&4_("HO"B`@("`@("`@)&EN<'5T(#T@87)R87DH*3L*("`@("`@("`D
M:6YP=71;72`]("<E<'5B<FEN9R`G("X@)'!U8E]F:6QE.PH@("`@("`@("1I
M;G!U=%M=(#T@)R5S96-R:6YG("<@+B`D<V5C<F5T7V9I;&4["B`@("`@("`@
M)&EN<'5T6UT@/2`G2V5Y+51Y<&4Z($1302<["B`@("`@("`@)&EN<'5T6UT@
M/2`G2V5Y+4QE;F=T:#H@,3`R-"<["B`@("`@("`@)&EN<'5T6UT@/2`G4W5B
M:V5Y+51Y<&4Z($5,1RU%)SL*("`@("`@("`D:6YP=71;72`]("=3=6)K97DM
M3&5N9W1H.B`G("X@)&ME>6QE;F=T:#L*("`@("`@("`D:6YP=71;72`]("=.
M86UE+5)E86PZ("<@+B`D<F5A;&YA;64["B`@("`@("`@:68@*"%E;7!T>2@D
M8V]M;65N="DI('L*("`@("`@("`@("`@)&EN<'5T6UT@/2`G3F%M92U#;VUM
M96YT.B`G("X@)&-O;6UE;G0["B`@("`@("`@?0H@("`@("`@("1I;G!U=%M=
M(#T@)TYA;64M16UA:6PZ("<@+B`D96UA:6P["B`@("`@("`@)&EN<'5T6UT@
M/2`G17AP:7)E+41A=&4Z(#`G.PH@("`@("`@("1I;G!U=%M=(#T@)U!A<W-P
M:')A<V4Z("<@+B`D<&%S<W!H<F%S93L*("`@("`@("`D:6YP=71;72`]("<E
M8V]M;6ET)SL*"B`@("`@("`@+RH@4G5N('1H<F]U9V@@9W!G(&)I;F%R>2X@
M*B\*("`@("`@("`D8VUD;&EN92`](&%R<F%Y*`H@("`@("`@("`@("`G+2UG
M96XM:V5Y)RP*("`@("`@("`@("`@)RTM8F%T8V@G+`H@("`@("`@("`@("`G
M+2UA<FUO<B<*("`@("`@("`I.PH@("`@("`@("1T:&ES+3Y?8V%L;$=P9R@D
M8VUD;&EN92P@)W<G+"`D:6YP=70I.PH*("`@("`@("`O*B!'970@=&AE(&ME
M>7,@9G)O;2!T:&4@=&5M<"!F:6QE<RX@*B\*("`@("`@("`D<'5B;&EC7VME
M>2`](&9I;&4H)'!U8E]F:6QE*3L*("`@("`@("`D<V5C<F5T7VME>2`](&9I
M;&4H)'-E8W)E=%]F:6QE*3L*"B`@("`@("`@+RH@268@96ET:&5R(&ME>2!I
M<R!E;7!T>2P@<V]M971H:6YG('=E;G0@=W)O;F<N("HO"B`@("`@("`@:68@
M*&5M<'1Y*"1P=6)L:6-?:V5Y*2!\?"!E;7!T>2@D<V5C<F5T7VME>2DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M87)R87DH)W!U8FQI8R<@/3X@)'!U8FQI8U]K97DL("=P<FEV871E)R`]/B`D
M<V5C<F5T7VME>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN
M9F]R;6%T:6]N(&]N(&$@4$=0(&1A=&$@8FQO8VLN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&=P9&%T82`@5&AE(%!'4"!D871A(&)L;V-K+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y('=I=&@@:6YF
M;W)M871I;VX@;VX@=&AE(%!'4"!D871A(&)L;V-K+B!)9B!A;@H@("`@("H@
M("`@("`@("`@("`@("`@96QE;65N="!I<R!N;W0@<')E<V5N="!I;B!T:&4@
M9&%T82!B;&]C:RP@:70@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@;&EK
M97=I<V4@;F]T(&)E('-E="!I;B!T:&4@87)R87DN"B`@("`@*B`\<')E/@H@
M("`@("H@07)R87D@1F]R;6%T.@H@("`@("H@+2TM+2TM+2TM+2TM+0H@("`@
M("H@6W!U8FQI8U]K97E=+UMS96-R971?:V5Y72`]/B!!<G)A>0H@("`@("H@
M("`H"B`@("`@*B`@("`@6V-R96%T961=(#T^($ME>2!C<F5A=&EO;B`M(%5.
M25@@=&EM97-T86UP"B`@("`@*B`@("`@6V5X<&ER97-=(#T^($ME>2!E>'!I
M<F%T:6]N("T@54Y)6"!T:6UE<W1A;7`@*#`@/2!N979E<B!E>'!I<F5S*0H@
M("`@("H@("`@(%MS:7IE72`@("`]/B!3:7IE(&]F('1H92!K97D@:6X@8FET
M<PH@("`@("H@("`I"B`@("`@*@H@("`@("H@6V9I;F=E<G!R:6YT72`]/B!&
M:6YG97)P<FEN="!O9B!T:&4@4$=0(&1A=&$@*&EF(&%V86EL86)L92D*("`@
M("`J("`@("`@("`@("`@("`@("`@,38M8FET(&AE>"!V86QU90H@("`@("H*
M("`@("`J(%MS:6=N871U<F5=(#T^($%R<F%Y("@*("`@("`J("`@("!;:61[
M;GTO)U]324=.05154D4G72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("`@(%MN
M86UE72`@("`@("`@/3X@1G5L;"!.86UE"B`@("`@*B`@("`@("`@(%MC;VUM
M96YT72`@("`@/3X@0V]M;65N=`H@("`@("H@("`@("`@("!;96UA:6Q=("`@
M("`@(#T^($4M;6%I;"!!9&1R97-S"B`@("`@*B`@("`@("`@(%MF:6YG97)P
M<FEN=%T@/3X@,38M8FET(&AE>"!V86QU90H@("`@("H@("`@("`@("!;8W)E
M871E9%T@("`@(#T^(%-I9VYA='5R92!C<F5A=&EO;B`M(%5.25@@=&EM97-T
M86UP"B`@("`@*B`@("`@("`@(%MM:6-A;&==("`@("`@/3X@5&AE(&AA<V@@
M=7-E9"!T;R!C<F5A=&4@=&AE('-I9VYA='5R90H@("`@("H@("`@("`@("!;
M<VEG7WMH97A]72`@(#T^($%R<F%Y(%MD971A:6QS(&]F(&$@<VEG('9E<FEF
M>6EN9R!T:&4@241=("@*("`@("`J("`@("`@("`@("`@(%MC<F5A=&5D72`@
M("`@/3X@4VEG;F%T=7)E(&-R96%T:6]N("T@54Y)6"!T:6UE<W1A;7`*("`@
M("`J("`@("`@("`@("`@(%MF:6YG97)P<FEN=%T@/3X@,38M8FET(&AE>"!V
M86QU90H@("`@("H@("`@("`@("`@("`@6VUI8V%L9UT@("`@("`]/B!4:&4@
M:&%S:"!U<V5D('1O(&-R96%T92!T:&4@<VEG;F%T=7)E"B`@("`@*B`@("`@
M("`@("D*("`@("`J("`@("`I"B`@("`@*B`I"B`@("`@*B`\+W!R93X*("`@
M("`J"B`@("`@*B!%86-H('5S97(@240@=VEL;"!B92!S=&]R960@:6X@=&AE
M(&%R<F%Y("=S:6=N871U<F4G(&%N9"!H879E(&1A=&$*("`@("`J(&%S<V]C
M:6%T960@=VET:"!I="P@:6YC;'5D:6YG(&%N(&%R<F%Y(&9O<B!I;F9O<FUA
M=&EO;B!O;B!E86-H"B`@("`@*B!S:6=N871U<F4@=&AA="!H87,@<VEG;F5D
M('1H870@54E$+B!3:6=N871U<F5S(&YO="!A<W-O8VEA=&5D('=I=&@@80H@
M("`@("H@54E$("AE+F<N(')E=F]C871I;VX@<VEG;F%T=7)E<R!A;F0@<W5B
M(&ME>7,I('=I;&P@8F4@<W1O<F5D('5N9&5R('1H90H@("`@("H@<W!E8VEA
M;"!K97EW;W)D("=?4TE'3D%455)%)RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<&=P4&%C:V5T26YF;W)M871I;VXH)'!G<&1A=&$I"B`@("!["B`@("`@("`@
M)&1A=&%?87)R87D@/2!A<G)A>2@I.PH@("`@("`@("1F:6YG97)P<FEN="`]
M("<G.PH@("`@("`@("1H96%D97(@/2!N=6QL.PH@("`@("`@("1I;G!U="`]
M("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@
M("1S:6=?:60@/2`D=6ED7VED>"`](#`["@H@("`@("`@("\J(%-T;W)E(&UE
M<W-A9V4@:6X@=&5M<&]R87)Y(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P
M96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1P9W!D871A
M*3L*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@)&-M9&QI;F4@/2!A
M<G)A>2@*("`@("`@("`@("`@)RTM;&ES="UP86-K971S)RP*("`@("`@("`@
M("`@)&EN<'5T"B`@("`@("`@*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]C86QL1W!G*"1C;61L:6YE+"`G<B<I.PH*("`@("`@("!F;W)E86-H("AE
M>'!L;V1E*")<;B(L("1R97-U;'0M/G-T9&]U="D@87,@)&QI;F4I('L*("`@
M("`@("`@("`@+RH@2&5A9&5R<R!A<F4@<')E9F%C960@=VET:"!A("<Z)R!A
M<R!T:&4@9FER<W0@8VAA<F%C=&5R(&]N('1H90H@("`@("`@("`@("`@("!L
M:6YE+B`J+PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1L:6YE+"`G.B<I(#T]
M/2`P*2!["B`@("`@("`@("`@("`@("`D;&]W97),:6YE(#T@4W1R:6YG.CIL
M;W=E<B@D;&EN92D["@H@("`@("`@("`@("`@("`@+RH@268@=V4@:&%V92!A
M(&ME>2`H<F%T:&5R('1H86X@82!S:6=N871U<F4@8FQO8VLI+"!G970@=&AE
M"B`@("`@("`@("`@("`@("`@("!K97DG<R!F:6YG97)P<FEN="`J+PH@("`@
M("`@("`@("`@("`@:68@*'-T<G!O<R@D;&]W97),:6YE+"`G.G!U8FQI8R!K
M97D@<&%C:V5T.B<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@("`@
M('-T<G!O<R@D;&]W97),:6YE+"`G.G-E8W)E="!K97D@<&%C:V5T.B<I("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1C;61L:6YE(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("<M+7=I=&@M8V]L;VYS)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN<'5T"B`@("`@("`@("`@("`@
M("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`D9&%T82`]("1T:&ES+3Y?
M8V%L;$=P9R@D8VUD;&EN92P@)W(G*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@B+RAS96-\<'5B*3HN*CHN*CHN*CHH6T$M1C`M.5U[
M,39]*3HO(BP@)&1A=&$M/G-T9&]U="P@)&UA=&-H97,I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1F:6YG97)P<FEN="`]("1M871C:&5S6S)=.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("!I9B`H<W1R<&]S*"1L;W=E<DQI;F4L("<Z<'5B;&EC(&ME
M>2!P86-K970Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@
M)&AE861E<B`]("=P=6)L:6-?:V5Y)SL*("`@("`@("`@("`@("`@('T@96QS
M96EF("AS=')P;W,H)&QO=V5R3&EN92P@)SIS96-R970@:V5Y('!A8VME=#HG
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R(#T@
M)W-E8W)E=%]K97DG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O
M<R@D;&]W97),:6YE+"`G.G5S97(@:60@<&%C:V5T.B<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@("`@("1U:61?:61X*RL["B`@("`@("`@("`@
M("`@("`@("`@)&QI;F4@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH)R]<7%Q<
M>"A;,"TY82UF77LR?2DO)RP@8W)E871E7V9U;F-T:6]N*"<D82<L("=R971U
M<FX@8VAR*&AE>&1E8R@D85LQ72DI.R<I+"`D;&EN92D["B`@("`@("`@("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]<(BA;7EP\72LI7#PH6UY</ETK
M*5P^7"(O(BP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:&5A9&5R(#T@)VED)R`N("1U:61?:61X.PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;7EPH72LI7"@H+BLI
M7"DD+R<L('1R:6TH)&UA=&-H97-;,5TI+"`D8V]M;65N=%]M871C:&5S*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;)W-I
M9VYA='5R92==6R1H96%D97)=6R=N86UE)UT@/2!T<FEM*"1C;VUM96YT7VUA
M=&-H97-;,5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?
M87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=C;VUM96YT)UT@/2`D8V]M
M;65N=%]M871C:&5S6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;
M)W-I9VYA='5R92==6R1H96%D97)=6R=N86UE)UT@/2!T<FEM*"1M871C:&5S
M6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y
M6R=S:6=N871U<F4G75LD:&5A9&5R75LG8V]M;65N="==(#T@)R<["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=E;6%I;"==(#T@
M)&UA=&-H97-;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R
M<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG9FEN9V5R<')I;G0G72`]("1F
M:6YG97)P<FEN=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H<W1R<&]S*"1L;W=E<DQI;F4L("<Z<VEG;F%T=7)E
M('!A8VME=#HG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&AE861E<BD@?'P@96UP='DH)'5I9%]I9'@I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1H96%D97(@/2`G7U-)1TY!5%5212<["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"(O:V5Y:61<<RLH6S`M.4$M1ETK*2]I(BP@)&QI;F4L("1M
M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<VEG7VED(#T@
M)&UA=&-H97-;,5T["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R
M<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG<VEG7R<@+B`D<VEG7VED75LG
M9FEN9V5R<')I;G0G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%T85]A<G)A>5LG9FEN9V5R<')I;G0G72`]("1M871C:&5S
M6S%=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AE861E<B`](&YU;&P["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H*"1H96%D97(@/3T@)W-E8W)E=%]K97DG*2!\?"`H)&AE
M861E<B`]/2`G<'5B;&EC7VME>2<I*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H(B]C<F5A=&5D7',K*%QD*RDL7',K97AP:7)E<UQS
M*RA<9"LI+VDB+"`D;&EN92P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1D871A7V%R<F%Y6R1H96%D97)=6R=C<F5A=&5D)UT@/2`D
M;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R
M87E;)&AE861E<EU;)V5X<&ER97,G72`]("1M871C:&5S6S)=.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O7',K6W-P76ME
M>5Q;,%Q=.EQS*UQ;*%QD*RDO:2(L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;)&AE861E<EU;)W-I
M>F4G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D:&5A9&5R*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]V97)S:6]N7',K7&0K+%QS*V-R
M96%T961<<RLH7&0K*2]I(BP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG<VEG;F%T=7)E)UU;)&AE
M861E<EU;)W-I9U\G("X@)'-I9U]I9%U;)V-R96%T960G72`]("1M871C:&5S
M6S%=.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H
M*"(O9&EG97-T(&%L9V]<<RLH7&1[,7TI+R(L("1L:6YE+"`D;6%T8VAE<RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UI8V%L9R`]("1T:&ES+3Y?
M:&%S:$%L9ULD;6%T8VAE<ULQ75T["B`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG<VEG7R<@+B`D
M<VEG7VED75LG;6EC86QG)UT@/2`D;6EC86QG.PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&AE861E<B`]/2`G7U-)1TY!5%5212<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\J($QI:V5L>2!A('-I9VYA='5R92!B
M;&]C:RP@;F]T(&$@:V5Y+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&%?87)R87E;)W-I9VYA='5R92==6R=?4TE'3D%455)%)UU;)VUI
M8V%L9R==(#T@)&UI8V%L9SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-I9U]I9"`]/2`D9FEN9V5R
M<')I;G0I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\J(%-E;&8@
M<VEG;FEN9R!S:6=N871U<F4@+2!W92!C86X@87-S=6UE('1H90H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;6EC86QG('9A;'5E(&9R;VT@=&AI
M<R!S:6=N871U<F4@:7,@=&AA="!F;W(*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!K97D@*B\*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LG7U-)1TY!5%5212==6R=M
M:6-A;&<G72`]("1M:6-A;&<["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&%T85]A<G)A>5LG<VEG;F%T=7)E)UU;)&AE861E<EU;)VUI8V%L9R==
M(#T@)&UI8V%L9SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&9I;F=E<G!R:6YT("8F("1D871A7V%R
M<F%Y6R=F:6YG97)P<FEN="==(#T@)&9I;F=E<G!R:6YT.PH*("`@("`@("!R
M971U<FX@)&1A=&%?87)R87D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&AU;6%N(')E861A8FQE(&EN9F]R;6%T:6]N(&]N(&$@4$=0(&ME>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P9W!D871A("!4:&4@4$=0
M(&1A=&$@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1A
M8G5L87(@:6YF;W)M871I;VX@;VX@=&AE(%!'4"!K97DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!G<%!R971T>4ME>2@D<&=P9&%T82D*("`@('L*("`@("`@
M("`D;7-G(#T@)R<["B`@("`@("`@)'!A8VME=%]I;F9O(#T@)'1H:7,M/G!G
M<%!A8VME=$EN9F]R;6%T:6]N*"1P9W!D871A*3L*"B`@("`@("`@:68@*"%E
M;7!T>2@D<&%C:V5T7VEN9F];)W-I9VYA='5R92==*2D@>PH@("`@("`@("`@
M("`O*B!-86MI;F<@=&AE('!R;W!E<G1Y(&YA;65S('1H92!S86UE('=I9'1H
M(&9O<B!A;&P*("`@("`@("`@("`@("H@;&]C86QI>F%T:6]N<R`N*B\*("`@
M("`@("`@("`@)&QE9G1R;W<@/2!A<G)A>2A?*").86UE(BDL(%\H(DME>2!4
M>7!E(BDL(%\H(DME>2!#<F5A=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%\H(D5X<&ER871I;VX@1&%T92(I+"!?*")+97D@3&5N9W1H
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B0V]M;65N="(I
M+"!?*")%+4UA:6PB*2P@7R@B2&%S:"U!;&=O<FET:&TB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?*")+97D@1FEN9V5R<')I;G0B*2D["B`@
M("`@("`@("`@("1L969T=VED=&@@/2!A<G)A>5]M87`H)W-T<FQE;B<L("1L
M969T<F]W*3L*("`@("`@("`@("`@)&UA>'=I9'1H("`](&UA>"@D;&5F='=I
M9'1H*2`K(#(["B`@("`@("`@("`@(&%R<F%Y7W=A;&LH)&QE9G1R;W<L(&-R
M96%T95]F=6YC=&EO;B@G)B1S+"`D:RP@)&TG+"`G)',@/2`D<R`N("(Z(B`N
M('-T<E]R97!E870H(B`B+"`D;2`M(%-T<FEN9SHZ;&5N9W1H*"1S*2D[)RDL
M("1M87AW:61T:"D["@H@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES
M*"1P86-K971?:6YF;ULG<VEG;F%T=7)E)UTI(&%S("1U:61?:61X*2!["B`@
M("`@("`@("`@("`@("!I9B`H)'5I9%]I9'@@/3T@)U]324=.05154D4G*2!C
M;VYT:6YU93L*("`@("`@("`@("`@("`@("1K97E?:6YF;R`]("1T:&ES+3YP
M9W!086-K9713:6=N871U<F5">55I9$EN9&5X*"1P9W!D871A+"`D=6ED7VED
M>"D["B`@("`@("`@("`@("`@("`D;7-G("X]("1L969T<F]W6S!=("X@<W1R
M:7!C<VQA<VAE<R@D:V5Y7VEN9F];)VYA;64G72D@+B`B7&XB.PH@("`@("`@
M("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULQ72`N("@H)&ME>5]I;F9O6R=K
M97E?='EP92==(#T]("=P=6)L:6-?:V5Y)RD@/R!?*")0=6)L:6,@2V5Y(BD@
M.B!?*")0<FEV871E($ME>2(I*2`N(")<;B(["B`@("`@("`@("`@("`@("`D
M;7-G("X]("1L969T<F]W6S)=("X@<W1R9G1I;64H(B5$(BP@)&ME>5]I;F9O
M6R=K97E?8W)E871E9"==*2`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G
M("X]("1L969T<F]W6S-=("X@*&5M<'1Y*"1K97E?:6YF;ULG:V5Y7V5X<&ER
M97,G72D@/R`G6R<@+B!?*").979E<B(I("X@)UTG(#H@<W1R9G1I;64H(B5$
M(BP@)&ME>5]I;F9O6R=K97E?97AP:7)E<R==*2D@+B`B7&XB.PH@("`@("`@
M("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULT72`N("1K97E?:6YF;ULG:V5Y
M7W-I>F4G72`N("(@0GET97-<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]
M("1L969T<F]W6S5=("X@*&5M<'1Y*"1K97E?:6YF;ULG8V]M;65N="==*2`_
M("=;)R`N(%\H(DYO;F4B*2`N("==)R`Z("1K97E?:6YF;ULG8V]M;65N="==
M*2`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]("1L969T<F]W6S9=
M("X@)&ME>5]I;F9O6R=E;6%I;"==("X@(EQN(CL*("`@("`@("`@("`@("`@
M("1M<V<@+CT@)&QE9G1R;W=;-UT@+B`H96UP='DH)&ME>5]I;F9O6R=M:6-A
M;&<G72D@/R`G6R<@+B!?*")5;FMN;W=N(BD@+B`G72<@.B`D:V5Y7VEN9F];
M)VUI8V%L9R==*2`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]("1L
M969T<F]W6SA=("X@*&5M<'1Y*"1K97E?:6YF;ULG9FEN9V5R<')I;G0G72D@
M/R`G6R<@+B!?*")5;FMN;W=N(BD@+B`G72<@.B`D:V5Y7VEN9F];)V9I;F=E
M<G!R:6YT)UTI("X@(EQN7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@;VYL>2!I;F9O<FUA=&EO;B!O;B!T:&4@9FER<W0@240@=&AA="!M
M871C:&5S('1H92!E;6%I;"!A9&1R97-S"B`@("`@*B!I;G!U="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P9W!D871A("!4:&4@4$=0(&1A=&$@
M8FQO8VLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;6%I;"`@("!!;B!E+6UA
M:6P@861D<F5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<G)A>2!W:71H(&EN9F]R;6%T:6]N(&]N('1H92!01U`@9&%T82!B;&]C:RX@
M268@86X*("`@("`J("`@("`@("`@("`@("`@(&5L96UE;G0@:7,@;F]T('!R
M97-E;G0@:6X@=&AE(&1A=&$@8FQO8VLL(&ET('=I;&P*("`@("`J("`@("`@
M("`@("`@("`@(&QI:V5W:7-E(&YO="!B92!S970@:6X@=&AE(&%R<F%Y+@H@
M("`@("H@/'!R93X*("`@("`J($%R<F%Y($9I96QD<SH*("`@("`J("TM+2TM
M+2TM+2TM+2T*("`@("`J(&ME>5]C<F5A=&5D("`]/B`@2V5Y(&-R96%T:6]N
M("T@54Y)6"!T:6UE<W1A;7`*("`@("`J(&ME>5]E>'!I<F5S("`]/B`@2V5Y
M(&5X<&ER871I;VX@+2!53DE8('1I;65S=&%M<"`H,"`](&YE=F5R(&5X<&ER
M97,I"B`@("`@*B!K97E?<VEZ92`@("`@/3X@(%-I>F4@;V8@=&AE(&ME>2!I
M;B!B:71S"B`@("`@*B!K97E?='EP92`@("`@/3X@(%1H92!K97D@='EP92`H
M<'5B;&EC7VME>2!O<B!S96-R971?:V5Y*0H@("`@("H@;F%M92`@("`@("`@
M(#T^("!&=6QL($YA;64*("`@("`J(&-O;6UE;G0@("`@("`]/B`@0V]M;65N
M=`H@("`@("H@96UA:6P@("`@("`@(#T^("!%+6UA:6P@061D<F5S<PH@("`@
M("H@9FEN9V5R<')I;G0@(#T^("`Q-BUB:70@:&5X('9A;'5E"B`@("`@*B!C
M<F5A=&5D("`@("`@/3X@(%-I9VYA='5R92!C<F5A=&EO;B`M(%5.25@@=&EM
M97-T86UP"B`@("`@*B!M:6-A;&<@("`@("`@/3X@(%1H92!H87-H('5S960@
M=&\@8W)E871E('1H92!S:6=N871U<F4*("`@("`J(#PO<')E/@H@("`@("HO
M"B`@("!F=6YC=&EO;B!P9W!086-K9713:6=N871U<F4H)'!G<&1A=&$L("1E
M;6%I;"D*("`@('L*("`@("`@("`D9&%T82`]("1T:&ES+3YP9W!086-K971)
M;F9O<FUA=&EO;B@D<&=P9&%T82D["B`@("`@("`@)&ME>5]T>7!E(#T@;G5L
M;#L*("`@("`@("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@
M+RH@0VAE8VL@=&AA="!;<VEG;F%T=7)E72!K97D@97AI<W1S+B`J+PH@("`@
M("`@(&EF("@A:7-S970H)&1A=&%;)W-I9VYA='5R92==*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@("`@("!]"@H@("`@("`@
M("\J(%-T;W)E('1H92!S:6=N871U<F4@:6YF;W)M871I;VX@;F]W+B`J+PH@
M("`@("`@(&EF("@H)&5M86EL(#T]("=?4TE'3D%455)%)RD@)B8*("`@("`@
M("`@("`@:7-S970H)&1A=&%;)W-I9VYA='5R92==6R=?4TE'3D%455)%)UTI
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=S:6=N871U<F4G75LD
M96UA:6Q=(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D
M<F5T=7)N7V%R<F%Y6R1K97E=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5I9%]I9'@@/2`Q.PH*("`@
M("`@("`@("`@=VAI;&4@*&ES<V5T*"1D871A6R=S:6=N871U<F4G75LG:60G
M("X@)'5I9%]I9'A=*2D@>PH@("`@("`@("`@("`@("`@:68@*"1D871A6R=S
M:6=N871U<F4G75LG:60G("X@)'5I9%]I9'A=6R=E;6%I;"==(#T]("1E;6%I
M;"D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=S:6=N
M871U<F4G75LG:60G("X@)'5I9%]I9'A=(&%S("1K97D@/3X@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6R1K97E=(#T@
M)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=6ED7VED>"LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/E]P9W!086-K9713:6=N871U<F4H)&1A=&$L("1R971U
M<FY?87)R87DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O
M<FUA=&EO;B!O;B!A(%!'4"!S:6=N871U<F4@96UB961D960@:6X@4$=0(&1A
M=&$N("!3:6UI;&%R"B`@("`@*B!T;R!P9W!086-K9713:6=N871U<F4H*2P@
M8G5T(')E='5R;G,@:6YF;W)M871I;VX@8GD@=6YI<75E(%5S97(@240*("`@
M("`J($EN9&5X("AF;W)M870@:61[;GT@=VAE<F4@;B!I<R!A;B!I;G1E9V5R
M(&]F(#$@;W(@9W)E871E<BDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&=P9&%T82`@(%-E92!P9W!086-K9713:6=N871U<F4H*2X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1U:61?:61X("!4:&4@54E$(&EN9&5X+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%-E92!P9W!086-K9713:6=N871U
M<F4H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<&=P4&%C:V5T4VEG;F%T=7)E
M0GE5:61);F1E>"@D<&=P9&%T82P@)'5I9%]I9'@I"B`@("!["B`@("`@("`@
M)&1A=&$@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH)'!G<&1A=&$I
M.PH@("`@("`@("1K97E?='EP92`](&YU;&P["B`@("`@("`@)')E='5R;E]A
M<G)A>2`](&%R<F%Y*"D["@H@("`@("`@("\J(%-E87)C:"!F;W(@=&AE(%5)
M1"!I;F1E>"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1D871A6R=S:6=N871U
M<F4G72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1D871A6R=S:6=N871U<F4G
M75LD=6ED7VED>%TI*2!["B`@("`@("`@("`@(')E='5R;B`D<F5T=7)N7V%R
M<F%Y.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE('-I9VYA='5R
M92!I;F9O<FUA=&EO;B!N;W<N("HO"B`@("`@("`@9F]R96%C:"`H)&1A=&%;
M)W-I9VYA='5R92==6R1U:61?:61X72!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6R1K97E=(#T@)'9A;'5E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&=P4&%C:V5T4VEG;F%T
M=7)E*"1D871A+"`D<F5T=7)N7V%R<F%Y*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9',@<V]M92!D871A('1O('1H92!P9W!086-K9713:6=N871U<F4J
M*"D@9G5N8W1I;VX@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D871A("`@("`@4V5E
M('!G<%!A8VME=%-I9VYA='5R92@I+@H@("`@("H@0'!A<F%M(&%R<F%Y("1R
M971A<G)A>2`@5&AE(')E='5R;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@<F5T=7)N(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&=P4&%C:V5T4VEG;F%T=7)E*"1D871A+"`D<F5T87)R87DI"B`@
M("!["B`@("`@("`@+RH@268@96UP='DL(')E='5R;B!N;W<N("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1R971A<G)A>2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1R971A<G)A>3L*("`@("`@("!]"@H@("`@("`@("1K97E?='EP92`](&YU
M;&P["@H@("`@("`@("\J(%-T;W)E(&%N>2!P=6)L:6,O<')I=F%T92!K97D@
M:6YF;W)M871I;VXN("HO"B`@("`@("`@:68@*&ES<V5T*"1D871A6R=P=6)L
M:6-?:V5Y)UTI*2!["B`@("`@("`@("`@("1K97E?='EP92`]("=P=6)L:6-?
M:V5Y)SL*("`@("`@("!](&5L<V5I9B`H:7-S970H)&1A=&%;)W-E8W)E=%]K
M97DG72DI('L*("`@("`@("`@("`@)&ME>5]T>7!E(#T@)W-E8W)E=%]K97DG
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1K97E?='EP92D@>PH@("`@("`@
M("`@("`D<F5T87)R87E;)VME>5]T>7!E)UT@/2`D:V5Y7W1Y<&4["B`@("`@
M("`@("`@(&EF("AI<W-E="@D9&%T85LD:V5Y7W1Y<&5=6R=C<F5A=&5D)UTI
M*2!["B`@("`@("`@("`@("`@("`D<F5T87)R87E;)VME>5]C<F5A=&5D)UT@
M/2`D9&%T85LD:V5Y7W1Y<&5=6R=C<F5A=&5D)UT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R1K97E?='EP95U;)V5X<&ER
M97,G72DI('L*("`@("`@("`@("`@("`@("1R971A<G)A>5LG:V5Y7V5X<&ER
M97,G72`]("1D871A6R1K97E?='EP95U;)V5X<&ER97,G73L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)&ME>5]T>7!E75LG
M<VEZ92==*2D@>PH@("`@("`@("`@("`@("`@)')E=&%R<F%Y6R=K97E?<VEZ
M92==(#T@)&1A=&%;)&ME>5]T>7!E75LG<VEZ92==.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E=&%R<F%Y.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VAO<G0@9FEN9V5R<')I;G0@
M*$ME>2!)1"D@;V8@=&AE(&ME>2!U<V5D('1O('-I9VX@82!B;&]C:PH@("`@
M("H@;V8@4$=0(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AE(%!'4"!S:6=N960@=&5X="!B;&]C:RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('-H;W)T(&9I;F=E<G!R:6YT(&]F('1H
M92!K97D@=7-E9"!T;R!S:6=N("1T97AT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9713:6=N97)S1FEN9V5R<')I;G0H)'1E>'0I"B`@("!["B`@("`@("`@
M)&9I;F=E<G!R:6YT(#T@;G5L;#L*"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M
M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD["@H@("`@("`@("1F<"`]
M(&9O<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G!U=',H)&9P+"`D=&5X
M="D["B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("1C;61L:6YE(#T@
M87)R87DH"B`@("`@("`@("`@("<M+79E<FEF>2<L"B`@("`@("`@("`@("1I
M;G!U="P*("`@("`@("`@("`@)S(^)C$G"B`@("`@("`@*3L*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G<B<I.PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O9W!G.EQS4VEG;F%T=7)E7'-M861E+BI)
M1%QS*RA;02U&,"TY77LX?2E<<RLO)RP@)')E<W5L="T^<W1D;W5T+"`D;6%T
M8VAE<RDI('L*("`@("`@("`@("`@)&9I;F=E<G!R:6YT(#T@)&UA=&-H97-;
M,5T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;F=E<G!R:6YT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5F5R:69Y(&$@<&%S<W!H<F%S92!F;W(@
M82!G:79E;B!P=6)L:6,O<')I=F%T92!K97EP86ER+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!U8FQI8U]K97D@("!4:&4@=7-E<B=S(%!'4"!P
M=6)L:6,@:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I=F%T95]K97D@
M(%1H92!U<V5R)W,@4$=0('!R:79A=&4@:V5Y+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%S<W!H<F%S92`@(%1H92!U<V5R)W,@<&%S<W!H<F%S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O;B!V
M86QI9"!P87-S<&AR87-E+"!F86QS92!O;B!I;G9A;&ED"B`@("`@*B`@("`@
M("`@("`@("`@("`@('!A<W-P:')A<V4L(&%N9"!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I9GE087-S<&AR87-E*"1P
M=6)L:6-?:V5Y+"`D<')I=F%T95]K97DL("1P87-S<&AR87-E*0H@("`@>PH@
M("`@("`@("\J($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@
M("`@("`D<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN
M96-T:6]N*"D["B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C
M:SL*("`@("`@("!]"@H@("`@("`@("\J($5N8W)Y<'0@82!T97-T(&UE<W-A
M9V4N("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YE;F-R>7!T*"=497-T
M)RP@87)R87DH)W1Y<&4G(#T^("=M97-S86=E)RP@)W!U8FME>2<@/3X@)'!U
M8FQI8U]K97DI*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\J(%1R>2!T;R!D96-R>7!T('1H92!M97-S86=E+B`J+PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^9&5C<GEP="@D<F5S=6QT+"!A<G)A
M>2@G='EP92<@/3X@)VUE<W-A9V4G+"`G<'5B:V5Y)R`]/B`D<'5B;&EC7VME
M>2P@)W!R:79K97DG(#T^("1P<FEV871E7VME>2P@)W!A<W-P:')A<V4G(#T^
M("1P87-S<&AR87-E*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!A<G-E<R!A(&UE<W-A9V4@:6YT;R!T97AT(&%N9"!01U`@8V]M<&]N
M96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@
M=&5X="!T;R!P87)S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!
M;B!A<G)A>2!W:71H('1H92!P87)S960@=&5X="P@<F5T=7)N960@:6X@8FQO
M8VMS(&]F"B`@("`@*B`@("`@("`@("`@("`@("!T97AT(&-O<G)E<W!O;F1I
M;F<@=&\@=&AE:7(@86-T=6%L(&]R9&5R+@H@("`@("H@/'!R93X*("`@("`J
M(%)E='5R;B!A<G)A>3H*("`@("`J($ME>2`@("`@("`@(%9A;'5E"B`@("`@
M*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM"B`@("`@*B`G='EP92<@(#T^("!4:&4@='EP92!O9B!D871A(&-O
M;G1A:6YE9"!I;B!B;&]C:RX*("`@("`J("`@("`@("`@("`@(%9A;&ED('1Y
M<&5S(&%R92!D969I;F5D(&%T('1H92!T;W`@;V8@=&AI<R!C;&%S<PH@("`@
M("H@("`@("`@("`@("`@*'1H92!01U!?05)-3U)?*B!C;VYS=&%N=',I+@H@
M("`@("H@)V1A=&$G("`]/B`@5&AE(&%C='5A;"!D871A(&9O<B!E86-H('-E
M8W1I;VXN"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R
M<V501U!$871A*"1T97AT*0H@("`@>PH@("`@("`@("1D871A(#T@87)R87DH
M*3L*"B`@("`@("`@)&)U9F9E<B`](&5X<&QO9&4H(EQN(BP@)'1E>'0I.PH*
M("`@("`@("`O*B!3970@)'1E;7!?87)R87D@=&\@8F4@;V8@='EP92!01U!?
M05)-3U)?5$585"X@*B\*("`@("`@("`D=&5M<%]A<G)A>2`](&%R<F%Y*"D[
M"B`@("`@("`@)'1E;7!?87)R87E;)W1Y<&4G72`](%!'4%]!4DU/4E]415A4
M.PH*("`@("`@("!F;W)E86-H("@D8G5F9F5R(&%S("1V86QU92D@>PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UXM+2TM+2A"14=)3GQ%3D0I(%!'
M4"`H6UXM72LI+2TM+2U<<RHD+R<L("1V86QU92P@)&UA=&-H97,I*2!["B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'1E;7!?87)R87E;)V1A=&$G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@)'1E;7!?87)R87D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!U;G-E="@D=&5M
M<%]A<G)A>2D["B`@("`@("`@("`@("`@("`D=&5M<%]A<G)A>2`](&%R<F%Y
M*"D["@H@("`@("`@("`@("`@("`@:68@*"1M871C:&5S6S%=(#T]/2`G0D5'
M24XG*2!["B`@("`@("`@("`@("`@("`@("`@)'1E;7!?87)R87E;)W1Y<&4G
M72`]("1T:&ES+3Y?87)M;W);)&UA=&-H97-;,EU=.PH@("`@("`@("`@("`@
M("`@("`@("1T96UP7V%R<F%Y6R=D871A)UU;72`]("1V86QU93L*("`@("`@
M("`@("`@("`@('T@96QS96EF("@D;6%T8VAE<ULQ72`]/3T@)T5.1"<I('L*
M("`@("`@("`@("`@("`@("`@("`D=&5M<%]A<G)A>5LG='EP92==(#T@4$=0
M7T%234]27U1%6%0["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;8V]U;G0H
M)&1A=&$I("T@,5U;)V1A=&$G75M=(#T@)'9A;'5E.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1E
M;7!?87)R87E;)V1A=&$G75M=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1E;7!?87)R87E;)V1A=&$G
M72DI('L*("`@("`@("`@("`@)&1A=&%;72`]("1T96UP7V%R<F%Y.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(%!'4"!P=6)L:6,@:V5Y(&9R;VT@82!P=6)L:6,@
M:V5Y<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9P<FEN
M="`@5&AE(&9I;F=E<G!R:6YT(&]F('1H92!01U`@:V5Y+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5R=F5R("!4:&4@:V5Y<V5R=F5R('1O('5S92X*("`@
M("`J($!P87)A;2!F;&]A="`D=&EM96]U="`@5&AE(&ME>7-E<G9E<B!T:6UE
M;W5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@4$=0('!U
M8FQI8R!K97DL(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!U8FQI8TME>7-E<G9E<B@D9G!R:6YT+"`D<V5R=F5R
M(#T@4$=07TM%65-%4E9%4E]054),24,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1I;65O=70@/2!01U!?2T594T525D527U1)345/550I
M"B`@("!["B`@("`@("`@+RH@1V5T('1H92`X(&-H87)A8W1E<B!F:6YG97)P
M<FEN="!S=')I;F<N("HO"B`@("`@("`@:68@*'-T<G!O<R@D9G!R:6YT+"`G
M,'@G*2`]/3T@,"D@>PH@("`@("`@("`@("`D9G!R:6YT(#T@<W5B<W1R*"1F
M<')I;G0L(#(I.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R;&5N*"1F<')I
M;G0I(#X@."D@>PH@("`@("`@("`@("`D9G!R:6YT(#T@<W5B<W1R*"1F<')I
M;G0L(#@I.PH@("`@("`@('T*("`@("`@("`D9G!R:6YT(#T@)S!X)R`N("1F
M<')I;G0["@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N("HO"B`@("`@("`@)&-M9"`]("='150@+W!K<R]L;V]K=7`_;W`]
M9V5T)F5X86-T/6]N)G-E87)C:#TG("X@)&9P<FEN="`N("<@2%144"\Q+C`G
M.PH@("`@("`@("1O=71P=70@/2`D=&AI<RT^7V-O;FYE8W1+97ES97)V97(H
M)&-M9"P@)'-E<G9E<BP@)'1I;65O=70I.PH@("`@("`@(&EF("AI<U]A*"1O
M=71P=70L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O
M=71P=70["B`@("`@("`@?0H*("`@("`@("`O*B!3=')I<"!(5$U,(%1A9W,@
M9G)O;2!O=71P=70N("HO"B`@("`@("`@:68@*"@D<W1A<G0@/2!S=')S='(H
M)&]U='!U="P@)RTM+2TM0D5'24XG*2DI('L*("`@("`@("`@("`@)&QE;F=T
M:"`]('-T<G!O<R@D<W1A<G0L("<M+2TM+45.1"<I("L@,S0["B`@("`@("`@
M("`@(')E='5R;B!S=6)S='(H)'-T87)T+"`P+"`D;&5N9W1H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!396YD<R!A(%!'4"!P=6)L:6,@:V5Y('1O(&$@<'5B
M;&EC(&ME>7-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M=6)K97D@(%1H92!01U`@<'5B;&EC(&ME>0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<V5R=F5R("!4:&4@:V5Y<V5R=F5R('1O('5S92X*("`@("`J($!P87)A
M;2!F;&]A="`D=&EM96]U="`@5&AE(&ME>7-E<G9E<B!T:6UE;W5T+@H@("`@
M("H*("`@("`J($!R971U<FX@4$5!4E]%<G)O<B`@4$5!4E]%<G)O<B!O;B!E
M<G)O<B]F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P=710=6)L:6-+
M97ES97)V97(H)'!U8FME>2P@)'-E<G9E<B`](%!'4%]+15E315)615)?4%5"
M3$E#+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:6UE;W5T
M(#T@4$=07TM%65-%4E9%4E]424U%3U54*0H@("`@>PH@("`@("`@("\J($=E
M="!T:&4@9FEN9V5R<')I;G0@;V8@=&AE('!U8FQI8R!K97DN("HO"B`@("`@
M("`@)&EN9F\@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH)'!U8FME
M>2D["@H@("`@("`@("\J(%-E92!I9B!T:&4@<'5B;&EC(&ME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@:V5Y<V5R=F5R+B`J+PH@("`@("`@(&EF("@A:7-?
M82@D=&AI<RT^9V5T4'5B;&EC2V5Y<V5R=F5R*"1I;F9O6R=F:6YG97)P<FEN
M="==+"`D<V5R=F5R+"`D=&EM96]U="DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(I+"`G:&]R9&4N
M=V%R;FEN9R<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX@7V-O;FYE8W1+97ES97)V97(H*2!R971U
M<FYS(&$*("`@("`@("`@("!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<B!A
M;F0@=&AE(&]U='!U="!T97AT(&]N('-U8V-E<W,N("HO"B`@("`@("`@)'!U
M8FME>2`]("=K97ET97AT/2<@+B!U<FQE;F-O9&4H<G1R:6TH)'!U8FME>2DI
M.PH@("`@("`@("1C;60@/2!A<G)A>2@*("`@("`@("`@("`@)U!/4U0@+W!K
M<R]A9&0@2%144"\Q+C`G+`H@("`@("`@("`@("`G2&]S=#H@)R`N("1S97)V
M97(@+B`G.C$Q,S<Q)RP*("`@("`@("`@("`@)U5S97(M06=E;G0Z($AO<F1E
M($%P<&QI8V%T:6]N($9R86UE=V]R:R`S+C$G+`H@("`@("`@("`@("`G0V]N
M=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]X+7=W=RUF;W)M+75R;&5N8V]D960G
M+`H@("`@("`@("`@("`G0V]N=&5N="U,96YG=&@Z("<@+B!S=')L96XH)'!U
M8FME>2DL"B`@("`@("`@("`@("=#;VYN96-T:6]N.B!C;&]S92<L"B`@("`@
M("`@("`@("<G+`H@("`@("`@("`@("`D<'5B:V5Y"B`@("`@("`@*3L*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T2V5Y<V5R=F5R*&EM<&QO
M9&4H(EQR7&XB+"`D8VUD*2P@)'-E<G9E<BP@)'1I;65O=70I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N;F5C=',@=&\@82!P=6)L:6,@:V5Y('-E<G9E<B!V:6$@2$M0
M("A(;W)R;W=I='H@2V5Y<V5R=F5R(%!R;W1O8V]L*2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VUM86YD("!4:&4@4$=0(&-O;6UA;F0@=&\@<G5N+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5R=F5R("`@5&AE(&ME>7-E<G9E<B!T;R!U<V4N"B`@
M("`@*B!`<&%R86T@9FQO870@)'1I;65O=70@("!4:&4@=&EM96]U="!V86QU
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@9G)O
M;2!S=&%N9&%R9"!O=71P=70@;VX@<W5C8V5S<RP@;W(@4$5!4E]%<G)O<@H@
M("`@("H@("`@("`@("`@("`@("`@(&]N(&5R<F]R+V9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T2V5Y<V5R=F5R*"1C;VUM86YD+"`D
M<V5R=F5R+"`D=&EM96]U="D*("`@('L*("`@("`@("`D8V]N;E)E9G5S92`]
M(#`["B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`O*B!!='1E;7!T
M('1O(&=E="!T:&4@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX@*B\*("`@("`@
M("!D;R!["B`@("`@("`@("`@("1C;VYN17)R;W(@/2!F86QS93L*("`@("`@
M("`@("`@)&5R<FYO(#T@)&5R<G-T<B`](&YU;&P["@H@("`@("`@("`@("`O
M*B!4:&4@2$M0('-E<G9E<B!I<R!L;V-A=&5D(&]N('!O<G0@,3$S-S$N("HO
M"B`@("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH)'-E<G9E<BP@)S$Q,S<Q
M)RP@)&5R<FYO+"`D97)R<W1R+"`D=&EM96]U="D["B`@("`@("`@("`@(&EF
M("@A)&9P*2!["B`@("`@("`@("`@("`@("`D8V]N;D5R<F]R(#T@=')U93L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9P=71S*"1F
M<"P@)&-O;6UA;F0@+B`B7&Y<;B(I.PH@("`@("`@("`@("`@("`@=VAI;&4@
M*"%F96]F*"1F<"DI('L*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M(&9G971S*"1F<"P@,3`R-"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"1C;VYN17)R;W(I('L*("`@("`@("`@("`@("`@(&EF("@K*R1C
M;VYN4F5F=7-E(#T]/2!01U!?2T594T525D527U)%1E5312D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D97)R;F\@/3T@,"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T(#T@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@/2!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB*2P@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D97)R<W1R+"!.3%,Z.F=E=$5X=&5R;F%L0VAA<G-E="@I
M*2P@)&5R<FYO*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H)&-O;FY%<G)O
M<BD["@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@16YC<GEP=',@=&5X="!U<VEN9R!01U`N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E(%!'4"!E;F-R
M>7!T960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M
M971E<G,@;F5E9&5D(&9O<B!E;F-R>7!T:6]N+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(%-E92!T:&4@:6YD:79I9'5A;"!?96YC<GEP="HH*2!F
M=6YC=&EO;G,@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('!A<F%M971E<B!R97%U:7)E;65N=',N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!E;F-R>7!T960@;65S<V%G92P@;W(@4$5!4E]%<G)O
M<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP="@D=&5X
M="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1P87)A;7-;)W1Y<&4G72DI('L*("`@("`@("`@("`@:68@*"1P87)A;7-;
M)W1Y<&4G72`]/3T@)VUE<W-A9V4G*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]E;F-R>7!T365S<V%G92@D=&5X="P@)'!A<F%M<RD["B`@
M("`@("`@("`@('T@96QS96EF("@D<&%R86US6R=T>7!E)UT@/3T]("=S:6=N
M871U<F4G*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]E;F-R
M>7!T4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'1S('1E>'0@
M=7-I;F<@4$=0+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@
M("!4:&4@=&5X="!T;R!B92!01U`@9&5C<GEP=&5D+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@9&5C
M<GEP=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!3964@=&AE
M(&EN9&EV:61U86P@7V1E8W)Y<'0J*"D@9G5N8W1I;VYS(&9O<B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97(@<F5Q=6ER96UE
M;G1S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP
M=&5D(&UE<W-A9V4L(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1E8W)Y<'0H)'1E>'0L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=T>7!E)UTI*2![
M"B`@("`@("`@("`@(&EF("@D<&%R86US6R=T>7!E)UT@/3T]("=M97-S86=E
M)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&5C<GEP=$UE
M<W-A9V4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@("`@("!](&5L<V5I9B`H
M*"1P87)A;7-;)W1Y<&4G72`]/3T@)W-I9VYA='5R92<I('Q\"B`@("`@("`@
M("`@("`@("`@("`@("`H)'!A<F%M<ULG='EP92==(#T]/2`G9&5T86-H960M
M<VEG;F%T=7)E)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1E8W)Y<'13:6=N871U<F4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A
M('1E;7!O<F%R>2!G<&<@:V5Y<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4
M:&4@='EP92!O9B!K97D@=&\@86YA;'EZ92X@16ET:&5R("=P=6)L:6,G"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`H1&5F875L="D@;W(@)W!R:79A
M=&4G"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($-O;6UA;F0@;&EN
M92!K97ES=')I;F<@;W!T:6]N('1O('5S92!W:71H(&=P9R!P<F]G<F%M+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E2V5Y<FEN9R@D='EP92`]("=P
M=6)L:6,G*0H@("`@>PH@("`@("`@("1T>7!E(#T@4W1R:6YG.CIL;W=E<B@D
M='EP92D["@H@("`@("`@(&EF("@D='EP92`]/3T@)W!U8FQI8R<I('L*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<'5B;&EC2V5Y<FEN9RDI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<'5B;&EC2V5Y<FEN9R`]("1T:&ES
M+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B`G+2UK97ER:6YG("<@+B`D=&AI<RT^7W!U
M8FQI8TME>7)I;F<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]/2`G<')I
M=F%T92<I('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<')I=F%T
M94ME>7)I;F<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R:79A=&5+
M97ER:6YG(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("<M+7-E8W)E="UK
M97ER:6YG("<@+B`D=&AI<RT^7W!R:79A=&5+97ER:6YG.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@4$=0(&ME>7,@=&\@=&AE(&ME
M>7)I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1K97ES("`@02!S:6YG;&4@:V5Y(&]R(&%N
M(&%R<F%Y(&]F(&ME>2AS*2!T;R!A9&0@=&\@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!K97ER:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M='EP92`@5&AE('1Y<&4@;V8@:V5Y*',I('1O(&%D9"X@16ET:&5R("=P=6)L
M:6,G"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`H1&5F875L="D@;W(@
M)W!R:79A=&4G"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($-O;6UA
M;F0@;&EN92!K97ES=')I;F<@;W!T:6]N('1O('5S92!W:71H(&=P9R!P<F]G
M<F%M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<'5T26Y+97ER:6YG*"1K97ES
M(#T@87)R87DH*2P@)'1Y<&4@/2`G<'5B;&EC)RD*("`@('L*("`@("`@("`D
M='EP92`](%-T<FEN9SHZ;&]W97(H)'1Y<&4I.PH*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1K97ES*2D@>PH@("`@("`@("`@("`D:V5Y<R`](&%R<F%Y*"1K
M97ES*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T:&4@:V5Y<FEN
M9W,@:68@=&AE>2!D;VXG="!A;')E861Y(&5X:7-T+B`J+PH@("`@("`@("1K
M97ER:6YG(#T@)'1H:7,M/E]C<F5A=&5+97ER:6YG*"1T>7!E*3L*"B`@("`@
M("`@+RH@4W1O<F4@=&AE(&ME>2AS*2!I;B!T:&4@:V5Y<FEN9RX@*B\*("`@
M("`@("`D8VUD;&EN92`](&%R<F%Y*`H@("`@("`@("`@("`G+2UA;&QO=RUS
M96-R970M:V5Y+6EM<&]R="<L"B`@("`@("`@("`@("<M+69A<W0M:6UP;W)T
M)RP*("`@("`@("`@("`@)&ME>7)I;F<*("`@("`@("`I.PH@("`@("`@("1T
M:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W<G+"!A<G)A>5]V86QU97,H)&ME
M>7,I*3L*"B`@("`@("`@<F5T=7)N("1K97ER:6YG.PH@("`@?0H*("`@("\J
M*@H@("`@("H@16YC<GEP=',@82!M97-S86=E(&EN(%!'4"!F;W)M870@=7-I
M;F<@82!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X
M="!T;R!B92!E;F-R>7!T960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!E;F-R>7!T:6]N+@H@("`@
M("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]/3T]
M/0H@("`@("H@)W1Y<&4G("`@(#T^("`G;65S<V%G92<@*%)%455)4D5$*0H@
M("`@("H@)W!U8FME>2<@(#T^("!01U`@<'5B;&EC(&ME>2X@*$]P=&EO;F%L
M*2`H1$504D5#051%1"D*("`@("`J("=E;6%I;"<@("`]/B`@12UM86EL(&%D
M9')E<W,@;V8@<F5C:7!I96YT+B!)9B!N;W0@<')E<V5N="P@;W(@;F]T(&9O
M=6YD"B`@("`@*B`@("`@("`@("`@("`@(&EN('1H92!P=6)L:6,@:V5Y+"!T
M:&4@9FER<W0@92UM86EL(&%D9')E<W,@9F]U;F0@:6X@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@(&ME>2!W:6QL(&)E('5S960@:6YS=&5A9"X@*$]P=&EO
M;F%L*2`H1$504D5#051%1"D*("`@("`J("=R96-I<',G("`]/B`@06X@87)R
M87D@=VET:"!T:&4@92UM86EL(&%D9')E<W,@;V8@=&AE(')E8VEP:65N="!A
M<PH@("`@("H@("`@("`@("`@("`@("!T:&4@:V5Y(&%N9"!T:&%T('!E<G-O
M;B=S('!U8FQI8R!K97D@87,@=&AE('9A;'5E+@H@("`@("H@("`@("`@("`@
M("`@("`H4D5154E2140I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!M97-S86=E+"!O<B!014%2
M7T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP
M=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I"B`@("!["B`@("`@("`@)&5M86EL
M(#T@;G5L;#L*"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=R96-I<',G
M72DI('L*("`@("`@("`@("`@+RH@0VAE8VL@9F]R(')E<75I<F5D('!A<F%M
M971E<G,N("HO"B`@("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B
M:V5Y)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@1V5T(&EN9F]R;6%T:6]N(&]N('1H92!K97DN
M("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=E;6%I;"==*2D@
M>PH@("`@("`@("`@("`@("`@)&ME>5]I;F9O(#T@)'1H:7,M/G!G<%!A8VME
M=%-I9VYA='5R92@D<&%R86US6R=P=6)K97DG72P@)'!A<F%M<ULG96UA:6PG
M72D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1K97E?:6YF;RDI('L*
M("`@("`@("`@("`@("`@("`@("`D96UA:6P@/2`D:V5Y7VEN9F];)V5M86EL
M)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($EF('=E(&AA=F4@;F\@96UA:6P@861D<F5S<R!A="!T:&ES('!O
M:6YT+"!U<V4@=&AE(&9I<G-T(&5M86EL"B`@("`@("`@("`@("`@(&%D9')E
M<W,@9F]U;F0@:6X@=&AE('!U8FQI8R!K97DN("HO"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D96UA:6PI*2!["B`@("`@("`@("`@("`@("`D:V5Y7VEN9F\@
M/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH)'!A<F%M<ULG<'5B:V5Y
M)UTI.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1K97E?:6YF;ULG<VEG
M;F%T=7)E)UU;)VED,2==6R=E;6%I;"==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1E;6%I;"`]("1K97E?:6YF;ULG<VEG;F%T=7)E)UU;)VED,2==6R=E
M;6%I;"==.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1P87)A;7-;)W)E8VEP<R==(#T@87)R87DH)&5M
M86EL(#T^("1P87)A;7-;)W!U8FME>2==*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%-T;W)E('!U8FQI8R!K97D@:6X@=&5M<&]R87)Y(&ME>7)I;F<N("HO
M"B`@("`@("`@)&ME>7)I;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9RAA<G)A
M>5]V86QU97,H)'!A<F%M<ULG<F5C:7!S)UTI*3L*"B`@("`@("`@+RH@16YC
M<GEP="!T:&4@9&]C=6UE;G0N("HO"B`@("`@("`@)&-M9&QI;F4@/2!A<G)A
M>2@*("`@("`@("`@("`@)RTM87)M;W(G+`H@("`@("`@("`@("`G+2UB871C
M:"<L"B`@("`@("`@("`@("<M+6%L=V%Y<RUT<G5S="<L"B`@("`@("`@("`@
M("1K97ER:6YG+`H@("`@("`@("`@("`G+2UE;F-R>7!T)PH@("`@("`@("D[
M"B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<&%R86US6R=R96-I<',G
M72D@87,@)'9A;"D@>PH@("`@("`@("`@("`D8VUD;&EN95M=(#T@)RTM<F5C
M:7!I96YT("<@+B`D=F%L.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G=R<L("1T97AT+"!T<G5E+"!T
M<G5E*3L*("`@("`@("!I9B`H96UP='DH)')E<W5L="T^;W5T<'5T*2D@>PH@
M("`@("`@("`@("`D97)R;W(@/2!P<F5G7W)E<&QA8V4H)R]<;BXJ+R<L("<G
M+"`D<F5S=6QT+3YS=&1E<G(I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@
M(BD@+B`D97)R;W(L("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R97-U;'0M/F]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-I9VYS(&$@;65S<V%G92!I;B!01U`@9F]R;6%T('5S:6YG(&$@<')I
M=F%T92!K97DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E
M('-I9VYE9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R
M86UE=&5R<R!N965D960@9F]R('-I9VYI;F<N"B`@("`@*B`\<')E/@H@("`@
M("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]/3T]/3T]"B`@("`@*B`G='EP
M92<@("`@("`@(#T^("`G<VEG;F%T=7)E)R`H4D5154E2140I"B`@("`@*B`G
M<'5B:V5Y)R`@("`@(#T^("!01U`@<'5B;&EC(&ME>2X@*%)%455)4D5$*0H@
M("`@("H@)W!R:79K97DG("`@("`]/B`@4$=0('!R:79A=&4@:V5Y+B`H4D51
M54E2140I"B`@("`@*B`G<&%S<W!H<F%S92<@(#T^("!087-S<&AR87-E(&9O
M<B!01U`@2V5Y+B`H4D5154E2140I"B`@("`@*B`G<VEG='EP92<@("`@(#T^
M("!$971E<FUI;F4@=&AE('-I9VYA='5R92!T>7!E('1O('5S92X@*$]P=&EO
M;F%L*0H@("`@("H@("`@("`@("`@("`@("`@("`@)V-L96%R=&5X="<@("TM
M("!-86ME(&$@8VQE87(@=&5X="!S:6=N871U<F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("=D971A8V@G("`@("`M+2`@36%K92!A(&1E=&%C:&5D('-I
M9VYA='5R92`H1$5&055,5"D*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<VEG;F5D(&UE<W-A9V4L(&]R(%!%05)?
M17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E;F-R>7!T
M4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@("\J($-H
M96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D<V5C=7)E
M7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN96-T:6]N*"D["B`@
M("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C:SL*("`@("`@("!]
M"@H@("`@("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J
M+PH@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y)UTI('Q\"B`@
M("`@("`@("`@("%I<W-E="@D<&%R86US6R=P<FEV:V5Y)UTI('Q\"B`@("`@
M("`@("`@("%I<W-E="@D<&%R86US6R=P87-S<&AR87-E)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I
M;G!U="X@*B\*("`@("`@("`D:6YP=70@/2`D=&AI<RT^7V-R96%T951E;7!&
M:6QE*"=H;W)D92UP9W`G*3L*"B`@("`@("`@+RH@16YC<GEP=&EO;B!R97%U
M:7)E<R!B;W1H(&ME>7)I;F=S+B`J+PH@("`@("`@("1P=6)?:V5Y<FEN9R`]
M("1T:&ES+3Y?<'5T26Y+97ER:6YG*&%R<F%Y*"1P87)A;7-;)W!U8FME>2==
M*2D["B`@("`@("`@)'-E8U]K97ER:6YG(#T@)'1H:7,M/E]P=71);DME>7)I
M;F<H87)R87DH)'!A<F%M<ULG<')I=FME>2==*2P@)W!R:79A=&4G*3L*"B`@
M("`@("`@+RH@4W1O<F4@;65S<V%G92!I;B!T96UP;W)A<GD@9FEL92X@*B\*
M("`@("`@("`D9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P
M=71S*"1F<"P@)'1E>'0I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@
M("`O*B!$971E<FUI;F4@=&AE('-I9VYA='5R92!T>7!E('1O('5S92X@*B\*
M("`@("`@("`D8VUD;&EN92`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES<V5T
M*"1P87)A;7-;)W-I9W1Y<&4G72D@)B8*("`@("`@("`@("`@)'!A<F%M<ULG
M<VEG='EP92==(#T]("=C;&5A<G1E>'0G*2!["B`@("`@("`@("`@("1S:6=N
M7W1Y<&4@/2`G+2UC;&5A<G-I9VXG.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1S:6=N7W1Y<&4@/2`G+2UD971A8V@M<VEG;B<["B`@("`@("`@
M?0H*("`@("`@("`O*B!!9&1I=&EO;F%L($=01R!O<'1I;VYS+B`J+PH@("`@
M("`@("1C;61L:6YE("L](&%R<F%Y*`H@("`@("`@("`@("`G+2UA<FUO<B<L
M"B`@("`@("`@("`@("<M+6)A=&-H)RP*("`@("`@("`@("`@)RTM<&%S<W!H
M<F%S92UF9"`P)RP*("`@("`@("`@("`@)'-E8U]K97ER:6YG+`H@("`@("`@
M("`@("`D<'5B7VME>7)I;F<L"B`@("`@("`@("`@("1S:6=N7W1Y<&4L"B`@
M("`@("`@("`@("1I;G!U=`H@("`@("`@("D["@H@("`@("`@("\J(%-I9VX@
M=&AE(&1O8W5M96YT+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A
M;&Q'<&<H)&-M9&QI;F4L("=W)RP@)'!A<F%M<ULG<&%S<W!H<F%S92==+"!T
M<G5E+"!T<G5E*3L*("`@("`@("!I9B`H96UP='DH)')E<W5L="T^;W5T<'5T
M*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!P<F5G7W)E<&QA8V4H)R]<;BXJ
M+R<L("<G+"`D<F5S=6QT+3YS=&1E<G(I.PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@(BD@+B`D97)R;W(L("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT+3YO=71P=70["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP=',@86X@4$=0(&5N
M8W)Y<'1E9"!M97-S86=E('5S:6YG(&$@<')I=F%T92]P=6)L:6,@:V5Y<&%I
M<B!A;F0@80H@("`@("H@<&%S<VAP<F%S92X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("`@5&AE('1E>'0@=&\@8F4@9&5C<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@9&5C<GEP
M=&EO;BX*("`@("`J(#QP<F4^"B`@("`@*B!087)A;65T97)S.@H@("`@("H@
M/3T]/3T]/3T]/3T*("`@("`J("=T>7!E)R`@("`@("`@/3X@("=M97-S86=E
M)R`H4D5154E2140I"B`@("`@*B`G<'5B:V5Y)R`@("`@(#T^("!01U`@<'5B
M;&EC(&ME>2X@*%)%455)4D5$*0H@("`@("H@)W!R:79K97DG("`@("`]/B`@
M4$=0('!R:79A=&4@:V5Y+B`H4D5154E2140I"B`@("`@*B`G<&%S<W!H<F%S
M92<@(#T^("!087-S<&AR87-E(&9O<B!01U`@2V5Y+B`H4D5154E2140I"B`@
M("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L87-S("!!
M;B!O8FIE8W0@=VET:"!T:&4@9F]L;&]W:6YG('!R;W!E<G1I97,L(&]R(%!%
M05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@("`@(&]N(&5R<F]R.@H@
M("`@("H@/'!R93X*("`@("`J("=M97-S86=E)R`@("`@+2`@5&AE(&1E8W)Y
M<'1E9"!M97-S86=E+@H@("`@("H@)W-I9U]R97-U;'0G("`M("!4:&4@<F5S
M=6QT(&]F('1H92!S:6=N871U<F4@=&5S="X*("`@("`J(#PO<')E/@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9&5C<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A
M;7,I"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R('-E8W5R92!C;VYN96-T
M:6]N+B`J+PH@("`@("`@("1S96-U<F5?8VAE8VL@/2`D=&AI<RT^<F5Q=6ER
M95-E8W5R94-O;FYE8W1I;VXH*3L*("`@("`@("!I9B`H:7-?82@D<V5C=7)E
M7V-H96-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<V5C=7)E7V-H96-K.PH@("`@("`@('T*"B`@("`@("`@)&=O;V1?<VEG7V9L
M86<@/2!F86QS93L*"B`@("`@("`@+RH@0VAE8VL@9F]R(')E<75I<F5D('!A
M<F%M971E<G,N("HO"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=P=6)K
M97DG72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1P87)A;7-;)W!R:79K97DG
M72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1P87)A;7-;)W!A<W-P:')A<V4G
M72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1E
M;7`@9FEL97,N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&54
M96UP1FEL92@G:&]R9&4M<&=P)RD["@H@("`@("`@("\J($1E8W)Y<'1I;VX@
M<F5Q=6ER97,@8F]T:"!K97ER:6YG<RX@*B\*("`@("`@("`D<'5B7VME>7)I
M;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9RAA<G)A>2@D<&%R86US6R=P=6)K
M97DG72DI.PH@("`@("`@("1S96-?:V5Y<FEN9R`]("1T:&ES+3Y?<'5T26Y+
M97ER:6YG*&%R<F%Y*"1P87)A;7-;)W!R:79K97DG72DL("=P<FEV871E)RD[
M"@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@9FEL92X@*B\*("`@("`@
M("`D9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P=71S*"1F
M<"P@)'1E>'0I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`O*B!$
M96-R>7!T('1H92!D;V-U;65N="!N;W<N("HO"B`@("`@("`@)&-M9&QI;F4@
M/2!A<G)A>2@*("`@("`@("`@("`@)RTM86QW87ES+71R=7-T)RP*("`@("`@
M("`@("`@)RTM87)M;W(G+`H@("`@("`@("`@("`G+2UB871C:"<L"B`@("`@
M("`@("`@("<M+7!A<W-P:')A<V4M9F0@,"<L"B`@("`@("`@("`@("1S96-?
M:V5Y<FEN9RP*("`@("`@("`@("`@)'!U8E]K97ER:6YG+`H@("`@("`@("`@
M("`G+2UD96-R>7!T)RP*("`@("`@("`@("`@)&EN<'5T"B`@("`@("`@*3L*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G
M=R<L("1P87)A;7-;)W!A<W-P:')A<V4G72P@=')U92P@=')U92D["B`@("`@
M("`@:68@*&5M<'1Y*"1R97-U;'0M/F]U='!U="DI('L*("`@("`@("`@("`@
M)&5R<F]R(#T@<')E9U]R97!L86-E*"<O7&XN*B\G+"`G)RP@)')E<W5L="T^
M<W1D97)R*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(I("X@)&5R<F]R+"`G
M:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T
M:&4@<F5T=7)N(&]B:F5C="X@*B\*("`@("`@("`D;V(@/2`F;F5W('-T9$-L
M87-S.PH@("`@("`@("1O8BT^;65S<V%G92`]("1R97-U;'0M/F]U='!U=#L*
M"B`@("`@("`@+RH@0VAE8VL@=&AE(%!'4"!S:6=N871U<F4N("HO"B`@("`@
M("`@)'-I9U]C:&5C:R`]("1T:&ES+3Y?8VAE8VM3:6=N871U<F5297-U;'0H
M)')E<W5L="T^<W1D97)R*3L*("`@("`@("!I9B`H:7-?82@D<VEG7V-H96-K
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1O8BT^<VEG7W)E<W5L
M="`]("1S:6=?8VAE8VL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&]B+3YS:6=?<F5S=6QT(#T@*"1S:6=?8VAE8VLI(#\@)')E<W5L="T^<W1D
M97)R(#H@)R<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]B.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5C<GEP=',@86X@4$=0('-I9VYE9"!M97-S
M86=E('5S:6YG(&$@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@
M5&AE('1E>'0@=&\@8F4@=F5R:69I960N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!V97)I9FEC871I
M;VXN"B`@("`@*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J(#T]
M/3T]/3T]/3T]"B`@("`@*B`G='EP92<@("`@("`@/3X@("=S:6=N871U<F4G
M(&]R("=D971A8VAE9"US:6=N871U<F4G("A215%525)%1"D*("`@("`J("=P
M=6)K97DG("`@("`]/B`@4$=0('!U8FQI8R!K97DN("A215%525)%1"D*("`@
M("`J("=S:6=N871U<F4G("`]/B`@4$=0('-I9VYA='5R92!B;&]C:RX@*%)%
M455)4D5$(&9O<B!D971A8VAE9"!S:6=N871U<F4I"B`@("`@*B`\+W!R93X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('9E<FEF:6-A=&EO
M;B!M97-S86=E(&9R;VT@9W!G+B!)9B!N;R!S:6=N871U<F4L"B`@("`@*B`@
M("`@("`@("`@("`@("`@<F5T=7)N<R!E;7!T>2!S=')I;F<L(&%N9"!014%2
M7T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C<GEP
M=%-I9VYA='5R92@D=&5X="P@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#
M:&5C:R!F;W(@<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*("`@("`@("!I9B`H
M(6ES<V5T*"1P87)A;7-;)W!U8FME>2==*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(I+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("!]"B`@("`@("`@:68@*"@D<&%R86US6R=T>7!E
M)UT@/3T]("=D971A8VAE9"US:6=N871U<F4G*2`F)@H@("`@("`@("`@("`A
M:7-S970H)'!A<F%M<ULG<VEG;F%T=7)E)UTI*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@
M("`@)&=O;V1?<VEG7V9L86<@/2`P.PH*("`@("`@("`O*B!#<F5A=&4@=&5M
M<"!F:6QE<R!F;W(@:6YP=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M
M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD["@H@("`@("`@("\J(%-T
M;W)E('!U8FQI8R!K97D@:6X@=&5M<&]R87)Y(&ME>7)I;F<N("HO"B`@("`@
M("`@)&ME>7)I;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9R@D<&%R86US6R=P
M=6)K97DG72D["@H@("`@("`@("\J(%-T;W)E('1H92!M97-S86=E(&EN(&$@
M=&5M<&]R87)Y(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T
M+"`G=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1T97AT*3L*("`@("`@("!F
M8VQO<V4H)&9P*3L*"B`@("`@("`@+RH@3W!T:6]N<R!F;W(@=&AE($=01R!B
M:6YA<GDN("HO"B`@("`@("`@)&-M9&QI;F4@/2!A<G)A>2@*("`@("`@("`@
M("`@)RTM87)M;W(G+`H@("`@("`@("`@("`G+2UA;'=A>7,M=')U<W0G+`H@
M("`@("`@("`@("`G+2UB871C:"<L"B`@("`@("`@("`@("<M+6-H87)S970@
M)R`N($Y,4SHZ9V5T0VAA<G-E="@I+`H@("`@("`@("`@("`D:V5Y<FEN9RP*
M("`@("`@("`@("`@)RTM=F5R:69Y)PH@("`@("`@("D["@H@("`@("`@("\J
M($5X=')A('-T=69F('1O(&1O(&EF('=E(&%R92!U<VEN9R!A(&1E=&%C:&5D
M('-I9VYA='5R92X@*B\*("`@("`@("!I9B`H)'!A<F%M<ULG='EP92==(#T]
M/2`G9&5T86-H960M<VEG;F%T=7)E)RD@>PH@("`@("`@("`@("`D<VEG9FEL
M92`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@
M("`@("`@("`D8VUD;&EN95M=(#T@)'-I9V9I;&4@+B`G("<@+B`D:6YP=70[
M"@H@("`@("`@("`@("`D9G`@/2!F;W!E;B@D<VEG9FEL92P@)W<K)RD["B`@
M("`@("`@("`@(&9P=71S*"1F<"P@)'!A<F%M<ULG<VEG;F%T=7)E)UTI.PH@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8VUD;&EN95M=(#T@)&EN<'5T.PH@("`@("`@('T*("`@("`@
M("`D8VUD;&EN95M=(#T@)S(^)C$G.PH*("`@("`@("`O*B!697)I9GD@=&AE
M('-I9VYA='5R92X*("`@("`@("`@("!792!N965D('1O(&-A=&-H('-T86YD
M87)D(&5R<F]R(&]U='!U="P@<VEN8V4@=&AI<R!I<R!W:&5R90H@("`@("`@
M("`@('1H92!S:6=N871U<F4@:6YF;W)M871I;VX@:7,@<V5N="X@*B\*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G<B<I
M.PH@("`@("`@("1S:6=?<F5S=6QT(#T@)'1H:7,M/E]C:&5C:U-I9VYA='5R
M95)E<W5L="@D<F5S=6QT+3YS=&1O=70I.PH@("`@("`@(&EF("AI<U]A*"1S
M:6=?<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<VEG7W)E<W5L=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@*"1S:6=?<F5S=6QT*2`_("1R97-U;'0M/G-T9&]U="`Z("<G.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!S:6=N871U
M<F4@<F5S=6QT(&9R;VT@=&AE($=N=5!'(&)I;F%R>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1R97-U;'0@(%1H92!S:6=N871U<F4@<F5S=6QT+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!S:6=N871U<F4@:7,@9V]O9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K4VEG;F%T=7)E4F5S=6QT*"1R
M97-U;'0I"B`@("!["B`@("`@("`@+RH@1V]O9"!S:6=N871U<F4Z"B`@("`@
M("`@("H@("!G<&<Z($=O;V0@<VEG;F%T=7)E(&9R;VT@(F)L86@@8FQA:"!B
M;&%H("A#;VUM96YT*2(*("`@("`@("`@*B!"860@<VEG;F%T=7)E.@H@("`@
M("`@("`J("`@9W!G.B!"040@<VEG;F%T=7)E(&9R;VT@(F)L86@@8FQA:"!B
M;&%H("A#;VUM96YT*2(@*B\*("`@("`@("!I9B`H<W1R<&]S*"1R97-U;'0L
M("=G<&<Z($)!1"!S:6=N871U<F4G*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)')E<W5L="P@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D<F5S=6QT+"`G9W!G
M.B!';V]D('-I9VYA='5R92<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4VEG
M;G,@82!-24U%7U!A<G0@=7-I;F<@4$=0+@H@("`@("H*("`@("`J($!P87)A
M;2!-24U%7U!A<G0@)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@
M=&\@<VEG;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@
M5&AE('!A<F%M971E<G,@<F5Q=6ER960@9F]R('-I9VYI;F<N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($!S964@7V5N8W)Y<'13:6=N
M871U<F4H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-
M24U%7U!A<G0@;V)J96-T('1H870@:7,@<VEG;F5D(&%C8V]R9&EN9R!T;R!2
M1D,*("`@("`J("`@("`@("`@("`@("`@("`@("`R,#$U+S,Q-38L(&]R(%!%
M05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I9VY-
M24U%4&%R="@D;6EM95]P87)T+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I;F-L=61E7V]N8V4@)TAO<F1E+TU)344O4&%R="YP:'`G.PH*
M("`@("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)'!A<F%M<RP@87)R87DH
M)W1Y<&4G(#T^("=S:6=N871U<F4G+"`G<VEG='EP92<@/3X@)V1E=&%C:"<I
M*3L*"B`@("`@("`@+RH@4D9#(#(P,34@4F5Q=6ER96UE;G1S(&9O<B!A(%!'
M4"!S:6=N960@;65S<V%G93H*("`@("`@("`@*B`K($-O;G1E;G0M5'EP92!P
M87)A;7,@)VUI8V%L9R<@)B`G<')O=&]C;VPG(&%R92!215%525)%1"X*("`@
M("`@("`@*B`K(%1H92!D:6=I=&%L;'D@<VEG;F5D(&UE<W-A9V4@35535"!B
M92!C;VYS=')A:6YE9"!T;R`W(&)I=',N"B`@("`@("`@("H@*R!4:&4@34E-
M12!H96%D97)S($U54U0@8F4@82!P87)T(&]F('1H92!S:6=N960@9&%T82X@
M*B\*"B`@("`@("`@)&UI;65?<&%R="T^<W1R:6-T-V)I="AT<G5E*3L*("`@
M("`@("`D;7-G7W-I9VX@/2`D=&AI<RT^96YC<GEP="@D;6EM95]P87)T+3YT
M;T-A;F]N:6-A;%-T<FEN9R@I+"`D<&%R86US*3L*("`@("`@("!I9B`H:7-?
M82@D;7-G7W-I9VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1M<V=?<VEG;CL*("`@("`@("!]"@H@("`@("`@("\J($%D9"!T:&4@
M4$=0('-I9VYA='5R92X@*B\*("`@("`@("`D<&=P7W-I9VX@/2`F;F5W($U)
M345?4&%R="@G87!P;&EC871I;VXO<&=P+7-I9VYA='5R92<L("1M<V=?<VEG
M;BP@;G5L;"P@)VEN;&EN92<I.PH@("`@("`@("1P9W!?<VEG;BT^<V5T1&5S
M8W)I<'1I;VXH7R@B4$=0($1I9VET86P@4VEG;F%T=7)E(BDI.PH*("`@("`@
M("`O*B!'970@=&AE(&%L9V]R:71H:6T@:6YF;W)M871I;VX@9G)O;2!T:&4@
M<VEG;F%T=7)E+B!3:6YC92!W92!A<F4*("`@("`@("`@*B!A;F%L>7II;F<@
M82!S:6=N871U<F4@<&%C:V5T+"!W92!N965D('1O('5S92!T:&4@<W!E8VEA
M;"!K97EW;W)D"B`@("`@("`@("H@)U]324=.05154D4G("T@<V5E($AO<F1E
M7T-R>7!T7W!G<"X@*B\*("`@("`@("`D<VEG7VEN9F\@/2`D=&AI<RT^<&=P
M4&%C:V5T4VEG;F%T=7)E*"1M<V=?<VEG;BP@)U]324=.05154D4G*3L*"B`@
M("`@("`@+RH@4V5T=7`@=&AE(&UU;'1I<&%R="!-24U%(%!A<G0N("HO"B`@
M("`@("`@)'!A<G0@/2`F;F5W($U)345?4&%R="@G;75L=&EP87)T+W-I9VYE
M9"<I.PH@("`@("`@("1P87)T+3YS971#;VYT96YT<R@G5&AI<R!M97-S86=E
M(&ES(&EN($U)344@9F]R;6%T(&%N9"!H87,@8F5E;B!01U`@<VEG;F5D+B<@
M+B`B7&XB*3L*("`@("`@("`D<&%R="T^861D4&%R="@D;6EM95]P87)T*3L*
M("`@("`@("`D<&%R="T^861D4&%R="@D<&=P7W-I9VXI.PH@("`@("`@("1P
M87)T+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G<')O=&]C;VPG+"`G87!P
M;&EC871I;VXO<&=P+7-I9VYA='5R92<I.PH@("`@("`@("1P87)T+3YS971#
M;VYT96YT5'EP95!A<F%M971E<B@G;6EC86QG)RP@)'-I9U]I;F9O6R=M:6-A
M;&<G72D["@H@("`@("`@(')E='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($5N8W)Y<'1S(&$@34E-15]087)T('5S:6YG(%!'4"X*("`@("`J
M"B`@("`@*B!`<&%R86T@34E-15]087)T("1M:6UE7W!A<G0@(%1H92!-24U%
M7U!A<G0@;V)J96-T('1O(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@("`@("`@(%1H92!P87)A;65T97)S(')E<75I<F5D(&9O<B!E
M;F-R>7!T:6]N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@0'-E92!?96YC<GEP=$UE<W-A9V4H*2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T('1H870@:7,@96YC
M<GEP=&5D(&%C8V]R9&EN9R!T;R!21D,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`R,#$U+S,Q-38L(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'1-24U%4&%R="@D;6EM95]P87)T+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@
M)TAO<F1E+TU)344O4&%R="YP:'`G.PH*("`@("`@("`D<&%R86US(#T@87)R
M87E?;65R9V4H)'!A<F%M<RP@87)R87DH)W1Y<&4G(#T^("=M97-S86=E)RDI
M.PH*("`@("`@("`D<VEG;F5N8U]B;V1Y(#T@)&UI;65?<&%R="T^=&]#86YO
M;FEC86Q3=')I;F<H*3L*("`@("`@("`D;65S<V%G95]E;F-R>7!T(#T@)'1H
M:7,M/F5N8W)Y<'0H)'-I9VYE;F-?8F]D>2P@)'!A<F%M<RD["B`@("`@("`@
M:68@*&ES7V$H)&UE<W-A9V5?96YC<GEP="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&UE<W-A9V5?96YC<GEP=#L*("`@("`@("!]
M"@H@("`@("`@("\J(%-E="!U<"!-24U%(%-T<G5C='5R92!A8V-O<F1I;F<@
M=&\@4D9#(#(P,34N("HO"B`@("`@("`@)'!A<G0@/2`F;F5W($U)345?4&%R
M="@G;75L=&EP87)T+V5N8W)Y<'1E9"<I.PH@("`@("`@("1P87)T+3YS971#
M;VYT96YT<R@G5&AI<R!M97-S86=E(&ES(&EN($U)344@9F]R;6%T(&%N9"!H
M87,@8F5E;B!01U`@96YC<GEP=&5D+B<@+B`B7&XB*3L*("`@("`@("`D<&%R
M="T^861D4&%R="AN97<@34E-15]087)T*"=A<'!L:6-A=&EO;B]P9W`M96YC
M<GEP=&5D)RP@(E9E<G-I;VXZ(#%<;B(L(&YU;&PI*3L*("`@("`@("`D<&%R
M="T^861D4&%R="AN97<@34E-15]087)T*"=A<'!L:6-A=&EO;B]O8W1E="US
M=')E86TG+"`D;65S<V%G95]E;F-R>7!T+"!N=6QL+"`G:6YL:6YE)RDI.PH@
M("`@("`@("1P87)T+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G<')O=&]C
M;VPG+"`G87!P;&EC871I;VXO<&=P+65N8W)Y<'1E9"<I.PH@("`@("`@("1P
M87)T+3YS971$97-C<FEP=&EO;BA?*")01U`@16YC<GEP=&5D($1A=&$B*2D[
M"@H@("`@("`@(')E='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-I9VYS(&%N9"!E;F-R>7!T<R!A($U)345?4&%R="!U<VEN9R!01U`N"B`@
M("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T("`@5&AE
M($U)345?4&%R="!O8FIE8W0@=&\@<VEG;B!A;F0@96YC<GEP="X*("`@("`J
M($!P87)A;2!A<G)A>2`D<VEG;E]P87)A;7,@("`@(%1H92!P87)A;65T97)S
M(')E<75I<F5D(&9O<B!S:6=N:6YG+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@0'-E92!?96YC<GEP=%-I9VYA='5R92@I+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1E;F-R>7!T7W!A<F%M<R`@5&AE('!A<F%M971E
M<G,@<F5Q=6ER960@9F]R(&5N8W)Y<'1I;VXN"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!`<V5E(%]E;F-R>7!T365S<V%G92@I+@H@
M("`@("H*("`@("`J($!R971U<FX@34E-15]087)T("!!($U)345?4&%R="!O
M8FIE8W0@=&AA="!I<R!S:6=N960@86YD(&5N8W)Y<'1E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@(&%C8V]R9&EN9R!T;R!21D,@,C`Q-2\S,34V+"!O
M<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M:6=N06YD16YC<GEP=$U)345087)T*"1M:6UE7W!A<G0L("1S:6=N7W!A<F%M
M<R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E;F-R>7!T7W!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:6YC;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@("`@("`@
M+RH@4D9#(#(P,34@<F5Q=6ER97,@=&AA="!T:&4@96YT:7)E('-I9VYE9"!M
M97-S86=E(&)E(&5N8W)Y<'1E9"X@(%=E"B`@("`@("`@("H@;F5E9"!T;R!E
M>'!L:6-I=&QY(&-A;&P@=7-I;F<@2&]R9&5?0W)Y<'1?<&=P.CH@8F5C875S
M92!W92!D;VXG=`H@("`@("`@("`J(&MN;W<@=VAE=&AE<B!A('-U8F-L87-S
M(&AA<R!E>'1E;F1E9"!T:&5S92!M971H;V1S+B`J+PH@("`@("`@("1P87)T
M(#T@)'1H:7,M/G-I9VY-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A
M;7,I.PH@("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"B`@("`@("`@
M)'!A<G0@/2`D=&AI<RT^96YC<GEP=$U)345087)T*"1P87)T+"`D96YC<GEP
M=%]P87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"B`@
M("`@("`@)'!A<G0M/G-E=$-O;G1E;G1S*"=4:&ES(&UE<W-A9V4@:7,@:6X@
M34E-12!F;W)M870@86YD(&AA<R!B965N(%!'4"!S:6=N960@86YD(&5N8W)Y
M<'1E9"XG("X@(EQN(BD["B`@("`@("`@)'!A<G0M/G-E=$1E<V-R:7!T:6]N
M*%\H(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B*2D["@H@("`@("`@(')E
M='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A
M($U)345?4&%R="!O8FIE8W0L(&EN(&%C8V]R9&%N8V4@=VET:"!21D,@,C`Q
M-2\S,34V+"!T:&%T"B`@("`@*B!C;VYT86EN<R!A('!U8FQI8R!K97DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@<'5B;&EC(&ME
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A
M<G0@;V)J96-T('1H870@8V]N=&%I;G,@=&AE('!U8FQI8R!K97DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!U8FQI8TME>4U)345087)T*"1K97DI"B`@("![
M"B`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*
M"B`@("`@("`@)'!A<G0@/2`F;F5W($U)345?4&%R="@G87!P;&EC871I;VXO
M<&=P+6ME>7,G+"`D:V5Y+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@
M)'!A<G0M/G-E=$1E<V-R:7!T:6]N*%\H(E!'4"!0=6)L:6,@2V5Y(BDI.PH*
M("`@("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M=6YC=&EO;B!T:&%T(&AA;F1L97,@:6YT97)F86-I;F<@=VET:"!T:&4@1VYU
M4$<@8FEN87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@(%1/1$\*("`@("`J
M($!P87)A;2!S=')I;F<@)&UO9&4@("`@(%1/1$\*("`@("`J($!P87)A;2!A
M<G)A>2`D:6YP=70@("`@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1O
M=71P=70@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1S=&1E<G(@(%1/
M1$\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L87-S("!43T1/"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C86QL1W!G*"1O<'1I;VYS+"`D;6]D92P@)&EN
M<'5T(#T@87)R87DH*2P@)&]U='!U="`](&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@)'-T9&5R<B`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;61L
M:6YE(#T@87)R87E?;65R9V4H)'1H:7,M/E]G;G5P9RP@)&]P=&EO;G,I.PH@
M("`@("`@("1D871A(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`D9&%T82T^
M;W5T<'5T(#T@;G5L;#L*("`@("`@("`D9&%T82T^<W1D97)R(#T@;G5L;#L*
M("`@("`@("`D9&%T82T^<W1D;W5T(#T@;G5L;#L*"B`@("`@("`@+RH@0W)E
M871E('1E;7`@9FEL97,@9F]R(&]U='!U="X@*B\*("`@("`@("!I9B`H)&]U
M='!U="D@>PH@("`@("`@("`@("`D;W5T<'5T7V9I;&4@/2`D=&AI<RT^7V-R
M96%T951E;7!&:6QE*"=H;W)D92UP9W`G+"!F86QS92D["B`@("`@("`@("`@
M(&%R<F%Y7W5N<VAI9G0H)&]P=&EO;G,L("<M+6]U='!U="`G("X@)&]U='!U
M=%]F:6QE*3L*"B`@("`@("`@("`@("\J($1O('=E(&YE960@<W1A;F1A<F0@
M97)R;W(@;W5T<'5T/R`J+PH@("`@("`@("`@("!I9B`H)'-T9&5R<BD@>PH@
M("`@("`@("`@("`@("`@)'-T9&5R<E]F:6QE(#T@)'1H:7,M/E]C<F5A=&54
M96UP1FEL92@G:&]R9&4M<&=P)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M)&]P=&EO;G-;72`]("<R/B`G("X@)'-T9&5R<E]F:6QE.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!T:&4@8V]M;6%N9"!L
M:6YE('-T<FEN9R!N;W<N("HO"B`@("`@("`@)&-M9&QI;F4@/2!I;7!L;V1E
M*"<@)RP@87)R87E?;65R9V4H)'1H:7,M/E]G;G5P9RP@)&]P=&EO;G,I*3L*
M"B`@("`@("`@:68@*"1M;V1E(#T]("=W)RD@>PH@("`@("`@("`@("`D9G`@
M/2!P;W!E;B@D8VUD;&EN92P@)W<G*3L*("`@("`@("`@("`@)'=I;C,R(#T@
M<W5B<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<["@H@("`@("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1I;G!U="DI('L*("`@("`@("`@("`@("`@("1I;G!U
M="`](&%R<F%Y*"1I;G!U="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M9F]R96%C:"`H)&EN<'5T(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I
M9B`H)'=I;C,R("8F("AS=')P;W,H)&QI;F4L(")<>#!D7'@P82(I("$]/2!F
M86QS92DI('L*("`@("`@("`@("`@("`@("`@("`D8VAU;FMS(#T@97AP;&]D
M92@B7'@P9%QX,&$B+"`D;&EN92D["B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&-H=6YK<R!A<R`D8VAU;FLI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@9G!U=',H)&9P+"`D8VAU;FL@+B`B7&XB*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@(&9P=71S*"1F<"P@)&QI;F4@+B`B7&XB*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D;6]D
M92`]/2`G<B<I('L*("`@("`@("`@("`@)&9P(#T@<&]P96XH)&-M9&QI;F4L
M("=R)RD["B`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2!["B`@("`@
M("`@("`@("`@("`D9&%T82T^<W1D;W5T("X](&9G971S*"1F<"P@,3`R-"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F<"D[
M"@H@("`@("`@(&EF("@D;W5T<'5T*2!["B`@("`@("`@("`@("1D871A+3YO
M=71P=70@/2!F:6QE7V=E=%]C;VYT96YT<R@D;W5T<'5T7V9I;&4I.PH@("`@
M("`@("`@("!U;FQI;FLH)&]U='!U=%]F:6QE*3L*("`@("`@("`@("`@:68@
M*"1S=&1E<G(I('L*("`@("`@("`@("`@("`@("1D871A+3YS=&1E<G(@/2!F
M:6QE7V=E=%]C;VYT96YT<R@D<W1D97)R7V9I;&4I.PH@("`@("`@("`@("`@
M("`@=6YL:6YK*"1S=&1E<G)?9FEL92D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M0V]M<')E<W,O````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`R,#`Q,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$P-S0`,3`U,34T,S$P-C$`,#(Q,S`Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V]M<')E<W-?9&)X(&-L87-S(&%L;&]W
M<R!D8G@@9FEL97,@*&4N9RX@9G)O;2!/=71L;V]K($5X<')E<W,I"B`J('1O
M(&)E(')E860N"B`J"B`J(%1H:7,@8VQA<W,@:7,@8F%S960@;VX@8V]D92!B
M>3H*("H@06YT;VYY(%)A:6IE:V]V(#QD979`<W1R871E9VUA+F)G/@H@*B!H
M='1P.B\O=7)U9',N9V%T97=A>2YB9R]Z96]S+PH@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP+'8@,2XS+C$R+CD@
M,C`P-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S<U]D8G@@97AT
M96YD<R!(;W)D95]#;VUP<F5S<R!["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M86EL
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T;7`@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@1&5C;VUP<F5S<V5S(&$@1$)8(&9I;&4@86YD
M(&=E=',@:6YF;W)M871I;VX@9G)O;2!I="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A("!4:&4@9&)X(&9I;&4@9&%T82X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!;GD*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@<F5Q=65S=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E8V]M<')E<W,H)B1D871A+"`D<&%R86US(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7VUA:6QS(#T@87)R87DH*3L*("`@("`@("`D=&AI
M<RT^7W1M<"`](&%R<F%Y*"D["B`@("`@("`@)'!O<VET:6]N(#T@,'A#-#L*
M("`@("`@("`D:&5A9&5R7VEN9F\@/2!U;G!A8VLH)TQP;W-I=&EO;B],1&%T
M84QE;F=T:"]N2&5A9&5R3&5N9W1H+VY&;&%G0V]U;G0G+"!S=6)S='(H)&1A
M=&$L("1P;W-I=&EO;BP@,3(I*3L*("`@("`@("`D<&]S:71I;VX@*ST@,3([
M"B`@("`@("`@+R\@1V\@=&\@=&AE(&9I<G-T('1A8FQE(&]F9F5S="!A;F0@
M<')O8V5S<R!I="X*("`@("`@("!I9B`H)&AE861E<E]I;F9O6R=P;W-I=&EO
M;B==(#X@,"D@>PH@("`@("`@("`@("`D<&]S:71I;VX@/2`P>#,P.PH@("`@
M("`@("`@("`D8G5F(#T@=6YP86-K*"=,<&]S:71I;VXG+"!S=6)S='(H)&1A
M=&$L("1P;W-I=&EO;BP@-"DI.PH@("`@("`@("`@("`D<&]S:71I;VX@/2`D
M8G5F6R=P;W-I=&EO;B==.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]R96%D26YD97@H)&1A=&$L("1P;W-I=&EO;BD["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7VUA:6QS.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(&YU;&PM=&5R;6EN871E9"!S=')I;F<@9G)O;2!T
M:&4@<W!E8VEF:65D(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&)U9B`@5$]$3PH@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<R`@5$]$3PH@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R
M96%D4W1R:6YG*"8D8G5F+"`D<&]S*0H@("`@>PH@("`@("`@(&EF("@D;&5N
M(#T@<W1R<&]S*'-U8G-T<B@D8G5F+"`D<&]S*2P@8VAR*#`I*2D@>PH@("`@
M("`@("`@("!R971U<FX@<W5B<W1R*"1B=68L("1P;W,L("1L96XI.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@("`@("!43T1/"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<&]S:71I;VX@(%1/1$\*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5A
M9$UE<W-A9V4H)B1D871A+"`D<&]S:71I;VXI"B`@("!["B`@("`@("`@)&US
M9R`]("<G.PH@("`@("`@("1P87)T(#T@,#L*"B`@("`@("`@:68@*"1P;W-I
M=&EO;B`^(#`I('L*("`@("`@("`@("`@)$EN9&5X271E;7-#;W5N="`](&%R
M<F%Y7W!O<"AU;G!A8VLH)U,G+"!S=6)S='(H)&1A=&$L(#!X0S0L(#0I*2D[
M"B`@("`@("`@("`@(&EF("@D26YD97A)=&5M<T-O=6YT(#X@,"D@>PH@("`@
M("`@("`@("`@("`@=VAI;&4@*"1P;W-I=&EO;B`\('-T<FQE;B@D9&%T82DI
M('L*("`@("`@("`@("`@("`@("`@("`D<&%R="LK.PH@("`@("`@("`@("`@
M("`@("`@("1S(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL(#4R."D["B`@
M("`@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D<RD@/3T@,"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)&US9U]I=&5M(#T@=6YP86-K*"=,
M1FEL95!O<R],56YK;F]W;B],271E;5-I>F4O3$YE>'1)=&5M+V$U,3)#;VYT
M96YT)RP@)',I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D;7-G7VET96U;
M)T9I;&50;W,G72`A/2`D<&]S:71I;VXI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!F:6QE
M(&9O<FUA="(I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)'!O<VET:6]N("L](#4R.#L*("`@("`@("`@("`@("`@("`@
M("`D;7-G("X]('-U8G-T<B@D;7-G7VET96U;)T-O;G1E;G0G72P@,"P@)&US
M9U]I=&5M6R=)=&5M4VEZ92==*3L*("`@("`@("`@("`@("`@("`@("`D<&]S
M:71I;VX@/2`D;7-G7VET96U;)TYE>'1)=&5M)UT["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1P;W-I=&EO;B`]/2`P*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`F)&1A=&$@("`@("!43T1/"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<&]S:71I;VX@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4
M3T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96%D365S<V%G94EN9F\H)B1D
M871A+"`D<&]S:71I;VXI"B`@("!["B`@("`@("`@)&UE<W-A9V5?:6YF;R`]
M(&%R<F%Y*"D["B`@("`@("`@)&US9U]H96%D97(@/2!U;G!A8VLH)TQP;W-I
M=&EO;B],1&%T84QE;F=T:"]32&5A9&5R3&5N9W1H+U-&;&%G0V]U;G0G+"!S
M=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@,3(I*3L*("`@("`@("!I9B`H)&US
M9U]H96%D97);)W!O<VET:6]N)UT@(3T@)'!O<VET:6]N*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@9FEL92!F
M;W)M870B*2D["B`@("`@("`@?0H@("`@("`@("1P;W-I=&EO;B`K/2`Q,CL*
M("`@("`@("`D;65S<V%G95]I;F9O6R=(96%D97)0;W-I=&EO;B==(#T@)&US
M9U]H96%D97);)W!O<VET:6]N)UT["B`@("`@("`@)&9L86=S(#T@)&US9U]H
M96%D97);)T9L86=#;W5N="==("8@,'A&1CL*("`@("`@("`D1&%T85-I>F4@
M/2`D;7-G7VAE861E<ELG1&%T84QE;F=T:"==("T@)&9L86=S("H@-#L*("`@
M("`@("`D<VEZ92`](#0@*B`D9FQA9W,["B`@("`@("`@)$9L86=S0G5F9F5R
M(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL("1S:7IE*3L*("`@("`@("`D
M<&]S:71I;VX@*ST@)'-I>F4["B`@("`@("`@)'-I>F4@/2`D1&%T85-I>F4[
M"B`@("`@("`@)$1A=&%"=69F97(@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO
M;BP@)'-I>F4I.PH@("`@("`@("1P;W-I=&EO;B`K/2`D<VEZ93L*("`@("`@
M("`D;65S<V%G95]I;F9O(#T@87)R87DH*3L*"B`@("`@("`@)&9L86=?87)R
M87D@/2!A<G)A>2@*("`@("`@("`@("`@,'@Q(#T^("=-<V=&;&%G<R<L"B`@
M("`@("`@("`@(#!X,B`]/B`G4V5N="<L"B`@("`@("`@("`@(#!X-"`]/B`G
M<&]S:71I;VXG+`H@("`@("`@("`@("`P>#<@/3X@)TUE<W-A9V5)1"<L"B`@
M("`@("`@("`@(#!X."`]/B`G4W5B:F5C="<L"B`@("`@("`@("`@(#!X.2`]
M/B`G1G)O;5]R97!L>2<L"B`@("`@("`@("`@(#!X02`]/B`G4F5F97)E;F-E
M<R<L"B`@("`@("`@("`@(#!X0B`]/B`G3F5W<V=R;W5P)RP*("`@("`@("`@
M("`@,'A$(#T^("=&<F]M)RP*("`@("`@("`@("`@,'A%(#T^("=297!L>5]4
M;R<L"B`@("`@("`@("`@(#!X,3(@/3X@)U)E8V5I=F5D)RP*("`@("`@("`@
M("`@,'@Q,R`]/B`G4F5C96EP="<L"B`@("`@("`@("`@(#!X,4$@/3X@)T%C
M8V]U;G0G+`H@("`@("`@("`@("`P>#%"(#T^("=!8V-O=6YT240G+`H@("`@
M("`@("`@("`P>#@P(#T^("=-<V<G+`H@("`@("`@("`@("`P>#@Q(#T^("=-
M<V=&;&%G<R<L"B`@("`@("`@("`@(#!X.#0@/3X@)W!O<VET:6]N)RP*("`@
M("`@("`@("`@,'@Y,2`]/B`G<VEZ92<L"B`@("`@("`@*3L*"B`@("`@("`@
M+RH@4')O8V5S<R!F;&%G<R`J+PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1F;&%G<SL@)&DK*RD@>PH@("`@("`@("`@("`D<&]S(#T@,#L*("`@("`@
M("`@("`@)&8@/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@<W5B<W1R*"1&;&%G
M<T)U9F9E<BP@)&D@*B`T+"`T*2DI.PH*("`@("`@("`@("`@)&UA<VL@/2`D
M9B`F(#!X1D8["B`@("`@("`@("`@('-W:71C:"`H)&UA<VLI('L*("`@("`@
M("`@("`@8V%S92`P>#$Z"B`@("`@("`@("`@("`@("`D<&]S(#T@)'!O<R`K
M("@D9B`^/B`X*3L*("`@("`@("`@("`@("`@("1M97-S86=E7VEN9F];)TUS
M9T9L86=S)UT@/2!A<G)A>5]P;W`H=6YP86-K*"=#)RP@<W5B<W1R*"1$871A
M0G5F9F5R+"`D<&]S*RLL(#$I*2D["B`@("`@("`@("`@("`@("`D;65S<V%G
M95]I;F9O6R=-<V=&;&%G<R==("L](&%R<F%Y7W!O<"AU;G!A8VLH)T,G+"!S
M=6)S='(H)$1A=&%"=69F97(L("1P;W,K*RP@,2DI*2`J(#(U-CL*("`@("`@
M("`@("`@("`@("1M97-S86=E7VEN9F];)TUS9T9L86=S)UT@*ST@87)R87E?
M<&]P*'5N<&%C:R@G0R<L('-U8G-T<B@D1&%T84)U9F9E<BP@)'!O<RP@,2DI
M*2`J(#8U-3,V.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E(#!X,CH*("`@("`@("`@("`@8V%S92`P>#0Z"B`@("`@("`@("`@
M("`@("`D<&]S("L](&%R<F%Y7W!O<"AU;G!A8VLH)TPG+"!S=6)S='(H)$9L
M86=S0G5F9F5R+"`D:2`J(#0L(#0I*2D@/CX@.#L*("`@("`@("`@("`@("`@
M("1M97-S86=E7VEN9F];)&9L86=?87)R87E;)&UA<VM=72`](&%R<F%Y7W!O
M<"AU;G!A8VLH)TPG+"!S=6)S='(H)$1A=&%"=69F97(L("1P;W,L(#0I*2D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@W
M.@H@("`@("`@("`@("!C87-E(#!X.#H*("`@("`@("`@("`@8V%S92`P>#DZ
M"B`@("`@("`@("`@(&-A<V4@,'A!.@H@("`@("`@("`@("!C87-E(#!X0CH*
M("`@("`@("`@("`@8V%S92`P>$0Z"B`@("`@("`@("`@(&-A<V4@,'A%.@H@
M("`@("`@("`@("!C87-E(#!X,3,Z"B`@("`@("`@("`@(&-A<V4@,'@Q03H*
M("`@("`@("`@("`@("`@("1P;W,@*ST@87)R87E?<&]P*'5N<&%C:R@G3"<L
M('-U8G-T<B@D1FQA9W-"=69F97(L("1I("H@-"P@-"DI*2`^/B`X.PH@("`@
M("`@("`@("`@("`@)&UE<W-A9V5?:6YF;ULD9FQA9U]A<G)A>5LD;6%S:UU=
M(#T@)'1H:7,M/E]R96%D4W1R:6YG*"1$871A0G5F9F5R+"`D<&]S*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#$R.@H@
M("`@("`@("`@("`@("`@)'!O<R`K/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@
M<W5B<W1R*"1&;&%G<T)U9F9E<BP@)&D@*B`T+"`T*2DI(#X^(#@["B`@("`@
M("`@("`@("`@("`D;65S<V%G95]I;F9O6R=296-E:79E9"==(#T@87)R87E?
M<&]P*'5N<&%C:R@G3"<L('-U8G-T<B@D1&%T84)U9F9E<BP@)'!O<RP@-"DI
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P
M>#%".@H@("`@("`@("`@("`@("`@)'!O<R`K/2!A<G)A>5]P;W`H=6YP86-K
M*"=,)RP@<W5B<W1R*"1&;&%G<T)U9F9E<BP@)&D@*B`T+"`T*2DI(#X^(#@[
M"B`@("`@("`@("`@("`@("`D;65S<V%G95]I;F9O6R=!8V-O=6YT240G72`]
M(&EN='9A;"@D=&AI<RT^7W)E8613=')I;F<H)$1A=&%"=69F97(L("1P;W,I
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P
M>#@P.@H@("`@("`@("`@("!C87-E(#!X.#$Z"B`@("`@("`@("`@(&-A<V4@
M,'@X-#H*("`@("`@("`@("`@8V%S92`P>#DQ.@H@("`@("`@("`@("`@("`@
M)&UE<W-A9V5?:6YF;ULD9FQA9U]A<G)A>5LD;6%S:UU=(#T@87)R87E?<&]P
M*'5N<&%C:R@G3"<L('-U8G-T<B@D1FQA9W-"=69F97(L("1I("H@-"P@-"DI
M*2`^/B`X.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;65S<V%G95]I;F9O.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("`@
M("`@5$]$3PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<VET:6]N("!43T1/
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96%D26YD97@H)B1D871A+"`D<&]S
M:71I;VXI"B`@("!["B`@("`@("`@)&EN9&5X7VAE861E<B`]('5N<&%C:R@G
M3$9I;&50;W,O3%5N:VYO=VXQ+TQ0<F5V26YD97@O3$YE>'1);F1E>"],0V]U
M;G0O3%5N:VYO=VXG+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@,C0I*3L*
M("`@("`@("!I9B`H)&EN9&5X7VAE861E<ELG1FEL95!O<R==("$]("1P;W-I
M=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*"));G9A;&ED(&9I;&4@9F]R;6%T(BDI.PH@("`@("`@('T*"B`@("`@("`@
M+R\@4'5S:"!I="!I;G1O(&QI<W0@;V8@<')O8V5S<V5D(&ET96US+@H@("`@
M("`@("1T:&ES+3Y?=&UP6R1P;W-I=&EO;ET@/2!T<G5E.PH@("`@("`@(&EF
M("@H)&EN9&5X7VAE861E<ELG3F5X=$EN9&5X)UT@/B`P*2`F)@H@("`@("`@
M("`@("!E;7!T>2@D=&AI<RT^7W1M<%LD:6YD97A?:&5A9&5R6R=.97AT26YD
M97@G75TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5A9$EN9&5X*"1D871A
M+"`D:6YD97A?:&5A9&5R6R=.97AT26YD97@G72D["B`@("`@("`@?0H@("`@
M("`@(&EF("@H)&EN9&5X7VAE861E<ELG4')E=DEN9&5X)UT@/B`P*2`F)@H@
M("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W1M<%LD:6YD97A?:&5A9&5R6R=0
M<F5V26YD97@G75TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5A9$EN9&5X
M*"1D871A+"`D:6YD97A?:&5A9&5R6R=0<F5V26YD97@G72D["B`@("`@("`@
M?0H@("`@("`@("1P;W-I=&EO;B`K/2`R-#L*("`@("`@("`D:6-O=6YT(#T@
M)&EN9&5X7VAE861E<ELG0V]U;G0G72`^/B`X.PH@("`@("`@(&EF("@D:6-O
M=6YT(#X@,"D@>PH@("`@("`@("`@("`D8G5F(#T@<W5B<W1R*"1D871A+"`D
M<&]S:71I;VXL(#$R("H@)&EC;W5N="D["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1I8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@("`@("1H
M9')?8G5F(#T@<W5B<W1R*"1B=68L("1I("H@,3(L(#$R*3L*("`@("`@("`@
M("`@("`@("1);F1E>$ET96T@/2!U;G!A8VLH)TQ(96%D97)0;W,O3$-H:6QD
M26YD97@O3%5N:VYO=VXG+"`D:&1R7V)U9BD["B`@("`@("`@("`@("`@("!I
M9B`H)$EN9&5X271E;5LG2&5A9&5R4&]S)UT@/B`P*2!["B`@("`@("`@("`@
M("`@("`@("`@)&UA:6Q;)VEN9F\G72`]("1T:&ES+3Y?<F5A9$UE<W-A9V5)
M;F9O*"1D871A+"`D26YD97A)=&5M6R=(96%D97)0;W,G72D["B`@("`@("`@
M("`@("`@("`@("`@)&UA:6Q;)V-O;G1E;G0G72`]("1T:&ES+3Y?<F5A9$UE
M<W-A9V4H)&1A=&$L("1M86EL6R=I;F9O)UU;)W!O<VET:6]N)UTI.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%I;'-;72`]("1M86EL.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"@D26YD97A)=&5M
M6R=#:&EL9$EN9&5X)UT@/B`P*2`F)@H@("`@("`@("`@("`@("`@("`@(&5M
M<'1Y*"1T:&ES+3Y?=&UP6R1);F1E>$ET96U;)T-H:6QD26YD97@G75TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96%D26YD97@H)&9P+"`D
M26YD97A)=&5M6R=#:&EL9$EN9&5X)UTI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'``````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#<S,P`Q,#4Q-30S,3`V
M,0`P,C$S,S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B\J*@H@*B!&;W(@9&5C;VUP<F5S<R@I+"!R971U<FX@
M82!L:7-T(&]F(&9I;&5S+VEN9F]R;6%T:6]N(&%B;W5T('1H92!Z:7!F:6QE
M+@H@*B\*9&5F:6YE*"=(3U)$15]#3TU04D534U]:25!?3$E35"<L(#$I.PH*
M+RHJ"B`J($9O<B!D96-O;7!R97-S*"DL(')E='5R;B!T:&4@9&%T82!F;W(@
M86X@:6YD:79I9'5A;"!F:6QE(&EN('1H92!Z:7!F:6QE+@H@*B\*9&5F:6YE
M*"=(3U)$15]#3TU04D534U]:25!?1$%402<L(#(I.PH*+RHJ"B`J(%1H92!(
M;W)D95]#;VUP<F5S<U]Z:7`@8VQA<W,@86QL;W=S(%I)4"!F:6QE<R!T;R!B
M92!C<F5A=&5D(&%N9`H@*B!R96%D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP+'8@,2XQ,2XQ,BXQ-B`R,#`V
M+S`V+S(Y(#`X.C,T.C,P(&IA;B!%>'`@)`H@*@H@*B!4:&4@6DE0(&-O;7!R
M97-S:6]N(&-O9&4@:7,@<&%R=&EA;&QY(&)A<V5D(&]N(&-O9&4@9G)O;3H*
M("H@("!%<FEC($UU96QL97(@/&5R:6-`=&AE;65P87)K+F-O;3X*("H@("!H
M='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X+G!H<#]I9#TU,S4F<VEN9VQE/3$*
M("H*("H@("!$96EN<S$R-2`\=V5B;6%S=&5R0&%T;&%N="YR=3X*("H@("!H
M='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X+G!H<#]I9#TT-S`F<VEN9VQE/3$*
M("H*("H@5&AE(%I)4"!C;VUP<F5S<VEO;B!D871E(&-O9&4@:7,@<&%R=&EA
M;&QY(&)A<V5D(&]N(&-O9&4@9G)O;0H@*B`@(%!E=&5R($QI<W1I86L@/&UL
M861Y0'5S97)S+G-O=7)C969O<F=E+FYE=#X*("H*("H@0V]P>7)I9VAT(#(P
M,#`M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`875T:&]R("!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#;VUP<F5S<PH@*B\*
M8VQA<W,@2&]R9&5?0V]M<')E<W-?>FEP(&5X=&5N9',@2&]R9&5?0V]M<')E
M<W,@>PH*("`@("\J*@H@("`@("H@6DE0(&-O;7!R97-S:6]N(&UE=&AO9',N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M
M971H;V1S(#T@87)R87DH"B`@("`@("`@,'@P(#T^("=.;VYE)RP*("`@("`@
M("`P>#$@/3X@)U-H<G5N:R<L"B`@("`@("`@,'@R(#T^("=3=7!E<B!&87-T
M)RP*("`@("`@("`P>#,@/3X@)T9A<W0G+`H@("`@("`@(#!X-"`]/B`G3F]R
M;6%L)RP*("`@("`@("`P>#4@/3X@)TUA>&EM=6TG+`H@("`@("`@(#!X-B`]
M/B`G26UP;&]D960G+`H@("`@("`@(#!X."`]/B`G1&5F;&%T960G"B`@("`I
M.PH*("`@("\J*@H@("`@("H@0F5G:6YN:6YG(&]F(&-E;G1R86P@9&ER96-T
M;W)Y(')E8V]R9"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]C=')L1&ER2&5A9&5R(#T@(EQX-3!<>#1B7'@P,5QX,#(B
M.PH*("`@("\J*@H@("`@("H@16YD(&]F(&-E;G1R86P@9&ER96-T;W)Y(')E
M8V]R9"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]C=')L1&ER16YD(#T@(EQX-3!<>#1B7'@P-5QX,#9<>#`P7'@P,%QX
M,#!<>#`P(CL*"B`@("`O*BH*("`@("`J($)E9VEN;FEN9R!O9B!F:6QE(&-O
M;G1E;G1S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7V9I;&5(96%D97(@/2`B7'@U,%QX-&)<>#`S7'@P-"(["@H@("`@
M+RHJ"B`@("`@*B!#<F5A=&4@82!:25`@8V]M<')E<W-E9"!F:6QE(&9R;VT@
M86X@87)R87D@;V8@9FEL92!D871A+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D9&%T82`@("!4:&4@9&%T82!T;R!C;VUP<F5S<RX*("`@("`J(#QP
M<F4^"B`@("`@*B!297%U:7)E<R!A;B!A<G)A>2!O9B!A<G)A>7,@+2!E86-H
M('-U8F%R<F%Y('-H;W5L9"!C;VYT86EN('1H90H@("`@("H@9F]L;&]W:6YG
M(&9I96QD<SH*("`@("`J("=D871A)R`H<W1R:6YG*2`@("TM("!4:&4@9&%T
M82!T;R!C;VUP<F5S<RX*("`@("`J("=N86UE)R`H<W1R:6YG*2`@("TM("!4
M:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B`G=&EM92<@*&EN=&5G
M97(I("`M+2`@6V]P=&EO;F%L72!4:&4@=&EM97-T86UP('1O('5S92!F;W(@
M=&AE(&9I;&4N"B`@("`@*B`\+W!R93X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y("A5;G5S960I+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@6DE0(&9I;&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-O;7!R97-S*"1D871A+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("`D8V]N=&5N=',@/2`D8W1R;&1I<B`](&%R<F%Y
M*"D["@H@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1V86PI('L*("`@("`@
M("`@("`@)'1H:7,M/E]A9&14;UI)4$9I;&4H)'9A;"P@)&-O;G1E;G1S+"`D
M8W1R;&1I<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]C
M<F5A=&5:25!&:6QE*"1C;VYT96YT<RP@)&-T<FQD:7(I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5C;VUP<F5S<R!A(%I)4"!F:6QE(&%N9"!G970@:6YF
M;W)M871I;VX@9G)O;2!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D871A("`@5&AE('II<&9I;&4@9&%T82X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y+@H@("`@("H@/'!R93X*
M("`@("`J(%1H92!F;VQL;W=I;F<@<&%R86UE=&5R<R!A<F4@4D5154E2140Z
M"B`@("`@*B`G86-T:6]N)R`H:6YT96=E<BD@(#T^("!4:&4@86-T:6]N('1O
M('1A:V4@;VX@=&AE(&1A=&$N("!%:71H97(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@($A/4D1%7T-/35!215-37UI)4%],25-4(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!(3U)$15]#3TU04D534U]:25!?
M1$%402X*("`@("`J"B`@("`@*B!4:&4@9F]L;&]W:6YG('!A<F%M971E<G,@
M87)E(%)%455)4D5$(&9O<B!(3U)$15]#3TU04D534U]:25!?1$%402!A;'-O
M.@H@("`@("H@)VEN9F\G("AA<G)A>2D@("`]/B`@5&AE('II<&9I;&4@;&ES
M="X*("`@("`J("=K97DG("AI;G1E9V5R*2`@/3X@(%1H92!P;W-I=&EO;B!O
M9B!T:&4@9FEL92!I;B!T:&4@87)C:&EV92!L:7-T+@H@("`@("H@/"]P<F4^
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E<75E<W1E9"!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O;7!R97-S*"1D871A+"`D
M<&%R86US*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=A8W1I
M;VXG72DI('L*("`@("`@("`@("`@:68@*"1P87)A;7-;)V%C=&EO;B==(#T]
M($A/4D1%7T-/35!215-37UI)4%],25-4*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]G971::7!);F9O*"1D871A*3L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1P87)A;7-;)V%C=&EO;B==(#T]($A/4D1%7T-/35!215-3
M7UI)4%]$051!*2!["B`@("`@("`@("`@("`@("`O+R!43T1/.B!#:&5C:R!F
M;W(@<&%R86UE=&5R<RX*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V=E=%II<$1A=&$H)&1A=&$L("1P87)A;7-;)VEN9F\G72P@)'!A<F%M<ULG
M:V5Y)UTI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(I+"`G
M:&]R9&4N97)R;W(G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M;&ES="!O9B!F:6QE<R]D871A(&9R;VT@=&AE('II<"!A<F-H:79E+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)B1D871A("!4:&4@>FEP9FEL92!D871A+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($M%63H@4&]S:71I;VX@:6X@>FEP9FEL90H@
M("`@("H@("`@("`@("`@("`@("`@5D%,5453.B`G871T<B<@("`@+2T@($9I
M;&4@871T<FEB=71E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G
M8W)C)R`@("`@+2T@($-20R!C:&5C:W-U;0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`G8W-I>F4G("`@+2T@($-O;7!R97-S960@9FEL92!S:7IE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=D871E)R`@("`M+2`@
M1FEL92!M;V1I9FEC871I;VX@=&EM90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@("`@+2T@($9I;&5N86UE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("=M971H;V0G("`M+2`@0V]M<')E<W-I;VX@;65T
M:&]D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=S:7IE)R`@("`M
M+2`@3W)I9VEN86P@9FEL92!S:7IE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@("`M+2`@1FEL92!T>7!E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]G971::7!);F9O*"8D9&%T82D*("`@('L*("`@("`@("`D96YT
M<FEE<R`](&%R<F%Y*"D["@H@("`@("`@("\J($=E="!D971A:6QS(&9R;VT@
M0V5N=')A;"!D:7)E8W1O<GD@<W1R=6-T=7)E+B`J+PH@("`@("`@("1F:%-T
M87)T(#T@<W1R<&]S*"1D871A+"`D=&AI<RT^7V-T<FQ$:7)(96%D97(I.PH*
M("`@("`@("!D;R!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1A=&$I(#P@
M)&9H4W1A<G0@*R`S,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B26YV86QI9"!:25`@9&%T82(I*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D:6YF;R`]('5N<&%C:R@G=DUE=&AO9"]65&EM
M92]60U)#,S(O5D-O;7!R97-S960O5E5N8V]M<')E<W-E9"]V3&5N9W1H)RP@
M<W5B<W1R*"1D871A+"`D9FA3=&%R="`K(#$P+"`R,"DI.PH@("`@("`@("`@
M("`D;F%M92`]('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@*R`T-BP@)&EN9F];
M)TQE;F=T:"==*3L*"B`@("`@("`@("`@("1E;G1R:65S6R1N86UE72`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)V%T='(G(#T^(&YU;&PL"B`@("`@("`@
M("`@("`@("`G8W)C)R`]/B!S<')I;G1F*"(E,#AS(BP@9&5C:&5X*"1I;F9O
M6R=#4D,S,B==*2DL"B`@("`@("`@("`@("`@("`G8W-I>F4G(#T^("1I;F9O
M6R=#;VUP<F5S<V5D)UTL"B`@("`@("`@("`@("`@("`G9&%T92<@/3X@;G5L
M;"P*("`@("`@("`@("`@("`@("=?9&%T85-T87)T)R`]/B!N=6QL+`H@("`@
M("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`H@("`@("`@("`@("`@("`@
M)VUE=&AO9"<@/3X@)'1H:7,M/E]M971H;V1S6R1I;F9O6R=-971H;V0G75TL
M"B`@("`@("`@("`@("`@("`G7VUE=&AO9"<@/3X@)&EN9F];)TUE=&AO9"==
M+`H@("`@("`@("`@("`@("`@)W-I>F4G(#T^("1I;F9O6R=5;F-O;7!R97-S
M960G72P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B!N=6QL"B`@("`@("`@
M("`@("D["@H@("`@("`@("`@("`D96YT<FEE<ULD;F%M95U;)V1A=&4G72`]
M"B`@("`@("`@("`@("`@("!M:W1I;64H*"@D:6YF;ULG5&EM92==(#X^(#$Q
M*2`F(#!X,68I+`H@("`@("`@("`@("`@("`@("`@("`@("@H)&EN9F];)U1I
M;64G72`^/B`U*2`F(#!X,V8I+`H@("`@("`@("`@("`@("`@("`@("`@("@H
M)&EN9F];)U1I;64G72`\/"`Q*2`F(#!X,V4I+`H@("`@("`@("`@("`@("`@
M("`@("`@("@H)&EN9F];)U1I;64G72`^/B`R,2D@)B`P>#`W*2P*("`@("`@
M("`@("`@("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@/CX@,38I("8@,'@Q
M9BDL"B`@("`@("`@("`@("`@("`@("`@("`@*"@H)&EN9F];)U1I;64G72`^
M/B`R-2D@)B`P>#=F*2`K(#$Y.#`I*3L*"B`@("`@("`@("`@(&EF("AS=')L
M96XH)&1A=&$I(#P@)&9H4W1A<G0@*R`T,RD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!:25`@9&%T82(I
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:6YF;R`]('5N<&%C:R@G
M=DEN=&5R;F%L+U9%>'1E<FYA;"<L('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@
M*R`S-BP@-BDI.PH*("`@("`@("`@("`@)&5N=')I97-;)&YA;65=6R=T>7!E
M)UT@/2`H)&EN9F];)TEN=&5R;F%L)UT@)B`P>#`Q*2`_("=T97AT)R`Z("=B
M:6YA<GDG.PH@("`@("`@("`@("`D96YT<FEE<ULD;F%M95U;)V%T='(G72`]
M"B`@("`@("`@("`@("`@("`H*"1I;F9O6R=%>'1E<FYA;"==("8@,'@Q,"D@
M/R`G1"<@.B`G+2<I("X*("`@("`@("`@("`@("`@("@H)&EN9F];)T5X=&5R
M;F%L)UT@)B`P>#(P*2`_("=!)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@
M*"@D:6YF;ULG17AT97)N86PG72`F(#!X,#,I(#\@)U,G(#H@)RTG*2`N"B`@
M("`@("`@("`@("`@("`H*"1I;F9O6R=%>'1E<FYA;"==("8@,'@P,BD@/R`G
M2"<@.B`G+2<I("X*("`@("`@("`@("`@("`@("@H)&EN9F];)T5X=&5R;F%L
M)UT@)B`P>#`Q*2`_("=2)R`Z("<M)RD["B`@("`@("`@?2!W:&EL92`H*"1F
M:%-T87)T(#T@<W1R<&]S*"1D871A+"`D=&AI<RT^7V-T<FQ$:7)(96%D97(L
M("1F:%-T87)T("L@-#8I*2`A/3T@9F%L<V4I.PH*("`@("`@("`O*B!'970@
M9&5T86EL<R!F<F]M(&QO8V%L(&9I;&4@:&5A9&5R+B`J+PH@("`@("`@("1F
M:%-T87)T(#T@<W1R<&]S*"1D871A+"`D=&AI<RT^7V9I;&5(96%D97(I.PH*
M("`@("`@("!D;R!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1A=&$I(#P@
M)&9H4W1A<G0@*R`S-"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B26YV86QI9"!:25`@9&%T82(I*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D:6YF;R`]('5N<&%C:R@G=DUE=&AO9"]65&EM
M92]60U)#,S(O5D-O;7!R97-S960O5E5N8V]M<')E<W-E9"]V3&5N9W1H+W9%
M>'1R84QE;F=T:"<L('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@*R`X+"`R-2DI
M.PH@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@
M*R`S,"P@)&EN9F];)TQE;F=T:"==*3L*("`@("`@("`@("`@)&5N=')I97-;
M)&YA;65=6R=?9&%T85-T87)T)UT@/2`D9FA3=&%R="`K(#,P("L@)&EN9F];
M)TQE;F=T:"==("L@)&EN9F];)T5X=')A3&5N9W1H)UT["B`@("`@("`@?2!W
M:&EL92`H<W1R;&5N*"1D871A*2`^("1F:%-T87)T("L@,S`@*R`D:6YF;ULG
M3&5N9W1H)UT@)B8*("`@("`@("`@("`@("`@("`H)&9H4W1A<G0@/2!S=')P
M;W,H)&1A=&$L("1T:&ES+3Y?9FEL94AE861E<BP@)&9H4W1A<G0@*R`S,"`K
M("1I;F9O6R=,96YG=&@G72DI("$]/2!F86QS92D["@H@("`@("`@(')E='5R
M;B!A<G)A>5]V86QU97,H)&5N=')I97,I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@9&%T82!F;W(@82!S<&5C:69I8R!A<F-H:79E9"!F
M:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@>FEP(&%R8VAI=F4@8V]N
M=&5N=',N"B`@("`@*B!`<&%R86T@87)R87D@)B1I;F9O("`@5&AE(&EN9F]R
M;6%T:6]N(&%R<F%Y(&9R;VT@7V=E=%II<$EN9F\H*2X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1K97D@("!4:&4@<&]S:71I;VX@;V8@=&AE(&9I;&4@:6X@
M=&AE(&%R8VAI=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971::7!$871A
M*"8D9&%T82P@)B1I;F9O+"`D:V5Y*0H@("`@>PH@("`@("`@(&EF("@H)&EN
M9F];)&ME>5U;)U]M971H;V0G72`]/2`P>#@I("8F(%5T:6PZ.F5X=&5N<VEO
M;D5X:7-T<R@G>FQI8B<I*2!["B`@("`@("`@("`@("\J($EF('1H92!F:6QE
M(&AA<R!B965N(&1E9FQA=&5D+"!A;F0@>FQI8B!I<R!I;G-T86QL960L"B`@
M("`@("`@("`@("`@('1H96X@:6YF;&%T92!T:&4@9&%T82!A9V%I;BX@*B\*
M("`@("`@("`@("`@<F5T=7)N($!G>FEN9FQA=&4H<W5B<W1R*"1D871A+"`D
M:6YF;ULD:V5Y75LG7V1A=&%3=&%R="==+"`D:6YF;ULD:V5Y75LG8W-I>F4G
M72DI.PH@("`@("`@('T@96QS96EF("@D:6YF;ULD:V5Y75LG7VUE=&AO9"==
M(#T](#!X,"D@>PH@("`@("`@("`@("`O*B!&:6QE<R!T:&%T(&%R96XG="!C
M;VUP<F5S<V5D+B`J+PH@("`@("`@("`@("!R971U<FX@<W5B<W1R*"1D871A
M+"`D:6YF;ULD:V5Y75LG7V1A=&%3=&%R="==+"`D:6YF;ULD:V5Y75LG8W-I
M>F4G72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@=&\@<V5E(&EF('1H92!D871A(&ES(&$@
M=F%L:60@6DE0(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F
M)&1A=&$@(%1H92!:25`@9FEL92!D871A+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!V86QI9"P@9F%L<V4@:68@:6YV86QI9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM::7!$871A*"8D9&%T82D*("`@
M('L*("`@("`@("!I9B`H<W1R<&]S*"1D871A+"`D=&AI<RT^7V9I;&5(96%D
M97(I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!53DE8('1I
M;65S=&%M<"!T;R!A(#0M8GET92!$3U,@9&%T92!A;F0@=&EM92!F;W)M870*
M("`@("`J("AD871E(&EN(&AI9V@@,BUB>71E<RP@=&EM92!I;B!L;W<@,BUB
M>71E<R!A;&QO=VEN9R!M86=N:71U9&4*("`@("`J(&-O;7!A<FES;VXI+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1U;FEX=&EM92`@5&AE(&-U<G)E;G0@54Y)6"!T:6UE
M<W1A;7`N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8W5R
M<F5N="!D871E(&EN(&$@-"UB>71E($1/4R!F;W)M870N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]U;FEX,D1/4U1I;64H)'5N:7AT:6UE(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&EM96%R<F%Y(#T@*&ES7VYU;&PH)'5N:7AT:6UE*2D@
M/R!G971D871E*"D@.B!G971D871E*"1U;FEX=&EM92D["@H@("`@("`@(&EF
M("@D=&EM96%R<F%Y6R=Y96%R)UT@/"`Q.3@P*2!["B`@("`@("`@("`@("1T
M:6UE87)R87E;)WEE87(G72`@("`](#$Y.#`["B`@("`@("`@("`@("1T:6UE
M87)R87E;)VUO;B==("`@("`](#$["B`@("`@("`@("`@("1T:6UE87)R87E;
M)VUD87DG72`@("`](#$["B`@("`@("`@("`@("1T:6UE87)R87E;)VAO=7)S
M)UT@("`](#`["B`@("`@("`@("`@("1T:6UE87)R87E;)VUI;G5T97,G72`]
M(#`["B`@("`@("`@("`@("1T:6UE87)R87E;)W-E8V]N9',G72`](#`["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@*"@D=&EM96%R<F%Y6R=Y96%R)UT@
M+2`Q.3@P*2`\/"`R-2D@?`H@("`@("`@("`@("`@("`@*"1T:6UE87)R87E;
M)VUO;B==(#P\(#(Q*2!\"B`@("`@("`@("`@("`@("`H)'1I;65A<G)A>5LG
M;61A>2==(#P\(#$V*2!\"B`@("`@("`@("`@("`@("`H)'1I;65A<G)A>5LG
M:&]U<G,G72`\/"`Q,2D@?`H@("`@("`@("`@("`@("`@*"1T:6UE87)R87E;
M)VUI;G5T97,G72`\/"`U*2!\"B`@("`@("`@("`@("`@("`H)'1I;65A<G)A
M>5LG<V5C;VYD<R==(#X^(#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D
M<R!A(")F:6QE(B!T;R!T:&4@6DE0(&%R8VAI=F4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M9FEL92`@("`@(%-E92!(;W)D95]#;VUP<F5S<U]Z:7`Z.F-R96%T95II<$9I
M;&4H*2X*("`@("`J($!P87)A;2!A<G)A>2`F)&-O;G1E;G1S("!!;B!A<G)A
M>2!O9B!E>&ES=&EN9R!Z:7!P960@9FEL97,N"B`@("`@*B!`<&%R86T@87)R
M87D@)B1C=')L9&ER("`@06X@87)R87D@;V8@8V5N=')A;"!D:7)E8W1O<GD@
M:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&14;UI)4$9I
M;&4H)B1F:6QE+"`F)&-O;G1E;G1S+"`F)&-T<FQD:7(I"B`@("!["B`@("`@
M("`@)&1A=&$@/2`F)&9I;&5;)V1A=&$G73L*("`@("`@("`D;F%M92`]('-T
M<E]R97!L86-E*"=<7"<L("<O)RP@)&9I;&5;)VYA;64G72D["@H@("`@("`@
M("\J(%-E92!I9B!T:6UE+V1A=&4@:6YF;W)M871I;VX@:&%S(&)E96X@<')O
M=FED960N("HO"B`@("`@("`@)&9T:6UE(#T@;G5L;#L*("`@("`@("!I9B`H
M:7-S970H)&9I;&5;)W1I;64G72DI('L*("`@("`@("`@("`@)&9T:6UE(#T@
M)&9I;&5;)W1I;64G73L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@
M:&5X('1I;64N("HO"B`@("`@("`@)&1T:6UE("`@(#T@9&5C:&5X*"1T:&ES
M+3Y?=6YI>#)$;W-4:6UE*"1F=&EM92DI.PH@("`@("`@("1H97AD=&EM92`]
M(&-H<BAH97AD96,H)&1T:6UE6S9=("X@)&1T:6UE6S==*2D@+@H@("`@("`@
M("`@("`@("`@("`@(&-H<BAH97AD96,H)&1T:6UE6S1=("X@)&1T:6UE6S5=
M*2D@+@H@("`@("`@("`@("`@("`@("`@(&-H<BAH97AD96,H)&1T:6UE6S)=
M("X@)&1T:6UE6S-=*2D@+@H@("`@("`@("`@("`@("`@("`@(&-H<BAH97AD
M96,H)&1T:6UE6S!=("X@)&1T:6UE6S%=*2D["@H@("`@("`@("1F<B`@/2`D
M=&AI<RT^7V9I;&5(96%D97([("`@+RH@0F5G:6X@8W)E871I;F<@=&AE(%I)
M4"!D871A+B`J+PH@("`@("`@("1F<B`N/2`B7'@Q-%QX,#`B.R`@("`@("`@
M("`@+RH@5F5R<VEO;B!N965D960@=&\@97AT<F%C="X@*B\*("`@("`@("`D
M9G(@+CT@(EQX,#!<>#`P(CL@("`@("`@("`@("\J($=E;F5R86P@<'5R<&]S
M92!B:70@9FQA9RX@*B\*("`@("`@("`D9G(@+CT@(EQX,#A<>#`P(CL@("`@
M("`@("`@("\J($-O;7!R97-S:6]N(&UE=&AO9"X@*B\*("`@("`@("`D9G(@
M+CT@)&AE>&1T:6UE.R`@("`@("`@("`@("\J($QA<W0@;6]D:69I8V%T:6]N
M('1I;64O9&%T92X@*B\*"B`@("`@("`@+RH@(DQO8V%L(&9I;&4@:&5A9&5R
M(B!S96=M96YT+B`J+PH@("`@("`@("1U;F-?;&5N(#T@<W1R;&5N*"1D871A
M*3L*("`@("`@("`D8W)C("`@("`](&-R8S,R*"1D871A*3L*("`@("`@("`D
M>F1A=&$@("`](&=Z8V]M<')E<W,H)&1A=&$I.PH@("`@("`@("1Z9&%T82`@
M(#T@<W5B<W1R*'-U8G-T<B@D>F1A=&$L(#`L('-T<FQE;B@D>F1A=&$I("T@
M-"DL(#(I.PH@("`@("`@("1C7VQE;B`@(#T@<W1R;&5N*"1Z9&%T82D["@H@
M("`@("`@("1F<B`N/2!P86-K*"=6)RP@)&-R8RD[("`@("`@("`@("`@+RH@
M0U)#(#,R(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@("1F<B`N/2!P86-K*"=6
M)RP@)&-?;&5N*3L@("`@("`@("`@+RH@0V]M<')E<W-E9"!F:6QE<VEZ92X@
M*B\*("`@("`@("`D9G(@+CT@<&%C:R@G5B<L("1U;F-?;&5N*3L@("`@("`@
M("\J(%5N8V]M<')E<W-E9"!F:6QE<VEZ92X@*B\*("`@("`@("`D9G(@+CT@
M<&%C:R@G=B<L('-T<FQE;B@D;F%M92DI.R`@("\J($QE;F=T:"!O9B!F:6QE
M;F%M92X@*B\*("`@("`@("`D9G(@+CT@<&%C:R@G=B<L(#`I.R`@("`@("`@
M("`@("`@("\J($5X=')A(&9I96QD(&QE;F=T:"X@*B\*("`@("`@("`D9G(@
M+CT@)&YA;64[("`@("`@("`@("`@("`@("`@("`@("\J($9I;&4@;F%M92X@
M*B\*"B`@("`@("`@+RH@(D9I;&4@9&%T82(@<V5G;65N="X@*B\*("`@("`@
M("`D9G(@+CT@)'ID871A.PH*("`@("`@("`O*B`B1&%T82!D97-C<FEP=&]R
M(B!S96=M96YT("AO<'1I;VYA;"!B=70@;F5C97-S87)Y(&EF(&%R8VAI=F4@
M:7,*("`@("`@("`@("!N;W0@<V5R=F5D(&%S(&9I;&4I+B`J+PH@("`@("`@
M("1F<B`N/2!P86-K*"=6)RP@)&-R8RD["B`@("`@("`@)&9R("X]('!A8VLH
M)U8G+"`D8U]L96XI.PH@("`@("`@("1F<B`N/2!P86-K*"=6)RP@)'5N8U]L
M96XI.PH*("`@("`@("`O*B!!9&0@=&AI<R!E;G1R>2!T;R!A<G)A>2X@*B\*
M("`@("`@("`D;VQD7V]F9G-E="`]('-T<FQE;BAI;7!L;V1E*"<G+"`D8V]N
M=&5N=',I*3L*("`@("`@("`D8V]N=&5N='-;72`]("8D9G(["@H@("`@("`@
M("\J($%D9"!T;R!C96YT<F%L(&1I<F5C=&]R>2!R96-O<F0N("HO"B`@("`@
M("`@)&-D<F5C("`]("1T:&ES+3Y?8W1R;$1I<DAE861E<CL*("`@("`@("`D
M8V1R96,@+CT@(EQX,#!<>#`P(CL@("`@("`@("`@("`@("`@+RH@5F5R<VEO
M;B!M861E(&)Y+B`J+PH@("`@("`@("1C9')E8R`N/2`B7'@Q-%QX,#`B.R`@
M("`@("`@("`@("`@("`O*B!697)S:6]N(&YE961E9"!T;R!E>'1R86-T("HO
M"B`@("`@("`@)&-D<F5C("X](")<>#`P7'@P,"([("`@("`@("`@("`@("`@
M("\J($=E;F5R86P@<'5R<&]S92!B:70@9FQA9R`J+PH@("`@("`@("1C9')E
M8R`N/2`B7'@P.%QX,#`B.R`@("`@("`@("`@("`@("`O*B!#;VUP<F5S<VEO
M;B!M971H;V0@*B\*("`@("`@("`D8V1R96,@+CT@)&AE>&1T:6UE.R`@("`@
M("`@("`@("`@("`@+RH@3&%S="!M;V0@=&EM92]D871E+B`J+PH@("`@("`@
M("1C9')E8R`N/2!P86-K*"=6)RP@)&-R8RD[("`@("`@("`@("`O*B!#4D,@
M,S(@:6YF;W)M871I;VXN("HO"B`@("`@("`@)&-D<F5C("X]('!A8VLH)U8G
M+"`D8U]L96XI.R`@("`@("`@("\J($-O;7!R97-S960@9FEL97-I>F4N("HO
M"B`@("`@("`@)&-D<F5C("X]('!A8VLH)U8G+"`D=6YC7VQE;BD[("`@("`@
M("\J(%5N8V]M<')E<W-E9"!F:6QE<VEZ92X@*B\*("`@("`@("`D8V1R96,@
M+CT@<&%C:R@G=B<L('-T<FQE;B@D;F%M92DI.R`@+RH@3&5N9W1H(&]F(&9I
M;&5N86UE+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=V)RP@,"D[("`@
M("`@("`@("`@("`O*B!%>'1R82!F:65L9"!L96YG=&@N("HO"B`@("`@("`@
M)&-D<F5C("X]('!A8VLH)W8G+"`P*3L@("`@("`@("`@("`@("\J($9I;&4@
M8V]M;65N="!L96YG=&@N("HO"B`@("`@("`@)&-D<F5C("X]('!A8VLH)W8G
M+"`P*3L@("`@("`@("`@("`@("\J($1I<VL@;G5M8F5R('-T87)T+B`J+PH@
M("`@("`@("1C9')E8R`N/2!P86-K*"=V)RP@,"D[("`@("`@("`@("`@("`O
M*B!);G1E<FYA;"!F:6QE(&%T=')I8G5T97,N("HO"B`@("`@("`@)&-D<F5C
M("X]('!A8VLH)U8G+"`S,BD[("`@("`@("`@("`@("\J($5X=&5R;F%L(&9I
M;&4@871T<FEB=71E<R`M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A<F-H:79E)R!B:70@<V5T+B`J+PH@("`@
M("`@("1C9')E8R`N/2!P86-K*"=6)RP@)&]L9%]O9F9S970I.R`@("`O*B!2
M96QA=&EV92!O9F9S970@;V8@;&]C86P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:&5A9&5R+B`J+PH@("`@("`@
M("1C9')E8R`N/2`D;F%M93L@("`@("`@("`@("`@("`@("`@("`O*B!&:6QE
M(&YA;64N("HO"B`@("`@("`@+RH@3W!T:6]N86P@97AT<F$@9FEE;&0L(&9I
M;&4@8V]M;65N="!G;V5S(&AE<F4N("HO"@H@("`@("`@("\O(%-A=F4@=&\@
M8V5N=')A;"!D:7)E8W1O<GD@87)R87DN("HO"B`@("`@("`@)&-T<FQD:7);
M72`]("8D8V1R96,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S('1H
M92!:25`@9FEL92X*("`@("`J($]F9FEC:6%L(%I)4"!F:6QE(&9O<FUA=#H@
M:'1T<#HO+W=W=RYP:W=A<F4N8V]M+V%P<&YO=&4N='AT"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!:25`@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T
M95I)4$9I;&4H)B1C;VYT96YT<RP@)B1C=')L1&ER*0H@("`@>PH@("`@("`@
M("1D871A(#T@:6UP;&]D92@G)RP@)&-O;G1E;G1S*3L*("`@("`@("`D9&ER
M(#T@:6UP;&]D92@G)RP@)&-T<FQ$:7(I.PH*("`@("`@("!R971U<FX@)&1A
M=&$@+B`D9&ER("X@)'1H:7,M/E]C=')L1&ER16YD("X*("`@("`@("`@("`@
M+RH@5&]T86P@(R!O9B!E;G1R:65S(")O;B!T:&ES(&1I<VLB+B`J+PH@("`@
M("`@("`@("!P86-K*"=V)RP@8V]U;G0H)&-T<FQ$:7(I*2`N"B`@("`@("`@
M("`@("\J(%1O=&%L(",@;V8@96YT<FEE<R!O=F5R86QL+B`J+PH@("`@("`@
M("`@("!P86-K*"=V)RP@8V]U;G0H)&-T<FQ$:7(I*2`N"B`@("`@("`@("`@
M("\J(%-I>F4@;V8@8V5N=')A;"!D:7)E8W1O<GDN("HO"B`@("`@("`@("`@
M('!A8VLH)U8G+"!S=')L96XH)&1I<BDI("X*("`@("`@("`@("`@+RH@3V9F
M<V5T('1O('-T87)T(&]F(&-E;G1R86P@9&ER+B`J+PH@("`@("`@("`@("!P
M86-K*"=6)RP@<W1R;&5N*"1D871A*2D@+@H@("`@("`@("`@("`O*B!:25`@
M9FEL92!C;VUM96YT(&QE;F=T:"X@*B\*("`@("`@("`@("`@(EQX,#!<>#`P
M(CL*("`@('T*"GT*````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R
M97-S+W1A<BYP:'``````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-S<U-``Q,#4Q-30S,3`V,0`P,C$S,C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#
M;VUP<F5S<U]T87(@8VQA<W,@86QL;W=S('1A<B!F:6QE<R!T;R!B92!R96%D
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T
M87(N<&AP+'8@,2XT+C$R+CD@,C`P-B\P-"\S,"`R,CHR.#HR.2!C:'5C:R!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0V]M
M<')E<W,*("HO"F-L87-S($AO<F1E7T-O;7!R97-S7W1A<B!E>'1E;F1S($AO
M<F1E7T-O;7!R97-S('L*"B`@("`O*BH*("`@("`J(%1A<B!F:6QE('1Y<&5S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M='EP97,@/2!A<G)A>2@*("`@("`@("`P>#`@("`]/B`@)U5N:7@@9FEL92<L
M"B`@("`@("`@,'@S,"`@/3X@("=&:6QE)RP*("`@("`@("`P>#,Q("`]/B`@
M)TQI;FLG+`H@("`@("`@(#!X,S(@(#T^("`G4WEM8F]L:6,@;&EN:R<L"B`@
M("`@("`@,'@S,R`@/3X@("=#:&%R86-T97(@<W!E8VEA;"!F:6QE)RP*("`@
M("`@("`P>#,T("`]/B`@)T)L;V-K('-P96-I86P@9FEL92<L"B`@("`@("`@
M,'@S-2`@/3X@("=$:7)E8W1O<GDG+`H@("`@("`@(#!X,S8@(#T^("`G1DE&
M3R!S<&5C:6%L(&9I;&4G+`H@("`@("`@(#!X,S<@(#T^("`G0V]N=&EG=6]U
M<R!F:6QE)PH@("`@*3L*"B`@("`O*BH*("`@("`J(%1A<B!F:6QE(&9L86=S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M9FQA9W,@/2!A<G)A>2@*("`@("`@("`G1E1%6%0G("`@("`]/B`@,'@P,2P*
M("`@("`@("`G1DA#4D,G("`@("`]/B`@,'@P,BP*("`@("`@("`G1D585%)!
M)R`@("`]/B`@,'@P-"P*("`@("`@("`G1DY!344G("`@("`]/B`@,'@P."P*
M("`@("`@("`G1D-/34U%3E0G("`]/B`@,'@Q,`H@("`@*3L*"B`@("`O*BH*
M("`@("`J($1E8V]M<')E<W,@82!T87(@9FEL92!A;F0@9V5T(&EN9F]R;6%T
M:6]N(&9R;VT@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A
M=&$@("!4:&4@=&%R(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y("A5;G5S960I+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!R97%U97-T960@9&%T82!O<B!0
M14%27T5R<F]R(&]N(&5R<F]R+@H@("`@("H@/'!R93X*("`@("`J($M%63H@
M4&]S:71I;VX@:6X@=&AE(&%R<F%Y"B`@("`@*B!604Q515,Z("=A='1R)R`@
M+2T@($9I;&4@871T<FEB=71E<PH@("`@("H@("`@("`@("`G9&%T82<@("TM
M("!287<@9FEL92!C;VYT96YT<PH@("`@("H@("`@("`@("`G9&%T92<@("TM
M("!&:6QE(&UO9&EF:6-A=&EO;B!T:6UE"B`@("`@*B`@("`@("`@("=N86UE
M)R`@+2T@($9I;&5N86UE"B`@("`@*B`@("`@("`@("=S:7IE)R`@+2T@($]R
M:6=I;F%L(&9I;&4@<VEZ90H@("`@("H@("`@("`@("`G='EP92<@("TM("!&
M:6QE('1Y<&4*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M96-O;7!R97-S*"8D9&%T82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'!O<VET:6]N(#T@,#L*("`@("`@("`D<F5T=7)N7V%R<F%Y(#T@
M87)R87DH*3L*"B`@("`@("`@=VAI;&4@*"1P;W-I=&EO;B`\('-T<FQE;B@D
M9&%T82DI('L*("`@("`@("`@("`@)&EN9F\@/2!`=6YP86-K*")A,3`P9FEL
M96YA;64O83AM;V1E+V$X=6ED+V$X9VED+V$Q,G-I>F4O83$R;71I;64O83AC
M:&5C:W-U;2]#='EP969L86<O83$P,&QI;FLO839M86=I8R]A,G9E<G-I;VXO
M83,R=6YA;64O83,R9VYA;64O83AD979M86IO<B]A.&1E=FUI;F]R(BP@<W5B
M<W1R*"1D871A+"`D<&]S:71I;VXI*3L*("`@("`@("`@("`@:68@*"$D:6YF
M;RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB*2D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1P;W-I=&EO;B`K/2`U,3(["B`@("`@("`@("`@
M("1C;VYT96YT<R`]('-U8G-T<B@D9&%T82P@)'!O<VET:6]N+"!O8W1D96,H
M)&EN9F];)W-I>F4G72DI.PH@("`@("`@("`@("`D<&]S:71I;VX@*ST@8V5I
M;"AO8W1D96,H)&EN9F];)W-I>F4G72D@+R`U,3(I("H@-3$R.PH*("`@("`@
M("`@("`@:68@*"1I;F9O6R=F:6QE;F%M92==*2!["B`@("`@("`@("`@("`@
M("`D9FEL92`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=A='1R)R`]
M/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("=D871A)R`]/B!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("=D871E)R`]/B!O8W1D96,H)&EN9F];)VUT
M:6UE)UTI+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!T<FEM*"1I
M;F9O6R=F:6QE;F%M92==*2P*("`@("`@("`@("`@("`@("`@("`G<VEZ92<@
M/3X@;V-T9&5C*"1I;F9O6R=S:7IE)UTI+`H@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`]/B!I<W-E="@D=&AI<RT^7W1Y<&5S6R1I;F9O6R=T>7!E9FQA
M9R==72D@/R`D=&AI<RT^7W1Y<&5S6R1I;F9O6R=T>7!E9FQA9R==72`Z(&YU
M;&P*("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@:68@*"@D
M:6YF;ULG='EP969L86<G72`]/2`P*2!\?`H@("`@("`@("`@("`@("`@("`@
M("@D:6YF;ULG='EP969L86<G72`]/2`P>#,P*2!\?`H@("`@("`@("`@("`@
M("`@("`@("@D:6YF;ULG='EP969L86<G72`]/2`P>#,U*2D@>PH@("`@("`@
M("`@("`@("`@("`@("\J($9I;&4@;W(@9F]L9&5R+B`J+PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE6R=D871A)UT@/2`D8V]N=&5N=',["@H@("`@("`@
M("`@("`@("`@("`@("1M;V1E(#T@:&5X9&5C*'-U8G-T<B@D:6YF;ULG;6]D
M92==+"`T+"`S*2D["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V%T='(G
M72`]"B`@("`@("`@("`@("`@("`@("`@("`@("@H)&EN9F];)W1Y<&5F;&%G
M)UT@/3T@,'@S-2D@/R`G9"<@.B`G+2<I("X*("`@("`@("`@("`@("`@("`@
M("`@("`@*"@D;6]D92`F(#!X-#`P*2`_("=R)R`Z("<M)RD@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`H*"1M;V1E("8@,'@R,#`I(#\@)W<G(#H@)RTG
M*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P>#$P,"D@
M/R`G>"<@.B`G+2<I("X*("`@("`@("`@("`@("`@("`@("`@("`@*"@D;6]D
M92`F(#!X,#0P*2`_("=R)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`H*"1M;V1E("8@,'@P,C`I(#\@)W<G(#H@)RTG*2`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P>#`Q,"D@/R`G>"<@.B`G+2<I
M("X*("`@("`@("`@("`@("`@("`@("`@("`@*"@D;6]D92`F(#!X,#`T*2`_
M("=R)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E
M("8@,'@P,#(I(#\@)W<G(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("@H)&UO9&4@)B`P>#`P,2D@/R`G>"<@.B`G+2<I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!3;VUE(&]T
M:&5R('1Y<&4N("HO"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@)')E='5R;E]A<G)A>5M=(#T@)&9I;&4["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T=7)N7V%R<F%Y.PH@("`@?0H*
M?0H``````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-30Q,P`Q,#4Q-30S,3`V,0`P,C$T-S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!(;W)D95]#;VUP<F5S<U]G>FEP(&-L87-S(&%L;&]W<R!G
M>FEP(&9I;&5S('1O(&)E(')E860N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP+'8@,2XW+C$R+CD@,C`P-B\P
M-"\S,"`R,CHR.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?0V]M<')E<W,*("HO"F-L87-S($AO<F1E7T-O
M;7!R97-S7V=Z:7`@97AT96YD<R!(;W)D95]#;VUP<F5S<R!["@H@("`@+RHJ
M"B`@("`@*B!'>FEP(&9I;&4@9FQA9W,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]F;&%G<R`](&%R<F%Y*`H@("`@("`@
M("=&5$585"<@("`@(#T^("`P>#`Q+`H@("`@("`@("=&2$-20R<@("`@(#T^
M("`P>#`R+`H@("`@("`@("=&15A44D$G("`@(#T^("`P>#`T+`H@("`@("`@
M("=&3D%-12<@("`@(#T^("`P>#`X+`H@("`@("`@("=&0T]-345.5"<@(#T^
M("`P>#$P"B`@("`I.PH*("`@("\J*@H@("`@("H@1&5C;VUP<F5S<R!A(&=Z
M:7`@9FEL92!A;F0@9V5T(&EN9F]R;6%T:6]N(&9R;VT@:70N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@(%1H92!T87(@9FEL92!D871A
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97(@
M87)R87D@*%5N=7-E9"DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!U;F-O;7!R97-S960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&5C;VUP<F5S<R@F)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("\J($EF(&=Z:7`@:7,@;F]T(&-O;7!I;&5D(&EN=&\@4$A0+"!R
M971U<FX@;F]W+B`J+PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI
M<W1S*"=Z;&EB)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@1WII<'!E
M9"!&:6QE("T@9&5C;VUP<F5S<R!I="!F:7)S="X@*B\*("`@("`@("`D<&]S
M:71I;VX@/2`P.PH@("`@("`@("1I;F9O(#T@0'5N<&%C:R@G0T--+T-&3$<O
M5E1I;64O0UA&3"]#3U,G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K(#(I
M*3L*("`@("`@("!I9B`H(21I;F9O*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M(BDI.PH@("`@("`@('T*("`@("`@("`D<&]S:71I;VX@*ST@,3`["@H@("`@
M("`@(&EF("@D:6YF;ULG1DQ')UT@)B`D=&AI<RT^7V9L86=S6R=&15A44D$G
M72D@>PH@("`@("`@("`@("`D6$Q%3B`]('5N<&%C:R@G=DQE;F=T:"<L('-U
M8G-T<B@D9&%T82P@)'!O<VET:6]N("L@,"P@,BDI.PH@("`@("`@("`@("`D
M6$Q%3B`]("183$5.6R=,96YG=&@G73L*("`@("`@("`@("`@)'!O<VET:6]N
M("L]("183$5.("L@,CL*("`@("`@("!]"@H@("`@("`@(&EF("@D:6YF;ULG
M1DQ')UT@)B`D=&AI<RT^7V9L86=S6R=&3D%-12==*2!["B`@("`@("`@("`@
M("1F:6QE;F%M95!O<R`]('-T<G!O<R@D9&%T82P@(EQX,"(L("1P;W-I=&EO
M;BD["B`@("`@("`@("`@("1F:6QE;F%M92`]('-U8G-T<B@D9&%T82P@)'!O
M<VET:6]N+"`D9FEL96YA;650;W,@+2`D<&]S:71I;VXI.PH@("`@("`@("`@
M("`D<&]S:71I;VX@/2`D9FEL96YA;650;W,@*R`Q.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1I;F9O6R=&3$<G72`F("1T:&ES+3Y?9FQA9W-;)T9#3TU-
M14Y4)UTI('L*("`@("`@("`@("`@)&-O;6UE;G10;W,@/2!S=')P;W,H)&1A
M=&$L(")<>#`B+"`D<&]S:71I;VXI.PH@("`@("`@("`@("`D8V]M;65N="`]
M('-U8G-T<B@D9&%T82P@)'!O<VET:6]N+"`D8V]M;65N=%!O<R`M("1P;W-I
M=&EO;BD["B`@("`@("`@("`@("1P;W-I=&EO;B`]("1C;VUM96YT4&]S("L@
M,3L*("`@("`@("!]"@H@("`@("`@(&EF("@D:6YF;ULG1DQ')UT@)B`D=&AI
M<RT^7V9L86=S6R=&2$-20R==*2!["B`@("`@("`@("`@("1H8W)C(#T@=6YP
M86-K*"=V0U)#)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VX@*R`P+"`R*2D[
M"B`@("`@("`@("`@("1H8W)C(#T@)&AC<F-;)T-20R==.PH@("`@("`@("`@
M("`D<&]S:71I;VX@*ST@,CL*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@
M/2!`9WII;F9L871E*'-U8G-T<B@D9&%T82P@)'!O<VET:6]N+"!S=')L96XH
M)&1A=&$I("T@)'!O<VET:6]N*2D["B`@("`@("`@:68@*&5M<'1Y*"1R97-U
M;'0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(BDI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M
M<')E<W,O=&YE9BYP:'``````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(U,S(T`#$P-3$U-#,Q,#8Q`#`R,30V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*9&5F:6YE*"=43D5&7U-)
M1TY!5%5212<L("`@("`@,'@R,C-E.68W."D["F1E9FEN92@G5$Y%1E],5DQ?
M34534T%'12<L("`@(#!X,#$I.PID969I;F4H)U1.149?3%9,7T%45$%#2$U%
M3E0G+"`P>#`R*3L*"F1E9FEN92@G5$Y%1E]35%))3D<G+"`P>#`P,#$P,#`P
M*3L*9&5F:6YE*"=43D5&7T)95$4G+"`@(#!X,#`P-C`P,#`I.PID969I;F4H
M)U1.149?5T]21"<L("`@,'@P,#`W,#`P,"D["F1E9FEN92@G5$Y%1E]$5T]2
M1"<L("`P>#`P,#@P,#`P*3L*"F1E9FEN92@G5$Y%1E]!4U5"2D5#5"<L("`@
M5$Y%1E]$5T]21"`@?"`P>#@P,#0I.PID969I;F4H)U1.149?04U#3$%34R<L
M("`@(%1.149?5T]21"`@('P@,'@X,#`X*3L*9&5F:6YE*"=43D5&7T%45$%#
M2$1!5$$G+"!43D5&7T)95$4@("!\(#!X.#`P9BD["F1E9FEN92@G5$Y%1E]!
M1DE,14Y!344G+"`@5$Y%1E]35%))3D<@?"`P>#@P,3`I.PID969I;F4H)U1.
M149?05)%3D1$051!)RP@(%1.149?0EE412`@('P@,'@Y,#`R*3L*9&5F:6YE
M*"=43D5&7T%-05!)05144E,G+"!43D5&7T)95$4@("!\(#!X.3`P-2D["F1E
M9FEN92@G5$Y%1E]!5D524TE/3B<L("`@5$Y%1E]$5T]21"`@?"`P>#DP,#8I
M.PH*9&5F:6YE*"=43D5&7TU!4$E?3E5,3"<L("`@("`@("`@("`P>#`P,#$I
M.PID969I;F4H)U1.149?34%025]32$]25"<L("`@("`@("`@(#!X,#`P,BD[
M"F1E9FEN92@G5$Y%1E]-05!)7TE.5"<L("`@("`@("`@("`@,'@P,#`S*3L*
M9&5F:6YE*"=43D5&7TU!4$E?1DQ/050G+"`@("`@("`@("`P>#`P,#0I.PID
M969I;F4H)U1.149?34%025]$3U5"3$4G+"`@("`@("`@(#!X,#`P-2D["F1E
M9FEN92@G5$Y%1E]-05!)7T-54E)%3D-9)RP@("`@("`@,'@P,#`V*3L*9&5F
M:6YE*"=43D5&7TU!4$E?05!05$E-12<L("`@("`@("`P>#`P,#<I.PID969I
M;F4H)U1.149?34%025]%4E)/4B<L("`@("`@("`@(#!X,#`P82D["F1E9FEN
M92@G5$Y%1E]-05!)7T)/3TQ%04XG+"`@("`@("`@,'@P,#!B*3L*9&5F:6YE
M*"=43D5&7TU!4$E?3T)*14-4)RP@("`@("`@("`P>#`P,&0I.PID969I;F4H
M)U1.149?34%025])3E0X0EE412<L("`@("`@(#!X,#`Q-"D["F1E9FEN92@G
M5$Y%1E]-05!)7U-44DE.1R<L("`@("`@("`@,'@P,#%E*3L*9&5F:6YE*"=4
M3D5&7TU!4$E?54Y)0T]$15]35%))3D<G+"`P>#`P,68I.PID969I;F4H)U1.
M149?34%025]365-424U%)RP@("`@("`@(#!X,#`T,"D["F1E9FEN92@G5$Y%
M1E]-05!)7T-,4TE$)RP@("`@("`@("`@,'@P,#0X*3L*9&5F:6YE*"=43D5&
M7TU!4$E?0DE.05)9)RP@("`@("`@("`P>#`Q,#(I.PH*9&5F:6YE*"=43D5&
M7TU!4$E?051404-(7TQ/3D=?1DE,14Y!344G+"`P>#,W,#<I.PID969I;F4H
M)U1.149?34%025]!5%1!0TA?34E-15]404<G+"`@("`@(#!X,S<P12D["@ID
M969I;F4H)U1.149?34%025].04U%1%]465!%7TE$)RP@("`@(#!X,#`P,"D[
M"F1E9FEN92@G5$Y%1E]-05!)7TY!345$7U194$5?4U1224Y')RP@,'@P,#`Q
M*3L*9&5F:6YE*"=43D5&7TU!4$E?359?1DQ!1R<L("`@("`@("`@("`P>#$P
M,#`I.PH*+RHJ"B`J(%1H92!(;W)D95]#;VUP<F5S<U]T;F5F(&-L87-S(&%L
M;&]W<R!-4RU43D5&(&1A=&$@=&\@8F4@9&ES<&QA>65D+@H@*@H@*B!4:&4@
M5$Y%1B!R96YD97)I;F<@:7,@8F%S960@;VX@8V]D92!B>3H*("H@("!'<F%H
M86T@3F]R8G5R>2`\9VYO<F)U<GE`8F]N9&-A<BYC;VT^"B`J($]R:6=I;F%L
M(&1E<VEG;B!B>3H*("H@("!4:&]M87,@0F]L;"`\=&)`8F]L;"YC:#XL($UA
M<FL@4VEM<'-O;B`\9&%M;F5D0'=O<FQD+G-T9"YC;VT^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1N968N<&AP+'8@,2XV
M+C$R+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S<U]T;F5F(&5X
M=&5N9',@2&]R9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@("H@1&5C;VUP
M<F5S<R!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M871A("`@5&AE(&1A=&$@=&\@9&5C;VUP<F5S<RX*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!;B!A<G)A>2!O9B!A<F=U;65N=',@;F5E9&5D('1O
M(&1E8V]M<')E<W,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@9&5C;VUP
M<F5S<V5D(&1A=&$N"B`@("`@*B`@("`@("`@("`@("`@("!2971U<FYS(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E8V]M<')E<W,H)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M
M/E]G971I*"1D871A+"`S,BD@/3T@5$Y%1E]324=.05154D4I('L*("`@("`@
M("`@("`@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["@H@("`@("`@("`@("!W
M:&EL92`H<W1R;&5N*"1D871A*2`^(#`I('L*("`@("`@("`@("`@("`@('-W
M:71C:"`H)'1H:7,M/E]G971I*"1D871A+"`X*2D@>PH@("`@("`@("`@("`@
M("`@8V%S92!43D5&7TQ63%]-15-304=%.@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&5C;V1E365S<V%G92@D9&%T82D["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92!43D5&7TQ63%]!
M5%1!0TA-14Y4.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E
M071T86-H;65N="@D9&%T82P@)&]U="D["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!A<G)A>5]R979E<G-E*"1O=70I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!4
M:&4@9&%T82!S=')I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8FET<R`@
M2&]W(&UA;GD@8FET<R!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E='@H)B1D871A+"`D
M8FET<RD*("`@('L*("`@("`@("`D=F%L=64@/2!N=6QL.PH*("`@("`@("!I
M9B`H<W1R;&5N*"1D871A*2`^/2`D8FET<RD@>PH@("`@("`@("`@("`D=F%L
M=64@/2!S=6)S='(H)&1A=&$L(#`L("1B:71S*3L*("`@("`@("`@("`@)&1A
M=&$@/2!S=6)S=')?<F5P;&%C92@D9&%T82P@)R<L(#`L("1B:71S*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@(%1H92!D871A('-T
M<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1B:71S("!(;W<@;6%N>2!B
M:71S('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@5$]$3PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T:2@F)&1A=&$L("1B:71S*0H@("`@
M>PH@("`@("`@("1B>71E<R`]("1B:71S("\@.#L*("`@("`@("`D=F%L=64@
M/2!N=6QL.PH*("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`^/2`D8GET97,I
M('L*("`@("`@("`@("`@)'9A;'5E(#T@;W)D*"1D871A6S!=*3L*("`@("`@
M("`@("`@:68@*"1B>71E<R`^/2`R*2!["B`@("`@("`@("`@("`@("`D=F%L
M=64@*ST@*&]R9"@D9&%T85LQ72D@/#P@."D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"1B>71E<R`^/2`T*2!["B`@("`@("`@("`@("`@("`D
M=F%L=64@*ST@*&]R9"@D9&%T85LR72D@/#P@,38I("L@*&]R9"@D9&%T85LS
M72D@/#P@,C0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D871A(#T@
M<W5B<W1R7W)E<&QA8V4H)&1A=&$L("<G+"`P+"`D8GET97,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@("`@(%1H92!D871A('-T
M<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T92`@5$]$3PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E071T<FEB=71E*"8D9&%T82P@
M)&%T=')I8G5T92D*("`@('L*("`@("`@("`O*B!$871A+B`J+PH@("`@("`@
M("1T:&ES+3Y?9V5T>"@D9&%T82P@)'1H:7,M/E]G971I*"1D871A+"`S,BDI
M.PH*("`@("`@("`O*B!#:&5C:W-U;2X@*B\*("`@("`@("`D=&AI<RT^7V=E
M=&DH)&1A=&$L(#$V*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A("`@("`@("`@("`@(%1H92!D871A('-T<FEN9RX*
M("`@("`J($!P87)A;2!A<G)A>2`F)&%T=&%C:&UE;G1?9&%T82`@5$]$3PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?97AT<F%C=$UA<&E!='1R:6)U=&5S*"1D
M871A+"`F)&%T=&%C:&UE;G1?9&%T82D*("`@('L*("`@("`@("`O*B!.=6UB
M97(@;V8@871T<FEB=71E<RX@*B\*("`@("`@("`D;G5M8F5R(#T@)'1H:7,M
M/E]G971I*"1D871A+"`S,BD["@H@("`@("`@('=H:6QE("@H<W1R;&5N*"1D
M871A*2`^(#`I("8F("1N=6UB97(M+2D@>PH@("`@("`@("`@("`D:&%V95]M
M=F%L(#T@9F%L<V4["B`@("`@("`@("`@("1N=6U?;79A;"`](#$["B`@("`@
M("`@("`@("1N86UE9%]I9"`]("1V86QU92`](&YU;&P["B`@("`@("`@("`@
M("1A='1R7W1Y<&4@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@
M("`@("`@)&%T=')?;F%M92`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,38I.PH*
M("`@("`@("`@("`@:68@*"@D871T<E]T>7!E("8@5$Y%1E]-05!)7TU67T9,
M04<I("$](#`I('L*("`@("`@("`@("`@("`@("1H879E7VUV86P@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@)&%T=')?='EP92`]("1A='1R7W1Y<&4@)B!^
M5$Y%1E]-05!)7TU67T9,04<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@H)&%T=')?;F%M92`^/2`P>#@P,#`I("8F("@D871T<E]N86UE(#P@
M,'A&1D9%*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]G971X*"1D871A
M+"`Q-BD["B`@("`@("`@("`@("`@("`D;F%M961?='EP92`]("1T:&ES+3Y?
M9V5T:2@D9&%T82P@,S(I.PH*("`@("`@("`@("`@("`@('-W:71C:"`H)&YA
M;65D7W1Y<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7TY!
M345$7U194$5?240Z"B`@("`@("`@("`@("`@("`@("`@)&YA;65D7VED(#T@
M)'1H:7,M/E]G971I*"1D871A+"`S,BD["B`@("`@("`@("`@("`@("`@("`@
M)&%T=')?;F%M92`]("1N86UE9%]I9#L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E(%1.149?34%025].04U%1%]4
M65!%7U-44DE.1SH*("`@("`@("`@("`@("`@("`@("`D871T<E]N86UE(#T@
M,'@Y.3DY.PH@("`@("`@("`@("`@("`@("`@("1I9&QE;B`]("1T:&ES+3Y?
M9V5T:2@D9&%T82P@,S(I.PH@("`@("`@("`@("`@("`@("`@("1D871A;&5N
M(#T@)&ED;&5N("L@*"@T("T@*"1I9&QE;B`E(#0I*2`E(#0I.PH@("`@("`@
M("`@("`@("`@("`@("1N86UE9%]I9"`]('-U8G-T<B@D=&AI<RT^7V=E='@H
M)&1A=&$L("1D871A;&5N*2P@,"P@)&ED;&5N*3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1H879E7VUV86PI('L*("`@("`@("`@("`@("`@
M("1N=6U?;79A;"`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1A='1R7W1Y<&4I('L*("`@
M("`@("`@("`@8V%S92!43D5&7TU!4$E?4TA/4E0Z"B`@("`@("`@("`@("`@
M("`D=F%L=64@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?24Y4
M.@H@("`@("`@("`@("!C87-E(%1.149?34%025]"3T],14%..@H@("`@("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&YU;5]M=F%L.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]G971I*"1D
M871A+"`S,BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T9,3T%4.@H@("`@
M("`@("`@("!C87-E(%1.149?34%025]%4E)/4CH*("`@("`@("`@("`@("`@
M("1V86QU92`]("1T:&ES+3Y?9V5T>"@D9&%T82P@-"D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T1/54),
M13H*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?05!05$E-13H*("`@("`@
M("`@("`@8V%S92!43D5&7TU!4$E?0U524D5.0UDZ"B`@("`@("`@("`@(&-A
M<V4@5$Y%1E]-05!)7TE.5#A"651%.@H@("`@("`@("`@("!C87-E(%1.149?
M34%025]365-424U%.@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M
M/E]G971X*"1D871A+"`X*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92!43D5&7TU!4$E?4U1224Y'.@H@("`@("`@("`@("!C
M87-E(%1.149?34%025]53DE#3T1%7U-44DE.1SH*("`@("`@("`@("`@8V%S
M92!43D5&7TU!4$E?0DE.05)9.@H@("`@("`@("`@("!C87-E(%1.149?34%0
M25]/0DI%0U0Z"B`@("`@("`@("`@("`@("`D;G5M7W9A;',@/2`H)&AA=F5?
M;79A;"D@/R`D;G5M7VUV86P@.B`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1N=6U?=F%L<SL@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1L96YG=&@@/2`D=&AI<RT^
M7V=E=&DH)&1A=&$L(#,R*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@4&%D
M('1O(&YE>'0@-"!B>71E(&)O=6YD87)Y+B`J+PH@("`@("`@("`@("`@("`@
M("`@("1D871A;&5N(#T@)&QE;F=T:"`K("@H-"`M("@D;&5N9W1H("4@-"DI
M("4@-"D["@H@("`@("`@("`@("`@("`@("`@(&EF("@D871T<E]T>7!E(#T]
M(%1.149?34%025]35%))3D<I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&QE;F=T:"`M/2`Q.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`@("`@+RH@4F5A9"!A;F0@=')U;F-A=&4@=&\@;&5N9W1H+B`J
M+PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-U8G-T<B@D=&AI<RT^
M7V=E='@H)&1A=&$L("1D871A;&5N*2P@,"P@)&QE;F=T:"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@4W1O<F4@86YY(&EN=&5R97-T:6YG(&%T=')I
M8G5T97,N("HO"B`@("`@("`@("`@('-W:71C:"`H)&%T=')?;F%M92D@>PH@
M("`@("`@("`@("!C87-E(%1.149?34%025]!5%1!0TA?3$].1U]&24Q%3D%-
M13H*("`@("`@("`@("`@("`@("\J(%5S960@:6X@<')E9F5R96YC92!T;R!!
M1DE,14Y!344@=F%L=64N("HO"B`@("`@("`@("`@("`@("`D871T86-H;65N
M=%]D871A6S!=6R=N86UE)UT@/2!P<F5G7W)E<&QA8V4H)R\N*EM<+UTH+BHI
M)"\G+"`G7#$G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)&%T=&%C:&UE
M;G1?9&%T85LP75LG;F%M92==(#T@<W1R7W)E<&QA8V4H(EPP(BP@)R<L("1A
M='1A8VAM96YT7V1A=&%;,%U;)VYA;64G72D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T%45$%#2%]-24U%
M7U1!1SH*("`@("`@("`@("`@("`@("\J($ES('1H:7,@979E<B!S970L(&%N
M9"!W:&%T(&ES(&9O<FUA=#\@*B\*("`@("`@("`@("`@("`@("1A='1A8VAM
M96YT7V1A=&%;,%U;)W1Y<&4G72`]('!R96=?<F5P;&%C92@G+UXH+BHI7"\N
M*B\G+"`G7#$G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)&%T=&%C:&UE
M;G1?9&%T85LP75LG<W5B='EP92==(#T@<')E9U]R97!L86-E*"<O+BI<+R@N
M*BDD+R<L("=<,2<L("1V86QU92D["B`@("`@("`@("`@("`@("`D871T86-H
M;65N=%]D871A6S!=6R=S=6)T>7!E)UT@/2!S=')?<F5P;&%C92@B7#`B+"`G
M)RP@)&%T=&%C:&UE;G1?9&%T85LP75LG<W5B='EP92==*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@
M9&%T82!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-O9&5-97-S
M86=E*"8D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7V1E8V]D94%T=')I
M8G5T92@D9&%T82P@)'1H:7,M/E]G971I*"1D871A+"`S,BDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("`@("`@
M("`@("`@5&AE(&1A=&$@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M871T86-H;65N=%]D871A("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D
M96-O9&5!='1A8VAM96YT*"8D9&%T82P@)B1A='1A8VAM96YT7V1A=&$I"B`@
M("!["B`@("`@("`@)&%T=')I8G5T92`]("1T:&ES+3Y?9V5T:2@D9&%T82P@
M,S(I.PH*("`@("`@("!S=VET8V@@*"1A='1R:6)U=&4I('L*("`@("`@("!C
M87-E(%1.149?05)%3D1$051!.@H@("`@("`@("`@("`O*B!-87)K<R!S=&%R
M="!O9B!N97<@871T86-H;65N="X@*B\*("`@("`@("`@("`@)'1H:7,M/E]G
M971X*"1D871A+"`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*2D["@H@("`@("`@
M("`@("`O*B!#:&5C:W-U;2`J+PH@("`@("`@("`@("`D=&AI<RT^7V=E=&DH
M)&1A=&$L(#$V*3L*"B`@("`@("`@("`@("\J($%D9"!A(&YE=R!D969A=6QT
M(&1A=&$@8FQO8VL@=&\@:&]L9"!D971A:6QS(&]F('1H:7,*("`@("`@("`@
M("`@("`@871T86-H;65N="X@4F5V97)S92!O<F1E<B!I<R!E87-I97(@=&\@
M:&%N9&QE(&QA=&5R(2`J+PH@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1A
M='1A8VAM96YT7V1A=&$L(&%R<F%Y*"=T>7!E)R`@("`]/B`G87!P;&EC871I
M;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=S=6)T>7!E)R`]/B`G;V-T970M<W1R96%M)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;F%M92<@("`@/3X@)W5N:VYO=VXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=')E86TG("`]/B`G)RDI
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!43D5&7T%&24Q%
M3D%-13H*("`@("`@("`@("`@+RH@4W1R:7`@<&%T:"X@*B\*("`@("`@("`@
M("`@)&%T=&%C:&UE;G1?9&%T85LP75LG;F%M92==(#T@<')E9U]R97!L86-E
M*"<O+BI;7"]=*"XJ*20O)RP@)UPQ)RP@)'1H:7,M/E]G971X*"1D871A+"`D
M=&AI<RT^7V=E=&DH)&1A=&$L(#,R*2DI.PH@("`@("`@("`@("`D871T86-H
M;65N=%]D871A6S!=6R=N86UE)UT@/2!S=')?<F5P;&%C92@B7#`B+"`G)RP@
M)&%T=&%C:&UE;G1?9&%T85LP75LG;F%M92==*3L*"B`@("`@("`@("`@("\J
M($-H96-K<W5M("HO"B`@("`@("`@("`@("1T:&ES+3Y?9V5T:2@D9&%T82P@
M,38I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!43D5&7T%4
M5$%#2$1!5$$Z"B`@("`@("`@("`@("\J(%1H92!A='1A8VAM96YT(&ET<V5L
M9BX@*B\*("`@("`@("`@("`@)&QE;F=T:"`]("1T:&ES+3Y?9V5T:2@D9&%T
M82P@,S(I.PH@("`@("`@("`@("`D871T86-H;65N=%]D871A6S!=6R=S:7IE
M)UT@/2`D;&5N9W1H.PH@("`@("`@("`@("`D871T86-H;65N=%]D871A6S!=
M6R=S=')E86TG72`]("1T:&ES+3Y?9V5T>"@D9&%T82P@)&QE;F=T:"D["@H@
M("`@("`@("`@("`O*B!#:&5C:W-U;2`J+PH@("`@("`@("`@("`D=&AI<RT^
M7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@5$Y%1E]!34%024%45%)3.@H@("`@("`@("`@("`D;&5N9W1H(#T@
M)'1H:7,M/E]G971I*"1D871A+"`S,BD["B`@("`@("`@("`@("1V86QU92`]
M("1T:&ES+3Y?9V5T>"@D9&%T82P@)&QE;F=T:"D["@H@("`@("`@("`@("`O
M*B!#:&5C:W-U;2`J+PH@("`@("`@("`@("`D=&AI<RT^7V=E=&DH)&1A=&$L
M(#$V*3L*("`@("`@("`@("`@)'1H:7,M/E]E>'1R86-T36%P:4%T=')I8G5T
M97,H)'9A;'5E+"`D871T86-H;65N=%]D871A*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?9&5C
M;V1E071T<FEB=71E*"1D871A+"`D871T<FEB=71E*3L*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+P``````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`V,0`P,38U,C<`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M5D,O<F-S+G!H<```````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$V,C,V`#$P-3$U-#,Q,#8Q`#`R,#`S-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5D-?<F-S
M(&EM<&QE;65N=&%T:6]N+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IE
M9F8@4V-H=V5N=&YE<B`\:F5F9G)E>2YS8VAW96YT;F5R0&QM8V\N8V]M/@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]60R]60R]R8W,N<&AP+'8@,2XS+C@N
M-2`R,#`V+S`Q+S`Q(#(Q.C(X.C0R(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R
M("!*969F(%-C:'=E;G1N97(@/&IE9F9R97DN<V-H=V5N=&YE<D!L;6-O+F-O
M;3X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]R8W,@97AT96YD<R!6
M0R!["@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@86X@4D-3(&9I;&4@:6X@=VET
M:"!A('-P96-I9FEE9"!C:&%N9V4@;&]G+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&5P871H("`@($QO8V%T:6]N(&]F(&9I;&4@=&\@8VAE
M8VL@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("`@("!,;V<@
M;V8@8VAA;F=E<R!S:6YC92!L87-T('9E<G-I;VXN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R("`@("`@("!4:&4@=7-E<B!N86UE('1O('5S92!F;W(@
M=&AE(&-H96-K(&EN+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YE=T)I;F%R
M>2`@1&]E<R!T:&4@8VAA;F=E(&EN=F]L=F4@8FEN87)Y(&1A=&$_"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F=\;V)J96-T("!4:&4@;F5W(')E=FES
M:6]N(&YU;6)E<B!O;B!S=6-C97-S+"!O<B!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-I*"1F:6QE<&%T:"P@)&UE<W-A9V4L("1U
M<V5R(#T@;G5L;"P@)&YE=T)I;F%R>2`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@D=7-E<BD@>PH@("`@("`@("`@("!P=71E;G8H)TQ/1TY!344])R`N
M("1U<V5R*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P=71E;G8H
M)TQ/1TY!344]9W5E<W0G*3L*("`@("`@("!]"@H@("`@("`@("11(#T@5D-?
M5TE.1$]74R`_("<B)R`Z("(G(B`["@H@("`@("`@("1C:5]C;60@/2`D=&AI
M<RT^9V5T4&%T:"@G8VDG*2`N("<@)R`N("11("X@)&9I;&5P871H("X@)%$N
M)R`R/B8Q)SL*("`@("`@("`D<F-S7V-M9"`]("1T:&ES+3YG9710871H*"=R
M8W,G*2`N("<@+6D@+6MB("<@+B`D42`N("1F:6QE<&%T:"`N("11+B<@,CXF
M,2<["B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`D;65S<V%G95]L
M:6YE<R`](&5X<&QO9&4H(EQN(BP@)&UE<W-A9V4I.PH*("`@("`@("`D<&EP
M95]D968@/2!A<G)A>2@P(#T^(&%R<F%Y*")P:7!E(BP@)W(G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*")P:7!E(BP@)W<G*2D[
M"@H@("`@("`@(&EF("@D;F5W0FEN87)Y*2!["B`@("`@("`@("`@("1P<F]C
M97-S(#T@<')O8U]O<&5N*"1R8W-?8VUD+"`D<&EP95]D968L("1P:7!E<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!R;V-E<W,@/2!P<F]C
M7V]P96XH)&-I7V-M9"P@)'!I<&5?9&5F+"`D<&EP97,I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1P<F]C97-S*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D;65S<V%G95]L:6YE<R!A<R`D;&EN92D@>PH@("`@
M("`@("`@("`@("`@:68@*"1L:6YE(#T]("<N7&XG*2!["B`@("`@("`@("`@
M("`@("`@("`@)&QI;F4@/2`G+B!<;B<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!F=W)I=&4H)'!I<&5S6S!=+"`D;&EN92D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&9W<FET92@D<&EP97-;,%TL(")<;BY<
M;B(I.PH@("`@("`@("`@("!F8VQO<V4H)'!I<&5S6S!=*3L*"B`@("`@("`@
M("`@('=H:6QE("@A9F5O9B@D<&EP97-;,5TI*2!["B`@("`@("`@("`@("`@
M("`D;W5T<'5T("X](&9R96%D*"1P:7!E<ULQ72P@.#$Y,BD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@9F-L;W-E*"1P:7!E<ULQ72D["B`@("`@("`@
M("`@('!R;V-?8VQO<V4H)'!R;V-E<W,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@
M;W!E;B!P:7!E(&EN(&-I*"DG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M;F5W0FEN87)Y*2!["B`@("`@("`@("`@(&5X96,H)&-I7V-M9"`N("<@,CXF
M,2<L("1R971U<FY?87)R87DL("1R971V86PI.PH*("`@("`@("`@("`@:68@
M*"1R971V86PI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*")5;F%B;&4@=&\@<W!A=VX@8VD@;VX@)&9I;&5P871H(&9R;VT@
M8VDH*2(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)')E='5R;E]A<G)A>2!A<R`D;&EN92D@>PH@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@)&QI;F4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R979?<W1A<G0@
M/2!S=')P;W,H)&]U='!U="P@)VYE=R!R979I<VEO;CH@)RD["@H@("`@("`@
M("\O($EF(&YO(&YE=R!R979I<VEO;BP@<V5E(&EF('1H:7,@:7,@86X@:6YI
M=&EA;"!C:&5C:VEN+@H@("`@("`@(&EF("@D<F5V7W-T87)T(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`D<F5V7W-T87)T(#T@<W1R<&]S*"1O=71P=70L
M("=I;FET:6%L(')E=FES:6]N.B`G*3L*("`@("`@("`@("`@)')E=E]E;F0@
M/2!S=')P;W,H)&]U='!U="P@)R`G+"`D<F5V7W-T87)T*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<F5V7V5N9"`]('-T<G!O<R@D;W5T<'5T
M+"`G.R<L("1R979?<W1A<G0I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R
M979?<W1A<G0@(3T](&9A;'-E("8F("1R979?96YD("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`D<F5V7W-T87)T("L](#$T.PH@("`@("`@("`@("!R971U
M<FX@<W5B<W1R*"1O=71P=70L("1R979?<W1A<G0L("1R979?96YD("T@)')E
M=E]S=&%R="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6YL;V-K
M*"1F:6QE<&%T:"D["B`@("`@("`@("`@("1T96UP7W!O<R`]('-T<G!O<R@D
M;W5T<'5T+"`G9FEL92!I<R!U;F-H86YG960G*3L*("`@("`@("`@("`@:68@
M*"1T96UP7W!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=#:&5C:RUI;B!&86EL=7)E.B`G("X@8F%S
M96YA;64H)&9I;&5P871H*2`N("<@:&%S(&YO="!B965N(&UO9&EF:65D)RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B1F%I;&5D('1O(&-H96-K:6X@)&9I;&5P871H
M+"`D8VE?8VUD+"`D;W5T<'5T(BD["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE(&QO8VMS(&]N(&$@
M0U93+U)#4R!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I
M;&5P871H("`@($QO8V%T:6]N(&]F(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("8D;&]C:V5D7V)Y("!2971U<FYS('1H92!U<V5R;F%M92!H;VQD:6YG
M('1H92!L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQO8FIE
M8W0@(%1R=64@;VX@<W5C8V5S<RP@;W(@82!014%27T5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3&]C:V5D*"1F:6QE<&%T:"P@
M)B1L;V-K961?8GDI"B`@("!["B`@("`@("`@)')L;V=?8VUD("`]("1T:&ES
M+3YG9710871H*"=R;&]G)RD["B`@("`@("`@)')L;V=?9FQA9R`]("<@+4P@
M)SL*"B`@("`@("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B.PH*("`@
M("`@("`D8VUD(#T@)')L;V=?8VUD("X@)')L;V=?9FQA9R`N("11("X@)&9I
M;&5P871H("X@)%$["@H@("`@("`@(&5X96,H)&-M9"XG(#(^)C$G+"`D<F5T
M=7)N7V%R<F%Y+"`D<F5T=F%L*3L*"B`@("`@("`@:68@*"1R971V86PI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E5N86)L92!T
M;R!S<&%W;B!R;&]G(&]N("1F:6QE<&%T:"!F<F]M(&ES3&]C:V5D*"DB*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;W5T<'5T(#T@)R<["@H@
M("`@("`@("`@("!F;W)E86-H("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2![
M"B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1L:6YE.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<W1A<G1?;F%M92`]('-T<G!O<R@D;W5T<'5T
M+"`G;&]C:V5D(&)Y.B`G*3L*("`@("`@("`@("`@)&5N9%]N86UE(#T@<W1R
M<&]S*"1O=71P=70L("<[)RP@)'-T87)T7VYA;64I.PH*("`@("`@("`@("`@
M:68@*"1S=&%R=%]N86UE("$]/2!F86QS92`F)B`D96YD7VYA;64@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D<W1A<G1?;F%M92`K/2`Q,3L*("`@
M("`@("`@("`@("`@("1L;V-K961?8GD@/2!S=6)S='(H)&]U='!U="P@)'-T
M87)T7VYA;64L("1E;F1?;F%M92`M("1S=&%R=%]N86UE*3L*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]("!E;'-E:68@*'-T
M<FQE;B@D;W5T<'5T*2`]/2`P*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;'5R92!R=6YN:6YG(')L;V<@
M:6X@:7-,;V-K960H*2<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@3&]C:W,@82!#5E,O4D-3(&9I;&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL97!A=&@@($QO8V%T:6]N(&]F
M(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@57-E<B!N
M86UE('1O(&QO8VL@=&AE(&9I;&4@=VET:`H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;GQO8FIE8W0@(%1R=64@;VX@<W5C8V5S<RP@;W(@82!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO8VLH
M)&9I;&5P871H+"`D=7-E<B`](&YU;&PI"B`@("!["B`@("`@("`@+R\@1V5T
M('5S97)N86UE(&9O<B!20U,@=&%G+@H@("`@("`@(&EF("@D=7-E<BD@>PH@
M("`@("`@("`@("!P=71E;G8H)TQ/1TY!344])R`N("1U<V5R*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!P=71E;G8H)TQ/1TY!344]9W5E<W0G
M*3L*("`@("`@("!]"@H@("`@("`@("1R8W-?8VUD(#T@)'1H:7,M/F=E=%!A
M=&@H)W)C<R<I.PH@("`@("`@("1R8W-?9FQA9R`]("<@+6P@)SL*"B`@("`@
M("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B(#L*("`@("`@("`D8VUD
M(#T@)')C<U]C;60@+B`D<F-S7V9L86<@+B`D42`N("1F:6QE<&%T:"`N("11
M.PH@("`@("`@(&5X96,H)&-M9"XG(#(^)C$G+"`D<F5T=7)N7V%R<F%Y+"`D
M<F5T=F%L*3L*"B`@("`@("`@:68@*"1R971V86PI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!S<&%W;B!R8W,@
M*"(G("X@)&-M9"`N("<B*2!O;B`B)R`N("1F:6QE<&%T:"`N("<B("AR971U
M<FYE9"`G("X@)')E='9A;"`N("<I)RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&]U='!U="`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D
M<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]("1L:6YE.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&]C
M:V5D7W!O<R`]('-T<G!O<R@D;W5T<'5T+"`G;&]C:V5D)RD["B`@("`@("`@
M("`@(&EF("@D;&]C:V5D7W!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!L
M;V-K("(G("X@)&9I;&5P871H("X@)R(@*%)A;B`B)R`N("1C;60@+B`G(BP@
M9V]T(')E='5R;B!C;V1E("<@+B`D<F5T=F%L("X@)RP@;W5T<'5T.B`G("X@
M)&]U='!U="`N("<I)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5;FQO8VMS(&$@0U93+U)#4R!F:6QE+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5P871H("!,;V-A=&EO;B!O
M9B!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%5S97(@
M;F%M92!T;R!U;FQO8VL@=&AE(&9I;&4@=VET:`H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;GQO8FIE8W0@(%1R=64@;VX@<W5C8V5S<RP@;W(@82!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N
M;&]C:R@D9FEL97!A=&@L("1U<V5R(#T@;G5L;"D*("`@('L*("`@("`@("`O
M+R!'970@=7-E<FYA;64@9F]R(%)#4R!T86<N"B`@("`@("`@:68@*"1U<V5R
M*2!["B`@("`@("`@("`@('!U=&5N=B@G3$]'3D%-13TG("X@)'5S97(I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@('!U=&5N=B@G3$]'3D%-13UG
M=65S="<I.PH@("`@("`@('T*"B`@("`@("`@)')C<U]C;60@/2`D=&AI<RT^
M9V5T4&%T:"@G<F-S)RD["B`@("`@("`@)')C<U]F;&%G(#T@)R`M=2`G.PH*
M("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(@.PH@("`@("`@
M("1C;60@/2`D<F-S7V-M9"`N("1R8W-?9FQA9R`N("11("X@)&9I;&5P871H
M("X@)%$["B`@("`@("`@97AE8R@D8VUD("X@)R`R/B8Q)RP@)')E='5R;E]A
M<G)A>2P@)')E='9A;"D["@H@("`@("`@(&EF("@D<F5T=F%L*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@<W!A
M=VX@<F-S("@B)R`N("1C;60@+B`G(BD@;VX@(B<@+B`D9FEL97!A=&@@+B`G
M(B`H<F5T=7)N960@)R`N("1R971V86P@+B`G*2<I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1O=71P=70@/2`G)SL*"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1R971U<FY?87)R87D@87,@)&QI;F4I('L*("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@)&QI;F4["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1U;FQO8VME9%]P;W,@/2!S=')P;W,H)&]U='!U="P@)W5N;&]C:V5D
M)RD["@H@("`@("`@("`@("!I9B`H)'5N;&]C:V5D7W!O<R`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@06QR96%D>2!U;FQO8VME9"X*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]60R]C=G,N<&AP````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`Q,#(R-34`,3`U,34T,S$P-C$`,#(P,#,U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W)C<RYP:'`G.PH*+RHJ"B`J(%9#
M7V-V<R!I;7!L96UE;G1A=&EO;BX*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P
M-B!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5D,O5D,O8W9S+G!H<"QV(#$N,S(N,BXR-"`R
M,#`V+S`U+S$R(#`T.C0W.C`X(&-H=6-K($5X<"`D"B`J"B`J($!A=71H;W(@
M($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K
M86=E(%9#"B`J+PIC;&%S<R!60U]C=G,@97AT96YD<R!60U]R8W,@>PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97(@=&AE(&-L87-S(&5X<&5C
M=',N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@/'!R93X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!#=7)R96YT('!A<F%M971E<G,Z"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W-O=7)C97)O;W0G.B!4:&4@
M<V]U<F-E(')O;W0@9F]R('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E<&]S:71O<GD*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`G<&%T:',G.B!(87-H('=I=&@@=&AE(&QO8V%T:6]N
M<R!O9B!A;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!N96-E<W-A<GD@8FEN87)I97,Z("=R8W-D:69F)RP@)W)L;V<G+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C=G-P<R<L("=C
M=G-P<U]H;VUE)R!A;F0@=&AE('1E;7`*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!P871H.B`G=&5M<"<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?
M8W9S*"1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]S;W5R8V5R;V]T
M(#T@)'!A<F%M<ULG<V]U<F-E<F]O="==.PH@("`@("`@("1T:&ES+3Y?<&%T
M:',@/2`D<&%R86US6R=P871H<R==.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES
M1FEL92@D=VAE<F4I"B`@("!["B`@("`@("`@<F5T=7)N($!I<U]F:6QE*"1W
M:&5R92`N("<L=B<I.PH@("`@?0H*("`@(&9U;F-T:6]N("9Q=65R>41I<B@D
M=VAE<F4I"B`@("!["B`@("`@("`@)&1I<B`](&YE=R!60U]$:7)E8W1O<GE?
M8W9S*"1T:&ES+"`D=VAE<F4I.PH@("`@("`@(')E='5R;B`D9&ER.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$-H96-K;W5T*"1F:6QE+"`D<F5V*0H@("`@
M>PH@("`@("`@(')E='5R;B!60U]#:&5C:V]U=%]C=G,Z.F=E="@D=&AI<RP@
M)&9I;&4M/G%U97)Y1G5L;%!A=&@H*2P@)')E=BD["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T1&EF9B@D9FEL92P@)')E=C$L("1R978R+"`D='EP92`]("=C
M;VYT97AT)RP@)&YU;2`](#,L("1W<R`]('1R=64I"B`@("!["B`@("`@("`@
M<F5T=7)N(%9#7T1I9F9?8W9S.CIG970H)'1H:7,L("1F:6QE+"`D<F5V,2P@
M)')E=C(L("1T>7!E+"`D;G5M+"`D=W,I.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9G971&:6QE3V)J96-T*"1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"P@)'%U
M:6-K;&]G(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*'-U8G-T<B@D9FEL
M96YA;64L(#`L(#$I("$]("<O)RD@>PH@("`@("`@("`@("`D9FEL96YA;64@
M/2`G+R<@+B`D9FEL96YA;64["B`@("`@("`@?0H@("`@("`@("1F;R`]("96
M0U]&:6QE7V-V<SHZ9V5T1FEL94]B:F5C="@D=&AI<RP@)'1H:7,M/G-O=7)C
M97)O;W0H*2`N("1F:6QE;F%M92P@)&-A8VAE+"`D<75I8VML;V<I.PH@("`@
M("`@(')E='5R;B`D9F\["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$%N;F]T
M871E3V)J96-T*"1F:6QE;F%M92D*("`@('L*("`@("`@("`D8FQA;64@/2!N
M97<@5D-?06YN;W1A=&5?8W9S*"1T:&ES+"`D9FEL96YA;64L(%5T:6PZ.F=E
M=%1E;7!&:6QE*"=V8R<L('1R=64L("1T:&ES+3Y?<&%T:'-;)W1E;7`G72DI
M.PH@("`@("`@(')E='5R;B`D8FQA;64["B`@("!]"@H@("`@9G5N8W1I;VX@
M)F=E=%!A=&-H<V5T3V)J96-T*"1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"D*
M("`@('L*("`@("`@("`D<&\@/2`F5D-?4&%T8VAS971?8W9S.CIG9710871C
M:'-E=$]B:F5C="@D=&AI<RP@)'1H:7,M/G-O=7)C97)O;W0H*2`N("<O)R`N
M("1F:6QE;F%M92P@)&-A8VAE*3L*("`@("`@("!R971U<FX@)'!O.PH@("`@
M?0H*?0H*+RHJ"B`J(%9#7V-V<R!A;FYO=&%T92!C;&%S<RX*("H*("H@06YI
M;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H
M;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P
M86-K86=E(%9#"B`J+PIC;&%S<R!60U]!;FYO=&%T95]C=G,@>PH*("`@('9A
M<B`D9FEL93L*("`@('9A<B`D<F5P.PH@("`@=F%R("1T;7!F:6QE.PH*("`@
M(&9U;F-T:6]N(%9#7T%N;F]T871E7V-V<R@D<F5P+"`D9FEL92P@)'1M<&9I
M;&4I"B`@("!["B`@("`@("`@)'1H:7,M/G)E<"`]("1R97`["B`@("`@("`@
M)'1H:7,M/F9I;&4@/2`D9FEL93L*("`@("`@("`D=&AI<RT^=&UP9FEL92`]
M("1T;7!F:6QE.PH@("`@?0H*("`@(&9U;F-T:6]N(&1O06YN;W1A=&4H)')E
M=BD*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=&AA="!T:&4@9FEL92!V
M86QU97,@9F]R('1H:7,@;V)J96-T(&ES('9A;&ED+B`J+PH@("`@("`@(&EF
M("AI<U]A*"1T:&ES+3YF:6QE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@
M<W5R92!T:&%T('1H92!C=G-R97`@<&%R86UE=&5R(&ES('9A;&ED+B`J+PH@
M("`@("`@(&EF("AI<U]A*"1T:&ES+3YR97`L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%60U]2979I<VEO;CHZ=F%L:60H)')E=BDI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'=H97)E(#T@)'1H
M:7,M/F9I;&4M/G%U97)Y36]D=6QE4&%T:"@I.PH@("`@("`@("1S;W5R8V5R
M;V]T(#T@)'1H:7,M/G)E<"T^<V]U<F-E<F]O="@I.PH*("`@("`@("`D<&EP
M92`]('!O<&5N*"1T:&ES+3YR97`M/F=E=%!A=&@H)V-V<R<I("X@)R`M;B!S
M97)V97(@/B`G("X@)'1H:7,M/G1M<&9I;&4L(%9#7U=)3D1/5U,@/R`G=V(G
M(#H@)W<G*3L*"B`@("`@("`@)&]U="`](&%R<F%Y*"D["B`@("`@("`@)&]U
M=%M=(#T@(E)O;W0@)'-O=7)C97)O;W0B.PH@("`@("`@("1O=71;72`]("=6
M86QI9"UR97-P;VYS97,@;VL@97)R;W(@5F%L:60M<F5Q=65S=',@0VAE8VME
M9"UI;B!5<&1A=&5D($UE<F=E9"!296UO=F5D($T@12<["B`@("`@("`@)&]U
M=%M=(#T@)U5S955N8VAA;F=E9"<["B`@("`@("`@)&]U=%M=(#T@)T%R9W5M
M96YT("UR)SL*("`@("`@("`D;W5T6UT@/2`B07)G=6UE;G0@)')E=B(["B`@
M("`@("`@)&]U=%M=(#T@(D%R9W5M96YT("1W:&5R92(["B`@("`@("`@)&1I
M<G,@/2!E>'!L;V1E*"<O)RP@9&ER;F%M92@D=VAE<F4I*3L*("`@("`@("!W
M:&EL92`H8V]U;G0H)&1I<G,I*2!["B`@("`@("`@("`@("1O=71;72`]("=$
M:7)E8W1O<GD@)R`N(&EM<&QO9&4H)R\G+"`D9&ER<RD["B`@("`@("`@("`@
M("1O=71;72`]("(D<V]U<F-E<F]O="\B("X@:6UP;&]D92@G+R<L("1D:7)S
M*3L*("`@("`@("`@("`@87)R87E?<&]P*"1D:7)S*3L*("`@("`@("!]"B`@
M("`@("`@)&]U=%M=(#T@)T1I<F5C=&]R>2`N)SL*("`@("`@("`D;W5T6UT@
M/2`D<V]U<F-E<F]O=#L*("`@("`@("`D;W5T6UT@/2`G86YN;W1A=&4G.PH*
M("`@("`@("!F;W)E86-H("@D;W5T(&%S("1L:6YE*2!["B`@("`@("`@("`@
M(&9W<FET92@D<&EP92P@(B1L:6YE7&XB*3L*("`@("`@("!]"B`@("`@("`@
M<&-L;W-E*"1P:7!E*3L*"B`@("`@("`@:68@*"$H)&9L(#T@9F]P96XH)'1H
M:7,M/G1M<&9I;&4L(%9#7U=)3D1/5U,@/R`G<F(G(#H@)W(G*2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&QI
M;F5S(#T@87)R87DH*3L*("`@("`@("`D;&EN92`](&9G971S*"1F;"P@-#`Y
M-BD["@H@("`@("`@("\O(%=I;F1O=W,@=F5R<VEO;G,@;V8@8W9S(&%L=V%Y
M<R!R971U<FX@)'=H97)E('=I=&@@9F]R=V%R9',@<VQA<VAE<RX*("`@("`@
M("!I9B`H5D-?5TE.1$]74RD@>PH@("`@("`@("`@("`D=VAE<F4@/2!S=')?
M<F5P;&%C92A$25)%0U1/4EE?4T5005)!5$]2+"`G+R<L("1W:&5R92D["B`@
M("`@("`@?0H*("`@("`@("!W:&EL92`H)&QI;F4@)B8@(7!R96=?;6%T8V@H
M(GQ>15QS*T%N;F]T871I;VYS(&9O<B`D=VAE<F5\(BP@)&QI;F4I*2!["B`@
M("`@("`@("`@("1L:6YE(#T@9F=E=',H)&9L+"`T,#DV*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A)&QI;F4I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)U5N86)L92!T;R!A;FYO=&%T93L@<V5R=F5R('-A
M:60Z("<@+B`D;&EN92D["B`@("`@("`@?0H*("`@("`@("`D;&EN96YO(#T@
M,3L*("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D9FPL(#0P.38I*2![
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7DU<<RLH6UQD7"Y=*RE<
M<RM<*"@N*RE<<RLH7&0K+5QW*RU<9"LI7"DZ+B@N*BDD+R<L("1L:6YE+"`D
M<F5G<RDI('L*("`@("`@("`@("`@("`@("1E;G1R>2`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`D96YT<GE;)W)E=B==("`@(#T@)')E9W-;,5T["B`@
M("`@("`@("`@("`@("`D96YT<GE;)V%U=&AO<B==(#T@=')I;2@D<F5G<ULR
M72D["B`@("`@("`@("`@("`@("`D96YT<GE;)V1A=&4G72`@(#T@)')E9W-;
M,UT["B`@("`@("`@("`@("`@("`D96YT<GE;)VQI;F4G72`@(#T@)')E9W-;
M-%T["B`@("`@("`@("`@("`@("`D96YT<GE;)VQI;F5N;R==(#T@)&QI;F5N
M;RLK.PH@("`@("`@("`@("`@("`@)&QI;F5S6UT@/2`D96YT<GD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9C;&]S92@D9FPI.PH@("`@
M("`@(')E='5R;B`D;&EN97,["B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&-H
M96-K;W5T(&-L87-S+@H@*@H@*B!3964@=&AE(%)%041-12!F:6QE('1H870@
M8V%M92!W:71H('1H:7,@;&EB<F%R>2!F;W(@;6]R90H@*B!I;F9O<FUA=&EO
M;BP@86YD(')E860@=&AE(&EN;&EN92!D;V-U;65N=&%T:6]N+@H@*@H@*B!!
M;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U
M=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@
M0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7T-H96-K;W5T7V-V<R!["@H@("`@
M+RHJ"B`@("`@*B!3=&%T:6,@9G5N8W1I;VX@=VAI8V@@<F5T=7)N<R!A(&9I
M;&4@<&]I;G1I;F<@=&\@=&AE(&AE860@;V8@=&AE"B`@("`@*B!R97%U97-T
M960@<F5V:7-I;VX@;V8@86X@4D-3(&9I;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M(%9#7V-V<R`D<F5P("`@("`@($$@<F5P;W-I=&]R>2!O8FIE8W0*("`@
M("`J($!P87)A;2!S=')I;F<@)&9U;&QN86UE("!&=6QL>2!Q=6%L:69I960@
M<&%T:&YA;64@;V8@=&AE(&1E<VER960@4D-3"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@9FEL92!T;R!C:&5C:V]U=`H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F5V("`@("`@(%)#4R!R979I<VEO;B!N=6UB97(@=&\@8VAE
M8VL@;W5T"B`@("`@*@H@("`@("H@0')E='5R;B!R97-O=7)C97QO8FIE8W0@
M($5I=&AE<B!A(%!%05)?17)R;W(@;V)J96-T+"!O<B!A('-T<F5A;0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@('!O:6YT97(@=&\@=&AE(&AE
M860@;V8@=&AE(&-H96-K;W5T"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D
M<F5P+"`D9G5L;&YA;64L("1R978I"B`@("!["B`@("`@("`@:68@*"%60U]2
M979I<VEO;CHZ=F%L:60H)')E=BDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@<F5V:7-I;VX@;G5M8F5R)RD["B`@
M("`@("`@?0H*("`@("`@("!I9B`H5D-?5TE.1$]74RD@>PH@("`@("`@("`@
M("`D;6]D92`]("=R8B<["B`@("`@("`@("`@("1Q7VYA;64@/2`G(B<@+B!E
M<V-A<&5S:&5L;&-M9"AS=')?<F5P;&%C92@G7%PG+"`G+R<L("1F=6QL;F%M
M92DI("X@)R(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M;V1E
M(#T@)W(G.PH@("`@("`@("`@("`D<5]N86UE(#T@97-C87!E<VAE;&QA<F<H
M)&9U;&QN86UE*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A*"120U,@/2!P
M;W!E;B@D<F5P+3YG9710871H*"=C;R<I("X@(B`M<"1R978@)'%?;F%M92`R
M/B8Q(BP@)&UO9&4I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G0V]U;&1N7"=T('!E<F9O<FT@8VAE8VMO=70@;V8@=&AE(')E
M<75E<W1E9"!F:6QE)RD["B`@("`@("`@?0H*("`@("`@("`O*B!&:7)S="!L
M:6YE(&9R;VT@8V\@<VAO=6QD(&)E(&]F('1H92!F;W)M(#H*("`@("`@("`@
M*B`O<&%T:"]T;R]F:6QE;F%M92QV("`M+3X@('-T86YD87)D(&]U=`H@("`@
M("`@("`J(&%N9"!W92!C:&5C:R!T:&%T('1H:7,@:7,@=&AE(&-A<V4@86YD
M(&5R<F]R(&]T:&5R=VES90H@("`@("`@("`J+PH*("`@("`@("`D8V\@/2!F
M9V5T<R@D4D-3+"`Q,#(T*3L*("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>
M*%M<4R!=*RDL=EQS*RTM/EQS*W-T*&%N9&%R*3]D(#]O=70H<'5T*3]<<RHD
M+R<L("1C;RP@)')E9W,I('Q\("1R96=S6S%=+B<L=B<@(3T@)&9U;&QN86UE
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;F5X
M<&5C=&5D(&]U='!U="!F<F]M(&-H96-K;W5T.B`G("X@)&-O*3L*("`@("`@
M("!]"@H@("`@("`@("\J($YE>'0@;&EN92!F<F]M(&-O(&ES(&]F('1H92!F
M;W)M.@H@("`@("`@("`J(')E=FES:6]N(#$N,BXS"B`@("`@("`@("H@5$]$
M3SH@8V]M<&%R92!T:&ES('1O("1R978@9F]R(&-O;G-I<W1E;F-Y+"!A=&T@
M=V4@:G5S=`H@("`@("`@("`J("`@("`@(&1I<V-A<F0@=&AE('9A;'5E('1O
M(&UO=F4@:6YP=70@<&]I;G1E<B!A;&]N9R`M(&%V<VT*("`@("`@("`@*B\*
M("`@("`@("`D8V\@/2!F9V5T<R@D4D-3+"`Q,#(T*3L*"B`@("`@("`@<F5T
M=7)N("120U,["B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&1I9F8@8VQA<W,N
M"B`J"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7T1I
M9F9?8W9S('L*"B`@("`O*BH*("`@("`J($]B=&%I;B!T:&4@9&EF9F5R96YC
M97,@8F5T=V5E;B!T=V\@<F5V:7-I;VYS(&]F(&$@9FEL92X*("`@("`J"B`@
M("`@*B!`<&%R86T@5D-?8W9S("1R97`@("`@("`@($$@<F5P;W-I=&]R>2!O
M8FIE8W0N"B`@("`@*B!`<&%R86T@5D-?1FEL95]C=G,@)&9I;&4@(%1H92!D
M97-I<F5D(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978Q("`@("`@
M($]R:6=I;F%L(')E=FES:6]N(&YU;6)E<B!T;R!C;VUP87)E(&9R;VTN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1R978R("`@("`@($YE=R!R979I<VEO;B!N
M=6UB97(@=&\@8V]M<&%R92!A9V%I;G-T+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D='EP92`@("`@("!4:&4@='EP92!O9B!D:69F("AE+F<N("=U;FEF:65D
M)RDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;G5M("`@("`@($YU;6)E<B!O
M9B!L:6YE<R!T;R!B92!U<V5D(&EN(&-O;G1E>'0@86YD"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('5N:69I960@9&EF9G,N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D=W,@("`@("`@(%-H;W<@=VAI=&5S<&%C92!I;B!T
M:&4@9&EF9C\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQB;V]L96%N
M("!&86QS92!O;B!F86EL=7)E+"!O<B!A('-T<FEN9R!C;VYT86EN:6YG('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9&EF9B!O;B!S=6-C
M97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)')E<"P@)&9I;&4L("1R
M978Q+"`D<F5V,BP@)'1Y<&4@/2`G8V]N=&5X="<L("1N=6T@/2`S+`H@("`@
M("`@("`@("`@("`@("1W<R`]('1R=64I"B`@("!["B`@("`@("`@+RH@36%K
M92!S=7)E('1H870@=&AE(&9I;&4@<&%R86UE=&5R(&ES('9A;&ED+B`J+PH@
M("`@("`@(&EF("AI<U]A*"1F:6QE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($-H
M96-K('1H870@=&AE(')E=FES:6]N(&YU;6)E<G,@87)E('9A;&ED+B`J+PH@
M("`@("`@("1R978Q(#T@5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978Q*2`_("1R
M978Q(#H@)S$N,2<["B`@("`@("`@)')E=C(@/2!60U]2979I<VEO;CHZ=F%L
M:60H)')E=C$I(#\@)')E=C(@.B`G,2XQ)SL*"B`@("`@("`@)&9U;&Q.86UE
M(#T@)&9I;&4M/G%U97)Y1G5L;%!A=&@H*3L*("`@("`@("`D9&EF9B`](&%R
M<F%Y*"D["B`@("`@("`@)&]P=&EO;G,@/2`G+6MK("<["B`@("`@("`@:68@
M*"$D=W,I('L*("`@("`@("`@("`@)&]P=',@/2`G("UB0B`G.PH@("`@("`@
M("`@("`D;W!T:6]N<R`N/2`D;W!T<SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;W!T<R`]("<G.PH@("`@("`@('T*("`@("`@("!S=VET8V@@
M*"1T>7!E*2!["B`@("`@("`@8V%S92`G8V]N=&5X="<Z"B`@("`@("`@("`@
M("1O<'1I;VYS(#T@)&]P=',@+B`G+7`@+2UC;VYT97AT/2<@+B`H:6YT*21N
M=6T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=U;FEF:65D
M)SH*("`@("`@("`@("`@)&]P=&EO;G,@/2`D;W!T<R`N("<M<"`M+75N:69I
M960])R`N("AI;G0I)&YU;3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)V-O;'5M;B<Z"B`@("`@("`@("`@("1O<'1I;VYS(#T@)&]P=',@
M+B`G+2US:61E+6)Y+7-I9&4@+2UW:61T:#TQ,C`G.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G960G.@H@("`@("`@("`@("`D;W!T:6]N
M<R`]("1O<'1S("X@)RUE)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H*("`@("`@("`O+R!7:6YD;W=S('9E<G-I;VYS(&]F(&-V<R!A;'=A>7,@
M<F5T=7)N("1W:&5R92!W:71H(&9O<G=A<F1S('-L87-H97,N"B`@("`@("`@
M:68@*%9#7U=)3D1/5U,I('L*("`@("`@("`@("`@)&9U;&Q.86UE(#T@<W1R
M7W)E<&QA8V4H1$E214-43U)97U-%4$%2051/4BP@)R\G+"`D9G5L;$YA;64I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@5$]$3SH@861D(&]P=&EO;G,@9F]R
M("1H<B!O<'1I;VYS("T@:&]W979E<B!T:&5S92!M87D@;F]T(&)E"B`@("`@
M("`@+R\@8V]M<&%T:6)L92!W:71H('-O;64@9&EF9G,N"B`@("`@("`@)&-O
M;6UA;F0@/2`D<F5P+3YG9710871H*"=R8W-D:69F)RD@+B`B("1O<'1I;VYS
M("UR)')E=C$@+7(D<F5V,B!<(B(@+B!E<V-A<&5S:&5L;&-M9"@D9G5L;$YA
M;64I("X@)R(@,CXF,2<["B`@("`@("`@:68@*%9#7U=)3D1/5U,I('L*("`@
M("`@("`@("`@)&-O;6UA;F0@+CT@)R`\("(G("X@7U]&24Q%7U\@+B`G(B<[
M"B`@("`@("`@?0H*("`@("`@("!E>&5C*"1C;VUM86YD+"`D9&EF9BP@)')E
M='9A;"D["B`@("`@("`@<F5T=7)N("@D<F5T=F%L(#X@,"D@/R`D9&EF9B`Z
M(&%R<F%Y*"D["B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&1I<F5C=&]R>2!C
M;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI
M;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@
M5D-?1&ER96-T;W)Y7V-V<R!["@H@("`@=F%R("1R97`["B`@("!V87(@)&1I
M<DYA;64["B`@("!V87(@)&9I;&5S.PH@("`@=F%R("1A='1I8T9I;&5S.PH@
M("`@=F%R("1M97)G961&:6QE<SL*("`@('9A<B`D9&ER<SL*("`@('9A<B`D
M<&%R96YT.PH@("`@=F%R("1M;V1U;&5.86UE.PH@("`@=F%R("1S;W)T1&ER
M.PH*("`@("\J*@H@("`@("H@0W)E871E<R!A($-64R!$:7)E8W1O<GD@;V)J
M96-T('1O('-T;W)E(&EN9F]R;6%T:6]N"B`@("`@*B!A8F]U="!T:&4@9FEL
M97,@:6X@82!S:6YG;&4@9&ER96-T;W)Y(&EN('1H92!R97!O<VET;W)Y+@H@
M("`@("H*("`@("`J($!P87)A;2!60U]C=G,@)')E<"`@("`@("`@("`@02!R
M97!O<VET;W)Y(&]B:F5C=`H@("`@("H@0'!A<F%M('-T<FEN9R`D9&X@("`@
M("`@("`@("!0871H('1O('1H92!D:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@
M5D-?1&ER96-T;W)Y7V-V<R`D<&X@(%1H92!P87)E;G0@5D-?1&ER96-T;W)Y
M('1O('1H:7,@;VYE+@H@("`@("HO"B`@("!F=6YC=&EO;B!60U]$:7)E8W1O
M<GE?8W9S*"1R97`L("1D;BP@)'!N(#T@)R<I"B`@("!["B`@("`@("`@)'1H
M:7,M/G)E<"`]("1R97`["B`@("`@("`@)'1H:7,M/G!A<F5N="`]("1P;CL*
M("`@("`@("`D=&AI<RT^;6]D=6QE3F%M92`]("1D;CL*("`@("`@("`D=&AI
M<RT^9&ER3F%M92`]("1R97`M/G-O=7)C97)O;W0H*2`N("(O)&1N(CL*("`@
M("`@("`D=&AI<RT^9FEL97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YD
M:7)S(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!F
M=6QL>2!Q=6%L:69I960@<&%T:&YA;64@=&\@=&AI<R!D:7)E8W1O<GD@=VET
M:"!N;PH@("`@("H@=')A:6QI;F<@+RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@4&%T:&YA;64@;V8@=&AI<R!D:7)E8W1O<GD*("`@("`J+PH@
M("`@9G5N8W1I;VX@<75E<GE$:7(H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9&ER3F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F<75E<GE$:7),
M:7-T*"D*("`@('L*("`@("`@("!R97-E="@D=&AI<RT^9&ER<RD["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YD:7)S.PH@("`@?0H*("`@(&9U;F-T:6]N("9Q
M=65R>49I;&5,:7-T*"1S:&]W871T:6,@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H)'-H;W=A='1I8R`F)B!I<W-E="@D=&AI<RT^;65R9V5D1FEL97,I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;65R9V5D1FEL97,["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF:6QE
M<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL('1H92!O
M8FIE8W0@=&\@;W!E;B!A;F0@8G)O=W-E(&ET<R!C=7)R96YT(&1I<F5C=&]R
M>2P@86YD"B`@("`@*B!R971R:65V92!A(&QI<W0@;V8@86QL('1H92!O8FIE
M8W1S(&EN('1H97)E+B`@270@=&AE;B!P;W!U;&%T97,*("`@("`J('1H92!F
M:6QE+V1I<F5C=&]R>2!S=&%C:R!A;F0@;6%K97,@:70@879A:6QA8FQE(&9O
M<B!R971R:65V86PN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B
M:F5C="`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@86X@97)R;W(L('1R=64@;VX@
M<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8G)O=W-E1&ER*"1C86-H
M92`](&YU;&PL("1Q=6EC:VQO9R`]('1R=64L("1S:&]W871T:6,@/2!F86QS
M92D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@87)E('1R>6EN9R!T
M;R!L:7-T(&$@9&ER96-T;W)Y("HO"B`@("`@("`@:68@*"%`:7-?9&ER*"1T
M:&ES+3YD:7).86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G56YA8FQE('1O(&9I;F0@9&ER96-T;W)Y("<@+B`D=&AI<RT^
M9&ER3F%M92D["B`@("`@("`@?0H*("`@("`@("`O*B!/<&5N('1H92!D:7)E
M8W1O<GD@9F]R(')E861I;F<@:71S(&-O;G1E;G1S("HO"B`@("`@("`@:68@
M*"$H)$1)4B`]($!O<&5N9&ER*"1T:&ES+3YD:7).86UE*2DI('L*("`@("`@
M("`@("`@)&5R<FUS9R`]("@A96UP='DH)'!H<%]E<G)O<FUS9RDI(#\@)'!H
M<%]E<G)O<FUS9R`Z("=097)M:7-S:6]N(&1E;FEE9"<["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)M<V<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0W)E871E('1W;R!A<G)A>7,@+2!O;F4@;V8@86QL('1H
M92!F:6QE<RP@86YD('1H92!O=&AE<B!O9@H@("`@("`@("`J(&%L;"!T:&4@
M9&ER96-T;W)I97,N("HO"B`@("`@("`@=VAI;&4@*"@D;F%M92`](')E861D
M:7(H)$1)4BDI("$]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H)&YA;64@
M/3T@)RXG('Q\("1N86UE(#T]("<N+B<I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&%T:"`]("1T
M:&ES+3YD:7).86UE("X@)R\G("X@)&YA;64["B`@("`@("`@("`@(&EF("A`
M:7-?9&ER*"1P871H*2D@>PH@("`@("`@("`@("`@("`@+RH@4VMI<"!!='1I
M8R!D:7)E8W1O<GDN("HO"B`@("`@("`@("`@("`@("!I9B`H)&YA;64@(3T@
M)T%T=&EC)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD:7)S6UT@
M/2`D;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M:68@*$!I<U]F:6QE*"1P871H*2`F)B!S=6)S='(H)&YA;64L("TR*2`]/2`G
M+'8G*2!["B`@("`@("`@("`@("`@("`O*B!3<&%W;B!A(&YE=R!F:6QE(&]B
M:F5C="!T;R!R97!R97-E;G0@=&AI<R!F:6QE+B`J+PH@("`@("`@("`@("`@
M("`@)&9L(#T@)'1H:7,M/G)E<"T^9V5T1FEL94]B:F5C="AS=6)S='(H)'!A
M=&@L('-T<FQE;B@D=&AI<RT^<F5P+3YS;W5R8V5R;V]T*"DI+"`M,BDL("1C
M86-H92P@)'%U:6-K;&]G*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1F
M;"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D9FP["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YF:6QE<UM=(#T@)&9L.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#;&]S92!T
M:&4@9FEL96AA;F1L93L@=V4G=F4@;F]W(&=O="!A(&QI<W0@;V8@9&ER<R!A
M;F0*("`@("`@("`@*B!F:6QE<RX@*B\*("`@("`@("!C;&]S961I<B@D1$E2
M*3L*"B`@("`@("`@+RH@268@=V4@=V%N="!T;R!M97)G92!T:&4@871T:6,L
M(&%D9"!I="!I;B!H97)E+B`J+PH@("`@("`@(&EF("@D<VAO=V%T=&EC*2![
M"B`@("`@("`@("`@("1A='1I8T1I<B`](&YE=R!60U]$:7)E8W1O<GE?8W9S
M*"1T:&ES+3YR97`L("1T:&ES+3YM;V1U;&5.86UE("X@)R]!='1I8R<L("1T
M:&ES*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1A='1I8T1I<BT^8G)O=W-E
M1&ER*"1C86-H92P@)'%U:6-K;&]G*2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F%T=&EC1FEL97,@/2`D871T:6-$:7(M/G%U
M97)Y1FEL94QI<W0H*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM97)G961&
M:6QE<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3YF:6QE<RP@)'1H:7,M/F%T=&EC
M1FEL97,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@=&AE(&-O;G1E
M;G1S(&]F('1H92!D:7)E8W1O<GD@:6X@82!G:79E;B!F87-H:6]N(&%N9`H@
M("`@("H@;W)D97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AO
M=R`@3V8@=&AE(&9O<FT@5D-?4T]25%\J('=H97)E("H@8V%N(&)E.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@3D].12P@3D%-12P@04=%+"!2158@
M9F]R('-O<G1I;F<@8GD@;F%M92P@86=E(&]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!R979I<VEO;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1D
M:7(@($]F('1H92!F;W)M(%9#7U-/4E1?*B!W:&5R92`J(&-A;B!B93H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@($%30T5.1$E.1RP@1$530T5.1$E.
M1R!F;W(@=&AE(&]R9&5R(&]F('1H92!S;W)T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A<'!L>5-O<G0H)&AO=R`](%9#7U-/4E1?3D].12P@)&1I<B`](%9#
M7U-/4E1?05-#14Y$24Y'*0H@("`@>PH@("`@("`@("\O($%L=V%Y<R!S;W)T
M(&1I<F5C=&]R:65S(&)Y(&YA;64N"B`@("`@("`@;F%T8V%S97-O<G0H)'1H
M:7,M/F1I<G,I.PH*("`@("`@("`D=&AI<RT^9&]&:6QE4V]R="@D=&AI<RT^
M9FEL97,L("1H;W<L("1D:7(I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M871T:6-&:6QE<RDI('L*("`@("`@("`@("`@)'1H:7,M/F1O1FEL95-O<G0H
M)'1H:7,M/F%T=&EC1FEL97,L("1H;W<L("1D:7(I.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/FUE<F=E9$9I;&5S*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^9&]&:6QE4V]R="@D=&AI<RT^;65R9V5D1FEL97,L("1H
M;W<L("1D:7(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D;T9I
M;&53;W)T*"8D9FEL94QI<W0L("1H;W<@/2!60U]33U)47TY/3D4L("1D:7(@
M/2!60U]33U)47T%30T5.1$E.1RD*("`@('L*("`@("`@("`D=&AI<RT^<V]R
M=$1I<B`]("1D:7(["@H@("`@("`@('-W:71C:"`H)&AO=RD@>PH@("`@("`@
M(&-A<V4@5D-?4T]25%]!1T4Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES
M="P@87)R87DH)'1H:7,L("=F:6QE06=E4V]R="<I*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@5D-?4T]25%].04U%.@H@("`@("`@("`@
M("!U<V]R="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL94YA;653;W)T
M)RDI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)4
M7T%55$A/4CH*("`@("`@("`@("`@=7-O<G0H)&9I;&5,:7-T+"!A<G)A>2@D
M=&AI<RP@)V9I;&5!=71H;W)3;W)T)RDI.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92!60U]33U)47U)%5CH*("`@("`@("`@("`@=7-O<G0H
M)&9I;&5,:7-T+"!A<G)A>2@D=&AI<RP@)V9I;&529793;W)T)RDI.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('5N<V5T*"1T:&ES
M+3YS;W)T1&ER*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I
M;VX@9F]R(&9I;&4@86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE06=E
M4V]R="@D82P@)&(I"B`@("!["B`@("`@("`@)&%A(#T@)&$M/G%U97)Y3&%S
M=$QO9R@I.PH@("`@("`@("1B8B`]("1B+3YQ=65R>4QA<W1,;V<H*3L*("`@
M("`@("!I9B`H)&%A+3YQ=65R>41A=&4H*2`]/2`D8F(M/G%U97)Y1&%T92@I
M*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T@96QS96EF("@D
M=&AI<RT^<V]R=$1I<B`]/2!60U]33U)47T%30T5.1$E.1RD@>PH@("`@("`@
M("`@("!R971U<FX@*"1A82T^<75E<GE$871E*"D@/"`D8F(M/G%U97)Y1&%T
M92@I*2`_(#$@.B`M,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@*"1B8BT^<75E<GE$871E*"D@/"`D86$M/G%U97)Y1&%T92@I*2`_
M(#$@.B`M,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T
M(&9U;F-T:6]N(&)Y(&%U=&AO<B!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!F:6QE075T:&]R4V]R="@D82P@)&(I"B`@("!["B`@("`@("`@)&%A(#T@
M)&$M/G%U97)Y3&%S=$QO9R@I.PH@("`@("`@("1B8B`]("1B+3YQ=65R>4QA
M<W1,;V<H*3L*("`@("`@("!I9B`H)&%A+3YQ=65R>4%U=&AO<B@I(#T]("1B
M8BT^<75E<GE!=71H;W(H*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!](&5L<V5I9B`H)'1H:7,M/G-O<G1$:7(@/3T@5D-?4T]25%]!4T-%
M3D1)3D<I('L*("`@("`@("`@("`@<F5T=7)N("@D86$M/G%U97)Y075T:&]R
M*"D@/B`D8F(M/G%U97)Y075T:&]R*"DI(#\@,2`Z("TQ.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`H)&)B+3YQ=65R>4%U=&AO<B@I
M(#X@)&%A+3YQ=65R>4%U=&AO<B@I*2`_(#$@.B`M,3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&9U;F-T:6]N(&9O<B!F:6QE;F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL94YA;653;W)T*"1A+"`D8BD*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/G-O<G1$:7(@/3T@5D-?4T]25%]!
M4T-%3D1)3D<I('L*("`@("`@("`@("`@<F5T=7)N('-T<F-A<V5C;7`H)&$M
M/FYA;64L("1B+3YN86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@<W1R8V%S96-M<"@D8BT^;F%M92P@)&$M/FYA;64I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I;VX@9F]R
M(')E=FES:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE4F5V4V]R="@D
M82P@)&(I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YS;W)T1&ER(#T](%9#
M7U-/4E1?05-#14Y$24Y'*2!["B`@("`@("`@("`@(')E='5R;B!60U]2979I
M<VEO;CHZ8VUP*"1A+3YQ=65R>4AE860H*2P@)&(M/G%U97)Y2&5A9"@I*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@5D-?4F5V:7-I
M;VXZ.F-M<"@D8BT^<75E<GE(96%D*"DL("1A+3YQ=65R>4AE860H*2D["B`@
M("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!F:6QE(&-L87-S+@H@
M*@H@*B!#;W!Y<FEG:'0@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I
M;"YO<F<^"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL
M0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]&:6QE
M7V-V<R!E>'1E;F1S(%9#7T9I;&4@>PH*("`@("\J*@H@("`@("H@0W)E871E
M(&$@<F5P;W-I=&]R>2!F:6QE(&]B:F5C="P@86YD(&=I=F4@:70@:6YF;W)M
M871I;VX@86)O=70*("`@("`J('=H870@:71S('!A<F5N="!D:7)E8W1O<GD@
M86YD(')E<&]S:71O<GD@;V)J96-T<R!A<F4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FP@($9U;&P@<&%T:"!T;R!T:&ES(&9I;&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%9#7T9I;&5?8W9S*"1F;"P@)'%U:6-K;&]G(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)&9L("X]("<L=B<["B`@("`@("`@)'1H
M:7,M/FYA;64@/2!B87-E;F%M92@D9FPI.PH@("`@("`@("1T:&ES+3YD:7(@
M/2!D:7)N86UE*"1F;"D["B`@("`@("`@)'1H:7,M/FQO9W,@/2!A<G)A>2@I
M.PH@("`@("`@("1T:&ES+3YQ=6EC:VQO9R`]("1Q=6EC:VQO9SL*("`@("`@
M("`D=&AI<RT^<F5V<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/F)R86YC
M:&5S(#T@87)R87DH*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T1FEL94]B
M:F5C="@D<F5P+"`D9FEL96YA;64L("1C86-H92`](&YU;&PL("1Q=6EC:VQO
M9R`](&9A;'-E*0H@("`@>PH@("`@("`@("\J(%1H92!V97)S:6]N(&]F('1H
M92!C86-H960@9&%T82X@26YC<F5M96YT('1H:7,@=VAE;F5V97(@=&AE"B`@
M("`@("`@("H@:6YT97)N86P@<W1O<F%G92!F;W)M870@8VAA;F=E<RP@<W5C
M:"!T:&%T('=E(&UU<W0*("`@("`@("`@*B!I;G9A;&ED871E('!R:6]R(&-A
M8VAE9"!D871A+B`J+PH@("`@("`@("1C86-H959E<G-I;VX@/2`R.PH@("`@
M("`@("1C86-H94ED(#T@)')E<"T^<V]U<F-E<F]O="@I("X@)U]N)R`N("1F
M:6QE;F%M92`N("=?9B<@+B`H:6YT*21Q=6EC:VQO9R`N("=?=B<@+B`D8V%C
M:&5697)S:6]N.PH*("`@("`@("`D8W1I;64@/2!T:6UE*"D@+2!`9FEL96UT
M:6UE*"1F:6QE;F%M92`N("<L=B<I.PH@("`@("`@(&EF("@D8V%C:&4@)B8*
M("`@("`@("`@("`@)&-A8VAE+3YE>&ES=',H)&-A8VAE260L("1C=&EM92DI
M('L*("`@("`@("`@("`@)&9I;&5/8B`]('5N<V5R:6%L:7IE*"1C86-H92T^
M9V5T*"1C86-H94ED+"`D8W1I;64I*3L*("`@("`@("`@("`@)&9I;&5/8BT^
M<V5T4F5P;W-I=&]R>2@D<F5P*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D9FEL94]B(#T@;F5W(%9#7T9I;&5?8W9S*"1F:6QE;F%M92P@)'%U
M:6-K;&]G*3L*("`@("`@("`@("`@)&9I;&5/8BT^<V5T4F5P;W-I=&]R>2@D
M<F5P*3L*("`@("`@("`@("`@:68@*&ES7V$H*"1R97-U;'0@/2`D9FEL94]B
M+3YG971"<F]W<V5);F9O*"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D9FEL94]B+3YA<'!L>5-O<G0H5D-?4T]25%]!1T4I.PH*("`@("`@
M("`@("`@:68@*"1C86-H92D@>PH@("`@("`@("`@("`@("`@)&-A8VAE+3YS
M970H)&-A8VAE260L('-E<FEA;&EZ92@D9FEL94]B*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL94]B.PH@("`@?0H*
M("`@("\J*@H@("`@("H@268@=&AI<R!F:6QE(&ES('!R97-E;G0@:6X@86X@
M071T:6,@9&ER96-T;W)Y+"!T:&ES(&EN9&EC871E<PH@("`@("H@:70N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&9I;&4@:7,@
M:6X@=&AE($%T=&EC+"!A;F0@9F%L<V4@;W1H97)W:7-E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES071T:6-&:6QE*"D*("`@('L*("`@("`@("!R971U<FX@
M<W5B<W1R*"1T:&ES+3YD:7(L("TU*2`]/2`G071T:6,G.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F%M92!O9B!T:&4@8W5R<F5N="!F
M:6QE(&%S(&EN('1H92!R97!O<VET;W)Y"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@($9I;&5N86UE("AW:71H;W5T('1H92!P871H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=65R>5)E<&]S:71O<GE.86UE*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/FYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&YA;64@;V8@=&AE(&-U<G)E;G0@9FEL92!W:71H;W5T('1H
M92!R97!O<VET;W)Y"B`@("`@*B!E>'1E;G-I;VYS("AU<W5A;&QY("QV*0H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!&:6QE;F%M92!W:71H;W5T
M(')E<&]S:71O<GD@97AT96YS:6]N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U
M97)Y3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G
M+RQV)"\G+"`G)RP@)'1H:7,M/FYA;64I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!L87-T(')E=FES:6]N(&]F('1H92!C=7)R96YT(&9I
M;&4@;VX@=&AE($A%040@8G)A;F-H"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F=\;V)J96-T("!,87-T(')E=FES:6]N(&]F('1H92!C=7)R96YT(&9I
M;&4@;W(@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>5)E=FES
M:6]N*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YR979S6S!=
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@
M<F5V:7-I;VYS)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^
M<F5V<ULP73L*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>5!R979I;W5S4F5V
M:7-I;VXH)')E=BD*("`@('L*("`@("`@("!R971U<FX@5D-?4F5V:7-I;VXZ
M.G!R978H)')E=BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M($A%040@*&UO<W0@<F5C96YT*2!R979I<VEO;B!N=6UB97(@9F]R('1H:7,@
M9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@2$5!1"!R979I
M<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE(96%D*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FAE860["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(&QA<W0@5D-?;&]G(&]B:F5C="!I;B!T
M:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%9#7VQO9R!O9B!T:&4@
M;&%S="!E;G1R>2!I;B!T:&4@9FEL90H@("`@("HO"B`@("!F=6YC=&EO;B!Q
M=65R>4QA<W1,;V<H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/G)E=G-;,%TI('Q\("%I<W-E="@D=&AI<RT^;&]G<ULD=&AI<RT^<F5V<ULP
M75TI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.
M;R!R979I<VEO;G,G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YL;V=S6R1T:&ES+3YR979S6S!=73L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-O<G0@=&AE(&QI<W0@;V8@5D-?;&]G(&]B:F5C=',@=&AA="!T:&ES(&9I
M;&4@8V]N=&%I;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AO
M=R`@5D-?4T]25%]2158@*'-O<G0@8GD@<F5V:7-I;VXI+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@5D-?4T]25%].04U%("AS;W)T(&)Y(&%U=&AO
M<B!N86UE*2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@(%9#7U-/4E1?
M04=%("AS;W)T(&)Y(&-O;6UI="!D871E*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!A<'!L>5-O<G0H)&AO=R`](%9#7U-/4E1?4D56*0H@("`@>PH@("`@("`@
M('-W:71C:"`H)&AO=RD@>PH@("`@("`@(&-A<V4@5D-?4T]25%].04U%.@H@
M("`@("`@("`@("`D9G5N8R`]("=.86UE)SL*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@5D-?4T]25%]!1T4Z"B`@("`@("`@("`@("1F=6YC
M(#T@)T%G92<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9#
M7U-/4E1?4D56.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1F=6YC
M(#T@)U)E=FES:6]N)SL*("`@("`@("!]"@H@("`@("`@('5A<V]R="@D=&AI
M<RT^;&]G<RP@87)R87DH)'1H:7,L(")S;W)T0GDD9G5N8R(I*3L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!S;W)T
M0GDJ*"D@9G5N8W1I;VYS(&%R92!I;G1E<FYA;&QY('5S960@8GD@87!P;'E3
M;W)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T0GE2979I<VEO;B@D82P@
M)&(I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIC;7`H)&(M
M/G)E=BP@)&$M/G)E=BD["B`@("!]"@H@("`@9G5N8W1I;VX@<V]R=$)Y06=E
M*"1A+"`D8BD*("`@('L*("`@("`@("!R971U<FX@)&(M/F1A=&4@+2`D82T^
M9&%T93L*("`@('T*"B`@("!F=6YC=&EO;B!S;W)T0GE.86UE*"1A+"`D8BD*
M("`@('L*("`@("`@("!R971U<FX@<W1R8VUP*"1A+3YA=71H;W(L("1B+3YA
M=71H;W(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&]P=6QA=&4@=&AE(&]B
M:F5C="!W:71H(&EN9F]R;6%T:6]N(&%B;W5T('1H92!R979I<VEO;G,@;&]G
M<R!A;F0@9&%T97,*("`@("`J(&]F('1H92!F:6QE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;GQO8FIE8W0@(%!%05)?17)R;W(@;V)J96-T(&]N
M(&5R<F]R+"!O<B!T<G5E(&]N('-U8V-E<W,*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0G)O=W-E26YF;R@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@=&AA
M="!W92!A<F4@86-T=6%L;'D@:6X@=&AE(&9I;&5S>7-T96TN("HO"B`@("`@
M("`@)&9I;&4@/2`D=&AI<RT^<75E<GE&=6QL4&%T:"@I.PH@("`@("`@(&EF
M("@A:7-?9FEL92@D9FEL92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T9I;&4@3F]T($9O=6YD.B`G("X@)&9I;&4I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0V%L;"!T:&4@4D-3(')L;V<@8V]M;6%N9"!T
M;R!R971R:65V92!T:&4@9FEL90H@("`@("`@("`J(&EN9F]R;6%T:6]N+B`J
M+PH@("`@("`@("1F;&%G(#T@)'1H:7,M/G%U:6-K;&]G(#\@)R`M<B`G(#H@
M)R`G.PH@("`@("`@("1Q7V9I;&4@/2!60U]724Y$3U=3(#\@)R(G("X@97-C
M87!E<VAE;&QC;60H)&9I;&4I("X@)R(G(#H@97-C87!E<VAE;&QA<F<H)&9I
M;&4I.PH*("`@("`@("`D8VUD(#T@)'1H:7,M/G)E<"T^9V5T4&%T:"@G<FQO
M9R<I("X@)&9L86<@+B`D<5]F:6QE.PH@("`@("`@(&5X96,H)&-M9"P@)')E
M='5R;E]A<G)A>2P@)')E='9A;"D["@H@("`@("`@(&EF("@D<F5T=F%L*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@
M=&\@<W!A=VX@<FQO9R!T;R!R971R:65V92!F:6QE(&QO9R!I;F9O<FUA=&EO
M;B!F;W(@)R`N("1F:6QE*3L*("`@("`@("!]"@H@("`@("`@("1A8V-U;2`]
M(&%R<F%Y*"D["B`@("`@("`@)'-Y;7)E=B`](&%R<F%Y*"D["B`@("`@("`@
M)')E=G-Y;2`](&%R<F%Y*"D["B`@("`@("`@)'-T871E(#T@)VEN:70G.PH@
M("`@("`@(&9O<F5A8V@@*"1R971U<FY?87)R87D@87,@)&QI;F4I('L*("`@
M("`@("`@("`@<W=I=&-H("@D<W1A=&4I('L*("`@("`@("`@("`@8V%S92`G
M:6YI="<Z"B`@("`@("`@("`@("`@("!I9B`H(7-T<FYC;7`H)VAE860Z("<L
M("1L:6YE+"`V*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH96%D
M(#T@<W5B<W1R*"1L:6YE+"`V*3L*("`@("`@("`@("`@("`@('T@96QS96EF
M("@A<W1R;F-M<"@G8G)A;F-H.B<L("1L:6YE+"`W*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1S=&%T92`]("=R978G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=R978G
M.@H@("`@("`@("`@("`@("`@:68@*"%S=')N8VUP*"<M+2TM+2TM+2TM)RP@
M)&QI;F4L(#$P*2D@>PH@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=I
M;F9O)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<WEM<F5V(#T@)'-Y
M;7)E=CL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<F5V<WEM(#T@)')E
M=G-Y;3L*("`@("`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O
M7EQS*RA;7CI=*RDZ7',K*%M<9%PN72LI+R(L("1L:6YE+"`D<F5G<RDI('L*
M("`@("`@("`@("`@("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=&AI<R!I
M<R!A(&)R86YC:`H@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O7BA<9"LH7"Y<9"LI*RE<+C!<+BA<9"LI)"\G+"1R96=S6S)=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8G)A;F-H4F5V(#T@5D-?4F5V:7-I
M;VXZ.G1O0G)A;F-H*"1R96=S6S)=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^8G)A;F-H97-;)&)R86YC:%)E=ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8G)A;F-H97-;
M)&)R86YC:%)E=ET@/2`D<F5G<ULQ73L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1S>6UR979;)')E9W-;,5U=(#T@)')E9W-;,ET["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<F5V<WEM6R1R96=S
M6S)=72DI("1R979S>6U;)')E9W-;,EU=/6%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1R979S>6U;)')E9W-;,EU=6UT@/2`D<F5G<ULQ73L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VEN9F\G.@H@
M("`@("`@("`@("`@("`@:68@*'-T<FYC;7`H)ST]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/2<L("1L:6YE+"`S,"D@)B8*("`@("`@("`@("`@("`@
M("`@("!S=')C;7`H)RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TG+"`D
M;&EN92DI('L*("`@("`@("`@("`@("`@("`@("`D86-C=6U;72`]("1L:6YE
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1A8V-U;2DI('L*
M("`@("`@("`@("`@("`@("`@("`O+R!S<&%W;B!A(&YE=R!60U]L;V<@;V)J
M96-T(&%N9"!A9&0@:70@=&\@=&AE(&QO9W,@:&%S:`H@("`@("`@("`@("`@
M("`@("`@("1L;V<@/2!N97<@5D-?3&]G7V-V<R@D=&AI<RD["B`@("`@("`@
M("`@("`@("`@("`@)&5R<B`]("1L;V<M/G!R;V-E<W-,;V<H)&%C8W5M*3L*
M("`@("`@("`@("`@("`@("`@("`O+R!43T1/.B!E<G)O<B!C:&5C:W,@+2!A
M=G-M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9W-;)&QO9RT^<75E
M<GE2979I<VEO;B@I72`]("1L;V<["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G)E=G-;72`]("1L;V<M/G%U97)Y4F5V:7-I;VXH*3L*("`@("`@("`@
M("`@("`@("`@("`D86-C=6T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!F=6QL>2!Q=6%L:69I960@9FEL96YA;64@;V8@=&AI
M<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!&=6QL>2!Q=6%L:69I
M960@9FEL96YA;64@;V8@=&AI<R!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I
M;VX@<75E<GE&=6QL4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YD:7(@+B`G+R<@+B`D=&AI<RT^;F%M93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@;F%M92!O9B!T:&ES(&9I;&4@<F5L871I=F4@=&\@
M:71S('-O=7)C97)O;W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%!A=&AN86UE(')E;&%T:79E('1O('1H92!S;W5R8V5R;V]T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=65R>4UO9'5L95!A=&@H*0H@("`@>PH@("`@("`@
M(')E='5R;B!P<F5G7W)E<&QA8V4H)WQ>)RX@)'1H:7,M/G)E<"T^<V]U<F-E
M<F]O="@I("X@)R\_*"XJ*2QV)'PG+"`G7#$G+"`D=&AI<RT^<75E<GE&=6QL
M4&%T:"@I*3L*("`@('T*"GT*"B\J*@H@*B!60U]C=G,@;&]G(&-L87-S+@H@
M*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?3&]G7V-V<R!["@H@
M("`@=F%R("1R97`["B`@("!V87(@)&9I;&4["B`@("!V87(@)'1A9W,["B`@
M("!V87(@)')E=CL*("`@('9A<B`D9&%T93L*("`@('9A<B`D;&]G.PH@("`@
M=F%R("1A=71H;W(["B`@("!V87(@)'-T871E.PH@("`@=F%R("1L:6YE<SL*
M("`@('9A<B`D8G)A;F-H97,["@H@("`@+RHJ"B`@("`@*@H@("`@("HO"B`@
M("!F=6YC=&EO;B!60U],;V=?8W9S*"1F;"D*("`@('L*("`@("`@("`D=&AI
M<RT^9FEL92`]("1F;#L*("`@("`@("`D=&AI<RT^8G)A;F-H97,@/2!A<G)A
M>2@I.PH@("`@?0H*("`@(&9U;F-T:6]N('!R;V-E<W-,;V<H)')A=RD*("`@
M('L*("`@("`@("`O*B!);FET:6%L:7-E(&$@<VEM<&QE('-T871E(&UA8VAI
M;F4@=&\@<&%R<V4@=&AE(&]U='!U="!O9B!R;&]G("HO"B`@("`@("`@)'-T
M871E(#T@)VEN:70G.PH@("`@("`@('=H:6QE("@A96UP='DH)')A=RD@)B8@
M)'-T871E("$]("=D;VYE)RD@>PH@("`@("`@("`@("!S=VET8V@@*"1S=&%T
M92D@>PH@("`@("`@("`@("`O*B!&;W5N9"!F:6QE;F%M92P@;F]W(&QO;VMI
M;F<@9F]R('1H92!R979I<VEO;B!N=6UB97(@*B\*("`@("`@("`@("`@8V%S
M92`G:6YI="<Z"B`@("`@("`@("`@("`@("`D;&EN92`](&%R<F%Y7W-H:69T
M*"1R87<I.PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]R979I
M<VEO;B`H+BLI)"\B+"`D;&EN92P@)'!A<G1S*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YR978@/2`D<&%R='-;,5T["B`@("`@("`@("`@("`@
M("`@("`@)'-T871E(#T@)V1A=&4G.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O*B!&;W5N9"!R979I
M<VEO;B!A;F0@9FEL96YA;64L(&YO=R!L;V]K:6YG(&9O<B!D871E("HO"B`@
M("`@("`@("`@(&-A<V4@)V1A=&4G.@H@("`@("`@("`@("`@("`@)&QI;F4@
M/2!A<G)A>5]S:&EF="@D<F%W*3L*("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*")\7F1A=&4Z7',K*%QD*RE;+2]=*%QD*RE;+2]=*%QD*RE<<RLH
M7&0K*3HH7&0K*3HH7&0K*2XJ/SM<<RMA=71H;W(Z7',K*"XK*3M<<RMS=&%T
M93I<<RLH7%,K*3LH7',K;&EN97,Z7',K*%LP+3E<<RLM72LI*3]\(BP@)&QI
M;F4L("1P87)T<RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&%T
M92`](&=M;6MT:6UE*"1P87)T<ULT72P@)'!A<G1S6S5=+"`D<&%R='-;-ETL
M("1P87)T<ULR72P@)'!A<G1S6S-=+"`D<&%R='-;,5TI.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YA=71H;W(@/2`D<&%R='-;-UT["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-T871E(#T@)'!A<G1S6SA=.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL:6YE<R`](&ES<V5T*"1P87)T<ULQ,%TI
M(#\@)'!A<G1S6S$P72`Z("<G.PH@("`@("`@("`@("`@("`@("`@("1S=&%T
M92`]("=B<F%N8VAE<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("\J($QO;VL@9F]R(&$@8G)A;F-H
M('!O:6YT(&AE<F4@+2!F;W)M870@:7,@)V)R86YC:&5S.B`@>"YY+GH[("!A
M+F(N8SLG("HO"B`@("`@("`@("`@(&-A<V4@)V)R86YC:&5S)SH*("`@("`@
M("`@("`@("`@("\J($EF('=E(&9I;F0@82!B<F%N8V@@=&%G+"!P<F]C97-S
M(&%N9"!P;W`@:70L"B`@("`@("`@("`@("`@("`@("!O=&AE<G=I<V4@;&5A
M=F4@:6YP=70@<W1R96%M('5N=&]U8VAE9"`J+PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D<F%W*2`F)B!P<F5G7VUA=&-H*"(O7F)R86YC:&5S.EQS
M*R@N*BDO(BP@)')A=ULP72P@)&)R*2D@>PH@("`@("`@("`@("`@("`@("`@
M("\J($=E="!T:&4@;&ES="!O9B!B<F%N8VAE<R!F<F]M('1H92!S=')I;F<L
M(&%N9`H@("`@("`@("`@("`@("`@("`@("`J('!U<V@@=F%L:60@<F5V:7-I
M;VYS(&EN=&\@=&AE(&)R86YC:&5S(&%R<F%Y("HO"B`@("`@("`@("`@("`@
M("`@("`@)&)R<R`]('!R96=?<W!L:70H)R\[7',J+R<L("1B<ELQ72D["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&)R<R!A<R`D8G)P;VEN="D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H5D-?4F5V:7-I;VXZ.G9A
M;&ED*"1B<G!O:6YT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F)R86YC:&5S6UT@/2`D8G)P;VEN=#L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]S:&EF="@D<F%W*3L*"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)'-T871E(#T@)V1O;F4G.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($%S<W5M92!T:&4@<F5S="!O9B!T:&4@;&EN97,@87)E('1H92!L;V<@
M;65S<V%G92`J+PH@("`@("`@("1T:&ES+3YL;V<@/2!I;7!L;V1E*")<;B(L
M("1R87<I.PH@("`@("`@("1T:&ES+3YT86=S(#T@0"1T:&ES+3YF:6QE+3YR
M979S>6U;)'1H:7,M/G)E=ET["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YT
M86=S*2D@>PH@("`@("`@("`@("`D=&AI<RT^=&%G<R`](&%R<F%Y*"D["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y1&%T92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YD871E.PH@("`@?0H*("`@(&9U;F-T
M:6]N('%U97)Y4F5V:7-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^<F5V.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y075T:&]R*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/F%U=&AO<CL*("`@('T*"B`@("!F
M=6YC=&EO;B!Q=65R>4QO9R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YL;V<["B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE#:&%N9V5D3&EN97,H
M*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^;&EN97,I(#\@
M*"1T:&ES+3YL:6YE<RD@.B`G)SL*("`@('T*"B`@("`O*BH*("`@("`J($=I
M=F5N(&$@8G)A;F-H(')E=FES:6]N(&YU;6)E<BP@=&AI<R!F=6YC=&EO;B!R
M96UA<',@:70*("`@("`J(&%C8V]R9&EN9VQY+"!A;F0@<&5R9F]R;7,@82!L
M;V]K=7`@;VX@=&AE(&9I;&4@;V)J96-T('1O"B`@("`@*B!R971U<FX@=&AE
M('-Y;6)O;&EC(&YA;64H<RD@;V8@=&AA="!B<F%N8V@@:6X@=&AE('1R964N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@2&%S:"!O9B!S>6UB;VQI
M8R!N86UE<R`]/B!B<F%N8V@@;G5M8F5R<PH@("`@("HO"B`@("!F=6YC=&EO
M;B!Q=65R>5-Y;6)O;&EC0G)A;F-H97,H*0H@("`@>PH@("`@("`@("1S>6U"
M<F%N8VAE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F)R
M86YC:&5S(&%S("1B<F%N8V@I('L*("`@("`@("`@("`@)'!A<G1S(#T@97AP
M;&]D92@G+B<L("1B<F%N8V@I.PH@("`@("`@("`@("`D;&%S="`](&%R<F%Y
M7W!O<"@D<&%R=',I.PH@("`@("`@("`@("`D<&%R='-;72`]("<P)SL*("`@
M("`@("`@("`@)'!A<G1S6UT@/2`D;&%S=#L*("`@("`@("`@("`@)')E=B`]
M(&EM<&QO9&4H)RXG+"`D<&%R=',I.PH@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F9I;&4M/F)R86YC:&5S6R1B<F%N8VA=*2D@>PH@("`@("`@("`@
M("`@("`@)'-Y;4)R86YC:&5S6R1T:&ES+3YF:6QE+3YB<F%N8VAE<ULD8G)A
M;F-H75T@/2`D8G)A;F-H.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<WEM0G)A;F-H97,["B`@("!]"@I]"@HO*BH*("H@5D-?
M8W9S(%!A=&-H<V5T(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@06YI;"!-861H
M879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@($%N
M:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E
M(%9#"B`J+PIC;&%S<R!60U]0871C:'-E=%]C=G,@97AT96YD<R!60U]0871C
M:'-E="!["@H@("`@=F%R("1?9&ER.PH@("`@=F%R("1?;F%M93L*"B`@("`O
M*BH*("`@("`J($-R96%T92!A('!A=&-H<V5T(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("!4:&4@9FEL96YA;64@=&\@9V5T
M('!A=&-H<V5T<R!F;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7U!A=&-H
M<V5T7V-V<R@D9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@/2!B
M87-E;F%M92@D9FEL92D["B`@("`@("`@)'1H:7,M/E]D:7(@/2!D:7)N86UE
M*"1F:6QE*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4&%T8VAS971/8FIE
M8W0H)')E<"P@)&9I;&5N86UE+"`D8V%C:&4@/2!N=6QL*0H@("`@>PH@("`@
M("`@("\J(%1H92!V97)S:6]N(&]F('1H92!C86-H960@9&%T82X@26YC<F5M
M96YT('1H:7,@=VAE;F5V97(@=&AE"B`@("`@("`@("H@:6YT97)N86P@<W1O
M<F%G92!F;W)M870@8VAA;F=E<RP@<W5C:"!T:&%T('=E(&UU<W0*("`@("`@
M("`@*B!I;G9A;&ED871E('!R:6]R(&-A8VAE9"!D871A+B`J+PH@("`@("`@
M("1C86-H959E<G-I;VX@/2`Q.PH@("`@("`@("1C86-H94ED(#T@)')E<"T^
M<V]U<F-E<F]O="@I("X@)U]N)R`N("1F:6QE;F%M92`N("=?9E]V)R`N("1C
M86-H959E<G-I;VX["@H@("`@("`@("1C=&EM92`]('1I;64H*2`M($!F:6QE
M;71I;64H)&9I;&5N86UE("X@)RQV)RD["B`@("`@("`@:68@*"1C86-H92`F
M)@H@("`@("`@("`@("`D8V%C:&4M/F5X:7-T<R@D8V%C:&5)9"P@)&-T:6UE
M*2D@>PH@("`@("`@("`@("`D<'-/8B`]('5N<V5R:6%L:7IE*"1C86-H92T^
M9V5T*"1C86-H94ED+"`D8W1I;64I*3L*("`@("`@("`@("`@)'!S3V(M/G-E
M=%)E<&]S:71O<GDH)')E<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'!S3V(@/2!N97<@5D-?4&%T8VAS971?8W9S*"1F:6QE;F%M92D["B`@
M("`@("`@("`@("1P<T]B+3YS971297!O<VET;W)Y*"1R97`I.PH@("`@("`@
M("`@("!I9B`H:7-?82@H)')E<W5L="`]("1P<T]B+3YG9710871C:'-E=',H
M*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&-A8VAE
M*2!["B`@("`@("`@("`@("`@("`D8V%C:&4M/G-E="@D8V%C:&5)9"P@<V5R
M:6%L:7IE*"1P<T]B*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<'-/8CL*("`@('T*"B`@("`O*BH*("`@("`J(%!O<'5L
M871E('1H92!O8FIE8W0@=VET:"!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<&%T
M8VAS971S('1H870*("`@("`J('1H:7,@9FEL92!I<R!I;G9O;'9E9"!I;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\;V)J96-T("!014%27T5R
M<F]R(&]B:F5C="!O;B!E<G)O<BP@;W(@=')U92!O;B!S=6-C97-S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9710871C:'-E=',H*0H@("`@>PH@("`@("`@
M("\J($-H96-K('1H870@=V4@87)E(&%C='5A;&QY(&EN('1H92!F:6QE<WES
M=&5M+B`J+PH@("`@("`@(&EF("@A:7-?9FEL92@D=&AI<RT^9V5T1G5L;%!A
M=&@H*2`N("<L=B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=&:6QE($YO="!&;W5N9"<I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@0V%L;"!C=G-P<R!T;R!R971R:65V92!A;&P@<&%T8VAS971S(&9O<B!T
M:&ES(&9I;&4N("HO"B`@("`@("`@)'%?<F]O="`]("1T:&ES+3Y?<F5P+3YS
M;W5R8V5R;V]T*"D["B`@("`@("`@)'%?<F]O="`](%9#7U=)3D1/5U,@/R`G
M(B<@+B!E<V-A<&5S:&5L;&-M9"@D<5]R;V]T*2`N("<B)R`Z(&5S8V%P97-H
M96QL87)G*"1Q7W)O;W0I.PH*("`@("`@("`D8W9S<'-?:&]M92`]("1T:&ES
M+3Y?<F5P+3YG9710871H*"=C=G-P<U]H;VUE)RD["B`@("`@("`@)$A/344@
M/2`A96UP='DH)&-V<W!S7VAO;64I(#\*("`@("`@("`@("`@)TA/344])R`N
M("1C=G-P<U]H;VUE("X@)R`G(#H*("`@("`@("`@("`@)R<["@H@("`@("`@
M("1C;60@/2`D2$]-12`N("1T:&ES+3Y?<F5P+3YG9710871H*"=C=G-P<R<I
M("X@)R`M=2`M+6-V<RUD:7)E8W0@+2UR;V]T("<@+B`D<5]R;V]T("X@)R`M
M9B`G("X@97-C87!E<VAE;&QA<F<H)'1H:7,M/E]N86UE*2`N("<@)R`N(&5S
M8V%P97-H96QL87)G*"1T:&ES+3Y?9&ER*3L*("`@("`@("!E>&5C*"1C;60L
M("1R971U<FY?87)R87DL("1R971V86PI.PH@("`@("`@(&EF("@D<F5T=F%L
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL
M960@=&\@<W!A=VX@8W9S<',@=&\@<F5T<FEE=F4@<&%T8VAS970@:6YF;W)M
M871I;VXG*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%T8VAS971S
M(#T@87)R87DH*3L*("`@("`@("`D<W1A=&4@/2`G8F5G:6XG.PH@("`@("`@
M(&9O<F5A8V@@*"1R971U<FY?87)R87D@87,@)&QI;F4I('L*("`@("`@("`@
M("`@)&QI;F4@/2!T<FEM*"1L:6YE*3L*("`@("`@("`@("`@:68@*"1L:6YE
M(#T]("<M+2TM+2TM+2TM+2TM+2TM+2TM+2TG*2!["B`@("`@("`@("`@("`@
M("`D<W1A=&4@/2`G8F5G:6XG.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-W:71C:"`H)'-T871E*2![
M"B`@("`@("`@("`@(&-A<V4@)V)E9VEN)SH*("`@("`@("`@("`@("`@("1I
M9"`]('-T<E]R97!L86-E*"=0871C:%-E="`G+"`G)RP@)&QI;F4I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)&ED72`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`D<W1A=&4@/2`G:6YF;R<["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VEN9F\G.@H@("`@("`@
M("`@("`@("`@)&EN9F\@/2!E>'!L;V1E*"<Z)RP@)&QI;F4L(#(I.PH@("`@
M("`@("`@("`@("`@<W=I=&-H("@D:6YF;ULP72D@>PH@("`@("`@("`@("`@
M("`@8V%S92`G1&%T92<Z"B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H)WPH7&1[-'TI+RA<9'LR?2DO*%QD>S)]*2`H7&1[,GTI.BA<9'LR
M?2DZ*%QD>S)]*7PG+"`D:6YF;ULQ72P@)&1A=&4I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%U;)V1A=&4G72`]
M(&=M;6MT:6UE*"1D871E6S1=+"`D9&%T95LU72P@)&1A=&5;-ETL("1D871E
M6S)=+"`D9&%T95LS72P@)&1A=&5;,5TI.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("=!=71H;W(G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%T8VAS971S6R1I9%U;)V%U=&AO<B==(#T@=')I;2@D:6YF;ULQ72D["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`G0G)A;F-H)SH*("`@("`@("`@("`@("`@("`@("!I9B`H=')I;2@D:6YF
M;ULQ72D@(3T@)TA%040G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%T8VAS971S6R1I9%U;)V)R86YC:"==(#T@=')I;2@D:6YF;ULQ
M72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)U1A9R<Z"B`@("`@("`@
M("`@("`@("`@("`@:68@*'1R:6TH)&EN9F];,5TI("$]("<H;F]N92DG*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I
M9%U;)W1A9R==(#T@=')I;2@D:6YF;ULQ72D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&-A<V4@)TQO9R<Z"B`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@
M)VQO9R<["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;
M)&ED75LG;&]G)UT@/2`G)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G;&]G)SH*("`@("`@("`@("`@("`@(&EF("@D;&EN
M92`]/2`G365M8F5R<SHG*2!["B`@("`@("`@("`@("`@("`@("`@)'-T871E
M(#T@)VUE;6)E<G,G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T
M8VAS971S6R1I9%U;)VQO9R==(#T@=')I;2@D=&AI<RT^7W!A=&-H<V5T<ULD
M:61=6R=L;V<G72D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P871C
M:'-E='-;)&ED75LG;65M8F5R<R==(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P871C
M:'-E='-;)&ED75LG;&]G)UT@+CT@)&QI;F4@+B`B7&XB.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=M96UB97)S)SH*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&QI
M;F4I*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G
M.B<L("1L:6YE*3L*("`@("`@("`@("`@("`@("`@("`D<F5V<R`](&5X<&QO
M9&4H)RT^)RP@)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A=&-H<V5T<ULD:61=6R=M96UB97)S)UU;72`](&%R<F%Y*"=F:6QE
M)R`]/B`D<&%R='-;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9G)O;2<@/3X@
M)')E=G-;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&\G(#T^("1R979S6S%=
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@9G5L;'D@<75A;&EF
M:65D(&9I;&5N86UE(&]F('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!&=6QL>2!Q=6%L:69I960@9FEL96YA;64@;V8@=&AI
M<R!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G5L;%!A=&@H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<B`N("<O)R`N("1T:&ES
M+3Y?;F%M93L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5D,O<W9N+G!H<```
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8P-3,W`#$P
M-3$U-#,Q,#8Q`#`R,#`U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5D-?<W9N(&EM<&QE;65N=&%T
M:6]N+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($%N:6P@36%D:&%V87!E
M9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]60R]60R]S=FXN<&AP+'8@,2XR."XT+C$X(#(P,#8O,#4O,3(@,#0Z-#<Z
M,#@@8VAU8VL@17AP("0*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D
M9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]S=FX@97AT96YD<R!60R!["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<B!T:&4@8VQA<W,@97AP
M96-T<RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!#=7)R96YT('!A
M<F%M971E<G,Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W-O=7)C
M97)O;W0G.B!4:&4@<V]U<F-E(')O;W0@9F]R('1H:7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<&]S:71O<GD*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`G<&%T:',G.B!(87-H('=I=&@@
M=&AE(&QO8V%T:6]N<R!O9B!A;&P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!N96-E<W-A<GD@8FEN87)I97,Z("=S=FXG+"`G9&EF
M9B<*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?<W9N*"1P87)A;7,I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]S;W5R8V5R;V]T(#T@)'!A<F%M<ULG<V]U<F-E
M<F]O="==.PH@("`@("`@("1T:&ES+3Y?<&%T:',@/2`D<&%R86US6R=P871H
M<R==.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES1FEL92@D=VAE<F4I"B`@("![
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@)G%U
M97)Y1&ER*"1W:&5R92D*("`@('L*("`@("`@("`D9&ER(#T@;F5W(%9#7T1I
M<F5C=&]R>5]S=FXH)'1H:7,L("1W:&5R92D["B`@("`@("`@<F5T=7)N("1D
M:7(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VAE8VMO=70H)&9I;&4L("1R
M978I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7T-H96-K;W5T7W-V;CHZ9V5T
M*"1T:&ES+"`D9FEL92T^<75E<GE&=6QL4&%T:"@I+"`D<F5V*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971$:69F*"1F:6QE+"`D<F5V,2P@)')E=C(L("1T
M>7!E(#T@)V-O;G1E>'0G+"`D;G5M(#T@,RP@)'=S(#T@=')U92D*("`@('L*
M("`@("`@("!R971U<FX@5D-?1&EF9E]S=FXZ.F=E="@D=&AI<RP@)&9I;&4L
M("1R978Q+"`D<F5V,BP@)'1Y<&4L("1N=6TL("1W<RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@)F=E=$9I;&5/8FIE8W0H)&9I;&5N86UE+"`D8V%C:&4@/2!N
M=6QL+"`D<75I8VML;V<@/2!F86QS92D*("`@('L*("`@("`@("`D9F\@/2`F
M5D-?1FEL95]S=FXZ.F=E=$9I;&5/8FIE8W0H)'1H:7,L("1F:6QE;F%M92P@
M)&-A8VAE+"`D<75I8VML;V<I.PH@("`@("`@(')E='5R;B`D9F\["B`@("!]
M"@H@("`@9G5N8W1I;VX@)F=E=$%N;F]T871E3V)J96-T*"1F:6QE;F%M92D*
M("`@('L*("`@("`@("`D8FQA;64@/2!N97<@5D-?06YN;W1A=&5?<W9N*"1T
M:&ES+"`D9FEL96YA;64I.PH@("`@("`@(')E='5R;B`D8FQA;64["B`@("!]
M"@H@("`@9G5N8W1I;VX@)F=E=%!A=&-H<V5T3V)J96-T*"1F:6QE;F%M92P@
M)&-A8VAE(#T@;G5L;"D*("`@('L*("`@("`@("`D<&\@/2`F5D-?4&%T8VAS
M971?<W9N.CIG9710871C:'-E=$]B:F5C="@D=&AI<RP@)&9I;&5N86UE+"`D
M8V%C:&4I.PH@("`@("`@(')E='5R;B`D<&\["B`@("!]"@I]"@HO*BH*("H@
M5D-?<W9N(&%N;F]T871E(&-L87-S+@H@*@H@*B!!;FEL($UA9&AA=F%P961D
M>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H
M879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO
M"F-L87-S(%9#7T%N;F]T871E7W-V;B!["@H@("`@=F%R("1F:6QE.PH@("`@
M=F%R("135DX["B`@("!V87(@)'1M<&9I;&4["@H@("`@9G5N8W1I;VX@5D-?
M06YN;W1A=&5?<W9N*"1R97`L("1F:6QE*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y35DX@/2`D<F5P.PH@("`@("`@("1T:&ES+3YF:6QE(#T@)&9I;&4["B`@
M("!]"@H@("`@9G5N8W1I;VX@9&]!;FYO=&%T92@D<F5V*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!T:&%T('1H92!F:6QE('9A;'5E<R!F;W(@=&AI
M<R!O8FIE8W0@:7,@=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/F9I;&4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%60U]2979I<VEO;CHZ=F%L
M:60H)')E=BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B.PH@("`@
M("`@("1C;VUM86YD(#T@)'1H:7,M/E-63BT^9V5T4&%T:"@G<W9N)RD@+B`G
M(&%N;F]T871E("UR(#$Z)R`N("1R978@+B`G("<@+B`D42`N('-T<E]R97!L
M86-E*"11+"`G7%PG("X@)%$L("1T:&ES+3YF:6QE+3YQ=65R>49U;&Q0871H
M*"DI("X@)%$@+B`G(#(^)C$G.PH@("`@("`@("1P:7!E(#T@<&]P96XH)&-O
M;6UA;F0L("=R)RD["B`@("`@("`@:68@*"$D<&EP92D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&5X96-U=&4@
M<W9N(&%N;F]T871E.B`G("X@)&-O;6UA;F0I.PH@("`@("`@('T*"B`@("`@
M("`@)&QI;F5S(#T@87)R87DH*3L*("`@("`@("`D;&EN96YO(#T@,3L*("`@
M("`@("!W:&EL92`H(69E;V8H)'!I<&4I*2!["B`@("`@("`@("`@("1L:6YE
M(#T@9F=E=',H)'!I<&4L(#0P.38I.PH@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UY<<RLH7&0K*5QS*RA;7'=<+ETK*5QS*"XJ*20O)RP@)&QI;F4L
M("1R96=S*2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*
M("`@("`@("`@("`@("`@("1E;G1R>5LG<F5V)UT@("`@/2`D<F5G<ULQ73L*
M("`@("`@("`@("`@("`@("1E;G1R>5LG875T:&]R)UT@/2!T<FEM*"1R96=S
M6S)=*3L*("`@("`@("`@("`@("`@("1E;G1R>5LG9&%T92==("`@/2`G)SL*
M("`@("`@("`@("`@("`@("1E;G1R>5LG;&EN92==("`@/2`D<F5G<ULS73L*
M("`@("`@("`@("`@("`@("1E;G1R>5LG;&EN96YO)UT@/2`D;&EN96YO*RL[
M"B`@("`@("`@("`@("`@("`D;&EN97-;72`]("1E;G1R>3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<&-L;W-E*"1P:7!E*3L*("`@("`@
M("!R971U<FX@)&QI;F5S.PH@("`@?0H*?0H*+RHJ"B`J(%9#7W-V;B!C:&5C
M:V]U="!C;&%S<RX*("H*("H@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E
M8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]#
M:&5C:V]U=%]S=FX@>PH*("`@("\J*@H@("`@("H@4W1A=&EC(&9U;F-T:6]N
M('=H:6-H(')E='5R;G,@82!F:6QE('!O:6YT:6YG('1O('1H92!H96%D(&]F
M('1H92!R97%U97-T960*("`@("`J(')E=FES:6]N(&]F(&%N(%)#4R!F:6QE
M+@H@("`@("H@0'!A<F%M(&9U;&QN86UE($9U;&QY('%U86QI9FEE9"!P871H
M;F%M92!O9B!T:&4@9&5S:7)E9"!20U,@9FEL92!T;R!C:&5C:V]U=`H@("`@
M("H@0'!A<F%M(')E=B!20U,@<F5V:7-I;VX@;G5M8F5R('1O(&-H96-K(&]U
M=`H@("`@("H@0')E='5R;B!%:71H97(@82!014%27T5R<F]R(&]B:F5C="P@
M;W(@82!S=')E86T@<&]I;G1E<B!T;R!T:&4@:&5A9"!O9B!T:&4@8VAE8VMO
M=70*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T*"1R97`L("1F=6QL;F%M92P@
M)')E=BD*("`@('L*("`@("`@("!I9B`H(59#7U)E=FES:6]N.CIV86QI9"@D
M<F5V*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M26YV86QI9"!R979I<VEO;B!N=6UB97(G*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("A60U]724Y$3U=3*2!["B`@("`@("`@("`@("11(#T@)R(G.PH@("`@
M("`@("`@("`D;6]D92`]("=R8B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)%$@/2`B)R(["B`@("`@("`@("`@("1M;V1E(#T@)W(G.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"$H)%)#4R`]('!O<&5N*"1R97`M/F=E=%!A
M=&@H)W-V;B<I("X@)R!C870@+7(@)R`N("1R978@+B`G("<@+B`D42`N('-T
M<E]R97!L86-E*"11+"`G7%PG("X@)%$L("1F=6QL;F%M92D@+B`D42`N("<@
M,CXF,2<L("1M;V1E*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)T-O=6QD;EPG="!P97)F;W)M(&-H96-K;W5T(&]F('1H92!R
M97%U97-T960@9FEL92<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("12
M0U,["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(&1I9F8@8VQA<W,N"B`J"B`J
M($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R
M9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7T1I9F9?<W9N
M('L*"B`@("`O*BH*("`@("`J($]B=&%I;B!T:&4@9&EF9F5R96YC97,@8F5T
M=V5E;B!T=V\@<F5V:7-I;VYS(&]F(&$@9FEL92X*("`@("`J"B`@("`@*B!`
M<&%R86T@5D-?<W9N("1R97`@("`@("`@($$@<F5P;W-I=&]R>2!O8FIE8W0N
M"B`@("`@*B!`<&%R86T@5D-?1FEL95]S=FX@)&9I;&4@(%1H92!D97-I<F5D
M(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978Q("`@("`@($]R:6=I
M;F%L(')E=FES:6]N(&YU;6)E<B!T;R!C;VUP87)E(&9R;VTN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1R978R("`@("`@($YE=R!R979I<VEO;B!N=6UB97(@
M=&\@8V]M<&%R92!A9V%I;G-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@("`@("!4:&4@='EP92!O9B!D:69F("AE+F<N("=U;FEF:65D)RDN"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D;G5M("`@("`@($YU;6)E<B!O9B!L:6YE
M<R!T;R!B92!U<V5D(&EN(&-O;G1E>'0@86YD"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('5N:69I960@9&EF9G,N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D=W,@("`@("`@(%-H;W<@=VAI=&5S<&%C92!I;B!T:&4@9&EF
M9C\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQB;V]L96%N("!&86QS
M92!O;B!F86EL=7)E+"!O<B!A('-T<FEN9R!C;VYT86EN:6YG('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@9&EF9B!O;B!S=6-C97-S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G970H)')E<"P@)&9I;&4L("1R978Q+"`D
M<F5V,BP@)'1Y<&4@/2`G8V]N=&5X="<L("1N=6T@/2`S+`H@("`@("`@("`@
M("`@("`@("1W<R`]('1R=64I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E
M('1H870@=&AE(&9I;&4@<&%R86UE=&5R(&ES('9A;&ED("HO"B`@("`@("`@
M:68@*&ES7V$H)&9I;&4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@=&AA
M="!T:&4@<F5V:7-I;VX@;G5M8F5R<R!A<F4@=F%L:60@*B\*("`@("`@("`D
M<F5V,2`](%9#7U)E=FES:6]N.CIV86QI9"@D<F5V,2D@/R`D<F5V,2`Z(#`[
M"B`@("`@("`@)')E=C(@/2!60U]2979I<VEO;CHZ=F%L:60H)')E=C$I(#\@
M)')E=C(@.B`P.PH*("`@("`@("`D9G5L;$YA;64@/2`D9FEL92T^<75E<GE&
M=6QL4&%T:"@I.PH@("`@("`@("1D:69F(#T@87)R87DH*3L*("`@("`@("`D
M;W!T:6]N<R`]("<G.PH@("`@("`@(&EF("@A)'=S*2!["B`@("`@("`@("`@
M("1O<'1I;VYS("X]("<@+6)"("<["B`@("`@("`@?0H*("`@("`@("!S=VET
M8V@@*"1T>7!E*2!["B`@("`@("`@8V%S92`G8V]N=&5X="<Z"B`@("`@("`@
M("`@("1O<'1I;VYS("X]("<M+6-O;G1E>'0])R`N("AI;G0I)&YU;3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W5N:69I960G.@H@("`@
M("`@("`@("`D;W!T:6]N<R`N/2`G+2UU;FEF:65D/2<@+B`H:6YT*21N=6T[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=C;VQU;6XG.@H@
M("`@("`@("`@("`D;W!T:6]N<R`N/2`G+2US:61E+6)Y+7-I9&4@+2UW:61T
M:#TQ,C`G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G960G
M.@H@("`@("`@("`@("`D;W!T:6]N<R`N/2`G+64G.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@("\O(%1/1$\Z(&%D9"!O<'1I;VYS
M(&9O<B`D:'(@;W!T:6]N<R`M(&AO=V5V97(@=&AE<V4@;6%Y(&YO=`H@("`@
M("`@("\O(&)E(&-O;7!A=&EB;&4@=VET:"!S;VUE(&1I9F9S+@H@("`@("`@
M("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G(CL*("`@("`@("`D8V]M;6%N
M9"`]("1R97`M/F=E=%!A=&@H)W-V;B<I("X@(B!D:69F("TM9&EF9BUC;60@
M(B`N("1R97`M/F=E=%!A=&@H)V1I9F8G*2`N("(@+7(@)')E=C$Z)')E=C(@
M+7@@(B`N("11("X@)&]P=&EO;G,@+B`D42`N("<@)R`N("1F:6QE+3YQ=65R
M>49U;&Q0871H*"D@+B`G(#(^)C$G.PH*("`@("`@("!E>&5C*"1C;VUM86YD
M+"`D9&EF9BP@)')E='9A;"D["B`@("`@("`@<F5T=7)N("1D:69F.PH@("`@
M?0H*?0H*+RHJ"B`J(%9#7W-V;B!D:7)E8W1O<GD@8VQA<W,N"B`J"B`J($-O
M<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL
M+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7T1I<F5C=&]R>5]S
M=FX@>PH*("`@('9A<B`D<F5P.PH@("`@=F%R("1D:7).86UE.PH@("`@=F%R
M("1F:6QE<SL*("`@('9A<B`D871T:6-&:6QE<SL*("`@('9A<B`D;65R9V5D
M1FEL97,["B`@("!V87(@)&1I<G,["B`@("!V87(@)'!A<F5N=#L*("`@('9A
M<B`D;6]D=6QE3F%M93L*"B`@("`O*BH*("`@("`J($-R96%T92!A(%-63B!$
M:7)E8W1O<GD@;V)J96-T('1O('-T;W)E(&EN9F]R;6%T:6]N(&%B;W5T('1H
M90H@("`@("H@9FEL97,@:6X@82!S:6YG;&4@9&ER96-T;W)Y(&EN('1H92!R
M97!O<VET;W)Y"B`@("`@*@H@("`@("H@0'!A<F%M(%9#7U)E<&]S:71O<GE?
M<W9N("1R<"`@5&AE(%9#7U)E<&]S:71O<GD@;V)J96-T('1H:7,@9&ER96-T
M;W)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<R!P
M87)T(&]F+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&X@("`@("`@("`@("`@
M4&%T:"!T;R!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M(%9#7T1I<F5C
M=&]R>5]S=FX@)'!N("`@5&AE('!A<F5N="!60U]$:7)E8W1O<GD@=&\@=&AI
M<R!O;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7T1I<F5C=&]R>5]S=FXH
M)')E<"P@)&1N+"`D<&X@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^<F5P
M(#T@)')E<#L*("`@("`@("`D=&AI<RT^<&%R96YT(#T@)'!N.PH@("`@("`@
M("1T:&ES+3YM;V1U;&5.86UE(#T@)&1N.PH@("`@("`@("1T:&ES+3YD:7).
M86UE(#T@(B\D9&XB.PH@("`@("`@("1T:&ES+3YF:6QE<R`](&%R<F%Y*"D[
M"B`@("`@("`@)'1H:7,M/F1I<G,@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&9U;&QY('%U86QI9FEE9"!P871H;F%M92!T;R!T
M:&ES(&1I<F5C=&]R>2!W:71H(&YO"B`@("`@*B!T<F%I;&EN9R`O+@H@("`@
M("H*("`@("`J($!R971U<FX@4&%T:&YA;64@;V8@=&AI<R!D:7)E8W1O<GD*
M("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE$:7(H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^9&ER3F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F
M<75E<GE$:7),:7-T*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1I
M<G,["B`@("!]"@H@("`@9G5N8W1I;VX@)G%U97)Y1FEL94QI<W0H)'-H;W=A
M='1I8R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D<VAO=V%T=&EC("8F
M(&ES<V5T*"1T:&ES+3YM97)G961&:6QE<RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YM97)G961&:6QE<SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F9I;&5S.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%1E;&P@=&AE(&]B:F5C="!T;R!O<&5N(&%N9"!B
M<F]W<V4@:71S(&-U<G)E;G0@9&ER96-T;W)Y+"!A;F0*("`@("`J(')E=')I
M979E(&$@;&ES="!O9B!A;&P@=&AE(&]B:F5C=',@:6X@=&AE<F4N("!)="!T
M:&5N('!O<'5L871E<PH@("`@("H@=&AE(&9I;&4O9&ER96-T;W)Y('-T86-K
M(&%N9"!M86ME<R!I="!A=F%I;&%B;&4@9F]R(')E=')I979A;"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(%!%05)?17)R;W(@;V)J96-T(&]N(&%N(&5R<F]R
M+"`Q(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)R;W=S941I
M<B@D8V%C:&4@/2!N=6QL+"`D<75I8VML;V<@/2!T<G5E+"`D<VAO=V%T=&EC
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)%$@/2!60U]724Y$3U=3(#\@)R(G
M(#H@(B<B(#L*("`@("`@("`D8VUD(#T@)'1H:7,M/G)E<"T^9V5T4&%T:"@G
M<W9N)RD@+B`G(&QS("<@+B`D42`N('-T<E]R97!L86-E*"11+"`G7%PG("X@
M)%$L("1T:&ES+3YR97`M/G-O=7)C97)O;W0H*2`N("1T:&ES+3YQ=65R>41I
M<B@I*2`N("11("X@)R`R/B8Q)SL*("`@("`@("`D9&ER(#T@<&]P96XH)&-M
M9"P@)W(G*3L*("`@("`@("!I9B`H(21D:7(I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!E>&5C=71E('-V;B!L
M<SH@)R`N("1C;60I.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1W
M;R!A<G)A>7,@+2!O;F4@;V8@86QL('1H92!F:6QE<RP@86YD('1H92!O=&AE
M<B!O9@H@("`@("`@("`J(&%L;"!T:&4@9&ER<RX@*B\*("`@("`@("`D97)R
M;W)S(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H(69E;V8H)&1I<BDI('L*
M("`@("`@("`@("`@)&QI;F4@/2!C:&]P*&9G971S*"1D:7(L(#$P,C0I*3L*
M("`@("`@("`@("`@:68@*"%S=')L96XH)&QI;F4I*2!["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*'-U8G-T<B@D;&EN92P@,"P@-"D@/3T@)W-V;CHG*2!["B`@("`@("`@("`@
M("`@("`D97)R;W)S6UT@/2`D;&EN93L*("`@("`@("`@("`@?2!E;'-E:68@
M*'-U8G-T<B@D;&EN92P@+3$I(#T]("<O)RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/F1I<G-;72`]('-U8G-T<B@D;&EN92P@,"P@+3$I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9L(#T@)'1H:7,M/G)E
M<"T^9V5T1FEL94]B:F5C="@D=&AI<RT^<75E<GE$:7(H*2`N("(O)&QI;F4B
M+"`D8V%C:&4L("1Q=6EC:VQO9RD["B`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D9FPL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&9L.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9FEL97-;72`]("1F;#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<&-L;W-E
M*"1D:7(I.PH*("`@("`@("!I9B`H)&5R<F]R<RD@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAI;7!L;V1E*")<;B(L("1E<G)O<G,I
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V]R="!T:&4@8V]N=&5N=',@;V8@=&AE(&1I<F5C=&]R
M>2!I;B!A(&=I=F5N(&9A<VAI;VX@86YD"B`@("`@*B!O<F1E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@)&AO=R!/9B!T:&4@9F]R;2!60U]33U)47RH@=VAE
M<F4@*B!C86X@8F4Z"B`@("`@*B`@("`@("`@("`@("!.3TY%+"!.04U%+"!!
M1T4L(%)%5B!F;W(@<V]R=&EN9R!B>2!N86UE+"!A9V4@;W(@<F5V:7-I;VXN
M"B`@("`@*B!`<&%R86T@)&1I<B!/9B!T:&4@9F]R;2!60U]33U)47RH@=VAE
M<F4@*B!C86X@8F4Z"B`@("`@*B`@("`@("`@("`@("!!4T-%3D1)3D<L($1%
M4T-%3D1)3D<@9F]R('1H92!O<F1E<B!O9B!T:&4@<V]R="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@87!P;'E3;W)T*"1H;W<@/2!60U]33U)47TY/3D4L("1D
M:7(@/2!60U]33U)47T%30T5.1$E.1RD*("`@('L*("`@("`@("`O*B!43T1/
M.B!T:&ES(&-O9&4@;&]O:W,@=F5R>2!I;F5F9FEC:65N="$@;W!T:6UI<V4N
M+BX@+0H@("`@("`@("`J(&%V<VTN("HO"@H@("`@("`@("\O($%S<W5M92!B
M>2!N86UE(&9O<B!T:&4@;6]M96YT+@H@("`@("`@(&YA=&-A<V5S;W)T*"1T
M:&ES+3YD:7)S*3L*("`@("`@("`D=&AI<RT^9&]&:6QE4V]R="@D=&AI<RT^
M9FEL97,L("1H;W<L("1D:7(I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M871T:6-&:6QE<RDI('L*("`@("`@("`@("`@)'1H:7,M/F1O1FEL95-O<G0H
M)'1H:7,M/F%T=&EC1FEL97,L("1H;W<L("1D:7(I.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/FUE<F=E9$9I;&5S*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^9&]&:6QE4V]R="@D=&AI<RT^;65R9V5D1FEL97,L("1H
M;W<L("1D:7(I.PH@("`@("`@('T*("`@("`@("!I9B`H)&1I<B`]/2!60U]3
M3U)47T1%4T-%3D1)3D<I('L*("`@("`@("`@("`@)'1H:7,M/F1I<G,@/2!A
M<G)A>5]R979E<G-E*"1T:&ES+3YD:7)S*3L*("`@("`@("`@("`@)'1H:7,M
M/F9I;&5S(#T@87)R87E?<F5V97)S92@D=&AI<RT^9FEL97,I.PH@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/FUE<F=E9$9I;&5S*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FUE<F=E9$9I;&5S(#T@87)R87E?<F5V97)S92@D
M=&AI<RT^;65R9V5D1FEL97,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&1O1FEL95-O<G0H)B1F:6QE3&ES="P@)&AO
M=R`](%9#7U-/4E1?3D].12P@)&1I<B`](%9#7U-/4E1?05-#14Y$24Y'*0H@
M("`@>PH@("`@("`@('-W:71C:"`H)&AO=RD@>PH@("`@("`@(&-A<V4@5D-?
M4T]25%]!1T4Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH
M)'1H:7,L("=F:6QE06=E4V]R="<I*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@5D-?4T]25%].04U%.@H@("`@("`@("`@("!U<V]R="@D
M9FEL94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL94YA;653;W)T)RDI.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)47T%55$A/4CH*
M("`@("`@("`@("`@=7-O<G0H)&9I;&5,:7-T+"!A<G)A>2@D=&AI<RP@)V9I
M;&5!=71H;W)3;W)T)RDI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!60U]33U)47U)%5CH*("`@("`@("`@("`@=7-O<G0H)&9I;&5,:7-T
M+"!A<G)A>2@D=&AI<RP@)V9I;&529793;W)T)RDI.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)47TY/3D4Z"B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!F;W(@87-C96YD:6YG(&%G92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9FEL94%G95-O<G0H)&$L("1B*0H@("`@
M>PH@("`@("`@("1A82`]("1A+3YQ=65R>4QA<W1,;V<H*3L*("`@("`@("`D
M8F(@/2`D8BT^<75E<GE,87-T3&]G*"D["B`@("`@("`@:68@*"1A82T^<75E
M<GE$871E*"D@/3T@)&)B+3YQ=65R>41A=&4H*2D@>PH@("`@("`@("`@("!R
M971U<FX@,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M*"1A82T^<75E<GE$871E*"D@/"`D8F(M/G%U97)Y1&%T92@I*2`_(#$@.B`M
M,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&9U;F-T
M:6]N(&)Y(&%U=&AO<B!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE
M075T:&]R4V]R="@D82P@)&(I"B`@("!["B`@("`@("`@)&%A(#T@)&$M/G%U
M97)Y3&%S=$QO9R@I.PH@("`@("`@("1B8B`]("1B+3YQ=65R>4QA<W1,;V<H
M*3L*("`@("`@("!I9B`H)&%A+3YQ=65R>4%U=&AO<B@I(#T]("1B8BT^<75E
M<GE!=71H;W(H*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@*"1A82T^<75E<GE!=71H;W(H
M*2`^("1B8BT^<75E<GE!=71H;W(H*2D@/R`Q(#H@+3$["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!F;W(@87-C96YD
M:6YG(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE3F%M95-O
M<G0H)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R;B!S=')C87-E8VUP*"1A
M+3YN86UE+"`D8BT^;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T
M(&9U;F-T:6]N(&9O<B!A<V-E;F1I;F<@<F5V:7-I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9I;&529793;W)T*"1A+"`D8BD*("`@('L*("`@("`@("!R
M971U<FX@5D-?4F5V:7-I;VXZ.F-M<"@D82T^<75E<GE(96%D*"DL("1B+3YQ
M=65R>4AE860H*2D["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(&9I;&4@8VQA
M<W,N"B`J"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#
M7T9I;&5?<W9N(&5X=&5N9',@5D-?1FEL92!["@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&4@82!R97!O<VET;W)Y(&9I;&4@;V)J96-T+"!A;F0@9VEV92!I="!I
M;F9O<FUA=&EO;B!A8F]U=`H@("`@("H@=VAA="!I=',@<&%R96YT(&1I<F5C
M=&]R>2!A;F0@<F5P;W-I=&]R>2!O8FIE8W1S(&%R92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F;"`@1G5L;"!P871H('1O('1H:7,@9FEL92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@5D-?1FEL95]S=FXH)')E<"P@)&9L+"`D
M<75I8VML;V<@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^<F5P(#T@
M)')E<#L*("`@("`@("`D=&AI<RT^;F%M92`](&)A<V5N86UE*"1F;"D["B`@
M("`@("`@)'1H:7,M/F1I<B`](&1I<FYA;64H)&9L*3L*("`@("`@("`D=&AI
M<RT^;&]G<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/G%U:6-K;&]G(#T@
M)'%U:6-K;&]G.PH@("`@("`@("1T:&ES+3YR979S(#T@87)R87DH*3L*("`@
M("`@("`D=&AI<RT^<F5V<WEM(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M<WEM<F5V(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^8G)A;F-H97,@/2!A
M<G)A>2@I.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971&:6QE3V)J96-T*"1R
M97`L("1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"P@)'%U:6-K;&]G(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@+RH@5&AE('9E<G-I;VX@;V8@=&AE(&-A8VAE
M9"!D871A+B!);F-R96UE;G0@=&AI<R!W:&5N979E<B!T:&4*("`@("`@("`@
M*B!I;G1E<FYA;"!S=&]R86=E(&9O<FUA="!C:&%N9V5S+"!S=6-H('1H870@
M=V4@;75S=`H@("`@("`@("`J(&EN=F%L:61A=&4@<')I;W(@8V%C:&5D(&1A
M=&$N("HO"B`@("`@("`@)&-A8VAE5F5R<VEO;B`](#(["B`@("`@("`@)&-A
M8VAE260@/2`D<F5P+3YS;W5R8V5R;V]T*"D@+B`G7VXG("X@)&9I;&5N86UE
M("X@)U]F)R`N("AI;G0I)'%U:6-K;&]G("X@)U]V)R`N("1C86-H959E<G-I
M;VX["@H@("`@("`@(&EF("@D8V%C:&4@)B8*("`@("`@("`@("`@+R\@5&AE
M(&9I;&4@:7,@8V%C:&5D(&9O<B!O;F4@:&]U<B!N;R!M871T97(@=VAA="P@
M8F5C875S90H@("`@("`@("`@("`O+R!T:&5R92!I<R!N;R!W87D@=&\@9&5T
M97)M:6YE('=I=&@@4W5B=F5R<VEO;B!T:&4@=&EM90H@("`@("`@("`@("`O
M+R!T:&4@9FEL92!L87-T(&-H86YG960N"B`@("`@("`@("`@("1C86-H92T^
M97AI<W1S*"1C86-H94ED+"`S-C`P*2D@>PH@("`@("`@("`@("`D9FEL94]B
M(#T@=6YS97)I86QI>F4H)&-A8VAE+3YG970H)&-A8VAE260L(#,V,#`I*3L*
M("`@("`@("`@("`@)&9I;&5/8BT^<V5T4F5P;W-I=&]R>2@D<F5P*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL94]B(#T@;F5W(%9#7T9I
M;&5?<W9N*"1R97`L("1F:6QE;F%M92P@)'%U:6-K;&]G*3L*("`@("`@("`@
M("`@)&9I;&5/8BT^<V5T4F5P;W-I=&]R>2@D<F5P*3L*("`@("`@("`@("`@
M:68@*&ES7V$H*"1R97-U;'0@/2`D9FEL94]B+3YG971"<F]W<V5);F9O*"DI
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FEL94]B+3YA<'!L
M>5-O<G0H5D-?4T]25%]!1T4I.PH*("`@("`@("`@("`@:68@*"1C86-H92D@
M>PH@("`@("`@("`@("`@("`@)&-A8VAE+3YS970H)&-A8VAE260L('-E<FEA
M;&EZ92@D9FEL94]B*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9FEL94]B.PH@("`@?0H*("`@("\J*@H@("`@("H@268@
M=&AI<R!F:6QE(&ES('!R97-E;G0@:6X@86X@071T:6,@9&ER96-T;W)Y+"!T
M:&ES(&EN9&EC871E<PH@("`@("H@:70N"B`@("`@*@H@("`@("H@0')E='5R
M;B!T<G5E(&EF(&9I;&4@:7,@:6X@=&AE($%T=&EC+"!A;F0@9F%L<V4@;W1H
M97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES071T:6-&:6QE*"D*("`@
M('L*("`@("`@("`O+R!.;W0@:6UP;&5M96YT960@>65T"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M;F%M92!O9B!T:&4@8W5R<F5N="!F:6QE(&%S(&EN('1H92!R97!O<VET;W)Y
M"B`@("`@*@H@("`@("H@0')E='5R;B!&:6QE;F%M92`H=VET:&]U="!T:&4@
M<&%T:"D*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE297!O<VET;W)Y3F%M
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YN86UE.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!N86UE(&]F('1H92!C=7)R96YT(&9I
M;&4@=VET:&]U="!T:&4@<F5P;W-I=&]R>0H@("`@("H@97AT96YS:6]N<R`H
M=7-U86QL>2`L=BD*("`@("`J"B`@("`@*B!`<F5T=7)N($9I;&5N86UE('=I
M=&AO=70@<F5P;W-I=&]R>2!E>'1E;G-I;VX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<75E<GE.86UE*"D*("`@('L*("`@("`@(')E='5R;B!P<F5G7W)E<&QA
M8V4H)R\L=B0O)RP@)R<L("1T:&ES+3YN86UE*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@;&%S="!R979I<VEO;B!O9B!T:&4@8W5R<F5N
M="!F:6QE(&]N('1H92!(14%$(&)R86YC:`H@("`@("H*("`@("`J($!R971U
M<FX@3&%S="!R979I<VEO;B!O9B!T:&4@8W5R<F5N="!F:6QE"B`@("`@*B\*
M("`@(&9U;F-T:6]N('%U97)Y4F5V:7-I;VXH*0H@("`@>PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/G)E=G-;,%TI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=.;R!R979I<VEO;G,G*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR979S6S!=.PH@("`@?0H*("`@(&9U
M;F-T:6]N('%U97)Y4')E=FEO=7-2979I<VEO;B@D<F5V*0H@("`@>PH@("`@
M("`@("1L87-T(#T@9F%L<V4["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G)E
M=G,@87,@)&5N=')Y*2!["B`@("`@("`@("`@(&EF("@D;&%S="D*("`@("`@
M("`@("`@("`@(')E='5R;B`D96YT<GD["B`@("`@("`@("`@(&EF("@D96YT
M<GD@/3T@)')E=BD*("`@("`@("`@("`@("`@("1L87-T(#T@=')U93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@2$5!1"`H;6]S="!R96-E;G0I(')E=FES:6]N
M(&YU;6)E<B!F;W(@=&AI<R!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@
M2$5!1"!R979I<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I;VX@<75E
M<GE(96%D*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y4F5V
M:7-I;VXH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;&%S
M="!60U],;V<@;V)J96-T(&EN('1H92!F:6QE+@H@("`@("H*("`@("`J($!R
M971U<FX@5D-?3&]G(&]F('1H92!L87-T(&5N=')Y(&EN('1H92!F:6QE"B`@
M("`@*B\*("`@(&9U;F-T:6]N('%U97)Y3&%S=$QO9R@I"B`@("!["B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^<F5V<ULP72D@?'P@(6ES<V5T*"1T:&ES
M+3YL;V=S6R1T:&ES+3YR979S6S!=72DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)TYO(')E=FES:6]N<R<I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/FQO9W-;)'1H:7,M/G)E=G-;,%U=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V]R="!T:&4@;&ES="!O9B!60U],;V<@
M;V)J96-T<R!T:&%T('1H:7,@9FEL92!C;VYT86EN<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@:&]W(%9#7U-/4E1?4D56("AS;W)T(&)Y(')E=FES:6]N*2P*
M("`@("`J("`@("`@("`@("`@5D-?4T]25%].04U%("AS;W)T(&)Y(&%U=&AO
M<B!N86UE*2P*("`@("`J("`@("`@("`@("`@5D-?4T]25%]!1T4@*'-O<G0@
M8GD@8V]M;6ET(&1A=&4I"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&QY4V]R
M="@D:&]W(#T@5D-?4T]25%]2158I"B`@("!["B`@("`@("`@<W=I=&-H("@D
M:&]W*2!["B`@("`@("`@8V%S92!60U]33U)47U)%5CH*("`@("`@("`@("`@
M)&9U;F,@/2`G4F5V:7-I;VXG.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!C87-E(%9#7U-/4E1?3D%-13H*("`@("`@("`@("`@)&9U;F,@/2`G3F%M
M92<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@5D-?4T]25%]!
M1T4Z"B`@("`@("`@("`@("1F=6YC(#T@)T%G92<["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1F=6YC(#T@)U)E
M=FES:6]N)SL*("`@("`@("!]"B`@("`@("`@=6%S;W)T*"1T:&ES+3YL;V=S
M+"!A<G)A>2@D=&AI<RP@(G-O<G1">21F=6YC(BDI.PH@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE('-O<G1">2HH*2!F
M=6YC=&EO;G,@87)E(&EN=&5R;F%L;'D@=7-E9"!B>2!A<'!L>5-O<G0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-O<G1">5)E=FES:6]N*"1A+"`D8BD*("`@
M('L*("`@("`@("!R971U<FX@5D-?4F5V:7-I;VXZ.F-M<"@D8BT^<F5V+"`D
M82T^<F5V*3L*("`@('T*"B`@("!F=6YC=&EO;B!S;W)T0GE!9V4H)&$L("1B
M*0H@("`@>PH@("`@("`@(')E='5R;B`D8BT^9&%T92`M("1A+3YD871E.PH@
M("`@?0H*("`@(&9U;F-T:6]N('-O<G1">4YA;64H)&$L("1B*0H@("`@>PH@
M("`@("`@(')E='5R;B!S=')C;7`H)&$M/F%U=&AO<BP@)&(M/F%U=&AO<BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0;W!U;&%T92!T:&4@;V)J96-T('=I
M=&@@:6YF;W)M871I;VX@86)O=70@=&AE(')E=FES:6]N<R!L;V=S"B`@("`@
M*B!A;F0@9&%T97,@;V8@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!B;V]L96%N("`@("`@("`@("`@5')U92!O;B!S=6-C97-S+`H@
M("`@("H@("`@("`@("`@("`@("!014%27T5R<F]R("`@("`@("`@3VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)R;W=S94EN9F\H*0H@("`@
M>PH@("`@("`@("\J(%1H:7,@9&]E<VXG="!W;W)K.R!N965D('1O(&9I;F0@
M86YO=&AE<B!W87D@=&\@<VEM<&QY"B`@("`@("`@("H@<F5Q=65S="!T:&4@
M;6]S="!R96-E;G0@<F5V:7-I;VXZ"B`@("`@("`@("H*("`@("`@("`@*B`D
M9FQA9R`]("1T:&ES+3YQ=6EC:VQO9R`_("<M<B!(14%$("<@.B`G)SL@*B\*
M("`@("`@("`D9FQA9R`]("<G.PH@("`@("`@("11(#T@5D-?5TE.1$]74R`_
M("<B)R`Z("(G(CL*("`@("`@("`D8VUD(#T@)'1H:7,M/G)E<"T^9V5T4&%T
M:"@G<W9N)RD@+B`G(&QO9R`M=B`G("X@)&9L86<@+B`D42`N('-T<E]R97!L
M86-E*"11+"`G7%PG("X@)%$L("1T:&ES+3YQ=65R>49U;&Q0871H*"DI("X@
M)%$@+B`G(#(^)C$G.PH@("`@("`@("1P:7!E(#T@<&]P96XH)&-M9"P@)W(G
M*3L*("`@("`@("!I9B`H(21P:7!E*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=&86EL960@=&\@97AE8W5T92!S=FX@;&]G.B`G
M("X@)&-M9"D["B`@("`@("`@?0H*("`@("`@("!F9V5T<R@D<&EP92D["B`@
M("`@("`@=VAI;&4@*"%F96]F*"1P:7!E*2D@>PH@("`@("`@("`@("`D;&]G
M(#T@;F5W(%9#7TQO9U]S=FXH)'1H:7,M/G)E<"P@)'1H:7,I.PH@("`@("`@
M("`@("`D97)R(#T@)&QO9RT^<')O8V5S<TQO9R@D<&EP92D["B`@("`@("`@
M("`@(&EF("@D97)R*2!["B`@("`@("`@("`@("`@("`D<F5V(#T@)&QO9RT^
M<75E<GE2979I<VEO;B@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9W-;
M)')E=ET@/2`D;&]G.PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E=G-;72`]
M("1R978["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M<75I8VML;V<I('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!P8VQO<V4H)'!I<&4I.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!F=6QL>2!Q=6%L:69I960@9FEL96YA;64@;V8@=&AI<R!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!&=6QL>2!Q=6%L:69I960@9FEL96YA;64@
M;V8@=&AI<R!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE&=6QL
M4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR97`M/G-O=7)C
M97)O;W0H*2`N("<O)R`N("1T:&ES+3YQ=65R>4UO9'5L95!A=&@H*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;F%M92!O9B!T:&ES(&9I
M;&4@<F5L871I=F4@=&\@:71S('-O=7)C97)O;W0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%!A=&AN86UE(')E;&%T:79E('1O('1H92!S;W5R
M8V5R;V]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>4UO9'5L95!A=&@H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&ER("X@)R\G("X@)'1H
M:7,M/FYA;64["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(&QO9R!C;&%S<RX*
M("H*("H@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J
M"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U],;V=?<W9N('L*"B`@
M("!V87(@)')E<#L*("`@('9A<B`D97)R.PH@("`@=F%R("1F:6QE.PH@("`@
M=F%R("1F:6QE<SL*("`@('9A<B`D=&%G<SL*("`@('9A<B`D<F5V.PH@("`@
M=F%R("1D871E.PH@("`@=F%R("1L;V<["B`@("!V87(@)&%U=&AO<CL*("`@
M('9A<B`D<W1A=&4["B`@("!V87(@)&QI;F5S.PH@("`@=F%R("1B<F%N8VAE
M<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!60U],;V=?<W9N*"1R97`L("1F;"D*("`@('L*("`@("`@("`D
M=&AI<RT^<F5P(#T@)')E<#L*("`@("`@("`D=&AI<RT^9FEL92`]("1F;#L*
M("`@("`@("`D=&AI<RT^8G)A;F-H97,@/2!A<G)A>2@I.PH@("`@?0H*("`@
M(&9U;F-T:6]N('!R;V-E<W-,;V<H)'!I<&4I"B`@("!["B`@("`@("`@)&QI
M;F4@/2!F9V5T<R@D<&EP92D["@H@("`@("`@(&EF("AF96]F*"1P:7!E*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UYR*%LP+3E=*BD@7'P@*"XJ/RD@7'P@*"XJ
M*2!<*"XJ7"D@7'P@*%LP+3E=*BD@;&EN97,_)"\G+"`D;&EN92P@)&UA=&-H
M97,I*2!["B`@("`@("`@("`@("1T:&ES+3YR978@/2`D;6%T8VAE<ULQ73L*
M("`@("`@("`@("`@)'1H:7,M/F%U=&AO<B`]("1M871C:&5S6S)=.PH@("`@
M("`@("`@("`D=&AI<RT^9&%T92`]('-T<G1O=&EM92@D;6%T8VAE<ULS72D[
M"B`@("`@("`@("`@("1S:7IE(#T@)&UA=&-H97-;-%T["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/F5R<B`]("1L:6YE.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!F9V5T<R@D
M<&EP92D["@H@("`@("`@("1T:&ES+3YF:6QE<R`](&%R<F%Y*"D["B`@("`@
M("`@=VAI;&4@*"@D;&EN92`]('1R:6TH9F=E=',H)'!I<&4I*2D@(3T@)R<I
M('L*("`@("`@("`@("`@)'1H:7,M/F9I;&5S6UT@/2`D;&EN93L*("`@("`@
M("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`A/2`D<VEZ93L@*RLD:2D@
M>PH@("`@("`@("`@("`D=&AI<RT^;&]G(#T@)'1H:7,M/FQO9R`N(&-H;W`H
M9F=E=',H)'!I<&4I*2`N(")<;B(["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^;&]G(#T@8VAO<"@D=&AI<RT^;&]G*3L*("`@("`@("!F9V5T<R@D<&EP
M92D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N
M('%U97)Y1&%T92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871E
M.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y4F5V:7-I;VXH*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F5V.PH@("`@?0H*("`@(&9U;F-T:6]N
M('%U97)Y075T:&]R*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F%U
M=&AO<CL*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>4QO9R@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YL;V<["B`@("!]"@H@("`@9G5N8W1I;VX@
M<75E<GE#:&%N9V5D3&EN97,H*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^;&EN97,I(#\@*"1T:&ES+3YL:6YE<RD@.B`G)SL*("`@('T*
M"B`@("`O*BH*("`@("`J($=I=F5N(&$@8G)A;F-H(')E=FES:6]N(&YU;6)E
M<BP@=&AI<R!F=6YC=&EO;B!R96UA<',@:70*("`@("`J(&%C8V]R9&EN9VQY
M+"!A;F0@<&5R9F]R;7,@82!L;V]K=7`@;VX@=&AE(&9I;&4@;V)J96-T('1O
M"B`@("`@*B!R971U<FX@=&AE('-Y;6)O;&EC(&YA;64H<RD@;V8@=&AA="!B
M<F%N8V@@:6X@=&AE('1R964N"B`@("`@*@H@("`@("H@0')E='5R;B!H87-H
M(&]F('-Y;6)O;&EC(&YA;65S(#T^(&)R86YC:"!N=6UB97)S"B`@("`@*B\*
M("`@(&9U;F-T:6]N('%U97)Y4WEM8F]L:6-"<F%N8VAE<R@I"B`@("!["B`@
M("`@("`@)'-Y;4)R86YC:&5S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^8G)A;F-H97,@87,@)&)R86YC:"D@>PH@("`@("`@("`@("`D
M<&%R=',@/2!E>'!L;V1E*"<N)RP@)&)R86YC:"D["B`@("`@("`@("`@("1L
M87-T(#T@87)R87E?<&]P*"1P87)T<RD["B`@("`@("`@("`@("1P87)T<UM=
M(#T@)S`G.PH@("`@("`@("`@("`D<&%R='-;72`]("1L87-T.PH@("`@("`@
M("`@("`D<F5V(#T@:6UP;&]D92@G+B<L("1P87)T<RD["B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^9FEL92T^8G)A;F-H97-;)&)R86YC:%TI*2![
M"B`@("`@("`@("`@("`@("`D<WEM0G)A;F-H97-;)'1H:7,M/F9I;&4M/F)R
M86YC:&5S6R1B<F%N8VA=72`]("1B<F%N8V@["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1S>6U"<F%N8VAE<SL*("`@('T*"GT*
M"B\J*@H@*B!60U]S=FX@4&%T8VAS970@8VQA<W,N"B`J"B`J($-O<'ER:6=H
M="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@
M0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7U!A=&-H<V5T7W-V;B!E>'1E
M;F1S(%9#7U!A=&-H<V5T('L*"B`@("!V87(@)%]F:6QE.PH*("`@("\J*@H@
M("`@("H@0W)E871E(&$@<&%T8VAS970@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I;&4@(%1H92!F:6QE;F%M92!T;R!G970@<&%T
M8VAS971S(&9O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?4&%T8VAS971?
M<W9N*"1F:6QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9FEL92`]("1F:6QE
M.PH@("`@?0H*("`@(&9U;F-T:6]N("9G9710871C:'-E=$]B:F5C="@D<F5P
M+"`D9FEL96YA;64L("1C86-H92`](&YU;&PI"B`@("!["B`@("`@("`@+RH@
M5&AE('9E<G-I;VX@;V8@=&AE(&-A8VAE9"!D871A+B!);F-R96UE;G0@=&AI
M<R!W:&5N979E<B!T:&4*("`@("`@("`@*B!I;G1E<FYA;"!S=&]R86=E(&9O
M<FUA="!C:&%N9V5S+"!S=6-H('1H870@=V4@;75S=`H@("`@("`@("`J(&EN
M=F%L:61A=&4@<')I;W(@8V%C:&5D(&1A=&$N("HO"B`@("`@("`@)&-A8VAE
M5F5R<VEO;B`](#$["B`@("`@("`@)&-A8VAE260@/2`D<F5P+3YS;W5R8V5R
M;V]T*"D@+B`G7VXG("X@)&9I;&5N86UE("X@)U]F7W8G("X@)&-A8VAE5F5R
M<VEO;CL*"B`@("`@("`@:68@*"1C86-H92`F)@H@("`@("`@("`@("`O+R!4
M:&4@9FEL92!I<R!C86-H960@9F]R(&]N92!H;W5R(&YO(&UA='1E<B!W:&%T
M+"!B96-A=7-E"B`@("`@("`@("`@("\O('1H97)E(&ES(&YO('=A>2!T;R!D
M971E<FUI;F4@=VET:"!S=FX@=&AE('1I;64@=&AE(&9I;&4*("`@("`@("`@
M("`@+R\@;&%S="!C:&%N9V5D+@H@("`@("`@("`@("`D8V%C:&4M/F5X:7-T
M<R@D8V%C:&5)9"P@,S8P,"DI('L*("`@("`@("`@("`@)'!S3V(@/2!U;G-E
M<FEA;&EZ92@D8V%C:&4M/F=E="@D8V%C:&5)9"P@,S8P,"DI.PH@("`@("`@
M("`@("`D<'-/8BT^<V5T4F5P;W-I=&]R>2@D<F5P*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<'-/8B`](&YE=R!60U]0871C:'-E=%]S=FXH
M)&9I;&5N86UE*3L*("`@("`@("`@("`@)'!S3V(M/G-E=%)E<&]S:71O<GDH
M)')E<"D["B`@("`@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT(#T@)'!S3V(M
M/F=E=%!A=&-H<V5T<R@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@D8V%C:&4I('L*("`@("`@("`@("`@("`@("1C86-H92T^<V5T
M*"1C86-H94ED+"!S97)I86QI>F4H)'!S3V(I*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P<T]B.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4&]P=6QA=&4@=&AE(&]B:F5C="!W:71H(&EN9F]R;6%T:6]N
M(&%B;W5T('1H92!P871C:'-E=',@=&AA=`H@("`@("H@=&AI<R!F:6QE(&ES
M(&EN=F]L=F5D(&EN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%!%
M05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+"!O<B!T<G5E(&]N('-U8V-E<W,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A=&-H<V5T<R@I"B`@("!["B`@
M("`@("`@)&9I;&5/8B`](&YE=R!60U]&:6QE7W-V;B@D=&AI<RT^7W)E<"P@
M)'1H:7,M/E]F:6QE*3L*("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]("1F
M:6QE3V(M/F=E=$)R;W=S94EN9F\H*2DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W!A=&-H<V5T<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H
M)&9I;&5/8BT^;&]G<R!A<R`D<F5V(#T^("1L;V<I('L*("`@("`@("`@("`@
M)'1H:7,M/E]P871C:'-E='-;)')E=ET@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V75LG9&%T92==(#T@)&QO9RT^<75E
M<GE$871E*"D["B`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R979=
M6R=A=71H;W(G72`]("1L;V<M/G%U97)Y075T:&]R*"D["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%T8VAS971S6R1R979=6R=B<F%N8V@G72`]("<G.PH@("`@
M("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V75LG=&%G)UT@/2`G)SL*
M("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)')E=EU;)VQO9R==(#T@
M)&QO9RT^<75E<GE,;V<H*3L*("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E
M='-;)')E=EU;)VUE;6)E<G,G72`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1L;V<M/F9I;&5S(&%S("1F:6QE*2!["B`@("`@("`@("`@("`@
M("`D86-T:6]N(#T@<W5B<W1R*"1F:6QE+"`P+"`Q*3L*("`@("`@("`@("`@
M("`@("1F:6QE(#T@<')E9U]R97!L86-E*"<O+BH_7',H+BH_*2A<<WPD*2XJ
M+R<L("=<7#$G+"`D9FEL92D["B`@("`@("`@("`@("`@("`D=&\@/2`D<F5V
M.PH@("`@("`@("`@("`@("`@:68@*"1A8W1I;VX@/3T@)T$G*2!["B`@("`@
M("`@("`@("`@("`@("`@)&9R;VT@/2`G24Y)5$E!3"<["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)&%C=&EO;B`]/2`G1"<I('L*("`@("`@("`@("`@
M("`@("`@("`D9G)O;2`]("1T;SL*("`@("`@("`@("`@("`@("`@("`D=&\@
M/2`G*$1%040I)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@+R\@5&AI<R!T96-H;FEC86QL>2!I<VXG="!T:&4@<')E
M=FEO=7,@<F5V:7-I;VXL"B`@("`@("`@("`@("`@("`@("`@+R\@8G5T(&ET
M('=O<FMS(&9O<B!D:69F:6YG('!U<G!O<V5S+@H@("`@("`@("`@("`@("`@
M("`@("1F<F]M(#T@)'1O("T@,3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V75LG;65M8F5R<R==
M6UT@/2!A<G)A>2@G9FEL92<@/3X@)&9I;&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9G)O;2<@/3X@)&9R;VTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&\G(#T^("1T;RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R\`````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`V,0`P,38V-3,`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M3DQ3+V-O;W)D:6YA=&5S+G!H<```````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-S8U,S,T`#$P-3$U-#,Q,#8Q`#`R,3<Q-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AI<R!F
M:6QE(&QI<W1S('1H92!L;V-A=&EO;G,@;V8@8VET:65S(&%R;W5N9"!T:&4@
M=V]R;&0N(%1H90H@*B!F;W)M870@:7,Z"B`J"B`J("`@)&-O;W)D:6YA=&5S
M6R=C;W5N=')Y;F%M92==6R=L870Z;&]N9R==(#T@)V-I='EN86UE)SL*("H*
M("H@3&%T:71U9&4@86YD(&QO;F=I='5D92!A<F4@9&5C:6UA;',@*'-O=71H
M(&%N9"!W97-T(&%R92!N96=A=&EV92DN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+TY,4R].3%,O8V]O<F1I;F%T97,N<&AP+'8@,2XR+C$R+C,@,C`P-2\Q
M,"\Q."`Q,3HP,3HQ."!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?
M3DQ3"B`J+PH*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S,2XP,#`Z
M-C$N.#4P)UT@/2`G6F%R86YJ)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A
M;B==6R<S,BXS-C<Z-C(N,3@S)UT@/2`G1F%R86@G.PHD8V]O<F1I;F%T97-;
M)T%F9VAA;FES=&%N)UU;)S,S+C0P,#HV,BXR.#,G72`]("=3:&EN9&%N9"<[
M"B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S0N,C$W.C8R+C(Q-R==
M(#T@)TAE<F%T)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S-"XT
M,S,Z-S`N-#8W)UT@/2`G2F%L86QA8F%D)SL*)&-O;W)D:6YA=&5S6R=!9F=H
M86YI<W1A;B==6R<S-"XV,S,Z-CDN,C`P)UT@/2`G2V%B=6P@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S4N,3,S.C8Y+C(U,"==
M(#T@)TIA8G5L+5-A<F%J)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==
M6R<S-BXU,#`Z-S$N,C4P)UT@/2`G6F5B86LG.PHD8V]O<F1I;F%T97-;)T%F
M9VAA;FES=&%N)UU;)S,V+C8V-SHV-2XW,3<G72`]("=3:&5B:7)G:&%N)SL*
M)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S-BXW,#`Z-C<N,C`P)UT@
M/2`G36%Z87(M22U3:&%R:68G.PHD8V]O<F1I;F%T97-;)T%F9VAA;FES=&%N
M)UU;)S,W+C$Q-SHW,"XU,3<G72`]("=&86EZ86)A9"<["B1C;V]R9&EN871E
M<ULG06QB86YI82==6R<T,2XS,S,Z,3DN-S@S)UT@/2`G5&ER86YA)SL*)&-O
M;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S(T+C4U,#HY+C0V-R==(#T@)T1J86YE
M="<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<R-BXU,#`Z."XT,3<G72`]
M("=);&QI>FDG.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,C<N-C8W.BTX
M+C$S,R==(#T@)U1I;F1O=68G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG
M,C<N.#@S.BTP+C(X,R==(#T@)T%D<F%R)SL*)&-O;W)D:6YA=&5S6R=!;&=E
M<FEA)UU;)S(X+C`U,#HY+C8S,R==(#T@)TEN($%M96YA<R<["B1C;V]R9&EN
M871E<ULG06QG97)I82==6R<R.2XR-3`Z,"XR.#,G72`]("=4:6UI;6]U;B<[
M"B1C;V]R9&EN871E<ULG06QG97)I82==6R<S,"XU-C<Z,BXX-C<G72`]("=%
M;"!';VQE82<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S,2XV,3<Z+3(N
M,C,S)UT@/2`G0F5C:&%R)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,Q
M+C8V-SHV+C$U,"==(#T@)TAA<W-I+4UE<W-A;W5D)SL*)&-O;W)D:6YA=&5S
M6R=!;&=E<FEA)UU;)S,Q+CDQ-SHU+C0P,"==(#T@)T]U87)G;&$G.PHD8V]O
M<F1I;F%T97-;)T%L9V5R:6$G75LG,S(N,S@S.C,N.#$W)UT@/2`G1VAA<F1A
M:6$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S,N,3$W.C8N,3,S)UT@
M/2`G5&]U9V=O=7)T)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,S+C4P
M,#HV+C$Q-R==(#T@)T5L($]U960G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G
M75LG,S,N-S8W.C(N.3,S)UT@/2`G3&%G:&]U870G.PHD8V]O<F1I;F%T97-;
M)T%L9V5R:6$G75LG,S0N-C@S.C,N,C4P)UT@/2`G1&IE;&9A)SL*)&-O;W)D
M:6YA=&5S6R=!;&=E<FEA)UU;)S,T+C@P,#HU+C<S,R==(#T@)T)I<VMR82<[
M"B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-"XY,S,Z+3`N-#,S)UT@/2`G
M365C:&5R:6$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S4N,#$W.BTQ
M+C0V-R==(#T@)U1L96UC96X@6F5N871A)SL*)&-O;W)D:6YA=&5S6R=!;&=E
M<FEA)UU;)S,U+C(P,#HM,"XQ,S,G72`]("=-87-C87)A+4=H<FES<R<["B1C
M;V]R9&EN871E<ULG06QG97)I82==6R<S-2XR-3`Z,2XT,S,G72`]("=4:6%R
M970G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S4N,S,S.C0N,C`P)UT@
M/2`G0F]U+5-A861A)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C0X
M,SHX+C$S,R==(#T@)U1E8F5S<V$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G
M75LG,S4N-34P.C8N,3@S)UT@/2`G0F%T;F$G.PHD8V]O<F1I;F%T97-;)T%L
M9V5R:6$G75LG,S4N-C,S.BTP+C8P,"==(#T@)T]R86X@+R!%<R!396YI82<[
M"B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-BXQ.#,Z-2XT,3<G72`]("=3
M971I9B<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-BXR,3<Z,2XS,S,G
M72`]("=#:&QE9B<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-BXR.#,Z
M-BXV,3<G72`]("=#;VYS=&%N=&EN92<["B1C;V]R9&EN871E<ULG06QG97)I
M82==6R<S-BXW,3<Z,RXR-3`G72`]("=$87(M16PM0F5I9&$G.PHD8V]O<F1I
M;F%T97-;)T%L9V5R:6$G75LG,S8N-S$W.C4N,#8W)UT@/2`G0F5J86EA)SL*
M)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,V+C@S,SHW+C@Q-R==(#T@)T%N
M;F%B82<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-BXX.#,Z-2XX,3<G
M72`]("=*:6IE;"!!8VAO=6%T)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;
M)S,V+CDS,SHV+CDU,"==(#T@)U-K:6MD82<["B1C;V]R9&EN871E<ULG06YG
M;VQA)UU;)RTQ,BXS.#,Z,38N.34P)UT@/2`G0FEE(%-I;'9A(%!O<G1O)SL*
M)&-O;W)D:6YA=&5S6R=!;F=O;&$G75LG+3$R+C4X,SHQ,RXT,3<G72`]("=-
M;VYB86-A($)E;F=U96QA)SL*)&-O;W)D:6YA=&5S6R=!;F=O;&$G75LG+3$R
M+C@P,#HQ-2XW-3`G72`]("=(=6%M8F\@3F]V82!,:7-B;V$G.PHD8V]O<F1I
M;F%T97-;)T%N9V]L82==6R<M-2XU-3`Z,3(N,3@S)UT@/2`G0V%B:6YD82<[
M"B1C;V]R9&EN871E<ULG06YG;VQA)UU;)RTX+C@U,#HQ,RXR,S,G72`]("=,
M=6%N9&$G.PHD8V]O<F1I;F%T97-;)T%N=&%R8W1I8V$G75LG+3<W+C@V-SHQ
M-C8N.38W)UT@/2`G5VEL;&EA;7,@1FEE;&0G.PHD8V]O<F1I;F%T97-;)T%N
M=&%R8W1I8V$G75LG+3DP+C`P,#HP+C`P,"==(#T@)T%M=6YD<V5N+5-C;W1T
M(%-O=71H(%!O;&4@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG06YT:6=U82!A
M;F0@0F%R8G5D82==6R<Q-RXQ,3<Z+38Q+C<X,R==(#T@)U9C($)I<F0@26YT
M97)N871I;VYA;"!!:7)P;W)T($%N=&EG=6$G.PHD8V]O<F1I;F%T97-;)T%N
M=&EG=6$@86YD($)A<F)U9&$G75LG,3<N,C`P.BTV,BXU.#,G72`]("=#:&%R
M;&5S=&]W;B`O($YE=V-A<W0G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,C(N,3`P.BTV-2XV,#`G72`]("=,82!1=6EA8V$@3V)S97)V871O<FEO
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(R+C8U,#HM-C,N.#$W
M)UT@/2`G5&%R=&%G86P@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3(S+C$U,#HM-C0N,S$W)UT@/2`G3W)A;B!!97)O9')O;64G
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C0N,38W.BTV,BXY,#`G
M72`]("=2:79A9&%V:6$G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,C0N,S@S.BTV-2XP.#,G72`]("=*=6IU>2!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M,C0N-S`P.BTV,"XU.#,G72`]("=,87,@
M3&]M:71A<R<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-"XX-3`Z
M+38U+C0X,R==(#T@)U-A;'1A($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTR-2XW,S,Z+34T+C0V-R==(#T@)TEG=6%Z=2!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C8N,C`P.BTU
M."XR,S,G72`]("=&;W)M;W-A($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTR-BXX,3<Z+38P+C0U,"==(#T@)U!R97-I9&5N8VEA
M(%)O<75E(%-A96YZ(%!E;F$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+3(V+C@U,#HM-C4N,3`P)UT@/2`G5'5C=6UA;B!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C<N,S8W.BTU
M-2XY-C<G72`]("=0;W-A9&%S($%E<F\N)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3(W+C0U,#HM-3@N-S8W)UT@/2`G0V]R<FEE;G1E<R!!97)O
M+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-RXT-3`Z+34Y+C`U
M,"==(#T@)U)E<VES=&5N8VEA($%E<F\N)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3(W+C<V-SHM-C0N,S`P)UT@/2`G4V%N=&EA9V\@1&5L($5S
M=&5R;R!!97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR."XP
M-C<Z+38W+C4V-R==(#T@)U1I;F]G87-T82<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTR."XV,#`Z+38U+C<V-R==(#T@)T-A=&%M87)C82!!97)O
M+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR.2XR,3<Z+38W+C0S
M,R==(#T@)T-H:6QE8VET;R<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;
M)RTR.2XS.#,Z+38V+C@Q-R==(#T@)TQA(%)I;VIA($%E<F\N)SL*)&-O;W)D
M:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(Y+C8X,SHM-3<N,34P)UT@/2`G4&%S
M;R!$92!,;W,@3&EB<F5S($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTR.2XW.#,Z+34W+CDX,R==(#T@)T-U<G5Z=2!#=6%T:6$@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(Y+C@X
M,SHM-C$N.34P)UT@/2`G0V5R97,@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3(Y+CDP,#HM-C,N-C@S)UT@/2`G5FEL;&$@1&4@
M36%R:6$@1&5L(%)I;R!396-O)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G
M75LG+3,P+C(U,#HM-C@N-S4P)UT@/2`G2F%C:&%L)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3,P+C(V-SHM-3<N-C4P)UT@/2`G36]N=&4@0V%S
M97)O<R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,S$N,S`P.BTU."XP,3<G72`]("=#;VYC;W)D:6$@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C,Q-SHM-C0N,C$W)UT@/2`G
M0V]R9&]B82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,S$N,S,S.BTV-BXV,#`G72`]("=#:&5P97,G.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M,S$N-38W.BTV."XX-C<G72`]("=386X@2G5A;B!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N-C8W
M.BTV,RXX.#,G72`]("=0:6QA<B!/8G-E<G9A=&]R:6\G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S$N-S`P.BTV,"XX,3<G72`]("=3875C92!6
M:65J;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,S$N-S@S.BTV,"XT.#,G72`]("=087)A;F$@065R;V1R;VUE)SL*)&-O;W)D
M:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C@U,#HM-3DN,#@S)UT@/2`G5FEL
M;&%G=6%Y($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;
M)RTS,2XY-3`Z+38U+C$S,R==(#T@)U9I;&QA($1O;&]R97,@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,R+C8P,#HM-CDN,S,S
M)UT@/2`G57-P86QL871A)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+3,R+C<P,#HM-C(N,34P)UT@/2`G36%R8V]S($IU87)E>B!!97)O9')O;64G
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S(N.#,S.BTV."XW.#,G
M72`]("=-96YD;WIA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT
M:6YA)UU;)RTS,BXY,3<Z+38P+C<X,R==(#T@)U)O<V%R:6\@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,S+C`P,#HM-3@N-C$W
M)UT@/2`G1W5A;&5G=6%Y8VAU($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTS,RXP.#,Z+38X+C0Q-R==(#T@)U-A;B!-87)T:6XG
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S,N,3$W.BTV-"XR,S,G
M72`]("=2:6\@0W5A<G1O($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTS,RXR-C<Z+38V+C,U,"==(#T@)U-A;B!,=6ES($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,RXW,S,Z+38U
M+C,X,R==(#T@)U9I;&QA(%)E>6YO;&1S($%E<F]D<F]M92<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTS,RXW-C<Z+38Y+C`S,R==(#T@)U-A;B!#
M87)L;W,G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N,3,S.BTV
M,RXS-C<G72`]("=,86)O=6QA>64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M,S0N-#@S.BTU."XV,3<G72`]("=$;VX@5&]R8W5A=&\@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,T+C4U,#HM-C`N
M.3$W)UT@/2`G2G5N:6X@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,T+C4V-SHM-3@N-#$W)UT@/2`G065R;W!A<G%U92!"<RX@
M07,N($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS
M-"XU.#,Z+34X+C0X,R==(#T@)T)U96YO<R!!:7)E<R!/8G-E<G9A=&]R:6\G
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N-3@S.BTV."XT,#`G
M72`]("=386X@4F%F865L($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTS-"XV,#`Z+34X+C8P,"==(#T@)T5L(%!A;&]M87(@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,T+C@Q-SHM
M-3@N-3,S)UT@/2`G17IE:7IA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTS-"XY-C<Z+34W+CDP,"==(#T@)TQA(%!L871A($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-2XU,#`Z
M+38Y+C4X,R==(#T@)TUA;&%R9W5E($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTS-2XW,#`Z+38S+C<U,"==(#T@)T=E;F5R86P@
M4&EC;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,S4N.#8W.BTV,2XY,#`G72`]("=096AU86IO($%E<F]D<F]M92<["B1C;V]R
M9&EN871E<ULG07)G96YT:6YA)UU;)RTS-BXS-3`Z+34W+C<S,R==(#T@)T1O
M;&]R97,@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+3,V+C4V-SHM-C0N,C8W)UT@/2`G4V%N=&$@4F]S82!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S8N-S4P.BTU.2XX,S,G72`]
M("=!>G5L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,S<N,C,S.BTU-RXP,S,G72`]("=6:6QL82!'97-E;&PG.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S<N,C,S.BTU.2XR-3`G72`]("=486YD:6P@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,W+C8P
M,#HM-C(N,S@S)UT@/2`G4&EG=64@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3,W+CDS,SHM-3<N-3@S)UT@/2`G36%R($1E;"!0
M;&%T82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,S@N,S,S.BTV,"XR-3`G72`]("=4<F5S($%R<F]Y;W,G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S@N-S,S.BTV,BXQ-C<G72`]("="86AI82!"
M;&%N8V$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+3,X+CDU,#HM-C@N,3,S)UT@/2`G3F5U<75E;B!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,SDN,#$W.BTV-"XP.#,G72`]("=2
M:6\@0V]L;W)A9&\G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#`N
M,#@S.BTW,2XQ,S,G72`]("=#:&%P96QC;R<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTT,"XW.#,Z+38U+C$P,"==(#T@)U-A;B!!;G1O;FEO($]E
M<W1E($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT
M,"XX-3`Z+38S+C`Q-R==(#T@)U9I961M82!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M-#$N,34P.BTW,2XQ-C<G72`]("="87)I
M;&]C:&4@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+30Q+CDV-SHM-S$N-3$W)UT@/2`G16P@0F]L<V]N($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT,BXY,S,Z+3<Q+C$U,"==(#T@
M)T5S<75E;"!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M-#,N,C`P.BTV-2XR-C<G72`]("=4<F5L97<@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30S+C@Q-SHM-C@N.#@S)UT@/2`G
M4&%S;R!$92!);F1I;W,G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M-#4N-S@S.BTV-RXU,#`G72`]("=#;VUO9&]R;R!2:79A9&%V:6$@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30V+C4Q-SHM-S$N
M,#$W)UT@/2`G4&5R:71O($UO<F5N;R!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M-#<N-S,S.BTV-2XY,3<G72`]("=0=65R=&\@
M1&5S96%D;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M-#@N-S@S.BTW,"XQ-C<G72`]("=';V)E<FYA9&]R($=R96=O<F5S($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT.2XS,3<Z
M+38W+C<U,"==(#T@)U-A;B!*=6QI86X@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+34P+C`Q-SHM-C@N-38W)UT@/2`G4V%N=&$@
M0W)U>B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M-3`N,S,S.BTW,BXS,#`G72`]("=,86=O($%R9V5N=&EN;R!!97)O9')O;64G
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-3$N-C$W.BTV.2XR.#,G
M72`]("=2:6\@1V%L;&5G;W,@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+34S+C@P,#HM-C<N-S4P)UT@/2`G4FEO($=R86YD92!"
M+B!!+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTU-"XX,#`Z+38X
M+C,Q-R==(#T@)U5S:'5A:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<FUE;FEA)UU;)S0P+C$S,SHT-"XT-C<G72`]("=997)E=F%N)SL*)&-O;W)D
M:6YA=&5S6R=!<G5B82==6R<Q,BXU,#`Z+3<P+C`Q-R==(#T@)U%U965N($)E
M871R:7@@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ
M,BXR-C<Z,3,V+C@Q-R==(#T@)T=O=F4@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTQ,BXT,#`Z,3,P+C@V-R==(#T@)T1A<G=I;B!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3$R+C8S,SHQ
M-#$N.#@S)UT@/2`G5V5I<&$@0VET>2<["B1C;V]R9&EN871E<ULG075S=')A
M;&EA)UU;)RTQ-2XW-C<Z,3(X+C<P,"==(#T@)TMU;G5N=7)R82!+=6YU;G5R
M<F$@07=S)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3$V+C@X,SHQ
M-#4N-S4P)UT@/2`G0V%I<FYS($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U
M<W1R86QI82==6R<M,3<N,S`P.C$R,RXV,3<G72`]("=$97)B>2<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTQ-RXY-3`Z,3(R+C(Q-R==(#T@)T)R
M;V]M92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3$Y
M+C(U,#HQ-#8N-S4P)UT@/2`G5&]W;G-V:6QL92!!;6\G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,3DN-C,S.C$S-"XQ-C<G72`]("=496YN86YT
M($-R965K($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M
M,C`N,3`P.C$Q.2XU-C<G72`]("=0;W)T($AE9&QA;F0@4&%R9&]O)SL*)&-O
M;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(P+C0X,SHQ-#@N-3,S)UT@/2`G
M4')O<V5R<&EN92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3(P+C8V-SHQ,SDN-#8W)UT@/2`G36]U;G0@27-A($%M;R<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTR,2XQ,3<Z,30Y+C(P,"==(#T@)TUA
M8VMA>2!-;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR,BXR,S,Z
M,3$T+C`X,R==(#T@)TQE87)M;VYT:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<F%L:6$G75LG+3(S+C,X,SHQ-3`N-#8W)UT@/2`G4F]C:VAA;7!T
M;VX@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR,RXT
M,S,Z,30T+C(V-R==(#T@)TQO;F=R96%C:"!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3(S+C@P,#HQ,S,N.#@S)UT@/2`G06QI8V4@
M4W!R:6YG<R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,C,N.#4P.C$U,2XR-3`G72`]("=';&%D<W1O;F4G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,C4N,3@S.C$S,"XY-C<G72`]("=9=6QA<F$@
M07=S)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(V+C0P,#HQ-#8N
M,C8W)UT@/2`G0VAA<FQE=FEL;&4@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M075S=')A;&EA)UU;)RTR-BXV,#`Z,3$X+C4S,R==(#T@)TUE96MA=&AA<G)A
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C<N,S@S
M.C$U,RXQ,#`G72`]("="<FES8F%N92!!:7)P;W)T($TN($\G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,C<N-#$W.C$U,2XW,S,G72`]("=/86ME
M>2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C<N
M-38W.C$U,RXP,#`G72`]("=!<F-H97)F:65L9"!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C<N-C,S.C$U,BXW,3<G72`]("=!
M;6)E<FQE>2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,C@N,38W.C$U,RXU,#`G72`]("=#;V]L86YG871T82!!:7)P;W)T($%W
M<R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR."XW.#,Z,3$T+C<P
M,"==(#T@)T=E<F%L9'1O;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+3(Y+C`S,SHQ-C<N.3,S)UT@/2`G3F]R9F]L:R!)<VQA;F0@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,"XS,3<Z
M,34S+C$Q-R==(#T@)T-O9F9S($AA<F)O=7(@36\G.PHD8V]O<F1I;F%T97-;
M)T%U<W1R86QI82==6R<M,S`N-3@S.C$S."XT,3<G72`]("=,96EG:"!#<F5E
M:R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,P+C<X
M,SHQ,C$N-#4P)UT@/2`G2V%L9V]O<FQI92!";W5L9&5R($%M;R<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTS,"XX,S,Z,3(X+C$P,"==(#T@)T9O
M<G)E<W0@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS
M,2XP.#,Z,34P+C@S,R==(#T@)U1A;7=O<G1H($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,S$N,3,S.C$S-BXX,3<G72`]("=7;V]M
M97)A($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS
M,2XV-C<Z,3$V+C`Q-R==(#T@)T)U;&QS8G)O;VL@4&5A<F-E($%M;R<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,2XY,S,Z,3$U+CDU,"==(#T@
M)T)E;&UO;G0@4&5R=&@@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A
M;&EA)UU;)RTS,2XY-C<Z,30Q+C0V-R==(#T@)T)R;VME;B!(:6QL(%!A='1O
M;B!3=')E970G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S(N,3$W
M.C$S,RXW,#`G72`]("=#961U;F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M075S=')A;&EA)UU;)RTS,BXR,#`Z,30X+C4V-R==(#T@)T1U8F)O)SL*)&-O
M;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,R+C<X,SHQ-3$N.#$W)UT@/2`G
M5VEL;&EA;71O=VX@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L
M:6$G75LG+3,S+C8P,#HQ-3`N-S@S)UT@/2`G4FEC:&UO;F0@075S+4%F8B<[
M"B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,RXY,3<Z,34P+CDX,R==
M(#T@)T)A;FMS=&]W;B!!:7)P;W)T($%W<R<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTS,RXY-3`Z,34Q+C$X,R==(#T@)U-Y9&YE>2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,T+C`S,SHQ-3`N-C@S
M)UT@/2`G0V%M9&5N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI
M82==6R<M,S0N,C$W.C$T,BXP.#,G72`]("=-:6QD=7)A($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S0N-S`P.C$S."XV,3<G72`]
M("=%9&EN8G5R9V@@32X@3RXG.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,S0N-S@S.C$S."XV,S,G72`]("=087)A9FEE;&0@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-"XY,S,Z,3$W+C@P,"==(#T@
M)T%L8F%N>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG
M+3,T+CDS,SHQ,S@N-3$W)UT@/2`G061E;&%I9&4@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTS-"XY-3`Z,34P+C4S,R==(#T@)TYO
M=W)A(%)A;B!!:7(@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTS-2XQ-3`Z,30W+C0U,"==(#T@)U=A9V=A($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S4N,S`P.C$T.2XQ.#,G72`]("=#
M86YB97)R82<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-BXP-C<Z
M,30V+CDU,"==(#T@)T%L8G5R>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!
M=7-T<F%L:6$G75LG+3,V+C(S,SHQ-#DN,#@S)UT@/2`G0V]O;6$G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S<N-C8W.C$T-"XX,S,G72`]("=-
M96QB;W5R;F4@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTS-RXW,S,Z,30P+C<X,R==(#T@)TUO=6YT($=A;6)I97(@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,W+C<S,SHQ-#4N-#`P
M)UT@/2`G1V]L9'-T<F5A;2!!=W,G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI
M82==6R<M,S<N.#4P.C$T-"XW,S,G72`]("=,879E<G1O;B!!97)O9')O;64G
M.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S<N.38W.C$T-2XQ,#`G
M72`]("=-;V]R86)B:6X@06ER<&]R="!!=W,G.PHD8V]O<F1I;F%T97-;)T%U
M<W1R86QI82==6R<M,S@N,3`P.C$T-RXQ,S,G72`]("=%87-T(%-A;&4@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+30P+CDX,SHQ
M-#4N-S$W)UT@/2`G5WEN>6%R9"!797-T)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+30Q+C$V-SHQ-#8N,S8W)UT@/2`G1&5V;VYP;W)T($5A<W0G
M.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M-#$N-3,S.C$T-RXR,#`G
M72`]("=,875N8V5S=&]N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R
M86QI82==6R<M-#(N.#,S.C$T-RXT.#,G72`]("=(;V)A<G0@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTU-"XT.#,Z,34X+CDU,"==
M(#T@)TUA8W%U87)I92!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G
M75LG-#8N-C4P.C$T+C,S,R==(#T@)TML86=E;F9U<G0M1FQU9VAA9F5N)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0W+C`P,#HQ-2XT,S,G72`]("='
M<F%Z+51H86QE<FAO9BU&;'5G:&%F96XG.PHD8V]O<F1I;F%T97-;)T%U<W1R
M:6$G75LG-#<N,C`P.C$T+C<U,"==(#T@)UIE;'1W96<G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R:6$G75LG-#<N,C8W.C$Q+C,U,"==(#T@)TEN;G-B<G5C:RU&
M;'5G:&%F96XG.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#<N,S,S.C$Q
M+C<P,"==(#T@)U-C:'=A>B!(96QI<&]R="<["B1C;V]R9&EN871E<ULG075S
M=')I82==6R<T-RXU,S,Z,30N,3,S)UT@/2`G06EG96X@26T@16YN<W1A;"<[
M"B1C;V]R9&EN871E<ULG075S=')I82==6R<T-RXX,#`Z,3,N,#`P)UT@/2`G
M4V%L>F)U<F<M1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;
M)S0W+CDV-#HQ-BXR-3DG72`]("=.:65D97)O<W1E<G)E:6-H("\@3'5G<&QA
M='H@(%9O<VQA=2<["B1C;V]R9&EN871E<ULG075S=')I82==6R<T."XQ,3<Z
M,38N-38W)UT@/2`G5VEE;B`O(%-C:'=E8VAA="U&;'5G:&%F96XG.PHD8V]O
M<F1I;F%T97-;)T%U<W1R:6$G75LG-#@N,C,S.C$T+C$X,R==(#T@)TAO<G-C
M:&EN9R!!=7,M069B)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0X+C(S
M,SHQ-"XQ.#,G72`]("=,:6YZ("\@2&]E<G-C:&EN9RU&;'5G:&%F96XG.PHD
M8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#@N,S$W.C$V+C$Q-R==(#T@)U1U
M;&QN)SL*)&-O;W)D:6YA=&5S6R=!>F5R8F%I:F%N)UU;)S0P+C0U,#HU,"XP
M-C<G72`]("="86MU("\@0FEN92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="
M86AA;6%S)UU;)S(P+CDU,#HM-S,N-C@S)UT@/2`G36%T=&AE=R!4;W=N+"!)
M;F%G=6$G.PHD8V]O<F1I;F%T97-;)T)A:&%M87,G75LG,C,N-#<U.BTW-2XW
M-C<G72`]("='96]R9V5T;W=N+"!%>'5M82<["B1C;V]R9&EN871E<ULG0F%H
M86UA<R==6R<R-"XP-3`Z+3<T+C4S,R==(#T@)T-O8VMB=7)N(%1O=VXL(%-A
M;B!386QV861O<B<["B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R-2XP-3`Z
M+3<W+C0V-R==(#T@)TYA<W-A=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="
M86AA;6%S)UU;)S(U+C<S,SHM-SDN,S`P)UT@/2`G06QI8V4@5&]W;BP@0FEM
M:6YI)SL*)&-O;W)D:6YA=&5S6R="86AA;6%S)UU;)S(V+C4U,#HM-S@N-S`P
M)UT@/2`G1G)E97!O<G0L($=R86YD($)A:&%M82<["B1C;V]R9&EN871E<ULG
M0F%H86UA<R==6R<R-BXW,#`Z+3<X+CDV-R==(#T@)U=E<W0@16YD+"!'<F%N
M9"!"86AA;6$G.PHD8V]O<F1I;F%T97-;)T)A:')A:6XG75LG,C8N,C8W.C4P
M+C8U,"==(#T@)T)A:')A:6X@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R="86YG;&%D97-H)UU;)S(Q+C0S,SHY,2XY-C<G72`]("=#
M;WA<)W,@0F%Z87(G.PHD8V]O<F1I;F%T97-;)T)A;F=L861E<V@G75LG,C(N
M,C8W.CDQ+C@Q-R==(#T@)T-H:71T86=O;F<@4&%T96YG82<["B1C;V]R9&EN
M871E<ULG0F%N9VQA9&5S:"==6R<R,RXQ.#,Z.#DN,38W)UT@/2`G2F5S<V]R
M92<["B1C;V]R9&EN871E<ULG0F%N9VQA9&5S:"==6R<R,RXW-C<Z.3`N,S@S
M)UT@/2`G1&AA:V$G.PHD8V]O<F1I;F%T97-;)T)A;F=L861E<V@G75LG,C,N
M.#4P.CDP+C0P,"==(#T@)TMU<FUI=&]L82P@1&EA)SL*)&-O;W)D:6YA=&5S
M6R="86YG;&%D97-H)UU;)S(T+C$S,SHX.2XP-3`G72`]("=)<VAU<F1I)SL*
M)&-O;W)D:6YA=&5S6R="86YG;&%D97-H)UU;)S(T+C,V-SHX."XW,#`G72`]
M("=286IS:&%H:2<["B1C;V]R9&EN871E<ULG0F%N9VQA9&5S:"==6R<R-"XY
M,#`Z.3$N.#@S)UT@/2`G4WEL:&5T)SL*)&-O;W)D:6YA=&5S6R="87)B861O
M<R==6R<Q,RXP-C<Z+34Y+C0X,R==(#T@)T=R86YT;&5Y($%D86US)SL*)&-O
M;W)D:6YA=&5S6R="96QA<G5S)UU;)S4S+CDS,SHR-RXV,S,G72`]("=-:6YS
M:R<["B1C;V]R9&EN871E<ULG0F5L87)U<R==6R<U-2XQ-C<Z,S`N,C$W)UT@
M/2`G5FET96)S:R<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<T.2XY,#`Z
M-2XR,3<G72`]("="97)T<FEX($)E;"U!9F(G.PHD8V]O<F1I;F%T97-;)T)E
M;&=I=6TG75LG-3`N,#,S.C4N-#`P)UT@/2`G4W0M2'5B97)T)SL*)&-O;W)D
M:6YA=&5S6R="96QG:75M)UU;)S4P+C(S,SHT+C8U,"==(#T@)T9L;W)E;FYE
M<R<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XT-C<Z-"XT-3`G72`]
M("=#:&%R;&5R;VD@+R!';W-S96QI97,G.PHD8V]O<F1I;F%T97-;)T)E;&=I
M=6TG75LG-3`N-#8W.C8N,3@S)UT@/2`G16QS96YB;W)N)SL*)&-O;W)D:6YA
M=&5S6R="96QG:75M)UU;)S4P+C0X,SHU+CDQ-R==(#T@)U-P82`O($QA(%-A
M=79E;FEE<F4G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N-38W.C,N
M.#,S)UT@/2`G0VAI979R97,G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG
M-3`N-C4P.C4N-#4P)UT@/2`G0FEE<G-E="<["B1C;V]R9&EN871E<ULG0F5L
M9VEU;2==6R<U,"XW-3`Z-"XW-C<G72`]("="96%U=F5C:&%I;B<["B1C;V]R
M9&EN871E<ULG0F5L9VEU;2==6R<U,"XW.#,Z-"XY-3`G72`]("=';V5T<V5N
M:&]V96XG.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N.#`P.C4N,C`P
M)UT@/2`G4VEN="U4<G5I9&5N)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;
M)S4P+CDP,#HT+C4P,"==(#T@)TUE;'-B<F]E:R!"96PM069B)SL*)&-O;W)D
M:6YA=&5S6R="96QG:75M)UU;)S4P+CDP,#HT+C4S,R==(#T@)T)R=7AE;&QE
M<R!.871I;VYA;"<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XY,S,Z
M,RXW,S,G72`]("=-=6YT92<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U
M,"XY,S,Z-2XU,#`G72`]("='96YK)SL*)&-O;W)D:6YA=&5S6R="96QG:75M
M)UU;)S4Q+C`P,#HU+C`V-R==(#T@)U-C:&%F9F5N)SL*)&-O;W)D:6YA=&5S
M6R="96QG:75M)UU;)S4Q+C`X,SHR+C8U,"==(#T@)TMO:W-I:F1E)SL*)&-O
M;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C$V-SHU+C0V-R==(#T@)TML96EN
M92!"<F]G96PG.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3$N,3@S.C,N
M.#$W)UT@/2`G1V5N="`O($EN9'5S=')I92U:;VYE)SL*)&-O;W)D:6YA=&5S
M6R="96QG:75M)UU;)S4Q+C(P,#HR+C@V-R==(#T@)T]O<W1E;F1E($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3$N,C`P.C0N-#8W)UT@
M/2`G06YT=V5R<&5N("\@1&5U<FYE)SL*)&-O;W)D:6YA=&5S6R="96QG:75M
M)UU;)S4Q+C,S,SHT+C4P,"==(#T@)T)R87-S8VAA870G.PHD8V]O<F1I;F%T
M97-;)T)E;&=I=6TG75LG-3$N-#$W.C4N,#`P)UT@/2`G5V5E;&1E($UI;&ET
M87)Y)SL*)&-O;W)D:6YA=&5S6R="96QI>F4G75LG,3<N-3,S.BTX."XS,#`G
M72`]("="96QI>F4@+R!0:&EL;&EP($=O;&1S=&]N($EN=&PN($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T)E;FEN)UU;)S$P+C,Q-SHQ+C,X,R==(#T@)TYA
M=&ET:6YG;W4G.PHD8V]O<F1I;F%T97-;)T)E;FEN)UU;)S$Q+C$S,SHR+CDS
M,R==(#T@)TMA;F1I)SL*)&-O;W)D:6YA=&5S6R="96YI;B==6R<V+C,U,#HR
M+C,X,R==(#T@)T-O=&]N;W4G.PHD8V]O<F1I;F%T97-;)T)E;FEN)UU;)S<N
M,38W.C(N,#8W)UT@/2`G0F]H:6-O;B<["B1C;V]R9&EN871E<ULG0F5N:6XG
M75LG."XP,S,Z,BXT-C<G72`]("=3879E)SL*)&-O;W)D:6YA=&5S6R="96YI
M;B==6R<Y+C,U,#HR+C8Q-R==(#T@)U!A<F%K;W4G.PHD8V]O<F1I;F%T97-;
M)T)E<FUU9&$G75LG,S(N,S8W.BTV-"XV.#,G72`]("="97)M=61A)SL*)&-O
M;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ,"XX,3<Z+38U+C,U,"==(#T@)T=U
M87EA<F%M97)I;B<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3$N,#`P
M.BTV-BXQ,3<G72`]("=2:6)E<F%L=&$G.PHD8V]O<F1I;F%T97-;)T)O;&EV
M:6$G75LG+3$Q+C`S,SHM-C@N-S@S)UT@/2`G0V]B:6IA)SL*)&-O;W)D:6YA
M=&5S6R=";VQI=FEA)UU;)RTQ,RXP-C<Z+38T+C@Q-R==(#T@)U-A;B!*;V%Q
M=6EN)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ,RXS,S,Z+38T+C$Q
M-R==(#T@)TUA9V1A;&5N82<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M
M,3,N-S8W.BTV-2XT,S,G72`]("=386YT82!!;F$G.PHD8V]O<F1I;F%T97-;
M)T)O;&EV:6$G75LG+3$T+C,Q-SHM-C<N,S@S)UT@/2`G4F5Y97,G.PHD8V]O
M<F1I;F%T97-;)T)O;&EV:6$G75LG+3$T+C0V-SHM-C<N-38W)UT@/2`G4G5R
M<F5N86)A<75E)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-"XW,S,Z
M+38X+C4P,"==(#T@)T%P;VQO)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;
M)RTQ-"XX,3<Z+38T+CDQ-R==(#T@)U1R:6YI9&%D)SL*)&-O;W)D:6YA=&5S
M6R=";VQI=FEA)UU;)RTQ-"XX-C<Z+38V+C@V-R==(#T@)U-A;B!";W)J82<[
M"B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,30N.3$W.BTV-2XV,#`G72`]
M("=386X@26=N86-I;R!$92!-;WAO<R<["B1C;V]R9&EN871E<ULG0F]L:79I
M82==6R<M,34N-S$W.BTV,RXQ,#`G72`]("=!<V-E;F-I;VX@1&4@1W5A<F%Y
M;W,G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$V+C$U,#HM-C(N,#$W
M)UT@/2`G0V]N8V5P8VEO;B<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M
M,38N,C8W.BTV,BXT-C<G72`]("=386X@2F%V:65R)SL*)&-O;W)D:6YA=&5S
M6R=";VQI=FEA)UU;)RTQ-BXS.#,Z+38P+CDV-R==(#T@)U-A;B!)9VYA8VEO
M($1E(%9E;&%S8V\G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$V+C4Q
M-SHM-C@N,3@S)UT@/2`G3&$@4&%Z("\@06QT;R<["B1C;V]R9&EN871E<ULG
M0F]L:79I82==6R<M,3<N-#$W.BTV-BXQ.#,G72`]("=#;V-H86)A;6)A)SL*
M)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-RXU.#,Z+38Y+C8P,"==(#T@
M)T-H87)A;F$G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$W+C8S,SHM
M-C,N,3,S)UT@/2`G5FER=2U6:7)U)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA
M)UU;)RTQ-RXX,#`Z+38P+C<S,R==(#T@)U-A;B!*;W-E($1E($-H:7%U:71O
M<R<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3<N.#`P.BTV,RXQ.#,G
M72`]("=386YT82!#<G5Z("\@16P@5')O;7!I;&QO)SL*)&-O;W)D:6YA=&5S
M6R=";VQI=FEA)UU;)RTQ-RXY-C<Z+38W+C`V-R==(#T@)T]R=7)O)SL*)&-O
M;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ."XS,3<Z+34Y+C<V-R==(#T@)U)O
M8F]R92<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3@N.3@S.BTU-RXX
M,3<G72`]("=0=65R=&\@4W5A<F5Z)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA
M)UU;)RTQ.2XP,3<Z+38U+C,P,"==(#T@)U-U8W)E)SL*)&-O;W)D:6YA=&5S
M6R=";VQI=FEA)UU;)RTQ.2XU-3`Z+38U+C<S,R==(#T@)U!O=&]S:2<["B1C
M;V]R9&EN871E<ULG0F]L:79I82==6R<M,C`N,#`P.BTV,RXU,S,G72`]("=#
M86UI<FDG.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3(Q+C(U,#HM-C,N
M-#4P)UT@/2`G5FEL;&%M;VYT97,G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G
M75LG+3(Q+C4U,#HM-C0N-S`P)UT@/2`G5&%R:6IA)SL*)&-O;W)D:6YA=&5S
M6R=";VQI=FEA)UU;)RTR,2XY-3`Z+38S+C8U,"==(#T@)UEA8W5I8F$G.PHD
M8V]O<F1I;F%T97-;)T)O<VYI82!A;F0@2&5R>F5G;W9I;F$G75LG-#,N.#,S
M.C$W+C`Q-R==(#T@)TQI=FYO)SL*)&-O;W)D:6YA=&5S6R=";W1S=V%N82==
M6R<M,3<N.#$W.C(U+C$U,"==(#T@)TMA<V%N92<["B1C;V]R9&EN871E<ULG
M0F]T<W=A;F$G75LG+3$X+C,V-SHR,2XX-3`G72`]("=3:&%K87=E)SL*)&-O
M;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,3DN.3@S.C(S+C0Q-R==(#T@)TUA
M=6XG.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTR,"XT-C<Z,C4N.3@S
M)UT@/2`G4W5A+5!A;B<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3(Q
M+C(Q-SHR-RXU,#`G72`]("=&<F%N8VES=&]W;B<["B1C;V]R9&EN871E<ULG
M0F]T<W=A;F$G75LG+3(Q+C0Q-SHR-2XV,#`G72`]("=,971L:&%K86YE)SL*
M)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,C$N-S`P.C(Q+C8U,"==(#T@
M)T=H86YZ:2<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3(T+C`Q-SHR
M,2XX.#,G72`]("=4<VAA;F4G.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;
M)RTR-"XR,3<Z,C4N.3$W)UT@/2`G4V5R971S92!+:&%M82!);G1E<FYA=&EO
M;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTR-"XV
M,#`Z,C0N-C8W)UT@/2`G2G=A;F5N9R<["B1C;V]R9&EN871E<ULG0F]T<W=A
M;F$G75LG+3(V+C`U,#HR,BXT-3`G72`]("=4<V%B;VYG)SL*)&-O;W)D:6YA
M=&5S6R="<F%Z:6PG75LG,"XP,S,Z+34P+C`U,"==(#T@)TUA8V%P82<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTP+C$S,SHM-C<N,#@S)UT@/2`G4V%O
M($=A8G)I96P@1&$@0V%C:&]E:7)A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG,"XV,3<Z+38Y+C(P,"==(#T@)TEA=6%R971E)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3`N.3@S.BTV,BXU.#,G72`]("="87)C96QO<R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ+C,X,SHM-#@N-#@S)UT@/2`G0F5L
M96T@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$P+C`P
M,#HM-C<N.#`P)UT@/2`G4FEO($)R86YC;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTQ,"XW,#`Z+30X+C0P,"==(#T@)U!O<G1O($YA8VEO;F%L($%E
M<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ,"XY.#,Z+3,W
M+C`V-R==(#T@)T%R86-A:G4@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3$R+C<P,#HM-C`N,3`P)UT@/2`G5FEL:&5N82!!97)O<&]R
M=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3(N.3`P.BTS."XS,S,G
M72`]("=386QV861O<B!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,3,N,C8W.BTT,RXT,3<G72`]("=";VT@2F5S=7,@1&$@3&%P82<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ-"XW,#`Z+34R+C,U,"==(#T@
M)UAA=F%N=&EN82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ-"XX,3<Z
M+3,Y+C`S,R==(#T@)TEL:&5U<R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M,30N.34P.BTT,"XX.#,G72`]("=6:71O<FEA($1A($-O
M;G%U:7-T82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ-2XV-3`Z+34V
M+C$P,"==(#T@)T-U:6%B82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,34N.#8W.BTT-RXY,S,G72`]("="<F%S:6QI82!!97)O<&]R
M=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,34N.#8W.BTU,BXS.#,G
M72`]("="87)R82!$;R!'87)C87,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,38N,#4P.BTT."XP-3`G72`]("='86UA)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3$V+C(S,SHM-#@N.38W)UT@/2`G06YA<&]L:7,@0G)A>BU!
M9F(G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,38N-C,S.BTT.2XR,3<G
M72`]("=';VEA;FEA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTQ-BXW,3<Z+30S+C@V-R==(#T@)TUO;G1E<R!#;&%R;W,G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,3<N-C,S.BTS.2XR-3`G72`]("=#87)A
M=F5L87,@065R;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ
M.2XP.#,Z+34W+C4P,"==(#T@)T-O<G5M8F$G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,3DN-S@S.BTT-RXY-C<G72`]("=58F5R86)A)SL*)&-O;W)D
M:6YA=&5S6R="<F%Z:6PG75LG+3$Y+C@U,#HM-#,N.34P)UT@/2`G0F5L;R!(
M;W)I>F]N=&4@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3$Y+CDS,SHM-#,N.3,S)UT@/2`G0F5L;R!(;W)I>F]N=&4G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,BXT,S,Z+34T+C<Q-R==(#T@)U-A;G1A<F5M
M+4%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR+C8P,#HM
M-#0N,C,S)UT@/2`G4V%O($QU:7H@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG,BXX,S,Z+38P+C<P,"==(#T@)T)O82!6:7-T82!!97)O
M<&]R+51O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(N.3$W.BTT,2XW
M-3`G72`]("=087)N86EB82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C`N,C8W.BTT,"XR.#,G72`]("=6:71O<FEA($%E<F]P;W)T
M;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,"XT-C<Z+34T+C8V-R==
M(#T@)T-A;7!O($=R86YD92!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C$N,C4P.BTT,RXW-C<G72`]("="87)B86-E;F$G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,C$N-S4P.BTT,2XS,S,G72`]("=#86UP
M;W,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C$N-S8W.BTT,RXS-3`G
M72`]("=*=6EZ($1E($9O<F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,C$N.#4P.BTT-BXU-C<G72`]("=0;V-O<R!$92!#86QD87,G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,C$N.3@S.BTT-RXS,S,G72`]("=0:7)A<W-U
M;G5N9V$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C(N,#$W.BTT-RXX
M.#,G72`]("=386\@0V%R;&]S)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3(R+C$Q-SHM-3$N,S@S)UT@/2`G4')E<VED96YT92!0<G5D96YT92<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXS,3<Z+30Y+C`V-R==(#T@)T)A
M=7)U)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+C0X,SHM-#0N-#8W
M)UT@/2`G4F5S96YD92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXU
M-3`Z+34U+C<P,"==(#T@)U!O;G1A(%!O<F$@065R;W!O<BU4;R<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)RTR,BXW.#,Z+30U+C(P,"==(#T@)T=U87)A
M=&EN9W5E=&$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C(N.#$W.BTT
M,BXQ,#`G72`]("=3+B!0+B!!;&1E:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R="<F%Z:6PG75LG+3(R+C@Q-SHM-#,N,C4P)UT@/2`G1V%L96%O)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+C@V-SHM-#,N,S8W)UT@/2`G
M069O;G-O<R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,C(N.3`P.BTT,RXQ-C<G72`]("=2:6\@1&4@2F%N96ER;R!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C(N.3,S.BTT,RXW,3<G72`]
M("=386YT82!#<G5Z($%E<F]P;W(M5&\G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,C(N.3@S.BTT,RXS-C<G72`]("=2:6\@+R!*86-A<F5P86=U82<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,RXP,#`Z+30W+C$S,R==(#T@
M)T-A;7!I;F%S($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTR,RXS,S,Z+34Q+C$S,R==(#T@)TQO;F1R:6YA($%E<F]P;W)T;R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,RXT,3<Z+34Q+CDU,"==(#T@)TUA
M<FEN9V$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C,N-3$W.BTT-BXV
M,S,G72`]("=-87)T92!#:78@+R!-:6PG.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,C,N-C$W.BTT-BXV-3`G72`]("=386\@4&%U;&\@065R;W!O<BU4
M;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,RXY,S,Z+30V+C,P,"==
M(#T@)U-A;G1O<R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,C4N-#,S.BTT.2XR-C<G72`]("=#=7)I=&EB82<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTR-2XU,3<Z+30X+C4Q-R==(#T@)U!A<F%N86=U82<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR-2XU,3<Z+30Y+C$V-R==(#T@
M)T-U<FET:6)A($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTR-2XU,3<Z+34T+C4X,R==(#T@)T9O>B!$;R!)9W5A8W4@065R;W!O<G1O
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(W+C8V-SHM-#@N-34P)UT@
M/2`G1FQO<FEA;F]P;VQI<R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C@N,C4P.BTU,BXT,#`G72`]("=087-S;R!&=6YD;R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR.2XW,3<Z+34S+C<P,"==(#T@)U-A
M;G1A($UA<FEA($%E<F\M4&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,CDN-S@S.BTU-RXP,S,G72`]("=5<G5G=6%I86YA($%E<F]P;W)T;R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C`S,SHM-C`N,#4P)UT@/2`G
M161U87)D;R!';VUE<R!);G1E<FYA=&EO;F%L)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3,N,34P.BTU.2XY.#,G72`]("=-86YA=7,@065R;W!O<G1O
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,N,C`P.BTU,BXR,#`G72`]
M("=!;'1A;6ER82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C,V-SHM
M-C0N-C@S)UT@/2`G5&5F92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS
M+C8V-SHM-CDN-C8W)UT@/2`G5&%B871I;F=A)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3,N-S$W.BTT.2XW,3<G72`]("=4=6-U<G5I)SL*)&-O;W)D
M:6YA=&5S6R="<F%Z:6PG75LG+3,N-S@S.BTS."XU,S,G72`]("=&;W)T86QE
M>F$@065R;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)S,N.#,S
M.BTU,2XX,S,G72`]("=/:6%P;W%U92<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTS+C@U,#HM,S(N-#$W)UT@/2`G1F5R;F%N9&\@1&4@3F]R;VYH82<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS,"XP,#`Z+34Q+C$X,R==(#T@
M)U!O<G1O($%L96=R92!!97)O+5!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3,P+C`Q-SHM-3$N,C$W)UT@/2`G4&]R=&\@06QE9W)E)SL*)&-O
M;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,Q+C,U,#HM-30N,3$W)UT@/2`G0F%G
M92!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,S$N.#8W
M.BTU,BXS-3`G72`]("=096QO=&%S)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+30N,C4P.BTU-BXP,#`G72`]("=)=&%I='5B82<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTT+C,X,SHM-S`N,#,S)UT@/2`G0F5N:F%M:6X@0V]N
M<W1A;G0G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-2XP-3`Z+30R+C@Q
M-R==(#T@)U1E<F5S:6YA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTU+C(P,#HM,S<N,S8W)UT@/2`G36]C;W)O("\@,3<@4F]S861O
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+34N,S4P.BTT.2XQ-3`G72`]
M("=-87)A8F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-2XU,S,Z+30W
M+C4P,"==(#T@)TEM<&5R871R:7HG.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M-2XX,3<Z+38Q+C,P,"==(#T@)TUA;FEC;W)E)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+34N.3$W.BTS-2XR-3`G72`]("=.871A;"!!97)O<&]R
M=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-BXR-C<Z+34W+C<S,R==
M(#T@)TIA8V%R96%C86YG82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTW
M+C$P,#HM,S0N.#8W)UT@/2`G2F]A;R!097-S;V$G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M-RXR,3<Z+3,U+C@X,R==(#T@)T-A;7!I;F$@1W)A;F1E
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3<N,S$W.BTT-RXT-C<G72`]
M("=-87)A;FAA;R`O($-A<F]L:6YA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M-RXV,S,Z+3<R+C8V-R==(#T@)T-R=7IE:7)O($1O(%-U
M;"<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTX+C`V-SHM,S0N.#4P)UT@
M/2`G4F5C:69E($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTX+C$V-SHM-S`N-S8W)UT@/2`G5&%R875A8V$G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M."XR-3`Z+30Y+C(X,R==(#T@)T-O;F-E:6-A;R!$;R!!
M<F%G=6%I82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTX+C<V-SHM-C,N
M.3$W)UT@/2`G4&]R=&\@5F5L:&\@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3DN,S4P.BTT,"XU-3`G72`]("=0971R;VQI;F$@065R
M;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTY+C0P,#HM,S@N
M,C$W)UT@/2`G4&%U;&\@069O;G-O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3DN-3$W.BTS-2XW.#,G72`]("=-86-E:6\@065R;W!O<G1O)SL*)&-O
M;W)D:6YA=&5S6R="<F%Z:6PG75LG+3DN.#8W.BTU-BXQ,#`G72`]("=!;'1A
M($9L;W)E<W1A($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y)UU;)RTW+C,P,#HW,BXT,#`G72`]("=$
M:65G;R!'87)C:6$G.PHD8V]O<F1I;F%T97-;)T)R=6YE:2!$87)U<W-A;&%M
M)UU;)S0N.3,S.C$Q-"XY,S,G72`]("="<G5N96D@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG0G5L9V%R:6$G75LG-#(N,3,S.C(T+C<U,"==(#T@)U!L;W9D
M:78G.PHD8V]O<F1I;F%T97-;)T)U;&=A<FEA)UU;)S0R+C0X,SHR-RXT.#,G
M72`]("="=7)G87,G.PHD8V]O<F1I;F%T97-;)T)U;&=A<FEA)UU;)S0R+C8U
M,#HR,RXS.#,G72`]("=3;V9I82!/8G-E<G8N)SL*)&-O;W)D:6YA=&5S6R="
M=6QG87)I82==6R<T,RXR,#`Z,C<N.3$W)UT@/2`G5F%R;F$G.PHD8V]O<F1I
M;F%T97-;)T)U;&=A<FEA)UU;)S0S+C@U,#HR-2XY-3`G72`]("=2;W5S<V4G
M.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,"XS,S,Z+3,N,3@S
M)UT@/2`G1V%O=6$G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q
M,2XQ-3`Z+3$N,34P)UT@/2`G4&\G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@
M1F%S;R==6R<Q,2XQ-C<Z+30N,S$W)UT@/2`G0F]B;RU$:6]U;&%S<V\G.PHD
M8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,2XW-3`Z+3(N.3,S)UT@
M/2`G0F]R;VUO)SL*)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3(N
M,#,S.C`N,S8W)UT@/2`G1F%D82!.7"=';W5R;6$G.PHD8V]O<F1I;F%T97-;
M)T)U<FMI;F$@1F%S;R==6R<Q,BXS-3`Z+3$N-3$W)UT@/2`G3W5A9V%D;W5G
M;W4G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,BXT-C<Z+3,N
M-#@S)UT@/2`G1&5D;W5G;W4G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S
M;R==6R<Q,RXU-C<Z+3(N-#$W)UT@/2`G3W5A:&EG;W5Y82<["B1C;V]R9&EN
M871E<ULG0G5R:VEN82!&87-O)UU;)S$T+C`S,SHM,"XP,S,G72`]("=$;W)I
M)SL*)&-O;W)D:6YA=&5S6R="=7)U;F1I)UU;)RTS+C,Q-SHR.2XS,3<G72`]
M("="=6IU;6)U<F$G.PHD8V]O<F1I;F%T97-;)T-A;6)O9&EA)UU;)S$Q+C4U
M,#HQ,#0N.#4P)UT@/2`G4&AN;VTM4&5N:"`O(%!O8VAE;G1O;F<G.PHD8V]O
M<F1I;F%T97-;)T-A;6)O9&EA)UU;)S$R+C`P,#HQ,#4N-#4P)UT@/2`G2V]M
M<&]N9RU#:&%M)SL*)&-O;W)D:6YA=&5S6R=#86UB;V1I82==6R<Q,RXS-C<Z
M,3`S+C@U,"==(#T@)U-I96UR96%P)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O
M;B==6R<Q,"XT-3`Z,30N,C4P)UT@/2`G36%R;W5A+5-A;&%K)SL*)&-O;W)D
M:6YA=&5S6R=#86UE<F]O;B==6R<R+CDU,#HY+CDP,"==(#T@)TMR:6)I)SL*
M)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<S+C$U,#HQ,RXV,3<G72`]("=,
M;VUI92<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG,RXX,S,Z,3$N-3$W
M)UT@/2`G66%O=6YD92<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG,RXY
M-C<Z,3,N,C`P)UT@/2`G06)O;F<M36)A;F<G.PHD8V]O<F1I;F%T97-;)T-A
M;65R;V]N)UU;)S0N,#`P.CDN-S,S)UT@/2`G1&]U86QA($]B<RXG.PHD8V]O
M<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N,#@S.CDN,S8W)UT@/2`G5&EK;R<[
M"B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-"XT-C<Z,30N,S8W)UT@/2`G
M0F%T;W5R:2<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-"XW,S,Z,3$N
M,C4P)UT@/2`G0F%F:6$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N
M.34P.CDN.3,S)UT@/2`G3FMO;F=S86UB82<["B1C;V]R9&EN871E<ULG0V%M
M97)O;VXG75LG-2XU-3`Z,3(N,S8W)UT@/2`G66]K;R<["B1C;V]R9&EN871E
M<ULG0V%M97)O;VXG75LG-2XV,#`Z,30N,#8W)UT@/2`G0F5T87)E+4]Y82<[
M"B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-2XV-3`Z,3`N-S4P)UT@/2`G
M2V]U;F1J82<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-2XW,3<Z.2XR
M.#,G72`]("=-86UF92<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-BXP
M-3`Z,3`N,3$W)UT@/2`G0F%M96YD82<["B1C;V]R9&EN871E<ULG0V%M97)O
M;VXG75LG-BXU,S,Z,30N,S8W)UT@/2`G365I9V%N9V$G.PHD8V]O<F1I;F%T
M97-;)T-A;65R;V]N)UU;)S8N-S@S.C$Q+C@Q-R==(#T@)T)A;GEO)SL*)&-O
M;W)D:6YA=&5S6R=#86UE<F]O;B==6R<W+C,U,#HQ,RXU-C<G72`]("=.9V%O
M=6YD97)E)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<Y+C,S,SHQ,RXS
M.#,G72`]("='87)O=6$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,2XX
M,S,Z+3@R+C0V-R==(#T@)U,N($4N(%-H;V%L($UE=&5O<F]L;V=I8V%L($%E
M<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#(N,C4P.BTX,2XY,#`G72`]("=%<FEE874@365T96]R
M;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,BXR-C<Z+3@R+CDV-R==(#T@)U=I
M;F1S;W(L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,BXS,#`Z
M+3@R+C<P,"==(#T@)T)E;&QE(%)I=F5R)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#(N-38W.BTX,"XP-3`G72`]("=,;VYG(%!O:6YT($UE=&5O<F]L
M;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N.#4P.BTX,"XR-C<G72`]("=3:6UC
M;V4L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,BXX-C<Z+3<Y
M+C(U,"==(#T@)U!O<G0@0V]L8F]R;F4@075T;VUA=&5D(%)E<&]R=&EN9R!3
M=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N.#8W.BTX,"XU
M-3`G72`]("=$96QH:2!#4RP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0S+C`P,#HM.#(N,S$W)UT@/2`G4V%R;FEA($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T,RXP,S,Z+3@Q+C$U,"==(#T@)TQO;F1O
M;BP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C$V-SHM-SDN
M.3,S)UT@/2`G2&%M:6QT;VX@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0S+C(U,#HM-SDN,C$W)UT@/2`G4&]R="!796QL97(L($]N="XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXS,#`Z+3<Y+C@P,"==(#T@
M)T)U<FQI;F=T;VX@4&EE<G,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M,RXT-C<Z+3@P+C,X,R==(#T@)U=A=&5R;&]O(%=E;&PG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T,RXV,3<Z+3<Y+C,U,"==(#T@)U1O<F]N=&\@2&5A
M9&QA;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXV,S,Z+3<Y+C0P
M,"==(#T@)U1O<F]N=&\@27-L86YD($%I<G!O<G0@075T;VUA=&5D(%)E<&]R
M=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N-C8W
M.BTW.2XV,S,G72`]("=4;W)O;G1O(%!E87)S;VX@26YT7"=,+B!/;G0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N-S8W.BTX,2XW,3<G72`]("='
M;V1E<FEC:"!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N-S@S.BTW.2XT-C<G72`]("=4
M;W)O;G1O($%E<R!(<2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C@S
M,SHM-C8N,#@S)UT@/2`G66%R;6]U=&@L($XN(%,N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#,N.#,S.BTW-RXQ-3`G72`]("=0;VEN="!0971R92P@
M3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+CDS,SHM-C`N,#$W
M)UT@/2`G4V%B;&4@27-L86YD+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0S+CDU,#HM-S@N,38W)UT@/2`G0V]B;W5R9RP@3VYT+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0S+CDX,SHM-C0N-C8W)UT@/2`G5V5S
M=&5R;B!(96%D+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S
M+CDX,SHM.#`N-S4P)UT@/2`G36]U;G0@1F]R97-T+"!/;G0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#0N,3$W.BTW-RXU,S,G72`]("=4<F5N=&]N
M+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N,C$W.BTW-BXV
M,#`G72`]("=+:6YG<W1O;BP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0T+C(S,SHM-S@N,S8W)UT@/2`G4&5T97)B;W)O=6=H($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XR.#8Z+38V+C,T-R==(#T@
M)T)R:65R($ES;&%N9"P@3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-"XS.#,Z+3<Y+C<X,R==(#T@)T)A<G)I92P@3VYT+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0T+C0Q-SHM-S4N.#4P)UT@/2`G1W)E;F%D:65R
M($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C0S,SHM-C4N
M,C`P)UT@/2`G2V5J:6UK=6II:R`Q+"!.+B!3+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0T+C4P,#HM.#`N,C$W)UT@/2`G0V]L;&EN9W=O;V0@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0T+C4S,SHM-SDN,C$W)UT@/2`G3&%G;V]N($-I='DG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XV,S,Z+38S+C4P,"==(#T@
M)U-H96%R=V%T97(L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#0N-S`P.BTW-BXS,#`G72`]("=5<'!E<B!2:61E874@3&%K92<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0T+C<S,SHM.#$N,C@S)UT@/2`G3VQI<&AA
M;G0@7"!/;G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XW-3`Z+3@Q
M+C$P,"==(#T@)U=I87)T;VXL($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-"XX,3<Z+38R+C,S,R==(#T@)T)E879E;B!)<VQA;F0L($XN(%,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N.#4P.BTW.2XX-C<G72`]
M("="96%U<V]L96EL($ES;&%N9"!!=71O;6%T960@4F5P;W)T:6YG(%-T871I
M;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XX.#,Z+38S+C4P,"==
M(#T@)TAA;&EF87@@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#0N.38W.BTW.2XS,#`G72`]("=-=7-K;VMA+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N.3@S.BTV-"XY,3<G
M72`]("='<F5E;G=O;V0L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#4N,#,S.BTX,"XS-C<G72`]("=797-T97)N($ES;&%N9"!-971E;W)O
M;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C`U,#HM-S(N.#,S)UT@/2`G1G)E
M;&EG:'-B=7)G)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,#8W.BTV
M-"XT.#,G72`]("=+96YT=FEL;&4L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#4N,3$W.BTW-"XR.#,G72`]("=3="!!;FEC970G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XQ-C<Z+3<S+C8X,R==(#T@)U-A:6YT
M($-L;W1H:6QD92!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XR,3<Z+38W+C(U,"==(#T@)U-T+B!3
M=&5P:&5N+"!.+B!"+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C,P
M,#HM-S,N,S4P)UT@/2`G3%PG06-A9&EE)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#4N,S$W.BTW,BXR-3`G72`]("=-;VYT+4]R9F]R9"<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0U+C,Q-SHM-S4N-C8W)UT@/2`G3W1T87=A
M($EN=%PG3"X@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C,S
M,SHM-C4N.#@S)UT@/2`G4V%I;G0@2F]H;BP@3BX@0BXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-2XS,S,Z+3@Q+C<S,R==(#T@)T-O=F4@27-L86YD
M($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,S4P.BTV,"XY.#,G
M72`]("=(87)T($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@
M4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0U+C,V-SHM-C,N,C8W)UT@/2`G5')U<F\L($XN(%,N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#4N,S8W.BTW,2XX,3<G72`]("=,96YN;WAV:6QL
M92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C0P,#HM-S$N.#@S)UT@
M/2`G4VAE<F)R;V]K92P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0U+C0Q-SHM-S,N.3,S)UT@/2`G36-G:6QL(%)A9&%R(%-I=&4G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XT,S,Z+3<S+CDS,R==(#T@)U-T92!!
M;FYE($1E($)E;&P@,2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C0V
M-SHM-S,N-S4P)UT@/2`G36]N=')E86P@+R!$;W)V86P@26YT97)N871I;VYA
M;"P@475E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N-3`P.BTW,RXU
M.#,G72`]("=-8R!4879I<V@@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N-3$W.BTW,RXT,3<G72`]
M("=386EN="!(=6)E<G0@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0U+C8S,SHM-S`N-34P)UT@/2`G36]N=')E86PM17-T)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#4N-C,S.BTX,BXY-C<G72`]("='<F5A="!$
M=6-K($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C<Q-SHM
M-C`N,C,S)UT@/2`G1F]U<F-H=2!(96%D($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#4N-S$W.BTW,RXS.#,G72`]("=687)E;FYE<R<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0U+C<V-SHM-C(N-C@S)UT@/2`G0V%R:6)O
M=2!0;VEN="!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T
M:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C@P,#HM
M.#`N-3,S)UT@/2`G0G)I='0L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-2XX,3<Z+3<S+C0S,R==(#T@)TQ<)T%S<V]M<'1I;VXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XX,S,Z+38V+C0S,R==(#T@)T=A9V5T
M;W=N($-A;BU-:6PG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX,S,Z
M+3<U+C8U,"==(#T@)TAI9V@@1F%L;',L(%%U92XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T-2XX-3`Z+38T+C(V-R==(#T@)T%M:&5R<W0L($XN(%,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N.#8W.BTV-BXU,S,G72`]
M("=&<F5D97)I8W1O;BP@3BX@0BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-2XX.#,Z+3@R+C4V-R==(#T@)T=O<F4@0F%Y+"!/;G0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#4N.34P.BTW-RXS,3<G72`]("=0971A=V%W
M82P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+CDV-SHM.#$N
M-#@S)UT@/2`G2VEL;&%R;F5Y($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A
M;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N,#4P.BTW-"XR.#,G72`]("=3=&4@06=A=&AE($1E<R!-;VYT)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,#8W.BTW-"XU,S,G72`]("=3
M="!*;W9I=&4@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C$Q-SHM-C0N-C@S)UT@/2`G
M36]N8W1O;BP@3BX@0BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXQ
M-C<Z+38P+C`U,"==(#T@)U-Y9&YE>2P@3BX@4RXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T-BXR,#`Z+3<P+C<X,R==(#T@)T)E875C979I;&QE)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,C$W.BTW,BXV-3`G72`]("=.
M:6-O;&5T($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXR.#,Z+38S+C$S,R==(#T@)T-H
M87)L;W1T971O=VXL(%`N($4N($DN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N,C@S.BTW-BXP,#`G72`]("=-86YI=V%K:2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0V+C,Q-SHM-SDN-#8W)UT@/2`G3FEP:7-S:6YG)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,S4P.BTW,BXU,3<G72`]("=4
M<F]I<R!2:79I97)E<R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C,U
M,#HM-SDN-#,S)UT@/2`G3F]R=&@@0F%Y+"!/;G0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#8N,S@S.BTW-2XY-C<G72`]("=-86YI=V%K:2P@475E
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C0S,SHM-C,N.#,S)UT@
M/2`G4W5M;65R<VED92!#86XM36EL)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N-#,S.BTW,2XY,S,G72`]("=6:6QL97)O>2!2861A<B!3:71E)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N-#4P.BTV,2XY-C<G72`]("=%
M87-T(%!O:6YT+"!0+B!%+B!))SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#8N-#@S.BTX-"XU,#`G72`]("=3875L="!3=&4@36%R:64L($]N="XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXU-3`Z+38Q+C`U,"==(#T@)T=R
M86YD($5T86YG+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V
M+C4X,SHM-S(N-3@S)UT@/2`G4VAA=VEN:6=A;B!#4RP@475E+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+C8Q-SHM.#`N.#`P)UT@/2`G4W5D8G5R
M>2P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C8U,#HM-3,N
M,#8W)UT@/2`G0V%P92!286-E+"!.9FQD)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#8N-C@S.BTW,2XY-3`G72`]("=$97-C:&%M8F%U;'1S+"!1=64N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N.#`P.BTW,2XS.#,G72`]
M("=1=65B96,L(%%U92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C@Q
M-SHM-C`N-C8W)UT@/2`G3F]R=&@@36]U;G1A:6XL($XN(%,N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#8N.#,S.BTW,2XR,#`G72`]("="96%U<&]R
M="!#4RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+CDP,#HM
M-S$N-3`P)UT@/2`G5F%L8V%R=&EE<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#8N.3`P.BTW,2XU,#`G72`]("=686QC87)T:65R)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N.3$W.BTU-2XS.#,G72`]("=3
M="X@3&%W<F5N8V4L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#<N,#`P.BTV-2XT-3`G72`]("=#:&%T:&%M($-A;BU-:6PG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-RXP,#`Z+3<P+C@Q-R==(#T@)TEL92!$7"=/
M<FQE86YS($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0W+C`V-SHM-C0N.#`P)UT@/2`G4&]I;G0@17-C
M=6UI;F%C($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I
M;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,#8W.BTW
M,"XX,#`G72`]("=#87`@5&]U<FUE;G1E)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#<N,34P.BTV-RXX,S,G72`]("=386EN="!,96]N87)D($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXR,S,Z+38P+C$S,R==
M(#T@)U-A:6YT(%!A=6P@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T
M:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#<N,C@S.BTW,"XV,S,G72`]("=#:&%R;&5V;VEX($-3+"!1=64N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,S`P.BTU-"XP,#`G72`]
M("=!<F=E;G1I82P@3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W
M+C,P,#HM-S$N,C8W)UT@/2`G4W1E($9O>2!#4RP@475E+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0W+C,S,SHM.#4N.#,S)UT@/2`G0V%R:6)O=2!)
M<VQA;F0L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXS-3`Z
M+3<P+C`S,R==(#T@)TQA(%!O8V%T:65R92<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0W+C,V-SHM-34N.#`P)UT@/2`G4V%G;VYA($ES;&%N9"!-971E
M;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C0Q-SHM-C$N-S@S)UT@/2`G
M26QE<R!$92!,82!-861E;&5I;F5Q=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#<N-#$W.BTV,2XX,#`G72`]("=);&5S+41E+4QA+4UA9&5L96EN
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N-#$W.BTW,BXX,#`G72`]
M("=,82!4=7%U92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C4Q-CHM
M-3(N-S@U)UT@/2`G4W0N($IO:&Y<)W,@5V5S="!#1$$@0U,L($YF;&0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N-38W.BTU.2XQ-C<G72`]("=0
M;W)T+4%U>"U"87-Q=65S+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0W+C4V-SHM-S$N,C,S)UT@/2`G4&%R8R!$97,@3&%U<F5N=&ED)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N-C$W.BTU,BXW,S,G72`]("=3
M="X@2F]H;EPG<RP@3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W
M+C<P,#HM-SDN.#4P)UT@/2`G16%R;'1O;BP@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0W+C@P,#HM-CDN-34P)UT@/2`G4FEV:65R92!$=2!,
M;W5P+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N.3$W.BTW
M-"XV,3<G72`]("=087)E;G0L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-RXY-C<Z+3@T+C<X,R==(#T@)U=A=V$L($]N="XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-RXY.#,Z+38V+C,S,R==(#T@)T-H87)L;RP@
M3BX@0BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XP,3<Z+38T+C4P
M,"==(#T@)TUI<V-O=2!)<VQA;F0L($XN($(N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#@N,#$W.BTV-2XS,S,G72`]("=.97<@0V%R;&ES;&4Q)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,#8W.BTW-RXW.#,G72`]("=6
M86P@1%PG3W(L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XP
M.#,Z+38Y+C4U,"==(#T@)TEL92!2;W5G92!-971E;W)O;&]G:6-A;"!!97)O
M;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0X+C(U,#HM-SDN,#,S)UT@/2`G4F]U>6XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T."XR-C<Z+3<P+C$Q-R==(#T@)U!U:6YT92!#
M;&%V96%U)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,S`P.BTQ,C,N
M-3,S)UT@/2`G4F%C92!2;V-K<R!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I
M;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,S`P.BTW
M,"XY,S,G72`]("=,82!"86EE+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#@N,S,S.BTW,2XP,#`G72`]("="86=O='9I;&QE+"!1=64N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,S8W.BTX.2XQ,3<G72`]("=7
M96QC;VUE($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C,V
M-SHM.#DN,S$W)UT@/2`G5&AU;F1E<B!"87DL($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T."XS.#,Z+3$R,RXY,3<G72`]("=3:&5R:6YG:&%M
M($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T."XS.#,Z+3<P+C4S,R==(#T@)T-A<"!2;W5G
M92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C0Q-CHM-C@N.#DS)UT@
M/2`G26QE($)I8W%U971T92P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0X+C0Q-SHM,3(S+C,Q-R==(#T@)U9I8W1O<FEA($%U=&]M871I8R!7
M96%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T."XT,3<Z+38T+C,Q-R==(#T@)T-A<"!$7"=%<W!O:7(L(%%U92XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XT,3<Z+3<Q+C(Q-R==(#T@
M)TIO;G%U:65R92!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T."XT,S,Z+3$R,RXT,S,G72`]("=%<W%U
M:6UA;'0@2&%R8F]U<BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T."XT-3`Z+3$R,RXS,#`G72`]("=6:6-T;W)I82!5;FEV97)S:71Y)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-#8W.BTV-RXT,S,G72`]("=!
M;7%U:2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C4Q-SHM
M-S(N,C8W)UT@/2`G4F]B97)V86PL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XU,S,Z+34X+C4U,"==(#T@)U-T97!H96YV:6QL92P@3F9L
M9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XU-3<Z+34S+CDW-"==
M(#T@)U1E<G)A($YO=F$@3F%T:6]N86P@4&%R:R!#4RP@3F9L9"XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T."XU-C<Z+3@Q+C,V-R==(#T@)U1I;6UI
M;G,L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XU.#,Z+3$R
M,RXU.#,G72`]("=-86QA:&%T($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XV,#`Z+38X
M+C(Q-R==(#T@)TUO;G0@2F]L:2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0X+C8P,#HM.#8N,S`P)UT@/2`G4'5K87-K=V$G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T."XV,S,Z+3<Y+C0U,"==(#T@)U)O<75E;6%U
M<F4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XV-3`Z+3$R,RXT,S,G
M72`]("=6:6-T;W)I82!);G0N($%I<G!O<G0L($(N($,N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#@N-C8W.BTQ,C0N.#,S)UT@/2`G3FET:6YA="!,
M86ME($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@
M4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-C8W.BTU,RXQ
M,3<G72`]("=";VYA=FES=&$L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#@N-S4P.BTY,2XV,3<G72`]("=!=&EK;VMA;B!!=71O;6%T960@
M4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M."XW-C<Z+38T+C0X,R==(#T@)T=A<W!E+"!1=64N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#@N-S8W.BTW,2XW,3<G72`]("=-:7-T;V]K($%U=&]M
M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0X+C<X,SHM,3(S+C`U,"==(#T@)U-A='5R;F$@27-L86YD($UE=&5O
M<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N.#,S.BTW,BXU-3`G72`]("=.
M;W)M86YD:6XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XX.#,Z+3<Q
M+C`S,R==(#T@)T]N871C:&EW87DL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XY,3<Z+3$R-2XU-3`G72`]("=!;7!H:71R:71E(%!O:6YT
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N.34P.BTU-"XU-C<G72`]
M("='86YD97(@26YT+B!!:7)P;W)T+"!.9FQD+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0X+CDV-SHM-38N,#8W)UT@/2`G0F%D9V5R+"!.9FQD)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#$W.BTQ,C(N-S@S)UT@/2`G
M5VAI=&4@4F]C:R!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#,S.BTQ,3DN-#,S)UT@
M/2`G3W-O>6]O<R!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#,S.BTQ,C(N,S8W)UT@
M/2`G06)B;W1S9F]R9"P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XP,S,Z+3DP+C0V-R==(#T@)U5P<V%L82P@3VYT+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C`S,SHM.3<N-38W)UT@/2`G1W)E=&YA+"!-
M86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#4P.BTQ,#4N-#@S
M)UT@/2`G0V]R;VYA8V@@4W!C)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN,#4P.BTQ,C,N.#8W)UT@/2`G3F%N86EM;R!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN,#8W.BTQ,#<N-3@S)UT@/2`G5F%L($UA
M<FEE(%-O=71H96%S="P@4V%S:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0Y+C`X,SHM,3$V+C4P,"==(#T@)T-R97-T;VX@075T;VUA=&EC(%=E871H
M97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0Y+C`X,SHM,3(U+C<V-R==(#T@)U1O9FEN;R!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN,#@S.BTV,2XW,#`G72`]("=(96%T:"!0
M;VEN="!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C$Q-SHM,3$P
M+C0V-R==(#T@)T]N969O=7(@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C$Q-SHM-C8N
M-C4P)UT@/2`G0V%P($-H870@0U,L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XQ,S,Z+3$Q,BXP-3`G72`]("=-:6QK(%)I=F5R)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,3,S.BTV."XR,#`G72`]("="86EE
M($-O;65A=2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C$V
M-SHM,3`U+CDX,R==(#T@)U)O8VMG;&5N+"!387-K+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C$X,SHM,3(S+C$V-R==(#T@)U9A;F-O=79E<B!)
M;G1E<FYA=&EO;F%L($%I<BU0;W)T+"!"+B!#+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C$X,SHM.3@N,#@S)UT@/2`G36]R9&5N($-$02!#4RP@
M36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(P,#HM,3$S+C(X
M,R==(#T@)T-A<F1S=&]N($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(P,#HM,3(R+C8X,R==(#T@
M)U`N($UE861O=W,@0V]A<W1A;"!3=&%T:6]N($%U=&]M871I8R!796%T:&5R
M(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M.2XR,#`Z+3DX+CDP,"==(#T@)U!I;&]T($UO=6YD+"!-86XN)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN,C$W.BTQ,#(N.38W)UT@/2`G17-T979A
M;BP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR,3<Z+3$R
M,RXX,#`G72`]("=%;G1R86YC92!)<VQA;F0@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C(Q-SHM-3<N-#`P)UT@/2`G1&5E<B!,86ME+"!.9FQD+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C(U,#HM,3(Q+C<V-R==(#T@)T%G87-S:7H@
M075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN,C4P.BTQ,C0N.#,S)UT@/2`G4&]R="!!;&)E<FYI+"!"
M+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(U,#HM-C4N,S,S
M)UT@/2`G0V%P($UA9&5L96EN92!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC
M86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C(V-SHM-30N.#@S)UT@/2`G0V]M9F]R="!#;W9E+"!.9FQD+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(V-SHM-C@N,34P)UT@/2`G
M0F%I92!#;VUE874G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR.#,Z
M+3$P,"XY.#,G72`]("=-96QI=&$L($UA;B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C(X,SHM-S,N,S4P)UT@/2`G0VAA;6]U8VAO=6%N92!!=71O
M;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN,S`P.BTQ,3<N-C,S)UT@/2`G0V%S=&QE9V%R($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XS,#`Z+3$R,RXQ
M,3<G72`]("=686YC;W5V97(@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C,Q-SHM-C<N
M,S@S)UT@/2`G4&]I;G1E+41E<RU-;VYT<RP@475E+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C,U,#HM,3(S+C$X,R==(#T@)U<@5F%N8V]U=F5R
M($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XS-3`Z+3$R-"XQ-C<G72`]("="86QL96YA
M<R!)<VQA;F0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C,V-SHM,3(Q+C0X,R==(#T@
M)TAO<&4L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,S@S
M.BTQ,C8N-34P)UT@/2`G17-T979A;B!0;VEN="P@0BX@0RXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XT,#`Z+3DX+C,Q-R==(#T@)T1E97)W;V]D
M(%)#4RP@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C0Q-SHM
M.#(N-#8W)UT@/2`G2V%P=7-K87-I;F<L($]N="XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XT,S,Z+3$P."XY.#,G72`]("=%87-T96YD($-Y<')E
M<W,L(%-A<VLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT-C<Z+3$Q
M.2XV,#`G72`]("=096YT:6-T;VXL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN-#8W.BTQ,C`N-3$W)UT@/2`G4')I;F-E=&]N($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT.#,Z+3$R,RXS,#`G
M72`]("=086T@4F]C:W,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT
M.#,Z+3$R-"XT,S,G72`]("=3:7-T97)S($ES;&%N9"!!=71O;6%T:6,@5V5A
M=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#DN-3`P.BTQ,3<N,S`P)UT@/2`G3F5L<V]N($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XU,#`Z+3DX+C`S,R==(#T@)T-A<FUA;B!5($]F($TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XU-C<Z+3$Q.2XV-3`G72`]("=3=6UM97)L
M86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XU-C<Z+34W+C@X,R==(#T@)U)O8VMY
M($AA<F)O=7(@0U,L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN-3@S.BTQ,30N-#$W)UT@/2`G5'5R=&QE($UO=6YT86EN)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN-C$W.BTQ,34N-S@S)UT@/2`G0W)A;F)R
M;V]K+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C8S,SHM
M,3$Q+C0U,"==(#T@)T)O=R!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XV,S,Z+3$Q,BXX,#`G72`]("=,971H8G)I9&=E+"!!;'1A+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C8S,SHM,3$T+C0X,R==(#T@
M)T-R;W=S;F5S="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C8U,#HM
M,3`Y+C4Q-R==(#T@)T-Y<')E<W,@2&EL;',@4&%R:R<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C8X,SHM-30N.#`P)UT@/2`G5'=I;&QI;F=A=&4@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW,#`Z+3$P,RXX,#`G
M72`]("=797EB=7)N($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW,#`Z+3$Q,BXW.#,G
M72`]("=,971H8G)I9&=E($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<Q-SHM,3(T+CDP,"==(#T@
M)T-O;6]X+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<Q
M-SHM.#@N,S,S)UT@/2`G2V%T871O=&$@27-L86YD)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN-S,S.BTQ,#4N.3,S)UT@/2`G07-S:6YI8F]I82!!
M:7)P;W)T($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C<U,#HM,3$T+CDP,"==(#T@)U-P87)W;V]D
M($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XW-3`Z+3@T+C$V-R==(#T@)TYA9V%G86UI
M+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S8W.BTW-"XU
M,S,G72`]("=#:&EB;W5G86UA=2U#:&%P86ES+"!1=64G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XW-C<Z+3<W+C@Q-R==(#T@)TUA=&%G86UI+"!1
M=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S@S.BTQ,C,N,38W
M)UT@/2`G4W%U86UI<V@@06ER<&]R="P@0BX@0R<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C<X,SHM.#8N.3,S)UT@/2`G1V5R86QD=&]N+"!/;G0N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S@S.BTY-"XS-C<G72`]
M("=+96YO<F$L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW
M.#,Z+3DY+C8S,R==(#T@)U-H:6QO)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#DN.#,S.BTQ,C0N-3`P)UT@/2`G4&]W96QL(%)I=F5R($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XX,S,Z+38T+C,P,"==(#T@
M)U!O<G0@365N:65R+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN.#@S.BTY-RXQ,S,G72`]("=7:6YN:7!E9R!4:&4@1F]R:W,L($UA;BXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,#`Z+3$P.2XT-C<G72`]
M("=-87!L96-R965K($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,#`Z+3<Q+C(U,"==
M(#T@)T-H=71E($1E<R!087-S97,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XY,#`Z+3DW+C(S,R==(#T@)U=I;FYI<&5G($EN="X@06ER<&]R=&UA
M;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,#`Z+3DX+C(V-R==
M(#T@)U!O<G1A9V4@4V]U=&AP;W)T($$G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XY,#`Z+3DY+C,U,"==(#T@)T-A<F)E<G)Y($UC9&,G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,3<Z+34U+C8V-R==(#T@)TQA(%-C
M:64L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.3$W.BTY
M.2XY-3`G72`]("="<F%N9&]N+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN.38W.BTQ,3DN,S@S)UT@/2`G2V5L;W=N82!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,#$W.BTQ,3`N-S$W)UT@/2`G
M365D:6-I;F4@2&%T+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4P+C`Q-SHM,3$S+C8S,R==(#T@)T-L87)E<VAO;&T@075T;VUA=&EC(%=E
M871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4P+C`U,#HM,3$R+C$S,R==(#T@)U9A=7AH86QL($-D82<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C$Q-SHM,3(W+CDS,R==(#T@)U-O;&%N
M9&5R($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N
M=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C$Q
M-SHM.3$N.3`P)UT@/2`G4VEO=7@@3&]O:V]U="P@3VYT+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4P+C$V-SHM-C`N,#8W)UT@/2`G0V%P92!7:&ET
M=&QE)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,38W.BTV-BXT,S,G
M72`]("=0;VEN=&4@3F]I<F4L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,"XQ.#,Z+38Q+C@Q-R==(#T@)TYA=&%S:'%U86XL(%%U92XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XQ.#,Z+3DV+C`V-R==(#T@)U!I
M;F%W82!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C`P.BTQ,#0N-S`P)UT@/2`G0G)A
M='1S($QA:V4L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N
M,C$W.BTV-BXR-C<G72`]("=397!T+4EL97,L(%%U92XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,"XR,C0Z+38T+C(P."==(#T@)TEL92!!=7@@4&5R
M<F]Q=65T<RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(S
M,SHM,3$Y+C(X,R==(#T@)U9E<FYO;BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,"XR,S,Z+3$R,2XU.#,G72`]("=,>71T;VXL($(N($,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C,S.BTU-RXU.#,G72`]
M("=$86YI96Q<)W,@2&%R8F]U<BP@3F9L9"<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4P+C(V-SHM,3`W+C<S,R==(#T@)U-W:69T($-U<G)E;G0@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+C(V-SHM,3$Q+C$X,R==(#T@)U-U9F9I96QD($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR-C<Z+3$Q-RXX
M,3<G72`]("=.86MU<W`@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(V-SHM-C0N,C,S
M)UT@/2`G3&]N9W5E(%!O:6YT($1E($UI;F=A;BP@475E+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4P+C(X,SHM,3`W+C8X,R==(#T@)U-W:69T($-U
M<G)E;G0L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C@S
M.BTV,RXV,3<G72`]("=(879R92!3="!0:65R<F4G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,"XS,#`Z+3$R,BXW,S,G72`]("=096UB97)T;VX@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+C,P,#HM.#DN,#,S)UT@/2`G07)M<W1R;VYG+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,S,S.BTQ,#4N-34P
M)UT@/2`G36]O<V4@2F%W+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4P+C,X,SHM,3`R+C8X,R==(#T@)T)R;V%D=FEE=RP@4V%S:RXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XT,#`Z+3$P-"XU.#,G72`]("=2
M96=I;F$@56YI=F5R<VET>2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P
M+C0P,#HM,3(U+C@V-R==(#T@)TAE;&UC:V5N($ES;&%N9"!-971E;W)O;&]G
M:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C0S,SHM,3`T+C8V-R==(#T@)U)E9VEN
M82P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XT-3`Z+3$P
M,"XV,#`G72`]("=3:&]A;"!,86ME($%I<G!O<G0@075T;VUA=&5D(%)E<&]R
M=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-#8W
M.BTU.2XV,S,G72`]("=#:&5V97)Y+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3`N-34P.BTQ,3$N.#4P)UT@/2`G0G)O;VMS($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,"XV,#`Z+3$R,"XU,3<G72`]("=0<FEN8V5T;VX@075T;VUA
M=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4P+C8Q-SHM.3<N,#,S)UT@/2`G1VEM;&D@26YD=7-T<FEA
M;"P@36%N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C,Q.BTY-BXY
M.#(G72`]("=':6UL:2!(87)B;W5R($-3+"!-86XN)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N-C,S.BTQ,C@N,3$W)UT@/2`G2&]L8F5R9RP@0BX@
M0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XV-3`Z+3DY+CDS,R==
M(#T@)U=A<V%G86UI;F<L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,"XV-C<Z+3<P+C4S,R==(#T@)TUA;F]U86YE+45S="!!=71O;6%T960@
M4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,"XV.#,Z+3$R-RXS-C<G72`]("=0;W)T($AA<F1Y+"!"+B!#+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C<P,#HM,3$Y+C(X,R==(#T@)U-A;&UO
M;B!!<FT@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C<P,#HM,3(P+C0U,"==(#T@)TMA
M;6QO;W!S+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C<P
M,#HM.38N-38W)UT@/2`G5FEC=&]R:6$@0F5A8V@G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,"XW,3<Z+34V+C$Q-R==(#T@)T5N9VQE92!-971E;W)O
M;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C<S,SHM-S$N,#$W)UT@/2`G0F]N
M;F%R9"`Q+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-S@S
M.BTQ,C@N-#,S)UT@/2`G0V%P92!38V]T="!,:6=H="<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+C@Q-SHM,3(X+CDP,"==(#T@)U-A<G1I;F4@27-L
M86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@
M4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N.3`P.BTQ,#DN
M-3`P)UT@/2`G3&5A9&5R($%I<G!O<G0@075T;VUA=&EC(%=E871H97(@4F5P
M;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+CDS
M,SHM,3(W+C8S,R==(#T@)TAE<F)E<G0@27-L86YD($UE=&5O<F]L;V=I8V%L
M($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3`N.34P.BTQ,#<N,34P)UT@/2`G3'5C:WD@3&%K
M92!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3`N.34P.BTQ,34N,3@S)UT@/2`G3F%K:7-K
M82!2:61G971O<"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+CDV-SHM
M,3$X+C$X,R==(#T@)U)E=F5L<W1O:V4L($(N($,N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N.3@S.BTQ,C<N-S,S)UT@/2`G4&EN92!)<VQA;F0@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XP-C<Z+3DS+C@P,"==
M(#T@)U)E9"!,86ME+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3$N,#@S.BTQ,30N,C$W)UT@/2`G0V]P(%5P<&5R)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3$N,#@S.BTQ,34N,#8W)UT@/2`G0F]W(%9A;&QE>2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C`X,SHM.3<N-34P)UT@/2`G
M1FES:&5R($)R86YC:"!-87)I;F4@079I871I;VX@4F5P;W)T:6YG(%-T871I
M;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XQ,#`Z+3$P,"XP-3`G
M72`]("=$875P:&EN($-O87-T86P@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4Q+C$P,#HM,3`P+C`U,"==(#T@)T1A=7!H:6XL($UA;BXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XQ,3<Z+3$Q-"XP,3<G72`]
M("=#86QG87)Y($EN=&5R;F%T:6]N86PL($%L=&$N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3$N,3,S.BTQ,#8N-3@S)UT@/2`G16QB;W<@36%R:6YE
M($%V:6%T:6]N(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3$N,34P.BTQ,C$N-3`P)UT@/2`G0VQI;G1O;BP@0BX@0RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XQ.#,Z+3$Q-2XU-C<G72`]
M("="86YF9BP@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XR
M-3`Z+3$R,RXP.#,G72`]("=":6<@0W)E96LG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,2XR-C<Z+3$P,BXT-C<G72`]("=9;W)K=&]N+"!387-K+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C(V-SHM.#`N-C4P)UT@/2`G
M36]O<V]N964L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XS
M-C<Z+34U+C8S,R==(#T@)U-T+B!!;G1H;VYY+"!.9FQD+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4Q+C0U,#HM,3$V+C,S,R==(#T@)UEO:&\@4&%R
M:R!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3$N-#4P.BTU-RXQ.#,G72`]("=";&%N8R!3
M86)L;VXL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XT-3`Z
M+3DP+C(P,"==(#T@)U!I8VML92!,86ME+"!/;G0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3$N-#@S.BTQ,#<N,#4P)UT@/2`G3W5T;&]O:R!09G)A
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-3$W.BTQ,#DN,38W)UT@
M/2`G2VEN9&5R<VQE>2P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,2XU-3`Z+3<Q+C$Q-R==(#T@)TQA8R!"96YO:70G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,2XU-C<Z+3$P-RXY,3<G72`]("=2;W-E=&]W;B!%
M87-T+"!387-K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-C8W.BTQ
M,#4N-#`P)UT@/2`G5V%T<F]U<R!%87-T($%U=&]M871E9"!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C8V-SHM,3$P
M+C(P,"==(#T@)T5S=&AE<B`Q)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3$N-C8W.BTY."XW-3`G72`]("='>7!S=6UV:6QL92<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4Q+C<P,#HM,3$S+C(Q-R==(#T@)U1H<F5E($AI;&QS
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-S4P.BTY.2XY,#`G72`]
M("="86-H96QO<G,@27-L86YD($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO
M;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C<V-SHM,3`T+C(P,"==
M(#T@)U=Y;GEA<F0L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3$N-S8W.BTQ,30N-C@S)UT@/2`G4W5N9')E)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3$N.#8W.BTV,RXR.#,G72`]("=,86,@16]N+"!1=64G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXP-C<Z+3$Q,2XT-3`G72`]("=#
M;W)O;F%T:6]N($UA<FEN92!!=FEA=&EO;B!297!O<G1I;F<@4W1A=&EO;B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C$Q-SHM,3`Q+C(S,R==(#T@
M)U-W86X@4FEV97(L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,BXQ,3<Z+3$R-"XQ,S,G72`]("=0=6YT>FD@36]U;G1A:6XL($(N($,N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,3,S.BTQ,3DN,S`P)UT@/2`G
M0FQU92!2:79E<BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,BXQ-3`Z+3$P-BXU-3`G72`]("=387-K871O;VX@2V5R;F5N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3(N,38W.BTQ,#8N-C@S)UT@/2`G4V%S:V%T
M;V]N+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C$X,SHM
M,3$S+CDP,"==(#T@)U)E9"!$965R+"!!;'1A+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4R+C$X,SHM,3(R+C`U,"==(#T@)U=I;&QI86US($QA:V4L
M($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,3@S.BTQ,C<N
M-#8W)UT@/2`G0V%T:&5D<F%L(%!O:6YT($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3(N,C,S.BTX-RXX.#,G72`]("=,86YS9&]W;F4@2&]U<V4G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXR-C<Z+3$R."XW,3<G72`]
M("=-8VEN;F5S($ES;&%N9"P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,BXS,#`Z+34U+C@S,R==(#T@)TUA<GE<)W,@2&%R8F]U<BP@3F9L
M9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXS-3`Z+3DW+C`S,R==
M(#T@)T)E<F5N<R!2:79E<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3(N,S4P.BTY-RXP,S,G72`]("="97)E;G,@4FEV97(@0U,L($UA
M;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXS.#,Z+3$R-BXU.#,G
M72`]("="96QL82!#;V]L82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3(N-#,S.BTQ,30N.3$W)UT@/2`G4F]C:WD@36]U;G1A:6X@2&]U
M<V4L($%L=&$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXT-3`Z+3$Q
M,RXW-3`G72`]("=,86-O;6)E($-D82<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4R+C8U,#HM-38N.#8W)UT@/2`G06QE>&ES(%)I=F5R($UE=&5O<F]L
M;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N-S8W.BTQ,#@N,C4P)UT@/2`G3F]R
M=&@@0F%T=&QE9F]R9"P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,BXX,#`Z+3DW+C8Q-R==(#T@)T=E;W)G92!)<VQA;F0@365T96]R;VQO
M9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,BXX,3<Z+3$P,BXS,3<G72`]("=(=61S
M;VX@0F%Y+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C@Q
M-SHM,3`T+C8P,"==(#T@)TUE;&9O<G0@075T;VUA=&EC(%=E871H97(@4F5P
M;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C@X
M,SHM,3$X+C`V-R==(#T@)TIA<W!E<BP@06QT82XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,BXY,S,Z+3$Q."XS,3<G72`]("=*87-P97(@5V%R9&5N
M($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4R+CDS,SHM-C8N.#8W)UT@/2`G5V%B=7-H($QA:V4L($YF
M;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,#,S.BTQ,#`N.3,S
M)UT@/2`G2'5N=&5R<R!0;VEN="!-87(G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,RXP,S,Z+3$Q,BXX,3<G72`]("=#86UR;W-E)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3,N,#,S.BTQ,C(N-3$W)UT@/2`G475E<VYE;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,#4P.BTQ,CDN
M-C@S)UT@/2`G171H96QD82!"87DG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,RXQ.#,Z+3DY+C(V-R==(#T@)T=R86YD(%)A<&ED<RP@36%N+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C(Q-SHM,3`U+C8X,R==(#T@)U!R
M:6YC92!!;&)E<G0L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3,N,C4P.BTQ,S$N.#$W)UT@/2`G4V%N9'-P:70L($(N($,N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3,N,S`P.BTQ,3,N-3@S)UT@/2`G161M;VYT
M;VX@26YT97)N871I;VYA;"P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,RXS,#`Z+3$Q,RXV,#`G72`]("=%9&UO;G1O;B!);G1E<FYA=&EO
M;F%L($-3+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C,Q
M-SHM,3$P+C`V-R==(#T@)TQL;WED;6EN:7-T97(L($%L=&$N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3,N,S$W.BTQ,S(N-S4P)UT@/2`G2VEN9&%K
M=6X@4F]C:W,L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N
M,S$W.BTV,"XT,3<G72`]("=';V]S92P@3F9L9"XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,RXS,S,Z+3$P-"XP,#`G72`]("=.:7!A=VEN+"!387-K
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C,V-SHM,3`W+C4U,"==
M(#T@)U-P:7)I='=O;V0@5V5S="P@4V%S:R<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4S+C,X,SHM,3$X+C,S,R==(#T@)U=I;&QO=R!#<F5E:R<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C0Q-SHM,3$S+C(P,"==(#T@)T5L
M;&5R<VQI92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C0U,#HM,3$T
M+C0V-R==(#T@)TAI9VAV86QE)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3,N-3`P.BTQ,S`N-C,S)UT@/2`G0F]N:6QL82!)<VQA;F0@365T96]R;VQO
M9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,RXU,S,Z+3$Q-"XQ,#`G72`]("=%9&UO
M;G1O;B!3=&]N>2!0;&%I;B!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4S+C4U,#HM-C0N,3`P)UT@/2`G0VAU<F-H:6QL($9A;&QS+"!.9FQD
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4V-SHM,3$S+C4Q-R==
M(#T@)T5D;6]N=&]N($UU;FEC:7!A;"!!;'1A+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4S+C4V-SHM,3$S+C4Q-R==(#T@)T5D;6]N=&]N($UU;FEC
M:7!A;"!#4C$P+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S
M+C4V-SHM-C0N,3`P)UT@/2`G0VAU<F-H:6QL($9A;&QS)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3,N-3@S.BTQ,38N-#8W)UT@/2`G161S;VXL($%L
M=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-C$W.BTQ,3(N,#,S
M)UT@/2`G5F5G<F5V:6QL92!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@
M4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-C,S.BTW-RXW
M,#`G72`]("=,82!'<F%N9&4@4FEV:65R92P@475E)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3,N-C8W.BTQ,3,N-#8W)UT@/2`G161M;VYT;VX@3F%M
M86\@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXV.#,Z+3$Q
M,BXX-C<G72`]("=%;&L@27-L86YD($YA=&EO;F%L(%!A<FLG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,RXV.#,Z+3$R-"XX,S,G72`]("=.96-H86MO
M(%)I=F5R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-S`P.BTU-RXP
M,S,G72`]("=#87)T=W)I9VAT+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4S+C<S,SHM,3`U+C(V-R==(#T@)T-A;F1L92!,86ME)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-S4P.BTW,RXV-C<G72`]("=,82!'
M<F%N9&4@278L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXW
M.#,Z+3$Q."XT,S,G72`]("=(96YD97)I8VMS;VX@075T;VUA=&EC(%=E871H
M97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4S+C@S,SHM.#DN.#8W)UT@/2`G0FEG(%1R;W5T($QA:V4G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,RXX-3`Z+3DT+C8U,"==(#T@)TES;&%N9"!,
M86ME+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N.#@S.BTQ
M,C(N-C@S)UT@/2`G4')I;F-E($=E;W)G92P@0BX@0RXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,RXY,3<Z+3$P-BXP-C<G72`]("=787-K97-I=2!,
M86ME($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+CDV-SHM,3`Q+C$P,"==(#T@)U1H92!087,L($UA
M;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXY-C<Z+3DW+C@S,R==
M(#T@)TYO<G=A>2!(;W5S92P@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4T+C$S,SHM,3`X+C4Q-R==(#T@)TUE861O=R!,86ME+"!387-K+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C$U,#HM,3$U+C<X,R==(#T@
M)U=H:71E8V]U<G0L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-30N,34P.BTQ,34N-S@S)UT@/2`G5VAI=&5C;W5R="P@06QT82XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-"XQ-C<Z+3$S,"XS-C<G72`]("=(;VQL
M86YD(%)O8VL@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C$V-SHM,3,Q+C8V-R==(#T@
M)U)O<V4@4W!I="!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N
M=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C(U
M,#HM,3,S+C$S,R==(#T@)TQA;F=A<F$L($(N($,N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-30N,S`P.BTQ,S`N-#,S)UT@/2`G4')I;F-E(%)U<&5R
M="P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-"XS.#,Z+3$R
M-2XY-3`G72`]("="=7)N<R!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-30N-#$W.BTQ,3`N,C@S)UT@/2`G0V]L9"!,86ME+"!!;'1A+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C0V-SHM,3(X+C4X,R==(#T@)U1E
M<G)A8V4L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N-3@S
M.BTQ,S`N-S`P)UT@/2`G1W)E>2!)<VQE="!-971E;W)O;&]G:6-A;"!!97)O
M;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4T+C<U,#HM,3$P+C`U,"==(#T@)U!R:6UR;W-E($QA:V4G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-"XW-C<Z+3$Q,BXP,3<G72`]
M("=,86,@3&$@0FEC:&4L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-30N-S@S.BTQ,3`N,#8W)UT@/2`G4')I;7)O<V4@3&%K92`R)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-30N.#`P.BTV-BXX,#`G72`]("=38VAE
M9F9E<G9I;&QE+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N
M.#$W.BTQ,C<N,3@S)UT@/2`G4VUI=&AE<G,L($(N($,N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-30N.3@S.BTX-2XT,S,G72`]("=096%W86YU8VL@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XQ-3`Z+3$P-2XR-C<G
M72`]("=,82!2;VYG92P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U-2XQ-3`Z+3$P-2XR-C<G72`]("=,82!2;VYG92P@4V%S:R<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4U+C$X,SHM,3$X+C@X,R==(#T@)T=R86YD
M92!0<F%I<FEE+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U
M+C(P,#HM,3$Y+C0P,"==(#T@)T)E879E<FQO9&=E)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-34N,C@S.BTW-RXW-C<G72`]("=+=75J:G5A<F%P:6LL
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XS,#`Z+3$Q-"XW
M.#,G72`]("=3;&%V92!,86ME+"!!;'1A)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-34N,S`P.BTQ,C,N,3,S)UT@/2`G36%C:V5N>FEE+"!"+B!#+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C,S,SHM-C,N,C$W)UT@/2`G
M0F]R9&5R+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N-#4P
M.BTV,"XR,S,G72`]("=(;W!E9&%L92!-971E;W)O;&]G:6-A;"!!97)O;F%U
M=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4U+C8Y-3HM,3$Y+C(S-"==(#T@)U-P:7)I="!2:79E<B!!=71O
M(%-T871I;VXL($%L=&$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XX
M,#`Z+3DW+C@U,"==(#T@)U1H;VUP<V]N(%=E871H97(@3V9F:6-E+"!-86XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XX,S,Z+3$P."XT,S,G72`]
M("="=69F86QO($YA<G)O=W,L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-34N.3,S.BTQ,CDN.3@S)UT@/2`G4W1E=V%R="!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-38N,C,S.BTQ,3<N-#,S)UT@/2`G
M4&5A8V4@4FEV97(L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-38N,C,S.BTQ,C`N-S,S)UT@/2`G1F]R="!3="!*;VAN+"!"+B!#+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C,S,SHM,3`S+C(X,R==(#T@)U-O
M=71H96YD($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-BXS-3`Z+3DT+C<P,"==(#T@)T=I
M;&QA;2P@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C4S,SHM
M,3$U+C(V-R==(#T@)U)E9"!%87)T:"<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4V+C4U,#HM-C$N-C@S)UT@/2`G3F%I;BP@3F9L9"<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4V+C8U,#HM,3$Q+C(Q-R==(#T@)T9O<G0@36--
M=7)R87D@0U,L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-38N
M-C4P.BTQ,3$N,C$W)UT@/2`G1F]R="!-8VUU<G)A>2P@06QT82XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-BXW,S,Z+3$S,2XV-C<G72`]("=)<VMU
M="!2:79E<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C@V-SHM,3`Q
M+C`X,R==(#T@)TQY;FX@3&%K92P@36%N+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4W+C$S,SHM-C$N-#@S)UT@/2`G0V%P92!+:6=L87!A:70L($YF
M;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3<N,C4P.BTQ,#4N-C$W
M)UT@/2`G2V5Y($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-RXS
M-3`Z+3$P-RXQ,S,G72`]("=#<F5E($QA:V4@365T96]R;VQO9VEC86P@065R
M;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U-RXU,S,Z+3$Q,2XU-C<G72`]("=-:6QD<F5D($QA:V4G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XQ,#`Z+38X+C0Q-R==(#T@
M)TMU=6IJ=6%Q+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N
M,3@S.BTQ,#,N-S`P)UT@/2`G0V]L;&EN<R!"87D@075T;VUA=&EC(%=E871H
M97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4X+C,S,SHM-C(N-3@S)UT@/2`G4V%G;&5K($)A>2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4X+C,X,SHM,3`Y+C4P,"==(#T@)T-L=69F($QA:V4L
M(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N-#$W.BTQ,S`N
M,#`P)UT@/2`G1&5A<V4@3&%K92!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4X+C0Q-SHM,3,P+C`P,"==(#T@)T1E87-E($QA:V4@0V]A<W1A
M;"!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N-#4P.BTW
M."XQ,3<G72`]("=);G5K:G5A:RP@475E)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3@N-3@S.BTQ,3@N-3`P)UT@/2`G4V]U<V$@0W)K($%V="<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C8Q-SHM,3$W+C$V-R==(#T@)TAI
M9V@@3&5V96PL($%L=&$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XV
M,C(Z+3$Q,2XV-S(G72`]("=0<F%I<FEE(%)I=F5R+"!!;'1A)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3@N-C@S.BTQ,3,N.#@S)UT@/2`G1V%R9&5N
M(%)I=F5R($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XW,S,Z+3DT+C`V-R==(#T@)T-H
M=7)C:&EL;"P@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C<V
M-SHM,3$Q+C$Q-R==(#T@)T9O<G0@0VAI<&5W>6%N+"!!;'1A+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4X+C@S,SHM,3(R+C4X,R==(#T@)T9O<G0@
M3F5L<V]N+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Y+C$S
M,SHM,3$S+C@P,"==(#T@)U=A=&5R=&]N(%!A<FL@1V%T92<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4Y+C(Q-SHM,3`Y+C<P,"==(#T@)T)E87)T;V]T
M:"!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U.2XR-3`Z+3$P
M-2XX,S,G72`]("=3=&]N>2!287!I9',@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4Y+C4V-SHM,3`X+C0X,R==(#T@)U5R86YI=6T@0VET
M>2P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U.2XY.#,Z+38T
M+C$V-R==(#T@)T-A<&4@2V%K:VEV:6%K)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C`N,#$W.BTQ,3$N.34P)UT@/2`G1F]R="!3;6ET:"P@3BX@5RX@
M5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,"XQ,3<Z+3$R."XX,3<G
M72`]("=7871S;VX@3&%K92P@62X@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V,"XQ-C<Z+3$S,BXW,S,G72`]("=497-L:6XL(%DN(%0N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N-#$W.BTV-"XX-3`G72`]("=+:6QL
M:6YE:R!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8P+C0S,SHM,3(Q
M+C(S,R==(#T@)U1R;W5T($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V,"XW,3<Z+3$S-2XP-C<G72`]("=7:&ET96AO<G-E+"!9+B!4+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8P+C<V-SHM,3,W+C4X,R==(#T@)TAA
M:6YE<R!*=6YC=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8P+C@S
M,SHM,3$U+C<X,R==(#T@)TAA>2!2:79E<BP@3BX@5RX@5"XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V,2XP-3`Z+3$P.2XS,S,G72`]("=0;W=D97(@
M3&%K92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Q+C`U,#HM-CDN-C,S
M)UT@/2`G475A<71A<2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-C$N,3$W.BTQ,C(N.#4P)UT@/2`G3&EN9&)E<F<@3&%N9&EN9RP@3BX@
M5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XQ,S,Z+3$P,"XY
M,#`G72`]("=%;FYA9&%I($QA:V4@365T96]R;VQO9VEC86P@065R;VYA=71I
M8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V,2XS,3<Z+3$Q-RXV,#`G72`]("=&;W)T(%!R;W9I9&5N8V4G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XS-C<Z+3$S.2XP-3`G72`]("="
M=7)W87-H($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XU.#,Z+38T+C8U,"==(#T@)U)E
M<V]L=71I;VX@27-L86YD+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8Q+C8S,SHM,3(U+C@P,"==(#T@)U9I<F=I;FEA($9A;&QS)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N-C8W.BTQ,#@N-#$W)UT@/2`G
M4&]R=&5R($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XW-3`Z
M+3$R,2XR,S,G72`]("=&;W)T(%-I;7!S;VXL($XN(%<N(%0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C$N.3$W.BTQ,3,N-S,S)UT@/2`G26YN97(@
M5VAA;&5B86-K<R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Q+CDV-SHM
M,3(W+C(Q-R==(#T@)U)A8F)I="!+971T;&4@075T;VUA=&5D(%)E<&]R=&EN
M9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C(N,3$W.BTQ
M,S8N,3@S)UT@/2`G0V%R;6%C:W,@0U,L(%DN(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C(N,C,S.BTQ,S,N,S4P)UT@/2`G1F%R;RP@62X@5"XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,BXT-C<Z+3$Q-"XT-3`G72`]
M("=996QL;W=K;FEF92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V,BXW,#`Z+3DX+C,P,"==(#T@)UEA=&AK>65D($QA:V4@365T96]R
M;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,BXW,3<Z+3$P.2XQ.#,G72`]("=&
M;W)T(%)E;&EA;F-E+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S8R+C@Q-SHM.3(N,3$W)UT@/2`G4F%N:VEN($EN;&5T+"!.+B!7+B!4
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8S+C$U,#HM,3$W+C(V-R==
M(#T@)TQA8R!,82!-87)T<F4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V
M,RXR,S,Z+3$P,2XW-C<G72`]("=$=6)A=VYT($QA:V4@365T96]R;VQO9VEC
M86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V,RXS,S,Z+38T+C$U,"==(#T@)T)R979O;W)T
M($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8S+C4X,SHM,3`U
M+C$U,"==(#T@)TAA;F)U<GD@4FEV97(@075T;VUA=&5D(%)E<&]R=&EN9R!3
M=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C,N-C`P.BTQ,3,N
M.#8W)UT@/2`G3&]W97(@0V%R<"!,86ME+"!.+B!7+B!4+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8S+C8Q-SHM,3,U+C@V-R==(#T@)TUA>6\@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8S+C<U,#HM-C@N-34P
M)UT@/2`G27%A;'5I="P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V-"XP-3`Z+3$S.2XQ,S,G72`]("=$87=S;VXL(%DN(%0N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-C0N,3$W.BTQ,3<N,S8W)UT@/2`G4F%E
M($QA:V5S)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C0N,C`P.BTX,RXS
M-C<G72`]("=#;W)A;"!(87)B;W5R+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8T+C(Q-SHM-S8N-3,S)UT@/2`G0V%P92!$;W)S970L
M($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C0N,S`P.BTY
M-BXP.#,G72`]("="86ME<B!,86ME+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8T+C,X,SHM,3$U+C`Q-R==(#T@)TEN9&EA;B!2:79E
M<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8T+C<U,#HM,3(T+C(Q-R==
M(#T@)U-T($-H87)L97,@0W)E96LG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V-"XY-3`Z+38S+C4X,R==(#T@)T-A<&4@365R8WDG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V-2XQ,#`Z+3$P,BXT,S,G72`]("=2;V)E<G1S;VX@
M3&%K92!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V-2XR,3<Z+3$R,RXT,S,G72`]("=$96QI;F4L($XN
M(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C4N,C@S.BTQ,C8N
M.#`P)UT@/2`G3F]R;6%N(%=E;&QS+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8U+C8Q-SHM,3$X+C$Q-R==(#T@)T-A;7-E;&P@4FEV
M97(L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C4N-S8W
M.BTQ,3$N,C,S)UT@/2`G3'5P:6XL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C4N.34P.BTQ,S`N-#8W)UT@/2`G4F%M<&%R="!2:79E
M<B!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C8N,#`P.BTQ,3<N-S8W)UT@/2`G0VQU="!,
M86ME($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8V+C`S,SHM.3$N.#,S)UT@/2`G0BP@4B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8V+C`X,SHM.38N-3`P)UT@/2`G0F%C:R!2
M:79E<B!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8V+C$U,#HM-C4N
M-S,S)UT@/2`G4&%N9VYI<G1U;F<G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V-BXU.#,Z+38Q+C8Q-R==(#T@)T-A<&4@1'EE<BP@3BX@5RX@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-BXX-C<Z+3$S-"XR,#`G72`]("=3
M871A:"!2:79E<B!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C<N,#,S.BTQ,C8N,#@S)UT@
M/2`G0V]L=FEL;&4@3&%K92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8W
M+C`V-SHM,3(Q+C$P,"==(#T@)TAA;&1A;F4@4FEV97(@075T;VUA=&EC(%=E
M871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S8W+C(P,#HM,3,P+C(Q-R==(#T@)TQI='1L92!#:&EC86=O)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-C<N-3,S.BTV,RXW.#,G72`]("="<F]U
M9VAT;VX@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C<N-38W
M.BTQ,SDN.#,S)UT@/2`G3VQD($-R;W<@075T;VUA=&EC(%=E871H97(@4F5P
M;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8W+C<P
M,#HM,3`T+C0V-R==(#T@)T5L;&EC92!2:79E<B!!=71O;6%T960@4F5P;W)T
M:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-RXX,3<Z
M+3$Q-2XQ,S,G72`]("=#;W!P97)M:6YE+"!.+B!7+B!4+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8X+C(U.#HM,3(R+C$P-"==(#T@)U%A=G9I:R!,
M86ME+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C,P
M,#HM,3,S+C0X,R==(#T@)TEN=79I:RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V."XS,#`Z+3@U+C8V-R==(#T@)TUA8VMA<B!);FQE
M="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C,Q-SHM,3`P+C`X,R==
M(#T@)TAA="!)<VQA;F0L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C@N-#,S.BTX.2XW,3<G72`]("=096QL>2!"87DG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V."XT-C<Z+38V+C@P,"==(#T@)T-A<&4@2&]O
M<&5R+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C4P
M,#HM,3$S+C(Q-R==(#T@)TQA9'D@1G)A;FML:6X@4&]I;G0L($XN(%<N(%0N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-C4P.BTQ,#$N-S,S)UT@
M/2`G2F5N;GD@3&EN9"!)<VQA;F0@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S8X+C8U,#HM-S$N,38W)UT@/2`G1&5W87(@3&%K97,L($XN
M(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-S4P.BTQ,#DN
M,#8W)UT@/2`G0GER;VX@0F%Y($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V."XW-3`Z+3$S,RXU,#`G72`]("=4<F%I;"!686QL97DL($XN
M(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-S@S.BTQ,30N
M.#,S)UT@/2`G0F5R;F%R9"!(87)B;W5R)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C@N-S@S.BTX,2XR-3`G72`]("=(86QL($)E86-H+"!.+B!7+B!4
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C@Q-SHM.3,N-#,S)UT@
M/2`G4VAE<&AE<F0@0F%Y+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8X+C@X,SHM-S4N,3,S)UT@/2`G3&]N9W-T869F($)L=69F+"!.
M+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+CDP,#HM,3,S
M+CDS,R==(#T@)U-T;W)M($AI;&QS+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8X+CDS,SHM,3$V+CDQ-R==(#T@)T-A<&4@66]U;F<@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+CDU,#HM,3,W
M+C(Q-R==(#T@)U-H:6YG;&4@4&]I;G0L(%DN(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-CDN,3`P.BTQ,#4N,3$W)UT@/2`G0V%M8G)I9&=E($)A
M>2P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XQ-3`Z
M+3$T,"XQ-3`G72`]("=)=G9A=FEK(%!A<FL@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y
M+C$X,SHM,3(R+C,U,"==(#T@)U1U:W1U="!.;V=A:70L($XN(%<N(%0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN,S4P.BTQ,C0N,#4P)UT@/2`G
M4&%U;&%T=6L@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-CDN-#,S.BTQ,S,N,#,S)UT@/2`G5'5K=&]Y
M86MT=6L@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-CDN-#,S.BTX.2XW,S,G72`]("=096QL>2!"87D@
M,2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C0U,#HM,3,S+C`Q-R==
M(#T@)U1U:W1O>6%K='5K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN
M-38W.BTQ,S@N.3$W)UT@/2`G2&5R<V-H96P@27-L86YD($%U=&]M871I8R!7
M96%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V.2XU.#,Z+3$T,"XQ.#,G72`]("=+;VUA:W5K($)E86-H($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XV,#`Z+3$S,"XY,#`G
M72`]("=,:79E<G!O;VP@0F%Y)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-CDN-C$W.BTQ-#`N,C`P)UT@/2`G2V]M86MU:R!"96%C:"P@62X@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XV,S,Z+3$S-2XT,S,G72`]("=0
M96QL>2!)<VQA;F0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+CDS,SHM,3(X+CDV-R==
M(#T@)TYI8VAO;'-O;B!096YI;G-U;"<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S<P+C$V-SHM,3(T+C<P,"==(#T@)T-A<&4@4&%R<GDL($XN(%<N(%0N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-S`N-#@S.BTV."XU,3<G72`]
M("=#;'ED92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<W
M,BXP,#`Z+3$R-2XR-C<G72`]("=386-H<R!(87)B;W5R+"!.+B!7+B!4+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<R+C<P,#HM-S<N.38W)UT@/2`G
M4&]N9"!);FQE="P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<W-"XQ,S,Z+3$Q.2XY.#,G72`]("=!=6QV:6L@3F%T:6]N86P@4&%R:R<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<T+C<Q-SHM.30N.3@S)UT@/2`G
M4F5S;VQU=&4L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-S8N,C,S.BTQ,3DN,S,S)UT@/2`G36]U;&0@0F%Y+"!.+B!7+B!4+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S<X+C<X,SHM,3`S+C4U,"==(#T@)TES
M86-H<V5N($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I
M;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-SDN.3@S.BTX
M-2XY,S,G72`]("=%=7)E:V$L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG.#(N-3`P.BTV,BXS,S,G72`]("=!;&5R="P@3BX@5RX@5"XG
M.PHD8V]O<F1I;F%T97-;)T-A<&4@5F5R9&4G75LG,38N-S,S.BTR,BXY-3`G
M72`]("=386PG.PHD8V]O<F1I;F%T97-;)T-A>6UA;B!)<VQA;F1S)UU;)S$Y
M+C(X,SHM.#$N,S4P)UT@/2`G3W=E;B!2;V)E<G1S($%I<G!O<G1G<F%N9"!#
M87EM86XG.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI
M8R==6R<Q,"XR.#,Z,C(N-S@S)UT@/2`G0FER86\G.PHD8V]O<F1I;F%T97-;
M)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<T+C(U,#HQ-2XX,#`G72`]
M("="97)B97)A=&DG.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R==6R<T+C0P,#HQ."XU,3<G72`]("="86YG=6DG.PHD8V]O<F1I
M;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<T+C<S,SHR,BXX
M,S,G72`]("="86YG87-S;W4G.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R
M:6-A;B!297!U8FQI8R==6R<U+C`U,#HR,2XR,#`G72`]("=!;&EN9&%O)SL*
M)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG-2XR
M-C<Z,3<N-C,S)UT@/2`G0F]S<V5M8F5L92<["B1C;V]R9&EN871E<ULG0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S4N-#`P.C(V+C4P,"==(#T@)T]B
M;R<["B1C;V]R9&EN871E<ULG0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;
M)S4N.#4P.C(P+C8U,"==(#T@)T)A;6)A<FDG.PHD8V]O<F1I;F%T97-;)T-E
M;G1R86P@069R:6-A;B!297!U8FQI8R==6R<U+CDV-SHQ-2XV,S,G72`]("="
M;W5A<B<["B1C;V]R9&EN871E<ULG0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M)UU;)S8N-#@S.C$W+C0S,R==(#T@)T)O<W-A;F=O82<["B1C;V]R9&EN871E
M<ULG0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S8N-3`P.C(S+C(V-R==
M(#T@)UEA;&EN9V$G.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R==6R<V+C4S,SHR,2XY.#,G72`]("="<FEA)SL*)&-O;W)D:6YA
M=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG."XT,#`Z,C`N-C4P
M)UT@/2`G3EPG1&5L92<["B1C;V]R9&EN871E<ULG0VAA9"==6R<Q,2XP,S,Z
M,C`N,C@S)UT@/2`G06TM5&EM86XG.PHD8V]O<F1I;F%T97-;)T-H860G75LG
M,3(N,3,S.C$U+C`S,R==(#T@)TYD:F%M96YA)SL*)&-O;W)D:6YA=&5S6R=#
M:&%D)UU;)S$R+C,X,SHQ-RXP-3`G72`]("=";VMO<F\G.PHD8V]O<F1I;F%T
M97-;)T-H860G75LG,3,N-#,S.C$T+C<S,R==(#T@)T)O;"U"97)I;2<["B1C
M;V]R9&EN871E<ULG0VAA9"==6R<Q,RXX-3`Z,C`N.#4P)UT@/2`G06)E8VAE
M)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S$X+C`P,#HQ.2XQ-C<G72`]("=&
M87EA)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S@N-C$W.C$V+C`V-R==(#T@
M)TUO=6YD;W4G.PHD8V]O<F1I;F%T97-;)T-H860G75LG.2XQ-3`Z,3@N,S@S
M)UT@/2`G4V%R:"<["B1C;V]R9&EN871E<ULG0VAA9"==6R<Y+C,V-SHQ-"XY
M,3<G72`]("=086QA)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,3@N,S,S
M.BTW,"XS,S,G72`]("=!<FEC82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG
M+3(P+C4S,SHM-S`N,3@S)UT@/2`G27%U:7%U92`O($1I96=O($%R86,G.PHD
M8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTR,RXT,S,Z+3<P+C0S,R==(#T@)T%N
M=&]F86=A<W1A)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,C8N,S$W.BTW
M,"XV,3<G72`]("=#:&%N87)A;"<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG
M+3(W+C$U,#HM,3`Y+C0Q-R==(#T@)TES;&$@1&4@4&%S8W5A)SL*)&-O;W)D
M:6YA=&5S6R=#:&EL92==6R<M,C<N,S`P.BTW,"XT,3<G72`]("=#;W!I87!O
M)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,C@N-C`P.BTW,"XW-C<G72`]
M("=686QL96YA<B<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3(Y+CDP,#HM
M-S$N,C`P)UT@/2`G3&$@4V5R96YA)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==
M6R<M,S(N-S@S.BTW,2XU,3<G72`]("=1=6EN=&5R;R!386YT:6%G;R<["B1C
M;V]R9&EN871E<ULG0VAI;&4G75LG+3,S+C,X,SHM-S`N-S@S)UT@/2`G4'5D
M86AU96PG.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTS-"XY-C<Z+3<Q+C(S
M,R==(#T@)T-U<FEC;R<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3,V+C4V
M-SHM-S(N,#,S)UT@/2`G0VAI;&QA;B<["B1C;V]R9&EN871E<ULG0VAI;&4G
M75LG+3,V+C<V-SHM-S,N,#4P)UT@/2`G0V]N8V5P8VEO;B<["B1C;V]R9&EN
M871E<ULG0VAI;&4G75LG+3,X+C<U,#HM-S(N-C,S)UT@/2`G5&5M=6-O)SL*
M)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,SDN-C$W.BTW,RXP.#,G72`]("=6
M86QD:79I82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+30Q+C0Q-SHM-S,N
M,#@S)UT@/2`G4'5E<G1O($UO;G1T)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==
M6R<M-#4N-3@S.BTW,BXQ,3<G72`]("=#;WEH86EQ=64G.PHD8V]O<F1I;F%T
M97-;)T-H:6QE)UU;)RTT-2XY,3<Z+3<Q+C8X,R==(#T@)T)A;&UA8V5D82<[
M"B1C;V]R9&EN871E<ULG0VAI;&4G75LG+30V+C4U,#HM-S$N-S`P)UT@/2`G
M0VAI;&4@0VAI8V\G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTT-RXR,S,Z
M+3<R+C4U,"==(#T@)T-O8VAR86YE)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==
M6R<M-3,N,#`P.BTW,"XX-3`G72`]("=0=6YT82!!<F5N87,G.PHD8V]O<F1I
M;F%T97-;)T-H:6YA)UU;)S(P+C`S,SHQ,3`N,S4P)UT@/2`G2&%I:V]U)SL*
M)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R,2XR,3<Z,3$P+C0P,"==(#T@)UIH
M86YJ:6%N9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C(N-34P.C$Q-"XQ
M,#`G72`]("=3:&5N>FAE;B<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C(N
M.#$W.C$P."XS-3`G72`]("=.86YN:6YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN
M82==6R<R,RXQ-C<Z,3$S+C,S,R==(#T@)T=U86YG>FAO=2<["B1C;V]R9&EN
M871E<ULG0VAI;F$G75LG,C,N-#`P.C$Q-BXV.#,G72`]("=3:&%N=&]U)SL*
M)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R-"XT.#,Z,3$X+C`X,R==(#T@)UAI
M86UE;B<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C4N,#$W.C$P,BXV.#,G
M72`]("=+=6YM:6YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R-2XS,S,Z
M,3$P+C,P,"==(#T@)T=U:6QI;B<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG
M,C4N.#4P.C$Q-"XY-3`G72`]("='86YZ:&]U)SL*)&-O;W)D:6YA=&5S6R=#
M:&EN82==6R<R-BXP.#,Z,3$Y+C(X,R==(#T@)T9U>FAO=2<["B1C;V]R9&EN
M871E<ULG0VAI;F$G75LG,C8N-3@S.C$P-BXW,3<G72`]("='=6EY86YG)SL*
M)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R."XR,#`Z,3$S+C`X,R==(#T@)T-H
M86YG<VAA)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R."XV,#`Z,3$U+CDQ
M-R==(#T@)TYA;F-H86YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R.2XU
M,3<Z,3`V+C0X,R==(#T@)T-H;VYG<6EN9R<["B1C;V]R9&EN871E<ULG0VAI
M;F$G75LG,CDN-C8W.CDQ+C$S,R==(#T@)TQH87-A)SL*)&-O;W)D:6YA=&5S
M6R=#:&EN82==6R<S,"XR,S,Z,3(P+C$V-R==(#T@)TAA;F=Z:&]U)SL*)&-O
M;W)D:6YA=&5S6R=#:&EN82==6R<S,"XV,3<Z,3$T+C$S,R==(#T@)U=U:&%N
M)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S,"XV-C<Z,3`T+C`Q-R==(#T@
M)T-H96YG9'4G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,Q+C$V-SHQ,C$N
M-#,S)UT@/2`G4VAA;F=H86D@+R!(;VYG<6EA;R<["B1C;V]R9&EN871E<ULG
M0VAI;F$G75LG,S$N.#8W.C$Q-RXR,S,G72`]("=(969E:2<["B1C;V]R9&EN
M871E<ULG0VAI;F$G75LG,S(N,#`P.C$Q."XX,#`G72`]("=.86YJ:6YG)SL*
M)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-"XS,#`Z,3`X+CDS,R==(#T@)UAI
M7"=!;B<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S0N-S$W.C$Q,RXV-3`G
M72`]("=::&5N9WIH;W4G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,V+C`V
M-SHQ,C`N,S,S)UT@/2`G46EN9V1A;R<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,S8N-C`P.C$P.2XU,#`G72`]("=986X@06XG.PHD8V]O<F1I;F%T97-;
M)T-H:6YA)UU;)S,V+C8Q-SHQ,#$N-S8W)UT@/2`G6&EN:6YG)SL*)&-O;W)D
M:6YA=&5S6R=#:&EN82==6R<S-BXV.#,Z,3$V+CDX,R==(#T@)TII;F%N)SL*
M)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-RXQ,S,Z-SDN.3,S)UT@/2`G2&]T
M86XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,W+C<X,SHQ,3(N-34P)UT@
M/2`G5&%I>75A;B<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S@N-#@S.C$P
M-BXR,3<G72`]("=9:6YC:'5A;B<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG
M,S@N.3`P.C$R,2XV,S,G72`]("=$86QI86XG.PHD8V]O<F1I;F%T97-;)T-H
M:6YA)UU;)S,Y+C0V-SHW-2XY.#,G72`]("=+87-H:2<["B1C;V]R9&EN871E
M<ULG0VAI;F$G75LG,SDN-S8W.CDX+C0X,R==(#T@)TII=7%U86XG.PHD8V]O
M<F1I;F%T97-;)T-H:6YA)UU;)S,Y+CDS,SHQ,38N,C@S)UT@/2`G0F5I:FEN
M9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG-#`N.#$W.C$Q,2XV.#,G72`]
M("=(;VAH;W0G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S0R+C@Q-SHY,RXU
M,3<G72`]("=(86UI)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<T,RXY,#`Z
M,3(U+C(Q-R==(#T@)T-H86YG8VAU;B<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG-#,N.34P.C@Q+C,S,R==(#T@)UEI;FEN9R<["B1C;V]R9&EN871E<ULG
M0VAI;F$G75LG-#<N,S@S.C$R,RXY,3<G72`]("=1:7%I:&%R)SL*)&-O;W)D
M:6YA=&5S6R=#:')I<W1M87,@27-L86YD)UU;)RTQ,"XT,S,Z,3`U+C8X,R==
M(#T@)T-H<FES=&UA<R!)<VQA;F0@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=#:')I<W1M87,@27-L86YD)UU;)RTQ,BXQ.#,Z.38N.#$W)UT@/2`G0V]C
M;W,@27-L86YD($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;
M)S`N-3`P.BTW-BXU,#`G72`]("=0=65R=&\@07-I<R<["B1C;V]R9&EN871E
M<ULG0V]L;VUB:6$G75LG,"XX,3<Z+3<W+C8S,R==(#T@)TEP:6%L97,@+R!3
M86X@3'5I<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,2XQ,S,Z+3<P
M+C`U,"==(#T@)TUI='4G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$N
M-#$W.BTW-RXR-C<G72`]("=087-T;R`O($%N=&]N:6\@3F%R:6XG.PHD8V]O
M<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$P+C0S,SHM-S,N,C4P)UT@/2`G5F%L
M;&5D=7!A<B`O($%L9F]N<V\@3&]P97HG.PHD8V]O<F1I;F%T97-;)T-O;&]M
M8FEA)UU;)S$P+C0U,#HM-S4N-3$W)UT@/2`G0V%R=&%G96YA("\@4F%F865L
M($YU;F5Z)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q,"XX.#,Z+3<T
M+C<X,R==(#T@)T)A<G)A;G%U:6QL82`O($5R;F5S=&]C;W)T:7-S;WHG.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$Q+C$S,SHM-S0N,C,S)UT@/2`G
M4V%N=&$@36%R=&$@+R!3:6UO;B!";VQI=F%R)SL*)&-O;W)D:6YA=&5S6R=#
M;VQO;6)I82==6R<Q,2XU,S,Z+3<R+CDS,R==(#T@)U)I;VAA8VAA("\@06QM
M:7)A;G1E(%!A9&EL;&$G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$R
M+C4X,SHM.#$N-S$W)UT@/2`G4V%N($%N9')E<R!)<VQA("\@4V5S<75I8V5N
M=&5N87)I;R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,3,N,S8W.BTX
M,2XS-3`G72`]("=0<F]V:61E;F-I82!)<VQA("\@16P@16UB<G5J;R<["B1C
M;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,BXT-C<Z+3<V+C8P,"==(#T@)U!O
M<&%Y86X@+R!'=6EL;&5R;6\G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;
M)S(N-38W.BTW,BXV,S,G72`]("=386X@2F]S92!$96P@1W5A=FEA<F4G.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S(N.38W.BTW-2XS,#`G72`]("=.
M96EV82`O($)E;FET;R!386QA<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G
M75LG,RXU-3`Z+3<V+C,X,R==(#T@)T-A;&D@+R!!;&9O;G-O($)O;FEL;&%A
M<F%G;VXG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S,N.#4P.BTW-BXY
M-C<G72`]("="=65N879E;G1U<F$G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA
M)UU;)RTT+C$V-SHM-CDN.34P)UT@/2`G3&5T:6-I82`O(%9A<W%U97H@0V]B
M;R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-"XQ-C<Z+3<S+C8Q-R==
M(#T@)U9I;&QA=FEC96YC:6\@+R!686YG=6%R9&EA)SL*)&-O;W)D:6YA=&5S
M6R=#;VQO;6)I82==6R<T+C0S,SHM-S4N,34P)UT@/2`G26)A9W5E("\@4&5R
M86QE<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-"XU,#`Z+3<U+C<Q
M-R==(#T@)T%R;65N:6$@+R!%;"!%9&5N)SL*)&-O;W)D:6YA=&5S6R=#;VQO
M;6)I82==6R<T+C<Q-SHM-S0N,34P)UT@/2`G0F]G;W1A("\@16QD;W)A9&\G
M.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S0N.#$W.BTW-2XW,S,G72`]
M("=097)E:7)A("\@36%T96-A;F$G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA
M)UU;)S4N-S$W.BTW-BXV,3<G72`]("=1=6EB9&\@+R!%;"!#87)A;F\G.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S8N,3,S.BTW-2XT,S,G72`]("=2
M:6]N96=R;R`O($HN($TN($-O<F1O=F$G.PHD8V]O<F1I;F%T97-;)T-O;&]M
M8FEA)UU;)S8N,38W.BTV-RXU,#`G72`]("=0=65R=&\@0V%R<F5N;R`O($$N
M($=U875Q=65A)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<V+C(Q-SHM
M-S4N-C`P)UT@/2`G365D96QL:6X@+R!/;&%Y82!(97)R97)A)SL*)&-O;W)D
M:6YA=&5S6R=#;VQO;6)I82==6R<W+C`Q-SHM-S,N.#`P)UT@/2`G0F%R<F%N
M8V%B97)M96IA("\@66%R:6=U:65S)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I
M82==6R<W+C`V-SHM-S`N-S,S)UT@/2`G07)A=6-A("\@4V%N=&EA9V\@4&5R
M97HG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S<N,3`P.BTW,RXR,#`G
M72`]("="=6-A<F%M86YG82`O(%!A;&]N96=R;R<["B1C;V]R9&EN871E<ULG
M0V]L;VUB:6$G75LG-RXX,3<Z+3<V+C<P,"==(#T@)T%P87)T861O("\@3&]S
M($-E9')O<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-RXY,S,Z+3<R
M+C4Q-R==(#T@)T-U8W5T82`O($-A;6EL;R!$87IA)SL*)&-O;W)D:6YA=&5S
M6R=#;VQO;6)I82==6R<X+C@Q-SHM-S4N.#4P)UT@/2`G36]N=&5R:6$@+R!,
M;W,@1V%R>F]N97,G.PHD8V]O<F1I;F%T97-;)T-O;6]R;W,G75LG+3$Q+C4S
M,SHT,RXR-C<G72`]("=(86AA>6$@26YT97)N871I;VYA;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#;VUO<F]S)UU;)RTQ,BXQ,3<Z-#0N-#,S)UT@/2`G
M3W5A;FD@06YJ;W5A;B<["B1C;V]R9&EN871E<ULG0V]M;W)O<R==6R<M,3(N
M.#`P.C0U+C(X,R==(#T@)T1Z86]U9'II("\@4&%M86YZ:2!-87EO='1E)SL*
M)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<M,"XP,3<Z,34N-3@S)UT@/2`G36%K
M;W5A)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<Q+C8Q-SHQ-BXP-3`G72`]
M("=/=65S<V\G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)S$N-C$W.C$X+C`V
M-R==(#T@)TEM<&9O;F1O)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<M,2XX
M-C<Z,34N.#8W)UT@/2`G1V%M8F]M82<["B1C;V]R9&EN871E<ULG0V]N9V\G
M75LG,BXP-C<Z,30N,3,S)UT@/2`G4V]U86YK92<["B1C;V]R9&EN871E<ULG
M0V]N9V\G75LG+3(N-3,S.C$T+C<V-R==(#T@)T1J86UB86QA)SL*)&-O;W)D
M:6YA=&5S6R=#;VYG;R==6R<M,BXV,3<Z,38N,C$W)UT@/2`G35PG4&]U>6$G
M.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTS+C0X,SHQ,BXV,3<G72`]("=-
M86MA8F%N82<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+3,N-C@S.C$S+C,U
M,"==(#T@)U-I8FET:2<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+3,N.3@S
M.C$S+CDQ-R==(#T@)TUO=7EO;F1Z:2<["B1C;V]R9&EN871E<ULG0V]N9V\G
M75LG+30N,C`P.C$R+C<P,"==(#T@)TQO=6)O;6\G.PHD8V]O<F1I;F%T97-;
M)T-O;F=O)UU;)RTT+C(U,#HQ-2XR-3`G72`]("="<F%Z>F%V:6QL92`O($UA
M>6$M36%Y82<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+30N.#$W.C$Q+CDP
M,"==(#T@)U!O:6YT92U.;VER92<["B1C;V]R9&EN871E<ULG0V]O:R!)<VQA
M;F1S)UU;)RTQ.2XP-C<Z+3$V.2XY,3<G72`]("=!;&]F:2`O($YI=64G.PHD
M8V]O<F1I;F%T97-;)T-O;VL@27-L86YD<R==6R<M,C$N,C`P.BTQ-3DN.#$W
M)UT@/2`G4F%R;W1O;F=A)SL*)&-O;W)D:6YA=&5S6R=#;W-T82!2:6-A)UU;
M)S$P+C`P,#HM.#,N,#4P)UT@/2`G4'5E<G1O($QI;6]N)SL*)&-O;W)D:6YA
M=&5S6R=#;W-T82!2:6-A)UU;)S$P+C`P,#HM.#0N,C$W)UT@/2`G2G5A;B!3
M86YT86UA<FEA)SL*)&-O;W)D:6YA=&5S6R=#;W-T82!2:6-A)UU;)S$P+C$U
M,#HM.#4N-#4P)UT@/2`G3FEC;WEA)SL*)&-O;W)D:6YA=&5S6R=#;W-T82!2
M:6-A)UU;)S$P+C8Q-SHM.#4N-#,S)UT@/2`G3&EB97)I82<["B1C;V]R9&EN
M871E<ULG0V]S=&$@4FEC82==6R<X+CDU,#HM.#,N-#8W)UT@/2`G4&%L;6%R
M(%-U<B<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G75LG-"XT,3<Z
M+3<N,S8W)UT@/2`G5&%B;W4G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O
M:7)E)UU;)S0N-S4P.BTV+C8U,"==(#T@)U-A;B!0961R;R<["B1C;V]R9&EN
M871E<ULG0V]T92!$7"=)=F]I<F4G75LG-"XY-3`Z+38N,#@S)UT@/2`G4V%S
M<V%N9')A)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<U+C(U
M,#HM,RXY,S,G72`]("=!8FED:F%N)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<
M)TEV;VER92==6R<U+C,P,#HM,RXS,#`G72`]("=!9&EA:V4G.PHD8V]O<F1I
M;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S8N,3,S.BTU+CDU,"==(#T@)T=A
M9VYO82<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G75LG-BXV-3`Z
M+30N-S`P)UT@/2`G1&EM8F]K<F\G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG
M279O:7)E)UU;)S8N.#8W.BTV+C0V-R==(#T@)T1A;&]A)SL*)&-O;W)D:6YA
M=&5S6R=#;W1E($1<)TEV;VER92==6R<V+CDP,#HM-2XS-3`G72`]("=986UO
M=7-S;W5K<F\G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S<N
M,S@S.BTW+C4Q-R==(#T@)TUA;B<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)
M=F]I<F4G75LG-RXW,S,Z+34N,#8W)UT@/2`G0F]U86ME)SL*)&-O;W)D:6YA
M=&5S6R=#;W1E($1<)TEV;VER92==6R<X+C`U,#HM,BXW.#,G72`]("=";VYD
M;W5K;W4G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)SDN-#$W
M.BTU+C8Q-R==(#T@)TMO<FAO9V\G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG
M279O:7)E)UU;)SDN-3`P.BTW+C4V-R==(#T@)T]D:65N;F4G.PHD8V]O<F1I
M;F%T97-;)T-R;V%T:6$G75LG-#(N-38W.C$X+C(V-R==(#T@)T1U8G)O=FYI
M:R`O($-I;&EP:2<["B1C;V]R9&EN871E<ULG0W)O871I82==6R<T,RXQ-C<Z
M,38N-#4P)UT@/2`G2'9A<B<["B1C;V]R9&EN871E<ULG0W)O871I82==6R<T
M,RXU,S,Z,38N,S`P)UT@/2`G4W!L:70@+R!297-N:6LG.PHD8V]O<F1I;F%T
M97-;)T-R;V%T:6$G75LG-#0N,3`P.C$U+C,U,"==(#T@)UIA9&%R("\@6F5M
M=6YI:R<["B1C;V]R9&EN871E<ULG0W)O871I82==6R<T-2XP,S,Z,3@N.#`P
M)UT@/2`G3W-I:F5K("\@0V5P:6XG.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G
M75LG-#4N,38W.C$X+C`P,"==(#T@)U-L879O;G-K:2!"<F]D)SL*)&-O;W)D
M:6YA=&5S6R=#<F]A=&EA)UU;)S0U+C(Q-SHQ-"XU.#,G72`]("=2:6IE:V$@
M+R!/;6ES86QJ)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0U+C<S,SHQ
M-BXP-C<G72`]("=:86=R96(@+R!0;&5S;R<["B1C;V]R9&EN871E<ULG0W)O
M871I82==6R<T-2XX,3<Z,38N,#,S)UT@/2`G6F%G<F5B("\@36%K<VEM:7(G
M.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#4N.3`P.C$S+CDQ-R==(#T@
M)U!U;&$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0V
M+C,P,#HQ-BXS.#,G72`]("=687)A>F1I;B<["B1C;V]R9&EN871E<ULG0W5B
M82==6R<Q.2XY,#`Z+3<U+C$S,R==(#T@)T=U86YT86YA;6\L($]R:65N=&4G
M.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,3DN.38W.BTW-2XX-3`G72`]("=3
M86YT:6%G;R!$92!#=6)A+"!/<FEE;G1E)SL*)&-O;W)D:6YA=&5S6R=#=6)A
M)UU;)S(P+C`X,SHM-S4N,34P)UT@/2`G1W5A;G1A;F%M;RP@3W)I96YT92<[
M"B1C;V]R9&EN871E<ULG0W5B82==6R<R,"XS,S,Z+3<W+C$Q-R==(#T@)TUA
M;GIA;FEL;&\L($]R:65N=&4G.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,C`N
M,S4P.BTW-"XU,#`G72`]("="87)A8V]A+"!/<FEE;G1E)SL*)&-O;W)D:6YA
M=&5S6R=#=6)A)UU;)S(P+CDU,#HM-S8N.34P)UT@/2`G3&%S(%1U;F%S+"!,
M87,@5'5N87,G.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,C$N-#$W.BTW-RXX
M-3`G72`]("=#86UA9W5E>2!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=#
M=6)A)UU;)S(Q+C<X,SHM-S@N-S@S)UT@/2`G5F5N97IU96QA+"!#:65G;R!$
M92!!=FEL82<["B1C;V]R9&EN871E<ULG0W5B82==6R<R,2XX,S,Z+3@R+C<X
M,R==(#T@)TYU979A($=E<F]N82P@27-L82!$92!0:6YO<R<["B1C;V]R9&EN
M871E<ULG0W5B82==6R<R,BXQ-3`Z+3@P+C0P,"==(#T@)T-I96YF=65G;W,L
M($QA<R!6:6QL87,G.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,C(N-#$W.BTX
M,RXV.#,G72`]("=0:6YA<B!$96P@4FEO+"!0:6YA<B!$96P@4FEO)SL*)&-O
M;W)D:6YA=&5S6R=#=6)A)UU;)S(R+CDX,SHM.#(N-#`P)UT@/2`G065R;W!U
M97)T;R!*;W-E($UA<G1I+"!286YC:&\M0F]Y97)O<RP@2&%B86YA)SL*)&-O
M;W)D:6YA=&5S6R=#=6)A)UU;)S(S+C$S,SHM.#$N,C@S)UT@/2`G5F%R861E
M<F\L($UA=&%N>F%S)SL*)&-O;W)D:6YA=&5S6R=#>7!R=7,G75LG,S0N-3@S
M.C,R+CDX,R==(#T@)T%K<F]T:7)I)SL*)&-O;W)D:6YA=&5S6R=#>7!R=7,G
M75LG,S0N-S$W.C,R+C0X,R==(#T@)U!A<&AO<R!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=#>7!R=7,G75LG,S0N.#@S.C,S+C8S,R==(#T@)TQA<FYA8V$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG0WEP<G5S)UU;)S,U+C$U,#HS,RXT
M,#`G72`]("=!=&AA;&%S<V$G.PHD8V]O<F1I;F%T97-;)T-Z96-H(%)E<'5B
M;&EC)UU;)S0Y+C$U,#HQ-BXW,#`G72`]("="<FYO("\@5'5R86YY)SL*)&-O
M;W)D:6YA=&5S6R=#>F5C:"!297!U8FQI8R==6R<T.2XS,3<Z,3<N-38W)UT@
M/2`G2&]L97-O=B<["B1C;V]R9&EN871E<ULG0WIE8V@@4F5P=6)L:6,G75LG
M-#DN-C@S.C$X+C$Q-R==(#T@)T]S=')A=F$@+R!-;W-N;W8G.PHD8V]O<F1I
M;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S4P+C$P,#HQ-"XR-3`G72`]("=0
M<F%H82`O(%)U>GEN92<["B1C;V]R9&EN871E<ULG0WIE8V@@4F5P=6)L:6,G
M75LG-3`N,C`P.C$R+CDQ-R==(#T@)TMA<FQO=GD@5F%R>2<["B1C;V]R9&EN
M871E<ULG1&5N;6%R:R==6R<U-"XW,#`Z,3$N-#4P)UT@/2`G36%R:6)O($QU
M9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4T+CDV-SHY+C<X
M,R==(#T@)U-O96YD97)B;W)G($QU9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$
M96YM87)K)UU;)S4U+C`Q-SHQ,"XU-C<G72`]("=3>61F>6YS($9L>79E<&QA
M9',G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N,#8W.C$T+C<U,"==
M(#T@)U)O96YN92<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XP.#,Z
M,3$N-S@S)UT@/2`G079N;R!$86YI<V@@06ER($9O<F-E($)A<V4G.PHD8V]O
M<F1I;F%T97-;)T1E;FUA<FLG75LG-34N,C,S.CDN,C8W)UT@/2`G4VMR>61S
M=')U<"<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XT,S,Z.2XS,S,G
M72`]("=686UD<G5P)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4U+C0X
M,SHQ,"XS,S,G72`]("=/9&5N<V4@+R!"96QD<FEN9V4G.PHD8V]O<F1I;F%T
M97-;)T1E;FUA<FLG75LG-34N-3,S.C@N-38W)UT@/2`G17-B:F5R9R<["B1C
M;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XU.#,Z,3(N,3,S)UT@/2`G2V]E
M8F5N:&%V;B`O(%)O<VMI;&1E)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;
M)S4U+C8Q-SHQ,BXV-3`G72`]("=+;V5B96YH879N("\@2V%S=')U<"<["B1C
M;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XW,#`Z.2XR,#`G72`]("=686YD
M96PG.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N-S,S.CDN,38W)UT@
M/2`G0FEL;'5N9"!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==
M6R<U-2XW-C<Z,3(N,S,S)UT@/2`G5F%E<FQO97-E)SL*)&-O;W)D:6YA=&5S
M6R=$96YM87)K)UU;)S4V+C`P,#HX+C,U,"==(#T@)U-T875N:6YG($QU9G1H
M879N)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4V+C,P,#HQ,"XV,3<G
M72`]("=4:7)S=')U<"<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-BXS
M,#`Z.2XQ,3<G72`]("=+87)U<"<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==
M6R<U-BXT,#`Z."XT-3`G72`]("=,:6YD=&]R<"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=$96YM87)K)UU;)S4V+C4U,#HY+C$V-R==(#T@)U-K:79E($QU
M9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4V+C<P,#HQ,2XU
M-3`G72`]("=!;FAO;'0@27-L86YD($%U=&]M871E9"!297!O<G1I;F<@4W1A
M=&EO;B<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-BXW,3<Z,3`N,3$W
M)UT@/2`G2&%D<W5N9"<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-RXP
M-C<Z."XW,3<G72`]("=4:&ES=&5D($QU9G1H879N)SL*)&-O;W)D:6YA=&5S
M6R=$96YM87)K)UU;)S4W+C$P,#HY+C@U,"==(#T@)T%A;&)O<F<G.PHD8V]O
M<F1I;F%T97-;)T1E;FUA<FLG75LG-3<N-3`P.C$P+C(Q-R==(#T@)U-I;F1A
M;"!&;'EV97!L861S)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S8R+C`V
M-SHM-RXR.#,G72`]("=3;V5R=F%A9R`O(%9A9V%R)SL*)&-O;W)D:6YA=&5S
M6R=$:FEB;W5T:2==6R<Q,2XU-3`Z-#,N,34P)UT@/2`G1&II8F]U=&DG.PHD
M8V]O<F1I;F%T97-;)T1O;6EN:6-A)UU;)S$U+C,P,#HM-C$N-#`P)UT@/2`G
M4F]S96%U)SL*)&-O;W)D:6YA=&5S6R=$;VUI;FEC82==6R<Q-2XU,S,Z+38Q
M+C,P,"==(#T@)TUE;'9I;&QE($AA;&P@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG1&]M:6YI8V$G75LG,34N-3,S.BTV,2XT,#`G72`]("=#86YE9FEE;&0@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG1&]M:6YI8V%N(%)E<'5B;&EC)UU;
M)S$X+C(P,#HM-S$N,3`P)UT@/2`G0F%R86AO;F$G.PHD8V]O<F1I;F%T97-;
M)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q."XT,S,Z+38Y+C8V-R==(#T@)TQA
M<R!!;65R:6-A<R<["B1C;V]R9&EN871E<ULG1&]M:6YI8V%N(%)E<'5B;&EC
M)UU;)S$X+C0V-SHM-CDN.38W)UT@/2`G2&5R<F5R82<["B1C;V]R9&EN871E
M<ULG1&]M:6YI8V%N(%)E<'5B;&EC)UU;)S$X+C4V-SHM-C@N,S8W)UT@/2`G
M4'5N=&$@0V%N82<["B1C;V]R9&EN871E<ULG1&]M:6YI8V%N(%)E<'5B;&EC
M)UU;)S$Y+C0U,#HM-S`N-S`P)UT@/2`G4V%N=&EA9V\G.PHD8V]O<F1I;F%T
M97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q.2XW-3`Z+3<P+C4U,"==(#T@
M)U!U97)T;R!0;&%T82!);G1E<FYA=&EO;F%L)SL*)&-O;W)D:6YA=&5S6R=%
M87-T(%1I;6]R)UU;)RTX+C4P,#HQ,C8N-#`P)UT@/2`G0F%U8V%U)SL*)&-O
M;W)D:6YA=&5S6R=%87-T(%1I;6]R)UU;)RTX+C4V-SHQ,C4N-38W)UT@/2`G
M1&EL;&D@+R!$:6QL:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=%87-T(%1I
M;6]R)UU;)RTY+C(P,#HQ,C0N,S8W)UT@/2`G3V4M0W5S<V4@+R!/92!#=7-S
M92<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,"XQ-3`Z+3<X+C0X,R==
M(#T@)U%U:71O("\@36%R:7-C86P@4W5C<F4G.PHD8V]O<F1I;F%T97-;)T5C
M=6%D;W(G75LG,"XS-3`Z+3<X+C$S,R==(#T@)TEB87)R82`O($%T86AU86QP
M82<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,"XU.#,Z+3@P+C0P,"==
M(#T@)T)A:&EA($1E($-A<F%Q=65Z)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R
M)UU;)RTP+C<X,SHM-S4N-3$W)UT@/2`G5&EP=71I;FDG.PHD8V]O<F1I;F%T
M97-;)T5C=6%D;W(G75LG,"XX,3<Z+3<W+C<P,"==(#T@)U1U;&-A;B`O($5L
M(%)O<V%L)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTP+CDP,#HM.#DN
M-C`P)UT@/2`G4V%N($-R:7-T;V)A;"!'86QA<&%G;W,G.PHD8V]O<F1I;F%T
M97-;)T5C=6%D;W(G75LG+3`N.3$W.BTW."XV,3<G72`]("=,871A8W5N9V$G
M.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+3`N.34P.BTX,"XV.#,G72`]
M("=-86YT82<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<P+CDV-SHM-SDN
M-C,S)UT@/2`G17-M97)A;&1A<RU486-H:6YA)SL*)&-O;W)D:6YA=&5S6R=%
M8W5A9&]R)UU;)RTQ+C(P,#HM-S@N-38W)UT@/2`G06UB871O("\@0VAA8VAO
M86XG.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+3$N-3`P.BTW."XP-3`G
M72`]("=087-T87IA("\@4FEO($%M87IO;F%S)SL*)&-O;W)D:6YA=&5S6R=%
M8W5A9&]R)UU;)RTR+C$U,#HM-SDN.#@S)UT@/2`G1W5A>6%Q=6EL("\@4VEM
M;VX@0F]L:79A<B<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,BXR,#`Z
M+3@P+CDX,R==(#T@)U-A;&EN87,@+R!'96YE<F%L(%5L<&EA;F\@4&%E>B<[
M"B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,BXX.#,Z+3<X+CDX,R==(#T@
M)T-U96YC82`O($UA<FES8V%L($QA;6%R)SL*)&-O;W)D:6YA=&5S6R=%8W5A
M9&]R)UU;)RTS+C(U,#HM-SDN.38W)UT@/2`G36%C:&%L82`O($=E;F5R86P@
M32X@4V5R<F%N;R<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M-"XP,#`Z
M+3<Y+C,V-R==(#T@)T-A=&%M87EO("\@0V%M:6QO(%!O;F-E($5N<FEQ=65Z
M)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTT+C,V-SHM-SDN.3,S)UT@
M/2`G36%C87)A("\@2BX@32X@5F5L87-C;R!)+B<["B1C;V]R9&EN871E<ULG
M16=Y<'0G75LG,C,N.38W.C,R+C<X,R==(#T@)T%S<W=A;B<["B1C;V]R9&EN
M871E<ULG16=Y<'0G75LG,C4N-C8W.C,R+C<P,"==(#T@)TQU>&]R)SL*)&-O
M;W)D:6YA=&5S6R=%9WEP="==6R<R-RXP-3`Z,S$N,#$W)UT@/2`G07-Y=70G
M.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S(W+C$U,#HS,RXW,3<G72`]("=(
M=7)G=6%D82<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,C@N,C,S.C,R+C8Q
M-R==(#T@)T5L(%1O<B<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,S`N,3,S
M.C,Q+C0P,"==(#T@)T-A:7)O($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T5G
M>7!T)UU;)S,Q+C`X,SHS,RXX,3<G72`]("=%;"!!<FES:"<["B1C;V]R9&EN
M871E<ULG16=Y<'0G75LG,S$N,C`P.C(Y+CDU,"==(#T@)T%L97AA;F1R:6$@
M+R!.;W5Z:&$G.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S,Q+C(V-SHS,BXS
M,#`G72`]("=0;W)T(%-A:60G.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S,Q
M+C,S,SHR-RXR,3<G72`]("=-97)S82!-871R=6@G.PHD8V]O<F1I;F%T97-;
M)T5L(%-A;'9A9&]R)UU;)S$S+C0S,SHM.#DN,#4P)UT@/2`G16P@4V%L=F%D
M;W(@26YT;"X@06ER<&]R="`O($-O;6%L87!A)SL*)&-O;W)D:6YA=&5S6R=%
M;"!386QV861O<B==6R<Q,RXT-3`Z+3@X+C$Q-R==(#T@)U-A;B!-:6=U96P@
M+R!%;"!087!A;&]N)SL*)&-O;W)D:6YA=&5S6R=%;"!386QV861O<B==6R<Q
M,RXU-C<Z+3@Y+C@S,R==(#T@)T%C86IU=&QA)SL*)&-O;W)D:6YA=&5S6R=%
M;"!386QV861O<B==6R<Q,RXW,#`Z+3@Y+C$Q-R==(#T@)U-A;B!386QV861O
M<B`O($EL;W!A;F=O)SL*)&-O;W)D:6YA=&5S6R=%;"!386QV861O<B==6R<Q
M,RXY.#,Z+3@Y+C4V-R==(#T@)U-A;G1A($%N82`O($5L(%!A;&UA<B<["B1C
M;V]R9&EN871E<ULG17%U871O<FEA;"!'=6EN96$G75LG,RXW-3`Z."XW-C<G
M72`]("=-86QA8F\O1F5R;F%N9&\@4&]O)SL*)&-O;W)D:6YA=&5S6R=%<W1O
M;FEA)UU;)S4X+CDX,SHR,BXX,3<G72`]("=+87)D;&$G.PHD8V]O<F1I;F%T
M97-;)T5S=&]N:6$G75LG-3DN,S@S.C(T+C4X,R==(#T@)U1A;&QI;FXG.PHD
M8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S$P+C,U,#HS-RXW,3<G72`]("=$
M96)R96UA<F-O<R<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,3$N,#@S
M.C,Y+C<Q-R==(#T@)T-O;6)O;&-H82<["B1C;V]R9&EN871E<ULG171H:6]P
M:6$G75LG,3$N-C`P.C,W+C0P,"==(#T@)T)A:&%R($1A<B<["B1C;V]R9&EN
M871E<ULG171H:6]P:6$G75LG,3(N-3,S.C,W+C0S,R==(#T@)T=O;F1A<B<[
M"B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,3,N,#8W.C0R+C<Q-R==(#T@
M)T%S<V%B)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Q,RXU,#`Z,SDN
M-#@S)UT@/2`G36%K86QE)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Q
M-2XR.#,Z,S@N.3$W)UT@/2`G07-M87)A)SL*)&-O;W)D:6YA=&5S6R=%=&AI
M;W!I82==6R<Q-2XV,3<Z,SDN-#4P)UT@/2`G36%S<V%W82<["B1C;V]R9&EN
M871E<ULG171H:6]P:6$G75LG-2XQ,#`Z-#0N-3@S)UT@/2`G1V]D92<["B1C
M;V]R9&EN871E<ULG171H:6]P:6$G75LG-2XR.#,Z,SDN-S4P)UT@/2`G3F5G
M:&5L;&DG.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S8N,#8W.C,W+C8V
M-R==(#T@)T%R8F$@36EN8V@G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;
M)S<N,#8W.C,X+C4P,"==(#T@)T%W87-S82<["B1C;V]R9&EN871E<ULG171H
M:6]P:6$G75LG-RXV-C<Z,S8N.#,S)UT@/2`G2FEM;6$G.PHD8V]O<F1I;F%T
M97-;)T5T:&EO<&EA)UU;)S@N,38W.C,U+C4U,"==(#T@)T=O<F4G.PHD8V]O
M<F1I;F%T97-;)T5T:&EO<&EA)UU;)S@N-S,S.C,Y+C`P,"==(#T@)TAA<F%R
M($UE9&$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S@N.3@S.C,X+C@P
M,"==(#T@)T%D9&ES($%B86)A)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==
M6R<Y+C,S,SHT,BXW,3<G72`]("=*:6=G:6=A)SL*)&-O;W)D:6YA=&5S6R=%
M=&AI;W!I82==6R<Y+C8P,#HT,2XX-C<G72`]("=$:7)E($1A=V$G.PHD8V]O
M<F1I;F%T97-;)T9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2==6R<M-3$N
M-C@S.BTU-RXW-C<G72`]("=3=&%N;&5Y($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T9I:FDG75LG+3$R+C4P,#HQ-S<N,#4P)UT@/2`G4F]T=6UA)SL*)&-O
M;W)D:6YA=&5S6R=&:6II)UU;)RTQ-RXW-3`Z,3<W+C0U,"==(#T@)TYA;F1I
M)SL*)&-O;W)D:6YA=&5S6R=&:6II)UU;)RTQ."XP-3`Z,3<X+C4V-R==(#T@
M)TYA=7-O<FDG.PHD8V]O<F1I;F%T97-;)T9I:FDG75LG+3$X+C(S,SHM,3<X
M+C@P,"==(#T@)TQA:V5M8F$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG
M-C`N,3$W.C$Y+CDP,"==(#T@)TUA<FEE:&%M;B`O($%L86YD($ES;&%N9"<[
M"B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,"XR-3`Z,C4N,#4P)UT@/2`G
M2&5L<VEN:VDM36%L;6DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C`N
M,S$W.C(T+CDV-R==(#T@)TAE;'-I;FMI+59A;G1A82<["B1C;V]R9&EN871E
M<ULG1FEN;&%N9"==6R<V,"XU,3<Z,C(N,C8W)UT@/2`G5'5R:W4G.PHD8V]O
M<F1I;F%T97-;)T9I;FQA;F0G75LG-C`N.3`P.C(V+CDS,R==(#T@)U5T=&DG
M.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C$N,#0V.C(X+C$T.2==(#T@
M)TQA<'!E96YR86YT82<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,2XT
M,3<Z,C,N-3@S)UT@/2`G5&%M<&5R92`O(%!I<FMK86QA)SL*)&-O;W)D:6YA
M=&5S6R=&:6YL86YD)UU;)S8Q+C0V-SHR,2XX,#`G72`]("=0;W)I)SL*)&-O
M;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8Q+C<S,SHR-RXS,#`G72`]("=-:6MK
M96QI)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8Q+C@U,#HR-"XX,#`G
M72`]("=(86QL:2<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,2XY-3`Z
M,C@N.34P)UT@/2`G4V%V;VYL:6YN82<["B1C;V]R9&EN871E<ULG1FEN;&%N
M9"==6R<V,BXT,#`Z,C4N-C@S)UT@/2`G2GEV87-K>6QA)SL*)&-O;W)D:6YA
M=&5S6R=&:6YL86YD)UU;)S8R+C4S,SHR-"XR,3<G72`]("=!:'1A<FDG.PHD
M8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C(N-C8W.C(Y+C8S,R==(#T@)TIO
M96YS=74G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N,#$W.C(W+C@P
M,"==(#T@)TMU;W!I;R<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,RXP
M-3`Z,C$N-S8W)UT@/2`G5F%A<V$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G
M75LG-C,N,#@S.C(U+C@V-R==(#T@)U9I:71A<V%A<FDG.PHD8V]O<F1I;F%T
M97-;)T9I;FQA;F0G75LG-C,N,3`P.C(S+C`S,R==(#T@)TMA=6AA=F$G.PHD
M8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N-S$W.C(S+C$U,"==(#T@)TMR
M=75N=7!Y>2<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-"XR.#,Z,C<N
M-C@S)UT@/2`G2V%J86%N:2<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V
M-"XY,#`Z,CDN,#$W)UT@/2`G4W5O;75S<V%L;6DG.PHD8V]O<F1I;F%T97-;
M)T9I;FQA;F0G75LG-C0N.3,S.C(U+C,V-R==(#T@)T]U;'4G.PHD8V]O<F1I
M;F%T97-;)T9I;FQA;F0G75LG-C4N,#,S.C(T+C@P,"==(#T@)TAA:6QU;W1O
M)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8U+C,V-SHR-RXP,3<G72`]
M("=0=61A<VIA<G9I)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8U+C<X
M,SHR-"XU.#,G72`]("=+96UI)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;
M)S8U+CDV-SHR.2XQ.#,G72`]("=+=75S86UO)SL*)&-O;W)D:6YA=&5S6R=&
M:6YL86YD)UU;)S8V+C4V-SHR-2XX,S,G72`]("=2;W9A;FEE;6DG.PHD8V]O
M<F1I;F%T97-;)T9I;FQA;F0G75LG-C8N.#`P.C(T+C`P,"==(#T@)U!E;&QO
M)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8W+C,V-SHR-BXV-3`G72`]
M("=3;V1A;FMY;&$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C@N-C$W
M.C(W+C0Q-R==(#T@)TEV86QO)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M+3$S+C(S,SHM,3<V+C$V-R==(#T@)TAI:&EF;R!);&4@5V%L;&ES)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG+3$T+C,Q-SHM,3<X+C$Q-R==(#T@)TUA
M;W!O;W!O($EL92!&=71U;F$G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M,2XU,#`Z.2XQ,#`G72`]("=&:6=A<FDG.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T,2XY,3<Z."XX,#`G72`]("=!:F%C8VEO)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#$N.3$W.CDN-#`P)UT@/2`G4V]L96YZ87)A)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#(N-3,S.C@N.#`P)UT@/2`G0V%L=FDG
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,BXU-3`Z.2XT.#,G72`]("="
M87-T:6$G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,BXW,S,Z,BXX-C<G
M72`]("=097)P:6=N86XG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXP
M,#`Z,2XQ,#`G72`]("=3="U':7)O;G,G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T,RXQ,#`Z-BXQ-3`G72`]("=(>65R97,G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T,RXQ.#,Z,"XP,#`G72`]("=487)B97,@+R!/<W-U;B<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C(Q-SHR+C,Q-R==(#T@)T-A
M<F-A<W-O;FYE)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N,S@S.BTP
M+C0Q-R==(#T@)U!A=2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C,X
M,SHV+C,X,R==(#T@)TQE($QU8R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0S+C0Q-SHV+C<U,"==(#T@)U-T+5)A<&AA96PG.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T,RXT-3`Z-2XR,S,G72`]("=-87)S96EL;&4@+R!-87)I
M9VYA;F4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXT-C<Z+3$N-3,S
M)UT@/2`G0FEA<G)I='HG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXU
M,#`Z-2XS-C<G72`]("=!:7@@3&5S($UI;&QE<R<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0S+C4Q-SHT+CDS,R==(#T@)TES=')E<R<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0S+C4S,SHQ+C,V-R==(#T@)U1O=6QO=7-E("\@
M1G)A;F-A>F%L)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-34P.C8N
M.34P)UT@/2`G0V%N;F5S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N
M-3@S.C,N.38W)UT@/2`G36]N='!E;&QI97(G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T,RXV,#`Z-2XQ,#`G72`]("=386QO;B<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0S+C8S,SHQ+C,V-R==(#T@)U1O=6QO=7-E("\@0FQA
M9VYA8R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C8U,#HW+C(P,"==
M(#T@)TYI8V4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXV.#,Z,"XV
M,#`G72`]("=!=6-H)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-C@S
M.BTQ+C`V-R==(#T@)T1A>"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S
M+C<U,#HT+C0Q-R==(#T@)TYI;65S("\@1V%R;VYS)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#,N.#8W.C0N-#`P)UT@/2`G3FEM97,@+R!#;W5R8F5S
M<V%C)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N.3$W.BTP+C4P,"==
M(#T@)TUO;G0M1&4M36%R<V%N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#,N.3$W.C(N,3$W)UT@/2`G06QB:2<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0T+C`V-SHV+C`P,"==(#T@)U-T+4%U8F%N+5-U<BU$=7)A;F-E)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N,3,S.C0N.#,S)UT@/2`G3W)A
M;F=E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N,3@S.C`N-C`P)UT@
M/2`G06=E;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C$X,SHR+C4Q
M-R==(#T@)T-A<W-A9VYE<RU"96=O;FAE<R<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0T+C0P,#HR+C0X,R==(#T@)U)O9&5Z)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#0N-#,S.BTQ+C(U,"==(#T@)T)I<V-A<F]S<V4G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XU,S,Z+3$N,3,S)UT@/2`G0V%Z
M875X)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N-3@S.C0N-S,S)UT@
M/2`G36]N=&5L:6UA<B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C@Q
M-SHP+C4Q-R==(#T@)T)E<F=E<F%C)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#0N.#,S.BTP+C<P,"==(#T@)T)O<F1E875X("\@365R:6=N86,G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XY,#`Z,BXT,3<G72`]("=!=7)I
M;&QA8R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C`X,SHS+C<V-R==
M(#T@)TQE(%!U>2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C$U,#HQ
M+C0V-R==(#T@)T)R:79E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N
M,C`P.C`N.#$W)UT@/2`G4&5R:6=U975X)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#4N,S8W.C4N,S,S)UT@/2`G1W)E;F]B;&4@+R!3="X@1V5O:7)S
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N-3,S.C0N,S`P)UT@/2`G
M4W0M171I96YN92!";W5T:&5O;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0U+C8U,#HU+C@X,R==(#T@)T-H86UB97)Y("\@06EX+4QE<RU"86EN<R<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C8V-SHM,"XS,3<G72`]("=#
M;V=N86,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XW,3<Z-"XY-3`G
M72`]("=,>6]N("\@0G)O;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U
M+C<S,SHU+C`X,R==(#T@)TQY;VX@+R!3871O;&%S)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#4N-S@S.C,N,38W)UT@/2`G0VQE<FUO;G0M1F5R<F%N
M9"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C@V-SHQ+C$X,R==(#T@
M)TQI;6]G97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XY.#,Z-2XS
M,S,G72`]("=!;6)E<FEE=2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V
M+C$U,#HM,2XQ-3`G72`]("=,82!2;V-H96QL92<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0V+C$V-SHS+C0P,"==(#T@)U9I8VAY)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#8N,S`P.C0N.#`P)UT@/2`G36%C;VXG.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T-BXS,3<Z+3`N-#`P)UT@/2`G3FEO<G0G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXT,3<Z-"XP,3<G72`]("=3
M86EN="U986XG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXU.#,Z,"XS
M,3<G72`]("=0;VET:65R<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V
M+C<P,#HM,2XS.#,G72`]("=,82!2;V-H92U3=7(M66]N)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#8N.#4P.C$N-S$W)UT@/2`G0VAA=&5A=7)O=7@G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXP,#`Z,RXQ,#`G72`]("=.
M979E<G,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXP-C<Z,BXS-C<G
M72`]("=";W5R9V5S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N,38W
M.BTQ+C8P,"==(#T@)TYA;G1E<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0W+C(U,#HU+CDX,R==(#T@)T)E<V%N8V]N)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#<N,C8W.C4N,#@S)UT@/2`G1&EJ;VXG.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-RXS,3<Z,2XV.#,G72`]("=2;VUO<F%N=&EN)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N,S$W.BTR+C$V-R==(#T@)U-T
M+4YA>F%I<F4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXT-3`Z,"XW
M,3<G72`]("=4;W5R<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C4P
M,#HM,"XU-C<G72`]("=!;F=E<G,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T-RXV,#`Z-RXU,3<G72`]("="86QE+4UU;&AO=7-E)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#<N-C,S.C8N.#8W)UT@/2`G0F5L9F]R="<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C<V-SHM,RXT-3`G72`]("=,86YN
M($)I:&]U92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C<X,SHV+C,U
M,"==(#T@)TQU>&5U:6PG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXX
M,#`Z,RXU-3`G72`]("=!=7AE<G)E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#<N.#4P.C0N-34P)UT@/2`G0VAA=&EL;&]N+5-U<BU396EN92<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+CDQ-SHW+C0P,"==(#T@)T-O;&UA
M<B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+CDS,SHP+C(P,"==(#T@
M)TQE($UA;G,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXY-C<Z+30N
M,38W)UT@/2`G475I;7!E<B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W
M+CDX,SHQ+C<U,"==(#T@)T]R;&5A;G,G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T."XP-3`Z,2XS.#,G72`]("=#:&%T96%U9'5N)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#@N,#8W.BTQ+C<S,R==(#T@)U)E;FYE<R<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C(X,SHM-"XT,S,G72`]("=,86YV
M96]C(%!O=6QM:6,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XS,S,Z
M-"XP,3<G72`]("=4<F]Y97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M."XT-3`Z,"XQ,3<G72`]("=!;&5N8V]N)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#@N-#4P.BTT+C0Q-R==(#T@)T)R97-T)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#@N-#8W.C$N-3$W)UT@/2`G0VAA<G1R97,G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T."XU,3<Z+30N,34P)UT@/2`G3&%N9&EV
M:7-I874G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XU,S,Z+3(N.#4P
M)UT@/2`G4V%I;G0M0G)I975C)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#@N-34P.C<N-C,S)UT@/2`G4W1R87-B;W5R9R<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0X+C4X,SHM,BXP-C<G72`]("=$:6YA<F0G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XU.#,Z-2XY-C<G72`]("=.86YC>2`O($]C
M:&5Y)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-C$W.C(N-C@S)UT@
M/2`G365L=6XG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XV,S,Z-"XY
M,#`G72`]("=3="U$:7II97(G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M."XV.#,Z-BXR,3<G72`]("=.86YC>2`O($5S<V5Y)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#@N-S,S.C(N-#`P)UT@/2`G4&%R:7,M3W)L>2<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C<V-SHQ+C$P,"==(#T@)U1O=7-S
M=7,@3&4@3F]B;&4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XW-C<Z
M,BXR,#`G72`]("=6:6QL86-O=6)L87DG.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T."XW.#,Z-2XT.#,G72`]("=4;W5L("\@4F]S:65R97,G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T."XY-C<Z,BXT-3`G72`]("=087)I<R`O
M($QE($)O=7)G970G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XY.#,Z
M-BXR-3`G72`]("=-971Z+4YA;F-Y+4QO<G)A:6YE)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#DN,#$W.C$N,C$W)UT@/2`G179R975X)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#DN,#$W.C(N-3,S)UT@/2`G4&%R:7,M065R
M;W!O<G0@0VAA<FQE<R!$92!'875L;&4G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T.2XP.#,Z-BXQ,S,G72`]("=-971Z("\@1G)E<V-A='DG.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T.2XQ.#,Z+3`N-#4P)UT@/2`G0V%E;B<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C(U,#HR+C4Q-R==(#T@)T-R
M96EL($9A9F(G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XS,#`Z-"XP
M,S,G72`]("=296EM<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C,X
M,SHQ+C$X,R==(#T@)U)O=65N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#DN-#8W.C(N,3$W)UT@/2`G0F5A=79A:7,G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T.2XU,3<Z,"XP-C<G72`]("=,82!(979E)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#DN-C4P.BTQ+C0V-R==(#T@)T-H97)B;W5R9R`O
M($UA=7!E<G1U<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C<X,SHT
M+C8S,R==(#T@)T-H87)L979I;&QE)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#DN.#$W.C,N,C`P)UT@/2`G4V%I;G0M475E;G1I;B<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0Y+C@S,SHP+C8U,"==(#T@)U9I='1E9FQE=7(@
M+R!3="X@5F%L92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S4P+C$S,SHQ
M+C@S,R==(#T@)T%B8F5V:6QL92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S4P+C(Q-SHS+C$U,"==(#T@)T-A;6)R86DG.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<U,"XU,3<Z,2XV,3<G72`]("=,92!4;W5Q=65T)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-3`N-38W.C,N,3`P)UT@/2`G3&EL;&4G.PHD
M8V]O<F1I;F%T97-;)T9R96YC:"!'=6EA;F$G75LG-"XX,S,Z+34R+C,V-R==
M(#T@)T-A>65N;F4@+R!2;V-H86UB96%U)SL*)&-O;W)D:6YA=&5S6R=&<F5N
M8V@@1W5I86YA)UU;)S4N-3`P.BTU-"XP,S,G72`]("=386EN="U,875R96YT
M+41U+4UA<F]N:2<["B1C;V]R9&EN871E<ULG1G)E;F-H(%!O;'EN97-I82==
M6R<M,30N.38W.BTQ-#<N-C8W)UT@/2`G4F%N9VER;V$@+R!4=6%M;W1O($ES
M;&%N9"<["B1C;V]R9&EN871E<ULG1G)E;F-H(%!O;'EN97-I82==6R<M,38N
M-#4P.BTQ-3$N-S4P)UT@/2`G0F]R82U";W)A)SL*)&-O;W)D:6YA=&5S6R=&
M<F5N8V@@4&]L>6YE<VEA)UU;)RTQ-RXU-3`Z+3$T.2XV,3<G72`]("=486AI
M=&DM1F%A82<["B1C;V]R9&EN871E<ULG1G)E;F-H(%!O;'EN97-I82==6R<M
M,3@N,#8W.BTQ-#`N.34P)UT@/2`G2&%O)SL*)&-O;W)D:6YA=&5S6R=&<F5N
M8V@@4&]L>6YE<VEA)UU;)RTR,2XX,3<Z+3$S."XX,#`G72`]("=-=7)U<F]A
M)SL*)&-O;W)D:6YA=&5S6R=&<F5N8V@@4&]L>6YE<VEA)UU;)RTR,RXS-3`Z
M+3$T.2XT.#,G72`]("=4=6)U86DG.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;
M)S`N-#4P.CDN-#$W)UT@/2`G3&EB<F5V:6QL92<["B1C;V]R9&EN871E<ULG
M1V%B;VXG75LG,"XU-C<Z,3(N.#8W)UT@/2`G36%K;VMO=2<["B1C;V]R9&EN
M871E<ULG1V%B;VXG75LG+3`N-S`P.C@N-S4P)UT@/2`G4&]R="U'96YT:6PG
M.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)RTP+C<Q-SHQ,"XR,S,G72`]("=,
M86UB87)E;F4G.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)S`N-S@S.C$Q+C4S
M,R==(#T@)TUI='II8R<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG+3`N.#,S
M.C$R+C<Q-R==(#T@)TQA<W1O=7)S=FEL;&4G.PHD8V]O<F1I;F%T97-;)T=A
M8F]N)UU;)S$N,#`P.CDN-C`P)UT@/2`G0V]C;V)E86-H)SL*)&-O;W)D:6YA
M=&5S6R='86)O;B==6R<Q+C`Q-SHQ,RXY,S,G72`]("=-96MA;6)O)SL*)&-O
M;W)D:6YA=&5S6R='86)O;B==6R<M,2XU,S,Z,3,N,C8W)UT@/2`G36]A;F1A
M)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<M,2XX-C<Z,3$N,#$W)UT@/2`G
M36]U:6QA)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<R+C`X,SHQ,2XT.#,G
M72`]("=":71A;2<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG+3(N.#4P.C$Q
M+C`Q-R==(#T@)U1C:&EB86YG82<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG
M+3,N-#$W.C$P+C8U,"==(#T@)TUA>75M8F$G.PHD8V]O<F1I;F%T97-;)T=A
M;6)I82==6R<Q,RXS-3`Z+3$V+C@P,"==(#T@)T)A;FIU;"`O(%EU;F1U;2<[
M"B1C;V]R9&EN871E<ULG1V5O<F=I82==6R<T,2XV.#,Z-#0N.34P)UT@/2`G
M5&)I;&ES:2<["B1C;V]R9&EN871E<ULG1V5O<F=I82==6R<T,2XY,S,Z-#0N
M-3@S)UT@/2`G375H<F%N:2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T
M-RXV-C<Z.2XU,3<G72`]("=&<FEE9')I8VAS:&%F96XG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-#<N-C@S.CDN,3@S)UT@/2`G2V]N<W1A;GHG.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N.#,S.C$P+C@V-R==(#T@)T%L
M=&5N<W1A9'0G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N.38W.C@N
M-3$W)UT@/2`G1&]N875E<V-H:6YG96X@+R!6:6QL:6YG96XG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-#<N.3@S.C$P+C(S,R==(#T@)TUE;6UI;F=E
M;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XP-C<Z,3`N.3`P)UT@
M/2`G3&%N9'-B97)G)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0X+C$S
M,SHQ,2XW,#`G72`]("=-=6YI8V@@+R!2:65M)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S0X+C$X,SHQ,"XX-C<G72`]("=,96-H9F5L9"<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<T."XQ.#,Z.2XP,#`G72`]("=-97-S<W1E
M='1E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XR,#`Z,3$N,C8W
M)UT@/2`G1G5E<G-T96YF96QD8G)U8VLG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-#@N,C$W.CDN.3$W)UT@/2`G3&%U<&AE:6TG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-#@N,S$W.C$Q+CDU,"==(#T@)T5R9&EN9R<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XT,S,Z,3`N.3,S)UT@/2`G075G
M<V)U<F<G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N-C@S.CDN,C$W
M)UT@/2`G4W1U='1G87)T+45C:'1E<F1I;F=E;B<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<T."XW,3<Z,3$N,C$W)UT@/2`G3F5U8G5R9R`O($1O;F%U
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0X+C<Q-SHQ,2XU,S,G72`]
M("=);F=O;'-T861T)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C(Q
M-SHQ,2XQ,#`G72`]("=2;W1H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S0Y+C(Q-SHQ,2XX,S,G72`]("=(;VAE;F9E;',G.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-#DN,C$W.C<N,3$W)UT@/2`G4V%A<F)R=65C:V5N("\@
M16YS:&5I;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XS,3<Z,3`N
M-C,S)UT@/2`G06YS8F%C:"`O($MA='1E<F)A8V@G.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-#DN-#`P.C@N-C4P)UT@/2`G2&5I9&5L8F5R9R<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XT,#`Z.2XY-C<G72`]("=.:65D
M97)S=&5T=&5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C0S,SHQ
M,2XY,#`G72`]("=+=65M;65R<W)U8VLG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-#DN-#,S.C<N-C`P)UT@/2`G4F%M<W1E:6XG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-#DN-#8W.C$P+C,X,R==(#T@)TEL;&5S:&5I;2<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XT-S,Z."XU,38G72`]("="
M861E;B!7=7)T=&5M8F5R9RP@3F5U;W-T:&5I;2<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<T.2XU,#`Z,3$N,#4P)UT@/2`G3G5E<FYB97)G)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C4P,#HW+C@V-R==(#T@)U-E;6)A
M8V@@56YI=&5D(%-T871E<R!!:7(@1F]R8V4@3W!E<F%T960@0F%S92!);B!&
M;W)E:6=N($-O=6YT<GDG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN
M-38W.C@N-#8W)UT@/2`G0V]L96UA;B!-86YN:&5I;2<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<T.2XV-3`Z.2XY-C<G72`]("=':65B96QS=&%D="<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XW,#`Z,3$N.34P)UT@/2`G
M1W)A9F5N=V]E:'(G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-S`P
M.C<N,S,S)UT@/2`G261A<BU/8F5R<W1E:6XG.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-#DN-S4P.C$P+C(P,"==(#T@)TMI='II;F=E;B!5<V$@7"!!
M9B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XX-3`Z-RXV,#`G72`]
M("=09F5R9'-F96QD)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C@U
M,#HW+C@X,R==(#T@)T)A9"!+<F5U>FYA8V@G.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-#DN.34P.C<N,C8W)UT@/2`G2&%H;B<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<T.2XY.#,Z,3$N-C,S)UT@/2`G0F%Y<F5U=&@G.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN.3@S.C8N-S`P)UT@/2`G4W!A
M;F=D86AL96TG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N,#4P.C@N
M,S,S)UT@/2`G5VEE<V)A9&5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4P+C`U,#HX+C8P,"==(#T@)T9R86YK9G5R="`O($TM1FQU9VAA9F5N)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C$V-SHW+C`V-R==(#T@)T)U
M96-H96PG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N,38W.C@N.38W
M)UT@/2`G2&%N874G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N,S$W
M.C$Q+C@X,R==(#T@)TAO9B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U
M,"XS-C<Z-RXS,3<G72`]("=-96YD:6<G.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-3`N.#$W.C8N,3@S)UT@/2`G06%C:&5N("\@365R>F)R=6-K)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C@S,SHV+C8V-R==(#T@)TYO
M97)V96YI8V@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N.#8W.C<N
M,38W)UT@/2`G2V]E;&X@+R!";VYN)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4P+CDV-SHV+C`U,"==(#T@)T=E:6QE;FMI<F-H96XG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3`N.3@S.C$P+CDV-R==(#T@)T5R9G5R="U"
M:6YD97)S;&5B96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N,3$W
M.CDN,C@S)UT@/2`G1G)I='IL87(G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-3$N,3,S.C$S+C<U,"==(#T@)T1R97-D96XM2VQO='IS8VAE)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C(P,#HV+C$S,R==(#T@)T)R=65G
M9V5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C,P,#HV+C<V-R==
M(#T@)T1U97-S96QD;W)F)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q
M+C0P,#HV+CDV-R==(#T@)T5S<V5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4Q+C0P,#HY+C,X,R==(#T@)TMA<W-E;"`O($-A;&1E;B<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<U,2XT,3<Z,3(N,C,S)UT@/2`G3&5I<'II
M9RU38VAK975D:71Z)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C4Q
M-SHW+C8Q-R==(#T@)T1O<G1M=6YD("\@5VEC:V5D92<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<U,2XV,#`Z-BXQ-3`G72`]("=,86%R8G)U8V@G.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N-C$W.C@N-C$W)UT@/2`G4&%D
M97)B;W)N("\@3&EP<'-T861T)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4Q+C8V-SHQ-"XV,S,G72`]("=0<F5S8VAE;B<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<U,2XW,S,Z-BXR-C<G72`]("=+86QK87(G.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3$N-S8W.C$S+C$X,R==(#T@)TAO;'ID;W)F
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C<V-SHQ-"XS,#`G72`]
M("=#;W1T8G5S($9L=6=P;&%T>B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<U,2XY,3<Z."XS,#`G72`]("='=65T97)S;&]H)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4R+C$S,SHW+C<P,"==(#T@)TUU96YS=&5R("\@3W-N
M86)R=65C:R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXR.#,Z.2XP
M.#,G72`]("="=65C:V5B=7)G)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4R+C,P,#HQ,"XT-3`G72`]("="<F%U;G-C:'=E:6<G.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-3(N,S`P.C<N,S@S)UT@/2`G4FAE:6YE+4)E;G1L
M86=E)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C,S,SHW+C4S,R==
M(#T@)TAO<'-T96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N,S@S
M.C$S+C4Q-R==(#T@)T)E<FQI;BU38VAO96YE9F5L9"<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<U,BXT-3`Z-RXQ-C<G72`]("=.;W)D:&]R;B<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXT-3`Z.2XT,S,G72`]("=7=6YS
M=&]R9B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXT-C<Z,3,N-#`P
M)UT@/2`G0F5R;&EN+51E;7!E;&AO9B<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<U,BXT-C<Z.2XV.#,G72`]("=(86YN;W9E<B<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<U,BXU-C<Z,3,N,S$W)UT@/2`G0F5R;&EN+51E9V5L
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C4X,SHX+C,U,"==(#T@
M)T1I97!H;VQZ)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C8P,#HQ
M,"XP,3<G72`]("=#96QL92<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U
M,BXX,3<Z.2XY,S,G72`]("="97)G96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-3(N.3$W.C$P+C$X,R==(#T@)T9A<W-B97)G)SL*)&-O;W)D:6YA
M=&5S6R='97)M86YY)UU;)S4S+C`U,#HX+C@P,"==(#T@)T)R96UE;B<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXR,#`Z,3(N-3$W)UT@/2`G5VET
M='-T;V-K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C0R-SHQ,2XW
M.#0G72`]("=-96-K;&5N8G5R9RU6;W)P;VUM97)N+"!087)C:&EM)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C4S,SHW+C@X,R==(#T@)TIE=F5R
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C4S,SHY+C@S,R==(#T@
M)TAA;6)U<F<M1FEN:V5N=V5R9&5R)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4S+C4U,#HW+C8V-R==(#T@)U=I='1M=6YD:&%V96XG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3,N-C`P.C$S+C,Q-R==(#T@)U1R;VQL96YH
M86=E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXV,S,Z,3`N,#`P
M)UT@/2`G2&%M8G5R9RU&=6AL<V)U971T96PG.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-3,N-S8W.C@N-C8W)UT@/2`G3F]R9&AO;'HG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3,N.#$W.C$P+C<P,"==(#T@)TQU96)E8VLM
M0FQA;FME;G-E92<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXY,3<Z
M,3(N,C@S)UT@/2`G3&%A9V4G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG
M-30N,#`P.CDN-3@S)UT@/2`G271Z96AO92<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U-"XS,3<Z.2XU,S,G72`]("=(;VAN)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4T+C,X,SHQ,"XQ-3`G72`]("=+:65L+4AO;'1E;F%U
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+C0V-SHY+C4Q-R==(#T@
M)U-C:&QE<W=I9RU*86=E;"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U
M-"XV,S,Z.2XS-3`G72`]("=%9V=E8F5K)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S4T+C@S,SHY+C4P,"==(#T@)T=L=65C:W-B=7)G("\@365I97)W
M:6LG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-30N.3$W.C@N,S4P)UT@
M/2`G5V5S=&5R;&%N9"`O(%-Y;'0G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;
M)S$P+C`U,#HM,BXU,#`G72`]("=782<["B1C;V]R9&EN871E<ULG1VAA;F$G
M75LG,3`N.3`P.BTQ+C$P,"==(#T@)TYA=G)O;F=O)SL*)&-O;W)D:6YA=&5S
M6R=':&%N82==6R<T+C@V-SHM,BXR,S,G72`]("=!>&EM)SL*)&-O;W)D:6YA
M=&5S6R=':&%N82==6R<T+C@X,SHM,2XW-C<G72`]("=486MO<F%D:2<["B1C
M;V]R9&EN871E<ULG1VAA;F$G75LG-2XR,#`Z+3$N,#8W)UT@/2`G4V%L='!O
M;F0G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S4N-C`P.BTP+C$V-R==(#T@
M)T%C8W)A)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<U+C8Q-SHP+C`P,"==
M(#T@)U1E;6$G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S4N-S@S.C`N-C,S
M)UT@/2`G061A)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<U+CDS,SHM,"XY
M.#,G72`]("=!:VEM($]D82<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-BXP
M.#,Z+3`N,C4P)UT@/2`G2V]F;W)I9'5A)SL*)&-O;W)D:6YA=&5S6R=':&%N
M82==6R<V+C$P,#HP+C$Q-R==(#T@)T%K=7-E)SL*)&-O;W)D:6YA=&5S6R='
M:&%N82==6R<V+C(P,#HM,BXS,S,G72`]("=3969W:2!"96MW86DG.PHD8V]O
M<F1I;F%T97-;)T=H86YA)UU;)S8N-C`P.C`N-#8W)UT@/2`G2&\G.PHD8V]O
M<F1I;F%T97-;)T=H86YA)UU;)S8N-S$W.BTQ+C8P,"==(#T@)TMU;6%S:2<[
M"B1C;V]R9&EN871E<ULG1VAA;F$G75LG-RXS,S,Z+3(N,S,S)UT@/2`G4W5N
M>6%N:2<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-RXW-3`Z+3(N,3`P)UT@
M/2`G5V5N8VAI)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<Y+C`S,SHM,BXT
M.#,G72`]("=";VQE)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<Y+C0U,#HM
M,"XP,3<G72`]("=996YD:2<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG.2XU
M,#`Z+3`N.#4P)UT@/2`G5&%M86QE)SL*)&-O;W)D:6YA=&5S6R=':6)R86QT
M87(G75LG,S8N,34P.BTU+C,U,"==(#T@)T=I8G)A;'1A<B<["B1C;V]R9&EN
M871E<ULG1W)E96-E)UU;)S,U+C,S,SHR-2XQ.#,G72`]("=(97)A:VQI;VX@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,U+C0Q-#HR-RXQ
M-#@G72`]("=+87)P871H;W,@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E
M96-E)UU;)S,U+C0X,SHR-"XQ,3<G72`]("=3;W5D82!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R='<F5E8V4G75LG,S8N-#`P.C(X+C`X,R==(#T@)U)H;V1E
M<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S8N-S@S.C(W
M+C`V-R==(#T@)TMO<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G
M75LG,S<N,#8W.C(R+C`Q-R==(#T@)TMA;&%M871A($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T=R965C92==6R<S-RXU,S,Z,C(N-#`P)UT@/2`G5')I<&]L
M:7,@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,W+C<P,#HR
M-BXY,3<G72`]("=386UO<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E
M8V4G75LG,S<N.3`P.C(S+C<S,R==(#T@)T%T:&EN86D@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG1W)E96-E)UU;)S,W+CDQ-SHR,2XR.#,G72`]("=!;F1R
M879I9&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,X+C`V
M-SHR,RXU-3`G72`]("=%;&5F<VES($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)T=R965C92==6R<S."XQ,#`Z,C,N-S@S)UT@/2`G5&%T;VDG.PHD8V]O<F1I
M;F%T97-;)T=R965C92==6R<S."XQ,3<Z,C`N-3`P)UT@/2`G2V5F86QH;FEA
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XQ-3`Z,C$N
M-#$W)UT@/2`G07)A>&]S($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C
M92==6R<S."XS,3<Z,C,N-3,S)UT@/2`G5&%N86=R82!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R='<F5E8V4G75LG,S@N,S,S.C(V+C$S,R==(#T@)T-H:6]S
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XV,3<Z,C`N
M-S8W)UT@/2`G06MT:6]N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C
M92==6R<S.2XP-C<Z,C8N-C`P)UT@/2`G37ET:6QI;FD@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG1W)E96-E)UU;)S,Y+C(Q-SHR,BXX,#`G72`]("=!;F-H
M:6%L;W,@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,Y+C8Q
M-SHQ.2XY,3<G72`]("=+97)K>7)A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)T=R965C92==6R<S.2XV,S,Z,C(N-#$W)UT@/2`G3&%R:7-S82!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,SDN.3$W.C(U+C(S,R==(#T@
M)TQI;6YO<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG-#`N
M,S`P.C(Q+C<X,R==(#T@)TMO>F%N:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R='<F5E8V4G75LG-#`N-#4P.C(Q+C(X,R==(#T@)TMA<W1O<FEA($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<T,"XU,3<Z,C(N.38W)UT@
M/2`G5&AE<W-A;&]N:6MI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C
M92==6R<T,"XX-3`Z,C4N.3$W)UT@/2`G06QE>&%N9')O=7!O;&D@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S0P+CDX,SHR-"XV,#`G72`]
M("=#:')Y<V]U<&]L:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA
M;F0G75LG-3DN.3@S.BTT-2XR,#`G72`]("=!;F=I<V]Q)SL*)&-O;W)D:6YA
M=&5S6R='<F5E;FQA;F0G75LG-C`N,#4P.BTT,RXQ-C<G72`]("=0<FEN<R!#
M:')I<W1I86X@4W5N9"<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8P
M+C<Q-SHM-#8N,#4P)UT@/2`G2G5L:6%N96AA86(G.PHD8V]O<F1I;F%T97-;
M)T=R965N;&%N9"==6R<V,2XQ-C<Z+30U+C0Q-R==(#T@)TYA<G-A<G-U87$G
M.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V,2XR,S,Z+30X+C$P,"==
M(#T@)T=R;V5N;F5D86PG.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V
M,BXP,#`Z+30Y+C8V-R==(#T@)T9R961E<FEK<VAA86(G.PHD8V]O<F1I;F%T
M97-;)T=R965N;&%N9"==6R<V-"XQ-C<Z+34Q+C<U,"==(#T@)T=O9'1H86%B
M("\@3G5U:R<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8U+C4X,SHM
M,S<N,34P)UT@/2`G2W5L=7-U:R!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG
M1W)E96YL86YD)UU;)S8U+C8P,#HM,S<N-C,S)UT@/2`G5&%S:6EL87$G.PHD
M8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V-BXY,3<Z+34S+C8V-R==(#T@
M)TAO;'-T96EN<V)O<F<G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V
M-RXP,3<Z+34P+C<P,"==(#T@)U-D<B!3=')O96UF:F]R9"<["B1C;V]R9&EN
M871E<ULG1W)E96YL86YD)UU;)S8W+C<X,SHM,S(N,S`P)UT@/2`G07!U=&ET
M965Q)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C@N-S`P.BTU,BXW
M-3`G72`]("=%9V5D97-M:6YD92<["B1C;V]R9&EN871E<ULG1W)E96YL86YD
M)UU;)S8Y+C(S,SHM-3$N,#8W)UT@/2`G2F%C;V)S:&%V;B!,=69T:&%V;B<[
M"B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S<P+C0Q-SHM,C$N.38W)UT@
M/2`G0V%P92!4;V)I;B!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD
M8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<W,"XT.#,Z+3(Q+CDU,"==(#T@
M)U-C;W)E<V)Y<W5N9"<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S<P
M+C<U,#HM,C(N-C4P)UT@/2`G0V]N<W1A8FQE(%!Y;G0G.PHD8V]O<F1I;F%T
M97-;)T=R965N;&%N9"==6R<W-"XS,#`Z+3(P+C(Q-R==(#T@)T1A;F5B;W)G
M)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-S8N-3,S.BTV."XW-3`G
M72`]("=4:'5L92!!+B!"+B<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;
M)S<V+C<V-SHM,3@N-C8W)UT@/2`G1&%N;6%R:W-H879N)SL*)&-O;W)D:6YA
M=&5S6R='<F5N861A)UU;)S$R+C`P,#HM-C$N-S@S)UT@/2`G4&]I;G0@4V%L
M:6YE<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='=6%D96QO=7!E)UU;)S$V
M+C(V-SHM-C$N-3$W)UT@/2`G3&4@4F%I>F5T+"!'=6%D96QO=7!E)SL*)&-O
M;W)D:6YA=&5S6R='=6%D96QO=7!E)UU;)S$W+CDP,#HM-C(N.#4P)UT@/2`G
M1W5S=&%V:6$L(%-A:6YT($)A<G1H96QE;7DG.PHD8V]O<F1I;F%T97-;)T=U
M871E;6%L82==6R<Q,RXY,3<Z+3DP+C@Q-R==(#T@)U-A;B!*;W-E)SL*)&-O
M;W)D:6YA=&5S6R='=6%T96UA;&$G75LG,30N-3,S.BTY,2XV-C<G72`]("=2
M971A;&AU;&5U)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA;&$G75LG,30N-3@S
M.BTY,"XU,3<G72`]("='=6%T96UA;&$@065R;W!U97)T;VQA($%U<F]R82<[
M"B1C;V]R9&EN871E<ULG1W5A=&5M86QA)UU;)S$U+C,Q-SHM.3$N-#8W)UT@
M/2`G2'5E:'5E=&5N86YG;R<["B1C;V]R9&EN871E<ULG1W5A=&5M86QA)UU;
M)S$U+C0V-SHM.3`N,S$W)UT@/2`G0V]B86XG.PHD8V]O<F1I;F%T97-;)T=U
M871E;6%L82==6R<Q-2XW,3<Z+3@X+C8P,"==(#T@)U!U97)T;R!"87)R:6]S
M)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA;&$G75LG,38N.3$W.BTX.2XX.#,G
M72`]("=&;&]R97,G.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q,"XP,S,Z
M+3$P+C<U,"==(#T@)T9A<F%N86@@+R!"861A;&$G.PHD8V]O<F1I;F%T97-;
M)T=U:6YE82==6R<Q,"XP-3`Z+3$R+C@V-R==(#T@)TMI;F1I82<["B1C;V]R
M9&EN871E<ULG1W5I;F5A)UU;)S$P+C,X,SHM.2XS,#`G72`]("=+86YK86XG
M.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q,"XY,S,Z+3$T+C,Q-R==(#T@
M)T)O:V4G.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q,2XS,3<Z+3$R+C,P
M,"==(#T@)TQA8F4G.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q,2XT,S,Z
M+3DN,38W)UT@/2`G4VEG=6ER:2<["B1C;V]R9&EN871E<ULG1W5I;F5A)UU;
M)S<N-S,S.BTX+C@S,R==(#T@)TY<)UIE<F5K;W)E)SL*)&-O;W)D:6YA=&5S
M6R='=6EN96$G75LG."XU,S,Z+3DN-#8W)UT@/2`G36%C96YT82<["B1C;V]R
M9&EN871E<ULG1W5I;F5A)UU;)SDN,3@S.BTQ,"XQ,#`G72`]("=+:7-S:61O
M=6=O=2<["B1C;V]R9&EN871E<ULG1W5I;F5A)UU;)SDN-38W.BTQ,RXV,3<G
M72`]("=#;VYA:W)Y("\@1V)E<W-I82<["B1C;V]R9&EN871E<ULG1W5I;F5A
M+4)I<W-A=2==6R<Q,2XX.#,Z+3$U+C8U,"==(#T@)T)I<W-A=2!!97)O<&]R
M="<["B1C;V]R9&EN871E<ULG1W5I;F5A+4)I<W-A=2==6R<Q,BXQ-C<Z+3$T
M+C8V-R==(#T@)T)A9F%T82<["B1C;V]R9&EN871E<ULG1W5Y86YA)UU;)S8N
M-3`P.BTU."XR-3`G72`]("=4:6UE:')I($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T=U>6%N82==6R<V+C@P,#HM-3@N,34P)UT@/2`G1V5O<F=E=&]W;B<[
M"B1C;V]R9&EN871E<ULG2&%I=&DG75LG,3@N-38W.BTW,BXS,#`G72`]("=0
M;W)T+4%U+5!R:6YC92`O($%E<F]P;W)T($EN=&5R;F%T:6]N86PG.PHD8V]O
M<F1I;F%T97-;)TAA:71I)UU;)S$Y+C<U,#HM-S(N,3@S)UT@/2`G0V%P+4AA
M:71I96XG.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$S+C(V-SHM.#<N
M-C4P)UT@/2`G06UA<&%L82<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG
M,3,N,S`P.BTX-RXQ.#,G72`]("=#:&]L=71E8V$G.PHD8V]O<F1I;F%T97-;
M)TAO;F1U<F%S)UU;)S$T+C`U,#HM.#<N,C$W)UT@/2`G5&5G=6-I9V%L<&$G
M.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$T+C,Q-SHM.#@N,34P)UT@
M/2`G3&$@17-P97)A;GIA)SL*)&-O;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q
M-"XS.#,Z+3@W+C8Q-R==(#T@)T-O<F]N96P@16YR:7%U92!3;W1O($-A;F\@
M06ER($)A<V4G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$T+C<X,SHM
M.#@N-S@S)UT@/2`G4V%N=&$@4F]S82!$92!#;W!A;B<["B1C;V]R9&EN871E
M<ULG2&]N9'5R87,G75LG,30N.3`P.BTX-2XY,S,G72`]("=#871A8V%M87,G
M.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$U+C$V-SHM.#<N,3$W)UT@
M/2`G66]R;R<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,34N,C$W.BTX
M,RXX,#`G72`]("=0=65R=&\@3&5M<&ER82<["B1C;V]R9&EN871E<ULG2&]N
M9'5R87,G75LG,34N-#4P.BTX-RXY,S,G72`]("=,82!-97-A(%-A;B!0961R
M;R!3=6QA)SL*)&-O;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-2XW,3<Z+3@W
M+C0X,R==(#T@)U1E;&$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$U
M+C<S,SHM.#8N.#8W)UT@/2`G3&$@0V5I8F$@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG2&]N9'5R87,G75LG,38N,S$W.BTX-BXU,3<G72`]("=2;V%T86XG
M.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$V+C0V-SHM.#8N,#8W)UT@
M/2`G1W5A;F%J82<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,3<N-#`P
M.BTX,RXY,S,G72`]("=)<VQA<R!$96P@0VES;F4G.PHD8V]O<F1I;F%T97-;
M)TAO;F<@2V]N9R==6R<R,BXR,#`Z,3$T+C`Q-R==(#T@)T-H975N9R!#:&%U
M)SL*)&-O;W)D:6YA=&5S6R=(;VYG($MO;F<G75LG,C(N,S,S.C$Q-"XQ.#,G
M72`]("=(;VYG($MO;F<@26YT97(M3F%T:6]N86P@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG2'5N9V%R>2==6R<T-BXQ,#`Z,3@N,C,S)UT@/2`G4&5C<R`O
M(%!O9V%N>2<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXR-3`Z,C`N
M,3`P)UT@/2`G4WIE9V5D)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0V
M+C,X,SHQ-RXX,S,G72`]("=+87!O<W9A<B<["B1C;V]R9&EN871E<ULG2'5N
M9V%R>2==6R<T-BXV.#,Z,C$N,38W)UT@/2`G0F5K97-C<V%B82<["B1C;V]R
M9&EN871E<ULG2'5N9V%R>2==6R<T-BXY,3<Z,3@N,#4P)UT@/2`G4VEO9F]K
M)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0V+CDQ-SHQ.2XW-3`G72`]
M("=+96-S:V5M970G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#<N,3$W
M.C(P+C(S,R==(#T@)U-Z;VQN;VLG.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG
M75LG-#<N,C`P.C$W+C4P,"==(#T@)U!A<&$G.PHD8V]O<F1I;F%T97-;)TAU
M;F=A<GDG75LG-#<N,C8W.C$V+C8S,R==(#T@)U-Z;VUB871H96QY)SL*)&-O
M;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C0S,SHQ.2XR-C<G72`]("="=61A
M<&5S="`O($9E<FEH96=Y)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W
M+C0U,#HQ."XY-C<G72`]("="=61A;W)S)SL*)&-O;W)D:6YA=&5S6R=(=6YG
M87)Y)UU;)S0W+C0X,SHR,2XV,#`G72`]("=$96)R96-E;B<["B1C;V]R9&EN
M871E<ULG2'5N9V%R>2==6R<T-RXU,3<Z,3DN,#,S)UT@/2`G0G5D87!E<W0@
M365T($-E;G1E<B<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-RXY-C<Z
M,C$N.3@S)UT@/2`G3GEI<F5G>6AA>F$@+R!.87!K;W(G.PHD8V]O<F1I;F%T
M97-;)TAU;F=A<GDG75LG-#@N,#@S.C(P+C<V-R==(#T@)TUI<VMO;&,G.PHD
M8V]O<F1I;F%T97-;)TEC96QA;F0G75LG-C,N-#`P.BTR,"XR.#,G72`]("=6
M97-T;6%N;F%E>6IA<B<["B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V,RXY
M-C<Z+3(R+C8P,"==(#T@)TME9FQA=FEK=7)F;'5G=F]L;'5R)SL*)&-O;W)D
M:6YA=&5S6R=)8V5L86YD)UU;)S8T+C$S,SHM,C$N.3`P)UT@/2`G4F5Y:VIA
M=FEK)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD)UU;)S8T+C,P,#HM,34N,C$W
M)UT@/2`G06MU<FYE<R<["B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V-2XP
M.#,Z+3(R+C<S,R==(#T@)U-T>6MK:7-H;VQM=7(G.PHD8V]O<F1I;F%T97-;
M)TEC96QA;F0G75LG-C4N,C@S.BTQ-"XT,#`G72`]("=%9VEL<W-T861I<B<[
M"B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V-2XV.#,Z+3$X+C`X,R==(#T@
M)T%K=7)E>7)I)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD)UU;)S8U+C<P,#HM
M,30N.#$W)UT@/2`G4VMJ86QD=&AI;F=S<W1A9&ER)SL*)&-O;W)D:6YA=&5S
M6R=)8V5L86YD)UU;)S8V+C0U,#HM,34N.34P)UT@/2`G4F%U9F%R:&]F;B<[
M"B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V-BXU,S,Z+3$X+C`Q-R==(#T@
M)T=R:6US97DG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$P+C<V-SHW."XW
M,3<G72`]("=4:7)U8VAC:&ER87!A;&QI)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<Q,2XP,S,Z-S<N,#4P)UT@/2`G0V]I;6)A=&]R92`O(%!E96QA;65D
M=2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,3$N-C8W.CDR+C<Q-R==(#T@
M)U!O<G0@0FQA:7(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$R+CDQ-SHW
M-"XX.#,G72`]("=-86YG86QO<F4@+R!"86IP92<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG,3(N.3$W.C<Y+C$U,"==(#T@)U9E;&QO<F4G.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S$S+C`P,#HX,"XQ.#,G72`]("=-861R87,@+R!-
M:6YA;6)A:VMA;2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,30N-#@S.C<X
M+C@S,R==(#T@)T-U9&1A<&%H)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q
M-2XQ-3`Z-S8N.#4P)UT@/2`G0F5L;&%R>2<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,34N,S@S.C<S+C@Q-R==(#T@)T=O82`O($1A8F]L:6T@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,34N.#4P.C<T+C8Q-R==(#T@
M)T)E;&=A=6T@+R!386UB<F$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$V
M+C4S,SHX,"XX,#`G72`]("=6:6IA>6%W861A("\@1V%N;F%V87)A;2<["B1C
M;V]R9&EN871E<ULG26YD:6$G75LG,38N-S`P.C<T+C(S,R==(#T@)TMO;&AA
M<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q-RXT-3`Z-S@N-#8W)UT@
M/2`G2'ED97)A8F%D($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;
M)S$W+C8V-SHW-2XY,#`G72`]("=3:&]L87!U<B<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG,3DN,3$W.C<R+C@U,"==(#T@)T)O;6)A>2`O(%-A;G1A8W)U
M>B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,3DN.#4P.C<U+C0P,"==(#T@
M)T%U<F%N9V%B860@0VAI:V%L=&AA;B!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)TEN9&EA)UU;)S(P+C(U,#HX-2XX,S,G72`]("=":'5B86YE<W=A<B<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C`N-S`P.C<W+C`V-R==(#T@)T%K
M;VQA)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,2XQ,#`Z-SDN,#4P)UT@
M/2`G3F%G<'5R(%-O;F5G86]N)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M,2XW-3`Z-S(N,C`P)UT@/2`G0FAA=6YA9V%R)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<R,2XX,S,Z-S8N,S8W)UT@/2`G2VAA;F1W82<["B1C;V]R9&EN
M871E<ULG26YD:6$G75LG,C$N.3$W.C@T+C`X,R==(#T@)TIH87)S=6=U9&$G
M.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(R+C,P,#HW,"XW.#,G72`]("=2
M86IK;W0G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(R+C8U,#HX."XT-3`G
M72`]("=#86QC=71T82`O($1U;2!$=6TG.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(R+C<Q-SHW-2XX,#`G72`]("=);F1O<F4G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(R+C@Q-SHX-BXQ.#,G72`]("=*86US:&5D<'5R)SL*)&-O
M;W)D:6YA=&5S6R=);F1I82==6R<R,RXP-C<Z-S(N-C,S)UT@/2`G06AM861A
M8F%D)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,RXR,#`Z-SDN.34P)UT@
M/2`G2F%B86QP=7(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(S+C(U,#HV
M.2XV-C<G72`]("=":'5J+5)U9')A;6%T82<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,C,N,C@S.C<W+C,U,"==(#T@)T)H;W!A;"`O($)A:7)A9V%R:"<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C,N,S$W.C@U+C,Q-R==(#T@)TTN
M($\N(%)A;F-H:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C,N.#@S.CDQ
M+C(U,"==(#T@)T%G87)T86QA)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M-"XU-C<Z.#`N.#,S)UT@/2`G4V%T;F$G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(T+C8Q-SHW,RXX.#,G72`]("=59&%I<'5R($1A8F]K)SL*)&-O;W)D
M:6YA=&5S6R=);F1I82==6R<R-"XW-3`Z.#0N.34P)UT@/2`G1V%Y82<["B1C
M;V]R9&EN871E<ULG26YD:6$G75LG,C0N-S8W.CDS+CDP,"==(#T@)TEM<&AA
M;"!4=6QI:&%L)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-2XQ-3`Z-S4N
M.#4P)UT@/2`G2V]T82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(U+C0U,#HW."XU.#,G72`]("=*:&%N<VDG.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(U+C0U,#HX,2XW,S,G72`]("=!;&QA:&%B860@+R!"86UH
M<F%U;&DG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(U+C0U,#HX,BXX-C<G
M72`]("=687)A;F%S:2`O($)A8F%T<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R-2XV,#`Z.#4N,3`P)UT@/2`G4&%T;F$G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(V+C$P,#HY,2XU.#,G72`]("='875H871I)SL*)&-O;W)D
M:6YA=&5S6R=);F1I82==6R<R-BXR,S,Z-S@N,C4P)UT@/2`G1W=A;&EO<B<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C8N,S`P.C<S+C`Q-R==(#T@)TIO
M9&AP=7(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(V+C0P,#HX,"XT,#`G
M72`]("=+86YP=7(@+R!#:&%K97)I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==
M6R<R-BXV,S,Z.#@N,S$W)UT@/2`G4VEL:6=U<FDG.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(V+C<U,#HX,"XX.#,G72`]("=,=6-K;F]W("\@06UA=7-I
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXW-3`Z.#,N,S8W)UT@/2`G
M1V]R86MH<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXX,3<Z-S4N
M.#`P)UT@/2`G2F%I<'5R("\@4V%N9V%N97(G.PHD8V]O<F1I;F%T97-;)TEN
M9&EA)UU;)S(W+C$U,#HW-RXY-C<G72`]("=!9W)A)SL*)&-O;W)D:6YA=&5S
M6R=);F1I82==6R<R-RXR,S,Z.30N,3$W)UT@/2`G3F]R=&@@3&%K:&EM<'5R
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-RXT.#,Z.34N,#$W)UT@/2`G
M1&EB<G5G87)H("\@36]H86YB87)I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==
M6R<R."XS-C<Z-SDN-#`P)UT@/2`G0F%R96EL;'DG.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(X+C4V-SHW-RXQ,3<G72`]("=.97<@1&5L:&D@+R!086QA
M;2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C@N-3@S.C<W+C(P,"==(#T@
M)TYE=R!$96QH:2`O(%-A9F1A<FIU;F<G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(Y+C$V-SHW-2XW,S,G72`]("=(:7-S87(G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S,Q+C(U,#HW-BXV-C<G72`]("=":6QA<W!U<B<["B1C;V]R
M9&EN871E<ULG26YD:6$G75LG,S$N-C,S.C<T+C@V-R==(#T@)T%M<FET<V%R
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<X+C0V-SHW-BXY-3`G72`]("=4
M:&ER=79A;F%N=&AA<'5R86TG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)SDN
M,34P.CDR+C@Q-R==(#T@)T-A<B!.:6-O8F%R)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<Y+C@S,SHW."XP.#,G72`]("=-861U<F%I)SL*)&-O;W)D:6YA
M=&5S6R=);F1I82==6R<Y+CDU,#HW-BXR-C<G72`]("=#;V-H:6X@+R!7:6QL
M:6YG9&]N)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,"XQ,3<Z,3$Q
M+C4S,R==(#T@)U-I;G1A;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M,"XQ-3`Z,3`Y+C0P,"==(#T@)U!O;G1I86YA:R`O(%-U<&%D:6\G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<P+C0V-SHQ,#$N-#4P)UT@/2`G
M4&%K86YB87)U("\@4VEM<&%N9W1I9V$G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<P+C0V-SHQ,#(N,S$W)UT@/2`G4F5N9V%T("\@2F%P=7)A)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N-#@S.C$P-"XU.#,G72`]
M("=3:6YG:V5P("\@1&%B;R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)S`N-3$W.C$R,RXP-C<G72`]("=';W)O;G1A;&\@+R!*86QA;'5D9&EN)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N-C$W.C$Q-RXQ-3`G72`]
M("=386UA<FEN9&$@+R!496UI;F1U;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<M,"XV.#,Z,3$Y+C<S,R==(#T@)U!A;'4@+R!-=71I87)A)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,"XW.#,Z,3(W+C,X,R==(#T@
M)U1E<FYA=&4@+R!"86)U;&QA:"<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTP+C@X,SHQ,#`N,S4P)UT@/2`G4&%D86YG("\@5&%B:6YG)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N.#@S.C$S-"XP-3`G72`]("=-
M86YO:W=A<FD@+R!296YD86YI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3`N.3`P.C$R,BXW.#,G72`]("=,=7=U:R`O($)U8G5N9R<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)S`N.3$W.C$P-"XU,S,G72`]("=486YJ
M=6YG<&EN86YG("\@2VEJ86YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3`N.3,S.C$S,2XQ,3<G72`]("=3;W)O;F<@+R!*969M86XG.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,"XY-3`Z,3$T+CDP,"==(#T@)TUU
M87)A=&5W92`O($)E<FEN9VEN)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3$N,#`P.C$Q-"XP,#`G72`]("=086QA;F=K87)A>6$@+R!086YA<G5N
M9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S$N,#$W.C$R,"XX,#`G
M72`]("=4;VQI+51O;&D@+R!,86QO<R<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)S$N,#@S.C$P.2XV-C<G72`]("=3:6YG:V%W86YG($EI)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,2XQ,3<Z,3`T+C$Q-R==(#T@)T)A
M=&%N("A3=6UA=')A*2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ
M+C$X,SHQ,S8N,3$W)UT@/2`G0FEA:R`O($UO:VUE<B<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)RTQ+C(V-SHQ,38N.3`P)UT@/2`G0F%L:6MP87!A
M;B`O(%-E<&EN9V=A;B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ
M+C,X,SHQ,C`N-S,S)UT@/2`G4&]S;R`O($MA<VEG=6YC=2<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)S$N-3`P.CDW+C8S,R==(#T@)T=U;G5N9R!3
M:71O;&D@+R!":6YA:V$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<Q
M+C4S,SHQ,C0N.3$W)UT@/2`G365N861O("\@1'(N(%-A;2!2871U;&%N9VDG
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<Q+C4U,#HY."XX.#,G72`]
M("=3:6)O;&=A("\@4&EN86YG<V]R:2<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTQ+C8Q-SHQ,C0N-34P)UT@/2`G3&%B=6AA("\@5&%L:6%B=2<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C8S,SHQ,#,N-C4P)UT@
M/2`G2F%M8FD@+R!3=6QT86X@5&%H82<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)S$N.#$W.C$R-RXX,S,G72`]("='86QE;&$@+R!'86UA<FUA;&%M
M=2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C@S,SHQ,S@N-S$W
M)UT@/2`G4V%R;6DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XX
M-3`Z,3`Y+CDV-R==(#T@)TME=&%P86YG("\@4F%H861I(%5S;6%M86XG.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XX-C<Z,3,V+C(S,R==(#T@
M)U-E<G5I("\@665N9&]S82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)RTQ,"XQ-C<Z,3(S+C8V-R==(#T@)TMU<&%N9R`O($5L(%1A<FDG.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,3`N-3`P.C$R,2XX,S,G72`]("=3
M86)U("\@5&%R9&%M=2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ
M,"XW,S,Z,3(S+C`V-R==(#T@)U)O=&4@+R!"86$G.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M,BXP.#,Z,3(V+C`P,"==(#T@)U-A;F%N82<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S(N,3$W.C$Q-RXT-3`G72`]("=4
M86YJ=6YG(%)E9&5P("\@0F5R874G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I
M82==6R<M,BXQ-C<Z,3`V+C$S,R==(#T@)U!A;F=K86QP:6YA;F<@+R!086YG
M:V%L<&EN86YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3(N-38W
M.C$T,"XT.#,G72`]("=*87EA<'5R82`O(%-E;G1A;FDG.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<M,BXW,#`Z,3$P+C<P,"==(#T@)U!A;F=K86QA
M;B!"=6X@+R!)<VMA;F1A<B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)RTR+C<U,#HQ,#<N-S4P)UT@/2`G5&%N:G5N9W!A;F1A;B`O($)U;'5H(%1U
M;6)A;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXW-C<Z,3`Q
M+C,V-R==(#T@)TME<FEN8VD@+R!$97!A=&D@4&%R8F\G.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<R+C@U,#HQ,3<N,S,S)UT@/2`G5&%N:G5N9R!3
M96QO<B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTR+C@X,SHQ,S(N
M,C4P)UT@/2`G1F%K+49A:R`O(%1O<F5A)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG+3(N.3`P.C$P-"XW,#`G72`]("=086QE;6)A;F<@+R!486QA
M;F=B971U='4G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXR-3`Z
M,3(W+C`X,R==(#T@)TYA;6QE82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)S,N,S,S.C$Q-RXU-C<G72`]("=487)A:V%N("\@2G5W871A)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N,S,S.C$S-2XU,#`G72`]("=.
M86)I<F4G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXS-3`Z,3(X
M+C@X,R==(#T@)T%M86AA:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)RTS+C0P,#HQ,38N,C$W)UT@/2`G2V]T86)A<G4G.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M,RXT,S,Z,3$T+C<U,"==(#T@)T)A;FIA<FUA<VEN
M("\@4WEA;7-U9&1I;B!.;V]R)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG,RXU-C<Z.3@N-C@S)UT@/2`G365D86X@+R!0;VQO;FEA)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG,RXU.#,Z,3(U+C0V-R==(#T@)U1A:'5N
M82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTS+C8V-SHQ,S,N-S4P
M)UT@/2`G2V%I;6%N82`O(%5T87)O;2<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTS+C<P,#HQ,C@N,#@S)UT@/2`G06UB;VX@+R!0871T:6UU<F$G
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<S+C<S,SHQ,34N-C@S)UT@
M/2`G3&]N9V)A=V%N("\@2G5V86D@4V5M87)I;F<G.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M,RXX.#,Z,3`R+C,S,R==(#T@)T)E;F=K=6QU("\@
M4&%D86YG:V5M:6QI;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M,RXY,3<Z,3,V+C,V-R==(#T@)T5N87)O=&%L:2<["B1C;V]R9&EN871E<ULG
M26YD;VYE<VEA)UU;)S,N.34P.C$P."XS.#,G72`]("=286YA:2`O(%)A;F%I
M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+30N,#8W.C$S."XY-3`G
M72`]("=786UE;F$@+R!786UE;F$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I
M82==6R<M-"XQ,#`Z,3(R+C0S,R==(#T@)TME;F1A<FD@+R!7;VQT97)M;VXM
M1VEN<VED:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S0N,C4P.CDV
M+C$Q-R==(#T@)TUE=6QA8F]H("\@0W5T($YY86L@1&AI96XG.PHD8V]O<F1I
M;F%T97-;)TEN9&]N97-I82==6R<M-"XT-3`Z,3`U+C$X,R==(#T@)TUE;F=G
M86QA("\@07-T<F$@2W-E=')A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+30N-S$W.C$S-BXT,S,G72`]("=+;VMO;F%O("\@5&EM=6MA)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+34N,#8W.C$Q.2XU-3`G72`]("=5
M:G5N9R!086YD86YG("\@2&%S86YU9&1I;B<["B1C;V]R9&EN871E<ULG26YD
M;VYE<VEA)UU;)S4N,C,S.CDW+C(P,"==(#T@)TQH;VMS975M87=E("\@36%L
M:6MU<W-A;&5H)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+34N,C8W
M.C$P-2XQ.#,G72`]("=496QU:V)E='5N9R`O($)E<F%N=&DG.PHD8V]O<F1I
M;F%T97-;)TEN9&]N97-I82==6R<M-2XT-C<Z,3(R+C8Q-R==(#T@)T)A=2U"
M874@+R!"971O($%M8FER:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)S4N-3$W.CDU+C0Q-R==(#T@)T)A;F1A($%C96@@+R!";&%N9V)I;G1A;F<G
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<U+C@V-SHY-2XS,3<G72`]
M("=386)A;F<@+R!#=70@0F%U)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+38N,3`P.C$T,"XS,#`G72`]("=486YA:"!-97)A:"`O(%1A;F%H($UE
M<F%H)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+38N,3$W.C$P-BXV
M-3`G72`]("=*86MA<G1A("\@4V]E:V%R;F\M2&%T=&$G.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<M-BXR,S,Z,3`V+C8U,"==(#T@)T-U<G5G("\@
M0G5D:6%R=&\G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-BXR-3`Z
M,3`V+CDP,"==(#T@)TIA:V%R=&$@2&%L:6T@4&5R9&%N86MU<W5M82<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTV+C4U,#HQ,#<N-C8W)UT@/2`G
M2V%L:6IA=&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-BXY,#`Z
M,3`W+C4X,R==(#T@)T)A;F1U;F<@+R!(=7-E:6XG.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M-BXY.#,Z,3$P+C,X,R==(#T@)U-E;6%R86YG("\@
M06AM861Y86YI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N,C$W
M.C$Q,BXW,3<G72`]("=3=7)A8F%Y82`O(%!E<F%K)SL*)&-O;W)D:6YA=&5S
M6R=);F1O;F5S:6$G75LG+3<N,C$W.C$Q,RXW,3<G72`]("=3=7)A8F%Y82<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTW+C,S,SHQ,#@N,C4P)UT@
M/2`G5&%S:6MM86QA>6$@+R!#:6)E=7)E=6TG.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M-RXS-C<Z,3$R+C<V-R==(#T@)U-U<F%B87EA("\@2G5A
M;F1A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N-C$W.C$Q,2XU
M,3<G72`]("=-861I=6X@+R!)<W=A:'EU9&DG.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M-RXW,S,Z,3`Y+C`Q-R==(#T@)T-I;&%C87`G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXW.#,Z,3$P+C0S,R==(#T@)TIO
M9WEA:V%R=&$@+R!!9&ES=6-I<'1O)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3<N.#8W.C$Q,"XY,3<G72`]("=3=7)A:V%R=&$@+R!!9&ES=6UA
M<FUO)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N.38W.C$Q,BXW
M,#`G72`]("=-86QA;F<@+R!!8F1U;"!286AK;6%N<V%L96@G.PHD8V]O<F1I
M;F%T97-;)TEN9&]N97-I82==6R<M-RXY.#,Z,3,Q+C,P,"==(#T@)U-A=6UL
M86MI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3@N,C$W.C$R-"XU
M-C<G72`]("=!;&]R("\@36%L:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTX+C(V-SHQ,C(N.38W)UT@/2`G3&%R86YT=6MA)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3@N-#,S.C$Q-RXT,3<G72`]("=3=6UB87=A
M($)E<V%R("\@4W5M8F%W82!"97-A<B<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTX+C0V-SHQ-#`N,S@S)UT@/2`G365R875K92`O($UO<&%H)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3@N-3,S.C$Q-BXP-C<G72`]
M("=!;7!E;F%N("\@4V5L87!A<F%N9R<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTX+C4U,#HQ,3@N-S`P)UT@/2`G0FEM82<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)RTX+C8S,SHQ,C(N,C4P)UT@/2`G36%U;65R92`O
M(%=A:2!/=&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M."XW-3`Z
M,3$U+C$V-R==(#T@)T1E;G!A<V%R("\@3F=U<F%H+5)A:2<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTY+C8V-SHQ,C`N,S,S)UT@/2`G5V%I;F=A
M<'4@+R!-874@2&%U)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F)UU;)S(U+C0Q-SHV,"XW-3`G72`]("=#:&%H8F%H87(G.PHD
M8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,C8N
M-3@S.C4T+C@S,R==(#T@)T)A;F1A<B!,96YG96@G.PHD8V]O<F1I;F%T97-;
M)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,C8N-C,S.C4W+C<V-R==
M(#T@)TIA<VLG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8G75LG,C<N,C`P.C8P+C<P,"==(#T@)TER86YS:&%H<B<["B1C;V]R
M9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R-RXR,3<Z
M-38N,S8W)UT@/2`G0F%N9&%R86)B87-S)SL*)&-O;W)D:6YA=&5S6R=)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(X+CDV-SHU,RXV.#,G72`]("=&
M87-A)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M)UU;)S(X+CDX,SHU,"XX,S,G72`]("="=7-H96AR($-I=B`O($%F8B<["B1C
M;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R.2XQ
M,#`Z-3@N-#`P)UT@/2`G0F%M)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F)UU;)S(Y+C0V-SHV,"XX.#,G72`]("=:86AE9&%N
M)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;
M)S(Y+C4S,SHU,BXU.#,G72`]("=3:&ER87HG.PHD8V]O<F1I;F%T97-;)TER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S`N,C4P.C4V+CDV-R==(#T@
M)TME<FUA;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9B==6R<S,"XS-C<Z-#@N,C4P)UT@/2`G06)A9&%N)SL*)&-O;W)D:6YA
M=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,P+C0S,SHU,"XW
M-C<G72`]("='86-H(%-A<F%N($1U($=U;F)A9&%N)SL*)&-O;W)D:6YA=&5S
M6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,P+C<V-SHT.2XV-C<G
M72`]("=/;6ED:65H)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F)UU;)S,Q+C$X,SHU,BXV-C<G72`]("=!8F%D96@G.PHD8V]O
M<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S$N,S,S
M.C0X+C8V-R==(#T@)T%H=V%Z)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F)UU;)S,Q+C,S,SHV,2XT.#,G72`]("=:86)O;"<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S
M,2XY,#`Z-30N-#`P)UT@/2`G66%Z9"<["B1C;V]R9&EN871E<ULG27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B==6R<S,2XY.#,Z-#DN,C8W)UT@/2`G36%S
M:F5D+5-O;&5Y;6%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F)UU;)S,R+C,S,SHU,"XX-3`G72`]("=3:&%H<F4M2V]R9"<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S
M,BXT-C<Z-3$N-S$W)UT@/2`G17-F86AA;B<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,BXX-C<Z-3DN,C`P)UT@/2`G
M0FER:F%N9"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9B==6R<S,RXV,#`Z-38N.3$W)UT@/2`G5&%B87,G.PHD8V]O<F1I;F%T
M97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S,N.3@S.C4Q+C0U
M,"==(#T@)TMA<VAA;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B==6R<S-"XQ,#`Z-#DN-#`P)UT@/2`G07)A:R<["B1C;V]R
M9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-"XR-C<Z
M-#<N,3$W)UT@/2`G2V5R;6%N<VAA:"<["B1C;V]R9&EN871E<ULG27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B==6R<S-"XU,3<Z-#4N-3@S)UT@/2`G1VAA
M<W)E+5-H:7)I;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B==6R<S-2XR-C<Z-3DN,C$W)UT@/2`G5&]R8F%T+4AE>61A<FEE
M:"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==
M6R<S-2XS,S,Z-#<N,#`P)UT@/2`G4V%N86YD86HG.PHD8V]O<F1I;F%T97-;
M)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S4N-34P.C4S+C,X,R==
M(#T@)U-E;6YA;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B==6R<S-2XV.#,Z-3$N,S4P)UT@/2`G5&5H<F%N+4UE:')A8F%D
M)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;
M)S,V+C(Q-SHU-RXV-C<G72`]("=386)Z979A<B<["B1C;V]R9&EN871E<ULG
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-BXR-3`Z-#8N,C8W)UT@
M/2`G4V%G:&5Z)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F)UU;)S,V+C(U,#HU,"XP,#`G72`]("=':&%Z=FEN)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C(V-SHU
M.2XV,S,G72`]("=-87-H:&%D)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C8X,SHT."XT.#,G72`]("=:86YJ86XG
M.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG
M,S8N.#$W.C4T+C0V-R==(#T@)T=O<F=A;B<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-BXY,#`Z-3`N-C8W)UT@/2`G
M4F%M<V%R)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F)UU;)S,W+C(P,#HT.2XV,S,G72`]("=287-H="<["B1C;V]R9&EN871E
M<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-RXT-C<Z-3<N,S,S
M)UT@/2`G0F]J;F]U<F0G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8G75LG,S<N-3,S.C0U+C`X,R==(#T@)T]R=6UI96@G.PHD
M8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S@N
M,#@S.C0V+C(X,R==(#T@)U1A8G)I>B<["B1C;V]R9&EN871E<ULG27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B==6R<S."XU-3`Z-#0N.38W)UT@/2`G2VAO
M>2<["B1C;V]R9&EN871E<ULG27)A<2==6R<S,"XT,3<Z-#<N-C4P)UT@/2`G
M4VAA:6)A:"`O($)A<W)A:"<["B1C;V]R9&EN871E<ULG27)A<2==6R<S,RXR
M,S,Z-#0N,C,S)UT@/2`G0F%G:&1A9"<["B1C;V]R9&EN871E<ULG27)A<2==
M6R<S-BXS,3<Z-#,N,34P)UT@/2`G36]S=6PG.PHD8V]O<F1I;F%T97-;)TER
M96QA;F0G75LG-3$N.#4P.BTX+C0X,R==(#T@)T-O<FL@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG27)E;&%N9"==6R<U,BXW,#`Z+3@N.3$W)UT@/2`G4VAA
M;FYO;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=)<F5L86YD)UU;)S4S+C,P
M,#HM-BXT,S,G72`]("=#87-E;65N="!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)TER96QA;F0G75LG-3,N-#,S.BTV+C(U,"==(#T@)T1U8FQI;B!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=)<W)A96PG75LG,CDN-34P.C,T+CDU,"==
M(#T@)T5I;&%T)SL*)&-O;W)D:6YA=&5S6R=)<W)A96PG75LG,S`N,#`P.C,T
M+C@S,R==(#T@)T]V9&$G.PHD8V]O<F1I;F%T97-;)TES<F%E;"==6R<S,2XR
M,S,Z,S0N-S@S)UT@/2`G0F5E<BU3:&5V82<["B1C;V]R9&EN871E<ULG27-R
M865L)UU;)S,Q+C@V-SHS-2XR,3<G72`]("=*97)U<V%L96T@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG27-R865L)UU;)S,R+C`P,#HS-"XY,#`G72`]("="
M96XM1W5R:6]N($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG27-R865L)UU;)S,R+C@P,#HS-2XP,S,G72`]("=39&4M2&%I9F$@2&%I
M9F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,U+C4P,#HQ,BXV,#`G72`]
M("=,86UP961U<V$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,V+C8X,SHQ
M-2XQ,S,G72`]("=#;WIZ;R!3<&%D87)O)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<S-BXX,3<Z,3$N.38W)UT@/2`G4&%N=&5L;&5R:6$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S,W+C`X,SHQ-"XR,3<G72`]("='96QA)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<S-RXT,#`Z,30N.3$W)UT@/2`G0V%T86YI
M82`O(%-I9V]N96QL82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,S<N-#8W
M.C$U+C`U,"==(#T@)T-A=&%N:6$@+R!&;VYT86YA<F]S<V$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S,W+C4V-SHQ-"XR.#,G72`]("=%;FYA)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<S-RXY,3<Z,3(N-3`P)UT@/2`G5')A<&%N
M:2`O($)I<F=I)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XP-C<Z,34N
M-C4P)UT@/2`G4F5G9VEO($-A;&%B<FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<S."XQ,#`Z,3,N,S`P)UT@/2`G4&%L97)M;R!";V-C861I9F%L8V\G
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,X+C$X,SHQ,RXQ,#`G72`]("=0
M86QE<FUO("\@4'5N=&$@4F%I<VDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S,X+C(P,#HQ-2XU-3`G72`]("=-97-S:6YA)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<S."XW,#`Z,3,N,3@S)UT@/2`G57-T:6-A)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<S."XY,#`Z,38N,C4P)UT@/2`G3&%M97II82!497)M
M92<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN,#`P.C$W+C`V-R==(#T@
M)T-R;W1O;F4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,Y+C$P,#HY+C4Q
M-R==(#T@)T-A<&\@0V%R8F]N87)A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<S.2XR-3`Z.2XP-C<G72`]("=#86=L:6%R:2`O($5L;6%S)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<S.2XS,S,Z,38N-#`P)UT@/2`G36]N=&4@4V-U
M<F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,Y+C,U,#HX+CDV-R==(#T@
M)T1E8VEM;VUA;FYU)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XU,#`Z
M.2XV,S,G72`]("=#87!O(%,N($QO<F5N>F\G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S,Y+C4X,SHQ-2XX.#,G72`]("=";VYI9F%T:2<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG,SDN-C8W.CDN-#,S)UT@/2`G4&5R9&%S9&5F;V=U
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XW-3`Z."XT-C<G72`]("=#
M87!O($9R87-C82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN.#$W.C$X
M+C,U,"==(#T@)U,N($UA<FEA($1I($QE=6-A)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<S.2XY,S,Z.2XW,3<G72`]("=#87!O($)E;&QA=FES=&$G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C`Q-SHQ-2XR.#,G72`]("=#87!O
M(%!A;&EN=7)O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XP.#,Z,38N
M,#$W)UT@/2`G3&%T<F]N:6-O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M,"XQ,3<Z.2XR-3`G72`]("=&;VYN:2<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG-#`N,C,S.C$X+C$U,"==(#T@)TQE8V-E)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,"XT,S,Z,38N.#@S)UT@/2`G36%R:6YA($1I($=I;F]S82<[
M"B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N-3$W.C$W+C0P,"==(#T@)T=R
M;W1T86=L:64G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C4U,#HQ-"XR
M,#`G72`]("=#87!R:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N-38W
M.C@N,38W)UT@/2`G0V%P;R!#86-C:6$G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0P+C8S,SHQ-2XX,#`G72`]("=0;W1E;GIA)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T,"XV,S,Z."XR.#,G72`]("=!;&=H97)O)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T,"XV-3`Z,3<N.34P)UT@/2`G0G)I;F1I<VDG
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C<V-SHQ-BXY,S,G72`]("='
M:6]I82!$96P@0V]L;&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C@U
M,#HQ-"XS,#`G72`]("=.87!O;&D@+R!#87!O9&EC:&EN;R<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#`N.3`P.CDN-3$W)UT@/2`G3VQB:6$@+R!#;W-T
M82!3;65R86QD82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N.3$W.C$R
M+CDU,"==(#T@)U!O;GIA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XP
M-3`Z,30N,#8W)UT@/2`G1W)A>GIA;FES92<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#$N,#4P.C$U+C(S,R==(#T@)U1R979I8V\G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0Q+C$S,SHQ-BXW.#,G72`]("="87)I("\@4&%L97-E
M($UA8V-H:64G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C(Q-SHY+C0P
M,"==(#T@)T=U87)D:6%V96-C:&EA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,2XU,S,Z,34N-S$W)UT@/2`G06UE;F1O;&$G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0Q+C4U,#HQ,BXY,#`G72`]("=,871I;F$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0Q+C4V-SHQ-"XV-3`G72`]("=#86UP;V)A<W-O
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XV,S,Z,3,N,S`P)UT@/2`G
M1G)O<VEN;VYE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XV-3`Z,3(N
M-#4P)UT@/2`G4')A=&EC82!$:2!-87)E)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T,2XW,#`Z,34N.34P)UT@/2`G36]N=&4@4RX@06YG96QO)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XW.#,Z,3(N-3@S)UT@/2`G4F]M82`O
M($-I86UP:6YO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XX,#`Z,3(N
M,C,S)UT@/2`G4F]M82!&:75M:6-I;F\G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0Q+CDU,#HQ,BXU,#`G72`]("=2;VUA("\@57)B92<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#(N,#`P.C$R+C<S,R==(#T@)T=U:61O;FEA)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXP,#`Z,34N,#`P)UT@/2`G5&5R
M;6]L:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N,#,S.C$Q+C@S,R==
M(#T@)T-I=FET879E8V-H:6$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R
M+C`X,SHQ,BXR,3<G72`]("=6:6=N82!$:2!686QL92<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#(N,S@S.C$Q+C$V-R==(#T@)TUO;G1E($%R9V5N=&%R
M:6\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+C0Q-SHQ,BXX-3`G72`]
M("=2:65T:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N-#,S.C$R+C`U
M,"==(#T@)U9I=&5R8F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+C0S
M,SHQ-"XR,#`G72`]("=097-C87)A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,BXT-C<Z,3(N.3@S)UT@/2`G36]N=&4@5&5R;6EN:6QL;R<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#(N-S,S.C$P+C0P,"==(#T@)TTN($-A;&%M
M:71A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXW-3`Z,3$N,#8W)UT@
M/2`G1W)O<W-E=&\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+CDP,#HQ
M,2XW-C<G72`]("=2861I8V]F86YI)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,RXP.#,Z,3(N-3`P)UT@/2`G4&5R=6=I82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#,N-#`P.C$P+C@V-R==(#T@)U9O;'1E<G)A)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T,RXT-C<Z,3$N.#4P)UT@/2`G07)E>GIO)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXU,3<Z,3(N-S,S)UT@/2`G1G)O
M;G1O;F4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0S+C8Q-SHQ,RXS-C<G
M72`]("=&86QC;VYA<F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0S+C8X
M,SHQ,"XS.#,G72`]("=0:7-A("\@4RX@1VEU<W1O)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T,RXX,#`Z,3$N,C`P)UT@/2`G1FER96YZ92`O(%!E<F5T
M;VQA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXY-3`Z."XQ-C<G72`]
M("=#87!O($UE;&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C`S,SHQ
M,BXV,3<G72`]("=2:6UI;FDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T
M+C`S,SHY+C@S,R==(#T@)TES;VQA($1I(%!A;&UA<FEA)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T-"XP-3`Z."XQ,3<G72`]("=!;&)E;F=A)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XP.#,Z.2XY.#,G72`]("=387)Z86YA
M("\@3'5N:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N,C`P.C$P+C<P
M,"==(#T@)TUO;G1E($-I;6]N92<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#0N,C`P.C$R+C`V-R==(#T@)T9O<FQI)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T-"XR,3<Z,3(N,S`P)UT@/2`G0V5R=FEA)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T-"XR-3`Z-RXX,#`G72`]("=-;VYT92!-86QA;F]T=&4G
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C0Q-SHX+C@U,"==(#T@)T=E
M;F]V82`O(%-E<W1R:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N-#,S
M.CDN.3,S)UT@/2`G4&%S<V\@1&5L;&$@0VES82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#0N-#4P.C$R+C,P,"==(#T@)U!U;G1A($UA<FEN82<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#0N-3,S.C$Q+C,P,"==(#T@)T)O;&]G
M;F$@+R!";W)G;R!086YI9V%L92<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#0N-C,S.C@N.3,S)UT@/2`G4&%S<V\@1&5I($=I;W9I)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T-"XX,S,Z,3$N-C$W)UT@/2`G1F5R<F%R82<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#0N.3$W.CDN-S,S)UT@/2`G4&EA8V5N
M>F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C`S,SHW+C<S,R==(#T@
M)U1O<FEN;R`O($)R:6,@1&5L;&$@0W)O8V4G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0U+C(Q-SHW+C8U,"==(#T@)U1O<FEN;R`O($-A<V5L;&4G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C,X,SHQ,"XX-C<G72`]("=697)O
M;F$@+R!6:6QL869R86YC82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N
M-#$W.C$P+C(X,R==(#T@)T)R97-C:6$@+R!':&5D:2<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#4N-#,S.CDN,C@S)UT@/2`G36EL86YO("\@3&EN871E
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XU,#`Z,3(N,S,S)UT@/2`G
M5F5N97II82`O(%1E<W-E<F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U
M+C4Q-SHX+C8V-R==(#T@)TYO=F%R82`O($-A;65R:2<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#4N-38W.C$Q+C4Q-R==(#T@)U9I8V5N>F$G.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0U+C8Q-SHX+C<S,R==(#T@)TUI;&%N;R`O
M($UA;'!E;G-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XV-3`Z,3(N
M,3@S)UT@/2`G5')E=FES;R`O(%,N($%N9V5L;R<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#4N-C4P.C$S+C<U,"==(#T@)U1R:65S=&4G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0U+C8V-SHY+C<P,"==(#T@)T)E<F=A;6\@+R!/
M<FEO($%L(%-E<FEO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XV.#,Z
M,3(N,3`P)UT@/2`G5')E=FES;R`O($ES=')A;F$G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0U+C@Q-SHQ,RXT.#,G72`]("=2;VYC:&D@1&5I($QE9VEO
M;F%R:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N.#8W.CDN,#8W)UT@
M/2`G36]N=&4@0FES8FEN;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N
M.3,S.C<N-S`P)UT@/2`G4&EA;B!2;W-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T-2XY.#,Z,3,N,#,S)UT@/2`G561I;F4@+R!2:79O;'1O)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T-BXP,S,Z,3(N-C`P)UT@/2`G079I86YO
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-BXP,S,Z,3(N-C$W)UT@/2`G
M079I86YO(%5S868G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0V+C`S,SHQ
M,RXQ.#,G72`]("=59&EN92`O($-A;7!O9F]R;6ED;R<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#8N,34P.C$Q+C`S,R==(#T@)U!A9V%N96QL82<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#8N,S`P.C$Q+C<X,R==(#T@)U!A<W-O
M(%)O;&QE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-BXT-C<Z,3$N,S,S
M)UT@/2`G0F]L>F%N;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#8N-3`P
M.C$S+C4X,R==(#T@)U1A<G9I<VEO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T-BXW,S,Z,3(N,C$W)UT@/2`G1&]B8FEA8V\G.PHD8V]O<F1I;F%T97-;
M)TIA;6%I8V$G75LG,3<N.3,S.BTW-BXW.#,G72`]("=+:6YG<W1O;B`O($YO
M<FUA;B!-86YL97DG.PHD8V]O<F1I;F%T97-;)TIA;6%I8V$G75LG,3@N-3`P
M.BTW-RXY,3<G72`]("=-;VYT96=O($)A>2`O(%-A;F=S=&5R)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<R-"XS,#`Z,34S+CDV-R==(#T@)TUI;F%M:71O
M<FES:&EM82<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C0N,S,S.C$R-"XQ
M-C<G72`]("=)<VAI9V%K:6II;6$G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S(T+C0V-SHQ,C(N.3@S)UT@/2`G66]N86=U;FD@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,C0N-S@S.C$R-2XR.#,G72`]("=-:7EA:V]J
M:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-"XW.#,Z,30Q+C,Q-R==
M(#T@)TEW;VII;6$G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(U+C@S,SHQ
M,S$N,C,S)UT@/2`G36EN86UI9&%I=&]J:6UA)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<R-BXQ.#,Z,3(W+C8U,"==(#T@)TYA:&$@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,C8N,C8W.C$R-RXW-3`G72`]("=&=71E
M;FUA($UA<FEN92!#;W)P<R!!:7(@1F%C:6QI='DG.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S(V+C,P,#HQ,C<N-S8W)UT@/2`G2&%M8GD@52X@4RX@07)M
M>2!!:7)F:65L9"<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C8N,S,S.C$R
M-BXX,#`G72`]("=+=6UE:FEM82<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,C8N,S4P.C$R-RXW-C<G72`]("=+861E;F$@06(G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S(V+C<Q-SHQ,C<N-S@S)UT@/2`G265J:6UA($%U>&EL:6%R
M>2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C<N,#@S.C$T,BXQ.#,G
M72`]("=#:&EC:&EJ:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-RXT
M,S,Z,3(X+C<P,"==(#T@)T]K:6YO97)A8G4G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S(W+C@S,SHQ,C@N.#@S)UT@/2`G5&]K=6YO<VAI;6$@27-L86YD
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R."XT,S,Z,3(Y+C<Q-R==(#T@
M)T%M86UI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,P+C,X
M,SHQ,S`N-C8W)UT@/2`G66%K=7-H:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S,"XU-3`Z,3,P+CDU,"==(#T@)U1A;F5G87-H:6UA($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,Q+C,V-SHQ,S`N.#,S)UT@/2`G
M2V%N;WEA($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,2XX,#`Z,3,P
M+C<Q-R==(#T@)TMA9V]S:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<S,2XX-C<Z,3,Q+C0U,"==(#T@)TUI>6%Z86MI($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,R+C`X,SHQ,S$N-#4P)UT@/2`G
M3GEU=&%B87)U($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,BXV-C<Z
M,3(X+C@S,R==(#T@)T9U:W5E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,R+C@S,SHQ,S`N.#4P)UT@/2`G2W5M86UO=&\@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,S(N.3$W.C$R.2XY,3<G72`]("=.
M86=A<V%K:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,RXQ
M,3<Z,3,Y+C<X,R==(#T@)TAA8VAI:F]J:6UA($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,S+C$U,#HQ,CDN-S$W)UT@/2`G4V%S96)O(%5S
M;B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N,S$W.C$S,"XT,3<G72`]
M("=-971A8F%R=2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N-#@S
M.C$S,2XW,S,G72`]("=/:71A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,S+C4S,SHQ,S,N-C8W)UT@/2`G2V]C:&D@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S,N-3@S.C$S,"XT-3`G72`]("=&=6MU
M;VMA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C8V-SHQ
M,S4N,S4P)UT@/2`G3F%N:VES:&ER86AA;6$@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S,N-C@S.C$S,2XP-3`G72`]("=4<W5I:VD@06(G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C<U,#HQ,CDN-S@S)UT@/2`G
M26MI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C@Q-SHQ
M,S(N-S`P)UT@/2`G36%T<W5Y86UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,S+C@S,SHQ,S`N.34P)UT@/2`G2VET86MY=7-H=2!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,RXX.#,Z,3,P+C8U,"==
M(#T@)T%S:&EY82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N.3,S
M.C$S,2XR.#,G72`]("=986UA9W5C:&D@56)E($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,T+C`P,#HQ,S0N-C,S)UT@/2`G2V]M871S=6II
M;6$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C`S,SHQ,S$N-34P
M)UT@/2`G2&]F=2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N,#4P
M.C$S,2XP-3`G72`]("=/>G5K:2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S0N,#8W.C$S.2XU-C<G72`]("=-:7EA:V5J:6UA($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C$S,SHQ,S(N,C,S)UT@/2`G27=A
M:W5N:2!-87)I;F4@0V]R<',@06ER(%-T871I;VXG.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,T+C$S,SHQ,S0N-C$W)UT@/2`G5&]K=7-H:6UA($%B)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XR,3<Z,3,T+C`Q-R==(#T@)U1A
M:V%M871S=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XR
M.#,Z,3(Y+C,S,R==(#T@)U1S=7-H:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TIA<&%N)UU;)S,T+C0Q-SHQ,S4N,C4P)UT@/2`G2V%N<V%I($EN=&5R
M;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N
M-#,S.C$S,BXY,3<G72`]("=(:7)O<VAI;6$@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S0N-3,S.C$S-BXV.#,G72`]("=!:V5N;R!!8B<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N-C`P.C$S-2XV,#`G72`]("=9
M86\@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N-C8W.C$S
M,2XX,#`G72`]("=)=V%M:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S-"XW-3`Z,3,S+C@U,"==(#T@)T]K87EA;6$@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S0N-S4P.C$S-RXW,#`G72`]("=(86UA
M;6%T<W4@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C<X,SHQ,S4N
M-#4P)UT@/2`G3W-A:V$@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S-"XW.#,Z,3,Y+C,V-R==(#T@)T]S:&EM82!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XX,3<Z,3,X+C,P
M,"==(#T@)U-H:7IU:&%M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S0N.3@S.C$S.2XX,S,G72`]("=4871E>6%M82!!8B<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S4N,C4P.C$S-BXY,S,G72`]("=.86=O>6$@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N,C@S.C$S.2XV-C<G72`]
M("=9;VMO<W5K82!&=V8G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C,Q
M-SHQ,S@N.#8W)UT@/2`G1G5J:2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S4N,S@S.C$S-BXX-C<G72`]("=':69U($%B)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S-2XT,#`Z,3,Y+CDQ-R==(#T@)TMI<V%R87IU($%B)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XT,3<Z,3,R+CDP,"==(#T@)TEZ
M=6UO($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C0U,#HQ
M,SDN-#4P)UT@/2`G071S=6=I(%5N:71E9"!3=&%T97,@3F%V86P@06ER(%-T
M871I;VXG.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C0X,SHQ,S,N,C4P
M)UT@/2`G36EH;R!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N-3$W
M.C$S.2XT,#`G72`]("=:86UA($%I<F9I96QD)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<S-2XU,S,Z,3,T+C$V-R==(#T@)U1O='1O<FD@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N-34P.C$S.2XW.#,G72`]("=4
M;VMY;R!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,U+C8S,SHQ,SDN.#4P)UT@/2`G5&]K>6\@2&5L:7!O<G0G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C8V-SHQ,SDN-3,S)UT@/2`G0VAO
M9G4@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N-C@S.C$S
M.2XW-C<G72`]("=4;VMY;R<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N
M-S`P.C$S.2XT,#`G72`]("=486-H:6MA=V$@06(G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,U+C<U,#HQ,SDN,S4P)UT@/2`G66]K;W1A($%B)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S-2XW-C<Z,30P+C,X,R==(#T@)TYE=R!4
M;VMY;R!);G1E<BU.871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<S-2XX,#`Z,30P+C`Q-R==(#T@)U-H:6UO9G5S82!!8B<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S4N.#,S.C$S.2XT,3<G72`]("=)<G5M
M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N,#,S.C$T,"XR,#`G
M72`]("=+87-U;6EG875R82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S8N,3,S.C$S-BXR,S,G72`]("=&=6MU:2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<S-BXQ-C<Z,3,W+CDS,R==(#T@)TUA='-U;6]T;R!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-BXQ.#,Z,3,S+C,S
M,R==(#T@)T]K:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S
M-BXQ.#,Z,30P+C0Q-R==(#T@)TAY86MU<FD@06(G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,V+C,X,SHQ,S8N-#$W)UT@/2`G2V]M871S=2!!8B<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S8N-3$W.C$S.2XX-C<G72`]("=5='-U
M;F]M:7EA($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-BXV-3`Z,3,W
M+C$X,R==(#T@)U1O>6%M82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S-RXR,S,Z,30P+C0S,R==(#T@)T9U:W5S:&EM82!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-RXY-3`Z,3,Y+C$Q-R==(#T@)TYI
M:6=A=&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S@N,#4P
M.C$S."XT,3<G72`]("=3861O($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,X+C$S,SHQ-#`N.3$W)UT@/2`G4V5N9&%I($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,X+C(S,SHQ-#`N.3$W)UT@/2`G2V%S
M=6UI;F]M92!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S@N-#`P.C$T
M,2XR,3<G72`]("=-871S=7-H:6UA($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S."XT,3<Z,30P+C,V-R==(#T@)UEA;6%G871A($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,Y+C0S,SHQ-#$N,3,S)UT@/2`G2&%N
M86UA:VD@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,SDN-C$W
M.C$T,"XR,3<G72`]("=!:VET82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<T,"XU-3`Z,30Q+C0V-R==(#T@)TAA8VAI;F]H92!!8B<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG-#`N-S`P.C$T,2XS.#,G72`]("=-:7-A
M=V$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0P+C<S,SHQ-#`N-S`P
M)UT@/2`G06]M;W)I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S0Q+C(S,SHQ-#$N,3,S)UT@/2`G3VUI;F%T;R!!8B<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG-#$N-S8W.C$T,"XX,3<G72`]("=(86MO9&%T92!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,BXS,3<Z,30P+CDX,R==
M(#T@)TUU<F]R86XG.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0R+C<S,SHQ
M-#,N,C$W)UT@/2`G3V)I:&ER;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<T,BXX,#`Z,30Q+C8V-R==(#T@)T-H:71O<V4@06(G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S0R+C@Q-SHQ-#$N-C@S)UT@/2`G0VAI=&]S
M92!*87!A;F5S92!!:7(@4V5L9B!$969E;G-E($9O<F-E)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<T,BXY.#,Z,30T+C0P,"==(#T@)TMU<VAI<F\G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S+C`S,SHQ-#0N,C`P)UT@/2`G2W5S
M:&ER;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,RXQ,3<Z
M,30Q+C,X,R==(#T@)U-A<'!O<F\@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S0S+C4V-SHQ-#0N.38W)UT@/2`G3F%K87-H:6)E='-U($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S+C8V-SHQ-#(N-#4P)UT@/2`G
M07-A:&EK87=A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S
M+C@P,#HQ-#(N,S8W)UT@/2`G07-A:&EK87=A($%B)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<T,RXX.#,Z,30T+C$V-R==(#T@)TUE;6%M8F5T<W4@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#0N,C4P.C$T,RXU,S,G
M72`]("=-;VUB971S=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<T-2XT,#`Z,30Q+C@P,"==(#T@)U=A:VMA;F%I($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TIO<F1A;B==6R<R.2XV,S,Z,S4N,#$W)UT@/2`G07%A8F$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F]R9&%N)UU;)S,P+C$V-SHS-2XW
M.#,G72`]("=-85PG06XG.PHD8V]O<F1I;F%T97-;)TIO<F1A;B==6R<S,2XV
M-C<Z,S4N.38W)UT@/2`G475E96X@06QI82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=*;W)D86XG75LG,S$N.3@S.C,U+CDX,R==(#T@)T%M;6%N($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)TIO<F1A;B==6R<S,BXR,#`Z,S<N,3,S)UT@
M/2`G2"TU7"=3869A=VDG.PHD8V]O<F1I;F%T97-;)TIO<F1A;B==6R<S,BXS
M-C<Z,S8N,C4P)UT@/2`G36%F<F%Q)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG
M75LG,S(N-3`P.C,X+C(P,"==(#T@)T@M-%PG27)W86ES:&5D)SL*)&-O;W)D
M:6YA=&5S6R=*;W)D86XG75LG,S(N-34P.C,U+C@U,"==(#T@)TER8FED)SL*
M)&-O;W)D:6YA=&5S6R=+87IA:VAS=&%N)UU;)S0R+C,Q-SHV.2XW,#`G72`]
M("=3:'EM:V5N="<["B1C;V]R9&EN871E<ULG2V%Z86MH<W1A;B==6R<T,RXR
M,S,Z-S8N.3,S)UT@/2`G06QM871Y)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS
M=&%N)UU;)S0T+C@U,#HV-2XU,#`G72`]("=+>GEL+4]R9&$G.PHD8V]O<F1I
M;F%T97-;)TMA>F%K:'-T86XG75LG-#8N-S@S.C8Q+C8U,"==(#T@)T%R86QS
M:V]E($UO<F4G.PHD8V]O<F1I;F%T97-;)TMA>F%K:'-T86XG75LG-3`N,C@S
M.C4W+C$U,"==(#T@)T%K=&IU8FEN<VLG.PHD8V]O<F1I;F%T97-;)TMA>F%K
M:'-T86XG75LG-3$N,C4P.C4Q+C(X,R==(#T@)U5R86QS:R<["B1C;V]R9&EN
M871E<ULG2V%Z86MS=&%N)UU;)S0Y+C@P,#HW,RXQ-3`G72`]("=+87)A9V%N
M9&$G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S`N,#@S.C,W+C8U,"==(#T@
M)TUE<G4G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTP+C$P,#HS-"XW-3`G
M72`]("=+:7-U;74G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTP+C(V-SHS
M-BXQ,#`G72`]("=.86MU<G4G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S`N
M,C@S.C,T+C<X,R==(#T@)TMA:V%M96=A)SL*)&-O;W)D:6YA=&5S6R=+96YY
M82==6R<M,"XS-C<Z,S4N,S4P)UT@/2`G2V5R:6-H;R<["B1C;V]R9&EN871E
M<ULG2V5N>6$G75LG+3`N-#8W.C,Y+C8S,R==(#T@)T=A<FES<V$G.PHD8V]O
M<F1I;F%T97-;)TME;GEA)UU;)RTP+C4P,#HS-BXY-C<G72`]("=.>65R:2<[
M"B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3`N-3`P.C,W+C0U,"==(#T@)T5M
M8G4G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S`N-3,S.C,U+C(X,R==(#T@
M)T5L9&]R970G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTP+C8V-SHS-"XW
M.#,G72`]("=+:7-I:2<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG,2XP,3<Z
M,S4N,#`P)UT@/2`G2VET86QE)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M
M,2XQ,S,Z,S4N.#,S)UT@/2`G3F%R;VLG.PHD8V]O<F1I;F%T97-;)TME;GEA
M)UU;)RTQ+C,P,#HS-BXW-3`G72`]("=.86ER;V)I("\@1&%G;W)E='1I)SL*
M)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,2XS,3<Z,S8N.#$W)UT@/2`G3F%I
M<F]B:2`O(%=I;'-O;B<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3$N,S$W
M.C,V+CDS,R==(#T@)TYA:7)O8FD@04-#+T9)0R]20T,O3454+T-/32\G.PHD
M8V]O<F1I;F%T97-;)TME;GEA)UU;)S$N-S4P.C0P+C`V-R==(#T@)U=A:FER
M)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,BXR-C<Z-#`N.#,S)UT@/2`G
M3&%M=2<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3(N,C@S.C,W+C@S,R==
M(#T@)TUA:VEN9'4G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S(N,S`P.C,W
M+CDP,"==(#T@)TUA<G-A8FET)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<S
M+C$Q-SHS-2XV,3<G72`]("=,;V1W87(G.PHD8V]O<F1I;F%T97-;)TME;GEA
M)UU;)RTS+C(S,SHT,"XQ,#`G72`]("=-86QI;F1I)SL*)&-O;W)D:6YA=&5S
M6R=+96YY82==6R<M,RXT,#`Z,S@N-38W)UT@/2`G5F]I)SL*)&-O;W)D:6YA
M=&5S6R=+96YY82==6R<S+C4S,SHS.2XP-3`G72`]("=-;WEA;&4G.PHD8V]O
M<F1I;F%T97-;)TME;GEA)UU;)S,N.3,S.C0Q+C@V-R==(#T@)TUA;F1E<F$G
M.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTT+C`S,SHS.2XV,3<G72`]("=-
M;VUB87-A)SL*)&-O;W)D:6YA=&5S6R=+:7)I8F%T:2==6R<Q+C,U,#HQ-S(N
M.3$W)UT@/2`G5&%R87=A)SL*)&-O;W)D:6YA=&5S6R=+:7)I8F%T:2==6R<M
M,2XS-3`Z,3<V+C`P,"==(#T@)T)E<G4G.PHD8V]O<F1I;F%T97-;)TMI<FEB
M871I)UU;)RTR+C8V-SHQ-S8N.#,S)UT@/2`G07)O<F%E)SL*)&-O;W)D:6YA
M=&5S6R=+:7)I8F%T:2==6R<S+C`S,SHQ-S(N-S@S)UT@/2`G0G5T87)I=&%R
M:2<["B1C;V]R9&EN871E<ULG2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE7"=S
M(%)E<'5B;&EC(&]F)UU;)S,Y+C`S,SHQ,C4N-S@S)UT@/2`G4'EO;F=Y86YG
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@1&5M;V-R871I8R!096]P;&5<)W,@
M4F5P=6)L:6,@;V8G75LG-#`N-C8W.C$R.2XR,#`G72`]("=+:6UC:&%E:R<[
M"B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,S+C(P,#HQ
M,C8N,C8W)UT@/2`G36]S=6QP;R!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L
M(%)E<'5B;&EC(&]F)UU;)S,S+C4P,#HQ,C8N-3`P)UT@/2`G0VAE:G4@26YT
M97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P
M=6)L:6,@;V8G75LG,S0N.#,S.C$R-RXV,3<G72`]("=9;W-U($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-2XP.#,Z
M,3(X+C`X,R==(#T@)U-A8VA<)T]N($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E
M82P@4F5P=6)L:6,@;V8G75LG,S4N,3$W.C$R-BXX,3<G72`]("=+=V%N9VIU
M($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N
M,3@S.C$R."XY,S,G72`]("=0=7-A;B`O($MI;6AA92!);G1E<FYA=&EO;F%L
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==
M6R<S-2XU-3`Z,3(Y+C,Q-R==(#T@)U5L<V%N)SL*)&-O;W)D:6YA=&5S6R=+
M;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N.#@S.C$R."XV,3<G72`]("=4865G
M=2<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,U+CDP
M,#HQ,C@N-C4P)UT@/2`G5&%E9W4@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A
M+"!297!U8FQI8R!O9B==6R<S-2XY,3<Z,3(V+C8Q-R==(#T@)TMU;G-A;B!!
M8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,U+CDX
M,SHQ,CDN-#$W)UT@/2`G4&]H86YG($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E
M82P@4F5P=6)L:6,@;V8G75LG,S8N,S`P.C$R-RXT,#`G72`]("=4865J;VXG
M.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-BXS,S,Z
M,3(W+C,X,R==(#T@)U1A96IO;B!+;W(M069B)SL*)&-O;W)D:6YA=&5S6R=+
M;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N-#`P.C$R-RXU,#`G72`]("=3;VYG
M;74@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S
M-BXU-3`Z,3(X+C<Q-R==(#T@)T%N9&]N9R<["B1C;V]R9&EN871E<ULG2V]R
M96$L(%)E<'5B;&EC(&]F)UU;)S,V+C8S,SHQ,C@N,S4P)UT@/2`G665C:&]N
M($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N
M-S`P.C$R-RXU,#`G72`]("=#:&]N9VIU($%B)SL*)&-O;W)D:6YA=&5S6R=+
M;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N.3,S.C$R-BXT-3`G72`]("=-86YG
M:6QS86X@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==
M6R<S-BXY,S,Z,3(W+C`P,"==(#T@)U!Y;VYG=&%E:R!!8B<["B1C;V]R9&EN
M871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C`S,SHQ,C8N-S4P)UT@
M/2`G2V]O;BU.:2!286YG92<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B
M;&EC(&]F)UU;)S,W+C`S,SHQ,C<N.#@S)UT@/2`G2G5N9R!7;VX@4F]K+4%B
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N,3`P
M.C$R-RXP,S,G72`]("=/<V%N($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@
M4F5P=6)L:6,@;V8G75LG,S<N,C4P.C$R-RXP,#`G72`]("=3=7=O;B!!8B<[
M"B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C,S,SHQ
M,C<N.34P)UT@/2`G5V]N:G4G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U
M8FQI8R!O9B==6R<S-RXT,S,Z,3(W+C$Q-R==(#T@)U-E;W5L($4@06(G.PHD
M8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXT,S,Z,3(W
M+CDU,"==(#T@)TAO96YG<V]N9R!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L
M(%)E<'5B;&EC(&]F)UU;)S,W+C0V-SHQ,C8N-#4P)UT@/2`G26YC:&5O;B!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!2
M97!U8FQI8R!O9B==6R<S-RXU,#`Z,3(V+CDS,R==(#T@)U-E;W5L("\@66]N
M9V1U;F=P7"=/(%)O:V%F(%=C)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P
M=6)L:6,@;V8G75LG,S<N-3`P.C$R.2XQ,S,G72`]("=4;VYG:&%E(%)A9&%R
M(%-I=&4G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S
M-RXU-3`Z,3(V+C@P,"==(#T@)U-E;W5L("\@2VEM<%PG3R!);G1E<FYA=&EO
M;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O
M9B==6R<S-RXU-C<Z,3(V+CDV-R==(#T@)U-E;W5L)SL*)&-O;W)D:6YA=&5S
M6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-S4P.C$R."XY-3`G72`]("=+
M86YG;G5N9R!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F
M)UU;)S,W+C@V-SHQ,C<N-S$W)UT@/2`G0VAU;F-H;VX@06(G.PHD8V]O<F1I
M;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXY-C<Z,3(T+C8V-R==
M(#T@)U!A96YG;GEO;F=D;R!!8B<["B1C;V]R9&EN871E<ULG2W5W86ET)UU;
M)S(Y+C(Q-SHT-RXY.#,G72`]("=+=7=A:70@26YT97)N871I;VYA;&%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)TQA;R!096]P;&5<)W,@1&5M;V-R871I8R!2
M97!U8FQI8R==6R<Q-"XX,#`Z,3`V+C@S,R==(#T@)T%T=&]P974G.PHD8V]O
M<F1I;F%T97-;)TQA;R!096]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==
M6R<Q-2XQ,3<Z,3`U+C$V-R==(#T@)U!A:W-E)SL*)&-O;W)D:6YA=&5S6R=,
M86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P=6)L:6,G75LG,34N-C@S.C$P
M-BXT,S,G72`]("=387)A=F%N92<["B1C;V]R9&EN871E<ULG3&%O(%!E;W!L
M95PG<R!$96UO8W)A=&EC(%)E<'5B;&EC)UU;)S$V+C4U,#HQ,#0N-C4P)UT@
M/2`G4V%V86YN86MH970G.PHD8V]O<F1I;F%T97-;)TQA;R!096]P;&5<)W,@
M1&5M;V-R871I8R!297!U8FQI8R==6R<Q-RXS.#,Z,3`T+C8U,"==(#T@)U1H
M86MH96LG.PHD8V]O<F1I;F%T97-;)TQA;R!096]P;&5<)W,@1&5M;V-R871I
M8R!297!U8FQI8R==6R<Q-RXY-3`Z,3`R+C4V-R==(#T@)U9I96YT:6%N92<[
M"B1C;V]R9&EN871E<ULG3&%O(%!E;W!L95PG<R!$96UO8W)A=&EC(%)E<'5B
M;&EC)UU;)S$Y+C(S,SHQ,#$N-S,S)UT@/2`G4V%Y86)O=7)Y)SL*)&-O;W)D
M:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P=6)L:6,G75LG
M,3DN.#@S.C$P,BXQ,S,G72`]("=,=6%N9RU0<F%B86YG)SL*)&-O;W)D:6YA
M=&5S6R=,871V:6$G75LG-38N.38W.C(T+C`U,"==(#T@)U)I9V$G.PHD8V]O
M<F1I;F%T97-;)TQA='9I82==6R<U-RXT,#`Z,C$N-3,S)UT@/2`G5F5N='-P
M:6QS)SL*)&-O;W)D:6YA=&5S6R=,96)A;F]N)UU;)S,S+C@Q-SHS-2XT.#,G
M72`]("="97ER;W5T:"!!97)O<&]R="<["B1C;V]R9&EN871E<ULG3&5S;W1H
M;R==6R<M,CDN-#4P.C(W+C4U,"==(#T@)TUA<V5R=2U-:6$G.PHD8V]O<F1I
M;F%T97-;)TQI8F5R:6$G75LG-BXR-3`Z+3$P+C,U,"==(#T@)T=R86YD($)A
M<W-A+"!2;V)E<G1S($9I96QD)SL*)&-O;W)D:6YA=&5S6R=,:6)Y86X@07)A
M8B!*86UA:&ER:7EA)UU;)S(T+C(Q-SHR,RXS,#`G72`]("=+=69R82<["B1C
M;V]R9&EN871E<ULG3&EB>6%N($%R86(@2F%M86AI<FEY82==6R<R-2XQ,S,Z
M,3`N,34P)UT@/2`G1VAA="<["B1C;V]R9&EN871E<ULG3&EB>6%N($%R86(@
M2F%M86AI<FEY82==6R<R-RXP,3<Z,30N-#4P)UT@/2`G4V5B:&$G.PHD8V]O
M<F1I;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H:7)I>6$G75LG,S`N,3,S.CDN
M-3`P)UT@/2`G1VAA9&%M97,G.PHD8V]O<F1I;F%T97-;)TQI8GEA;B!!<F%B
M($IA;6%H:7)I>6$G75LG,S(N,3`P.C(P+C(V-R==(#T@)T)E;FEN82<["B1C
M;V]R9&EN871E<ULG3&EB>6%N($%R86(@2F%M86AI<FEY82==6R<S,BXV-C<Z
M,3,N,34P)UT@/2`G5')I<&]L:2!);G1E<BU.871I;VYA;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=,:71H=6%N:6$G75LG-30N-C,S.C(U+C$P,"==(#T@
M)U9I;&YI=7,G.PHD8V]O<F1I;F%T97-;)TQU>&5M8F]U<F<G75LG-#DN-C$W
M.C8N,C$W)UT@/2`G3'5X96UB;W5R9R`O($QU>&5M8F]U<F<G.PHD8V]O<F1I
M;F%T97-;)TUA8V%U)UU;)S(R+C$V-SHQ,3,N-38W)UT@/2`G5&%I<&$G.PHD
M8V]O<F1I;F%T97-;)TUA8V5D;VYI82P@=&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B==6R<T,2XQ,3<Z,C`N.#`P)UT@/2`G3VAR:60G.PHD8V]O
M<F1I;F%T97-;)TUA8V5D;VYI82P@=&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9B==6R<T,2XY-C<Z,C$N-C4P)UT@/2`G4VMO<&IE+5!E=')O=F5C
M)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ,BXS-3`Z-#DN,S`P
M)UT@/2`G1&EE9V\M4W5A<F5Z)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R
M)UU;)RTQ,RXS,3<Z-#@N,S$W)UT@/2`G1F%S8V5N92!.;W-S:2U"92<["B1C
M;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,3,N,S8W.C4P+C`P,"==(#T@
M)U9O:&5M87(G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3$T+C(X
M,SHU,"XQ-C<G72`]("=386UB879A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S
M8V%R)UU;)RTQ-"XV,S,Z-#<N-S8W)UT@/2`G06YA;&%L879A)SL*)&-O;W)D
M:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-"XV-3`Z-#DN-C$W)UT@/2`G06YD
M87!A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-"XX.#,Z-3`N
M,C4P)UT@/2`G06YT86QA:&$G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G
M75LG+3$U+C8V-SHT-BXS-3`G72`]("=-86IU;F=A)SL*)&-O;W)D:6YA=&5S
M6R=-861A9V%S8V%R)UU;)RTQ-BXW-3`Z-#0N-#@S)UT@/2`G0F5S86QA;7!Y
M)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-RXP.#,Z-#DN.#$W
M)UT@/2`G4V%I;G1E+4UA<FEE($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M36%D86=A<V-A<B==6R<M,3@N,#4P.C0T+C`S,R==(#T@)TUA:6YT:7)A;F\G
M.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3$X+C$Q-SHT.2XT,#`G
M72`]("=486UA=&%V92<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M
M,3@N.#`P.C0W+C0X,R==(#T@)T%N=&%N86YA<FEV;R`O($EV871O)SL*)&-O
M;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ.2XX,3<Z-#<N,#8W)UT@/2`G
M06YT<VER86)E)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ.2XX
M,S,Z-#@N.#`P)UT@/2`G36%H86YO<F\G.PHD8V]O<F1I;F%T97-;)TUA9&%G
M87-C87(G75LG+3(P+C(X,SHT-"XS,3<G72`]("=-;W)O;F1A=F$G.PHD8V]O
M<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(Q+C(P,#HT."XS-C<G72`]("=-
M86YA;FIA<GDG.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(Q+C0U
M,#HT-RXQ,#`G72`]("=&:6%N87)A;G1S;V$G.PHD8V]O<F1I;F%T97-;)TUA
M9&%G87-C87(G75LG+3(Q+C<U,#HT,RXS-C<G72`]("=-;W)O;6)E)SL*)&-O
M;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTR,BXU-3`Z-#4N-#`P)UT@/2`G
M4F%N;VAI<F$G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(R+C@P
M,#HT-RXX,S,G72`]("=&87)A9F%N9V%N82<["B1C;V]R9&EN871E<ULG36%D
M86=A<V-A<B==6R<M,C,N,S@S.C0S+C<S,R==(#T@)U1U;&5A<B<["B1C;V]R
M9&EN871E<ULG36%D86=A<V-A<B==6R<M,C4N,#,S.C0V+CDU,"==(#T@)T9O
M<G0M1&%U<&AI;B<["B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTQ,2XT-3`Z
M,S0N,#$W)UT@/2`G37IU>G4G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M
M,3$N.#@S.C,S+C8Q-R==(#T@)TUZ:6UB82<["B1C;V]R9&EN871E<ULG36%L
M87=I)UU;)RTQ,BXY,3<Z,S0N,C8W)UT@/2`G3FMH;W1A($MO=&$G.PHD8V]O
M<F1I;F%T97-;)TUA;&%W:2==6R<M,3,N-S4P.C,T+C4X,R==(#T@)U-A;&EM
M82<["B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTQ,RXW.#,Z,S,N-S8W)UT@
M/2`G3&EL;VYG=V4@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=-86QA=VDG75LG+3$T+C`X,SHS-"XY,3<G72`]("=-;VYK97D@0F%Y
M)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3$T+C,Q-SHS-"XR-C<G72`]
M("=$961Z82<["B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTQ-"XT,S,Z,S4N
M,C4P)UT@/2`G36%N9V]C:&DG.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M
M,34N-C@S.C,T+CDV-R==(#T@)T-H:6QE:V$G.PHD8V]O<F1I;F%T97-;)TUA
M;&%W:2==6R<M.2XW,#`Z,S,N,C8W)UT@/2`G0VAI=&EP82<["B1C;V]R9&EN
M871E<ULG36%L87=I)UU;)RTY+CDU,#HS,RXX.#,G72`]("=+87)O;F=A)SL*
M)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<Q+C0X,SHQ,3`N,S,S)UT@/2`G
M2W5C:&EN9R<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG,2XV,S,Z,3`S
M+C8V-R==(#T@)TIO:&]R92!":&%R=2`O(%-E;F%I)SL*)&-O;W)D:6YA=&5S
M6R=-86QA>7-I82==6R<R+C(V-SHQ,#(N,C4P)UT@/2`G36%L86-C82<["B1C
M;V]R9&EN871E<ULG36%L87ES:6$G75LG,BXS,S,Z,3$Q+C@S,R==(#T@)U-I
M8G4G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S,N,3$W.C$P,2XU-3`G
M72`]("=+=6%L82!,=6UP=7(@+R!3=6)A;F<G.PHD8V]O<F1I;F%T97-;)TUA
M;&%Y<VEA)UU;)S,N,C`P.C$Q,RXP,S,G72`]("=":6YT=6QU)SL*)&-O;W)D
M:6YA=&5S6R=-86QA>7-I82==6R<S+C8Q-SHQ,#,N,C$W)UT@/2`G2W5A;G1A
M;B<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG-"XR,3<Z,3`P+C<P,"==
M(#T@)U-I=&EA=V%N)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<T+C(V
M-SHQ,3<N.#@S)UT@/2`G5&%W874G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA
M)UU;)S0N,S,S.C$Q,RXY.#,G72`]("=-:7)I)SL*)&-O;W)D:6YA=&5S6R=-
M86QA>7-I82==6R<U+C,P,#HQ,#`N,C8W)UT@/2`G4&5N86YG("\@0F%Y86X@
M3&5P87,G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S4N,S`P.C$Q-2XR
M-3`G72`]("=,86)U86XG.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S4N
M.3`P.C$Q."XP-C<G72`]("=386YD86MA;B<["B1C;V]R9&EN871E<ULG36%L
M87ES:6$G75LG-2XY,S,Z,3$V+C`U,"==(#T@)TMO=&$@2VEN86)A;'4G.PHD
M8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S8N,38W.C$P,BXR.#,G72`]("=+
M;W1A($)H87)U)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<V+C,S,SHY
M.2XW,S,G72`]("=,86YG:V%W:2<["B1C;V]R9&EN871E<ULG36%L87ES:6$G
M75LG-BXY,3<Z,3$V+C@S,R==(#T@)TMU9&%T)SL*)&-O;W)D:6YA=&5S6R=-
M86QD:79E<R==6R<M,"XV.#,Z-S,N,34P)UT@/2`G1V%N)SL*)&-O;W)D:6YA
M=&5S6R=-86QD:79E<R==6R<T+C(P,#HW,RXU,S,G72`]("=-86QE)SL*)&-O
M;W)D:6YA=&5S6R=-86QI)UU;)S$Q+C,U,#HM-2XV.#,G72`]("=3:6MA<W-O
M)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$Q+C0Q-SHM-RXU,#`G72`]("="
M;W5G;W5N:2<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q,BXS.#,Z+34N-#8W
M)UT@/2`G2V]U=&EA;&$G.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,3(N-3,S
M.BTW+CDU,"==(#T@)T)A;6%K;R`O(%-E;F]U)SL*)&-O;W)D:6YA=&5S6R=-
M86QI)UU;)S$R+C@U,#HM,3$N,C,S)UT@/2`G2V5N:65B82<["B1C;V]R9&EN
M871E<ULG36%L:2==6R<Q,RXP-C<Z+3DN-#8W)UT@/2`G2VET82<["B1C;V]R
M9&EN871E<ULG36%L:2==6R<Q,RXS,S,Z+30N.#,S)UT@/2`G4V%N)SL*)&-O
M;W)D:6YA=&5S6R=-86QI)UU;)S$S+C0P,#HM-BXQ-3`G72`]("=396=O=2<[
M"B1C;V]R9&EN871E<ULG36%L:2==6R<Q-"XT,S,Z+3$Q+C0S,R==(#T@)TMA
M>65S)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$T+C4Q-SHM-"XQ,#`G72`]
M("=-;W!T:2<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q-2XQ-C<Z+3<N,C@S
M)UT@/2`G3F%R82<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q-2XR,S,Z+3DN
M,S4P)UT@/2`G3FEO<F\@1'4@4V%H96PG.PHD8V]O<F1I;F%T97-;)TUA;&DG
M75LG,34N,S,S.BTQ+C8X,R==(#T@)TAO;6)O<FDG.PHD8V]O<F1I;F%T97-;
M)TUA;&DG75LG,34N.#8W.C(N,C$W)UT@/2`G365N86MA)SL*)&-O;W)D:6YA
M=&5S6R=-86QI)UU;)S$V+C(V-SHM,"XP-3`G72`]("='86\G.PHD8V]O<F1I
M;F%T97-;)TUA;&DG75LG,38N-S$W.BTS+C`P,"==(#T@)U1O;6)O=6-T;W4G
M.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,3@N-#,S.C$N,S4P)UT@/2`G2VED
M86PG.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,C`N,C`P.C`N.3@S)UT@/2`G
M5&5S<V%L:70G.PHD8V]O<F1I;F%T97-;)TUA;'1A)UU;)S,U+C@U,#HQ-"XT
M.#,G72`]("=,=7%A)SL*)&-O;W)D:6YA=&5S6R=-87)S:&%L;"!)<VQA;F1S
M)UU;)S<N,#8W.C$W,2XR.#,G72`]("=-86IU<F\@071O;&PL($UA<G-H86QL
M($ES;&%N9',@26YT+B!!:7)P+B<["B1C;V]R9&EN871E<ULG36%R<VAA;&P@
M27-L86YD<R==6R<X+C<Q-SHQ-C<N-S,S)UT@/2`G2W=A:F%L96EN+"!"=6-H
M;VQZ($%!1BA+=V%J86QE:6X@2TU2*2A!5$],*2!!:7)P+B<["B1C;V]R9&EN
M871E<ULG36%R=&EN:7%U92==6R<Q-"XV,#`Z+38Q+C`P,"==(#T@)TQE($QA
M;65N=&EN)SL*)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S$V+C$U,#HM
M,3,N-3$W)UT@/2`G2V%E9&DG.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G
M75LG,38N-3`P.BTQ-2XX,3<G72`]("=2;W-S;R<["B1C;V]R9&EN871E<ULG
M36%U<FET86YI82==6R<Q-BXV,#`Z+3<N,C8W)UT@/2`G3F5M82<["B1C;V]R
M9&EN871E<ULG36%U<FET86YI82==6R<Q-BXV,S,Z+3$Q+C0P,"==(#T@)TMI
M9F9A)SL*)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S$V+C<P,#HM.2XV
M,#`G72`]("=!:6]U;B!%;"!!=')O=7-S)SL*)&-O;W)D:6YA=&5S6R=-875R
M:71A;FEA)UU;)S$W+C4S,SHM,30N-C@S)UT@/2`G0F]U=&EL:6UI="<["B1C
M;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q."XQ,#`Z+3$U+CDU,"==(#T@
M)TYO=6%K8VAO='0G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG,3@N
M-38W.BTQ,2XT,S,G72`]("=4:61J:6MJ82<["B1C;V]R9&EN871E<ULG36%U
M<FET86YI82==6R<Q.2XW-3`Z+3$T+C,V-R==(#T@)T%K:F]U:G0G.PHD8V]O
M<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG,C`N-3$W.BTQ,RXP-C<G72`]("=!
M=&%R)SL*)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S(P+CDS,SHM,3<N
M,#,S)UT@/2`G3F]U861H:6)O=2<["B1C;V]R9&EN871E<ULG36%U<FET86YI
M82==6R<R-2XR,S,Z+3$Q+C8Q-R==(#T@)T)I<B!-;V=H<F5I;B<["B1C;V]R
M9&EN871E<ULG36%U<FET:75S)UU;)RTQ.2XV.#,Z-C,N-#$W)UT@/2`G4F]D
M<FEG=65S)SL*)&-O;W)D:6YA=&5S6R=-875R:71I=7,G75LG+3(P+C0S,SHU
M-RXV-C<G72`]("=0;&%I<V%N8V4@36%U<FET:75S)SL*)&-O;W)D:6YA=&5S
M6R=-97AI8V\G75LG,38N-S4P.BTY,RXQ,3<G72`]("=4=7AT;&$@1W5T:65R
M<F5Z+"!#:&ES+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S$X+C0X,SHM
M.#@N,S`P)UT@/2`G0VAE='5M86PL(%$N(%)O;R<["B1C;V]R9&EN871E<ULG
M365X:6-O)UU;)S$X+C@X,SHM.3DN,C,S)UT@/2`G0W5E<FYA=F%C82P@36]R
M+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S$Y+C`U,#HM.3@N,38W)UT@
M/2`G4'5E8FQA+"!0=64N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,3DN
M,C8W.BTQ,#,N-3@S)UT@/2`G0V]L:6UA)SL*)&-O;W)D:6YA=&5S6R=-97AI
M8V\G75LG,3DN.#4P.BTY,"XU-3`G72`]("=#86UP96-H92P@0V%M<"XG.PHD
M8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,"XP.#,Z+3DX+C,V-R==(#T@)U1U
M;&%N8VEN9V\G.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,"XV,#`Z+3$P
M,"XS.#,G72`]("=1=65R971A<F\L(%%R;RXG.PHD8V]O<F1I;F%T97-;)TUE
M>&EC;R==6R<R,"XY,S,Z+3@Y+C8U,"==(#T@)TUE<FED82`O(&QI8R!-86YU
M96P@0W)E8V5N8VEO)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C$N-3$W
M.BTQ,#0N.3`P)UT@/2`G5&5P:6,L($YA>2XG.PHD8V]O<F1I;F%T97-;)TUE
M>&EC;R==6R<R,2XX.#,Z+3$P,BXS,#`G72`]("=!9W5A<V-A;&EE;G1E<RP@
M06=S+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(R+C$U,#HM,3`P+CDX
M,R==(#T@)U-A;B!,=6ES(%!O=&]S:2P@4RX@3"X@4"XG.PHD8V]O<F1I;F%T
M97-;)TUE>&EC;R==6R<R-"XX,3<Z+3$P-RXT,#`G72`]("=#=6QI86-A;BP@
M4VEN+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(U+C0U,#HM,3`P+CDX
M,R==(#T@)U-A;'1I;&QO+"!#;V%H+B<["B1C;V]R9&EN871E<ULG365X:6-O
M)UU;)S(U+C4S,SHM,3`S+C0U,"==(#T@)U1O<G)E;VXL($-O86@N)SL*)&-O
M;W)D:6YA=&5S6R=-97AI8V\G75LG,C4N.#8W.BTQ,#`N,C,S)UT@/2`G065R
M;W`N($EN=&5R;F%C:6]N86P@36]N=&5R<F5Y+"!.+B!,+B<["B1C;V]R9&EN
M871E<ULG365X:6-O)UU;)S(V+C`Q-SHM,3$Q+C,U,"==(#T@)TQO<F5T;RP@
M0BX@0RX@4RXG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-BXX.#,Z+3$P
M,2XT,3<G72`]("=-;VYC;&]V82P@0V]A:"XG.PHD8V]O<F1I;F%T97-;)TUE
M>&EC;R==6R<R-RXS,3<Z+3$Q,BXS,#`G72`]("=386YT82!2;W-A;&EA+"!"
M+B!#+B!3+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(X+C<P,#HM,3`P
M+C4Q-R==(#T@)U!I961R87,@3F5G<F%S+"!#;V%H+B<["B1C;V]R9&EN871E
M<ULG365X:6-O)UU;)S(Y+C`V-SHM,3$P+CDU,"==(#T@)TAE<FUO<VEL;&\L
M(%-O;BXG.PHD8V]O<F1I;F%T97-;)TUI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8G75LG-2XS-3`Z,38R+CDU,"==(#T@)TMO<W)A92!#87)O;&EN
M97,@+R!6)SL*)&-O;W)D:6YA=&5S6R=-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F)UU;)S4N,S4P.C$V,BXY-3`G72`]("=+;W-R864@27-L86YD
M+"!+;W-R864@06ER<&]R="<["B1C;V]R9&EN871E<ULG36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9B==6R<V+CDX,SHQ-3@N,C`P)UT@/2`G4&]H
M;G!E:2!)<VQA;F0L(%!O:&YP96D@26YT+B!!:7)P+B<["B1C;V]R9&EN871E
M<ULG36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B==6R<W+C0V-SHQ
M-3$N.#4P)UT@/2`G5V5N;R!)<VQA;F0L($-H=75K($EN="X@06ER<"XG.PHD
M8V]O<F1I;F%T97-;)TUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8G
M75LG.2XT.#,Z,3,X+C`X,R==(#T@)UEA<"!)<VQA;F0L(%EA<"!);G0N($%I
M<G`N)SL*)&-O;W)D:6YA=&5S6R=-;VQD;W9A+"!297!U8FQI8R!O9B==6R<T
M-RXP,3<Z,C@N.3@S)UT@/2`G2VES:6YE=B<["B1C;V]R9&EN871E<ULG36]R
M;V-C;R==6R<R."XT-3`Z+3$Q+C$U,"==(#T@)U1A;BU486XG.PHD8V]O<F1I
M;F%T97-;)TUO<F]C8V\G75LG,CDN,S8W.BTQ,"XQ.#,G72`]("=3:61I($EF
M;FDG.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S`N,S,S.BTY+C0P,"==
M(#T@)T%G861I<B!!;"!-87-S:7)A)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O
M)UU;)S,P+C,X,SHM.2XU-C<G72`]("=!9V%D:7(G.PHD8V]O<F1I;F%T97-;
M)TUO<F]C8V\G75LG,S`N.3,S.BTV+CDP,"==(#T@)T]U87)Z87IA=&4G.PHD
M8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S$N-3$W.BTY+C<X,R==(#T@)T5S
M<V%O=6ER82<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,2XV,3<Z+3@N
M,#,S)UT@/2`G36%R<F%K96-H)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;
M)S,Q+CDS,SHM-"XT,#`G72`]("=%<G)A8VAI9&EA)SL*)&-O;W)D:6YA=&5S
M6R=-;W)O8V-O)UU;)S,R+C(X,SHM.2XR,S,G72`]("=3869I)SL*)&-O;W)D
M:6YA=&5S6R=-;W)O8V-O)UU;)S,S+C,V-SHM-RXU.#,G72`]("=.;W5A<W-E
M=7(G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S,N-3`P.BTU+C$V-R==
M(#T@)TEF<F%N92<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,RXU-C<Z
M+3<N-C8W)UT@/2`G0V%S86)L86YC82<["B1C;V]R9&EN871E<ULG36]R;V-C
M;R==6R<S,RXX.#,Z+34N-3,S)UT@/2`G365K;F5S)SL*)&-O;W)D:6YA=&5S
M6R=-;W)O8V-O)UU;)S,S+CDS,SHM-"XY.#,G72`]("=&97,M4V%I<R<["B1C
M;V]R9&EN871E<ULG36]R;V-C;R==6R<S-"XP-3`Z+38N-S8W)UT@/2`G4F%B
M870M4V%L92<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S-"XR,3<Z+30N
M,#`P)UT@/2`G5&%Z82<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S-"XS
M,#`Z+38N-C`P)UT@/2`G2V5N:71R82<["B1C;V]R9&EN871E<ULG36]R;V-C
M;R==6R<S-"XW.#,Z+3$N.3,S)UT@/2`G3W5J9&$G.PHD8V]O<F1I;F%T97-;
M)TUO<F]C8V\G75LG,S4N,34P.BTR+CDQ-R==(#T@)TYA9&]R)SL*)&-O;W)D
M:6YA=&5S6R=-;W)O8V-O)UU;)S,U+C$X,SHM,RXX-3`G72`]("=!;"!(;V-E
M:6UA)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,U+C4X,SHM-2XS,S,G
M72`]("=4971U86X@+R!386YI82!286UE;"<["B1C;V]R9&EN871E<ULG36]R
M;V-C;R==6R<S-2XW,S,Z+34N.3`P)UT@/2`G5&%N9V5R($%E<F]D<F]M92<[
M"B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,3$N,S4P.C0P+C,V-R==
M(#T@)TUO8VEM8F]A($1A(%!R86EA)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I
M<75E)UU;)RTQ,BXY.#,Z-#`N-3,S)UT@/2`G4&5M8F$G.PHD8V]O<F1I;F%T
M97-;)TUO>F%M8FEQ=64G75LG+3$S+C,P,#HS-2XR,S,G72`]("=,:6-H:6YG
M82<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,30N.#$W.C,V+C4S
M,R==(#T@)T-U86UB82<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M
M,34N,#,S.C0P+C8V-R==(#T@)TQU;6)O)SL*)&-O;W)D:6YA=&5S6R=-;WIA
M;6)I<75E)UU;)RTQ-2XQ,#`Z,SDN,C@S)UT@/2`G3F%M<'5L82<["B1C;V]R
M9&EN871E<ULG36]Z86UB:7%U92==6R<M,38N,3@S.C,S+C4X,R==(#T@)U1E
M=&4G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$W+C@X,SHS-BXX
M.#,G72`]("=1=65L:6UA;F4G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G
M75LG+3$Y+C$Q-SHS,RXT-C<G72`]("=#:&EM;VEO)SL*)&-O;W)D:6YA=&5S
M6R=-;WIA;6)I<75E)UU;)RTQ.2XX,#`Z,S0N.3`P)UT@/2`G0F5I<F$G.PHD
M8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3(R+C`P,#HS-2XS,3<G72`]
M("=6:6QA;F-U;&]S)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTR
M,RXX-C<Z,S4N,S@S)UT@/2`G26YH86UB86YE)SL*)&-O;W)D:6YA=&5S6R=-
M;WIA;6)I<75E)UU;)RTR-2XP-3`Z,S,N-C,S)UT@/2`G6&%I(%AA:2<["B1C
M;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,C4N.3$W.C,R+C4V-R==(#T@
M)TUA<'5T;R`O($UA=F%L86YE)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;
M)S$R+C0S,SHY."XV,#`G72`]("=-97)G=6DG.PHD8V]O<F1I;F%T97-;)TUY
M86YM87(G75LG,30N,3`P.CDX+C(Q-R==(#T@)T1A=V5I)SL*)&-O;W)D:6YA
M=&5S6R=->6%N;6%R)UU;)S$T+C$Q-SHY,RXS-C<G72`]("=#;V-O($ES;&%N
M9"<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q-BXU,#`Z.3<N-C$W)UT@
M/2`G36]U;&UE:6XG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,38N-S4P
M.CDW+C8V-R==(#T@)TAP82U!;B<["B1C;V]R9&EN871E<ULG37EA;FUA<B==
M6R<Q-BXW-C<Z.30N-S8W)UT@/2`G4&%T:&5I;B<["B1C;V]R9&EN871E<ULG
M37EA;FUA<B==6R<Q-BXW-C<Z.38N,38W)UT@/2`G66%N9V]N)SL*)&-O;W)D
M:6YA=&5S6R=->6%N;6%R)UU;)S$V+CDP,#HY-BXQ.#,G72`]("=-:6YG86QA
M9&]N)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$X+C0V-SHY-"XS-3`G
M72`]("=386YD;W=A>2<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q."XX
M,#`Z.34N,C$W)UT@/2`G4')O;64G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G
M75LG,3DN-#$W.CDS+C4U,"==(#T@)TMY875K<'EU)SL*)&-O;W)D:6YA=&5S
M6R=->6%N;6%R)UU;)S(P+C$S,SHY,BXX.#,G72`]("=3:71T=V4G.PHD8V]O
M<F1I;F%T97-;)TUY86YM87(G75LG,C`N.#,S.CDU+C@S,R==(#T@)TUE:6MT
M:6QA)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S(Q+C,P,#HY.2XV,3<G
M72`]("=+96YG='5N9R<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<R,2XY
M.#,Z.38N,3`P)UT@/2`G36%N9&%L87DG.PHD8V]O<F1I;F%T97-;)TUY86YM
M87(G75LG,C(N.3,S.CDW+C<U,"==(#T@)TQA<VAI;R<["B1C;V]R9&EN871E
M<ULG37EA;FUA<B==6R<R-"XR-C<Z.3<N,C`P)UT@/2`G0FAA;6\G.PHD8V]O
M<F1I;F%T97-;)TUY86YM87(G75LG,C0N.#8W.CDT+CDQ-R==(#T@)TAO;6%L
M:6XG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C4N,S8W.CDW+C0P,"==
M(#T@)TUY:71K>6EN82<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<R-RXS
M,S,Z.3<N-#$W)UT@/2`G4'5T86\G.PHD8V]O<F1I;F%T97-;)TYA;6EB:6$G
M75LG+3$W+CDQ-SHQ.2XW-C<G72`]("=2=6YD=2<["B1C;V]R9&EN871E<ULG
M3F%M:6)I82==6R<M,3DN-C`P.C$X+C$Q-R==(#T@)T=R;V]T9F]N=&5I;B<[
M"B1C;V]R9&EN871E<ULG3F%M:6)I82==6R<M,C(N-#8W.C$X+CDV-R==(#T@
M)T=O8F%B:7,G.PHD8V]O<F1I;F%T97-;)TYA;6EB:6$G75LG+3(R+C0X,SHQ
M-RXT-C<G72`]("=*+B!'+B!3=')I:F1O;2<["B1C;V]R9&EN871E<ULG3F%M
M:6)I82==6R<M,C8N-3,S.C$X+C$Q-R==(#T@)TME971M86YS:&]O<"<["B1C
M;V]R9&EN871E<ULG3F%U<G4G75LG+3`N-3,S.C$V-BXY,3<G72`]("=.875R
M=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=.97!A;"==6R<R-BXT.#,Z.#<N
M,C8W)UT@/2`G0FER871N86=A<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=.
M97!A;"==6R<R-RXQ-C<Z.#0N.3@S)UT@/2`G4VEM<F$@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG3F5P86PG75LG,C<N,S4P.C@W+C8V-R==(#T@)U1A<&QE
M:G5N9R<["B1C;V]R9&EN871E<ULG3F5P86PG75LG,C<N-3$W.C@S+C0U,"==
M(#T@)T)H86ER87=A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TYE<&%L)UU;
M)S(W+C<P,#HX-2XS-C<G72`]("=+871H;6%N9'4@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG3F5P86PG75LG,C@N,C$W.C@T+C`P,"==(#T@)U!O:VAA<F$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG75LG,C@N-C`P.C@Q+C8Q
M-R==(#T@)U-U<FMH970G.PHD8V]O<F1I;F%T97-;)TYE<&%L)UU;)S(Y+C(X
M,SHX,BXQ-C<G72`]("=*=6UL82<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N
M9',@06YT:6QL97,G75LG,3(N,34P.BTV."XR.#,G72`]("=&;&%M:6YG;R!!
M:7)P;W)T+"!";VYA:7)E)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R!!
M;G1I;&QE<R==6R<Q,BXR,#`Z+38X+CDV-R==(#T@)TAA=&\@06ER<&]R="P@
M0W5R86-A;R<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',@06YT:6QL97,G
M75LG,3<N-#@S.BTV,BXY.#,G72`]("=2;V]S979E;'0@06ER<&]R="!386EN
M="!%=7-T871I=7,G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S($%N=&EL
M;&5S)UU;)S$X+C`U,#HM-C,N,3$W)UT@/2`G2G5L:6%N82!!:7)P;W)T+"!3
M86EN="!-86%R=&5N)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U
M,"XY,3<Z-2XW.#,G72`]("=-86%S=')I8VAT($%I<G!O<G0@6G5I9"!,:6UB
M=7)G)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,2XT-3`Z-"XS
M,S,G72`]("=7;V5N<V1R96-H="<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N
M9',G75LG-3$N-#4P.C4N-#$W)UT@/2`G16EN9&AO=F5N)SL*)&-O;W)D:6YA
M=&5S6R=.971H97)L86YD<R==6R<U,2XU-C<Z-"XY,S,G72`]("=':6QZ92U2
M:6IE;B<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3$N-C4P.C4N
M-S`P)UT@/2`G5F]L:V5L)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==
M6R<U,2XY-3`Z-"XT-3`G72`]("=2;W1T97)D86T@06ER<&]R="!:97-T:65N
M:&]V96XG.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+C`V-SHU
M+C@X,R==(#T@)T1E96QE;B<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G
M75LG-3(N,3`P.C4N,3@S)UT@/2`G1&4@0FEL="<["B1C;V]R9&EN871E<ULG
M3F5T:&5R;&%N9',G75LG-3(N,3,S.C4N,C@S)UT@/2`G4V]E<W1E<F)E<F<G
M.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+C$X,SHT+C0Q-R==
M(#T@)U9A;&ME;F)U<F<G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;
M)S4R+C(V-SHV+CDP,"==(#T@)U1W96YT:&4G.PHD8V]O<F1I;F%T97-;)TYE
M=&AE<FQA;F1S)UU;)S4R+C,P,#HT+C<V-R==(#T@)T%M<W1E<F1A;2!!:7)P
M;W)T(%-C:&EP:&]L)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U
M,BXT-3`Z-2XU,3<G72`]("=,96QY<W1A9"<["B1C;V]R9&EN871E<ULG3F5T
M:&5R;&%N9',G75LG-3(N.3$W.C0N-S@S)UT@/2`G1&4@2V]O>2<["B1C;V]R
M9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3,N,3,S.C8N-3@S)UT@/2`G1W)O
M;FEN9V5N($%I<G!O<G0@165L9&4G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA
M;F1S)UU;)S4S+C(Q-SHU+C<V-R==(#T@)TQE975W87)D96XG.PHD8V]O<F1I
M;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4S+C(U,#HT+CDQ-R==(#T@)U9L:65L
M86YD)SL*)&-O;W)D:6YA=&5S6R=.97<@0V%L961O;FEA)UU;)RTR,"XU-C<Z
M,38T+C(X,R==(#T@)TMO=6UA8R!.;&QE+4-A;&5D;VYI92<["B1C;V]R9&EN
M871E<ULG3F5W($-A;&5D;VYI82==6R<M,C`N-C4P.C$V-BXU.#,G72`]("=/
M=6QO=7`@26QE($]U=F5A)SL*)&-O;W)D:6YA=&5S6R=.97<@0V%L961O;FEA
M)UU;)RTR,"XW-C<Z,38W+C(S,R==(#T@)T]U86YA:&%M($EL92!,:69O=2<[
M"B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M,C$N-#@S.C$V."XP
M,S,G72`]("=,82!2;V-H92!);&4@36%R92<["B1C;V]R9&EN871E<ULG3F5W
M($-A;&5D;VYI82==6R<M,C(N,#$W.C$V-BXR,3<G72`]("=,82!4;VYT;W5T
M82!.;&QE+4-A;&5D;VYI92<["B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI
M82==6R<M,C(N,C8W.C$V-BXT-3`G72`]("=.;W5M96$@3FQL92U#86QE9&]N
M:64G.PHD8V]O<F1I;F%T97-;)TYE=R!#86QE9&]N:6$G75LG+3(R+C8P,#HQ
M-C<N-#4P)UT@/2`G36]U92!);&4@1&5S(%!I;G,G.PHD8V]O<F1I;F%T97-;
M)TYE=R!:96%L86YD)UU;)S$N.3@S.BTQ-3<N-#@S)UT@/2`G0VAR:7-T;6%S
M("\@0V%S<VED>2<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+3(Y
M+C(U,#HM,3<W+CDQ-R==(#T@)U)A;W5L($ES;&%N9"P@2V5R;6%D96,@27-L
M86YD)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<S+C@U,#HM,34Y
M+C,V-R==(#T@)T9A;FYI;F<@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=.97<@
M6F5A;&%N9"==6R<M,S8N-S@S.C$W-"XV,S,G72`]("=7:&5N=6%P86DG.PHD
M8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTS-RXP,3<Z,3<T+C@P,"==
M(#T@)T%U8VML86YD($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L
M86YD)UU;)RTS-RXV-C<Z,3<V+C(P,"==(#T@)U1A=7)A;F=A($%E<F]D<F]M
M92!!=W,G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTS."XQ,3<Z
M,3<V+C,Q-R==(#T@)U)O=&]R=6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=.97<@6F5A;&%N9"==6R<M,S@N-C8W.C$W-RXY.#,G72`]("=':7-B;W)N
M92!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTS
M.2XP,3<Z,3<T+C$X,R==(#T@)TYE=R!0;'EM;W5T:"!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTT,"XR,#`Z,3<U+C,V-R==
M(#T@)T]H86ME82<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+30P
M+CDP,#HQ-S0N.3@S)UT@/2`G4&%R87!A<F%U;74@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M-#$N,S,S.C$W-"XX,#`G72`]
M("=796QL:6YG=&]N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L
M86YD)UU;)RTT,BXT,3<Z,3<S+C<P,"==(#T@)TMA:6MO=7)A)SL*)&-O;W)D
M:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M-#(N-S$W.C$W,"XY.#,G72`]("=(
M;VMI=&EK82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD
M)UU;)RTT,RXT.#,Z,3<R+C4U,"==(#T@)T-H<FES=&-H=7)C:"<["B1C;V]R
M9&EN871E<ULG3F5W(%IE86QA;F0G75LG+30S+CDU,#HM,3<V+C4V-R==(#T@
M)T-H871H86T@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==
M6R<M-#4N.3,S.C$W,"XR,#`G72`]("=$=6YE9&EN($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+30V+C<P,#HQ-C@N-34P)UT@
M/2`G26YV97)C87)G:6QL($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG3FEC
M87)A9W5A)UU;)S$Q+C0Q-SHM.#4N.#,S)UT@/2`G4FEV87,G.PHD8V]O<F1I
M;F%T97-;)TYI8V%R86=U82==6R<Q,BXP,#`Z+3@V+C<V-R==(#T@)T)L=65F
M:65L9',G.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U82==6R<Q,BXQ,#`Z+3@U
M+C,V-R==(#T@)TIU:6=A;'!A)SL*)&-O;W)D:6YA=&5S6R=.:6-A<F%G=6$G
M75LG,3(N,34P.BTX-BXQ-C<G72`]("=-86YA9W5A($$N($,N(%-A;F1I;F\G
M.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U82==6R<Q,BXV,S,Z+3@W+C$S,R==
M(#T@)T-H:6YA;F1E9V$G.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U82==6R<Q
M,RXP.#,Z+3@U+CDX,R==(#T@)TII;F]T96=A)SL*)&-O;W)D:6YA=&5S6R=.
M:6-A<F%G=6$G75LG,30N,#4P.BTX,RXS-C<G72`]("=0=65R=&\@0V%B97IA
M<R<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,3$N.#@S.C,N-#4P)UT@/2`G
M1V%Y82<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,3,N,C,S.C$Q+CDX,R==
M(#T@)TUA:6YE+5-O<F]A)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==6R<Q,RXT
M,3<Z,3(N-S@S)UT@/2`G1&EF9F$G.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;
M)S$S+C0V-SHW+C`X,R==(#T@)TUA<F%D:2<["B1C;V]R9&EN871E<ULG3FEG
M97(G75LG,3,N-#@S.C(N,38W)UT@/2`G3FEA;65Y+4%E<F\G.PHD8V]O<F1I
M;F%T97-;)TYI9V5R)UU;)S$S+C<X,SHX+CDX,R==(#T@)UII;F1E<B<["B1C
M;V]R9&EN871E<ULG3FEG97(G75LG,3,N.#`P.C4N,C4P)UT@/2`G0FER;FDM
M3EPG2V]N;FDG.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$S+CDX,SHQ,"XS
M,#`G72`]("=';W5R92<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,30N,C`P
M.C$N-#4P)UT@/2`G5&EL;&%B97)Y)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==
M6R<Q-"XY,#`Z-2XR-3`G72`]("=486AO=6$G.PHD8V]O<F1I;F%T97-;)TYI
M9V5R)UU;)S$V+CDV-SHW+CDX,R==(#T@)T%G861E>B<["B1C;V]R9&EN871E
M<ULG3FEG97(G75LG,3@N-C@S.C$R+CDQ-R==(#T@)T)I;&UA)SL*)&-O;W)D
M:6YA=&5S6R=.:6=E<FEA)UU;)S$P+C8P,#HW+C0U,"==(#T@)TMA9'5N82<[
M"B1C;V]R9&EN871E<ULG3FEG97)I82==6R<Q,2XQ,S,Z-RXV.#,G72`]("=:
M87)I82<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<Q,2XX-3`Z,3,N,#@S
M)UT@/2`G36%I9'5G=7)I)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S$R
M+C`U,#HX+C4S,R==(#T@)TMA;F\G.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G
M75LG,3(N,38W.C8N-S`P)UT@/2`G1W5S874G.PHD8V]O<F1I;F%T97-;)TYI
M9V5R:6$G75LG,3,N,#$W.C4N,C4P)UT@/2`G4V]K;W1O)SL*)&-O;W)D:6YA
M=&5S6R=.:6=E<FEA)UU;)S0N.#4P.C<N,#$W)UT@/2`G4&]R="!(87)C;W5R
M="<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<T+CDV-SHX+C,U,"==(#T@
M)T-A;&%B87(G.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG-BXT-C<Z-RXU
M-3`G72`]("=%;G5G=2<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<V+C4X
M,SHS+C,S,R==(#T@)TQA9V]S("\@26ME:F$G.PHD8V]O<F1I;F%T97-;)TYI
M9V5R:6$G75LG-RXT,S,Z,RXY,#`G72`]("=)8F%D86XG.PHD8V]O<F1I;F%T
M97-;)TYI9V5R:6$G75LG-RXV.#,Z."XV,3<G72`]("=-86MU<F1I)SL*)&-O
M;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S<N-S@S.C0N-#@S)UT@/2`G3W-H;V=B
M;R<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<X+C0X,SHT+C4X,R==(#T@
M)TEL;W)I;B<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<Y+C$P,#HV+C`Q
M-R==(#T@)T)I9&$G.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG.2XR,S,Z
M,3(N-#8W)UT@/2`G66]L82<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<Y
M+C@V-SHX+CDP,"==(#T@)TIO<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S4X+C$P,#HV+C8S,R==(#T@)TQI<W1A($9L>7!L87-S)SL*)&-O;W)D:6YA
M=&5S6R=.;W)W87DG75LG-3@N,C`P.C@N,#@S)UT@/2`G2W)I<W1I86YS86YD
M("\@2VIE=FEK)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3@N.#@S.C4N
M-C,S)UT@/2`G4W1A=F%N9V5R("\@4V]L82<["B1C;V]R9&EN871E<ULG3F]R
M=V%Y)UU;)S4Y+C$X,SHY+C4V-R==(#T@)U-K:65N+4=E:71E<GEG9V5N)SL*
M)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3DN,C`P.C$P+C(V-R==(#T@)U1O
M<G`G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<U.2XS-3`Z-2XR,3<G72`]
M("=(875G97-U;F0@+R!+87)M;WDG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==
M6R<U.2XS.#,Z,3`N-S@S)UT@/2`G4GEG9V4G.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<U.2XY,#`Z,3`N-C,S)UT@/2`G3W-L;R`O($9O<FYE8G4G.PHD
M8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,"XR,#`Z,3$N,#@S)UT@/2`G3W-L
M;R`O($=A<F1E<FUO96XG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,"XR
M.#,Z-2XR,S,G72`]("="97)G96X@+R!&;&5S;&%N9"<["B1C;V]R9&EN871E
M<ULG3F]R=V%Y)UU;)S8P+C8U,#HV+C4P,"==(#T@)U9O<W,M0F\G.PHD8V]O
M<F1I;F%T97-;)TYO<G=A>2==6R<V,2XP,#`Z.2XS,#`G72`]("=&86=E<FYE
M<R!,96ER:6XG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,2XQ-3`Z-RXQ
M,S,G72`]("=3;V=N9&%L("\@2&%U:V%S96XG.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<V,2XU.#,Z-2XP,S,G72`]("=&;&]R;R<["B1C;V]R9&EN871E
M<ULG3F]R=V%Y)UU;)S8Q+C@S,SHV+C$Q-R==(#T@)U-A;F1A;F4@+R!!;F1A
M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C(N,3@S.C8N,#8W)UT@/2`G
M3W)S=&$M5F]L9&$@+R!(;W9D96XG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==
M6R<V,BXU-C<Z-BXQ,3<G72`]("=!;&5S=6YD("\@5FEG<F$G.PHD8V]O<F1I
M;F%T97-;)TYO<G=A>2==6R<V,BXU.#,Z,3$N,S4P)UT@/2`G4F]R;W,@3'5F
M=&AA=FXG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,BXW-3`Z-RXR-C<G
M72`]("=-;VQD92`O($%R;R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8S
M+C$Q-SHW+C@S,R==(#T@)TMR:7-T:6%N<W5N9"`O($MV97)N8F5R9V5T)SL*
M)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C,N-#8W.C$P+CDS,R==(#T@)U1R
M;VYD:&5I;2`O(%9A97)N97,G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V
M,RXW,#`Z.2XV,#`G72`]("=/<FQA;F0@26EI)SL*)&-O;W)D:6YA=&5S6R=.
M;W)W87DG75LG-C0N-#8W.C$Q+C4X,R==(#T@)TYA;7-O<R!,=69T:&%V;B<[
M"B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8T+C@S,SHQ,2XQ-3`G72`]("=2
M;W)V:6L@+R!2>75M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C4N-#8W
M.C$R+C(Q-R==(#T@)T)R;VYN;WES=6YD("\@0G)O;FYO>2<["B1C;V]R9&EN
M871E<ULG3F]R=V%Y)UU;)S8U+C@P,#HQ,RXQ,S,G72`]("=-;W-J;V5N($MJ
M865R<W1A9"<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8U+CDV-SHQ,BXT
M-C<G72`]("=386YD;F5S<VIO96X@+R!3=&]K:V$G.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<V-BXS-C<Z,30N,S`P)UT@/2`G36\@22!286YA("\@4F]S
M<W9O;&PG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V-RXR-C<Z,30N,S8W
M)UT@/2`G0F]D;R!6:2<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8W+C4Q
M-SHQ,BXQ,#`G72`]("=2;W-T($9L>7!L87-S)SL*)&-O;W)D:6YA=&5S6R=.
M;W)W87DG75LG-C@N,34P.C$S+C8Q-R==(#T@)TQE:VYE<R<["B1C;V]R9&EN
M871E<ULG3F]R=V%Y)UU;)S8X+C(U,#HQ-"XV-C<G72`]("=3=F]L=F%E<B`O
M($AE;&QE)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C@N-#8W.C$W+C4P
M,"==(#T@)TYA<G9I:R!):6DG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V
M."XU,3<Z,38N-C@S)UT@/2`G179E;F5S)SL*)&-O;W)D:6YA=&5S6R=.;W)W
M87DG75LG-C@N-3@S.C$U+C`Q-R==(#T@)U-T;W)K;6%R:VYE<R`O(%-K86=E
M;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C`P,#HR,RXP,S,G72`]
M("=+875T;VME:6YO)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-CDN,#8W
M.C$X+C4S,R==(#T@)T)A<F1U9F]S<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S8Y+C,P,#HQ-BXQ-3`G72`]("=!;F1O>6$G.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<V.2XV.#,Z,3@N.3$W)UT@/2`G5')O;7-O("\@3&%N9VYE
M<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C<S,SHR.2XY,#`G72`]
M("=+:7)K96YE<R!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S8Y+C<X,SHR,"XY-C<G72`]("=3;W)K:F]S96XG.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<V.2XY.#,Z,C,N,S8W)UT@/2`G06QT82!,=69T:&%V;B<[
M"B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<P+C`V-SHR-"XY.#,G72`]("="
M86YA:R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<P+C`V-SHR.2XX-3`G
M72`]("=6861S;R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<P+C,U,#HS
M,2XP-3`G72`]("=3=F%R=&YE<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S<P+C8V-SHR,RXV-C<G72`]("=(86UM97)F97-T)SL*)&-O;W)D:6YA=&5S
M6R=.;W)W87DG75LG-S`N.#8W.C(Y+C`S,R==(#T@)T)E<FQE=F%G)SL*)&-O
M;W)D:6YA=&5S6R=.;W)W87DG75LG-S`N.3,S.BTX+C8V-R==(#T@)TIA;B!-
M87EE;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<Q+C`Q-SHR-2XY.#,G
M72`]("=(;VYN:6YG<W9A9R`O(%9A;&%N)SL*)&-O;W)D:6YA=&5S6R=.;W)W
M87DG75LG-S$N,#,S.C(W+C@S,R==(#T@)TUE:&%M;B<["B1C;V]R9&EN871E
M<ULG3F]R=V%Y)UU;)S<T+C4Q-SHQ.2XP,3<G72`]("=":F]R;F]Y82<["B1C
M;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<V+C4P,#HR-2XP-C<G72`]("=(;W!E
M;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<X+C(U,#HQ-2XT-C<G72`]
M("=3=F%L8F%R9"!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S<X+CDQ-SHQ,2XY,S,G72`]("=.>2U!;&5S=6YD($EI)SL*)&-O;W)D:6YA
M=&5S6R=/;6%N)UU;)S$W+C`S,SHU-"XP.#,G72`]("=386QA;&%H)SL*)&-O
M;W)D:6YA=&5S6R=/;6%N)UU;)S$W+C8V-SHU-"XP,S,G72`]("=4:'5M<F%I
M="<["B1C;V]R9&EN871E<ULG3VUA;B==6R<R,"XV-C<Z-3@N.3`P)UT@/2`G
M36%S:7)A:"<["B1C;V]R9&EN871E<ULG3VUA;B==6R<R,BXS-3`Z-38N-#@S
M)UT@/2`G1F%H=60G.PHD8V]O<F1I;F%T97-;)T]M86XG75LG,C(N-3,S.C4Y
M+C0X,R==(#T@)U-U<B<["B1C;V]R9&EN871E<ULG3VUA;B==6R<R,RXP-C<Z
M-3<N-C4P)UT@/2`G4V%I<2<["B1C;V]R9&EN871E<ULG3VUA;B==6R<R,RXU
M.#,Z-3@N,C@S)UT@/2`G4V5E8BP@26YT97)N871I;VYA;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S(T+C(S,SHU-2XW.#,G72`]("="=7)A
M:6UI)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S(T+C0V-SHU-BXV,S,G72`]
M("=3;VAA<B!-86II<R<["B1C;V]R9&EN871E<ULG3VUA;B==6R<R-BXR,3<Z
M-38N,C,S)UT@/2`G2VAA<W-A8B<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG
M75LG,C0N.3`P.C8W+C$S,R==(#T@)TMA<F%C:&D@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG4&%K:7-T86XG75LG,C4N,#8W.C8Q+C@P,"==(#T@)TII=V%N
M:2<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,C4N,S@S.C8X+C0Q-R==
M(#T@)TAY9&5R86)A9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A
M;B==6R<R-BXR-3`Z-C@N,S8W)UT@/2`G3F%W86)S:&%H)SL*)&-O;W)D:6YA
M=&5S6R=086MI<W1A;B==6R<R-BXY-C<Z-C0N,3`P)UT@/2`G4&%N:F=U<B<[
M"B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,C@N,S`P.C8X+C0V-R==(#T@
M)TIA8V]B86)A9"<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,CDN-34P
M.C8W+C@X,R==(#T@)U-I8FDG.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;
M)S,P+C(P,#HW,2XT,S,G72`]("=-=6QT86XG.PHD8V]O<F1I;F%T97-;)U!A
M:VES=&%N)UU;)S,P+C(U,#HV-BXX.#,G72`]("=1=65T=&$@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,S$N-3$W.C<T+C0P,"==(#T@
M)TQA:&]R92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S
M,2XU-3`Z-S0N,S,S)UT@/2`G3&%H;W)E($-I='DG.PHD8V]O<F1I;F%T97-;
M)U!A:VES=&%N)UU;)S,Q+C@Q-SHW,"XY,3<G72`]("=$97)A($ES;6%I;"!+
M:&%N)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,BXP-3`Z-S(N-C8W
M)UT@/2`G4V%R9V]D:&$G.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,R
M+C4U,#HW,2XU,3<G72`]("=-:6%N=V%L:2<["B1C;V]R9&EN871E<ULG4&%K
M:7-T86XG75LG,S,N-C$W.C<S+C$P,"==(#T@)TES;&%M86)A9"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S-"XP,3<Z-S$N-3@S)UT@
M/2`G4&5S:&%W87(G.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,T+C`V
M-SHW,2XY.#,G72`]("=2:7-A;'!U<B<["B1C;V]R9&EN871E<ULG4&%L874G
M75LG-RXS-C<Z,3,T+C4S,R==(#T@)T)A8F5L=&AU87`@27-L86YD+"!"86)E
M;'1H=6%P+TMO<F]R($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U!A;F%M82==
M6R<X+C`X,SHM.#`N.34P)UT@/2`G4V%N=&EA9V\G.PHD8V]O<F1I;F%T97-;
M)U!A;F%M82==6R<X+C0P,#HM.#(N-#$W)UT@/2`G1&%V:60G.PHD8V]O<F1I
M;F%T97-;)U!A;F%M82==6R<X+CDQ-SHM-SDN-C`P)UT@/2`G2&]W87)D($%I
M<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=086YA;6$G75LG.2XP-3`Z
M+3<Y+C,V-R==(#T@)U1O8W5M96XG.PHD8V]O<F1I;F%T97-;)U!A;F%M82==
M6R<Y+C,S,SHM-SDN.3@S)UT@/2`G1G0@4VAE<FUA;B!2;V-O8B<["B1C;V]R
M9&EN871E<ULG4&%P=6$@3F5W($=U:6YE82==6R<M,RXU-C<Z,30S+C8S,R==
M(#T@)U=E=V%K)SL*)&-O;W)D:6YA=&5S6R=087!U82!.97<@1W5I;F5A)UU;
M)RTU+C(Q-SHQ-#4N-S@S)UT@/2`G36%D86YG)SL*)&-O;W)D:6YA=&5S6R=0
M87!U82!.97<@1W5I;F5A)UU;)RTY+C0S,SHQ-#<N,C$W)UT@/2`G36]R97-B
M>2<["B1C;V]R9&EN871E<ULG4&%R86=U87DG75LG+3(P+C<Q-SHM-C$N.3$W
M)UT@/2`G3G5E=F$@07-U;F-I;VXG.PHD8V]O<F1I;F%T97-;)U!A<F%G=6%Y
M)UU;)RTR,BXP,3<Z+38P+C8P,"==(#T@)TUA<FES8V%L($5S=&EG87)R:6)I
M82<["B1C;V]R9&EN871E<ULG4&%R86=U87DG75LG+3(S+C0Q-SHM-3<N,S`P
M)UT@/2`G0V]N8V5P8VEO;B<["B1C;V]R9&EN871E<ULG4&%R86=U87DG75LG
M+3(U+C(V-SHM-3<N-C,S)UT@/2`G07-U;F-I;VX@+R!!97)O<'5E<G1O)SL*
M)&-O;W)D:6YA=&5S6R=087)A9W5A>2==6R<M,C<N,S$W.BTU-2XX,S,G72`]
M("=%;F-A<FYA8VEO;B<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3`N-S,S
M.BTW,RXW.#,G72`]("=!=&%L87EA)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;
M)RTQ,BXP,#`Z+3<W+C$Q-R==(#T@)TQI;6$M0V%L;&%O("\@065R;W`N($EN
M=&5R;F%C:6]N86P@2F]R9V5C:&%V97HG.PHD8V]O<F1I;F%T97-;)U!E<G4G
M75LG+3$R+C8S,SHM-CDN,C`P)UT@/2`G4'5E<G1O($UA;&1O;F%D;R<["B1C
M;V]R9&EN871E<ULG4&5R=2==6R<M,3,N,3,S.BTW-"XR,3<G72`]("=!>6%C
M=6-H;R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3,N-34P.BTW,2XY.#,G
M72`]("=#=7IC;R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3,N-S$W.BTW
M,RXS-3`G72`]("=!;F1A:'5A>6QA)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;
M)RTQ,RXW-3`Z+3<V+C(X,R==(#T@)U!I<V-O)SL*)&-O;W)D:6YA=&5S6R=0
M97)U)UU;)RTQ-2XS.#,Z+3<U+C$V-R==(#T@)U-A;B!*=6%N)SL*)&-O;W)D
M:6YA=&5S6R=097)U)UU;)RTQ-2XT.#,Z+3<P+C$U,"==(#T@)TIU;&EA8V$G
M.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3$V+C,Q-SHM-S$N-34P)UT@/2`G
M07)E<75I<&$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3$X+C`V-SHM-S`N
M,S`P)UT@/2`G5&%C;F$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3,N-34P
M.BTX,"XT,#`G72`]("=4=6UB97,G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG
M+3,N-S4P.BTW,RXR-3`G72`]("=)<75I=&]S)SL*)&-O;W)D:6YA=&5S6R=0
M97)U)UU;)RTT+C4V-SHM.#$N,C4P)UT@/2`G5&%L87)A)SL*)&-O;W)D:6YA
M=&5S6R=097)U)UU;)RTU+C$X,SHM.#`N-C`P)UT@/2`G4&EU<F$G.PHD8V]O
M<F1I;F%T97-;)U!E<G4G75LG+34N.3`P.BTW-BXP.#,G72`]("=9=7)I;6%G
M=6%S)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTV+C`U,#HM-S<N,34P)UT@
M/2`G4FEO:F$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+38N,C$W.BTW-RXX
M,S,G72`]("=#:&%C:&%P;WEA<R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M
M-BXT-3`Z+3<V+C,X,R==(#T@)U1A<F%P;W1O)SL*)&-O;W)D:6YA=&5S6R=0
M97)U)UU;)RTV+C<X,SHM-SDN.#,S)UT@/2`G0VAI8VQA>6\G.PHD8V]O<F1I
M;F%T97-;)U!E<G4G75LG+3<N,3,S.BTW."XT-C<G72`]("=#86IA;6%R8V$G
M.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3<N,C$W.BTW-BXW,3<G72`]("=*
M=6%N:G5I)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTX+C$P,#HM-SDN,#,S
M)UT@/2`G5')U:FEL;&\G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3@N-#$W
M.BTW-"XV,#`G72`]("=0=6-A;&QP82<["B1C;V]R9&EN871E<ULG4&5R=2==
M6R<M.2XQ,S,Z+3<U+CDU,"==(#T@)U1I;F=O($UA<FEA)SL*)&-O;W)D:6YA
M=&5S6R=097)U)UU;)RTY+C$V-SHM-S@N-3$W)UT@/2`G0VAI;6)O=&4G.PHD
M8V]O<F1I;F%T97-;)U!E<G4G75LG+3DN,S4P.BTW-RXV,#`G72`]("=!;G1A
M($AU87)A>B<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M.2XY,#`Z+3<U+C<U
M,"==(#T@)TAU86YU8V\G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;
M)S$P+C,P,#HQ,C,N.38W)UT@/2`G36%C=&%N)SL*)&-O;W)D:6YA=&5S6R=0
M:&EL:7!P:6YE<R==6R<Q,"XW,#`Z,3(R+C4V-R==(#T@)TEL;VEL;R<["B1C
M;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3$N,#,S.C$R-BXW,S,G72`]
M("='=6EU86XG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$Q+C(U
M,#HQ,C4N,#`P)UT@/2`G5&%C;&]B86XG.PHD8V]O<F1I;F%T97-;)U!H:6QI
M<'!I;F5S)UU;)S$Q+C4X,SHQ,C(N-S4P)UT@/2`G4F]X87,G.PHD8V]O<F1I
M;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$R+C,U,#HQ,C$N,#,S)UT@/2`G4V%N
M($IO<V4G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$R+C,V-SHQ
M,C,N-C$W)UT@/2`G36%S8F%T92<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN
M97,G75LG,3(N-#@S.C$R-"XV,S,G72`]("=#871A<FUA;B<["B1C;V]R9&EN
M871E<ULG4&AI;&EP<&EN97,G75LG,3(N-3@S.C$R,BXR-C<G72`]("=2;VUB
M;&]N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,RXQ,S,Z,3(S
M+C<S,R==(#T@)TQE9V%S<&DG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S
M)UU;)S$S+C0Q-SHQ,C$N,3@S)UT@/2`G0V%L87!A;B<["B1C;V]R9&EN871E
M<ULG4&AI;&EP<&EN97,G75LG,3,N-3@S.C$R-"XR,S,G72`]("=6:7)A8R<[
M"B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,30N,#@S.C$R,BXP,3<G
M72`]("=!;&%B870G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$T
M+C$S,SHQ,C(N.3@S)UT@/2`G1&%E="<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG,30N-3`P.C$R,"XY,3<G72`]("=386YG;&5Y(%!O:6YT)SL*
M)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-"XU,3<Z,3(Q+C`P,"==
M(#T@)TYI;F]Y($%Q=6EN;R!);G1E<BU.871I;VYA;"!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-"XX,#`Z,3(P+C(V-R==(#T@
M)U-U8FEC($)A>2!796%T:&5R(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)U!H
M:6QI<'!I;F5S)UU;)S$U+C$V-SHQ,C`N-38W)UT@/2`G0VQA<FL@06(G.PHD
M8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$U+C,S,SHQ,3DN.38W)UT@
M/2`G26)A)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-2XW-C<Z
M,3(Q+C4V-R==(#T@)T)A;&5R)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE
M<R==6R<Q-BXT,3<Z,3(P+C8P,"==(#T@)T)A9W5I;R<["B1C;V]R9&EN871E
M<ULG4&AI;&EP<&EN97,G75LG,3<N-38W.C$R,"XS.#,G72`]("=6:6=A;B<[
M"B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3<N-C$W.C$R,2XW,S,G
M72`]("=4=6=U96=A<F%O)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==
M6R<Q."XQ.#,Z,3(P+C4S,R==(#T@)TQA;V%G)SL*)&-O;W)D:6YA=&5S6R=0
M:&EL:7!P:6YE<R==6R<Q."XS-C<Z,3(Q+C8S,R==(#T@)T%P87)R:2<["B1C
M;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,C`N-#4P.C$R,2XY-C<G72`]
M("="87-C;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG-BXQ,3<Z
M,3(U+C$X,R==(#T@)T=E;BX@4V%N=&]S)SL*)&-O;W)D:6YA=&5S6R=0:&EL
M:7!P:6YE<R==6R<V+CDP,#HQ,C(N,#8W)UT@/2`G6F%M8F]A;F=A)SL*)&-O
M;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<W+C$Q-SHQ,C4N-C4P)UT@/2`G
M1&%V86\@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG
M-RXQ-C<Z,3(T+C(Q-R==(#T@)T-O=&]B871O)SL*)&-O;W)D:6YA=&5S6R=0
M:&EL:7!P:6YE<R==6R<X+C$U,#HQ,C4N,#@S)UT@/2`G36%L87EB86QA>2<[
M"B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG."XT.#,Z,3(T+C8S,R==
M(#T@)T-A9V%Y86X@1&4@3W)O)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE
M<R==6R<X+C8P,#HQ,C,N,S4P)UT@/2`G1&EP;VQO9R<["B1C;V]R9&EN871E
M<ULG4&AI;&EP<&EN97,G75LG.2XS,#`Z,3(S+C,P,"==(#T@)T1U;6%G=65T
M92<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG.2XV,#`Z,3(S+C@U
M,"==(#T@)U1A9V)I;&%R86XG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S
M)UU;)SDN-S4P.C$Q."XW,S,G72`]("=0=65R=&\@4')I;F-E<V$G.PHD8V]O
M<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)SDN.#`P.C$R-2XU,#`G72`]("=3
M=7)I9V%O)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Y+CDS,SHQ
M,C4N-3$W)UT@/2`G0G5T=6%N)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG
M-3`N,#@S.C$Y+C@P,"==(#T@)TMR86MO=R<["B1C;V]R9&EN871E<ULG4&]L
M86YD)UU;)S4P+C$P,#HR,BXP-3`G72`]("=2>F5S>F]W+4IA<VEO;FMA)SL*
M)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3`N,C,S.C$Y+C`S,R==(#T@)TMA
M=&]W:6-E)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3$N,3`P.C$V+C@X
M,R==(#T@)U=R;V-L87<@26DG.PHD8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U
M,2XY,S,Z,34N-3,S)UT@/2`G6FEE;&]N82!';W)A)SL*)&-O;W)D:6YA=&5S
M6R=0;VQA;F0G75LG-3(N,38W.C(P+CDV-R==(#T@)U=A<G-Z87=A+4]K96-I
M92<["B1C;V]R9&EN871E<ULG4&]L86YD)UU;)S4R+C0Q-SHQ-BXX,S,G72`]
M("=0;WIN86XG.PHD8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U,RXT,#`Z,30N
M-C$W)UT@/2`G4WIC>F5C:6XG.PHD8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U
M-"XR,#`Z,38N,34P)UT@/2`G2V]S>F%L:6XG.PHD8V]O<F1I;F%T97-;)U!O
M;&%N9"==6R<U-"XS.#,Z,3@N-#8W)UT@/2`G1V1A;G-K+5)E8FEE8VAO=V\G
M.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,R+C8X,SHM,38N-S8W)UT@
M/2`G1G5N8VAA;"`O(%,N($-A=&%R:6YA)SL*)&-O;W)D:6YA=&5S6R=0;W)T
M=6=A;"==6R<S,RXP-C<Z+3$V+C,U,"==(#T@)U!O<G1O(%-A;G1O)SL*)&-O
M;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S-BXY-C<Z+3(U+C$V-R==(#T@)U-A
M;G1A($UA<FEA($%C;W)E<R<["B1C;V]R9&EN871E<ULG4&]R='5G86PG75LG
M,S<N,#$W.BTW+CDV-R==(#T@)T9A<F\@+R!!97)O<&]R=&\G.PHD8V]O<F1I
M;F%T97-;)U!O<G1U9V%L)UU;)S,W+C<S,SHM,C4N-S`P)UT@/2`G4&]N=&$@
M1&5L9V%D82`O($YO<F1E;&$@06-O<F5S)SL*)&-O;W)D:6YA=&5S6R=0;W)T
M=6=A;"==6R<S."XP,3<Z+3<N.#8W)UT@/2`G0F5J82<["B1C;V]R9&EN871E
M<ULG4&]R='5G86PG75LG,S@N-3$W.BTR."XW,3<G72`]("=(;W)T82`O($-A
M<W1E;&\@0G)A;F-O($%C;W)E<R<["B1C;V]R9&EN871E<ULG4&]R='5G86PG
M75LG,S@N-S8W.BTR-RXQ,#`G72`]("=,86IE<R!!8V]R97,G.PHD8V]O<F1I
M;F%T97-;)U!O<G1U9V%L)UU;)S,X+C<V-SHM.2XQ,S,G72`]("=,:7-B;V$@
M+R!0;W)T96QA)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S.2XT-3`Z
M+3,Q+C$S,R==(#T@)T9L;W)E<R!!8V]R97,G.PHD8V]O<F1I;F%T97-;)U!O
M<G1U9V%L)UU;)S0Q+C(S,SHM."XV.#,G72`]("=0;W)T;R`O(%!E9')A<R!2
M=6)R87,G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S0Q+C(V-SHM-RXW
M,3<G72`]("=6:6QA(%)E86PG.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;
M)S0Q+C@P,#HM-BXW,S,G72`]("="<F%G86YC82<["B1C;V]R9&EN871E<ULG
M46%T87(G75LG,C4N,C4P.C4Q+C4V-R==(#T@)T1O:&$@26YT97)N871I;VYA
M;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=2975N:6]N)UU;)RTR,"XX.#,Z
M-34N-3$W)UT@/2`G4V%I;G0M1&5N:7,@+R!':6QL;W0G.PHD8V]O<F1I;F%T
M97-;)U)E=6YI;VXG75LG+3(Q+C,S,SHU-2XT.#,G72`]("=386EN="U0:65R
M<F4G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#0N,C,S.C(S+C@V-R==
M(#T@)T-R86EO=F$G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#0N,S,S
M.C(X+C0S,R==(#T@)TMO9V%L;FEC96%N=2<["B1C;V]R9&EN871E<ULG4F]M
M86YI82==6R<T-"XU,#`Z,C8N,3,S)UT@/2`G0G5C=7)E<W1I("\@26UH)SL*
M)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0T+C4U,#HR-BXQ,#`G72`]("="
M=6-U<F5S=&D@3W1O<&5N:2<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T
M-2XQ.#,Z,C@N.#$W)UT@/2`G5'5L8V5A)SL*)&-O;W)D:6YA=&5S6R=2;VUA
M;FEA)UU;)S0U+C0Q-SHR,BXR-3`G72`]("=#87)A;G-E8F5S)SL*)&-O;W)D
M:6YA=&5S6R=2;VUA;FEA)UU;)S0U+C<V-SHR,2XR-3`G72`]("=4:6UI<V]A
M<F$G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#4N.#`P.C(T+C$U,"==
M(#T@)U-I8FEU)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0V+C(P,#HR
M,2XT,#`G72`]("=!<F%D)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0V
M+C4S,SHR-"XU,S,G72`]("=4:7)G=2!-=7)E<R<["B1C;V]R9&EN871E<ULG
M4F]M86YI82==6R<T-BXU.#,Z,C8N.38W)UT@/2`G0F%C874G.PHD8V]O<F1I
M;F%T97-;)U)O;6%N:6$G75LG-#8N-S@S.C(S+C4V-R==(#T@)T-L=6HM3F%P
M;V-A)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0W+C`U,#HR,2XY,S,G
M72`]("=/<F%D96$G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#<N,38W
M.C(W+C8S,R==(#T@)TEA<VDG.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG
M-#<N-C4P.C(V+C(U,"==(#T@)U-U8V5A=F$@+R!386QC96$G.PHD8V]O<F1I
M;F%T97-;)U)O;6%N:6$G75LG-#<N-C8W.C(S+C4X,R==(#T@)T)A:6$@36%R
M92<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-RXX,#`Z,C(N.#@S)UT@
M/2`G4V%T=2!-87)E)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I
M;VXG75LG-#,N,3$W.C$S,2XY,S,G72`]("=6;&%D:79O<W1O:R<["B1C;V]R
M9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0S+C0S,SHS.2XY,#`G
M72`]("=!9&QE<B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N
M)UU;)S0T+C(S,SHT,RXP-C<G72`]("=-:6YE<F%L7"=.>64@5F]D>2<["B1C
M;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0U+C`S,SHS.2XQ
M-3`G72`]("=+<F%S;F]D87(G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<T-BXS-C<Z-#0N,S,S)UT@/2`G16QI<W1A)SL*)&-O;W)D
M:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-#8N.34P.C$T,BXW,3<G
M72`]("=9=7IH;F\M4V%K:&%L:6YS:R<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S0W+C(V-SHS.2XX,3<G72`]("=2;W-T;W8M3F$M
M1&]N=2<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0X
M+C4Q-SHQ,S4N,38W)UT@/2`G2&%B87)O=G-K)SL*)&-O;W)D:6YA=&5S6R=2
M=7-S:6%N($9E9&5R871I;VXG75LG-#@N-S@S.C0T+C,V-R==(#T@)U9O;&=O
M9W)A9"<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0Y
M+C0U,#HQ,S8N-38W)UT@/2`G5')O:6-K;V4G.PHD8V]O<F1I;F%T97-;)U)U
M<W-I86X@1F5D97)A=&EO;B==6R<U,2XV-3`Z,SDN,C4P)UT@/2`G5F]R;VYE
M>B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4Q+C@S
M,SHQ,#<N-C`P)UT@/2`G56QA;BU59&4G.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<U,BXP.#,Z,3$S+C0X,R==(#T@)T-H:71A)SL*
M)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3(N,38W.C$P
M.2XW.#,G72`]("=(;W)I;G-K)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E
M9&5R871I;VXG75LG-3(N,C8W.C$P-"XS,3<G72`]("=)<FMU='-K)SL*)&-O
M;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3(N.#$W.C$P-"XW
M-C<G72`]("=5<W1<)T]R9'EN<VMI:B<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S4S+C`V-SHQ,S(N.3@S)UT@/2`G16MI;6-H86XG
M.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,RXP.#,Z
M,34X+C4X,R==(#T@)U!E=')O<&%V;&]V<VLM2V%M8VAA='-K:6HG.PHD8V]O
M<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,RXQ,3<Z-#4N,#$W
M)UT@/2`G4&5N>F$G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO
M;B==6R<U,RXR,#`Z-3`N,34P)UT@/2`G4V%M87)A)SL*)&-O;W)D:6YA=&5S
M6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3,N,C4P.C,T+C,Q-R==(#T@)T)R
M:F%N<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U
M,RXT,S,Z.#,N-3$W)UT@/2`G0F%R;F%U;"<["B1C;V]R9&EN871E<ULG4G5S
M<VEA;B!&961E<F%T:6]N)UU;)S4T+C@X,SHY.2XP,S,G72`]("=.:7IH;F5U
M9&EN<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U
M-2XP.#,Z.#(N.3`P)UT@/2`G3F]V;W-I8FER<VLG.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<U-BXS-3`Z,S`N-C$W)UT@/2`G5F5L
M:6MI92!,=6MI)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG
M75LG-38N.#,S.C$R-"XX-C<G72`]("=#=6Q<)TUA;B<["B1C;V]R9&EN871E
M<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4V+C@S,SHV,"XV,S,G72`]("=%
M:V%T97)I;F)U<F<G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO
M;B==6R<U-BXY,#`Z,S4N.#@S)UT@/2`G5'9E<B<["B1C;V]R9&EN871E<ULG
M4G5S<VEA;B!&961E<F%T:6]N)UU;)S4W+C<V-SHQ,#@N,#8W)UT@/2`G2VER
M96YS:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4W
M+C@U,#HQ,30N,C,S)UT@/2`G0F]D86IB;R<["B1C;V]R9&EN871E<ULG4G5S
M<VEA;B!&961E<F%T:6]N)UU;)S4X+C0U,#HY,BXQ-3`G72`]("=%;FES96IS
M:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4Y+C,Q
M-SHS.2XY,3<G72`]("=6;VQO9V1A)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N
M($9E9&5R871I;VXG75LG-3DN-34P.C$U,"XW.#,G72`]("=-86=A9&%N)SL*
M)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3DN.#@S.C0R
M+C<U,"==(#T@)U1O=%PG36$G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<U.2XY-C<Z,S`N,S`P)UT@/2`G4W0N(%!E=&5R8G5R9R<[
M"B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S8Q+C`Q-SHV
M.2XP,S,G72`]("=(86YT>2U-86YS:6IS:R<["B1C;V]R9&EN871E<ULG4G5S
M<VEA;B!&961E<F%T:6]N)UU;)S8Q+C(S,SHT-BXW,3<G72`]("=+;W1L87,G
M.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V,2XR-3`Z
M-S,N-3`P)UT@/2`G4W5R9W5T)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E
M9&5R871I;VXG75LG-C$N-C@S.C4S+C8X,R==(#T@)U5S=%PG+2!+=6QO;2<[
M"B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S8Q+C<Q-SHU
M,"XX,S,G72`]("=3>6MT>79K87(G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@
M1F5D97)A=&EO;B==6R<V,BXP,3<Z,3(Y+C<Q-R==(#T@)TIA:W5T<VLG.PHD
M8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V-"XT,3<Z+3$W
M,RXR,S,G72`]("="=6AT82!0<F]V:61E;FIA)SL*)&-O;W)D:6YA=&5S6R=2
M=7-S:6%N($9E9&5R871I;VXG75LG-C0N-3`P.C0P+C<S,R==(#T@)T%R:&%N
M9V5L7"=3:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;
M)S8T+C<X,SHQ-S<N-38W)UT@/2`G06YA9'ER)SL*)&-O;W)D:6YA=&5S6R=2
M=7-S:6%N($9E9&5R871I;VXG75LG-C@N.38W.C,S+C`U,"==(#T@)TUU<FUA
M;G-K)SL*)&-O;W)D:6YA=&5S6R=2=V%N9&$G75LG+3$N-C8W.C(Y+C(U,"==
M(#T@)T=I<V5N>6DG.PHD8V]O<F1I;F%T97-;)U)W86YD82==6R<M,2XY-C<Z
M,S`N,3$W)UT@/2`G2VEG86QI)SL*)&-O;W)D:6YA=&5S6R=386EN="!(96QE
M;F$G75LG+3<N.38W.BTQ-"XT,#`G72`]("=7:61E($%W86ME($9I96QD($%S
M8V5N<VEO;B!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)U-A:6YT($MI='1S(&%N
M9"!.979I<R==6R<Q-RXS,#`Z+38R+C8X,R==(#T@)T=O;&1E;B!2;V-K)SL*
M)&-O;W)D:6YA=&5S6R=386EN="!,=6-I82==6R<Q,RXW-3`Z+38P+CDU,"==
M(#T@)TAE=V%N;W)R82!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)U-A:6YT($QU8VEA)UU;)S$T+C`Q-SHM-C$N,#`P)UT@/2`G5FEG
M:64G.PHD8V]O<F1I;F%T97-;)U-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXG
M75LG-#8N-S8W.BTU-BXQ-C<G72`]("=386EN="U0:65R<F4G.PHD8V]O<F1I
M;F%T97-;)U-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S)UU;)S$S
M+C$S,SHM-C$N,C`P)UT@/2`G07)N;W,@5F%L92<["B1C;V]R9&EN871E<ULG
M4V%M;V$G75LG+3$S+C@P,#HM,3<Q+C<X,R==(#T@)T%P:6$@+R!5<&]L=2!)
M<VQA;F0G.PHD8V]O<F1I;F%T97-;)U-A;6]A)UU;)RTQ,RXX,3<Z+3$W,BXP
M,#`G72`]("=&86QE;VQO($EN=&P@+R!!<&EA)SL*)&-O;W)D:6YA=&5S6R=3
M86\@5&]M92!A;F0@4')I;F-I<&4G75LG,"XS.#,Z-BXW,3<G72`]("=3+B!4
M;VUE)SL*)&-O;W)D:6YA=&5S6R=386\@5&]M92!A;F0@4')I;F-I<&4G75LG
M,2XV-3`Z-RXT,3<G72`]("=0<FEN8VEP92<["B1C;V]R9&EN871E<ULG4V%U
M9&D@07)A8FEA)UU;)S$V+CDP,#HT,BXU.#,G72`]("=':7IA;B<["B1C;V]R
M9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$W+C0V-SHT-RXQ,3<G72`]("=3
M:&%R=7)A:"<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$W+C8Q
M-SHT-"XT,3<G72`]("=.86IR86XG.PHD8V]O<F1I;F%T97-;)U-A=61I($%R
M86)I82==6R<Q."XR,S,Z-#(N-C4P)UT@/2`G06)H82<["B1C;V]R9&EN871E
M<ULG4V%U9&D@07)A8FEA)UU;)S$X+C,P,#HT,BXX,#`G72`]("=+:&%M:7,@
M375S:&%I="<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$Y+CDX
M,SHT,BXV,3<G72`]("=":7-H82<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A
M8FEA)UU;)S(P+C,P,#HT,2XV,S,G72`]("=!;"!"86AA)SL*)&-O;W)D:6YA
M=&5S6R=3875D:2!!<F%B:6$G75LG,C`N-3`P.C0U+C(P,"==(#T@)U=A9&D@
M06P@1&%W87-S97(@06ER<&]R="<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A
M8FEA)UU;)S(Q+C0S,SHS.2XW-C<G72`]("=-86MK86@G.PHD8V]O<F1I;F%T
M97-;)U-A=61I($%R86)I82==6R<R,2XT.#,Z-#`N-34P)UT@/2`G5&%I9B<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(Q+C4P,#HS.2XR,#`G
M72`]("=*961D86@G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R
M,2XW,#`Z,SDN,3@S)UT@/2`G2F5D9&%H($MI;F<@06)D=6P@07II>B!);G1E
M<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I
M82==6R<R-"XQ-3`Z,S@N,#8W)UT@/2`G665N8F\G.PHD8V]O<F1I;F%T97-;
M)U-A=61I($%R86)I82==6R<R-"XU,#`Z-#0N,S4P)UT@/2`G1&%W861M:2<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(T+C4U,#HS.2XW,#`G
M72`]("=-861I;F%H)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG
M,C0N-S$W.C0V+C<S,R==(#T@)U)I>6%D:"<["B1C;V]R9&EN871E<ULG4V%U
M9&D@07)A8FEA)UU;)S(T+CDS,SHT-BXW,3<G72`]("=+:6YG($MH86QE9"!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R
M86)I82==6R<R-2XS,#`Z-#DN-#@S)UT@/2`G06P@06AS82<["B1C;V]R9&EN
M871E<ULG4V%U9&D@07)A8FEA)UU;)S(V+C(P,#HS-BXT-C<G72`]("=796IH
M)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C8N,C8W.C4P+C$U
M,"==(#T@)T1H86AR86XG.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==
M6R<R-BXS,#`Z-#,N-S8W)UT@/2`G1V%S<VEM)SL*)&-O;W)D:6YA=&5S6R=3
M875D:2!!<F%B:6$G75LG,C8N-#8W.C0Y+C<X,R==(#T@)T1A;6UA;2U+:6YG
M($9A:&0@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3
M875D:2!!<F%B:6$G75LG,C<N-#,S.C0Q+C8X,R==(#T@)TAA:6PG.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-RXY,#`Z-#4N-3,S)UT@/2`G
M2&%F<B!!;"U"871I;B<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;
M)S(X+C,Q-SHT-BXQ,3<G72`]("=!;"!187ES=6UA:"<["B1C;V]R9&EN871E
M<ULG4V%U9&D@07)A8FEA)UU;)S(X+C,V-SHS-BXV,#`G72`]("=486)U:R<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(Y+C8Q-SHT,RXT.#,G
M72`]("=2869H82<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(Y
M+C<X,SHT,"XQ,#`G72`]("=!;"U*;W5F)SL*)&-O;W)D:6YA=&5S6R=3875D
M:2!!<F%B:6$G75LG,S`N.3`P.C0Q+C$S,R==(#T@)T%R87(G.PHD8V]O<F1I
M;F%T97-;)U-A=61I($%R86)I82==6R<S,2XT,#`Z,S<N,C8W)UT@/2`G1W5R
M:6%T)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,S$N-C@S.C,X
M+C<S,R==(#T@)U1U<F%I9B<["B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q
M,BXT,#`Z+3$V+C<U,"==(#T@)T-A<"U3:VER<FEN9R<["B1C;V]R9&EN871E
M<ULG4V5N96=A;"==6R<Q,BXU-3`Z+3$V+C(V-R==(#T@)UII9W5I;F-H;W(G
M.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,3(N-38W.BTQ,BXR,3<G72`]
M("=+961O=6=O=2<["B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q,BXX.#,Z
M+3$T+CDV-R==(#T@)TMO;&1A)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;
M)S$S+C<V-SHM,3,N-C@S)UT@/2`G5&%M8F%C;W5N9&$G.PHD8V]O<F1I;F%T
M97-;)U-E;F5G86PG75LG,30N,3,S.BTQ-BXP-C<G72`]("=+86]L86-K)SL*
M)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$T+C8U,#HM,38N,C,S)UT@/2`G
M1&EO=7)B96PG.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,30N-S,S.BTQ
M-RXU,#`G72`]("=$86MA<B`O(%EO9F8G.PHD8V]O<F1I;F%T97-;)U-E;F5G
M86PG75LG,34N,S@S.BTQ-2XQ,3<G72`]("=,:6YG=65R92<["B1C;V]R9&EN
M871E<ULG4V5N96=A;"==6R<Q-2XV-3`Z+3$S+C(U,"==(#T@)TUA=&%M)SL*
M)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$V+C`U,#HM,38N-#4P)UT@/2`G
M4V%I;G0M3&]U:7,G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,38N-C4P
M.BTQ-"XY-C<G72`]("=0;V1O<B<["B1C;V]R9&EN871E<ULG4V5Y8VAE;&QE
M<R==6R<M-"XV-C<Z-34N-3$W)UT@/2`G4V5Y8VAE;&QE<R!);G1E<BU.871I
M;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=397EC:&5L;&5S)UU;)RTT
M+C8X,SHU-2XU,S,G72`]("=397EC:&5L;&5S($EN=&5R;F%T:6]N86P@06ER
M<&]R="!287=I;G-O;F1E(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)U-I97)R
M82!,96]N92==6R<X+C8Q-SHM,3,N,C`P)UT@/2`G3'5N9VDG.PHD8V]O<F1I
M;F%T97-;)U-I;F=A<&]R92==6R<Q+C,V-SHQ,#,N.3$W)UT@/2`G4VEN9V%P
M;W)E("\@4&%Y82!,96)A<B<["B1C;V]R9&EN871E<ULG4VEN9V%P;W)E)UU;
M)S$N,S8W.C$P,RXY.#,G72`]("=3:6YG87!O<F4@+R!#:&%N9VD@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG4VQO=F%K:6$G75LG-#@N,C`P.C$W+C(P,"==
M(#T@)T)R871I<VQA=F$@279A;FMA)SL*)&-O;W)D:6YA=&5S6R=3;&]V86MI
M82==6R<T."XS,S,Z,3DN-S,S)UT@/2`G3'5C96YE8R<["B1C;V]R9&EN871E
M<ULG4VQO=F%K:6$G75LG-#@N-C$W.C$W+C@S,R==(#T@)U!I97-T86YY)SL*
M)&-O;W)D:6YA=&5S6R=3;&]V86MI82==6R<T."XV-3`Z,3DN,34P)UT@/2`G
M4VQI86,G.PHD8V]O<F1I;F%T97-;)U-L;W9A:VEA)UU;)S0X+C8V-SHR,2XR
M,3<G72`]("=+;W-I8V4G.PHD8V]O<F1I;F%T97-;)U-L;W9A:VEA)UU;)S0X
M+CDS,SHR,BXP,#`G72`]("=+86UE;FEC82!.860@0VER;V-H;W4G.PHD8V]O
M<F1I;F%T97-;)U-L;W9A:VEA)UU;)S0Y+C`V-SHR,"XR-3`G72`]("=0;W!R
M860@+R!4871R>2<["B1C;V]R9&EN871E<ULG4VQO=F5N:6$G75LG-#4N-#@S
M.C$S+C8Q-R==(#T@)U!O<G1O<F]Z("\@4V5C;W9L:F4G.PHD8V]O<F1I;F%T
M97-;)U-L;W9E;FEA)UU;)S0U+C4Q-SHQ,RXU-C<G72`]("=0;W)T;W)O>B<[
M"B1C;V]R9&EN871E<ULG4VQO=F5N:6$G75LG-#8N,C$W.C$T+C0X,R==(#T@
M)TQJ=6)L:F%N82`O($)R;FEK)SL*)&-O;W)D:6YA=&5S6R=3;&]V96YI82==
M6R<T-BXR,3<Z,30N-#@S)UT@/2`G3&IU8FQJ86YA("\@0G)N:6LG.PHD8V]O
M<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0V+C0X,SHQ-2XV.#,G72`]("=-87)I
M8F]R("\@4VQI=FYI8V$G.PHD8V]O<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0V
M+C8U,#HQ-BXQ.#,G72`]("=-=7)S:V$@4V]B;W1A)SL*)&-O;W)D:6YA=&5S
M6R=3;VQO;6]N($ES;&%N9',G75LG+3$P+C<P,#HQ-C4N.#`P)UT@/2`G4V%N
M=&$@0W)U>B<["B1C;V]R9&EN871E<ULG4V]L;VUO;B!)<VQA;F1S)UU;)RTX
M+C,S,SHQ-3<N,C8W)UT@/2`G375N9&$G.PHD8V]O<F1I;F%T97-;)U-O;&]M
M;VX@27-L86YD<R==6R<M.2XT,3<Z,38P+C`U,"==(#T@)TAO;FEA<F$@+R!(
M96YD97)S;VXG.PHD8V]O<F1I;F%T97-;)U-O;6%L:6$G75LG,3`N-#$W.C0U
M+C`Q-R==(#T@)T)E<F)E<F$G.PHD8V]O<F1I;F%T97-;)U-O;6%L:6$G75LG
M,BXP,S,Z-#4N,S4P)UT@/2`G36]G861I<V-I;R<["B1C;V]R9&EN871E<ULG
M4V]M86QI82==6R<T+C<P,#HT-2XR,3<G72`]("="96QE="!596XG.PHD8V]O
M<F1I;F%T97-;)U-O;6%L:6$G75LG.2XU,#`Z-#0N,#@S)UT@/2`G2&%R9V5I
M<V$G.PHD8V]O<F1I;F%T97-;)U-O;6%L:6$G75LG.2XU,#`Z-#4N-38W)UT@
M/2`G0G5R86\G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C,N
M-S(V.C(W+C8X."==(#T@)T5L;&ES<F%S)SL*)&-O;W)D:6YA=&5S6R=3;W5T
M:"!!9G)I8V$G75LG+3(S+C@V-SHR.2XT-3`G72`]("=0:65T97)S8G5R9R<[
M"B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR,RXY,S,Z,S$N,34P
M)UT@/2`G4&AA;&%B;W)W82<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A
M)UU;)RTR-"XS-C<Z,S$N,#,S)UT@/2`G2&]E9'-P<G5I="<["B1C;V]R9&EN
M871E<ULG4V]U=&@@069R:6-A)UU;)RTR-2XT,S,Z,S`N.3@S)UT@/2`G3F5L
M<W!R=6ET)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(U+C<S
M,SHR."XQ.#,G72`]("=0<F5T;W)I82<["B1C;V]R9&EN871E<ULG4V]U=&@@
M069R:6-A)UU;)RTR-2XW.#,Z,C4N-3,S)UT@/2`G36UA8F%T:&\@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-2XX,S,Z,C@N
M,C$W)UT@/2`G5V%T97)K;&]O9B!,;6(G.PHD8V]O<F1I;F%T97-;)U-O=71H
M($%F<FEC82==6R<M,C4N.3$W.C(X+C(Q-R==(#T@)U!R971O<FEA($ER96YE
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(V+C`V-SHS,"XQ
M,3<G72`]("=#87)O;&EN82<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A
M)UU;)RTR-BXQ,S,Z,C@N,C,S)UT@/2`G2F%N(%-M=71S)SL*)&-O;W)D:6YA
M=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(V+C@V-SHR-BXW,3<G72`]("=+;&5R
M:W-D;W)P)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(V+CDU
M,#HR-"XV,S,G72`]("=6<GEB=7)G)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3(W+C(V-SHR."XU,#`G72`]("=&<F%N:V9O<G0G.PHD8V]O
M<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C@N,#`P.C(V+C8V-R==(#T@
M)U=E;&MO;2<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR."XR
M-3`Z,C@N,S,S)UT@/2`G0F5T:&QE:&5M($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)U-O=71H($%F<FEC82==6R<M,C@N-#`P.C(Q+C(V-R==(#T@)U5P:6YG
M=&]N)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(X+C4V-SHQ
M-BXU,S,G72`]("=!;&5X86YD97(@0F%Y)SL*)&-O;W)D:6YA=&5S6R=3;W5T
M:"!!9G)I8V$G75LG+3(X+C4V-SHR.2XW-C<G72`]("=,861Y<VUI=&@G.PHD
M8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C@N.#`P.C(T+C<V-R==
M(#T@)TMI;6)E<FQE>2<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;
M)RTR."XX,#`Z,S(N,3`P)UT@/2`G4FEC:&%R9"!"87DG.PHD8V]O<F1I;F%T
M97-;)U-O=71H($%F<FEC82==6R<M,CDN,3`P.C(V+C,P,"==(#T@)T)L;V5M
M9F]N=&5I;B!*+B!"+B!-+B!(97)T>F]G)SL*)&-O;W)D:6YA=&5S6R=3;W5T
M:"!!9G)I8V$G75LG+3(Y+C8V-SHQ-RXX-C<G72`]("=3<')I;F=B;VLG.PHD
M8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,CDN.38W.C,P+CDU,"==
M(#T@)T1U<F)A;B!,;W5I<R!";W1H82<["B1C;V]R9&EN871E<ULG4V]U=&@@
M069R:6-A)UU;)RTS,"XV,S,Z,C,N.3$W)UT@/2`G1&4@06%R)SL*)&-O;W)D
M:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,P+C8U,#HR-"XP,3<G72`]("=$
M92!!87(G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S`N-S$W
M.C(V+C<Q-R==(#T@)T%L:7=A;"!.;W)T:"<["B1C;V]R9&EN871E<ULG4V]U
M=&@@069R:6-A)UU;)RTS,2XT-C<Z,3DN-S8W)UT@/2`G0V%L=FEN:6$G.PHD
M8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S$N-#@S.C(U+C`S,R==
M(#T@)TUI9&1E;&)U<F<G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==
M6R<M,S$N-3,S.C(X+C8V-R==(#T@)U5M=&%T82<["B1C;V]R9&EN871E<ULG
M4V]U=&@@069R:6-A)UU;)RTS,2XV,S,Z,CDN-34P)UT@/2`G4&]R="!3="!*
M;VAN<R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,2XV-C<Z
M,3@N-3`P)UT@/2`G5G)E9&5N9&%L)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3,Q+CDP,#HR-BXX-C<G72`]("=1=65E;G-T;W=N)SL*)&-O
M;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,Q+CDQ-SHR,2XU,3<G72`]
M("=&<F%S97)B=7)G)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG
M+3,R+C(U,#HR-"XU,S,G72`]("='<F%A9F8@4F5I;F5T)SL*)&-O;W)D:6YA
M=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,R+C,U,#HR,BXU.#,G72`]("="96%U
M9F]R="!797-T)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,R
M+CDV-SHQ."XQ-C<G72`]("=,86YG96)A86YW96<G.PHD8V]O<F1I;F%T97-;
M)U-O=71H($%F<FEC82==6R<M,S,N,#,S.C(W+C@S,R==(#T@)T5A<W0@3&]N
M9&]N)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,S+C4V-SHR
M,BXR,3<G72`]("=/=61T<VAO;W)N)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3,S+CDX,SHQ."XV,#`G72`]("=#87!E(%1O=VX@1"X@1BX@
M36%L86XG.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S,N.3@S
M.C(U+C8P,"==(#T@)U!O<G0@16QI>F%B971H)SL*)&-O;W)D:6YA=&5S6R=3
M;W5T:"!!9G)I8V$G75LG+3,T+C`P,#HR,BXS.#,G72`]("='96]R9V4@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS-"XQ.#,Z
M,C(N,34P)UT@/2`G36]S<V5L($)A>2!#87!E(%-A:6YT($)L86EZ92<["B1C
M;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS-RXP-3`Z+3$R+C,Q-R==
M(#T@)U1R:7-T86X@1&$@0W5N:&$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F
M<FEC82==6R<M-#`N,S4P.BTY+C@X,R==(#T@)T=O=6=H($ES;&%N9"<["B1C
M;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTT-BXX.#,Z,S<N.#8W)UT@
M/2`G36%R:6]N($ES;&%N9"<["B1C;V]R9&EN871E<ULG4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',G75LG+34Q+C@Q-SHM
M-3@N-#4P)UT@/2`G36]U;G0@4&QE87-A;G0@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG,C<N.#$W.BTQ-RXX.#,G72`]("=(:65R<F\@+R!!
M97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<R-RXY,S,Z+3$U
M+C,X,R==(#T@)TQA<R!086QM87,@1&4@1W)A;B!#86YA<FEA("\@1V%N9&\G
M.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S(X+C`U,#HM,38N-38W)UT@/2`G
M5&5N97)I9F4@4W5R)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<R."XT-3`Z
M+3$S+C@V-R==(#T@)T9U97)T979E;G1U<F$@+R!!97)O<'5E<G1O)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<R."XT-C<Z+3$V+C,Q-R==(#T@)U1E;F5R
M:69E("\@3&]S(%)O9&5O<R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,C@N
M-C$W.BTQ-RXW-3`G72`]("=,82!086QM82`O($%E<F]P=65R=&\G.PHD8V]O
M<F1I;F%T97-;)U-P86EN)UU;)S(X+CDU,#HM,3,N-C`P)UT@/2`G3&%N>F%R
M;W1E("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S4N
M,C@S.BTR+CDU,"==(#T@)TUE;&EL;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN
M)UU;)S,V+C8U,#HM-BXS-3`G72`]("=2;W1A)SL*)&-O;W)D:6YA=&5S6R=3
M<&%I;B==6R<S-BXV-C<Z+30N-#@S)UT@/2`G36%L86=A("\@065R;W!U97)T
M;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S8N-S4P.BTV+C`V-R==(#T@
M)TIE<F5Z($1E($QA($9R;VYT97)A865R;W!U97)T;R<["B1C;V]R9&EN871E
M<ULG4W!A:6XG75LG,S8N.#4P.BTR+C,X,R==(#T@)T%L;65R:6$@+R!!97)O
M<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXQ-3`Z+34N-C$W
M)UT@/2`G36]R;VX@1&4@3&$@1G)O;G1E<F$G.PHD8V]O<F1I;F%T97-;)U-P
M86EN)UU;)S,W+C$X,SHM,RXW.#,G72`]("='<F%N861A("\@065R;W!U97)T
M;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S<N-#$W.BTU+CDP,"==(#T@
M)U-E=FEL;&$@+R!386X@4&%B;&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;
M)S,W+C<X,SHM,"XX,#`G72`]("=-=7)C:6$@+R!386X@2F%V:65R)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXX-3`Z+30N.#4P)UT@/2`G0V]R9&]B
M82`O($%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,W+CDU
M,#HM,2XR,S,G72`]("=-=7)C:6$@+R!!;&-A;G1A<FEL;&$G.PHD8V]O<F1I
M;F%T97-;)U-P86EN)UU;)S,X+C(X,SHM,"XU-3`G72`]("=!;&EC86YT92`O
M($5L($%L=&5T)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S."XU,3<Z+34N
M,3$W)UT@/2`G2&EN;VIO<V$@1&5L($1U<75E)SL*)&-O;W)D:6YA=&5S6R=3
M<&%I;B==6R<S."XX-C<Z,2XS.#,G72`]("=)8FEZ82`O($5S($-O9&]L82<[
M"B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S@N.#@S.BTV+C@Q-R==(#T@)T)A
M9&%J;WH@+R!486QA=F5R82!,82!296%L)SL*)&-O;W)D:6YA=&5S6R=3<&%I
M;B==6R<S."XY-3`Z+3$N.#4P)UT@/2`G06QB86-E=&4@+R!,;W,@3&QA;F]S
M)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S.2XU,#`Z+3`N-#8W)UT@/2`G
M5F%L96YC:6$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==
M6R<S.2XU-3`Z,BXW,S,G72`]("=086QM82!$92!-86QL;W)C82`O(%-O;B!3
M86X@2G5A;B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,SDN.#8W.C0N,C,S
M)UT@/2`G365N;W)C82`O($UA:&]N)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==
M6R<T,"XS,#`Z+3,N-S$W)UT@/2`G36%D<FED("\@1V5T869E)SL*)&-O;W)D
M:6YA=&5S6R=3<&%I;B==6R<T,"XS.#,Z+3,N-S@S)UT@/2`G36%D<FED("\@
M0W5A=')O(%9I96YT;W,G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0P+C0U
M,#HM,RXU-3`G72`]("=-861R:60@+R!"87)A:F%S)SL*)&-O;W)D:6YA=&5S
M6R=3<&%I;B==6R<T,"XT.#,Z+3,N-#4P)UT@/2`G36%D<FED("\@5&]R<F5J
M;VXG.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0P+C8U,#HM,RXW,S,G72`]
M("=-861R:2U#;VQM96YA<B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#`N
M.3,S.BTQ+C,P,"==(#T@)T-A;&%M;V-H82<["B1C;V]R9&EN871E<ULG4W!A
M:6XG75LG-#`N.34P.BTU+C4P,"==(#T@)U-A;&%M86YC82`O($UA=&%C86XG
M.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0Q+C$U,#HQ+C$V-R==(#T@)U)E
M=7,@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,2XR
M.#,Z,BXP-C<G72`]("="87)C96QO;F$@+R!!97)O<'5E<G1O)SL*)&-O;W)D
M:6YA=&5S6R=3<&%I;B==6R<T,2XV-C<Z+3$N,#$W)UT@/2`G6F%R86=O>F$@
M+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,2XW,3<Z
M+30N.#4P)UT@/2`G5F%L;&%D;VQI9"`O(%9I;&QA;G5B;&$G.PHD8V]O<F1I
M;F%T97-;)U-P86EN)UU;)S0Q+CDP,#HR+C<V-R==(#T@)T=E<F]N82`O($-O
M<W1A($)R879A)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,BXR,3<Z+3@N
M-C,S)UT@/2`G5FEG;R`O(%!E:6YA9&]R)SL*)&-O;W)D:6YA=&5S6R=3<&%I
M;B==6R<T,BXS-C<Z+3,N-C,S)UT@/2`G0G5R9V]S("\@5FEL;&%F<FEA)SL*
M)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,BXT-3`Z+3(N,S,S)UT@/2`G3&]G
M<F]N;R`O($%G;VYC:6QL;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#(N
M-3@S.BTU+C8U,"==(#T@)TQE;VX@+R!6:7)G96X@1&5L($-A;6EN;R<["B1C
M;V]R9&EN871E<ULG4W!A:6XG75LG-#(N-S8W.BTQ+C8S,R==(#T@)U!A;7!L
M;VYA("\@3F]A:6XG.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0R+C@X,SHM
M,BXW,3<G72`]("=6:71O<FEA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T
M,BXY,#`Z+3@N-#,S)UT@/2`G4V%N=&EA9V\@+R!,86)A8V]L;&$G.PHD8V]O
M<F1I;F%T97-;)U-P86EN)UU;)S0S+C,P,#HM,BXY,S,G72`]("=":6QB86\@
M+R!3;VYD:6-A)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,RXS,#`Z+3@N
M,S@S)UT@/2`G3&$@0V]R=6YA("\@06QV961R;R<["B1C;V]R9&EN871E<ULG
M4W!A:6XG75LG-#,N,S4P.BTQ+C@P,"==(#T@)U-A;B!396)A<W1I86X@+R!&
M=65N=&5R<F%B:6$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0S+C0S,SHM
M,RXX,3<G72`]("=386YT86YD97(@+R!087)A>6%S)SL*)&-O;W)D:6YA=&5S
M6R=3<&%I;B==6R<T,RXU-3`Z+38N,#,S)UT@/2`G07-T=7)I87,@+R!!=FEL
M97,G.PHD8V]O<F1I;F%T97-;)U-R:2!,86YK82==6R<V+C@Q-SHW.2XX.#,G
M72`]("=2871M86QA;F$G.PHD8V]O<F1I;F%T97-;)U-R:2!,86YK82==6R<W
M+C$V-SHW.2XX.#,G72`]("=+871U;F%Y86ME)SL*)&-O;W)D:6YA=&5S6R=3
M<FD@3&%N:V$G75LG-RXW,3<Z.#$N-S`P)UT@/2`G0F%T=&EC86QO82<["B1C
M;V]R9&EN871E<ULG4W)I($QA;FMA)UU;)S@N,S,S.C@P+C0Q-R==(#T@)T%N
M=7)A9&AA<'5R82<["B1C;V]R9&EN871E<ULG4W)I($QA;FMA)UU;)S@N-3@S
M.C@Q+C(U,"==(#T@)U1R:6YC;VUA;&5E)SL*)&-O;W)D:6YA=&5S6R=3=61A
M;B==6R<Q,2XP,#`Z,CDN-S$W)UT@/2`G2V%D=6=L:2<["B1C;V]R9&EN871E
M<ULG4W5D86XG75LG,3$N-S4P.C,R+C<X,R==(#T@)U)E;FLG.PHD8V]O<F1I
M;F%T97-;)U-U9&%N)UU;)S$Q+C<X,SHS-"XS.#,G72`]("=$86UA>FEN92<[
M"B1C;V]R9&EN871E<ULG4W5D86XG75LG,3(N,#4P.C(T+C@X,R==(#T@)TYY
M86QA)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q,RXQ-C<Z,S`N,C,S)UT@
M/2`G16P@3V)E:60G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$S+C$V-SHS
M,BXV-C<G72`]("=+;W-T:2<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3,N
M-#@S.C(R+C0U,"==(#T@)T=E;F5I;F$G.PHD8V]O<F1I;F%T97-;)U-U9&%N
M)UU;)S$S+C4U,#HS,RXV,3<G72`]("=396YN87(G.PHD8V]O<F1I;F%T97-;
M)U-U9&%N)UU;)S$S+C8Q-SHR-2XS,S,G72`]("=%;"!&87-H97(G.PHD8V]O
M<F1I;F%T97-;)U-U9&%N)UU;)S$T+C`S,SHS-2XT,#`G72`]("='961A<F5F
M)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q-2XT-C<Z,S8N-#`P)UT@/2`G
M2V%S<V%L82<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,34N-C`P.C,R+C4U
M,"==(#T@)TMH87)T;W5M)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q-RXW
M,#`Z,S,N.38W)UT@/2`G071B87)A)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==
M6R<Q.2XQ-C<Z,S`N-#@S)UT@/2`G1&]N9V]L82<["B1C;V]R9&EN871E<ULG
M4W5D86XG75LG,3DN-3@S.C,W+C(Q-R==(#T@)U!O<G0@4W5D86XG.PHD8V]O
M<F1I;F%T97-;)U-U9&%N)UU;)S(Q+C@Q-SHS,2XT.#,G72`]("=7861I($AA
M;&9A)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<T+C@V-SHS,2XV,#`G72`]
M("=*=6)A)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Y+C4U,#HS,2XV-3`G
M72`]("=-86QA:V%L)SL*)&-O;W)D:6YA=&5S6R=3=7)I;F%M92==6R<U+C0U
M,#HM-34N,C`P)UT@/2`G6F%N9&5R:6HG.PHD8V]O<F1I;F%T97-;)U-W87II
M;&%N9"==6R<M,C8N-3,S.C,Q+C,P,"==(#T@)TUA;GII;FD@+R!-871S87!A
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U-2XU-3`Z,3,N
M,S8W)UT@/2`G36%L;6\@+R!3='5R=7`G.PHD8V]O<F1I;F%T97-;)U-W961E
M;B==6R<U-2XY,3<Z,30N,#@S)UT@/2`G2W)I<W1I86YS=&%D("\@179E<F]D
M)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-38N,#@U.C$S+C(P-R==(#T@
M)TQJ=6YG8GEH960L($QJ=6YG8GEH960@*%-712U!1D(I)SL*)&-O;W)D:6YA
M=&5S6R=3=V5D96XG75LG-38N,C8W.C$U+C(X,R==(#T@)U)O;FYE8GDG.PHD
M8V]O<F1I;F%T97-;)U-W961E;B==6R<U-BXS,#`Z,3(N.#4P)UT@/2`G06YG
M96QH;VQM)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-38N-C@S.C$R+C@S
M,R==(#T@)TAA;&US=&%D(%-W961I<V@@06ER($9O<F-E($)A<V4G.PHD8V]O
M<F1I;F%T97-;)U-W961E;B==6R<U-BXW,S,Z,38N,S`P)UT@/2`G2V%L;6%R
M)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-38N.#4P.C$T+C@S,R==(#T@
M)U9A>&IO)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3<N,S`P.C$T+C$S
M,R==(#T@)TAA9W-H=6QT)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3<N
M-3$W.C$U+C@S,R==(#T@)TAU;'1S9G)E9"!3=V5D:7-H($%I<B!&;W)C92!"
M87-E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3<N-C8W.C$R+C,P,"==
M(#T@)T=O=&5B;W)G("\@3&%N9'9E='1E<B<["B1C;V]R9&EN871E<ULG4W=E
M9&5N)UU;)S4W+C8V-SHQ."XS-3`G72`]("=6:7-B>2!&;'EG<&QA=',G.PHD
M8V]O<F1I;F%T97-;)U-W961E;B==6R<U-RXW-C<Z,30N,#@S)UT@/2`G2F]N
M:V]P:6YG($9L>6=P;&%T<R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W
M+C<X,SHQ,2XX.#,G72`]("=';W1E8F]R9R`O(%-A=F4G.PHD8V]O<F1I;F%T
M97-;)U-W961E;B==6R<U."XT,#`Z,34N-3$W)UT@/2`G3&EN:V]P:6YG("\@
M36%L;65N)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3@N-#,S.C$R+C<P
M,"==(#T@)U-A=&5N87,G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U."XT
M-3`Z,3,N.38W)UT@/2`G4VMO=F1E($9L>6=P;&%T<R<["B1C;V]R9&EN871E
M<ULG4W=E9&5N)UU;)S4X+C4X,SHQ-BXQ-3`G72`]("=.;W)R:V]P:6YG)SL*
M)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3DN,S4P.C$W+CDU,"==(#T@)U-T
M;V-K:&]L;2`O($)R;VUM82<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4Y
M+C,V-SHQ,RXT-C<G72`]("=+87)L<W1A9"!&;'EG<&QA=',G.PHD8V]O<F1I
M;F%T97-;)U-W961E;B==6R<U.2XU.#,Z,38N-C,S)UT@/2`G5F%S=&5R87,@
M+R!(87-S;&\G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U.2XV-3`Z,3<N
M.34P)UT@/2`G4W1O8VMH;VQM("\@07)L86YD82<["B1C;V]R9&EN871E<ULG
M4W=E9&5N)UU;)S4Y+C@X,SHQ-RXV,#`G72`]("=5<'!S86QA)SL*)&-O;W)D
M:6YA=&5S6R=3=V5D96XG75LG-C`N-#,S.C$U+C4Q-R==(#T@)T)O<FQA;F=E
M)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C`N-C`P.C$V+CDU,"==(#T@
M)T=A=FQE("\@4V%N9'9I:V5N($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA
M=&5S6R=3=V5D96XG75LG-C$N,C8W.C$W+C$P,"==(#T@)U-O9&5R:&%M;B<[
M"B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8R+C4S,SHQ-RXT-3`G72`]("=3
M=6YD<W9A;&PM2&%R;F]S86YD($9L>6=P;&%T<R<["B1C;V]R9&EN871E<ULG
M4W=E9&5N)UU;)S8S+C`U,#HQ-RXW-C<G72`]("=+<F%M9F]R<R!&;'EG<&QA
M=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<V,RXQ.#,Z,30N-3`P)UT@
M/2`G3W-T97)S=6YD("\@1G)O<V]N)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG
M75LG-C,N-#`P.C$X+CDV-R==(#T@)T]R;G-K;VQD<W9I:R!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C,N.#`P.C(P+C(X,R==(#T@)U5M
M96$@1FQY9W!L871S)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C0N-C,S
M.C(Q+C`X,R==(#T@)U-K96QL969T96$@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG4W=E9&5N)UU;)S8T+CDV-SHQ-RXW,#`G72`]("='=6YN87)N)SL*)&-O
M;W)D:6YA=&5S6R=3=V5D96XG75LG-C4N-34P.C(R+C$S,R==(#T@)TQU;&5A
M("\@2V%L;&%X)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C4N.#8W.C(P
M+C$S,R==(#T@)U9I9'-E;"<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8V
M+C8S,SHQ.2XV-3`G72`]("=*;VMK;6]K:R<["B1C;V]R9&EN871E<ULG4W=E
M9&5N)UU;)S8W+C$U,#HR,"XV-3`G72`]("='86QL:79A<F4G.PHD8V]O<F1I
M;F%T97-;)U-W961E;B==6R<V-RXX,3<Z,C`N,S,S)UT@/2`G2VER=6YA($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0V+C`P,#HX
M+CDV-R==(#T@)TQU9V%N;R<["B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G
M75LG-#8N,C$W.C<N,S,S)UT@/2`G4VEO;B<["B1C;V]R9&EN871E<ULG4W=I
M='IE<FQA;F0G75LG-#8N,C4P.C8N,3,S)UT@/2`G1V5N979E+4-O:6YT<FEN
M)SL*)&-O;W)D:6YA=&5S6R=3=VET>F5R;&%N9"==6R<T-BXU-3`Z-BXV,3<G
M72`]("=,875S86YN92<["B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG
M-#8N.#$W.C8N.34P)UT@/2`G4&%Y97)N92<["B1C;V]R9&EN871E<ULG4W=I
M='IE<FQA;F0G75LG-#<N,#`P.C8N.34P)UT@/2`G3F5U8VAA=&5L)SL*)&-O
M;W)D:6YA=&5S6R=3=VET>F5R;&%N9"==6R<T-RXQ.#$Z-RXT,38G72`]("='
M<F5N8VAE;B<["B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#<N-#@S
M.C@N-3,S)UT@/2`G6G5R:6-H+4ML;W1E;B<["B1C;V]R9&EN871E<ULG4W=I
M='IE<FQA;F0G75LG-#<N-#@U.CDN-38R)UT@/2`G4V%I;G0@1V%L;&5N+4%L
M=&5N<FAE:6XG.PHD8V]O<F1I;F%T97-;)U-Y<FEA;B!!<F%B(%)E<'5B;&EC
M)UU;)S,S+C0Q-SHS-BXU,3<G72`]("=$86UA<V-U<R!);G0N($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)U-Y<FEA;B!!<F%B(%)E<'5B;&EC)UU;)S,T+C4U
M,#HS."XS,#`G72`]("=086QM>7)A)SL*)&-O;W)D:6YA=&5S6R=3>7)I86X@
M07)A8B!297!U8FQI8R==6R<S-2XS,3<Z-#`N,34P)UT@/2`G1&5I<B!%>GIO
M<B<["B1C;V]R9&EN871E<ULG4WER:6%N($%R86(@4F5P=6)L:6,G75LG,S4N
M-3,S.C,U+C<V-R==(#T@)TQA='1A:VEA)SL*)&-O;W)D:6YA=&5S6R=3>7)I
M86X@07)A8B!297!U8FQI8R==6R<S-BXQ.#,Z,S<N,C`P)UT@/2`G06QE<'!O
M($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG4WER:6%N
M($%R86(@4F5P=6)L:6,G75LG,S<N,#4P.C0Q+C(Q-R==(#T@)TMA;6ES:&QI
M)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C`N-C8W.C$Q-BXW,3<G72`]
M("=$;VYG<VAA)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C$N.3,S.C$R
M,"XX,S,G72`]("=(96YG8VAU;B<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;
M)S(R+C`S,SHQ,C$N-34P)UT@/2`G3&%N(%EU)SL*)&-O;W)D:6YA=&5S6R=4
M86EW86XG75LG,C(N-#$W.C$R,"XU-3`G72`]("=#:&EA(%1U;F<G.PHD8V]O
M<F1I;F%T97-;)U1A:7=A;B==6R<R,BXT-C<Z,3(P+C0S,R==(#T@)T1O;F=G
M86YG)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N-3@S.C$R,"XS-3`G
M72`]("=+86]H<VEU;F<@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=486EW86XG75LG,C(N-C@S.C$R,"XT-C<G72`]("=0:6YG='5N
M9R!3;W5T:"!!:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG5&%I=V%N
M)UU;)S(R+C<P,#HQ,C`N-#@S)UT@/2`G4&EN9W1U;F<@3F]R=&@@06ER($9O
M<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R,BXW.#,Z,3(P
M+C(V-R==(#T@)TMA;F=S:&%N(%1W+4%F8B<["B1C;V]R9&EN871E<ULG5&%I
M=V%N)UU;)S(R+C@P,#HQ,C$N,3@S)UT@/2`G0VAI:&AA;F<@5'<M069B)SL*
M)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N.34P.C$R,"XR,#`G72`]("=4
M86EN86X@5'<M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C,N,C8W
M.C$Q.2XV-C<G72`]("=$;VYG<VAI)SL*)&-O;W)D:6YA=&5S6R=486EW86XG
M75LG,C,N-#8W.C$R,"XS.#,G72`]("=#:&EA>6D@5'<M069B)SL*)&-O;W)D
M:6YA=&5S6R=486EW86XG75LG,C,N-3@S.C$Q.2XV,3<G72`]("=-86MU;F<@
M06(G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R-"XP,S,Z,3(Q+C8Q-R==
M(#T@)TAU;&EE;B!!8B<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(T+C$X
M,SHQ,C`N-C4P)UT@/2`G5&%I8VAU;F<@5'<M069B)SL*)&-O;W)D:6YA=&5S
M6R=486EW86XG75LG,C0N,C8W.C$R,"XV,3<G72`]("=7=6-H:6$@3V)S97)V
M871O<GDG.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R-"XT,S,Z,3$X+C,V
M-R==(#T@)T-H:6YM96T@+R!3:&%T;W4@06ER($9O<F-E($)A<V4G.PHD8V]O
M<F1I;F%T97-;)U1A:7=A;B==6R<R-"XW-3`Z,3(Q+C<V-R==(#T@)TEL86XG
M.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R-"XX,3<Z,3(P+CDS,R==(#T@
M)TAS:6YC:'4@5'<M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C0N
M.3,S.C$R,2XS,#`G72`]("=082!+=65I("\@0F%K=6%I)SL*)&-O;W)D:6YA
M=&5S6R=486EW86XG75LG,C4N,#8W.C$R,2XR,S,G72`]("=486]Y=6%N($%B
M(#T@-3@Y-C4P)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C4N,#8W.C$R
M,2XU-3`G72`]("=3=6YG<VAA;B`O(%1A:7!E:2<["B1C;V]R9&EN871E<ULG
M5&%I=V%N)UU;)S(U+C`X,SHQ,C$N,C$W)UT@/2`G0VAI86YG($MA:2!3:&5K
M)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C8N,38W.C$Q.2XY,S,G72`]
M("=-87IU)SL*)&-O;W)D:6YA=&5S6R=486II:VES=&%N)UU;)S,X+C4U,#HV
M."XW.#,G72`]("=$=7-H86YB92<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L
M(%5N:71E9"!297!U8FQI8R!O9B==6R<M,2XS,S,Z,S$N.#$W)UT@/2`G0G5K
M;V)A)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F)UU;)RTQ+C4P,#HS,RXX,#`G72`]("=-=7-O;6$G.PHD8V]O<F1I;F%T
M97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3$P+C(V-SHT
M,"XQ.#,G72`]("=-='=A<F$G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8G75LG+3$P+C,U,#HS."XW-3`G72`]("=.86-H
M:6YG=V5A)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F)UU;)RTQ,"XV.#,Z,S4N-3@S)UT@/2`G4V]N9V5A)SL*)&-O;W)D
M:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTR+C0V
M-SHS,BXY,3<G72`]("=-=V%N>F$G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3,N,S,S.C,V+C8Q-R==(#T@)T%R
M=7-H82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B==6R<M,RXS-3`Z,S<N,S,S)UT@/2`G36]S:&DG.PHD8V]O<F1I;F%T
M97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3,N-#$W.C,W
M+C`V-R==(#T@)TMI;&EM86YJ87)O($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+30N,#@S.C,W+C<Q
M-R==(#T@)U-A;64G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8G75LG+30N.#@S.C(Y+C8S,R==(#T@)TMI9V]M82<["B1C
M;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M
M-"XX.#,Z,S@N,C@S)UT@/2`G36]M8F\G.PHD8V]O<F1I;F%T97-;)U1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+34N,#@S.C,R+C@S,R==(#T@
M)U1A8F]R82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F)UU;)RTU+C`X,SHS.2XP-C<G72`]("=486YG82<[
M"B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==
M6R<M-2XR-3`Z,SDN.#$W)UT@/2`G4&5M8F$@+R!+87)U;64@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==
M6R<M-BXQ-C<Z,S4N-S8W)UT@/2`G1&]D;VUA)SL*)&-O;W)D:6YA=&5S6R=4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTV+C(Q-SHS.2XR,3<G
M72`]("=:86YZ:6)A<B`O($MI<V%U;FDG.PHD8V]O<F1I;F%T97-;)U1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+38N.#,S.C,W+C8U,"==(#T@
M)TUO<F]G;W)O)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F)UU;)RTV+C@V-SHS.2XR,#`G72`]("=$87(@17,@4V%L86%M
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8G75LG+3<N-C8W.C,U+C<U,"==(#T@)TER:6YG82<["B1C;V]R
M9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M."XY
M,S,Z,S,N-#8W)UT@/2`G36)E>6$G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$P+C0X,SHY.2XQ.#,G72`]("=#:'5M<&AO;B<["B1C;V]R9&EN871E
M<ULG5&AA:6QA;F0G75LG,3$N.#,S.CDY+C@S,R==(#T@)U!R86-H=6%P($MH
M:7)I:VAA;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3(N-3@S.CDY
M+CDU,"==(#T@)TAU82!(:6XG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;
M)S$R+C8P,#HQ,#(N,3$W)UT@/2`G0VAA;G1H86)U<FDG.PHD8V]O<F1I;F%T
M97-;)U1H86EL86YD)UU;)S$R+C8S,SHQ,#$N,S4P)UT@/2`G4F%Y;VYG)SL*
M)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q,RXQ-3`Z,3`P+C`V-R==(#T@
M)U!H971C:&%B=7)I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q,RXS
M-C<Z,3`P+CDX,R==(#T@)T-H;VX@0G5R:2<["B1C;V]R9&EN871E<ULG5&AA
M:6QA;F0G75LG,3,N.3$W.C$P,"XV,#`G72`]("=$;VX@375A;F<G.PHD8V]O
M<F1I;F%T97-;)U1H86EL86YD)UU;)S$T+C`Q-SHY.2XU,S,G72`]("=+86YC
M:&%N86)U<FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$T+C`U,#HQ
M,#$N,S8W)UT@/2`G4')A8VAI;B!"=7)I)SL*)&-O;W)D:6YA=&5S6R=4:&%I
M;&%N9"==6R<Q-"XY-C<Z,3`R+C`X,R==(#T@)TYA:VAO;B!2871C:&%S:6UA
M)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-2XR-3`Z,3`T+C@V-R==
M(#T@)U5B;VX@4F%T8VAA=&AA;FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$U+C@P,#HQ,#`N,38W)UT@/2`G3F%K:&]N(%-A=V%N)SL*)&-O;W)D
M:6YA=&5S6R=4:&%I;&%N9"==6R<Q-2XX,#`Z,3`R+C`S,R==(#T@)T-H86EY
M87!H=6TG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$V+C`U,#HQ,#,N
M-C@S)UT@/2`G4F]I($5T)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M-BXT,S,Z,3`R+C@S,R==(#T@)TMH;VX@2V%E;B<["B1C;V]R9&EN871E<ULG
M5&AA:6QA;F0G75LG,38N-3,S.C$P-"XW,3<G72`]("=-=6MD86AA;B<["B1C
M;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,38N-C8W.CDX+C4U,"==(#T@)TUA
M92!3;W0G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$V+C<X,SHQ,#`N
M,C8W)UT@/2`G4&AI='-A;G5L;VLG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$V+C@X,SHY.2XQ-3`G72`]("=486LG.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)S$W+C$U,#HQ,#0N,3,S)UT@/2`G4V%K;VX@3F%K:&]N)SL*
M)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-RXS.#,Z,3`R+C@P,"==(#T@
M)U5D;VX@5&AA;FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$W+C0Q
M-SHQ,#0N-S@S)UT@/2`G3F%K:&]N(%!H86YO;2<["B1C;V]R9&EN871E<ULG
M5&AA:6QA;F0G75LG,3<N-#4P.C$P,2XW,S,G72`]("=,;V5I)SL*)&-O;W)D
M:6YA=&5S6R=4:&%I;&%N9"==6R<Q-RXV,3<Z,3`P+C$P,"==(#T@)U5T=&%R
M861I="<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3<N.#8W.C$P,BXW
M,3<G72`]("=.;VYG($MH86DG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;
M)S$X+C$V-SHQ,#`N,38W)UT@/2`G4&AR864G.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)S$X+C$V-SHY-RXY,S,G72`]("=-864@4V%R:6%N9R<["B1C
M;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3@N,C@S.CDY+C4Q-R==(#T@)TQA
M;7!A;F<G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$X+C<V-SHQ,#`N
M-S8W)UT@/2`G3F%N)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q."XW
M.#,Z.3@N.3@S)UT@/2`G0VAI86YG($UA:2<["B1C;V]R9&EN871E<ULG5&AA
M:6QA;F0G75LG,3DN,S`P.CDW+C@S,R==(#T@)TUA92!(;VYG(%-O;B<["B1C
M;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3DN.3$W.CDY+C@S,R==(#T@)T-H
M:6%N9R!286DG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S8N-C4P.C$P
M,"XP.#,G72`]("=3871U;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG
M-BXW.#,Z,3`Q+C$U,"==(#T@)U!A='1A;FDG.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)S8N.3$W.C$P,"XT,S,G72`]("=(870@66%I)SL*)&-O;W)D
M:6YA=&5S6R=4:&%I;&%N9"==6R<W+C(P,#HQ,#`N-C`P)UT@/2`G4V]N9VMH
M;&$G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S<N-3$W.CDY+C8Q-R==
M(#T@)U1R86YG)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<X+C$Q-SHY
M."XS,3<G72`]("=0:'5K970@06ER<&]R="<["B1C;V]R9&EN871E<ULG5&AA
M:6QA;F0G75LG."XT-C<Z.3DN.38W)UT@/2`G3F%K:&]N(%-I(%1H86UM87)A
M="<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG.2XQ,3<Z.3DN,S4P)UT@
M/2`G4W5R870@5&AA;FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)SDN
M.3@S.CDX+C8Q-R==(#T@)U)A;F]N9R<["B1C;V]R9&EN871E<ULG5&]G;R==
M6R<Q,"XS-C<Z,"XT-C<G72`]("=-86YG;R<["B1C;V]R9&EN871E<ULG5&]G
M;R==6R<V+C$V-SHQ+C(U,"==(#T@)TQO;64G.PHD8V]O<F1I;F%T97-;)U1O
M9V\G75LG-BXU.#,Z,2XU,#`G72`]("=486)L:6=B;R<["B1C;V]R9&EN871E
M<ULG5&]G;R==6R<W+C4X,SHQ+C$Q-R==(#T@)T%T86MP86UE)SL*)&-O;W)D
M:6YA=&5S6R=4;V=O)UU;)S@N.3@S.C$N,34P)UT@/2`G4V]K;V1E)SL*)&-O
M;W)D:6YA=&5S6R=4;V=O)UU;)SDN-S8W.C$N,3`P)UT@/2`G3FEA;71O=6=O
M=2<["B1C;V]R9&EN871E<ULG5&]N9V$G75LG+3$Y+C@P,#HM,3<T+C,U,"==
M(#T@)TAA87!A:2<["B1C;V]R9&EN871E<ULG5&]N9V$G75LG+3(Q+C(S,SHM
M,3<U+C$U,"==(#T@)T9U85PG06UO='4G.PHD8V]O<F1I;F%T97-;)U1R:6YI
M9&%D(&%N9"!4;V)A9V\G75LG,3`N-C$W.BTV,2XS-3`G72`]("=0:6%R8V\@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!4<FEN:61A9"<["B1C;V]R9&EN871E
M<ULG5')I;FED860@86YD(%1O8F%G;R==6R<Q,2XQ-3`Z+38P+C@S,R==(#T@
M)T-R;W=N(%!O:6YT($%I<G!O<G0L(%1O8F%G;R<["B1C;V]R9&EN871E<ULG
M5'5N:7-I82==6R<S,2XV.#,Z.2XQ-C<G72`]("=%;"!";W)M82<["B1C;V]R
M9&EN871E<ULG5'5N:7-I82==6R<S,BXS,3<Z,3`N-#`P)UT@/2`G4F5M861A
M)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,S+C@V-SHQ,"XW-C<G72`]
M("=$:F5R8F$@365L;&ET82<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S
M,RXX.#,Z,3`N,3`P)UT@/2`G1V%B97,G.PHD8V]O<F1I;F%T97-;)U1U;FES
M:6$G75LG,S,N.3$W.C@N,3`P)UT@/2`G5&]Z975R)SL*)&-O;W)D:6YA=&5S
M6R=4=6YI<VEA)UU;)S,T+C0Q-SHX+C@Q-R==(#T@)T=A9G-A)SL*)&-O;W)D
M:6YA=&5S6R=4=6YI<VEA)UU;)S,T+C<Q-SHQ,"XV.#,G72`]("=39F%X($5L
M+4UA;W4G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S4N-C8W.C$P+C$P
M,"==(#T@)TMA:7)O=6%N)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,U
M+C8V-SHQ,"XW-3`G72`]("=-;VYA<W1I<BU3:V%N97,G.PHD8V]O<F1I;F%T
M97-;)U1U;FES:6$G75LG,S8N-#@S.C@N.#`P)UT@/2`G2F5N9&]U8F$G.PHD
M8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S8N.#,S.C$P+C(S,R==(#T@)U1U
M;FES+4-A<G1H86=E)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,V+C@U
M,#HQ,2XP.#,G72`]("=+96QI8FEA)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA
M)UU;)S,V+CDU,#HX+C<U,"==(#T@)U1A8F%R:V$G.PHD8V]O<F1I;F%T97-;
M)U1U;FES:6$G75LG,S<N,C4P.CDN.#`P)UT@/2`G0FEZ97)T92<["B1C;V]R
M9&EN871E<ULG5'5R:V5Y)UU;)S,V+C4X,SHS-BXQ-C<G72`]("=)<VME;F1E
M<G5N)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S8N-S`P.C(X+C<X,R==
M(#T@)T1A;&%M86XG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-BXW,#`Z
M,S`N-S,S)UT@/2`G06YT86QY82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;
M)S,V+CDX,SHS-2XS,#`G72`]("=!9&%N82`O(%-A:VER<&%S82<["B1C;V]R
M9&EN871E<ULG5'5R:V5Y)UU;)S,W+C`P,#HS-2XT,3<G72`]("=!9&%N82`O
M($EN8VER;&EK)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S<N,#,S.C(W
M+C0Q-R==(#T@)T)O9')U;2<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W
M+C`X,SHS-RXS-C<G72`]("='87II86YT97`G.PHD8V]O<F1I;F%T97-;)U1U
M<FME>2==6R<S-RXQ,S,Z,S@N-S8W)UT@/2`G57)F82<["B1C;V]R9&EN871E
M<ULG5'5R:V5Y)UU;)S,W+C<U,#HS,"XU-3`G72`]("=)<W!A<G1A)SL*)&-O
M;W)D:6YA=&5S6R=4=7)K97DG75LG,S<N.#4P.C(W+C@U,"==(#T@)T%Y9&EN
M)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S<N.#8W.C0Q+C$V-R==(#T@
M)T)A=&UA;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+C@X,SHT,"XQ
M.#,G72`]("=$:7EA<F)A:VER)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG
M,S<N.38W.C,R+C4U,"==(#T@)TMO;GEA)SL*)&-O;W)D:6YA=&5S6R=4=7)K
M97DG75LG,S@N,C8W.C(W+C$U,"==(#T@)TEZ;6ER("\@061N86X@365N9&5R
M97,G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S."XT,S,Z,S@N,#@S)UT@
M/2`G36%L871Y82`O($5R:&%C)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG
M,S@N-#4P.C0S+C,Q-R==(#T@)U9A;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y
M)UU;)S,X+C4P,#HR-RXP,3<G72`]("=)>FUI<B`O($-I9VQI)SL*)&-O;W)D
M:6YA=&5S6R=4=7)K97DG75LG,S@N-C`P.C,Y+C(X,R==(#T@)T5L87II9R<[
M"B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C8V-SHR.2XT,3<G72`]("=5
M<V%K)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N-S4P.C,P+C4S,R==
M(#T@)T%F>6]N)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N-S@S.C,U
M+C0X,R==(#T@)TMA>7-E<FD@+R!%<FMI;&5T)SL*)&-O;W)D:6YA=&5S6R=4
M=7)K97DG75LG,S@N.3$W.C(W+C@U,"==(#T@)T%K:&ES87(G.PHD8V]O<F1I
M;F%T97-;)U1U<FME>2==6R<S.2XV,3<Z,C<N.3$W)UT@/2`G0F%L:6ME<VER
M)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,SDN-S,S.C,Y+C4P,"==(#T@
M)T5R>FEN8V%N)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,SDN-S4P.C,W
M+C`Q-R==(#T@)U-I=F%S)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,SDN
M-S@S.C,P+C4V-R==(#T@)T5S:VES96AI<B<["B1C;V]R9&EN871E<ULG5'5R
M:V5Y)UU;)S,Y+CDQ-SHT,2XR-C<G72`]("=%<GIU<G5M)SL*)&-O;W)D:6YA
M=&5S6R=4=7)K97DG75LG,SDN.34P.C,R+C8X,R==(#T@)T%N:V%R82`O($5T
M:6UE<V=U="<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+C`X,SHS,BXU
M-C<G72`]("=-=7)T960@5'5R+4%F8B<["B1C;V]R9&EN871E<ULG5'5R:V5Y
M)UU;)S0P+C$Q-SHS,BXY.#,G72`]("=!;FMA<F$@+R!%<V5N8F]G82<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+C$S,SHR-BXT,#`G72`]("=#86YA
M:VMA;&4G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XQ.#,Z,CDN,#8W
M)UT@/2`G0G5R<V$G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XS,#`Z
M,S8N-38W)UT@/2`G5&]K870G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T
M,"XS,3<Z,C<N.38W)UT@/2`G0F%N9&ER;6$G.PHD8V]O<F1I;F%T97-;)U1U
M<FME>2==6R<T,"XV,#`Z-#,N,#@S)UT@/2`G2V%R<R<["B1C;V]R9&EN871E
M<ULG5'5R:V5Y)UU;)S0P+C@U,#HS-2XU.#,G72`]("=-97)Z:69O;B<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+CDV-SHR."XX,3<G72`]("=)<W1A
M;F)U;"`O($%T871U<FLG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,2XP
M,#`Z,SDN-S$W)UT@/2`G5')A8GIO;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y
M)UU;)S0Q+C(V-SHS-BXS,#`G72`]("=386US=6XG.PHD8V]O<F1I;F%T97-;
M)U1U<FME>2==6R<T,2XT-3`Z,S$N.#`P)UT@/2`G6F]N9W5L9&%K)SL*)&-O
M;W)D:6YA=&5S6R=4=79A;'4G75LG+34N-C8W.C$W-BXQ,S,G72`]("=.86YU
M;65A)SL*)&-O;W)D:6YA=&5S6R=4=79A;'4G75LG+3@N-3$W.C$W.2XR,3<G
M72`]("=&=6YA9G5T:2<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S`N,#4P
M.C,R+C0U,"==(#T@)T5N=&5B8F4@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M56=A;F1A)UU;)S`N,3@S.C,P+C$P,"==(#T@)TMA<V5S92<["B1C;V]R9&EN
M871E<ULG56=A;F1A)UU;)S`N-#4P.C,S+C$X,R==(#T@)TII;FIA)SL*)&-O
M;W)D:6YA=&5S6R=59V%N9&$G75LG+3`N-C$W.C,P+C8U,"==(#T@)TUB87)A
M<F$G.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<P+C8X,SHS-"XQ-C<G72`]
M("=4;W)O<F\G.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<M,2XR-3`Z,CDN
M.3@S)UT@/2`G2V%B86QE)SL*)&-O;W)D:6YA=&5S6R=59V%N9&$G75LG,2XV
M.#,Z,S$N-S$W)UT@/2`G36%S:6YD:2<["B1C;V]R9&EN871E<ULG56=A;F1A
M)UU;)S$N-S$W.C,S+C8Q-R==(#T@)U-O<F]T:2<["B1C;V]R9&EN871E<ULG
M56=A;F1A)UU;)S(N-S4P.C,R+C,S,R==(#T@)T=U;'4G.PHD8V]O<F1I;F%T
M97-;)U5G86YD82==6R<S+C`U,#HS,"XY,3<G72`]("=!<G5A)SL*)&-O;W)D
M:6YA=&5S6R=5:W)A:6YE)UU;)S0T+C8X,SHS-"XQ,S,G72`]("=3:6UF97)O
M<&]L)SL*)&-O;W)D:6YA=&5S6R=5:W)A:6YE)UU;)S0V+C0S,SHS,"XW-C<G
M72`]("=/9&5S82<["B1C;V]R9&EN871E<ULG56MR86EN92==6R<T.2XX,3<Z
M,C,N.34P)UT@/2`G3%PG5FEV)SL*)&-O;W)D:6YA=&5S6R=5:W)A:6YE)UU;
M)S0Y+CDV-SHS-BXQ,S,G72`]("=+:&%R:VEV)SL*)&-O;W)D:6YA=&5S6R=5
M:W)A:6YE)UU;)S4P+C,S,SHS,"XY-C<G72`]("=";W)Y<W!I;"<["B1C;V]R
M9&EN871E<ULG56MR86EN92==6R<U,"XT,#`Z,S`N-38W)UT@/2`G2WEI=B<[
M"B1C;V]R9&EN871E<ULG56MR86EN92==6R<U,"XU.#,Z,C8N,3,S)UT@/2`G
M4FEV;F4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!!<F%B($5M:7)A=&5S)UU;
M)S(T+C(V-SHU-2XV,#`G72`]("=!;"!!:6X@26YT97)N871I;VYA;"!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R
M-"XT,S,Z-30N-#8W)UT@/2`G06)U($1H86)I($)A=&5E;B!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-"XT,S,Z
M-30N-C4P)UT@/2`G06)U($1H86)I($EN=&5R;F%T:6]N86P@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($%R86(@16UI<F%T97,G75LG,C4N,3`P
M.C4V+C,S,R==(#T@)T9U:F%I<F%H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M07)A8B!%;6ER871E<R==6R<R-2XR-3`Z-34N,S,S)UT@/2`G1'5B86D@26YT
M97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@07)A
M8B!%;6ER871E<R==6R<R-2XS,S,Z-34N-3$W)UT@/2`G4VAA<FIA:"!);G1E
M<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!!<F%B
M($5M:7)A=&5S)UU;)S(U+C8Q-SHU-2XY,S,G72`]("=287,@06P@2VAA:6UA
M:"!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S0Y+C(Q-SHM,BXR,#`G72`]("=*97)S97D@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-#DN-#,S.BTR
M+C8P,"==(#T@)T=U97)N<V5Y($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S0Y+CDQ-SHM-BXS,#`G72`]("=38VEL;'DL(%-A
M:6YT($UA<GE<)U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;
M)S4P+C`X,SHM-2XR-3`G72`]("=#=6QD<F]S92<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-3`N,S4P.BTT+C$Q-R==(#T@)U!L>6UO=71H
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XT,S,Z+34N
M,#`P)UT@/2`G4V%I;G0@36%W9V%N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U,"XU-C<Z+3(N-#4P)UT@/2`G4&]R=&QA;F0@+R!2;F%S
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XW,S,Z+3,N
M-#$W)UT@/2`G17AE=&5R($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4P+C<X,SHM,2XX,S,G72`]("=";W5R;F5M;W5T:"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XX
M,S,Z+3`N,C@S)UT@/2`G4VAO<F5H86T@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-3`N.3`P.BTQ+C0P,"==(#T@)U-O=71H
M86UP=&]N("\@5V5A=&AE<B!#96YT<F4G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4Q+C`P,#HM,BXV,S,G72`]("=996]V:6QT;VXG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C`X,SHM-"XQ-3`G
M72`]("=#:&EV96YO<B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG
M75LG-3$N,34P.BTP+C$X,R==(#T@)TQO;F1O;B`O($=A='=I8VL@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,34P.BTQ
M+C4V-R==(#T@)TUI9&1L92!786QL;W`G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4Q+C$V-SHM,2XW-3`G72`]("=";W-C;VUB92!$;W=N
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XR,S,Z+3`N
M.34P)UT@/2`G3V1I:&%M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U,2XR.#,Z+3`N-S8W)UT@/2`G1F%R;F)O<F]U9V@@36EL:71A<GDG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C(X,SHM,"XW
M-C<G72`]("=&87)N8F]R;W5G:"<["B1C;V]R9&EN871E<ULG56YI=&5D($MI
M;F=D;VTG75LG-3$N,S4P.C$N,S4P)UT@/2`G36%N<W1O;B<["B1C;V]R9&EN
M871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,S@S.BTP+C<X,R==(#T@)T)R
M86-K;F5L;"`O($)E875F;W)T(%!A<FLG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4Q+C0P,#HM,RXS-3`G72`]("=#87)D:69F+5=A;&5S
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q
M+C0X,SHM,"XT-3`G72`]("=,;VYD;VX@+R!(96%T:')O=R!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XU,#`Z+3$N.3@S
M)UT@/2`G3'EN96AA;2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG
M75LG-3$N-3$W.BTP+C$Q-R==(#T@)TQO;F1O;B!796%T:&5R($-E;G1R92<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N-34P.BTP+C0Q
M-R==(#T@)TYO<G1H;VQT)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U,2XV,3<Z+3$N,#@S)UT@/2`G0F5N<V]N)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@2VEN9V1O;2==6R<U,2XV.#,Z+3$N-S@S)UT@/2`G1F%I<F9O
M<F0@4F]Y86P@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4Q+C<Q-SHM-"XS-C<G72`]("=096UB<F5Y(%-A;F1S
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XW-3`Z+3$N
M-3@S)UT@/2`G0G)I>F4@3F]R=&]N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U,2XX.#,Z,"XR,S,G72`]("=3=&%N<W1E9"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXQ,3<Z,"XY
M-C<G72`]("=7871T:7-H86TG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4R+C$S,SHM-"XU-C<G72`]("=!8F5R<&]R=&@G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C,S,SHP+C<V-R==(#T@)TAO
M;FEN9W1O;B!2;WEA;"!!:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-3(N,S4P.BTP+C$Q-R==(#T@)U=Y=&]N(%)O
M>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,BXS-C<Z+3`N,C$W)UT@/2`G06QC;VYB=7)Y(%)O>6%L($%I
M<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==
M6R<U,BXS-C<Z,"XT.#,G72`]("=-:6QD96YH86QL(%)O>6%L($%I<B!&;W)C
M92!"87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXT
M,3<Z,"XU-C<G72`]("=,86ME;FAE871H(%)O>6%L($%I<B!&;W)C92!"87-E
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXT,S,Z,2XS
M-3`G72`]("=#;VQT:7-H86QL)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,BXT-3`Z+3$N-S,S)UT@/2`G0FER;6EN9VAA;2`O($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C8Q-SHM
M,"XT-C<G72`]("=7:71T97)I;F<G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+
M:6YG9&]M)UU;)S4R+C8S,SHQ+C,P,"==(#T@)TYO<G=I8V@@5V5A=&AE<B!#
M96YT<F4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C8U
M,#HP+C4V-R==(#T@)TUA<FAA;2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI
M;F=D;VTG75LG-3(N-S,S.BTP+C8U,"==(#T@)T-O='1E<VUO<F4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C@P,#HM,BXV-C<G72`]
M("=3:&%W8G5R>2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3(N.#8W.C`N,34P)UT@/2`G2&]L8F5A8V@G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4S+C`S,SHM,"XU,#`G72`]("=#<F%N=V5L;"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N,#@S.BTP+C$V
M-R==(#T@)T-O;FEN9W-B>2!2;WEA;"!!:7(@1F]R8V4@0F%S92<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N,#@S.C`N,C8W)UT@/2`G
M5V%I;F9L965T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U
M,RXQ-C<Z+3`N-3$W)UT@/2`G5V%D9&EN9W1O;B<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-3,N,38W.BTR+CDX,R==(#T@)TAA=V%R9&5N
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXR-3`Z+30N
M-3,S)UT@/2`G5F%L;&5Y)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U,RXS-3`Z+3(N,C@S)UT@/2`G36%N8VAE<W1E<B!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXW-C<Z+3,N,#,S
M)UT@/2`G0FQA8VMP;V]L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4S+C@S,SHM,2XR,#`G72`]("=#:'5R8V@@1F5N=&]N
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXX-C<Z+3`N
M-#,S)UT@/2`G3&5C;VYF:65L9"<["B1C;V]R9&EN871E<ULG56YI=&5D($MI
M;F=D;VTG75LG-30N,#4P.BTQ+C(U,"==(#T@)TQI;G1O;BU/;BU/=7-E)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XP.#,Z+30N-C,S
M)UT@/2`G27-L92!/9B!-86X@+R!2;VYA;&1S=V%Y($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4T+C$Q-SHM,RXR-3`G72`]
M("=786QN97D@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U-"XQ,S,Z+3$N-#$W)UT@/2`G1&ES9F]R=&@G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!+:6YG9&]M)UU;)S4T+C,P,#HM,2XU,S,G72`]("=,965M
M:6YG)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XV,#`Z
M+34N.#@S)UT@/2`G0F5L9F%S="`O($AA<F)O=7(G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!+:6YG9&]M)UU;)S4T+C8U,#HM-BXR,3<G72`]("="96QF87-T
M("\@06QD97)G<F]V92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U-"XX-3`Z+30N.34P)UT@/2`G5V5S="!&<F5U9V@G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4T+CDS,SHM,BXY-3`G
M72`]("=#87)L:7-L92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG
M75LG-34N,#4P.BTR+C4U,"==(#T@)U-P861E861A;2<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-34N-#$W.BTQ+C8P,"==(#T@)T)O=6QM
M97(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4U+C0S,SHM
M-2XW,#`G72`]("=-86-H<FEH86YI<V@G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4U+C4P,#HM-"XU.#,G72`]("=0<F5S='=I8VL@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-34N.#8W
M.BTT+C0S,R==(#T@)T=L87-G;W<@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-34N.34P.BTS+C,U,"==(#T@)T5D:6YB=7)G
M:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U
M-BXS.#,Z+3(N.#8W)UT@/2`G3&5U8VAA<G,G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4V+C4P,#HM-BXX.#,G72`]("=4:7)E92<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N,C`P.BTR+C(Q-R==
M(#T@)T%B97)D965N("\@1'EC92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI
M;F=D;VTG75LG-3<N-#8W.BTW+C,V-R==(#T@)T)E;F)E8W5L82<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N-3,S.BTT+C`U,"==(#T@
M)TEN=F5R;F5S<R`O($1A;&-R;W-S)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U-RXV-3`Z+3,N-38W)UT@/2`G2VEN;&]S<R<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N-S$W.BTS+C,Q-R==(#T@
M)TQO<W-I96UO=71H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==
M6R<U-RXX,3<Z+3,N.38W)UT@/2`G5&%I;B!286YG92<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-3@N,C$W.BTV+C,Q-R==(#T@)U-T;W)N
M;W=A>2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3@N-#4P
M.BTS+C`X,R==(#T@)U=I8VLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4X+CDU,#HM,BXY,#`G72`]("=+:7)K=V%L;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U.2XX.#,Z+3$N,S`P
M)UT@/2`G4W5M8G5R9V@@0V%P92<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S)UU;)RTQ-"XS,S,Z+3$W,"XW
M,3<G72`]("=086=O(%!A9V\@+R!);G0N($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R==6R<Q
M-BXW,S,Z+3$V.2XU,S,G72`]("=*;VAN<W1O;B!)<VQA;F0L($IO:&YS=&]N
M($%T;VQL($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,3,N-#@S.C$T-"XX,#`G72`]("=!9V%N82P@1W5A;2!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($=5)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S$S+C4X,SHQ-#0N.3,S)UT@/2`G06YD97)S96X@*$UA<FEA;F$@27,I
M+"!!;F1E<G-E;B!!:7(@1F]R8V4@0F%S92P@1U4G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,3,N.3$W.C$T-"XX,S,G72`]("='=6%M+"!-
M87)I86YA($ES;&%N9"P@1U4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,30N,3@S.C$T-2XR-3`G72`]("=2;W1A($ES;&%N9"`H3BX@36%R
M:6%N82!)<RDL(%)O=&$@26YT97)N871I;VYA;"!!:7)P;W)T+"!'52<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<Q-"XY.#,Z,30U+C8Q-R==
M(#T@)U1I;FEA;B!)<VQA;F0@*$XN($UA<FEA;F$@27,I+"!797-T(%1I;FEA
M;B!!:7)P;W)T+"!'52<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<Q-2XQ,3<Z,30U+C<S,R==(#T@)U-A:7!A;B!)<VQA;F0L(%-A:7!A;B!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($YO<G1H97)N($UA<FEA;F$@27-L86YD
M<R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<Q."XR-34Z+38U
M+C8T,R==(#T@)U)O;W-E=F5L="!2;V%D<RP@4F]O<V5V96QT(%)O861S($YA
M=F%L(%-T871I;VX@*$]F<W1I92!&:65L9"DL(%!2)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S$X+C4P,#HM-C<N,3,S)UT@/2`G07%U861I
M;&QA+"!2869A96P@2&5R;F%N9&5Z($%I<G!O<G0L(%!2)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S$Y+C$P,#HM,34U+C<U,"==(#T@)U-O
M=71H($MO;F$@+R!(87=A:6DL($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S$Y+C(X,SHQ-C8N-C4P)UT@/2`G5V%K92!)<VQA;F0L(%=A
M:V4@27-L86YD($%R;7D@06ER9FEE;&0@06ER<&]R="P@1U4G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,3DN-S(R.BTQ-34N,#4V)UT@/2`G
M2&EL;RP@2&EL;R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($A))SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(P+C@Y,CHM,34V+C0S-R==(#T@
M)TMA:'5L=6DL($MA:'5L=6D@06ER<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,C$N,34P.BTQ-3<N,3`P)UT@/2`G36]L;VMA
M:2!!=71O;6%T:6,@365T96]R;VQO9VEC86P@3V)S97)V:6YG(%-Y<W1E;2P@
M2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C$N,S`X.BTQ
M-3@N,#8X)UT@/2`G3V%H=2P@2V%L865L;V$@06ER<&]R="P@2$DG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C$N,S(X.BTQ-3<N.30S)UT@
M/2`G2&]N;VQU;'4L($AO;F]L=6QU($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C$N-#4T.BTQ
M-3<N-S8V)UT@/2`G2V%N96]H92P@36%R:6YE($-O<G!S($%I<B!3=&%T:6]N
M+"!(22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R,2XT.#,Z
M+3$U."XP,S,G72`]("=7:&5E;&5R($%I<B!&;W)C92!"87-E("\@3V%H=2P@
M2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C$N.3@T.BTQ
M-3DN,S0Q)UT@/2`G3&EH=64L($QI:'5E($%I<G!O<G0L($A))SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(R+C`S-CHM,34Y+C<X-B==(#T@
M)TME:V%H82P@4&%C:69I8R!-:7-S:6QE(%1E<W0@1F%C:6QI='D@0F%R:VEN
M9R!386YD<RP@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,C0N-34T.BTX,2XW-30G72`]("=+97D@5V5S="P@2V5Y(%=E<W0@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<R-2XW.3$Z+3@P+C,Q-B==(#T@)TUI86UI+"!-:6%M:2!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S(U+CDQ-#HM.3<N-#(S)UT@/2`G0G)O=VYS=FEL;&4L($)R
M;W=N<W9I;&QE("\@4V]U=&@@4&%D<F4@27-L86YD($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,C8N-C@U.BTX,"XP.3DG72`]("=797-T(%!A;&T@0F5A8V@L(%!A;&T@0F5A
M8V@@26YT97)N871I;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<R-RXU-3`Z+3DY+C0V-R==(#T@)TQA<F5D;R!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S(W+C8U,#HM.#$N,S,S)UT@/2`G079O;B!087)K($=U
M;FYE<GD@4F%N9V4L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S(W+C<P,#HM.#(N-#`P)UT@/2`G5&%M<&$@0F%Y($%R96$L($9,)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(W+C<W,SHM.3<N-3$S
M)UT@/2`G0V]R<'5S($-H<FES=&DL($-O<G!U<R!#:')I<W1I($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,C<N.#4P.BTX,BXU,#`G72`]("=-86-D:6QL($%I<B!&;W)C92!"
M87-E+"!&;"XL($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S(W+CDV,3HM.#(N-30P)UT@/2`G5&%M<&$L(%1A;7!A($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,C@N,3`S.BTX,"XV-#8G72`]("=-96QB;W5R;F4L($UE;&)O=7)N92!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S(X+C(Q-SHM,3<W+C,V-R==(#T@)U-A;F0@27-L86YD
M+"!(96YD97)S;VX@1FEE;&0@06ER<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,C@N,C,S.BTX,"XV,#`G72`]("=#;V-O82`O
M(%!A=')I8VL@06ER($9O<F-E($)A<V4L($9,)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S(X+C0Q-SHM.#$N,S(U)UT@/2`G3W)L86YD;RP@
M3W)L86YD;R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($9,)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S(X+C0V-SHM.#`N-34P)UT@/2`G0V%P
M92!+96YN961Y+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<R."XX-C,Z+3DV+CDS,"==(#T@)U9I8W1O<FEA+"!6:6-T;W)I82!296=I
M;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<R.2XR-S`Z+3DT+C@V-"==(#T@)T=A;'9E<W1O;BP@4V-H;VQE<R!&
M:65L9"P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN
M,S,S.BTX.2XT,#`G72`]("=";V]T:'9I;&QE+"!,02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<R.2XS-S4Z+3$P,"XY,C0G72`]("=$96P@
M4FEO+"!$96P@4FEO($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN-3,S.BTY."XT-C0G72`]
M("=386X@06YT;VYI;RP@4V%N($%N=&]N:6\@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R.2XU
M-3`Z+3@S+C$P-2==(#T@)T-R;W-S($-I='DL($-R;W-S($-I='D@06ER<&]R
M="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN-S(W
M.BTX-2XP,C4G72`]("=!<&%L86-H:6-O;&$L($%P86QA8VAI8V]L82P@1DPG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN.34Q.BTY-"XP
M,C$G72`]("="96%U;6]N="`O(%!O<G0@07)T:'5R+"!3;W5T:&5A<W0@5&5X
M87,@4F5G:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,CDN.3DR.BTY-2XS-C0G72`]("=(;W5S=&]N+"!(;W5S
M=&]N($EN=&5R8V]N=&EN96YT86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,CDN.3DS.BTY,"XR-3$G72`]("=.97<@
M3W)L96%N<RP@3F5W($]R;&5A;G,@26YT97)N871I;VYA;"!!:7)P;W)T+"!,
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XP-C<Z+3@U
M+C4X,R==(#T@)U1Y;F1A;&P@06ER($9O<F-E($)A<V4L($9,)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C$R-CHM.3,N,C(S)UT@/2`G
M3&%K92!#:&%R;&5S+"!,86ME($-H87)L97,@4F5G:6]N86P@06ER<&]R="P@
M3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N,38W.BTQ
M,#(N-#$W)UT@/2`G4V%N9&5R<V]N+"!46"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S,"XS,S,Z+3@Y+C@Q-R==(#T@)U-L:61E;&PL($Q!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C,V-SHM,3`T
M+C`Q-R==(#T@)TUA<F9A+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S,"XS.3,Z+3@T+C,U,R==(#T@)U1A;&QA:&%S<V5E+"!486QL
M86AA<W-E92!296=I;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,"XT,3<Z+3@V+C8X,R==(#T@)TAU<FQB=7)T
M($9I96QD+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M,"XT.#,Z+3@V+C4Q-R==(#T@)U9A;'!A<F%I<V\@+R!%9VQI;B!!:7(@1F]R
M8V4@0F%S92P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S`N-#DT.BTX,2XV.3,G72`]("=*86-K<V]N=FEL;&4L($IA8VMS;VYV:6QL
M92!);G1E<FYA=&EO;F%L($%I<G!O<G0L($9,)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,P+C4Q,3HM.3DN-S8V)UT@/2`G2G5N8W1I;VXL
M($MI;6)L92!#;W5N='D@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S`N-C@X.BTX."XR-#8G72`]("=-;V)I;&4L($UO
M8FEL92!296=I;VYA;"!!:7)P;W)T+"!!3"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S,"XY-C<Z+3@S+C(P,"==(#T@)TUO;V1Y($%I<B!&
M;W)C92!"87-E+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S,2XP,S,Z+3DS+C`S,R==(#T@)T9O<G0@4&]L:RP@3$$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N,3`P.BTY-RXS,S,G72`]("=&
M;W)T($AO;V0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,Q+C$S,SHM.3(N-38W)UT@/2`G0VQA:6)O<FYE(%)A;F=E+"!!:7)W87ES
M($9A8VEL:71I97,@4V5C=&]R+"!,02<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,2XR-3`Z+3@R+C0P,"==(#T@)U=A>6-R;W-S("\@5V%R
M92!#;W5N='DL($=A+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,2XS,S4Z+3DR+C4U.2==(#T@)T%L97AA;F1R:6$L($%L97AA;F1R
M:6$@26YT97)N871I;VYA;"!!:7)P;W)T+"!,02<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,2XS-3$Z+3$P,"XT.30G72`]("=386X@06YG
M96QO+"!-871H:7,@1FEE;&0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,Q+C4S-CHM.#0N,3DT)UT@/2`G06QB86YY+"!3;W5T:'=E
M<W0@1V5O<F=I82!296=I;VYA;"!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,2XU.#,Z+3$Q,"XS,S,G72`]("=&;W)T
M($AU86-H=6-A+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S,2XV,3<Z+3DW+C(R."==(#T@)U=A8V\L(%=A8V\@4F5G:6]N86P@06ER
M<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N
M.#$Q.BTQ,#8N,S<V)UT@/2`G16P@4&%S;RP@16P@4&%S;R!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,Q+C@S,3HM,3`T+C@P.2==(#T@)U!I;F4@4W!R:6YG<RP@1W5A9&%L
M=7!E($UO=6YT86EN<R!.871I;VYA;"!087)K+"!46"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,2XX-C<Z+3$P-BXW,#`G72`]("=386YT
M82!497)E<V$L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,Q+C@X,SHM.#$N-38W)UT@/2`G1G0N(%-T97=A<G0L($=!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+CDT.#HM,3`R+C(P.2==(#T@
M)TUI9&QA;F0L($UI9&QA;F0@26YT97)N871I;VYA;"!!:7)P;W)T+"!46"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXQ,3DZ+3@Q+C(P
M,B==(#T@)U-A=F%N;F%H+"!3879A;FYA:"!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C$S
M,3HM,3$P+CDU-2==(#T@)U1U8W-O;BP@5'5C<V]N($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@05HG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S(N,C$W.BTY."XQ.#,G72`]("=3=&5P:&5N=FEL;&4@+R!#;&%R:R!&:65L
M9"!-=6YI8VEP86PL(%1X+BP@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S(N,S`P.BTX-BXT,#8G72`]("=-;VYT9V]M97)Y+"!$86YN
M96QL>2!&:65L9"P@04PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S(N,S(P.BTY,"XP-S@G72`]("=*86-K<V]N+"!*86-K<V]N($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@35,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S(N,S,S.BTX-"XX,S,G72`]("=&;W)T($)E;FYI;F<L($=!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C,S.#HM.#@N
M-S0X)UT@/2`G365R:61I86XL($ME>2!&:65L9"P@35,G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S@S.BTQ,#8N-#@S)UT@/2`G5VAI
M=&4@4V%N9',L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,R+C,Y,3HM.30N-S$T)UT@/2`G3&]N9W9I97<L($=R96=G($-O=6YT>2!!
M:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M,BXT,3`Z+3DY+C8X,B==(#T@)T%B:6QE;F4L($%B:6QE;F4@4F5G:6]N86P@
M06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S(N-#,S.BTQ,3(N-C@S)UT@/2`G1VEL82!"96YD(%4N(%,N($%R;7D@06ER
M9FEE;&0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R
M+C0T-SHM.3,N.#(T)UT@/2`G4VAR979E<&]R="P@4VAR979E<&]R="!296=I
M;VYA;"!!:7)P;W)T+"!,02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,BXV,S,Z+3$P."XQ-3`G72`]("=3:6QV97(@0VET>2`O($=R86YT
M+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXV-3`Z
M+3$Q-"XV,#`G72`]("=9=6UA("\@675M82!);G1E<FYA=&EO;F%L+"!!6B<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXV.#@Z+3@S+C8U
M-"==(#T@)TUA8V]N+"!-:61D;&4@1V5O<F=I82!296=I;VYA;"!!:7)P;W)T
M+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXW,S0Z
M+3$Q-RXQ.#,G72`]("=386X@1&EE9V\L(%-A;B!$:65G;R!);G1E<FYA=&EO
M;F%L+4QI;F1B97)G:"!&:65L9"P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S(N.#(U.BTQ,34N-C8Q)UT@/2`G16P@0V5N=')O+"!.
M879A;"!!:7(@1F%C:6QI='DL($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,R+C@S,SHM.3<N,S`P)UT@/2`G1F]R="!7;W)T:"P@5%@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N.#4P.BTQ,#8N
M,3`P)UT@/2`G2&]L;&]M86X@06ER($9O<F-E($)A<V4L($Y-)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C@V.#HM,3$W+C$T,R==(#T@
M)U-A;B!$:65G;RP@36ER86UA<B!-0T%3+TUI='-C:&5R($9I96QD($%I<G!O
M<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C@Y
M-SHM.3<N,#(R)UT@/2`G1&%L;&%S("\@1F]R="!7;W)T:"P@1&%L;&%S("\@
M1F]R="!7;W)T:"!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C@Y.3HM.#`N,#0Q)UT@/2`G
M0VAA<FQE<W1O;BP@0VAA<FQE<W1O;B!!:7(@1F]R8V4@0F%S92P@4T,G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N.3`P.BTX-RXR-3`G
M72`]("=#96YT<F5V:6QL92P@04PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S,N,C,U.BTQ,3DN-#4S)UT@/2`G4V%N($YI8VAO;&%S($ES
M;&%N9"P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N
M,C,W.BTQ,#<N,C8X)UT@/2`G5')U=&@@3W(@0V]N<V5Q=65N8V5S+"!4<G5T
M:"!/<B!#;VYS97%U96YC97,@375N:6-I<&%L($%I<G!O<G0L($Y-)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C,P.#HM,3`T+C4P."==
M(#T@)U)O<W=E;&PL(%)O<W=E;&P@26YD=7-T<FEA;"!!:7(@0V5N=&5R($%I
M<G!O<G0L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S
M+C,V-#HM.#$N.38S)UT@/2`G075G=7-T82P@0G5S:"!&:65L9"P@1T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N-#`U.BTQ,3@N-#$V
M)UT@/2`G079A;&]N+"!#871A;&EN82!!:7)P;W)T+"!#02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,RXT,S0Z+3$Q,BXP-3$G72`]("=0
M:&]E;FEX+"!0:&]E;FEX(%-K>2!(87)B;W(@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXU
M-C8Z+3@V+C<T-2==(#T@)T)I<FUI;F=H86TL($)I<FUI;F=H86T@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!!3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S,RXV,S`Z+3@T+C0T,B==(#T@)T%T;&%N=&$L($AA<G1S9FEE
M;&0@071L86YT82!);G1E<FYA=&EO;F%L($%I<G!O<G0L($=!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C8V-SHM,3`Q+C@R,2==(#T@
M)TQU8F)O8VLL($QU8F)O8VL@26YT97)N871I;VYA;"!!:7)P;W)T+"!46"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXV.#,Z+3<X+CDS
M,R==(#T@)TUY<G1L92!"96%C:"!!:7(@1F]R8V4@0F%S92P@4T,G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N.#$R.BTQ,3@N,30V)UT@
M/2`G3&]N9R!"96%C:"P@3&]N9R!"96%C:"!!:7)P;W)T+"!#02<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXX-3`Z+3@P+C0X,R==(#T@
M)U!O:6YS971T(%)A;F=E+"!3=6UP=&5R+"!30R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,RXY,#`Z+3$P-BXT,#`G72`]("=.;W)T:')U
M<"!,86YD:6YG(%-T<FEP+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S,RXY,#`Z+3$Q-RXR-3`G72`]("=2:79E<G-I9&4@+R!-87)C
M:"!!:7(@1F]R8V4@0F%S92P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S,N.3$W.BTX-"XU,3<G72`]("=-87)I971T82`O($1O8F)I
M;G,@06ER($9O<F-E($)A<V4L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,S+CDS.#HM,3$X+C,X.2==(#T@)TQO<R!!;F=E;&5S+"!,
M;W,@06YG96QE<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($-!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+CDT,CHM.#$N,3$X)UT@/2`G
M0V]L=6UB:6$L($-O;'5M8FEA($UE=')O<&]L:71A;B!!:7)P;W)T+"!30R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXY-3$Z+3@S+C,R
M."==(#T@)T%T:&5N<RP@071H96YS($%I<G!O<G0L($=!)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+CDV-SHM.#`N-#@S)UT@/2`G4VAA
M=R!!:7(@1F]R8V4@0F%S92P@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S,N.3<Y.BTY."XT.3,G72`]("=7:6-H:71A($9A;&QS+"!3
M:&5P<&%R9"!!:7(@1F]R8V4@0F%S92P@5%@G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S0N,#$W.BTQ,#8N.3`P)UT@/2`G4V]C;W)R;R!-
M=6YI8VEP86PL($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,T+C$R-#HM,3$Y+C$R,B==(#T@)U!O:6YT($UU9W4L($YA=F%L($%I<B!7
M87)F87)E($-E;G1E<BP@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S0N,C`P.BTQ,3@N,S8U)UT@/2`G0G5R8F%N:RP@0G5R8F%N:RU'
M;&5N9&%L92U087-A9&5N82!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-"XR,S,Z+3$Q."XP-C<G72`]("=-;W5N="!7
M:6QS;VXL($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T
M+C(V.#HM.#@N-S<P)UT@/2`G5'5P96QO+"!4=7!E;&\@4F5G:6]N86P@06ER
M<&]R="P@35,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N
M,S`P.BTQ,#,N.#`P)UT@/2`G365L<F]S92!'=6YN97)Y(%)A;F=E+"!.32<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XS-#@Z+3@U+C$V
M,2==(#T@)U)O;64L(%(N($(N(%)U<W-E;&P@06ER<&]R="P@1T$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-3$W.BTY-BXY.#,G72`]
M("=3=6QP:'5R($UU;FEC:7!A;"P@3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S0N-C`P.BTY."XT,#`G72`]("=&;W)T(%-I;&PL($]+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C8S,#HM,3$X
M+C`X,2==(#T@)U!A;&UD86QE+"!086QM9&%L92!0<F]D=6-T:6]N($9L:6=H
M="!0;&%N="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S0N-C0T.BTX-BXW.#8G72`]("=(=6YT<W9I;&QE+"!(=6YT<W9I;&QE($EN
M=&5R;F%T:6]N86P@+R!*;VYE<R!&:65L9"P@04PG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S0N-C4P.BTY.2XR-C<G72`]("=!;'1U<R!!
M:7(@1F]R8V4@0F%S92P@3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S0N-S,Y.BTY,BXR-S@G72`]("=,:71T;&4@4F]C:RP@2&5I9VAT
M<RP@05(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-S0T
M.BTQ,3@N-S(T)UT@/2`G4V%N9&)E<F<L($-!)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,T+C<U,#HM,3(P+C4V-R==(#T@)U9A;F1E;F)E
M<F<@06ER($9O<F-E($)A<V4L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,T+C<X,SHM-S8N.#@S)UT@/2`G3F5W<&]R="P@3D,G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N.#,S.BTY,BXR-3`G
M72`]("=.;W)T:"!,:71T;&4@4F]C:RP@3F]R=&@@3&ET=&QE(%)O8VL@06ER
M<&]R="P@05(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N
M.#@T.BTX,BXR,C$G72`]("='<F5E<BP@1W)E96YV:6QL92U3<&%R=&%N8G5R
M9R!!:7)P;W)T+"!30R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S-"XX.3@Z+3<V+C@X,2==(#T@)T-H97)R>2!0;VEN="P@36%R:6YE($-O
M<G!S($%I<B!3=&%T:6]N+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-"XX.3DZ+3$R,"XT-#DG72`]("=386YT82!-87)I82P@4V%N
M=&$@36%R:6$@4'5B;&EC($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,T+CDQ-SHM,3$W+CDP,"==(#T@)T5D=V%R9',@
M06ER($9O<F-E($)A<V4L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,U+C`R.#HM,3$P+C<R,2==(#T@)U=I;G-L;W<L(%=I;G-L;W<@
M375N:6-I<&%L($%I<G!O<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,U+C`S,SHM.#4N,C`P)UT@/2`G0VAA='1A;F]O9V$L($QO
M=F5L;"!&:65L9"P@5$XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S4N,#0R.BTQ,#8N-C$U)UT@/2`G06QB=7%U97)Q=64L($%L8G5Q=65R
M<75E($EN=&5R;F%T:6]N86P@06ER<&]R="P@3DTG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S4N,#8Q.BTX.2XY.#4G72`]("=-96UP:&ES
M+"!-96UP:&ES($EN=&5R;F%T:6]N86P@06ER<&]R="P@5$XG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,3,S.BTW."XY,S,G72`]("=&
M;W)T($)R86=G("\@4VEM;6]N<R!!<FUY($%I<F9I96QD+"!.0R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XQ-3`Z+3<U+C,P,"==(#T@
M)T1I86UO;F0@4VAO86QS($-O87-T($=U87)D(%-T871I;VXL($Y#)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C$V-SHM-SDN,#,S)UT@
M/2`G4&]P92!!:7(@1F]R8V4@0F%S92P@3D,G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S4N,C$S.BTX,"XY-#DG72`]("=#:&%R;&]T=&4L
M($-H87)L;W1T92`O($1O=6=L87,@26YT97)N871I;VYA;"!!:7)P;W)T+"!.
M0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XR,3<Z+3DW
M+C0U,"==(#T@)TYO<FUA;B`O($UA>"!797-T:&5I;65R+"!/2R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XR,C`Z+3$P,2XW,3<G72`]
M("=!;6%R:6QL;RP@06UA<FEL;&\@26YT97)N871I;VYA;"!!:7)P;W)T+"!4
M6"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XR-3@Z+3$Q
M,RXY,S,G72`]("=+:6YG;6%N+"!+:6YG;6%N($%I<G!O<G0L($%:)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C(U.3HM.3,N,#DS)UT@
M/2`G4G5S<V5L;'9I;&QE+"!2=7-S96QL=FEL;&4@4F5G:6]N86P@06ER<&]R
M="P@05(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,C8W
M.BTQ,3<N-#,S)UT@/2`G0W5D9&QE8F%C:R!'=6YN97)Y(%)A;F=E+"!#02<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XR-C<Z+3<U+C4U
M,"==(#T@)T-A<&4@2&%T=&5R87,L($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,U+C(X,SHM,3$V+C8Q-R==(#T@)T)I8WEC;&4@3&%K
M92!5+B!3+B!!<FUY($%I<F9I96QD+"!#82P@0T$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S4N,S,T.BTY-"XS-C4G72`]("=&;W)T(%-M
M:71H+"!&;W)T(%-M:71H(%)E9VEO;F%L($%I<G!O<G0L($%2)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C,X.3HM.3<N-C`P)UT@/2`G
M3VML86AO;6$@0VET>2P@5VEL;"!2;V=E<G,@5V]R;&0@06ER<&]R="P@3TLG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N-#`P.BTY-BXP
M,3<G72`]("=(96YR>65T=&$@375N:6-I<&%L+"!/2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-2XT,3<Z+3DW+C,X,R==(#T@)U1I;FME
M<B!!:7(@1F]R8V4@0F%S92P@3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S4N-#,R.BTX,BXU,S<G72`]("=!<VAE=FEL;&4L($%S:&5V
M:6QL92!296=I;VYA;"!!:7)P;W)T+"!.0R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-2XT,S0Z+3$Q.2XP-3<G72`]("="86ME<G-F:65L
M9"P@365A9&]W<R!&:65L9"!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-2XV-3`Z+3$P.2XP-C<G72`]("=7:6YD;W<@
M4F]C:RP@5VEN9&]W(%)O8VL@06ER<&]R="P@05HG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S4N-C8V.BTQ,C$N,C@U)UT@/2`G4&]I;G0@
M4&EE9')A<R!";&%N8V$L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,U+C8V-SHM-S4N.3`P)UT@/2`G1&%R92!#;W5N='D@1W5N;F5R
M>2!286YG92P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S4N-C@V.BTQ,3<N-CDP)UT@/2`G0VAI;F$@3&%K92P@3F%V86P@06ER($9A
M8VEL:71Y+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M-2XX,3@Z+3@S+CDX-B==(#T@)TMN;WAV:6QL92P@36-':&5E(%1Y<V]N($%I
M<G!O<G0L(%1.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U
M+C@W,3HM-S@N-S@V)UT@/2`G4F%L96EG:"`O($1U<FAA;2P@4F%L96EG:"U$
M=7)H86T@26YT97)N871I;VYA;"!!:7)P;W)T+"!.0R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-BXP-SDZ+3$Q-2XQ-34G72`]("=,87,@
M5F5G87,L($UC0V%R<F%N($EN=&5R;F%T:6]N86P@06ER<&]R="P@3E8G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S8N,#DX.BTW.2XY-#0G
M72`]("='<F5E;G-B;W)O+"!0:65D;6]N="!4<FEA9"!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,V+C$Q.3HM.#8N-C@Y)UT@/2`G3F%S:'9I;&QE+"!.87-H=FEL;&4@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!43B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-BXQ.3<Z+3DU+C@X-B==(#T@)U1U;'-A+"!4=6QS82!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,V+C,P-#HM,3$Y+CDS."==(#T@)TQE;6]O<F4L($YA
M=F%L($%I<B!3=&%T:6]N+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-BXS,S,Z+3$Q-RXQ,#`G72`]("=3=7!E<FEO<B!686QL97D@
M1W5N;F5R>2!286YG92P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S8N-#,S.BTY-BXS.#,G72`]("=(;VUI;GD@375N:6-I<&%L+"!/
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXT,S<Z+3DY
M+C4R,2==(#T@)U=O;V1W87)D+"!797-T(%=O;V1W87)D($%I<G!O<G0L($]+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C0T.#HM,3`S
M+C$U,R==(#T@)T-L87ET;VXL($-L87ET;VX@375N:6-I<&%L($%I<G!A<FLL
M($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C4S,SHM
M,3$U+CDP,"==(#T@)TEN9&EA;B!3<')I;F=S($=U;FYE<GD@4F%N9V4L($Y6
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C8R,3HM,3$V
M+C`R."==(#T@)TUE<F-U<GDL($1E<V5R="!2;V-K($%I<G!O<G0L($Y6)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C8V-SHM.#<N-3`P
M)UT@/2`G1F]R="!#86UP8F5L;"!5+B!3+B!!<FUY($%I<F9I96QD+"!+62<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXW.#`Z+3$Q.2XW
M,3DG72`]("=&<F5S;F\L($9R97-N;R!!:7(@5&5R;6EN86PL($-!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+CDP-#HM-S8N,3DR)UT@
M/2`G3F]R9F]L:RP@3F]R9F]L:R!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%9!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+CDR,3HM,3$Q
M+C0T."==(#T@)U!A9V4L(%!A9V4@375N:6-I<&%L($%I<G!O<G0L($%:)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C`P,#HM,3`Q+C@X
M,R==(#T@)T5L:VAA<G0@+R!%;&MH87)T+4UO<G1O;B!#;W5N='D@06ER<&]R
M="P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N,#4V
M.BTX."XW-S0G72`]("=0861U8V%H+"!"87)K;&5Y(%)E9VEO;F%L($%I<G!O
M<G0L($M9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C`X
M,SHM-S8N,S4P)UT@/2`G3&%N9VQE>2!!:7(@1F]R8V4@0F%S92P@5D$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N,C0P.BTY,RXS.3`G
M72`]("=3<')I;F=F:65L9"P@4W!R:6YG9FEE;&0@4F5G:6]N86P@06ER<&]R
M="P@34\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N,C@T
M.BTY."XU-3,G72`]("=-961I8VEN92!,;V1G92P@365D:6-I;F4@3&]D9V4L
M($M3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C,Q-SHM
M-SDN.3<T)UT@/2`G4F]A;F]K92P@4F]A;F]K92!296=I;VYA;"!!:7)P;W)T
M+"!602<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXS,C$Z
M+3<Y+C(P-R==(#T@)TQY;F-H8G5R9RP@3'EN8VAB=7)G(%)E9VEO;F%L($%I
M<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W
M+C,V-SHM,3(P+C4V-R==(#T@)TUE<F-E9"`O($-A<W1L92!!:7(@1F]R8V4@
M0F%S92P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N
M,S<Q.BTQ,3@N,S4X)UT@/2`G0FES:&]P+"!":7-H;W`@06ER<&]R="P@0T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N-#`V.BTQ,C(N
M,#0X)UT@/2`G36]U;G1A:6X@5FEE=RP@36]F9F5T="!&:65L9"P@0T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N-#,Y.BTQ,#4N.#8Q
M)UT@/2`G06QA;6]S82P@4V%N($QU:7,@5F%L;&5Y(%)E9VEO;F%L($%I<G!O
M<G0L($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C4Q
M,3HM-S<N,S(S)UT@/2`G4FEC:&UO;F0L(%)I8VAM;VYD($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@5D$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S<N-C$R.BTQ,30N-3(V)UT@/2`G0V%L:65N=&4L($Y6)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C8R,#HM,3(R+C,V-2==(#T@
M)U-A;B!&<F%N8VES8V\L(%-A;B!&<F%N8VES8V\@26YT97)N871I;VYA;"!!
M:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M-RXV-#<Z+3DW+C0R.2==(#T@)U=I8VAI=&$L(%=I8VAI=&$@36ED+4-O;G1I
M;F5N="!!:7)P;W)T+"!+4R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-RXW,#`Z+3$R,RXP,#`G72`]("=&87)A;&QO;B!)<VQA;F0L($-!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C<P,#HM.3@N
M-S4P)UT@/2`G4')A='0@375N:6-I<&%L+"!+4R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-RXW,3DZ+3$R,BXR,S4G72`]("=/86ML86YD
M+"!-971R;R!/86ML86YD($EN=&5R;F%T:6]N86P@06ER<&]R="P@0T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N-S<S.BTY.2XY-S`G
M72`]("=$;V1G92!#:71Y+"!$;V1G92!#:71Y(%)E9VEO;F%L($%I<G!O<G0L
M($M3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C<X,SHM
M,3(R+C,Q-R==(#T@)T%L86UE9&$@3F%V86P@06ER(%-T871I;VXL($-!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C<Y-3HM.#$N,3(U
M)UT@/2`G0F5C:VQE>2P@4F%L96EG:"!#;W5N='D@365M;W)I86P@06ER<&]R
M="P@5U8G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N.#DP
M.BTQ,C$N,C(T)UT@/2`G4W1O8VMT;VXL(%-T;V-K=&]N($UE=')O<&]L:71A
M;B!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S-RXY,#`Z+3@U+CDV-R==(#T@)T9O<G0@2VYO>"P@2UDG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N.30Q.BTW-2XT-C,G72`]("=7
M86QL;W!S($ES;&%N9"P@5V%L;&]P<R!&;&EG:'0@1F%C:6QI='D@06ER<&]R
M="P@5D$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N,#0Q
M.BTX-"XV,#8G72`]("=,97AI;F=T;VXL($)L=64@1W)A<W,@06ER<&]R="P@
M2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N,#0S.BTX
M-RXU,C`G72`]("=%=F%N<W9I;&QE+"!%=F%N<W9I;&QE(%)E9VEO;F%L($%I
M<G!O<G0L($E.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X
M+C$W-SHM.#4N-S,P)UT@/2`G3&]U:7-V:6QL92P@4W1A;F1I9F]R9"!&:65L
M9"P@2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N,C8W
M.BTQ,C$N.34P)UT@/2`G1F%I<F9I96QD("\@5')A=FES($%I<B!&;W)C92!"
M87-E+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XR
M-SDZ+3<V+C0Q-"==(#T@)U!A='5X96YT(%)I=F5R+"!.879A;"!!:7(@4W1A
M=&EO;BP@340G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N
M,CDP.BTQ,#0N-#DX)UT@/2`G4'5E8FQO+"!0=65B;&\@365M;W)I86P@06ER
M<&]R="P@0T\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N
M,S,S.BTW-2XP.#,G72`]("=/8V5A;B!#:71Y+"!-1"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S."XS-C4Z+3@R+C4U-2==(#T@)TAU;G1I
M;F=T;VXL(%1R:2U3=&%T92!!:7)P;W)T+"!75B<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S."XS-SDZ+3@Q+C4Y,2==(#T@)T-H87)L97-T
M;VXL(%EE86=E<B!!:7)P;W)T+"!75B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S."XU,#<Z+3$R,2XT.34G72`]("=386-R86UE;G1O+"!3
M86-R86UE;G1O($5X96-U=&EV92!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S."XV-#,Z+3@X+CDV-"==(#T@)U-A;&5M
M+"!386QE;2U,96-K<F]N92!!:7)P;W)T+"!)3"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S."XW,#`Z+3$P-"XW-C<G72`]("=&;W)T($-A
M<G-O;BP@0T\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N
M-S4R.BTY,"XS-S0G72`]("=3="X@3&]U:7,L($QA;6)E<G0M4W0N($QO=6ES
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@34\G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N.#$V.BTQ,#0N-S$Q)UT@/2`G0V]L;W)A9&\@
M4W!R:6YG<RP@0VET>2!/9B!#;VQO<F%D;R!3<')I;F=S($UU;FEC:7!A;"!!
M:7)P;W)T+"!#3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M."XX,3<Z+3<V+C@U,"==(#T@)T-A;7`@4W!R:6YG<R`O($%N9')E=W,@06ER
M($9O<F-E($)A<V4L($U$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,X+C@Q-SHM.3(N,C$X)UT@/2`G0V]L=6UB:6$L($-O;'5M8FEA(%)E
M9VEO;F%L($%I<G!O<G0L($U/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,X+C@T.#HM-S<N,#,T)UT@/2`G5V%S:&EN9W1O;B!$0RP@4F5A
M9V%N($YA=&EO;F%L($%I<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,X+C@X-3HM-SDN.#4S)UT@/2`G16QK:6YS+"!%;&MI
M;G,M4F%N9&]L<&@@0V]U;G1Y+4IE;FYI;F=S(%)A;F1O;'!H($9I96QD+"!7
M5B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XY,S4Z+3<W
M+C0T."==(#T@)U=A<VAI;F=T;VX@1$,L(%=A<VAI;F=T;VXM1'5L;&5S($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@5D$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S@N.38W.BTQ,#0N.#$W)UT@/2`G06ER($9O<F-E($%C
M861E;7DL($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y
M+C`T,SHM.#0N-C<R)UT@/2`G0V]V:6YG=&]N("\@0VEN8VEN;F%T:2P@0VEN
M8VEN;F%T:2`O($YO<G1H97)N($ME;G1U8VMY($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN
M,#<S.BTY-2XV,C8G72`]("=4;W!E:V$L(%!H:6QI<"!":6QL87)D($UU;FEC
M:7!A;"!!:7)P;W)T+"!+4R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S.2XQ,#`Z+3DV+C<V-R==(#T@)T9O<G0@4FEL97DL($M3)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C$S-#HM,3`X+C4S.2==
M(#T@)T=R86YD($IU;F-T:6]N+"!786QK97(@1FEE;&0L($-/)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C$V-SHM-S8N-C@S)UT@/2`G
M0F%L=&EM;W)E+"!"86QT:6UO<F4M5V%S:&EN9W1O;B!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($U$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,Y+C(Y-3HM,3$T+C@T-2==(#T@)T5L>2P@16QY($%I<G!O<G0L($Y6)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C(Y-SHM.30N-S,Q
M)UT@/2`G2V%N<V%S($-I='DL($MA;G-A<R!#:71Y($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@34\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,SDN,S8W.BTQ,#$N-CDS)UT@/2`G1V]O9&QA;F0L(%)E;FYE<B!&:65L9"P@
M2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-#`P.BTQ
M,C,N.#$W)UT@/2`G1F]R="!"<F%G9RP@0T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,SDN-#8U.BTW-"XU.#<G72`]("=!=&QA;G1I8R!#
M:71Y+"!!=&QA;G1I8R!#:71Y($EN=&5R;F%T:6]N86P@06ER<&]R="P@3DHG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-#@T.BTQ,3DN
M-S<Q)UT@/2`G4F5N;RP@4F5N;R!486AO92!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C4U
M,3HM.3<N-C4Q)UT@/2`G0V]N8V]R9&EA+"!";&]S<V5R($UU;FEC:7!A;"!!
M:7)P;W)T+"!+4R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M.2XV,#DZ+3$Q,"XW-34G72`]("=0<FEC92P@0V%R8F]N($-O=6YT>2!!:7)P
M;W)T+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XW
M,C4Z+3@V+C(X,B==(#T@)TEN9&EA;F%P;VQI<RP@26YD:6%N87!O;&ES($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@24XG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,SDN-S8W.BTW-"XQ,#`G72`]("="87)N96=A="!#;V%S
M="!'=6%R9"!3=&%T:6]N+"!.2B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S.2XW-C@Z+3DT+CDP.2==(#T@)U-T+B!*;W-E<&@L(%)O<V5C
M<F%N<R!-96UO<FEA;"!!:7)P;W)T+"!-3R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S.2XW.#,Z+3$P-"XX-C<G72`]("=$96YV97(@+R!3
M=&%P;&5T;VX@26YT97)N871I;VYA;"P@0V\N+"!#3R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S.2XX,S,Z+3$P-"XV-3<G72`]("=$96YV
M97(L($1E;G9E<B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($-/)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C@S,SHM.#0N,#4P)UT@/2`G
M1&%Y=&]N("\@5W)I9VAT+5!A='1E<G-O;B!!:7(@1F]R8V4@0F%S92P@3T@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN.#0U.BTX.2XV
M.#0G72`]("=3<')I;F=F:65L9"P@0V%P:71A;"!!:7)P;W)T+"!)3"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XX-C@Z+3<U+C(S,2==
M(#T@)U!H:6QA9&5L<&AI82P@4&AI;&%D96QP:&EA($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@4$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,SDN.3`V.BTX-"XR,3DG72`]("=$87ET;VXL($-O>"!$87ET;VX@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!/2"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S.2XY.34Z+3@R+C@W-B==(#T@)T-O;'5M8G5S+"!0;W)T($-O
M;'5M8G5S($EN=&5R;F%T:6]N86P@06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#`N,#,S.BTW-"XS,3<G72`]("=,86ME
M:'5R<W0@3F%V86P@06ER(%-T871I;VXL($Y*)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0P+C$U,3HM,3(R+C(U,B==(#T@)U)E9"!";'5F
M9BP@4F5D($)L=69F($UU;FEC:7!A;"!!:7)P;W)T+"!#02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,"XQ-C<Z+3$Q,BXY,S,G72`]("=$
M=6=W87D@4')O=FEN9R!'<F]U;F1S+"!55"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,"XR-3`Z+3DS+C<Q-R==(#T@)U-P:6-K87)D+"!-
M3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XS,#`Z+3$P
M.2XY.#,G72`]("=2;V]S979E;'0L(%54)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0P+C0Y,SHM,3`W+C4R-"==(#T@)T-R86EG+"!#<F%I
M9RU-;V9F870@06ER<&]R="P@0T\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#`N-3`T.BTX,"XR-C8G72`]("=0:71T<V)U<F=H+"!0:71T
M<V)U<F=H($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#`N-3$U.BTQ,C(N,CDW)UT@/2`G4F5D
M9&EN9RP@4F5D9&EN9R!-=6YI8VEP86P@06ER<&]R="P@0T$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N-C,Y.BTW,RXW-C(G72`]("=.
M97<@66]R:RP@2V5N;F5D>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y9)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C8U,3HM-S4N-#0Y
M)UT@/2`G06QL96YT;W=N+"!,96AI9V@@5F%L;&5Y($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@4$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#`N-C8W.BTX.2XV.#0G72`]("=096]R:6$L($=R96%T97(@4&5O<FEA(%)E
M9VEO;F%L($%I<G!O<G0L($E,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0P+C8X,CHM-S0N,38Y)UT@/2`G3F5W87)K+"!.97=A<FL@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!.2B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,"XW,S,Z+3$Q-"XP,S,G72`]("=796YD;W9E<B`O($%I
M<B!&;W)C92!!=7AI;&QA<GD@1FEE;&0L(%54)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0P+C<W.#HM,3$Q+CDV.2==(#T@)U-A;'0@3&%K
M92!#:71Y+"!386QT($QA:V4@0VET>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M(%54)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C<W.3HM
M-S,N.#@P)UT@/2`G3F5W(%EO<FLL($QA($=U87)D:6$@06ER<&]R="P@3EDG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N.#`P.BTQ,C0N
M,38W)UT@/2`G175R96MA+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,"XX,S$Z+3DV+C<V-"==(#T@)TQI;F-O;&XL($QI;F-O;&X@
M375N:6-I<&%L($%I<G!O<G0L($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0P+CDP,CHM,3$W+C@P-R==(#T@)U=I;FYE;75C8V$L(%=I
M;FYE;75C8V$@375N:6-I<&%L($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0P+CDQ.#HM.#$N-#0S)UT@/2`G06MR;VXL
M($%K<F]N+4-A;G1O;B!296=I;VYA;"!!:7)P;W)T+"!/2"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,"XY-3@Z+3DX+C,Q,R==(#T@)T=R
M86YD($ES;&%N9"P@0V5N=')A;"!.96)R87-K82!296=I;VYA;"!!:7)P;W)T
M+"!.12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XY-S@Z
M+3@U+C$Y-2==(#T@)T9O<G0@5V%Y;F4L($9O<G0@5V%Y;F4@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!)3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,2XP.3DZ+3$P,BXY.#8G72`]("=3:61N97DL(%-I9&YE>2!-=6YI
M8VEP86P@06ER<&]R="P@3D4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#$N,3$W.BTY-2XY,#`G72`]("=/;6%H82`O($]F9G5T="!!:7(@
M1F]R8V4@0F%S92P@3D4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#$N,3(R.BTQ,#`N-C8X)UT@/2`G3F]R=&@@4&QA='1E+"!.;W)T:"!0
M;&%T=&4@4F5G:6]N86P@06ER<&]R="P@3D4G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#$N,34X.BTQ,#0N.#`W)UT@/2`G0VAE>65N;F4L
M($-H97EE;FYE($%I<G!O<G0L(%=9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0Q+C$U.#HM-S,N,3(Y)UT@/2`G0G)I9&=E<&]R="P@4VEK
M;W)S:WD@365M;W)I86P@06ER<&]R="P@0U0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#$N,3DT.BTQ,3(N,#$V)UT@/2`G3V=D96XL($]G
M9&5N+4AI;F-K;&5Y($%I<G!O<G0L(%54)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0Q+C(T,SHM-S8N.3(R)UT@/2`G5VEL;&EA;7-P;W)T
M+"!7:6QL:6%M<W!O<G0M3'EC;VUI;F<@0V]U;G1Y($%I<G!O<G0L(%!!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C(U-#HM.#`N-C<T
M)UT@/2`G66]U;F=S=&]W;BP@66]U;F=S=&]W;BU787)R96X@4F5G:6]N86P@
M06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#$N,S$P.BTY-2XX.3DG72`]("=/;6%H82P@17!P;&5Y($%I<F9I96QD+"!.
M12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XS,3<Z+3DV
M+C,V-R==(#T@)U9A;&QE>2P@3D4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#$N,S,Y.BTW-2XW,C<G72`]("=7:6QK97,M0F%R<F4@+2!3
M8W)A;G1O;BP@5VEL:V5S+4)A<G)E("\@4V-R86YT;VX@26YT97)N871I;VYA
M;"!!:7)P;W)T+"!002<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,2XS-C<Z+3@X+C8X,R==(#T@)TUA<G-E:6QL97,@27-L86YD+"!)3"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XT,#4Z+3@Q+C@U
M,R==(#T@)T-L979E;&%N9"P@0VQE=F5L86YD+4AO<&MI;G,@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!/2"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,2XT-3$Z+3DP+C4Q-2==(#T@)TUO;&EN92P@475A9"U#:71Y($%I
M<G!O<G0L($E,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q
M+C4S.#HM.3,N-C8V)UT@/2`G1&5S($UO:6YE<RP@1&5S($UO:6YE<R!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0Q+C4X.3HM.#,N.#`Q)UT@/2`G5&]L961O+"!4;VQE9&\@
M17AP<F5S<R!!:7)P;W)T+"!/2"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,2XU.30Z+3$P.2XP-C4G72`]("=2;V-K(%-P<FEN9W,L(%)O
M8VL@4W!R:6YG<RU3=V5E='=A=&5R($-O=6YT>2!!:7)P;W)T+"!762<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XV-3`Z+3<P+C4Q-R==
M(#T@)T]T:7,@06ER($YA=&EO;F%L($=U87)D($)A<V4L($U!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C8V-SHM-CDN.38W)UT@/2`G
M0VAA=&AA;2P@34$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#$N-S`Y.BTX-BXS,3DG72`]("=3;W5T:"!"96YD+"!3;W5T:"!"96YD(%)E
M9VEO;F%L($%I<G!O<G0L($E.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0Q+C<R-#HM-S$N-#(X)UT@/2`G4')O=FED96YC92P@5&AE;V1O
M<F4@1G)A;F-I<R!'<F5E;B!3=&%T92!!:7)P;W)T+"!222<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,2XW.#0Z+3@W+C<U-2==(#T@)T-H
M:6-A9V\L($-H:6-A9V\@36ED=V%Y($%I<G!O<G0L($E,)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C@V-SHM,3`S+C4X-B==(#T@)U-C
M;W1T<V)L=69F+"!(96EL:6<@1FEE;&0L($Y%)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0Q+C@X,SHM.3$N-S(T)UT@/2`G0V5D87(@4F%P
M:61S+"!#961A<B!287!I9',@375N:6-I<&%L($%I<G!O<G0L($E!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+CDS.#HM-S(N-C@S)UT@
M/2`G5VEN9'-O<B!,;V-K<RP@0G)A9&QE>2!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($-4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+CDX
M,#HM.#<N.3`T)UT@/2`G0VAI8V%G;RP@0VAI8V%G;RU/7"=(87)E($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@24PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#$N.3@Q.BTY-RXT,S<G72`]("=.;W)F;VQK+"!3=&5F86X@
M365M;W)I86P@06ER<&]R="P@3D4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#(N,#@P.BTX,"XQ.#,G72`]("=%<FEE+"!%<FEE($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#(N,3DS.BTX.2XP.3,G72`]("=2;V-K9F]R9"P@1W)E871E
M<B!2;V-K9F]R9"!!:7)P;W)T+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,BXR,#`Z+3<R+C4S,R==(#T@)T-H:6-O<&5E($9A;&QS
M("\@5V5S=&]V97(@06ER($9O<F-E($)A<V4L($U!)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0R+C(P.#HM-S4N.3@Q)UT@/2`G0FEN9VAA
M;71O;BP@0FEN9VAA;71O;B!296=I;VYA;"!!:7)P;W)T+"!.62<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXR,S$Z+3@S+C,S,2==(#T@
M)T1E=')O:70L($1E=')O:70@365T<F]P;VQI=&%N(%=A>6YE($-O=6YT>2!!
M:7)P;W)T+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M,BXS-C$Z+3<Q+C`Q,2==(#T@)T)O<W1O;BP@3&]G86X@26YT97)N871I;VYA
M;"!!:7)P;W)T+"!-02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,BXS.#$Z+3$R,BXX-S(G72`]("=-961F;W)D+"!2;V=U92!686QL97D@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!/4B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,BXS.3@Z+3DP+C<P-"==(#T@)T1U8G5Q=64L($1U
M8G5Q=64@4F5G:6]N86P@06ER<&]R="P@24$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#(N-#`R.BTY-BXS.#0G72`]("=3:6]U>"!#:71Y
M+"!3:6]U>"!'871E=V%Y($%I<G!O<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0R+C0V.#HM-S$N,CDT)UT@/2`G0F5D9F]R9"P@
M2&%N<V-O;2!&:65L9"P@34$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#(N-34P.BTY-"XQ.#,G72`]("=&;W)T($1O9&=E+"!)02<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXU-30Z+3DR+C0P,2==
M(#T@)U=A=&5R;&]O+"!7871E<FQO;R!-=6YI8VEP86P@06ER<&]R="P@24$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N-3<Y.BTQ,3`N
M,3`S)UT@/2`G0FEG(%!I;F5Y+"!":6<@4&EN97DM36%R8FQE=&]N($%I<G!O
M<G0L(%=9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C<T
M-SHM-S,N-SDY)UT@/2`G06QB86YY+"!!;&)A;GD@0V]U;G1Y($%I<G!O<G0L
M($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C<X,#HM
M.#0N-3<Y)UT@/2`G3&%N<VEN9RP@0V%P:71A;"!#:71Y($%I<G!O<G0L($U)
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C<Y-#HM,3`U
M+C,X,B==(#T@)T1O=6=L87,L($-O;G9E<G-E($-O=6YT>2!!:7)P;W)T+"!7
M62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXX,34Z+3$P
M."XW,C@G72`]("=,86YD97(L(%=9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0R+C@U.3HM,3`P+C4U,2==(#T@)U9A;&5N=&EN92P@36EL
M;&5R($9I96QD+"!.12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,BXX.#$Z+3@U+C4R,R==(#T@)T=R86YD(%)A<&ED<RP@1V5R86QD(%(N
M($9O<F0@26YT97)N871I;VYA;"!!:7)P;W)T+"!-22<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,BXX.3@Z+3$P-BXT-S,G72`]("=#87-P
M97(L($YA=')O;F$@0V]U;G1Y($EN=&5R;F%T:6]N86P@06ER<&]R="P@5UDG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N.3(P.BTQ,3(N
M-3<Q)UT@/2`G4&]C871E;&QO+"!0;V-A=&5L;&\@4F5G:6]N86P@06ER<&]R
M="P@240G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N.30Q
M.BTW."XW,S8G72`]("="=69F86QO+"!'<F5A=&5R($)U9F9A;&\@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!.62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,BXY-34Z+3@W+CDP-"==(#T@)TUI;'=A=6ME92P@1V5N97)A
M;"!-:71C:&5L;"!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%=))SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+CDV-SHM.#,N-S0Y)UT@/2`G
M1FQI;G0L($)I<VAO<"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U))SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C`V,CHM,3`X+C0T-B==
M(#T@)U)I=F5R=&]N+"!2:79E<G1O;B!296=I;VYA;"!!:7)P;W)T+"!762<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXQ,#DZ+3<V+C$P
M,R==(#T@)U-Y<F%C=7-E+"!3>7)A8W5S92!(86YC;V-K($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#,N,3$W.BTW-RXV-S<G72`]("=2;V-H97-T97(L($=R96%T97(@4F]C
M:&5S=&5R($EN=&5R;F%T:6]N86P@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#,N,30Q.BTX.2XS-#4G72`]("=-861I
M<V]N+"!$86YE($-O=6YT>2!296=I;VYA;"U4<G5A>"!&:65L9"P@5TDG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N,3<Q.BTX-BXR,S<G
M72`]("=-=7-K96=O;BP@375S:V5G;VX@0V]U;G1Y($%I<G!O<G0L($U))SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C$Y-3HM-S$N-3`Q
M)UT@/2`G0V]N8V]R9"P@0V]N8V]R9"!-=6YI8VEP86P@06ER<&]R="P@3D@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N,SDQ.BTY.2XX
M-#,G72`]("=7:6YN97(L($)O8B!7:6QE>2!&:65L9"!!:7)P;W)T+"!31"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXU-C<Z+3$Q-BXR
M-#$G72`]("=";VES92P@0F]I<V4@06ER(%1E<FUI;F%L+"!)1"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXU-S<Z+3DV+C<U-"==(#T@
M)U-I;W5X($9A;&QS+"!&;W-S($9I96QD+"!31"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T,RXU.34Z+3$Q."XY-38G72`]("="=7)N<RP@
M0G5R;G,@375N:6-I<&%L($%I<G!O<G0L($]2)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0S+C8T,CHM-S`N,S`T)UT@/2`G4&]R=&QA;F0L
M(%!O<G1L86YD($EN=&5R;F%T:6]N86P@2F5T<&]R="P@344G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N-S8W.BTY.2XS,3@G72`]("=#
M:&%M8F5R;&%I;BP@0VAA;6)E<FQA:6X@375N:6-I<&%L($%I<G!O<G0L(%-$
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C@W.3HM.3$N
M,C4W)UT@/2`G3&$@0W)O<W-E+"!,82!#<F]S<V4@375N:6-I<&%L($%I<G!O
M<G0L(%=))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+CDP
M,#HM-CDN.3,U)UT@/2`G0G)U;G-W:6-K+"!.879A;"!!:7(@4W1A=&EO;BP@
M344G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N.3`T.BTY
M,BXT.3(G72`]("=2;V-H97-T97(L(%)O8VAE<W1E<B!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0T+C`T-CHM,3`S+C`U-"==(#T@)U)A<&ED($-I='DL(%)A<&ED($-I='D@
M4F5G:6]N86P@06ER<&]R="P@4T0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#0N,#4P.BTW-2XW,S,G72`]("=&;W)T($1R=6T@+R!7:&5E
M;&5R+5-A8VL@52X@4RX@07)M>2!!:7)F:65L9"P@3EDG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#0N,3,S.BTQ,C,N,C$T)UT@/2`G175G
M96YE+"!-86AL;VX@4W=E970@1FEE;&0L($]2)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0T+C(V-SHM-S$N,S`P)UT@/2`G36]U;G0@5V%S
M:&EN9W1O;BP@3D@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#0N,S,Y.BTQ,#4N-30R)UT@/2`G1VEL;&5T=&4L($=I;&QE='1E+4-A;7!B
M96QL($-O=6YT>2!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T-"XS-3$Z+3@T+C8W-"==(#T@)TAO=6=H=&]N($QA:V4L
M(%)O<V-O;6UO;B!#;W5N='D@06ER<&]R="P@34DG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#0N,S@X.BTY."XR,C@G72`]("=(=7)O;BP@
M2'5R;VX@4F5G:6]N86P@06ER<&]R="P@4T0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#0N-#$Y.BTW,BXP,3DG72`]("=386EN="!*;VAN
M<V)U<GDL(%94)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T
M+C0V.#HM-S,N,34P)UT@/2`G0G5R;&EN9W1O;BP@0G5R;&EN9W1O;B!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L(%94)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0T+C0W.3HM.#@N,3,W)UT@/2`G1W)E96X@0F%Y+"!!=7-T
M:6X@4W1R875B96P@26YT97)N871I;VYA;"!!:7)P;W)T+"!722<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XU,3<Z+3$P.2XP,3<G72`]
M("=#;V1Y+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M-"XU,S,Z+3<P+C4S,R==(#T@)U)U;69O<F0L($U%)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0T+C4W-CHM-S$N,3<Y)UT@/2`G0F5R;&EN
M+"!"97)L:6X@375N:6-I<&%L($%I<G!O<G0L($Y()SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0T+C<V.3HM,3`V+CDV.2==(#T@)U-H97)I
M9&%N+"!3:&5R:61A;B!#;W5N='D@06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#0N.#,S.BTX-"XU-3`G72`]("='<F%Y
M:6YG($%I<B!&;W)C92!286YG92P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#0N.#@S.BTY,RXR,CDG72`]("=-:6YN96%P;VQI<RP@
M36EN;F5A<&]L:7,M4W0N(%!A=6P@26YT97)N871I;VYA;"!!:7)P;W)T+"!-
M3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XY,#@Z+3$R
M,BXY.34G72`]("=386QE;2P@36-.87)Y($9I96QD+"!/4B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-"XY,3<Z+38W+C`P,"==(#T@)T5A
M<W1P;W)T+"!-12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M-"XY,S,Z+3<R+C(P,"==(#T@)TYE=W!O<G0L(%94)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0U+C`W,CHM.#,N-38T)UT@/2`G06QP96YA
M+"!!;'!E;F$@0V]U;G1Y(%)E9VEO;F%L($%I<G!O<G0L($U))SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C0T,SHM.3@N-#$S)UT@/2`G
M06)E<F1E96XL($%B97)D965N(%)E9VEO;F%L($%I<G!O<G0L(%-$)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C4T-3HM.30N,#4R)UT@
M/2`G4W0N($-L;W5D+"!3="X@0VQO=60@375N:6-I<&%L($%I<G!O<G0L($U.
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C4Y,3HM,3(R
M+C8P,"==(#T@)U!O<G1L86YD+"!0;W)T;&%N9"!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($]2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U
M+C8Y.#HM,3$X+C@S-"==(#T@)U!E;F1L971O;BP@16%S=&5R;B!/<F5G;VX@
M4F5G:6]N86P@070@4&5N9&QE=&]N($%I<G!O<G0L($]2)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C<U,#HM.#<N,#,S)UT@/2`G17-C
M86YA8F$L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U
M+C@P-SHM,3`X+C4T,B==(#T@)T)I;&QI;F=S+"!":6QL:6YG<R!,;V=A;B!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0U+CDS,SHM.3`N-#4P)UT@/2`G4&%R:R!&86QL<RP@
M5TDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N,34W.BTQ
M,C,N.#@R)UT@/2`G07-T;W)I82P@07-T;W)I82!296=I;VYA;"!!:7)P;W)T
M+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXS-S4Z
M+3$Q-RXP,30G72`]("=,97=I<W1O;BP@3&5W:7-T;VXM3F5Z(%!E<F-E($-O
M=6YT>2!!:7)P;W)T+"!)1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T-BXT,C@Z+3$P-2XX.#8G72`]("=-:6QE<R!#:71Y+"!&<F%N:R!7
M:6QE>2!&:65L9"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T-BXT-SDZ+3@T+C,U-R==(#T@)U-A=6QT(%-T92X@36%R
M:64L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C4S
M,SHM.#<N-34P)UT@/2`G36%R<75E='1E+"!-22<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T-BXU-C0Z+3$R,"XU,S0G72`]("=986MI;6$L
M(%EA:VEM82!!:7(@5&5R;6EN86PL(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0V+C4V-SHM,3$Y+C8P,"==(#T@)TAA;F9O<F0L(%=!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C8P,#HM.30N
M,S$W)UT@/2`G4&5Q=6]T($QA:V4L($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0V+C8P-CHM,3$Q+CDV-"==(#T@)TAE;&5N82P@2&5L
M96YA(%)E9VEO;F%L($%I<G!O<G0L($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0V+C8X,SHM-C@N,#4P)UT@/2`G4')E<W%U92!)<VQE
M+"!-12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXW.#(Z
M+3$P,"XW-3<G72`]("=":7-M87)C:RP@0FES;6%R8VL@375N:6-I<&%L($%I
M<G!O<G0L($Y$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V
M+C@T,SHM.3(N,C(V)UT@/2`G1'5L=71H+"!$=6QU=&@@26YT97)N871I;VYA
M;"!!:7)P;W)T+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T-BXX-C<Z+38X+C`Q,R==(#T@)T-A<FEB;W4L($-A<FEB;W4@375N:6-I
M<&%L($%I<G!O<G0L($U%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0V+CDR,3HM,3$T+C`Y,R==(#T@)TUI<W-O=6QA+"!-:7-S;W5L82!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0V+CDR-3HM.38N.#$Q)UT@/2`G1F%R9V\L($AE8W1O
M<B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y$)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0V+CDW,SHM,3(R+CDP,R==(#T@)T]L>6UP:6$L
M($]L>6UP:6$@06ER<&]R="P@5T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#<N,3$W.BTQ,C(N-34P)UT@/2`G1F]R="!,97=I<R`O($=R
M87D@52X@4RX@07)M>2!!:7)F:65L9"P@5T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#<N,34P.BTQ,C(N-#@S)UT@/2`G5&%C;VUA("\@
M36-#:&]R9"!!:7(@1F]R8V4@0F%S92P@5T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#<N,38X.BTX."XT.#DG72`]("=(86YC;V-K+"!(
M;W5G:'1O;B!#;W5N='D@365M;W)I86P@06ER<&]R="P@34DG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N-#0U.BTQ,C(N,S$T)UT@/2`G
M4V5A='1L92P@4V5A='1L92U486-O;6$@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!702<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-RXT-S,Z
M+3$Q,2XS.#(G72`]("='<F5A="!&86QL<RP@1W)E870@1F%L;',@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-RXU,#`Z+3DT+CDS,R==(#T@)T)E;6ED:FDL($U.)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0W+C8R,3HM,3$W+C4R."==
M(#T@)U-P;VMA;F4L(%-P;VMA;F4@26YT97)N871I;VYA;"!!:7)P;W)T+"!7
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-RXW-3`Z+3$P
M,2XX,S,G72`]("=2;W-E9VQE;BP@3D0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#<N.3,X.BTQ,C0N-34U)UT@/2`G475I;&QA>75T92P@
M475I;&QA>75T92!3=&%T92!!:7)P;W)T+"!702<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T."XQ,#`Z+3DX+C@V-R==(#T@)T1E=FEL<R!,
M86ME+"!.1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XQ
M,S,Z+3$R,RXT,#`G72`]("=0;W)T($%N9V5L97,@0V]A<W0@1W5A<F0@06ER
M(%-T871I;VXL(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0X+C$W-#HM,3`S+C8S-R==(#T@)U=I;&QI<W1O;BP@4VQO=6QI;B!&:65L
M9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y$)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0X+C(Q-#HM,3`V+C8R,2==(#T@)T=L87-G;W<L
M($=L87-G;W<@26YT97)N871I;VYA;"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T."XS,#0Z+3$Q-"XR-C0G72`]("=+
M86QI<W!E;&PL($=L86-I97(@4&%R:R!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0X+C4T,SHM
M,3`Y+C<V,R==(#T@)TAA=G)E+"!(879R92!#:71Y+4-O=6YT>2!!:7)P;W)T
M+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XU-C(Z
M+3DS+C,Y."==(#T@)TEN=&5R;F%T:6]N86P@1F%L;',L($9A;&QS($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@34XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#@N.3,S.BTY-2XS-3`G72`]("=787)R;V%D+"!-3B<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U,2XX.3`Z+3$W-BXV,C4G
M72`]("=!9&%K+"!.879A;"!!:7(@4W1A=&EO;BP@04LG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-3(N-S$W.C$W-"XQ,3<G72`]("=3:&5M
M>6$L($5A<F5C:W-O;B!!<RP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-3(N.34P.BTQ-C@N.#4P)UT@/2`G3FEK;VQS:VDL($%+)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4S+CDP,#HM,38V+C4U
M,"==(#T@)T1U=&-H($AA<F)O<BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-34N,#,S.BTQ,S$N-38W)UT@/2`G06YN971T92!)<VQA
M;F0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4U+C(R
M,3HM,38R+C<R."==(#T@)T-O;&0@0F%Y+"!#;VQD($)A>2!!:7)P;W)T+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-2XS-3,Z+3$S
M,2XW,C(G72`]("=+971C:&EK86XL($ME=&-H:6MA;B!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S4U+C4X,SHM,3,S+C`X,R==(#T@)TML87=O8VLL($ML87=O8VL@06ER<&]R
M="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-38N-#@S
M.BTQ,S(N,S8W)UT@/2`G5W)A;F=E;&PL($%+)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S4V+C@Q-SHM,3,R+CDV-R==(#T@)U!E=&5R<V)U
M<F<L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4V+CDU
M,#HM,34X+C8Q-R==(#T@)U!O<G0@2&5I9&5N+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<U-RXP-#@Z+3$S-2XS-C4G72`]("=3:71K
M82P@4VET:V$@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-3<N,34P.BTQ-S`N,C$W)UT@/2`G4V%I;G0@4&%U;"P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3<N-3`P.BTQ,S0N
M-3@S)UT@/2`G06YG;V]N+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<U-RXW-3`Z+3$U,BXU,#`G72`]("=+;V1I86LL($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4X+C,U-CHM,3,T+C4V,R==
M(#T@)TIU;F5A=2P@2G5N96%U($EN=&5R;F%T:6]N86P@06ER<&]R="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3@N-#$W.BTQ,S4N
M-S,S)UT@/2`G1W5S=&%V=7,L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S4X+C8U,#HM,38R+C`V-R==(#T@)T-A<&4@3F5W96YH86T@
M06ER=V%Y<R!&86-I;&ET:65S(%-E8W1O<BP@04LG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-3@N-C@T.BTQ-38N-C4T)UT@/2`G2VEN9R!3
M86QM;VXL($MI;F<@4V%L;6]N($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S4Y+C`U,#HM,34X+C4Q-R==(#T@)T1I;&QI
M;F=H86T@375N:6-I<&%L+"!!:RP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-3DN-#,S.BTQ-#8N,S,S)UT@/2`G36ED9&QE=&]N($ES
M;&%N9"P@06LL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S4Y+C0V-SHM,3,U+C,P,"==(#T@)U-K86=W87DL($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y+C4Q-SHM,3,Y+C8V-R==(#T@)UEA
M:W5T870L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y
M+C8S,SHM,34Q+C4P,"==(#T@)TAO;65R("\@375N:6-I<&%L+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U.2XW-3`Z+3$U-"XY,3<G
M72`]("=);&EA;6YA("\@26QI86UN82!!:7)P;W)T+"!!2R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<U.2XX,#`Z+3$T-"XV,#`G72`]("=#
M87!E(%-A:6YT($5L:6%S+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V,"XP.#,Z+3$T,BXU,#`G72`]("=986MA=&%G82P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C`N,3$W.BTQ-#DN-#4P
M)UT@/2`G4V5W87)D+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<V,"XT.3(Z+3$T-2XT-S@G72`]("=#;W)D;W9A+"!-97)L92!++B`H
M375D:&]L92D@4VUI=&@@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C`N-3@P.BTQ-3$N,C,Y)UT@/2`G2V5N86DL($ME
M;F%I($UU;FEC:7!A;"!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<V,"XW.#,Z+3$V,2XX,S,G72`]("="971H96P@+R!"
M971H96P@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-C$N,3`P.BTQ-34N-38W)UT@/2`G4W!A<G)E=F]H;B!!:7)W87ES
M($9A8VEL:71I97,@4V5C=&]R+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<V,2XQ-S0Z+3$T.2XY.38G72`]("=!;F-H;W)A9V4L(%1E
M9"!3=&5V96YS($%N8VAO<F%G92!);G1E<FYA=&EO;F%L($%I<G!O<G0L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+C(U,#HM,30Y
M+C@P,"==(#T@)T%N8VAO<F%G92`O($5L;65N9&]R9B!!:7(@1F]R8V4@0F%S
M92P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C$N,C8W
M.BTQ-#DN-C4P)UT@/2`G1G0N(%)I8VAA<F1S;VX@+R!"<GEA;G0@52X@4RX@
M07)M>2!(96QI<&]R="P@06LL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S8Q+C4X,SHM,34Y+C4S,R==(#T@)T%N:6%K+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,2XV,#`Z+3$T.2XP.#,G
M72`]("=086QM97(L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S8Q+C<X,SHM,38V+C`S,R==(#T@)T-A<&4@4F]M86YZ;V9F($%I<G=A
M>7,@1F%C:6QI=&EE<R!396-T;W(L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S8Q+CDV-SHM,34Q+C$X,R==(#T@)U-K=V5N=&YA+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,BXQ,#`Z+3$U
M,BXW-3`G72`]("=0=6YT:6QL82P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-C(N,34P.BTQ-#4N-#4P)UT@/2`G1W5L:V%N82P@1W5L
M:V%N82!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<V,BXS,C$Z+3$U,"XP.30G72`]("=486QK965T;F$L(%1A;&ME971N
M82!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<V,BXY-C,Z+3$T,2XY,S8G72`]("=.;W)T:'=A>2P@3F]R=&AW87D@06ER
M<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C(N
M.38W.BTQ-34N-C$W)UT@/2`G36-'<F%T:"P@36-'<F%T:"!!:7)P;W)T+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,RXW-C<Z+3$W
M,2XW,S,G72`]("='86UB96QL($%U=&]M871I8R!796%T:&5R($]B<V5R=FEN
M9R`O(%)E<&]R=&EN9R!3>7-T96TL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S8S+C@X,SHM,38P+C@P,"==(#T@)U5N86QA:VQE970L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8S+CDP,#HM
M,34R+C(V-R==(#T@)TUI;F-H=6UI;F$L($%+)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S8T+C`P,#HM,30U+C<S,R==(#T@)T9O<G0@1W)E
M96QY("\@06QL96X@52X@4RX@07)M>2!!:7)F:65L9"P@06LL($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C4Q,CHM,38U+C0S-B==
M(#T@)TYO;64L($YO;64@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C0N-34P.BTQ-#DN,#@S)UT@/2`G3F5N86YA("\@
M375N+BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C0N
M-C4P.BTQ-#<N,#8W)UT@/2`G1F%I<F)A;FMS("\@16EE;'-O;B!!:7(@1F]R
M8V4@0F%S92P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-C0N-S,S.BTQ-38N.3,S)UT@/2`G1V%L96YA($$N+"!!2R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<V-"XX,#0Z+3$T-RXX-S8G72`]("=&
M86ER8F%N:W,L($9A:7)B86YK<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8U+C$V-SHM,34R
M+C$P,"==(#T@)U1A;F%N82P@0V%L:&]U;B!-96UO<FEA;"!!:7)P;W)T+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-2XR-3`Z+3$V
M-BXX-C<G72`]("=0;W)T($-L87)E;F-E+"!!2R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<V-2XU-C<Z+3$V-RXY,3<G72`]("=4:6X@0VET
M>2!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<V-2XY.#(Z+3$V,2XQ-3(G72`]("="=6-K
M;&%N9"P@0G5C:VQA;F0@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C8N,#`P.BTQ-3,N-S`P)UT@/2`G26YD:6%N($UO
M=6YT86EN($%I<G=A>7,@1F%C:6QI=&EE<R!396-T;W(L($%+)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8V+C4V-SHM,30U+C(V-R==(#T@
M)T9O<G0@675K;VXL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S8V+C@X-CHM,38R+C8P-"==(#T@)TMO='IE8G5E+"!7:65N($UE;6]R
M:6%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S8V+CDQ-SHM,34Q+C4Q-R==(#T@)T)E='1L97,L($)E='1L97,@06ER
M<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C<N
M,3`P.BTQ-3<N.#4P)UT@/2`G06UB;&5R+"!!;6)L97(@06ER<&]R="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C@N.#@S.BTQ-C8N
M,3,S)UT@/2`G0V%P92!,:7-B=7)N92!!:7)W87ES($9A8VEL:71I97,@4V5C
M=&]R+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V.2XS
M-C<Z+3$U,BXQ,S,G72`]("=5;6EA="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-CDN.#$W.BTQ-C(N.3$W)UT@/2`G4&]I;G0@3&%Y
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<W,"XQ,S,Z
M+3$T,RXV,S,G72`]("="87)T97(@27-L86YD+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<W,"XR,3`Z+3$U,2XP,#8G72`]("=.=6EQ
M<W5T+"!.=6EQ<W5T($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S<P+C4P,#HM,30Y+C@X,R==(#T@)T]L:6MT;VL@1&ES
M=&%N="!%87)L>2!787)N:6YG+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<W,"XV,S,Z+3$U.2XX-3`G72`]("=786EN=W)I9VAT+"!7
M86EN=W)I9VAT($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S<Q+C(X-#HM,34V+C<W."==(#T@)T)A<G)O=RP@4&]S="!2
M;V=E<G,@365M;W)I86P@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5R
M=6=U87DG75LG+3,P+C,X,SHM-38N-3`P)UT@/2`G07)T:6=A<R<["B1C;V]R
M9&EN871E<ULG57)U9W5A>2==6R<M,S`N.#@S.BTU-2XU,S,G72`]("=2:79E
M<F$G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,Q+C,X,SHM-3<N.34P
M)UT@/2`G4V%L=&\G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,Q+C<P
M,#HM-34N.3@S)UT@/2`G5&%C=6%R96UB;R<["B1C;V]R9&EN871E<ULG57)U
M9W5A>2==6R<M,S(N,S,S.BTU."XP,S,G72`]("=087ES86YD=2<["B1C;V]R
M9&EN871E<ULG57)U9W5A>2==6R<M,S(N,S8W.BTU-"XR,3<G72`]("=-96QO
M)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,RXR,3<Z+34T+C,X,R==
M(#T@)U1R96EN=&$@62!4<F5S)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;
M)RTS,RXR-3`Z+34X+C`V-R==(#T@)TUE<F-E9&5S)SL*)&-O;W)D:6YA=&5S
M6R=5<G5G=6%Y)UU;)RTS,RXS-3`Z+34V+C4P,"==(#T@)T1U<F%Z;F\G.PHD
M8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,T+C0U,#HM-3<N.#,S)UT@/2`G
M0V]L;VYI82<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S0N-S@S.BTU
M-BXR-3`G72`]("=-96QI;&QA)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;
M)RTS-"XX,S,Z+34V+C`P,"==(#T@)T-A<G)A<V-O)SL*)&-O;W)D:6YA=&5S
M6R=5>F)E:VES=&%N)UU;)S,W+C(S,SHV-RXR-C<G72`]("=497)M97HG.PHD
M8V]O<F1I;F%T97-;)U5Z8F5K:7-T86XG75LG,SDN-38W.C8V+CDU,"==(#T@
M)U-A;6%R:V%N9"<["B1C;V]R9&EN871E<ULG57IB96MI<W1A;B==6R<T,"XQ
M,3<Z-C<N.#,S)UT@/2`G1'II>F%K)SL*)&-O;W)D:6YA=&5S6R=5>F)E:VES
M=&%N)UU;)S0Q+C(V-SHV.2XR-C<G72`]("=487-H:V5N="<["B1C;V]R9&EN
M871E<ULG57IB96MI<W1A;B==6R<T,2XW,S,Z-C0N-C$W)UT@/2`G5&%M9'DG
M.PHD8V]O<F1I;F%T97-;)U9A;G5A='4G75LG+3$S+C@U,#HQ-C<N-34P)UT@
M/2`G4V]L82!686YU82!,879A)SL*)&-O;W)D:6YA=&5S6R=686YU871U)UU;
M)RTQ-2XU,3<Z,38W+C(Q-R==(#T@)U!E:V]A($%I<G!O<G0@4V%N=&\G.PHD
M8V]O<F1I;F%T97-;)U9A;G5A='4G75LG+3$V+C0Q-SHQ-C<N.#`P)UT@/2`G
M3&%M87`@36%L96MU;&$G.PHD8V]O<F1I;F%T97-;)U9A;G5A='4G75LG+3$W
M+C<P,#HQ-C@N,S`P)UT@/2`G0F%U97)F:65L9"!%9F%T92<["B1C;V]R9&EN
M871E<ULG5F5N97IU96QA)UU;)S$P+C`V-SHM-CDN,S$W)UT@/2`G0F%R<75I
M<VEM971O)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N,3$W.BTV
M-"XV.#,G72`]("="87)C96QO;F$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L
M82==6R<Q,"XQ-C<Z+38W+CDS,R==(#T@)U9A;&5N8VEA)SL*)&-O;W)D:6YA
M=&5S6R=696YE>G5E;&$G75LG,3`N,C4P.BTV-RXV-3`G72`]("=-87)A8V%Y
M+4(N($$N(%-U8W)E)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N
M-#4P.BTV-"XQ.#,G72`]("=#=6UA;F$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z
M=65L82==6R<Q,"XU,#`Z+38V+C@X,R==(#T@)T-A<F%C87,@+R!,82!#87)L
M;W1A)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N-3`P.BTV."XP
M,#`G72`]("=0=&\N($-A8F5L;&\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L
M82==6R<Q,"XU-C<Z+3<Q+C<S,R==(#T@)TUA<F%C86EB;RU,82!#:&EN:71A
M)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N-3@S.BTV,BXS,3<G
M72`]("='=6ER:6$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,"XV
M,#`Z+38V+CDX,R==(#T@)T-A<F%C87,@+R!-86EQ=65T:6$@065R;W`N($EN
M=&PN(%-I;6]N($)O;&EV87(G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==
M6R<Q,2XT,3<Z+38Y+C8X,R==(#T@)T-O<F\G.PHD8V]O<F1I;F%T97-;)U9E
M;F5Z=65L82==6R<Q,2XX,#`Z+38V+C$X,R==(#T@)TQA($]R8VAI;&$G.PHD
M8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<T+C8P,#HM-C$N,3$W)UT@/2`G
M4V%N=&$@16QE;F$@1&4@56%I<F5N)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E
M;&$G75LG-2XV,#`Z+38W+C4P,"==(#T@)U!U97)T;R!!>6%C=6-H;R<["B1C
M;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S<N,C,S.BTW,"XX,#`G72`]("='
M=6%S9'5A;&ET;R<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S<N,S`P
M.BTV,2XT-3`G72`]("=4=6UE<F5M;R<["B1C;V]R9&EN871E<ULG5F5N97IU
M96QA)UU;)S<N-3@S.BTW,BXP-C<G72`]("=3=&\N($1O;6EN9V\G.PHD8V]O
M<F1I;F%T97-;)U9E;F5Z=65L82==6R<W+C@U,#HM-S(N-#4P)UT@/2`G4V%N
M($%N=&]N:6\@1&5L(%1A8VAI<F$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L
M82==6R<W+CDP,#HM-C<N-#$W)UT@/2`G4V%N($9E<FYA;F1O($1E($%P=7)E
M)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG."XQ-3`Z+38S+C4U,"==
M(#T@)T-I=61A9"!";VQI=F%R)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G
M75LG."XV,#`Z+3<Q+C$X,R==(#T@)TUE<FED82<["B1C;V]R9&EN871E<ULG
M5F5N97IU96QA)UU;)S@N-C$W.BTW,"XR,3<G72`]("="87)I;F%S)SL*)&-O
M;W)D:6YA=&5S6R=696YE>G5E;&$G75LG."XY,S,Z+38W+C0Q-R==(#T@)T-A
M;&%B;WIO)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG.2XP,3<Z+38R
M+C8Q-R==(#T@)U1E;6)L861O<B<["B1C;V]R9&EN871E<ULG5F5N97IU96QA
M)UU;)SDN,#$W.BTV.2XW,S,G72`]("='=6%N87)E)SL*)&-O;W)D:6YA=&5S
M6R=696YE>G5E;&$G75LG.2XR,3<Z+38V+C`Q-R==(#T@)U9A;&QE($1E($QA
M(%!A<V-U82<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)SDN,S4P.BTW
M,"XV,3<G72`]("=686QE<F$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==
M6R<Y+C4U,#HM-CDN,C,S)UT@/2`G06-A<FEG=6$G.PHD8V]O<F1I;F%T97-;
M)U9E;F5Z=65L82==6R<Y+C<U,#HM-C,N,3@S)UT@/2`G36%T=7)I;B<["B1C
M;V]R9&EN871E<ULG5F5N97IU96QA)UU;)SDN.#$W.BTW,"XY,S,G72`]("=-
M96YE($=R86YD92<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)SDN.3$W
M.BTV-RXS,S,G72`]("=386X@2G5A;B!$92!,;W,@36]R<F]S)SL*)&-O;W)D
M:6YA=&5S6R=6:65T($YA;2==6R<Q,"XX,3<Z,3`V+C8V-R==(#T@)TAO($-H
M:2!-:6YH)SL*)&-O;W)D:6YA=&5S6R=6:65T($YA;2==6R<Q,BXR-3`Z,3`Y
M+C(P,"==(#T@)TYH82!4<F%N9R<["B1C;V]R9&EN871E<ULG5FEE="!.86TG
M75LG,3,N-S8W.C$P.2XR,3<G72`]("=1=7D@3FAO;B<["B1C;V]R9&EN871E
M<ULG5FEE="!.86TG75LG,3,N.3@S.C$P."XP,#`G72`]("=0;&5I:W4@0VET
M>2<["B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,38N,#,S.C$P."XQ.#,G
M72`]("=$82!.86YG)SL*)&-O;W)D:6YA=&5S6R=6:65T($YA;2==6R<Q-BXT
M,#`Z,3`W+C8X,R==(#T@)TAU92<["B1C;V]R9&EN871E<ULG5FEE="!.86TG
M75LG,3@N-S`P.C$P-2XV-C<G72`]("=6:6YH)SL*)&-O;W)D:6YA=&5S6R=6
M:65T($YA;2==6R<R,2XP,3<Z,3`U+C@P,"==(#T@)TAA($YO:2<["B1C;V]R
M9&EN871E<ULG5FER9VEN($ES;&%N9',L($)R:71I<V@G75LG,3@N-#4P.BTV
M-"XU,S,G72`]("="965F($ES;&%N9"P@5&]R=&]L82<["B1C;V]R9&EN871E
M<ULG5FER9VEN($ES;&%N9',L(%5N:71E9"!3=&%T97,G75LG,3<N-S`P.BTV
M-"XX,#`G72`]("=#:')I<W1I86YS=&5D+"!(96YR>2!%+B!2;VAL<V5N($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)U9I<F=I;B!)<VQA;F1S+"!5;FET960@
M4W1A=&5S)UU;)S$X+C,S,SHM-C0N.3@S)UT@/2`G0VAA<FQO='1E($%M86QI
M92!3="X@5&AO;6%S+"!#>7)I;"!%+B!+:6YG($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)U=E<W1E<FX@4V%H87)A)UU;)S(S+C<P,#HM,34N.#8W)UT@/2`G
M5FEL;&$@0VES;F5R;W,G.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;)S$R+C8S
M,SHU,RXY,#`G72`]("=3;V-O=')A)SL*)&-O;W)D:6YA=&5S6R=996UE;B==
M6R<Q,BXV-C<Z-#4N,#,S)UT@/2`G061E;B<["B1C;V]R9&EN871E<ULG665M
M96XG75LG,3,N,C4P.C0S+C(X,R==(#T@)TUO:VAA)SL*)&-O;W)D:6YA=&5S
M6R=996UE;B==6R<Q,RXR-3`Z-#0N,3,S)UT@/2`G36]K:&$G.PHD8V]O<F1I
M;F%T97-;)UEE;65N)UU;)S$S+C8X,SHT-"XQ,S,G72`]("=486EZ)SL*)&-O
M;W)D:6YA=&5S6R=996UE;B==6R<Q-"XU,3<Z-#8N.#4P)UT@/2`G071A<2<[
M"B1C;V]R9&EN871E<ULG665M96XG75LG,30N-C4P.C0Y+C,X,R==(#T@)U)I
M>6%N)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q-"XW-3`Z-#(N.3@S)UT@
M/2`G2&]D96ED86@G.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;)S$U+C0S,SHT
M-2XS,S,G72`]("=-87)I8B<["B1C;V]R9&EN871E<ULG665M96XG75LG,34N
M-3$W.C0T+C$X,R==(#T@)U-A;F%<)T$G.PHD8V]O<F1I;F%T97-;)UEE;65N
M)UU;)S$V+C(P,#HT-"XW.#,G72`]("=!;"U(87IM)SL*)&-O;W)D:6YA=&5S
M6R=9=6=O<VQA=FEA)UU;)S0R+C,V-SHQ.2XR-3`G72`]("=0;V1G;W)I8V$@
M+R!';VQU8F]V8VDG.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG-#(N
M-#`P.C$X+C<S,R==(#T@)U1I=F%T)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA
M=FEA)UU;)S0R+C8U,#HR,2XQ-3`G72`]("=0<FES=&EN82<["B1C;V]R9&EN
M871E<ULG675G;W-L879I82==6R<T,RXS,S,Z,C$N.3`P)UT@/2`G3FES)SL*
M)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0S+C,U,#HQ-RXX,#`G72`]
M("=-;W-T87(G.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG-#,N.#$W
M.C$X+C,S,R==(#T@)U-A<F%J979O("\@0G5T;6ER)SL*)&-O;W)D:6YA=&5S
M6R=9=6=O<VQA=FEA)UU;)S0T+C4U,#HQ."XW,#`G72`]("=4=7IL82<["B1C
M;V]R9&EN871E<ULG675G;W-L879I82==6R<T-"XW.#,Z,3<N,C$W)UT@/2`G
M0F%N:F$@3'5K82<["B1C;V]R9&EN871E<ULG675G;W-L879I82==6R<T-"XX
M,3<Z,34N.#@S)UT@/2`G0FEH86,G.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V
M:6$G75LG-#0N.#$W.C(P+C(X,R==(#T@)T)E;V=R860@+R!3=7)C:6XG.PHD
M8V]O<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG-#4N,34P.C(Q+C,Q-R==(#T@
M)U9R<V%C)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<P+C`U,#HQ."XR-C<G
M72`]("=-8F%N9&%K82<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG,"XQ,S,Z
M,CDN,C8W)UT@/2`G0G5T96UB;R<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG
M+3`N,C$W.C(P+C@U,"==(#T@)T)O96YD92<["B1C;V]R9&EN871E<ULG6F%I
M<F4G75LG,"XU,3<Z,C4N,3@S)UT@/2`G2VES86YG86YI)SL*)&-O;W)D:6YA
M=&5S6R=:86ER92==6R<M,2XQ.#,Z,CDN-#4P)UT@/2`G4G5T<VAU<G4G.PHD
M8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTQ+C8X,SHR.2XR,S,G72`]("=';VUA
M)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M,2XY-C<Z,3@N,C8W)UT@/2`G
M26YO;F=O)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M,3`N-S$W.C(U+C0U
M,"==(#T@)TMO;'=E>FDG.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTQ,2XV
M-C<Z,C<N-#@S)UT@/2`G3'5B=6UB87-H:2U,=6%N;R<["B1C;V]R9&EN871E
M<ULG6F%I<F4G75LG+3(N.34P.C(U+CDQ-R==(#T@)TMI;F1U)SL*)&-O;W)D
M:6YA=&5S6R=:86ER92==6R<S+C(X,SHQ.2XW.#,G72`]("='96UE;F$G.PHD
M8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTS+C,P,#HQ-RXS-3`G72`]("="86YD
M=6YD=2<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3,N-#@S.C(S+C0V-R==
M(#T@)TQO9&IA)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-"XS,S,Z,C`N
M-3@S)UT@/2`G26QE8F\G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTT+C,X
M,SHQ-2XT,S,G72`]("=+:6YS:&%S82`O($Y<)T1J:6QI)SL*)&-O;W)D:6YA
M=&5S6R=:86ER92==6R<M-"XY,3<Z,3<N,#8W)UT@/2`G2V5N9V4G.PHD8V]O
M<F1I;F%T97-;)UIA:7)E)UU;)RTT+CDV-SHR,RXT,S,G72`]("=,=7-A;6)O
M)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-2XP,S,Z,3@N.#`P)UT@/2`G
M2VEK=VET)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-2XS-3`Z,C<N,#`P
M)UT@/2`G2V]N9V]L;R<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+34N-3$W
M.C$S+C4X,R==(#T@)TEN9V$G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTU
M+C@P,#HQ,RXT,S,G72`]("=-871A9&DG.PHD8V]O<F1I;F%T97-;)UIA:7)E
M)UU;)RTU+C@X,SHR,BXT,3<G72`]("=+86YA;F=A)SL*)&-O;W)D:6YA=&5S
M6R=:86ER92==6R<M-2XX.#,Z,CDN,3@S)UT@/2`G2V%L96UI92<["B1C;V]R
M9&EN871E<ULG6F%I<F4G75LG+38N,#`P.C$R+C0Q-R==(#T@)TUO86YD82<[
M"B1C;V]R9&EN871E<ULG6F%I<F4G75LG+38N,38W.C(S+C8Q-R==(#T@)TUB
M=6II+4UA>6DG.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTV+C0Q-SHR,"XX
M-3`G72`]("=4<VAI:V%P82<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3<N
M,C@S.C(W+C0S,R==(#T@)TUA;F]N;R<["B1C;V]R9&EN871E<ULG6F%I<F4G
M75LG+3@N-C,S.C(U+C(U,"==(#T@)TMA;6EN82`O($)A<V4G.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,3`N,3$W.C,R+C8S,R==(#T@)TES;VMA)SL*
M)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$P+C(Q-SHS,2XQ,S,G72`]("=+
M87-A;6$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3$N,3`P.C(X+C@U
M,"==(#T@)TUA;G-A)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$Q+C<U
M,#HR-"XT,S,G72`]("=-=VEN:6QU;F=A)SL*)&-O;W)D:6YA=&5S6R=:86UB
M:6$G75LG+3$Q+CDP,#HS,2XT,S,G72`]("=-<&EK82<["B1C;V]R9&EN871E
M<ULG6F%M8FEA)UU;)RTQ,BXQ.#,Z,C8N,S@S)UT@/2`G4V]L=V5Z:2<["B1C
M;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ,BXR.#,Z,S,N,C`P)UT@/2`G3'5N
M9&%Z:2<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ,RXP,#`Z,C@N-C4P
M)UT@/2`G3F1O;&$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3,N,C,S
M.C,P+C(Q-R==(#T@)U-E<F5N:F4G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==
M6R<M,3,N-3,S.C(S+C$Q-R==(#T@)UIA;6)E>FDG.PHD8V]O<F1I;F%T97-;
M)UIA;6)I82==6R<M,3,N-3,S.C(U+C@U,"==(#T@)TMA<V5M<&$G.PHD8V]O
M<F1I;F%T97-;)UIA;6)I82==6R<M,3,N-34P.C,R+C4X,R==(#T@)T-H:7!A
M=&$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3,N-C`P.C(T+C(P,"==
M(#T@)TMA8F]M<&\G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,30N,C4P
M.C,Q+C(X,R==(#T@)U!E=&%U:V4G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==
M6R<M,30N-#4P.C(X+C0V-R==(#T@)TMA8G=E)SL*)&-O;W)D:6YA=&5S6R=:
M86UB:6$G75LG+3$T+C0U,#HR."XT-C<G72`]("=,=7-A:V$@0VET>2!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$T+C@P,#HR-"XX,#`G
M72`]("=+86]M82<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ-2XR-3`Z
M,C,N,34P)UT@/2`G36]N9W4G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M
M,34N,S$W.C(X+C0U,"==(#T@)TQU<V%K82!);G1E<FYA=&EO;F%L86ER<&]R
M="<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ-BXQ,#`Z,C,N,C8W)UT@
M/2`G4V5N86YG82<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ-BXX,S,Z
M,C<N,#8W)UT@/2`G0VAO;6$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M
M,3<N-#8W.C(T+C,P,"==(#T@)U-E<VAE:V4G.PHD8V]O<F1I;F%T97-;)UIA
M;6)I82==6R<M,3<N.#$W.C(U+C@Q-R==(#T@)TQI=FEN9W-T;VYE)SL*)&-O
M;W)D:6YA=&5S6R=:86UB:6$G75LG+3@N.#4P.C,Q+C,S,R==(#T@)TUB86QA
M)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3DN.#`P.C(Y+C`X,R==(#T@
M)TMA=V%M8G=A)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,38N-3$W
M.C(X+C@X,R==(#T@)TMA<FEB82<["B1C;V]R9&EN871E<ULG6FEM8F%B=V4G
M75LG+3$V+C@S,SHR.2XV,3<G72`]("=+87)O:2<["B1C;V]R9&EN871E<ULG
M6FEM8F%B=V4G75LG+3$W+C0Q-SHS,BXR,3<G72`]("=-=71O:V\G.PHD8V]O
M<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ-RXV,3<Z,C<N,S,S)UT@/2`G0FEN
M9V$G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ-RXY,3<Z,S$N,3,S
M)UT@/2`G2&%R87)E($MU='-A9V$G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E
M)UU;)RTQ."XQ,#`Z,C4N.#4P)UT@/2`G5FEC=&]R:6$@1F%L;',G.PHD8V]O
M<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ."XR,3<Z,C@N.3,S)UT@/2`G1V]K
M=V4G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ."XU,S,Z,S(N,3,S
M)UT@/2`G4G5S87!E)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,3@N
M-C,S.C(W+C`P,"==(#T@)TAW86YG92!.871I;VYA;"!087)K)SL*)&-O;W)D
M:6YA=&5S6R=::6UB86)W92==6R<M,3DN-#4P.C(Y+C@U,"==(#T@)T=W97)U
M)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,C`N,#$W.C(X+C8Q-R==
M(#T@)T)U;&%W87EO($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E
M)UU;)RTR,"XP-C<Z,S`N.#8W)UT@/2`G36%S=FEN9V\G.PHD8V]O<F1I;F%T
M97-;)UII;6)A8G=E)UU;)RTR,"XR,#`Z,S(N-C$W)UT@/2`G0VAI<&EN9V4G
M.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTR,2XP,3<Z,S$N-3@S)UT@
M/2`G0G5F9F%L;R!286YG92<["B1C;V]R9&EN871E<ULG6FEM8F%B=V4G75LG
M+3(R+C(Q-SHS,"XP,#`G72`]("="96ET8G)I9&=E)SL*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TY,4R]C87)S:6=N<RYP:'``````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-S,R,@`Q,#4Q-30S,3`V,0`P,C$Q-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!L
M:7-T(&]F(&EN=&5R;F%T:6]N86P@;&EC96YS92!P;&%T92!C;V1E<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO3DQ3+TY,4R]C87)S:6=N<RYP:'`L=B`Q
M+C$@,C`P-"\P.2\P."`Q-3HQ.#HU-R!J86X@17AP("0*("H*("H@0'!A8VMA
M9V4@2&]R9&5?3DQ3"B`J+PH*)&-A<G-I9VYS(#T@87)R87DH"B`@("`G870G
M(#T^("=!)RP*("`@("=A9B<@/3X@)T%&1R<L"B`@("`G86<G(#T^("=!1R<L
M"B`@("`G86PG(#T^("=!3"<L"B`@("`G860G(#T^("=!3D0G+`H@("`@)V%O
M)R`]/B`G04Y')RP*("`@("=A;2<@/3X@)T%232<L"B`@("`G874G(#T^("=!
M55,G+`H@("`@)V%Z)R`]/B`G05HG+`H@("`@)V)E)R`]/B`G0B<L"B`@("`G
M8F0G(#T^("="1"<L"B`@("`G8F(G(#T^("="1%,G+`H@("`@)V)F)R`]/B`G
M0D8G+`H@("`@)V)G)R`]/B`G0D<G+`H@("`@)V)Z)R`]/B`G0D@G+`H@("`@
M)V)T)R`]/B`G0DA4)RP*("`@("=B82<@/3X@)T))2"<L"B`@("`G8F\G(#T^
M("="3TPG+`H@("`@)V)R)R`]/B`G0E(G+`H@("`@)V)H)R`]/B`G0E).)RP*
M("`@("=B;B<@/3X@)T)252<L"B`@("`G8G,G(#T^("="4R<L"B`@("`G8FDG
M(#T^("="52<L"B`@("`G=F<G(#T^("="5DDG+`H@("`@)V)Y)R`]/B`G0EDG
M+`H@("`@)V)Z)R`]/B`G0EHG+`H@("`@)V-U)R`]/B`G0R<L"B`@("`G8VTG
M(#T^("=#04TG+`H@("`@)V-D)R`]/B`G0T0G+`H@("`@)V-A)R`]/B`G0T1.
M)RP*("`@("=C:"<@/3X@)T-()RP*("`@("=C:2<@/3X@)T-))RP*("`@("=L
M:R<@/3X@)T-,)RP*("`@("=C;R<@/3X@)T-/)RP*("`@("=K;2<@/3X@)T-/
M32<L"B`@("`G8W(G(#T^("=#4B<L"B`@("`G8W8G(#T^("=#5B<L"B`@("`G
M8WDG(#T^("=#62<L"B`@("`G8WHG(#T^("=#6B<L"B`@("`G9&4G(#T^("=$
M)RP*("`@("=D:B<@/3X@)T1*22<L"B`@("`G9&LG(#T^("=$2R<L"B`@("`G
M9&\G(#T^("=$3TTG+`H@("`@)VMP)R`]/B`G1%922R<L"B`@("`G8FHG(#T^
M("=$62<L"B`@("`G9'HG(#T^("=$6B<L"B`@("`G97,G(#T^("=%)RP*("`@
M("=K92<@/3X@)T5!2R<L"B`@("`G='HG(#T^("=%050G+`H@("`@)W5G)R`]
M/B`G14%5)RP*("`@("=E8R<@/3X@)T5#)RP*("`@("=E<B<@/3X@)T52)RP*
M("`@("=S=B<@/3X@)T53)RP*("`@("=E92<@/3X@)T535"<L"B`@("`G96<G
M(#T^("=%5"<L"B`@("`G970G(#T^("=%5$@G+`H@("`@)V9R)R`]/B`G1B<L
M"B`@("`G9FDG(#T^("=&24XG+`H@("`@)V9J)R`]/B`G1DI))RP*("`@("=L
M:2<@/3X@)T9,)RP*("`@("=F;R<@/3X@)T9/)RP*("`@("=F;2<@/3X@)T93
M32<L"B`@("`G9V$G(#T^("=')RP*("`@("=G8B<@/3X@)T=")RP*("`@("=G
M:2<@/3X@)T="6B<L"B`@("`G9W0G(#T^("='0T$G+`H@("`@)V=E)R`]/B`G
M1T4G+`H@("`@)V=H)R`]/B`G1T@G+`H@("`@)V=Q)R`]/B`G1U$G+`H@("`@
M)V=R)R`]/B`G1U(G+`H@("`@)V=Y)R`]/B`G1U59)RP*("`@("=H=2<@/3X@
M)T@G+`H@("`@)VAK)R`]/B`G2$LG+`H@("`@)VAN)R`]/B`G2$XG+`H@("`@
M)VAR)R`]/B`G2%(G+`H@("`@)VET)R`]/B`G22<L"B`@("`G:6PG(#T^("=)
M3"<L"B`@("`G:6XG(#T^("=)3D0G+`H@("`@)VER)R`]/B`G25(G+`H@("`@
M)VEE)R`]/B`G25),)RP*("`@("=I<2<@/3X@)TE242<L"B`@("`G:7,G(#T^
M("=)4R<L"B`@("`G:G`G(#T^("=*)RP*("`@("=J;2<@/3X@)TI!)RP*("`@
M("=J;R<@/3X@)TI/4B<L"B`@("`G:V@G(#T^("=+)RP*("`@("=K:2<@/3X@
M)TM)4B<L"B`@("`G9VPG(#T^("=+3B<L"B`@("`G:V<G(#T^("=+4R<L"B`@
M("`G<V$G(#T^("=+4T$G+`H@("`@)VMW)R`]/B`G2U=4)RP*("`@("=K>B<@
M/3X@)TM:)RP*("`@("=L=2<@/3X@)TPG+`H@("`@)VQA)R`]/B`G3$%/)RP*
M("`@("=L>2<@/3X@)TQ!4B<L"B`@("`G;'(G(#T^("=,0B<L"B`@("`G;',G
M(#T^("=,4R<L"B`@("`G;'0G(#T^("=,5"<L"B`@("`G;'8G(#T^("=,5B<L
M"B`@("`G;70G(#T^("=-)RP*("`@("=M82<@/3X@)TU!)RP*("`@("=M>2<@
M/3X@)TU!3"<L"B`@("`G;6,G(#T^("=-0R<L"B`@("`G;60G(#T^("=-1"<L
M"B`@("`G;7@G(#T^("=-15@G+`H@("`@)VUN)R`]/B`G34=,)RP*("`@("=M
M:"<@/3X@)TU()RP*("`@("=M:R<@/3X@)TU+)RP*("`@("=M>B<@/3X@)TU/
M0R<L"B`@("`G;74G(#T^("=-4R<L"B`@("`G;78G(#T^("=-5B<L"B`@("`G
M;7<G(#T^("=-5R<L"B`@("`G;6TG(#T^("=-64$G+`H@("`@)VYO)R`]/B`G
M3B<L"B`@("`G86XG(#T^("=.02<L"B`@("`G;FPG(#T^("=.3"<L"B`@("`G
M;GHG(#T^("=.6B<L"B`@("`G;VTG(#T^("=/32<L"B`@("`G<'0G(#T^("=0
M)RP*("`@("=P82<@/3X@)U!!)RP*("`@("=P=R<@/3X@)U!!3"<L"B`@("`G
M<&4G(#T^("=012<L"B`@("`G<&LG(#T^("=02R<L"B`@("`G<&PG(#T^("=0
M3"<L"B`@("`G<&<G(#T^("=03D<G+`H@("`@)V-N)R`]/B`G4%)#)RP*("`@
M("=P<R<@/3X@)U!3)RP*("`@("=P>2<@/3X@)U!9)RP*("`@("=Q82<@/3X@
M)U$G+`H@("`@)V%R)R`]/B`G4D$G+`H@("`@)V)W)R`]/B`G4D(G+`H@("`@
M)W1W)R`]/B`G4D,G+`H@("`@)V-F)R`]/B`G4D-!)RP*("`@("=C9"<@/3X@
M)U)#0B<L"B`@("`G8VPG(#T^("=20T@G+`H@("`@)W)E)R`]/B`G4D4G+`H@
M("`@)V=N)R`]/B`G4D<G+`H@("`@)VAT)R`]/B`G4D@G+`H@("`@)VED)R`]
M/B`G4DDG+`H@("`@)VUR)R`]/B`G4DE-)RP*("`@("=L8B<@/3X@)U),)RP*
M("`@("=M9R<@/3X@)U)-)RP*("`@("=M;"<@/3X@)U)-32<L"B`@("`G;F4G
M(#T^("=23B<L"B`@("`G<F\G(#T^("=23R<L"B`@("`G:W(G(#T^("=23TLG
M+`H@("`@)W5Y)R`]/B`G4D]5)RP*("`@("=P:"<@/3X@)U)0)RP*("`@("=S
M;2<@/3X@)U)332<L"B`@("`G=&<G(#T^("=25"<L"B`@("`G<G4G(#T^("=2
M55,G+`H@("`@)W)W)R`]/B`G4E=!)RP*("`@("=S92<@/3X@)U,G+`H@("`@
M)V-S)R`]/B`G4T-')RP*("`@("=K;B<@/3X@)U-#3B<L"B`@("`G<WHG(#T^
M("=31"<L"B`@("`G<V<G(#T^("=31U`G+`H@("`@)W-K)R`]/B`G4TLG+`H@
M("`@)W-I)R`]/B`G4TQ/)RP*("`@("=S<B<@/3X@)U--12<L"B`@("`G<VXG
M(#T^("=33B<L"B`@("`G<V(G(#T^("=33TPG+`H@("`@)W-O)R`]/B`G4U`G
M+`H@("`@)W-T)R`]/B`G4U10)RP*("`@("=S9"<@/3X@)U-51"<L"B`@("`G
M<V,G(#T^("=362<L"B`@("`G<WDG(#T^("=365(G+`H@("`@)W1D)R`]/B`G
M5$-()RP*("`@("=T:"<@/3X@)U1(02<L"B`@("`G=&HG(#T^("=42B<L"B`@
M("`G=&PG(#T^("=43"<L"B`@("`G=&TG(#T^("=432<L"B`@("`G=&XG(#T^
M("=43B<L"B`@("`G=&\G(#T^("=43R<L"B`@("`G='(G(#T^("=44B<L"B`@
M("`G='0G(#T^("=45"<L"B`@("`G='8G(#T^("=4558G+`H@("`@)W5A)R`]
M/B`G54$G+`H@("`@)V%E)R`]/B`G54%%)RP*("`@("=U<R<@/3X@)U5302<L
M"B`@("`G=7HG(#T^("=56B<L"B`@("`G=F$G(#T^("=6)RP*("`@("=V;B<@
M/3X@)U9.)RP*("`@("=V=2<@/3X@)U95)RP*("`@("='32<@/3X@)U=!1R<L
M"B`@("`G<VPG(#T^("=704PG+`H@("`@)VYG)R`]/B`G5T%.)RP*("`@("=D
M;2<@/3X@)U=$)RP*("`@("=G9"<@/3X@)U=')RP*("`@("=L8R<@/3X@)U=,
M)RP*("`@("=W<R<@/3X@)U=3)RP*("`@("=V8R<@/3X@)U=6)RP*("`@("=Y
M92<@/3X@)UE!4B<L"B`@("`G=F4G(#T^("=95B<L"B`@("`G>FTG(#T^("=:
M)RP*("`@("=Z82<@/3X@)UI!)RP*("`@("=Z=R<@/3X@)UI7)PHI.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]T;&0N<&AP````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C<R-0`Q,#4Q-30S,3`V,0`P,C`Q
M-3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1O<"!L979E;"!D;VUA:6X@*%1,1"D@;&ES="!F;W(@
M8V]U;G1R>2!C;V1E<RX*("H@1V5N97)A=&5D(&9R;VT@24%.02`H26YT97)N
M970@07-S:6=N960@3G5M8F5R<R!!=71H;W)I='DI(&1A=&$@;&]C871E9`H@
M*B!A="!H='1P.B\O=W=W+FEA;F$N;W)G+V-C=&QD+V-C=&QD+7=H;VES+FAT
M;0H@*@H@*B!&;W)M870Z"B`J("`@)'1L9%LG8V]U;G1R>6-O9&4G72`]("=C
M;W5N=')Y;F%M92<["B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<"QV(#$N-2`R,#`T+S`Q+S`T(#`R.C(T.C`U(&UD:G5K:6,@17AP
M("0*("H*("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PHD=&QD(#T@87)R87DH
M"B`@("`G86,G(#T^(%\H(D%S8V5N<VEO;B!)<VQA;F0B*2P*("`@("=A9"<@
M/3X@7R@B06YD;W)R82(I+`H@("`@)V%E)R`]/B!?*")5;FET960@07)A8B!%
M;6ER871E<R(I+`H@("`@)V%F)R`]/B!?*")!9F=H86YI<W1A;B(I+`H@("`@
M)V%G)R`]/B!?*")!;G1I9W5A(&%N9"!"87)B=61A(BDL"B`@("`G86DG(#T^
M(%\H(D%N9W5I;&QA(BDL"B`@("`G86PG(#T^(%\H(D%L8F%N:6$B*2P*("`@
M("=A;2<@/3X@7R@B07)M96YI82(I+`H@("`@)V%N)R`]/B!?*").971H97)L
M86YD<R!!;G1I;&QE<R(I+`H@("`@)V%O)R`]/B!?*")!;F=O;&$B*2P*("`@
M("=A<2<@/3X@7R@B06YT87)C=&EC82(I+`H@("`@)V%R)R`]/B!?*")!<F=E
M;G1I;F$B*2P*("`@("=A<R<@/3X@7R@B06UE<FEC86X@4V%M;V$B*2P*("`@
M("=A="<@/3X@7R@B075S=')I82(I+`H@("`@)V%U)R`]/B!?*")!=7-T<F%L
M:6$B*2P*("`@("=A=R<@/3X@7R@B07)U8F$B*2P*("`@("=A>B<@/3X@7R@B
M07IE<F)A:6IA;B(I+`H@("`@)V)A)R`]/B!?*")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(BDL"B`@("`G8F(G(#T^(%\H(D)A<F)A9&]S(BDL"B`@("`G8F0G
M(#T^(%\H(D)A;F=L861E<V@B*2P*("`@("=B92<@/3X@7R@B0F5L9VEU;2(I
M+`H@("`@)V)F)R`]/B!?*")"=7)K:6YA($9A<V\B*2P*("`@("=B9R<@/3X@
M7R@B0G5L9V%R:6$B*2P*("`@("=B:"<@/3X@7R@B0F%H<F%I;B(I+`H@("`@
M)V)I)R`]/B!?*")"=7)U;F1I(BDL"B`@("`G8FHG(#T^(%\H(D)E;FEN(BDL
M"B`@("`G8FTG(#T^(%\H(D)E<FUU9&$B*2P*("`@("=B;B<@/3X@7R@B0G)U
M;F5I($1A<G5S<V%L86TB*2P*("`@("=B;R<@/3X@7R@B0F]L:79I82(I+`H@
M("`@)V)R)R`]/B!?*")"<F%Z:6PB*2P*("`@("=B<R<@/3X@7R@B0F%H86UA
M<R(I+`H@("`@)V)T)R`]/B!?*")":'5T86XB*2P*("`@("=B=B<@/3X@7R@B
M0F]U=F5T($ES;&%N9"(I+`H@("`@)V)W)R`]/B!?*")";W1S=V%N82(I+`H@
M("`@)V)Y)R`]/B!?*")"96QA<G5S(BDL"B`@("`G8GHG(#T^(%\H(D)E;&EZ
M92(I+`H@("`@)V-A)R`]/B!?*")#86YA9&$B*2P*("`@("=C8R<@/3X@7R@B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B*2P*("`@("=C9"<@/3X@7R@B0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(I+`H@("`@)V-F
M)R`]/B!?*")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B*2P*("`@("=C9R<@
M/3X@7R@B0V]N9V\B*2P*("`@("=C:"<@/3X@7R@B4W=I='IE<FQA;F0B*2P*
M("`@("=C:2<@/3X@7R@B0V]T92!D)TEV;VER92(I+`H@("`@)V-K)R`]/B!?
M*")#;V]K($ES;&%N9',B*2P*("`@("=C;"<@/3X@7R@B0VAI;&4B*2P*("`@
M("=C;2<@/3X@7R@B0V%M97)O;VXB*2P*("`@("=C;B<@/3X@7R@B0VAI;F$B
M*2P*("`@("=C;R<@/3X@7R@B0V]L;VUB:6$B*2P*("`@("=C<B<@/3X@7R@B
M0V]S=&$@4FEC82(I+`H@("`@)V-U)R`]/B!?*")#=6)A(BDL"B`@("`G8W8G
M(#T^(%\H(D-A<&4@5F5R9&4B*2P*("`@("=C>"<@/3X@7R@B0VAR:7-T;6%S
M($ES;&%N9"(I+`H@("`@)V-Y)R`]/B!?*")#>7!R=7,B*2P*("`@("=C>B<@
M/3X@7R@B0WIE8V@@4F5P=6)L:6,B*2P*("`@("=D92<@/3X@7R@B1V5R;6%N
M>2(I+`H@("`@)V1J)R`]/B!?*")$:FEB;W5T:2(I+`H@("`@)V1K)R`]/B!?
M*")$96YM87)K(BDL"B`@("`G9&TG(#T^(%\H(D1O;6EN:6-A(BDL"B`@("`G
M9&\G(#T^(%\H(D1O;6EN:6-A;B!297!U8FQI8R(I+`H@("`@)V1Z)R`]/B!?
M*")!;&=E<FEA(BDL"B`@("`G96,G(#T^(%\H(D5C=6%D;W(B*2P*("`@("=E
M92<@/3X@7R@B17-T;VYI82(I+`H@("`@)V5G)R`]/B!?*")%9WEP="(I+`H@
M("`@)V5H)R`]/B!?*")797-T97)N(%-A:&%R82(I+`H@("`@)V5R)R`]/B!?
M*")%<FET<F5A(BDL"B`@("`G97,G(#T^(%\H(E-P86EN(BDL"B`@("`G970G
M(#T^(%\H(D5T:&EO<&EA(BDL"B`@("`G9FDG(#T^(%\H(D9I;FQA;F0B*2P*
M("`@("=F:B<@/3X@7R@B1FEJ:2(I+`H@("`@)V9K)R`]/B!?*")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB*2P*("`@("=F;2<@/3X@7R@B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(I+`H@("`@)V9O)R`]/B!?*")&
M87)O92!)<VQA;F1S(BDL"B`@("`G9G(G(#T^(%\H(D9R86YC92(I+`H@("`@
M)V=A)R`]/B!?*")'86)O;B(I+`H@("`@)V=D)R`]/B!?*")'<F5N861A(BDL
M"B`@("`G9V4G(#T^(%\H(D=E;W)G:6$B*2P*("`@("=G9B<@/3X@7R@B1G)E
M;F-H($=U:6%N82(I+`H@("`@)V=G)R`]/B!?*")'=65R;G-E>2(I+`H@("`@
M)V=H)R`]/B!?*")':&%N82(I+`H@("`@)V=I)R`]/B!?*")':6)R86QT87(B
M*2P*("`@("=G;"<@/3X@7R@B1W)E96YL86YD(BDL"B`@("`G9VTG(#T^(%\H
M(D=A;6)I82(I+`H@("`@)V=N)R`]/B!?*")'=6EN96$B*2P*("`@("=G<"<@
M/3X@7R@B1W5A9&5L;W5P92(I+`H@("`@)V=Q)R`]/B!?*")%<75A=&]R:6%L
M($=U:6YE82(I+`H@("`@)V=R)R`]/B!?*")'<F5E8V4B*2P*("`@("=G<R<@
M/3X@7R@B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',B*2P*("`@("=G="<@/3X@7R@B1W5A=&5M86QA(BDL"B`@("`G9W4G
M(#T^(%\H(D=U86TB*2P*("`@("=G=R<@/3X@7R@B1W5I;F5A+4)I<W-A=2(I
M+`H@("`@)V=Y)R`]/B!?*")'=7EA;F$B*2P*("`@("=H:R<@/3X@7R@B2&]N
M9R!+;VYG(BDL"B`@("`G:&TG(#T^(%\H(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(I+`H@("`@)VAN)R`]/B!?*")(;VYD=7)A<R(I+`H@
M("`@)VAR)R`]/B!?*")#<F]A=&EA(BDL"B`@("`G:'0G(#T^(%\H(DAA:71I
M(BDL"B`@("`G:'4G(#T^(%\H(DAU;F=A<GDB*2P*("`@("=I9"<@/3X@7R@B
M26YD;VYE<VEA(BDL"B`@("`G:64G(#T^(%\H(DER96QA;F0B*2P*("`@("=I
M;"<@/3X@7R@B27-R865L(BDL"B`@("`G:6TG(#T^(%\H(DES;&4@;V8@36%N
M(BDL"B`@("`G:6XG(#T^(%\H(DEN9&EA(BDL"B`@("`G:6\G(#T^(%\H(D)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(I+`H@("`@)VEQ)R`]/B!?
M*"))<F%Q(BDL"B`@("`G:7(G(#T^(%\H(DER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8B*2P*("`@("=I<R<@/3X@7R@B26-E;&%N9"(I+`H@("`@)VET)R`]
M/B!?*"))=&%L>2(I+`H@("`@)VIE)R`]/B!?*")*97)S97DB*2P*("`@("=J
M;2<@/3X@7R@B2F%M86EC82(I+`H@("`@)VIO)R`]/B!?*")*;W)D86XB*2P*
M("`@("=J<"<@/3X@7R@B2F%P86XB*2P*("`@("=K92<@/3X@7R@B2V5N>6$B
M*2P*("`@("=K9R<@/3X@7R@B2WER9WEZ<W1A;B(I+`H@("`@)VMH)R`]/B!?
M*")#86UB;V1I82(I+`H@("`@)VMI)R`]/B!?*")+:7)I8F%T:2(I+`H@("`@
M)VMM)R`]/B!?*")#;VUO<F]S(BDL"B`@("`G:VXG(#T^(%\H(E-A:6YT($MI
M='1S(&%N9"!.979I<R(I+`H@("`@)VMP)R`]/B!?*")+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9B(I+`H@("`@)VMR)R`]/B!?*")+
M;W)E82P@4F5P=6)L:6,@;V8B*2P*("`@("=K=R<@/3X@7R@B2W5W86ET(BDL
M"B`@("`G:WDG(#T^(%\H(D-A>6UA;B!)<VQA;F1S(BDL"B`@("`G:WHG(#T^
M(%\H(DMA>F%K:'-T86XB*2P*("`@("=L82<@/3X@7R@B3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,B*2P*("`@("=L8B<@/3X@7R@B3&5B86YO
M;B(I+`H@("`@)VQC)R`]/B!?*")386EN="!,=6-I82(I+`H@("`@)VQI)R`]
M/B!?*"),:65C:'1E;G-T96EN(BDL"B`@("`G;&LG(#T^(%\H(E-R:2!,86YK
M82(I+`H@("`@)VQR)R`]/B!?*"),:6)E<FEA(BDL"B`@("`G;',G(#T^(%\H
M(DQE<V]T:&\B*2P*("`@("=L="<@/3X@7R@B3&ET:'5A;FEA(BDL"B`@("`G
M;'4G(#T^(%\H(DQU>&5M8F]U<F<B*2P*("`@("=L=B<@/3X@7R@B3&%T=FEA
M(BDL"B`@("`G;'DG(#T^(%\H(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B*2P*
M("`@("=M82<@/3X@7R@B36]R;V-C;R(I+`H@("`@)VUC)R`]/B!?*")-;VYA
M8V\B*2P*("`@("=M9"<@/3X@7R@B36]L9&]V82P@4F5P=6)L:6,@;V8B*2P*
M("`@("=M9R<@/3X@7R@B36%D86=A<V-A<B(I+`H@("`@)VUH)R`]/B!?*")-
M87)S:&%L;"!)<VQA;F1S(BDL"B`@("`G;6LG(#T^(%\H(DUA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(I+`H@("`@)VUL)R`]
M/B!?*")-86QI(BDL"B`@("`G;6TG(#T^(%\H(DUY86YM87(B*2P*("`@("=M
M;B<@/3X@7R@B36]N9V]L:6$B*2P*("`@("=M;R<@/3X@7R@B36%C86\B*2P*
M("`@("=M<"<@/3X@7R@B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(BDL"B`@
M("`G;7$G(#T^(%\H(DUA<G1I;FEQ=64B*2P*("`@("=M<B<@/3X@7R@B36%U
M<FET86YI82(I+`H@("`@)VUS)R`]/B!?*")-;VYT<V5R<F%T(BDL"B`@("`G
M;70G(#T^(%\H(DUA;'1A(BDL"B`@("`G;74G(#T^(%\H(DUA=7)I=&EU<R(I
M+`H@("`@)VUV)R`]/B!?*")-86QD:79E<R(I+`H@("`@)VUW)R`]/B!?*")-
M86QA=VDB*2P*("`@("=M>"<@/3X@7R@B365X:6-O(BDL"B`@("`G;7DG(#T^
M(%\H(DUA;&%Y<VEA(BDL"B`@("`G;7HG(#T^(%\H(DUO>F%M8FEQ=64B*2P*
M("`@("=N82<@/3X@7R@B3F%M:6)I82(I+`H@("`@)VYC)R`]/B!?*").97<@
M0V%L961O;FEA(BDL"B`@("`G;F4G(#T^(%\H(DYI9V5R(BDL"B`@("`G;F8G
M(#T^(%\H(DYO<F9O;&L@27-L86YD(BDL"B`@("`G;F<G(#T^(%\H(DYI9V5R
M:6$B*2P*("`@("=N:2<@/3X@7R@B3FEC87)A9W5A(BDL"B`@("`G;FPG(#T^
M(%\H(DYE=&AE<FQA;F1S(BDL"B`@("`G;F\G(#T^(%\H(DYO<G=A>2(I+`H@
M("`@)VYP)R`]/B!?*").97!A;"(I+`H@("`@)VYR)R`]/B!?*").875R=2(I
M+`H@("`@)VYU)R`]/B!?*").:75E(BDL"B`@("`G;GHG(#T^(%\H(DYE=R!:
M96%L86YD(BDL"B`@("`G;VTG(#T^(%\H(D]M86XB*2P*("`@("=P82<@/3X@
M7R@B4&%N86UA(BDL"B`@("`G<&4G(#T^(%\H(E!E<G4B*2P*("`@("=P9B<@
M/3X@7R@B1G)E;F-H(%!O;'EN97-I82(I+`H@("`@)W!G)R`]/B!?*")087!U
M82!.97<@1W5I;F5A(BDL"B`@("`G<&@G(#T^(%\H(E!H:6QI<'!I;F5S(BDL
M"B`@("`G<&LG(#T^(%\H(E!A:VES=&%N(BDL"B`@("`G<&PG(#T^(%\H(E!O
M;&%N9"(I+`H@("`@)W!M)R`]/B!?*")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(BDL"B`@("`G<&XG(#T^(%\H(E!I=&-A:7)N(BDL"B`@("`G<'(G(#T^
M(%\H(E!U97)T;R!2:6-O(BDL"B`@("`G<',G(#T^(%\H(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B*2P*("`@("=P="<@/3X@7R@B4&]R='5G
M86PB*2P*("`@("=P=R<@/3X@7R@B4&%L874B*2P*("`@("=P>2<@/3X@7R@B
M4&%R86=U87DB*2P*("`@("=Q82<@/3X@7R@B46%T87(B*2P*("`@("=R92<@
M/3X@7R@B4F5U;FEO;B(I+`H@("`@)W)O)R`]/B!?*")2;VUA;FEA(BDL"B`@
M("`G<G4G(#T^(%\H(E)U<W-I86X@1F5D97)A=&EO;B(I+`H@("`@)W)W)R`]
M/B!?*")2=V%N9&$B*2P*("`@("=S82<@/3X@7R@B4V%U9&D@07)A8FEA(BDL
M"B`@("`G<V(G(#T^(%\H(E-O;&]M;VX@27-L86YD<R(I+`H@("`@)W-C)R`]
M/B!?*")397EC:&5L;&5S(BDL"B`@("`G<V0G(#T^(%\H(E-U9&%N(BDL"B`@
M("`G<V4G(#T^(%\H(E-W961E;B(I+`H@("`@)W-G)R`]/B!?*")3:6YG87!O
M<F4B*2P*("`@("=S:"<@/3X@7R@B4V%I;G0@2&5L96YA(BDL"B`@("`G<VDG
M(#T^(%\H(E-L;W9E;FEA(BDL"B`@("`G<VHG(#T^(%\H(E-V86QB87)D(&%N
M9"!*86X@36%Y96XB*2P*("`@("=S:R<@/3X@7R@B4VQO=F%K:6$B*2P*("`@
M("=S;"<@/3X@7R@B4VEE<G)A($QE;VYE(BDL"B`@("`G<VTG(#T^(%\H(E-A
M;B!-87)I;F\B*2P*("`@("=S;B<@/3X@7R@B4V5N96=A;"(I+`H@("`@)W-O
M)R`]/B!?*")3;VUA;&EA(BDL"B`@("`G<W(G(#T^(%\H(E-U<FEN86UE(BDL
M"B`@("`G<W0G(#T^(%\H(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(I+`H@("`@
M)W-V)R`]/B!?*")%;"!386QV861O<B(I+`H@("`@)W-Y)R`]/B!?*")3>7)I
M86X@07)A8B!297!U8FQI8R(I+`H@("`@)W-Z)R`]/B!?*")3=V%Z:6QA;F0B
M*2P*("`@("=T8R<@/3X@7R@B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(BDL
M"B`@("`G=&0G(#T^(%\H(D-H860B*2P*("`@("=T9B<@/3X@7R@B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(BDL"B`@("`G=&<G(#T^(%\H(E1O9V\B
M*2P*("`@("=T:"<@/3X@7R@B5&AA:6QA;F0B*2P*("`@("=T:B<@/3X@7R@B
M5&%J:6MI<W1A;B(I+`H@("`@)W1K)R`]/B!?*")4;VME;&%U(BDL"B`@("`G
M=&TG(#T^(%\H(E1U<FMM96YI<W1A;B(I+`H@("`@)W1N)R`]/B!?*")4=6YI
M<VEA(BDL"B`@("`G=&\G(#T^(%\H(E1O;F=A(BDL"B`@("`G='`G(#T^(%\H
M(E1I;6]R+4QE<W1E(BDL"B`@("`G='(G(#T^(%\H(E1U<FME>2(I+`H@("`@
M)W1T)R`]/B!?*")4<FEN:61A9"!A;F0@5&]B86=O(BDL"B`@("`G='8G(#T^
M(%\H(E1U=F%L=2(I+`H@("`@)W1W)R`]/B!?*")486EW86XB*2P*("`@("=T
M>B<@/3X@7R@B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(I+`H@("`@
M)W5A)R`]/B!?*")5:W)A:6YE(BDL"B`@("`G=6<G(#T^(%\H(E5G86YD82(I
M+`H@("`@)W5K)R`]/B!?*")5;FET960@2VEN9V1O;2(I+`H@("`@)W5M)R`]
M/B!?*")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B*2P*
M("`@("=U<R<@/3X@7R@B56YI=&5D(%-T871E<R(I+`H@("`@)W5Y)R`]/B!?
M*")5<G5G=6%Y(BDL"B`@("`G=7HG(#T^(%\H(E5Z8F5K:7-T86XB*2P*("`@
M("=V82<@/3X@7R@B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB*2P*
M("`@("=V8R<@/3X@7R@B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,B*2P*("`@("=V92<@/3X@7R@B5F5N97IU96QA(BDL"B`@("`G=F<G(#T^
M(%\H(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(BDL"B`@("`G=FDG(#T^(%\H
M(E9I<F=I;B!)<VQA;F1S+"!5+E,N(BDL"B`@("`G=FXG(#T^(%\H(E9I970@
M3F%M(BDL"B`@("`G=G4G(#T^(%\H(E9A;G5A='4B*2P*("`@("=W9B<@/3X@
M7R@B5V%L;&ES(&%N9"!&=71U;F$B*2P*("`@("=W<R<@/3X@7R@B4V%M;V$B
M*2P*("`@("=Y92<@/3X@7R@B665M96XB*2P*("`@("=Y="<@/3X@7R@B36%Y
M;W1T92(I+`H@("`@)WEU)R`]/B!?*")9=6=O<VQA=FEA(BDL"B`@("`G>F$G
M(#T^(%\H(E-O=71H($%F<FEC82(I+`H@("`@)WIM)R`]/B!?*"):86UB:6$B
M*2P*("`@("=Z=R<@/3X@7R@B6FEM8F%B=V4B*0HI.PH`````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'``````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V,S`U`#$P-3$U-#,Q,#8Q`#`R
M,30P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($E33RTS,38V(&-O=6YT<GD@;&ES="X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP+'8@
M,2XS+C$R+C$@,C`P-2\Q,"\Q."`Q,3HP,3HQ."!J86X@17AP("0*("H*("H@
M0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PH*)&-O=6YT<FEE<R`](&%R<F%Y*`H@
M("`@)T%&)R`]/B!?*")!9F=H86YI<W1A;B(I+`H@("`@)T%,)R`]/B!?*")!
M;&)A;FEA(BDL"B`@("`G1%HG(#T^(%\H(D%L9V5R:6$B*2P*("`@("=!4R<@
M/3X@7R@B06UE<FEC86X@4V%M;V$B*2P*("`@("=!1"<@/3X@7R@B06YD;W)R
M82(I+`H@("`@)T%/)R`]/B!?*")!;F=O;&$B*2P*("`@("=!22<@/3X@7R@B
M06YG=6EL;&$B*2P*("`@("=!42<@/3X@7R@B06YT87)C=&EC82(I+`H@("`@
M)T%')R`]/B!?*")!;G1I9W5A(&%N9"!"87)B=61A(BDL"B`@("`G05(G(#T^
M(%\H(D%R9V5N=&EN82(I+`H@("`@)T%-)R`]/B!?*")!<FUE;FEA(BDL"B`@
M("`G05<G(#T^(%\H(D%R=6)A(BDL"B`@("`G054G(#T^(%\H(D%U<W1R86QI
M82(I+`H@("`@)T%4)R`]/B!?*")!=7-T<FEA(BDL"B`@("`G05HG(#T^(%\H
M(D%Z97)B86EJ86XB*2P*("`@("="4R<@/3X@7R@B0F%H86UA<R(I+`H@("`@
M)T)()R`]/B!?*")"86AR86EN(BDL"B`@("`G0D0G(#T^(%\H(D)A;F=L861E
M<V@B*2P*("`@("="0B<@/3X@7R@B0F%R8F%D;W,B*2P*("`@("="62<@/3X@
M7R@B0F5L87)U<R(I+`H@("`@)T)%)R`]/B!?*")"96QG:75M(BDL"B`@("`G
M0EHG(#T^(%\H(D)E;&EZ92(I+`H@("`@)T)*)R`]/B!?*")"96YI;B(I+`H@
M("`@)T)-)R`]/B!?*")"97)M=61A(BDL"B`@("`G0E0G(#T^(%\H(D)H=71A
M;B(I+`H@("`@)T)/)R`]/B!?*")";VQI=FEA(BDL"B`@("`G0D$G(#T^(%\H
M(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B*2P*("`@("="5R<@/3X@7R@B0F]T
M<W=A;F$B*2P*("`@("="5B<@/3X@7R@B0F]U=F5T($ES;&%N9"(I+`H@("`@
M)T)2)R`]/B!?*")"<F%Z:6PB*2P*("`@("=)3R<@/3X@7R@B0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y(BDL"B`@("`G0DXG(#T^(%\H(D)R=6YE
M:2!$87)U<W-A;&%M(BDL"B`@("`G0D<G(#T^(%\H(D)U;&=A<FEA(BDL"B`@
M("`G0D8G(#T^(%\H(D)U<FMI;F$@1F%S;R(I+`H@("`@)T)))R`]/B!?*")"
M=7)U;F1I(BDL"B`@("`G2T@G(#T^(%\H(D-A;6)O9&EA(BDL"B`@("`G0TTG
M(#T^(%\H(D-A;65R;V]N(BDL"B`@("`G0T$G(#T^(%\H(D-A;F%D82(I+`H@
M("`@)T-6)R`]/B!?*")#87!E(%9E<F1E(BDL"B`@("`G2UDG(#T^(%\H(D-A
M>6UA;B!)<VQA;F1S(BDL"B`@("`G0T8G(#T^(%\H(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(I+`H@("`@)U1$)R`]/B!?*")#:&%D(BDL"B`@("`G0TPG
M(#T^(%\H(D-H:6QE(BDL"B`@("`G0TXG(#T^(%\H(D-H:6YA(BDL"B`@("`G
M0U@G(#T^(%\H(D-H<FES=&UA<R!)<VQA;F0B*2P*("`@("=#0R<@/3X@7R@B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B*2P*("`@("=#3R<@/3X@7R@B0V]L
M;VUB:6$B*2P*("`@("=+32<@/3X@7R@B0V]M;W)O<R(I+`H@("`@)T-')R`]
M/B!?*")#;VYG;R(I+`H@("`@)T-$)R`]/B!?*")#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE(BDL"B`@("`G0TLG(#T^(%\H(D-O;VL@
M27-L86YD<R(I+`H@("`@)T-2)R`]/B!?*")#;W-T82!2:6-A(BDL"B`@("`G
M0TDG(#T^(%\H(D-O=&4@9"=)=F]I<F4B*2P*("`@("=(4B<@/3X@7R@B0W)O
M871I82(I+`H@("`@)T-5)R`]/B!?*")#=6)A(BDL"B`@("`G0UDG(#T^(%\H
M(D-Y<')U<R(I+`H@("`@)T-:)R`]/B!?*")#>F5C:"!297!U8FQI8R(I+`H@
M("`@)T1+)R`]/B!?*")$96YM87)K(BDL"B`@("`G1$HG(#T^(%\H(D1J:6)O
M=71I(BDL"B`@("`G1$TG(#T^(%\H(D1O;6EN:6-A(BDL"B`@("`G1$\G(#T^
M(%\H(D1O;6EN:6-A;B!297!U8FQI8R(I+`H@("`@)T5#)R`]/B!?*")%8W5A
M9&]R(BDL"B`@("`G14<G(#T^(%\H(D5G>7!T(BDL"B`@("`G4U8G(#T^(%\H
M(D5L(%-A;'9A9&]R(BDL"B`@("`G1U$G(#T^(%\H(D5Q=6%T;W)I86P@1W5I
M;F5A(BDL"B`@("`G15(G(#T^(%\H(D5R:71R96$B*2P*("`@("=%12<@/3X@
M7R@B17-T;VYI82(I+`H@("`@)T54)R`]/B!?*")%=&AI;W!I82(I+`H@("`@
M)T9+)R`]/B!?*")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB*2P*("`@
M("=&3R<@/3X@7R@B1F%R;V4@27-L86YD<R(I+`H@("`@)T9*)R`]/B!?*")&
M:6II(BDL"B`@("`G1DDG(#T^(%\H(D9I;FQA;F0B*2P*("`@("=&4B<@/3X@
M7R@B1G)A;F-E(BDL"B`@("`G1T8G(#T^(%\H(D9R96YC:"!'=6EA;F$B*2P*
M("`@("=01B<@/3X@7R@B1G)E;F-H(%!O;'EN97-I82(I+`H@("`@)U1&)R`]
M/B!?*")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B*2P*("`@("='02<@
M/3X@7R@B1V%B;VXB*2P*("`@("='32<@/3X@7R@B1V%M8FEA(BDL"B`@("`G
M1T4G(#T^(%\H(D=E;W)G:6$B*2P*("`@("=$12<@/3X@7R@B1V5R;6%N>2(I
M+`H@("`@)T=()R`]/B!?*")':&%N82(I+`H@("`@)T=))R`]/B!?*")':6)R
M86QT87(B*2P*("`@("='4B<@/3X@7R@B1W)E96-E(BDL"B`@("`G1TPG(#T^
M(%\H(D=R965N;&%N9"(I+`H@("`@)T=$)R`]/B!?*")'<F5N861A(BDL"B`@
M("`G1U`G(#T^(%\H(D=U861E;&]U<&4B*2P*("`@("='52<@/3X@7R@B1W5A
M;2(I+`H@("`@)T=4)R`]/B!?*")'=6%T96UA;&$B*2P*("`@("='3B<@/3X@
M7R@B1W5I;F5A(BDL"B`@("`G1U<G(#T^(%\H(D=U:6YE82U":7-S874B*2P*
M("`@("='62<@/3X@7R@B1W5Y86YA(BDL"B`@("`G2%0G(#T^(%\H(DAA:71I
M(BDL"B`@("`G2$TG(#T^(%\H(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<R(I+`H@("`@)U9!)R`]/B!?*")(;VQY(%-E92`H5F%T:6-A;B!#
M:71Y(%-T871E*2(I+`H@("`@)TA.)R`]/B!?*")(;VYD=7)A<R(I+`H@("`@
M)TA+)R`]/B!?*")(;VYG($MO;F<B*2P*("`@("=(52<@/3X@7R@B2'5N9V%R
M>2(I+`H@("`@)TE3)R`]/B!?*"))8V5L86YD(BDL"B`@("`G24XG(#T^(%\H
M(DEN9&EA(BDL"B`@("`G240G(#T^(%\H(DEN9&]N97-I82(I+`H@("`@)TE2
M)R`]/B!?*"))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(BDL"B`@("`G25$G
M(#T^(%\H(DER87$B*2P*("`@("=)12<@/3X@7R@B27)E;&%N9"(I+`H@("`@
M)TE,)R`]/B!?*"))<W)A96PB*2P*("`@("=)5"<@/3X@7R@B271A;'DB*2P*
M("`@("=*32<@/3X@7R@B2F%M86EC82(I+`H@("`@)TI0)R`]/B!?*")*87!A
M;B(I+`H@("`@)TI/)R`]/B!?*")*;W)D86XB*2P*("`@("=+6B<@/3X@7R@B
M2V%Z86MH<W1A;B(I+`H@("`@)TM%)R`]/B!?*")+96YY82(I+`H@("`@)TM)
M)R`]/B!?*")+:7)I8F%T:2(I+`H@("`@)TM0)R`]/B!?*")+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(I+`H@("`@)TM2)R`]/B!?
M*")+;W)E82P@4F5P=6)L:6,@;V8B*2P*("`@("=+5R<@/3X@7R@B2W5W86ET
M(BDL"B`@("`G2T<G(#T^(%\H(DMY<F=Y>G-T86XB*2P*("`@("=,02<@/3X@
M7R@B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B*2P*("`@("=,
M5B<@/3X@7R@B3&%T=FEA(BDL"B`@("`G3$(G(#T^(%\H(DQE8F%N;VXB*2P*
M("`@("=,4R<@/3X@7R@B3&5S;W1H;R(I+`H@("`@)TQ2)R`]/B!?*"),:6)E
M<FEA(BDL"B`@("`G3%DG(#T^(%\H(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B
M*2P*("`@("=,22<@/3X@7R@B3&EE8VAT96YS=&5I;B(I+`H@("`@)TQ4)R`]
M/B!?*"),:71H=6%N:6$B*2P*("`@("=,52<@/3X@7R@B3'5X96UB;W5R9R(I
M+`H@("`@)TU/)R`]/B!?*")-86-A;R(I+`H@("`@)TU+)R`]/B!?*")-86-E
M9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B*2P*("`@
M("=-1R<@/3X@7R@B36%D86=A<V-A<B(I+`H@("`@)TU7)R`]/B!?*")-86QA
M=VDB*2P*("`@("=-62<@/3X@7R@B36%L87ES:6$B*2P*("`@("=-5B<@/3X@
M7R@B36%L9&EV97,B*2P*("`@("=-3"<@/3X@7R@B36%L:2(I+`H@("`@)TU4
M)R`]/B!?*")-86QT82(I+`H@("`@)TU()R`]/B!?*")-87)S:&%L;"!)<VQA
M;F1S(BDL"B`@("`G35$G(#T^(%\H(DUA<G1I;FEQ=64B*2P*("`@("=-4B<@
M/3X@7R@B36%U<FET86YI82(I+`H@("`@)TU5)R`]/B!?*")-875R:71I=7,B
M*2P*("`@("=95"<@/3X@7R@B36%Y;W1T92(I+`H@("`@)TU8)R`]/B!?*")-
M97AI8V\B*2P*("`@("=&32<@/3X@7R@B36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9B(I+`H@("`@)TU$)R`]/B!?*")-;VQD;W9A+"!297!U8FQI
M8R!O9B(I+`H@("`@)TU#)R`]/B!?*")-;VYA8V\B*2P*("`@("=-3B<@/3X@
M7R@B36]N9V]L:6$B*2P*("`@("=-4R<@/3X@7R@B36]N='-E<G)A="(I+`H@
M("`@)TU!)R`]/B!?*")-;W)O8V-O(BDL"B`@("`G35HG(#T^(%\H(DUO>F%M
M8FEQ=64B*2P*("`@("=-32<@/3X@7R@B37EA;FUA<B(I+`H@("`@)TY!)R`]
M/B!?*").86UI8FEA(BDL"B`@("`G3E(G(#T^(%\H(DYA=7)U(BDL"B`@("`G
M3E`G(#T^(%\H(DYE<&%L(BDL"B`@("`G3DPG(#T^(%\H(DYE=&AE<FQA;F1S
M(BDL"B`@("`G04XG(#T^(%\H(DYE=&AE<FQA;F1S($%N=&EL;&5S(BDL"B`@
M("`G3D,G(#T^(%\H(DYE=R!#86QE9&]N:6$B*2P*("`@("=.6B<@/3X@7R@B
M3F5W(%IE86QA;F0B*2P*("`@("=.22<@/3X@7R@B3FEC87)A9W5A(BDL"B`@
M("`G3D4G(#T^(%\H(DYI9V5R(BDL"B`@("`G3D<G(#T^(%\H(DYI9V5R:6$B
M*2P*("`@("=.52<@/3X@7R@B3FEU92(I+`H@("`@)TY&)R`]/B!?*").;W)F
M;VQK($ES;&%N9"(I+`H@("`@)TU0)R`]/B!?*").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B*2P*("`@("=.3R<@/3X@7R@B3F]R=V%Y(BDL"B`@("`G3TTG
M(#T^(%\H(D]M86XB*2P*("`@("=02R<@/3X@7R@B4&%K:7-T86XB*2P*("`@
M("=05R<@/3X@7R@B4&%L874B*2P*("`@("=04R<@/3X@7R@B4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(I+`H@("`@)U!!)R`]/B!?*")086YA
M;6$B*2P*("`@("=01R<@/3X@7R@B4&%P=6$@3F5W($=U:6YE82(I+`H@("`@
M)U!9)R`]/B!?*")087)A9W5A>2(I+`H@("`@)U!%)R`]/B!?*")097)U(BDL
M"B`@("`G4$@G(#T^(%\H(E!H:6QI<'!I;F5S(BDL"B`@("`G4$XG(#T^(%\H
M(E!I=&-A:7)N(BDL"B`@("`G4$PG(#T^(%\H(E!O;&%N9"(I+`H@("`@)U!4
M)R`]/B!?*")0;W)T=6=A;"(I+`H@("`@)U!2)R`]/B!?*")0=65R=&\@4FEC
M;R(I+`H@("`@)U%!)R`]/B!?*")1871A<B(I+`H@("`@)U)%)R`]/B!?*")2
M975N:6]N(BDL"B`@("`G4D\G(#T^(%\H(E)O;6%N:6$B*2P*("`@("=252<@
M/3X@7R@B4G5S<VEA;B!&961E<F%T:6]N(BDL"B`@("`G4E<G(#T^(%\H(E)W
M86YD82(I+`H@("`@)U-()R`]/B!?*")386EN="!(96QE;F$B*2P*("`@("=+
M3B<@/3X@7R@B4V%I;G0@2VET=',@86YD($YE=FES(BDL"B`@("`G3$,G(#T^
M(%\H(E-A:6YT($QU8VEA(BDL"B`@("`G4$TG(#T^(%\H(E-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VXB*2P*("`@("=60R<@/3X@7R@B4V%I;G0@5FEN8V5N
M="!A;F0@=&AE($=R96YA9&EN97,B*2P*("`@("=74R<@/3X@7R@B4V%M;V$B
M*2P*("`@("=332<@/3X@7R@B4V%N($UA<FEN;R(I+`H@("`@)U-4)R`]/B!?
M*")386\@5&]M92!A;F0@4')I;F-I<&4B*2P*("`@("=302<@/3X@7R@B4V%U
M9&D@07)A8FEA(BDL"B`@("`G4TXG(#T^(%\H(E-E;F5G86PB*2P*("`@("=#
M4R<@/3X@7R@B4V5R8FEA(&%N9"!-;VYT96YE9W)O(BDL"B`@("`G4T,G(#T^
M(%\H(E-E>6-H96QL97,B*2P*("`@("=33"<@/3X@7R@B4VEE<G)A($QE;VYE
M(BDL"B`@("`G4T<G(#T^(%\H(E-I;F=A<&]R92(I+`H@("`@)U-+)R`]/B!?
M*")3;&]V86MI82(I+`H@("`@)U-))R`]/B!?*")3;&]V96YI82(I+`H@("`@
M)U-")R`]/B!?*")3;VQO;6]N($ES;&%N9',B*2P*("`@("=33R<@/3X@7R@B
M4V]M86QI82(I+`H@("`@)UI!)R`]/B!?*")3;W5T:"!!9G)I8V$B*2P*("`@
M("='4R<@/3X@7R@B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',B*2P*("`@("=%4R<@/3X@7R@B4W!A:6XB*2P*("`@("=,
M2R<@/3X@7R@B4W)I($QA;FMA(BDL"B`@("`G4T0G(#T^(%\H(E-U9&%N(BDL
M"B`@("`G4U(G(#T^(%\H(E-U<FEN86UE(BDL"B`@("`G4THG(#T^(%\H(E-V
M86QB87)D(&%N9"!*86X@36%Y96XB*2P*("`@("=36B<@/3X@7R@B4W=A>FEL
M86YD(BDL"B`@("`G4T4G(#T^(%\H(E-W961E;B(I+`H@("`@)T-()R`]/B!?
M*")3=VET>F5R;&%N9"(I+`H@("`@)U-9)R`]/B!?*")3>7)I86X@07)A8B!2
M97!U8FQI8R(I+`H@("`@)U17)R`]/B!?*")486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA(BDL"B`@("`G5$HG(#T^(%\H(E1A:FEK:7-T86XB*2P*("`@("=4
M6B<@/3X@7R@B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(I+`H@("`@
M)U1()R`]/B!?*")4:&%I;&%N9"(I+`H@("`@)U1,)R`]/B!?*")4:6UO<BU,
M97-T92(I+`H@("`@)U1')R`]/B!?*")4;V=O(BDL"B`@("`G5$LG(#T^(%\H
M(E1O:V5L874B*2P*("`@("=43R<@/3X@7R@B5&]N9V$B*2P*("`@("=45"<@
M/3X@7R@B5')I;FED860@86YD(%1O8F%G;R(I+`H@("`@)U1.)R`]/B!?*")4
M=6YI<VEA(BDL"B`@("`G5%(G(#T^(%\H(E1U<FME>2(I+`H@("`@)U1-)R`]
M/B!?*")4=7)K;65N:7-T86XB*2P*("`@("=40R<@/3X@7R@B5'5R:W,@86YD
M($-A:6-O<R!)<VQA;F1S(BDL"B`@("`G5%8G(#T^(%\H(E1U=F%L=2(I+`H@
M("`@)U5')R`]/B!?*")59V%N9&$B*2P*("`@("=502<@/3X@7R@B56MR86EN
M92(I+`H@("`@)T%%)R`]/B!?*")5;FET960@07)A8B!%;6ER871E<R(I+`H@
M("`@)T=")R`]/B!?*")5;FET960@2VEN9V1O;2(I+`H@("`@)U53)R`]/B!?
M*")5;FET960@4W1A=&5S(BDL"B`@("`G54TG(#T^(%\H(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(I+`H@("`@)U59)R`]/B!?*")5
M<G5G=6%Y(BDL"B`@("`G55HG(#T^(%\H(E5Z8F5K:7-T86XB*2P*("`@("=6
M52<@/3X@7R@B5F%N=6%T=2(I+`H@("`@)U9%)R`]/B!?*")696YE>G5E;&$B
M*2P*("`@("=63B<@/3X@7R@B5FEE="!.86TB*2P*("`@("=61R<@/3X@7R@B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B*2P*("`@("=622<@/3X@7R@B5FER
M9VEN($ES;&%N9',L(%4N4RXB*2P*("`@("=71B<@/3X@7R@B5V%L;&ES(&%N
M9"!&=71U;F$B*2P*("`@("=%2"<@/3X@7R@B5V5S=&5R;B!386AA<F$B*2P*
M("`@("=912<@/3X@7R@B665M96XB*2P*("`@("=:32<@/3X@7R@B6F%M8FEA
M(BDL"B`@("`G6E<G(#T^(%\H(EII;6)A8G=E(BDI.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,O1V5O25`N<&AP````````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S$U-#,`,3`U,34T,S$P-C$`
M,#(P,S,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!(;W)D92!O<'1I;6EZ960@:6YT97)F86-E('1O
M('1H92!-87A-:6YD($E0($%D9')E<W,M/D-O=6YT<GD*("H@;&ES=&EN9RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`L=B`Q
M+C$P+C$P+C<@,C`P-B\P-B\R-R`Q-3HQ.3HQ,B!S;'5S87)Z($5X<"`D"B`J
M"B`J($)A<V5D(&]N(%!(4"!G96]I<"YI;F,@;&EB<F%R>2!B>2!-87A-:6YD
M($Q,0SH*("H@("!H='1P.B\O=W=W+FUA>&UI;F0N8V]M+V1O=VYL;V%D+V=E
M;VEP+V%P:2]P:'`O"B`J"B`J($]R:6=I;F%L;'D@8F%S960@;VX@<&AP('9E
M<G-I;VX@;V8@=&AE(&=E;VEP(&QI8G)A<GD@=W)I='1E;B!I;B!-87D*("H@
M,C`P,B!B>2!J:6T@=VEN<W1E860@/&II;7=`87!A8VAE+F]R9SX*("H*("H@
M0V]P>7)I9VAT("A#*2`R,#`S($UA>$UI;F0@3$Q#"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*@H@*B!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R
M93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`J(&UO9&EF>2!I
M="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,*("H@3&EC96YS92!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F
M='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R"B`J('9E<G-I;VX@,BXQ(&]F('1H
M92!,:6-E;G-E+"!O<B`H870@>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V97)S
M:6]N+@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PH*+RH@0V]U
M;G1R>2!L:7-T+B`J+PHD1TQ/0D%,4ULG1T5/25!?0T]53E1265]#3T1%4R==
M(#T@87)R87DH"B<G+"`G05`G+"`G154G+"`G040G+"`G044G+"`G048G+"`G
M04<G+"`G04DG+"`G04PG+"`G04TG+"`G04XG+"`G04\G+"`G05$G+`HG05(G
M+"`G05,G+"`G050G+"`G054G+"`G05<G+"`G05HG+"`G0D$G+"`G0D(G+"`G
M0D0G+"`G0D4G+"`G0D8G+"`G0D<G+"`G0D@G+`HG0DDG+"`G0DHG+"`G0DTG
M+"`G0DXG+"`G0D\G+"`G0E(G+"`G0E,G+"`G0E0G+"`G0E8G+"`G0E<G+"`G
M0EDG+"`G0EHG+"`G0T$G+`HG0T,G+"`G0T0G+"`G0T8G+"`G0T<G+"`G0T@G
M+"`G0TDG+"`G0TLG+"`G0TPG+"`G0TTG+"`G0TXG+"`G0T\G+"`G0U(G+"`G
M0U4G+`HG0U8G+"`G0U@G+"`G0UDG+"`G0UHG+"`G1$4G+"`G1$HG+"`G1$LG
M+"`G1$TG+"`G1$\G+"`G1%HG+"`G14,G+"`G144G+"`G14<G+`HG14@G+"`G
M15(G+"`G15,G+"`G150G+"`G1DDG+"`G1DHG+"`G1DLG+"`G1DTG+"`G1D\G
M+"`G1E(G+"`G1E@G+"`G1T$G+"`G54LG+`HG1T0G+"`G1T4G+"`G1T8G+"`G
M1T@G+"`G1TDG+"`G1TPG+"`G1TTG+"`G1TXG+"`G1U`G+"`G1U$G+"`G1U(G
M+"`G1U,G+"`G1U0G+`HG1U4G+"`G1U<G+"`G1UDG+"`G2$LG+"`G2$TG+"`G
M2$XG+"`G2%(G+"`G2%0G+"`G2%4G+"`G240G+"`G244G+"`G24PG+"`G24XG
M+`HG24\G+"`G25$G+"`G25(G+"`G25,G+"`G250G+"`G2DTG+"`G2D\G+"`G
M2E`G+"`G2T4G+"`G2T<G+"`G2T@G+"`G2TDG+"`G2TTG+`HG2TXG+"`G2U`G
M+"`G2U(G+"`G2U<G+"`G2UDG+"`G2UHG+"`G3$$G+"`G3$(G+"`G3$,G+"`G
M3$DG+"`G3$LG+"`G3%(G+"`G3%,G+`HG3%0G+"`G3%4G+"`G3%8G+"`G3%DG
M+"`G34$G+"`G34,G+"`G340G+"`G34<G+"`G34@G+"`G34LG+"`G34PG+"`G
M34TG+"`G34XG+`HG34\G+"`G35`G+"`G35$G+"`G35(G+"`G35,G+"`G350G
M+"`G354G+"`G358G+"`G35<G+"`G35@G+"`G35DG+"`G35HG+"`G3D$G+`HG
M3D,G+"`G3D4G+"`G3D8G+"`G3D<G+"`G3DDG+"`G3DPG+"`G3D\G+"`G3E`G
M+"`G3E(G+"`G3E4G+"`G3EHG+"`G3TTG+"`G4$$G+`HG4$4G+"`G4$8G+"`G
M4$<G+"`G4$@G+"`G4$LG+"`G4$PG+"`G4$TG+"`G4$XG+"`G4%(G+"`G4%,G
M+"`G4%0G+"`G4%<G+"`G4%DG+`HG44$G+"`G4D4G+"`G4D\G+"`G4E4G+"`G
M4E<G+"`G4T$G+"`G4T(G+"`G4T,G+"`G4T0G+"`G4T4G+"`G4T<G+"`G4T@G
M+"`G4TDG+`HG4THG+"`G4TLG+"`G4TPG+"`G4TTG+"`G4TXG+"`G4T\G+"`G
M4U(G+"`G4U0G+"`G4U8G+"`G4UDG+"`G4UHG+"`G5$,G+"`G5$0G+`HG5$8G
M+"`G5$<G+"`G5$@G+"`G5$HG+"`G5$LG+"`G5$TG+"`G5$XG+"`G5$\G+"`G
M5%`G+"`G5%(G+"`G5%0G+"`G5%8G+"`G5%<G+`HG5%HG+"`G54$G+"`G54<G
M+"`G54TG+"`G55,G+"`G55DG+"`G55HG+"`G5D$G+"`G5D,G+"`G5D4G+"`G
M5D<G+"`G5DDG+"`G5DXG+`HG5E4G+"`G5T8G+"`G5U,G+"`G644G+"`G650G
M+"`G654G+"`G6D$G+"`G6DTG+"`G6E(G+"`G6E<G+"`G03$G+"`G03(G+"`G
M3S$G"BD["@HO*B!#;W5N=')Y($YA;65S+B`J+PHD1TQ/0D%,4ULG1T5/25!?
M0T]53E1265].04U%4R==(#T@87)R87DH"B(B+"!?*")!<VEA+U!A8VEF:6,@
M4F5G:6]N(BDL(%\H(D5U<F]P92(I+"!?*")!;F1O<G)A(BDL"E\H(E5N:71E
M9"!!<F%B($5M:7)A=&5S(BDL(%\H(D%F9VAA;FES=&%N(BDL(%\H(D%N=&EG
M=6$@86YD($)A<F)U9&$B*2P*7R@B06YG=6EL;&$B*2P@7R@B06QB86YI82(I
M+"!?*")!<FUE;FEA(BDL(%\H(DYE=&AE<FQA;F1S($%N=&EL;&5S(BDL"E\H
M(D%N9V]L82(I+"!?*")!;G1A<F-T:6-A(BDL(%\H(D%R9V5N=&EN82(I+"!?
M*")!;65R:6-A;B!386UO82(I+`I?*")!=7-T<FEA(BDL(%\H(D%U<W1R86QI
M82(I+"!?*")!<G5B82(I+"!?*")!>F5R8F%I:F%N(BDL"E\H(D)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$B*2P@7R@B0F%R8F%D;W,B*2P@7R@B0F%N9VQA9&5S
M:"(I+"!?*")"96QG:75M(BDL"E\H(D)U<FMI;F$@1F%S;R(I+"!?*")"=6QG
M87)I82(I+"!?*")"86AR86EN(BDL(%\H(D)U<G5N9&DB*2P@7R@B0F5N:6XB
M*2P*7R@B0F5R;75D82(I+"!?*")"<G5N96D@1&%R=7-S86QA;2(I+"!?*")"
M;VQI=FEA(BDL(%\H(D)R87II;"(I+"!?*")"86AA;6%S(BDL"E\H(D)H=71A
M;B(I+"!?*")";W5V970@27-L86YD(BDL(%\H(D)O='-W86YA(BDL(%\H(D)E
M;&%R=7,B*2P@7R@B0F5L:7IE(BDL"E\H(D-A;F%D82(I+"!?*")#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<R(I+`I?*")#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE(BDL(%\H(D-E;G1R86P@069R:6-A;B!297!U8FQI
M8R(I+`I?*")#;VYG;R(I+"!?*")3=VET>F5R;&%N9"(I+"!?*")#;W1E(&0G
M279O:7)E(BDL(%\H(D-O;VL@27-L86YD<R(I+`I?*")#:&EL92(I+"!?*")#
M86UE<F]O;B(I+"!?*")#:&EN82(I+"!?*")#;VQO;6)I82(I+"!?*")#;W-T
M82!2:6-A(BDL"E\H(D-U8F$B*2P@7R@B0V%P92!697)D92(I+"!?*")#:')I
M<W1M87,@27-L86YD(BDL(%\H(D-Y<')U<R(I+`I?*")#>F5C:"!297!U8FQI
M8R(I+"!?*")'97)M86YY(BDL(%\H(D1J:6)O=71I(BDL(%\H(D1E;FUA<FLB
M*2P@7R@B1&]M:6YI8V$B*2P*7R@B1&]M:6YI8V%N(%)E<'5B;&EC(BDL(%\H
M(D%L9V5R:6$B*2P@7R@B16-U861O<B(I+"!?*")%<W1O;FEA(BDL(%\H(D5G
M>7!T(BDL"E\H(E=E<W1E<FX@4V%H87)A(BDL(%\H(D5R:71R96$B*2P@7R@B
M4W!A:6XB*2P@7R@B171H:6]P:6$B*2P@7R@B1FEN;&%N9"(I+`I?*")&:6II
M(BDL(%\H(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(I+"!?*")-:6-R
M;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(BDL"E\H(D9A<F]E($ES;&%N
M9',B*2P@7R@B1G)A;F-E(BDL(%\H(D9R86YC92P@365T<F]P;VQI=&%N(BDL
M(%\H(D=A8F]N(BDL"E\H(E5N:71E9"!+:6YG9&]M(BDL(%\H(D=R96YA9&$B
M*2P@7R@B1V5O<F=I82(I+"!?*")&<F5N8V@@1W5I86YA(BDL"E\H(D=H86YA
M(BDL(%\H(D=I8G)A;'1A<B(I+"!?*")'<F5E;FQA;F0B*2P@7R@B1V%M8FEA
M(BDL(%\H(D=U:6YE82(I+`I?*")'=6%D96QO=7!E(BDL(%\H(D5Q=6%T;W)I
M86P@1W5I;F5A(BDL(%\H(D=R965C92(I+`I?*")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(I+"!?*")'=6%T96UA;&$B
M*2P@7R@B1W5A;2(I+`I?*")'=6EN96$M0FES<V%U(BDL(%\H(D=U>6%N82(I
M+"!?*")(;VYG($MO;F<B*2P*7R@B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S(BDL(%\H(DAO;F1U<F%S(BDL(%\H(D-R;V%T:6$B*2P*7R@B
M2&%I=&DB*2P@7R@B2'5N9V%R>2(I+"!?*"));F1O;F5S:6$B*2P@7R@B27)E
M;&%N9"(I+"!?*"))<W)A96PB*2P*7R@B26YD:6$B*2P@7R@B0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y(BDL(%\H(DER87$B*2P*7R@B27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B(I+"!?*"))8V5L86YD(BDL(%\H(DET86QY
M(BDL(%\H(DIA;6%I8V$B*2P*7R@B2F]R9&%N(BDL(%\H(DIA<&%N(BDL(%\H
M(DME;GEA(BDL(%\H(DMY<F=Y>G-T86XB*2P@7R@B0V%M8F]D:6$B*2P*7R@B
M2VER:6)A=&DB*2P@7R@B0V]M;W)O<R(I+"!?*")386EN="!+:71T<R!A;F0@
M3F5V:7,B*2P*7R@B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8B*2P@7R@B2V]R96$L(%)E<'5B;&EC(&]F(BDL"E\H(DMU=V%I="(I
M+"!?*")#87EM86X@27-L86YD<R(I+"!?*")+87IA:VAS=&%N(BDL"E\H(DQA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(BDL(%\H(DQE8F%N;VXB
M*2P@7R@B4V%I;G0@3'5C:6$B*2P*7R@B3&EE8VAT96YS=&5I;B(I+"!?*")3
M<FD@3&%N:V$B*2P@7R@B3&EB97)I82(I+"!?*"),97-O=&AO(BDL"E\H(DQI
M=&AU86YI82(I+"!?*"),=7AE;6)O=7)G(BDL(%\H(DQA='9I82(I+"!?*"),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(BDL"E\H(DUO<F]C8V\B*2P@7R@B36]N
M86-O(BDL(%\H(DUO;&1O=F$L(%)E<'5B;&EC(&]F(BDL(%\H(DUA9&%G87-C
M87(B*2P*7R@B36%R<VAA;&P@27-L86YD<R(I+"!?*")-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B*2P*7R@B36%L:2(I+"!?
M*")->6%N;6%R(BDL(%\H(DUO;F=O;&EA(BDL(%\H(DUA8V%O(BDL"E\H(DYO
M<G1H97)N($UA<FEA;F$@27-L86YD<R(I+"!?*")-87)T:6YI<75E(BDL(%\H
M(DUA=7)I=&%N:6$B*2P*7R@B36]N='-E<G)A="(I+"!?*")-86QT82(I+"!?
M*")-875R:71I=7,B*2P@7R@B36%L9&EV97,B*2P@7R@B36%L87=I(BDL"E\H
M(DUE>&EC;R(I+"!?*")-86QA>7-I82(I+"!?*")-;WIA;6)I<75E(BDL(%\H
M(DYA;6EB:6$B*2P@7R@B3F5W($-A;&5D;VYI82(I+`I?*").:6=E<B(I+"!?
M*").;W)F;VQK($ES;&%N9"(I+"!?*").:6=E<FEA(BDL(%\H(DYI8V%R86=U
M82(I+`I?*").971H97)L86YD<R(I+"!?*").;W)W87DB*2P@7R@B3F5P86PB
M*2P@7R@B3F%U<G4B*2P@7R@B3FEU92(I+`I?*").97<@6F5A;&%N9"(I+"!?
M*")/;6%N(BDL(%\H(E!A;F%M82(I+"!?*")097)U(BDL(%\H(D9R96YC:"!0
M;VQY;F5S:6$B*2P*7R@B4&%P=6$@3F5W($=U:6YE82(I+"!?*")0:&EL:7!P
M:6YE<R(I+"!?*")086MI<W1A;B(I+"!?*")0;VQA;F0B*2P*7R@B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(I+"!?*")0:71C86ER;B(I+"!?*")0=65R
M=&\@4FEC;R(I+`I?*")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M(BDL(%\H(E!O<G1U9V%L(BDL(%\H(E!A;&%U(BDL"E\H(E!A<F%G=6%Y(BDL
M(%\H(E%A=&%R(BDL(%\H(E)E=6YI;VXB*2P@7R@B4F]M86YI82(I+`I?*")2
M=7-S:6%N($9E9&5R871I;VXB*2P@7R@B4G=A;F1A(BDL(%\H(E-A=61I($%R
M86)I82(I+"!?*")3;VQO;6]N($ES;&%N9',B*2P*7R@B4V5Y8VAE;&QE<R(I
M+"!?*")3=61A;B(I+"!?*")3=V5D96XB*2P@7R@B4VEN9V%P;W)E(BDL(%\H
M(E-A:6YT($AE;&5N82(I+`I?*")3;&]V96YI82(I+"!?*")3=F%L8F%R9"!A
M;F0@2F%N($UA>65N(BDL(%\H(E-L;W9A:VEA(BDL(%\H(E-I97)R82!,96]N
M92(I+`I?*")386X@36%R:6YO(BDL(%\H(E-E;F5G86PB*2P@7R@B4V]M86QI
M82(I+"!?*")3=7)I;F%M92(I+`I?*")386\@5&]M92!A;F0@4')I;F-I<&4B
M*2P@7R@B16P@4V%L=F%D;W(B*2P@7R@B4WER:6%N($%R86(@4F5P=6)L:6,B
M*2P*7R@B4W=A>FEL86YD(BDL(%\H(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(I+"!?*")#:&%D(BDL"E\H(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE
M<R(I+"!?*")4;V=O(BDL(%\H(E1H86EL86YD(BDL(%\H(E1A:FEK:7-T86XB
M*2P*7R@B5&]K96QA=2(I+"!?*")4=7)K;65N:7-T86XB*2P@7R@B5'5N:7-I
M82(I+"!?*")4;VYG82(I+"!?*")4:6UO<BU,97-T92(I+`I?*")4=7)K97DB
M*2P@7R@B5')I;FED860@86YD(%1O8F%G;R(I+"!?*")4=79A;'4B*2P@7R@B
M5&%I=V%N(BDL"E\H(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B*2P@
M7R@B56MR86EN92(I+"!?*")59V%N9&$B*2P*7R@B56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S(BDL(%\H(E5N:71E9"!3=&%T97,B*2P@
M7R@B57)U9W5A>2(I+`I?*")5>F)E:VES=&%N(BDL(%\H(DAO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I(BDL"E\H(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(BDL(%\H(E9E;F5Z=65L82(I+`I?*")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(I+"!?*")6:7)G:6X@27-L86YD<RP@52Y3+B(I+"!?
M*")6:65T($YA;2(I+`I?*")686YU871U(BDL(%\H(E=A;&QI<R!A;F0@1G5T
M=6YA(BDL(%\H(E-A;6]A(BDL(%\H(EEE;65N(BDL(%\H(DUA>6]T=&4B*2P*
M7R@B675G;W-L879I82(I+"!?*")3;W5T:"!!9G)I8V$B*2P@7R@B6F%M8FEA
M(BDL(%\H(EIA:7)E(BDL(%\H(EII;6)A8G=E(BDL"E\H(D%N;VYY;6]U<R!0
M<F]X>2(I+"!?*")3871E;&QI=&4@4')O=FED97(B*2P@7R@B3W1H97(B*0HI
M.PH*9&5F:6YE*"='14])4%]#3U5.5%)97T)%1TE.)RP@,38W-S8Y-C`I.PID
M969I;F4H)U-44E5#5%5215])3D9/7TU!6%]325I%)RP@,C`I.PID969I;F4H
M)U-404Y$05)$7U)%0T]21%],14Y'5$@G+"`S*3L*"F-L87-S($Y,4U]'96])
M4"!["@H@("`@+RHJ"B`@("`@*B!4:&4@;&]C871I;VX@;V8@=&AE($=E;TE0
M(&1A=&%B87-E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V1A=&%F:6QE.PH*("`@("\J*@H@("`@("H@5&AE(&]P96X@
M9FEL96AA;F1L92!T;R!T:&4@1V5O25`@9&%T86)A<V4N"B`@("`@*@H@("`@
M("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]F:6QE:&%N9&QE
M.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@
M9VQO8F%L($Y,4U]'96])4"!O8FIE8W0L(&]N;'D@8W)E871I;F<@:70*("`@
M("`J(&EF(&ET(&1O97-N)W0@86QR96%D>2!E>&ES="X*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@("`@*B`@("1G
M96]I<"`]("9'96])4#HZ<VEN9VQE=&]N*"1D871A9FEL92D["B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&%T869I;&4@(%1H92!L;V-A=&EO;B!O
M9B!T:&4@1V5O25`@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!O
M8FIE8W0@3DQ37T=E;TE0("!4:&4@3DQ37T=E;TE0(&EN<W1A;F-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D871A9FEL92D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1I;G-T86YC92DI('L*("`@("`@("`@("`@)&EN<W1A;F-E(#T@;F5W($Y,
M4U]'96])4"@D9&%T869I;&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;G-T86YC93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A($Y,
M4U]'96])4"!I;G-T86YC92`H0V]N<W1R=6-T;W(I+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&%F:6QE("!4:&4@;&]C871I;VX@;V8@=&AE
M($=E;TE0(&1A=&%B87-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!.3%-?1V5O
M25`H)&1A=&%F:6QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&%T869I;&4@
M/2`D9&%T869I;&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N('1H92!'
M96])4"!D871A8F%S92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($9A;'-E(&]N(&5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;W!E;B@I"B`@("!["B`@("`@("`@
M+RH@4F5T=7)N(&EF('=E(&%L<F5A9'D@:&%V92!A;B!O8FIE8W0N("HO"B`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V9I;&5H86YD;&4I*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T
M=7)N(&EF(&YO(&1A=&%F:6QE('-P96-I9FEE9"X@*B\*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]D871A9FEL92DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]F:6QE:&%N9&QE
M(#T@9F]P96XH)'1H:7,M/E]D871A9FEL92P@)W)B)RD["@H@("`@("`@("1F
M:6QE<&]S(#T@9G1E;&PH)'1H:7,M/E]F:6QE:&%N9&QE*3L*("`@("`@("!F
M<V5E:R@D=&AI<RT^7V9I;&5H86YD;&4L("TS+"!3145+7T5.1"D["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@4U1254-455)%7TE.1D]?34%87U-)6D4[
M("1I*RLI('L*("`@("`@("`@("`@)&1E;&EM(#T@9G)E860H)'1H:7,M/E]F
M:6QE:&%N9&QE+"`S*3L*("`@("`@("`@("`@:68@*"1D96QI;2`]/2`H8VAR
M*#(U-2D@+B!C:'(H,C4U*2`N(&-H<B@R-34I*2D@>PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!F<V5E:R@D=&AI<RT^7V9I;&5H86YD;&4L("TT+"!3145+7T-54BD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9G-E96LH)'1H:7,M/E]F
M:6QE:&%N9&QE+"`D9FEL97!O<RP@4T5%2U]3150I.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O
M=6YT<GD@240@9F]R(&$@:&]S=&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&AO<W1N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE($=E;TE0(&-O=6YT<GD@240N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-O=6YT<GE)9$)Y3F%M92@D;F%M92D*("`@('L*("`@
M("`@("!I9B`H(21T:&ES+3Y?;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)&%D9'(@/2!G971H;W-T8GEN
M86UE*"1N86UE*3L*("`@("`@("!I9B`H(21A9&1R('Q\("@D861D<B`]/2`D
M;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/F-O=6YT<GE)9$)Y061D<B@D861D<BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N=')Y(&%B
M8G)E=FEA=&EO;B`H,BUL971T97(I(&9O<B!A(&AO<W1N86UE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!H;W-T;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C;W5N=')Y(&%B8G)E
M=FEA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1R>4-O9&5">4YA
M;64H)&YA;64I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;B@I*2![
M"B`@("`@("`@("`@("1C;W5N=')Y7VED(#T@)'1H:7,M/F-O=6YT<GE)9$)Y
M3F%M92@D;F%M92D["B`@("`@("`@("`@(&EF("@D8V]U;G1R>5]I9"`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG1T5/
M25!?0T]53E1265]#3T1%4R==6R1C;W5N=')Y7VED73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N=')Y(&YA;64@9F]R(&$@:&]S
M=&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&AO<W1N86UE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE
M(&-O=6YT<GD@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1R>4YA
M;65">4YA;64H)&YA;64I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E
M;B@I*2!["B`@("`@("`@("`@("1C;W5N=')Y7VED(#T@)'1H:7,M/F-O=6YT
M<GE)9$)Y3F%M92@D;F%M92D["B`@("`@("`@("`@(&EF("@D8V]U;G1R>5]I
M9"`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG1T5/25!?0T]53E1265].04U%4R==6R1C;W5N=')Y7VED73L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N=')Y($E$(&9O<B!A
M;B!)4"!!9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D
M9'(@(%1H92!)4"!!9&1R97-S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE($=E;TE0(&-O=6YT<GD@240N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O=6YT<GE)9$)Y061D<B@D861D<BD*("`@('L*("`@("`@("!I9B`H
M(21T:&ES+3Y?;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@)&EP;G5M(#T@:7`R;&]N9R@D861D<BD["B`@
M("`@("`@<F5T=7)N("@D=&AI<RT^7W-E96M#;W5N=')Y*"1I<&YU;2D@+2!'
M14])4%]#3U5.5%)97T)%1TE.*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&-O=6YT<GD@86)B<F5V:6%T:6]N("@R+6QE='1E<BD@9F]R
M(&%N($E0($%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M861D<B`@5&AE($E0($%D9')E<W,N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@8V]U;G1R>2!A8F)R979I871I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O=6YT<GE#;V1E0GE!9&1R*"1A9&1R*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7V]P96XH*2D@>PH@("`@("`@("`@("`D8V]U;G1R
M>5]I9"`]("1T:&ES+3YC;W5N=')Y261">4%D9'(H)&%D9'(I.PH@("`@("`@
M("`@("!I9B`H)&-O=6YT<GE?:60@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?0T]$15,G75LD
M8V]U;G1R>5]I9%T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@8V]U;G1R>2!N86UE(&9O<B!A;B!)4"!A9&1R97-S+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&%D9'(@(%1H92!)4"!A9&1R97-S+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!C;W5N=')Y(&YA;64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE.86UE0GE!9&1R*"1A9&1R*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH*2D@>PH@("`@("`@("`@
M("`D8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y261">4%D9'(H)&%D9'(I
M.PH@("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?
M3D%-15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEN9',@82!C;W5N=')Y(&)Y($E0($%D9')E<W,@:6X@=&AE($=E;TE0(&1A
M=&%B87-E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&EP;G5M("!4:&4@25`@061D<F5S<R!T
M;R!S96%R8V@@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!C;W5N=')Y($E$(&]R(&9A;'-E(&EF(&YO="!F;W5N9"X*("`@("`J("`@
M("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-E96M#;W5N=')Y*"1I<&YU;2D*("`@('L*
M("`@("`@("`D;V9F<V5T(#T@,#L*("`@("`@("!F;W(@*"1D97!T:"`](#,Q
M.R`D9&5P=&@@/CT@,#L@+2TD9&5P=&@I('L*("`@("`@("`@("`@:68@*&9S
M965K*"1T:&ES+3Y?9FEL96AA;F1L92P@,B`J(%-404Y$05)$7U)%0T]21%],
M14Y'5$@@*B`D;V9F<V5T+"!3145+7U-%5"D@(3T@,"D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)V9S965K(&9A:6QE9"<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B=68@/2!F<F5A9"@D=&AI
M<RT^7V9I;&5H86YD;&4L(#(@*B!35$%.1$%21%]214-/4D1?3$5.1U1(*3L*
M("`@("`@("`@("`@)'@@/2!A<G)A>2@P+"`P*3L*("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@,CL@*RLD:2D@>PH@("`@("`@("`@("`@("`@9F]R
M("@D:B`](#`[("1J(#P@4U1!3D1!4D1?4D5#3U)$7TQ%3D=42#L@*RLD:BD@
M>PH@("`@("`@("`@("`@("`@("`@("1X6R1I72`K/2!O<F0H)&)U9EM35$%.
M1$%21%]214-/4D1?3$5.1U1(("H@)&D@*R`D:ETI(#P\("@D:B`J(#@I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D:7!N=6T@)B`H,2`\/"`D9&5P=&@I*2!["B`@("`@("`@("`@("`@("!I
M9B`H)'A;,5T@/CT@1T5/25!?0T]53E1265]"14=)3BD@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D>%LQ73L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1O9F9S970@/2`D>%LQ73L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&EF("@D>%LP72`^/2!'14])4%]#3U5.
M5%)97T)%1TE.*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1X6S!=
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&]F9G-E="`]
M("1X6S!=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A5')E92\`````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C$`,#$W-S$P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'``````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#$W-#(V-0`Q,#4Q-30S,3`V,0`P,C$R,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!$871A5')E95]S<6PZ.B!C;&%S<R!P<F]V:61E<R!A;B!344P@:6UP;&5M
M96YT871I;VX@;V8@=&AE($AO<F1E"B`J($1A=&%4<F5E('-Y<W1E;2X*("H*
M("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P:'!T>7!E)R`@
M(%1H92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C
M+BDN"B`J("`@)V-H87)S970G("`@5&AE(&-H87)S970@=7-E9"!B>2!T:&4@
M9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R
M93X*("H@("`G=&%B;&4G("`@("!4:&4@;F%M92!O9B!T:&4@9&%T82!T86)L
M92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("=H
M;W)D95]D871A=')E92<\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D
M871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G9&%T86)A<V4G
M("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N"B`J("`@)W5S97)N86UE)R`@
M5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T
M960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T
M;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@
M(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E
M=&,N*2X*("H@("`G;W!T:6]N<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@
M<&%S<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O
M<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@
M)W1T>2<@("`@("`@5&AE(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H
M92!D871A8F%S92X\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F
M;W(@=&AE($1A=&%4<F5E('-Y<W1E;2!I<R!I;@H@*B!S8W)I<'1S+W-Q;"]H
M;W)D95]D871A=')E92YS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`L=B`Q+C$U-BXR+C,P(#(P,#8O,#<O
M,3,@,#DZ,#0Z,C`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M/@H@*B!#
M;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268*("H@
M>6]U(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E90H@*B!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?1&%T851R964*("HO
M"F-L87-S($1A=&%4<F5E7W-Q;"!E>'1E;F1S($1A=&%4<F5E('L*"B`@("`O
M*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N
M;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($1""B`@("`@*B\*("`@('9A
M<B`D7V1B.PH*("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!C;W!I97,@
M;V8@=&AE(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@=&%B;&4*("`@("`J
M('1H870@=V4@;F5E9"!T;R!J;VEN(&]N(&EN('1H92!C=7)R96YT('%U97)Y
M+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@
M)%]T86)L94-O=6YT(#T@,3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@4U%,($1A=&%4<F5E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!$871A5')E95]S
M<6PH)'!A<F%M<RD*("`@('L*("`@("`@("!P87)E;G0Z.D1A=&%4<F5E*"1P
M87)A;7,I.PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@86QL(&=R;W5P<R`H<F]O
M="!N;V1E<RD@;V8@=&AE(&1A=&$@=')E92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@=&AE(&=R;W5P($E$<PH@("`@("HO"B`@("!F=6YC
M=&EO;B!G971'<F]U<',H*0H@("`@>PH@("`@("`@("1Q=65R>2`]("=314Q%
M0U0@1$E35$E.0U0@9W)O=7!?=6ED($923TT@)R`N("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G73L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$=R;W5P<R@I.B`G("X@)'%U97)Y
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3&]A9',@*&$@<W5B<V5T(&]F*2!T:&4@9&%T871R
M964@:6YT;R!T:&4@)%]D871A(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1R;V]T
M("`@("`@("`@5VAI8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!L;V%D+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T
M;R!A;&P@;V8@:70N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]A9%1R964@
M("`@($QO860@82!T<F5E('-T87)T:6YG(&%T("1R;V]T+"!O<B!J=7-T('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U97-T
M960@;&5V96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5L;V%D("`@("`@(%)E+6QO860@
M86QR96%D>2!L;V%D960@=F%L=65S/PH@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I
M;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VME>2`@($%T=')I
M8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN
M9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7VQO860H)')O;W0@/2!$051!5%)%15]23T]4+"`D;&]A9%1R964@
M/2!F86QS92P@)')E;&]A9"`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER
M96-T:6]N(#T@,"D*("`@('L*("`@("`@("`O*B!$;R!.3U0@=7-E($1A=&%4
M<F5E.CIE>&ES=',H*2!H97)E.R!T:&%T('=O=6QD(&-A=7-E(&%N(&EN9FEN
M:71E"B`@("`@("`@("H@;&]O<"X@*B\*("`@("`@("!I9B`H(21R96QO860@
M)B8*("`@("`@("`@("`@*&EN7V%R<F%Y*"1R;V]T+"`D=&AI<RT^7VYA;65-
M87`I('Q\"B`@("`@("`@("`@("`H8V]U;G0H)'1H:7,M/E]D871A*2`F)B`D
M<F]O="`]/2!$051!5%)%15]23T]4*2D@?'P*("`@("`@("`@("`@*"%I<U]N
M=6QL*"1T:&ES+3Y?<V]R=$AA<V@I("8F"B`@("`@("`@("`@("!I<W-E="@D
M=&AI<RT^7V1A=&%;)')O;W1=6R=S;W)T97(G75LD=&AI<RT^7W-O<G1(87-H
M72DI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@)'%U97)Y(#T@)'1H:7,M/E]B=6EL9$QO8611=65R>2@D<F]O="P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L;V%D
M5')E92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1!5$%44D5%7T)524Q$7U-%3$5#5"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO
M;BD["B`@("`@("`@:68@*&ES7V$H)'%U97)Y+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<75E<GD["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!$871A5')E95]S<6PZ.E]L;V%D*"DZ("<@+B`D<75E<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1D
M871A(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2D["B`@("`@("`@:68@
M*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1D871A.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G-E
M="@D9&%T82P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;W5N=',@*&$@<W5B<V5T(&]F*2!T:&4@9&%T871R
M964@=VAI8V@@=V]U;&0@8F4@;&]A9&5D(&EN=&\@=&AE("1?9&%T80H@("`@
M("H@87)R87D@:68@7VQO860H*2!I<R!C86QL960@=VET:"!T:&4@<V%M92!V
M86QU92!O9B`D<F]O="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R;V]T("!7:&EC:"!P;W)T
M:6]N(&]F('1H92!T<F5E('1O(&QO860N($1E9F%U;'1S('1O(&%L;`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@;V8@:70N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!.=6UB97(@;V8@;V)J96-T<PH@("`@("HO"B`@
M("!F=6YC=&EO;B!?8V]U;G0H)')O;W0@/2!$051!5%)%15]23T]4*0H@("`@
M>PH@("`@("`@("1Q=65R>2`]("1T:&ES+3Y?8G5I;&1,;V%D475E<GDH)')O
M;W0L('1R=64L($1!5$%44D5%7T)524Q$7T-/54Y4*3L*("`@("`@("!I9B`H
M:7-?82@D<75E<GDL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1Q=65R>3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1Q=65R
M>2DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L
M.CI?8V]U;G0H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N("AI;G0I)'1H:7,M/E]D
M8BT^9V5T3VYE*"1Q=65R>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D
M<R`H82!S=6)S970@;V8I('1H92!D871A=')E92!I;G1O('1H92`D7V1A=&$@
M87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)')O;W0@("`@("`@("!7:&EC:"!P;W)T
M:6]N(&]F('1H92!T<F5E('1O(&QO860N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!O9B!I="X*("`@("`J
M($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@("`@3&]A9"!A('1R964@<W1A
M<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A;F0@9&ER96-T
M('!A<F5N=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1E9F%U;'1S('1O('-I;F=L92!L979E;"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1O<&5R871I;VX@("`@5'EP92!O9B!Q=65R>2!T;R!B=6EL9`H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M
M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I
M<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD3&]A9%%U97)Y*"1R;V]T
M(#T@1$%40512145?4D]/5"P@)&QO8614<F5E(#T@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&]P97)A=&EO;B`]($1!5$%44D5%7T)5
M24Q$7U-%3$5#5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R
M=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME>2`](&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@
M("`@("`@)'-O<G1E9"`](&9A;'-E.PH@("`@("`@("1W:&5R92`]('-P<FEN
M=&8H)V,N9W)O=7!?=6ED(#T@)7,@)RP@)'1H:7,M/E]D8BT^<75O=&4H)'1H
M:7,M/E]P87)A;7-;)V=R;W5P)UTI*3L*"B`@("`@("`@:68@*"%E;7!T>2@D
M<F]O="D@)B8@)')O;W0@(3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@
M("`D<&%R96YT7W=H97)E(#T@)'1H:7,M/E]B=6EL9%!A<F5N=$ED<R@D<F]O
M="P@)&QO8614<F5E+"`G8RXG*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M<&%R96YT7W=H97)E*2`F)B`A:7-?82@D<&%R96YT7W=H97)E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=VAE<F4@/2!S<')I;G1F*"<E
M<R!!3D0@*"5S*2<L("1W:&5R92P@)'!A<F5N=%]W:&5R92D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?
M;F%M92DI('L*("`@("`@("`@("`@)'=H97)E(#T@<W!R:6YT9B@G)7,@04Y$
M(&$N871T<FEB=71E7VYA;64@/2`E<R`G+"`D=VAE<F4L("1T:&ES+3Y?9&(M
M/G%U;W1E*"1S;W)T8GE?;F%M92DI.PH@("`@("`@("`@("`D<V]R=&5D(#T@
M=')U93L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?
M:V5Y*2D@>PH@("`@("`@("`@("`D=VAE<F4@/2!S<')I;G1F*"<E<R!!3D0@
M82YA='1R:6)U=&5?:V5Y(#T@)7,@)RP@)'=H97)E+"`D=&AI<RT^7V1B+3YQ
M=6]T92@D<V]R=&)Y7VME>2DI.PH@("`@("`@("`@("`D<V]R=&5D(#T@=')U
M93L*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)&]P97)A=&EO;BD@>PH@
M("`@("`@(&-A<V4@1$%40512145?0E5)3$1?0T]53E0Z"B`@("`@("`@("`@
M("1W:&%T(#T@)T-/54Y4*"HI)SL*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1W:&%T(#T@)V,N9&%T871R965?
M:60L(&,N9&%T871R965?;F%M92P@8RYD871A=')E95]P87)E;G1S+"!C+F1A
M=&%T<F5E7V]R9&5R)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'-O<G1E9"D@>PH@("`@("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!C($Q%1E0@2D])3B`E<R!A($].
M("AC+F1A=&%T<F5E7VED(#T@82YD871A=')E95]I9"!/4B!C+F1A=&%T<F5E
M7VYA;64])7,I("<N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U=(
M15)%("5S($=23U50($)9(&,N9&%T871R965?:60L(&,N9&%T871R965?;F%M
M92P@8RYD871A=')E95]P87)E;G1S+"!C+F1A=&%T<F5E7V]R9&5R($]21$52
M($)9(&$N871T<FEB=71E7W9A;'5E("5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=VAA="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&5?871T<FEB=71E<R==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U
M;W1E*"1R;V]T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=VAE
M<F4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1D:7)E8W1I;VX@
M/3T@,2D@/R`G1$530R<@.B`G05-#)RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@
M8R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=H
M870L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=H
M97)E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<75E<GD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@<&%R96YT($E$('-T<FEN9R!F;W(@
M<V5L96-T:6YG('1R965S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1R;V]T("`@("`@5VAI
M8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!L;V%D+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&QO8614<F5E("!,;V%D(&$@=')E92!S=&%R=&EN9R!A="`D
M<F]O="P@;W(@:G5S="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=65S=&5D(&QE=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@<VEN
M9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&IO:6Y?;F%M92!4
M86)L92!J;VEN(&YA;64*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M260@;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD4&%R96YT261S
M*"1R;V]T+"`D;&]A9%1R964@/2!F86QS92P@)&IO:6Y?;F%M92`]("<G*0H@
M("`@>PH@("`@("`@(&EF("AS=')P;W,H)')O;W0L("<Z)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)SHG+"`D<F]O="D[
M"B`@("`@("`@("`@("1R;V]T(#T@87)R87E?<&]P*"1P87)T<RD["B`@("`@
M("`@?0H@("`@("`@("1R;V]T(#T@*'-T<FEN9RDD<F]O=#L*"B`@("`@("`@
M)'%U97)Y(#T@)U-%3$5#5"!D871A=')E95]I9"P@9&%T871R965?<&%R96YT
M<R<@+@H@("`@("`@("`@("`G($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L92==("X*("`@("`@("`@("`@)R!72$5212!D871A=')E95]N86UE(#T@
M/R!!3D0@9W)O=7!?=6ED(#T@/R<@+@H@("`@("`@("`@("`G($]21$52($)9
M(&1A=&%T<F5E7VED)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH)')O;W0L
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=G<F]U
M<"==*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B
M>2!$871A5')E95]S<6PZ.E]B=6EL9%!A<F5N=$ED<R@I.B`G("X@)'%U97)Y
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@
M("`D<F]O="`]("1T:&ES+3Y?9&(M/F=E=$%S<V]C*"1Q=65R>2P@9F%L<V4L
M("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R;V]T+"`G4$5!4E]%<G)O
M<B<I('Q\("%C;W5N="@D<F]O="DI('L*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T*"B`@("`@("`@)'=H97)E(#T@)R<["B`@("`@("`@)&9I
M<G-T7W1I;64@/2!T<G5E.PH@("`@("`@(&9O<F5A8V@@*"1R;V]T(&%S("1O
M8FIE8W1?:60@/3X@)&]B:F5C=%]P87)E;G1S*2!["B`@("`@("`@("`@("1P
M<W1R:6YG(#T@)&]B:F5C=%]P87)E;G1S("X@)SHG("X@)&]B:F5C=%]I9"`N
M("<E)SL*("`@("`@("`@("`@)'!Q=65R>2`]("<G.PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1O8FIE8W1?<&%R96YT<RDI('L*("`@("`@("`@("`@("`@
M("1I9',@/2!S=6)S='(H)&]B:F5C=%]P87)E;G1S+"`Q*3L*("`@("`@("`@
M("`@("`@("1P<75E<GD@/2`G($]2("<@+B`D:F]I;E]N86UE("X@)V1A=&%T
M<F5E7VED($E.("@G("X@<W1R7W)E<&QA8V4H)SHG+"`G+"`G+"`D:61S*2`N
M("<I)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&QO8614<F5E
M*2!["B`@("`@("`@("`@("`@("`D<'%U97)Y("X]("<@3U(@)R`N("1J;VEN
M7VYA;64@+B`G9&%T871R965?<&%R96YT<R`]("<@+B`D=&AI<RT^7V1B+3YQ
M=6]T92AS=6)S='(H)'!S=')I;F<L(#`L("TR*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A)&9I<G-T7W1I;64I('L*("`@("`@("`@("`@
M("`@("1W:&5R92`N/2`G($]2("<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'=H97)E("X]('-P<FEN=&8H)&IO:6Y?;F%M92`N("=D871A=')E95]P
M87)E;G1S($Q)2T4@)7,@3U(@)R`N("1J;VEN7VYA;64@+B`G9&%T871R965?
M:60@/2`E<R5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D8BT^<75O=&4H)'!S=')I;F<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;V)J96-T7VED+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<'%U97)Y*3L*"B`@("`@("`@("`@("1F:7)S=%]T:6UE(#T@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'=H97)E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@3&]A9',@82!S970@;V8@;V)J96-T<R!I9&5N
M=&EF:65D(&)Y('1H96ER('5N:7%U92!)1',L(&%N9"!T:&5I<@H@("`@("H@
M<&%R96YT<RP@:6YT;R!T:&4@)%]D871A(&%R<F%Y+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M8VED<R`@5&AE('5N:7%U92!)1"!O9B!T:&4@;V)J96-T('1O(&QO860L(&]R
M(&%N(&%R<F%Y(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&]B:F5C
M="!I9',N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;&]A9$)Y260H)&-I9',I"B`@("!["B`@("`@("`@+RH@
M36%K92!S=7)E('=E(&AA=F4@86X@87)R87DN("HO"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D8VED<RDI('L*("`@("`@("`@("`@)&-I9',@/2!A<G)A>2@H
M:6YT*21C:61S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!A<G)A
M>5]W86QK*"1C:61S+"`G:6YT=F%L)RD["B`@("`@("`@?0H*("`@("`@("`O
M*B!"86EL(&]U="!N;W<@:68@=&AE<F4G<R!N;W1H:6YG('1O(&QO860N("HO
M"B`@("`@("`@:68@*"%C;W5N="@D8VED<RDI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!$;VXG="!L;V%D(&%N
M>2!T:&%T(&%R92!A;')E861Y(&QO861E9"X@06QS;RP@;6%K92!S=7)E('1H
M870*("`@("`@("`@*B!E=F5R>71H:6YG(&EN('1H92`D:61S(&%R<F%Y('1H
M870@=V4@87)E(&)U:6QD:6YG(&ES(&%N(&EN=&5G97(N("HO"B`@("`@("`@
M)&ED<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-I9',@87,@)&-I
M9"D@>PH@("`@("`@("`@("`O*B!$;R!.3U0@=7-E($1A=&%4<F5E.CIE>&ES
M=',H*2!H97)E.R!T:&%T('=O=6QD(&-A=7-E(&%N"B`@("`@("`@("`@("`J
M(&EN9FEN:71E(&QO;W`N("HO"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]D871A6R1C:61=*2D@>PH@("`@("`@("`@("`@("`@)&ED<UM=(#T@
M*&EN="DD8VED.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!T:&5R92!A<F4@;F]N92!L969T('1O(&QO860L(')E='5R;BX@*B\*
M("`@("`@("!I9B`H(6-O=6YT*"1I9',I*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&EN(#T@87)R87E?<V5A<F-H
M*$1!5$%44D5%7U)/3U0L("1I9',I(#T]/2!F86QS92`_('-P<FEN=&8H)V1A
M=&%T<F5E7VED($E.("@E<RD@04Y$("<L(&EM<&QO9&4H)RP@)RP@)&ED<RDI
M(#H@)R<["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4(&1A=&%T
M<F5E7VED+"!D871A=')E95]P87)E;G1S($923TT@)7,G("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("<@5TA%4D4@)7-G<F]U<%]U:60@/2`E<R<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@)R!/4D1%4B!"62!D871A=')E95]I
M9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1I;BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES+3Y?
M<&%R86US6R=G<F]U<"==*2D["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.E]L;V%D0GE)9"@I.B`G("X@
M)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@("`@("`D<&%R96YT<R`]("1T:&ES+3Y?9&(M/F=E=$%S<V]C*"1Q=65R
M>2D["B`@("`@("`@:68@*&ES7V$H)'!A<F5N=',L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1P87)E;G1S.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)'!A<F5N=',I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DYO="!F;W5N9"XB*2P@;G5L;"P@;G5L
M;"P@;G5L;"P@)T1A=&%4<F5E(&ED<R`G("X@:6UP;&]D92@G+"`G+"`D:61S
M*2`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@)&ED<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'!A<F5N=',@87,@)&-I9"`]
M/B`D<&%R96YT*2!["B`@("`@("`@("`@("1I9'-;*&EN="DD8VED72`]("AI
M;G0I)&-I9#L*"B`@("`@("`@("`@("1P:61S(#T@97AP;&]D92@G.B<L('-U
M8G-T<B@D<&%R96YT+"`Q*2D["B`@("`@("`@("`@(&9O<F5A8V@@*"1P:61S
M(&%S("1P:60I('L*("`@("`@("`@("`@("`@("1P:60@/2`H:6YT*21P:60[
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?9&%T85LD<&ED
M72DI('L*("`@("`@("`@("`@("`@("`@("`D:61S6R1P:61=(#T@)'!I9#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@268@)&ED<R!I<R!E;7!T>2P@=V4@:&%V92!N;W1H:6YG('1O
M(&QO860N("HO"B`@("`@("`@:68@*"%C;W5N="@D:61S*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1Q=65R>2`]
M("=314Q%0U0@9&%T871R965?:60L(&1A=&%T<F5E7VYA;64L(&1A=&%T<F5E
M7W!A<F5N=',L(&1A=&%T<F5E7V]R9&5R)R`N"B`@("`@("`@("`@("`@("`@
M)R!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@
M("`@("`@("`@)R!72$5212!D871A=')E95]I9"!)3B`H/R<@+B!S=')?<F5P
M96%T*"<L(#\G+"!C;W5N="@D:61S*2`M(#$I("X@)RDG("X*("`@("`@("`@
M("`@("`@("`G($%.1"!G<F]U<%]U:60@/2`_($]21$52($)9(&1A=&%T<F5E
M7VED)SL*("`@("`@("`D=F%L=65S(#T@87)R87E?;65R9V4H)&ED<RP@87)R
M87DH)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI*3L*"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.E]L;V%D
M0GE)9"@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9&(M/F=E=$%L
M;"@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1D871A+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<V5T*"1D871A+"`D=&AI
M<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!T<F5E('-O<G1E9"!B>2!T:&4@<W!E8VEF:65D(&%T=')I
M8G5T92!N86UE(&%N9"]O<B!K97DN"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')O;W0@("`@
M("`@("!7:&EC:"!P;W)T:6]N(&]F('1H92!T<F5E('1O('-O<G0N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@86QL
M(&]F(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8614<F5E("`@(%-O
M<G0@=&AE('1R964@<W1A<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=65S=&5D(&QE
M=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@
M=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V]R
M=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@(%-O<G0@9&ER96-T
M:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A
M<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q
M("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713;W)T9614
M<F5E*"1R;V]T+"`D;&]A9%1R964@/2!F86QS92P@)'-O<G1B>5]N86UE(#T@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]K97D@
M/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("`D<75E<GD@
M/2`D=&AI<RT^7V)U:6QD3&]A9%%U97)Y*"1R;V]T+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QO8614<F5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$%40512145?0E5)
M3$1?4T5,14-4+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O<G1B>5]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-O<G1B>5]K97DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&ER96-T:6]N*3L*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D<R!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1O8FIE8W0@("`@("`@(%1H92!O8FIE8W0@=&\@861D("AS
M=')I;F<@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M871A5')E94]B:F5C="DN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:61?87-?
M;F%M92`@5VAE=&AE<B!T:&4@;V)J96-T($E$(&ES('1O(&)E('5S960@87,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0@;F%M
M92X@(%5S960@:6X@<VET=6%T:6]N<R!W:&5R90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H97)E(&ES(&YO(&%V86EL86)L92!U;FEQ
M=64@:6YP=70@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D;V)J
M96-T+"`D:61?87-?;F%M92`](&9A;'-E*0H@("`@>PH@("`@("`@("1A='1R
M:6)U=&5S(#T@9F%L<V4["B`@("`@("`@:68@*&ES7V$H)&]B:F5C="P@)T1A
M=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@)&9U;&QN86UE(#T@)&]B
M:F5C="T^9V5T3F%M92@I.PH@("`@("`@("`@("`D;W)D97(@/2`D;V)J96-T
M+3YO<F1E<CL*"B`@("`@("`@("`@("\J(%=E(&AA;F1L92!D871A(&1I9F9E
M<F5N=&QY(&EF('=E(&-A;B!M87`@:70@=&\@=&AE"B`@("`@("`@("`@("`J
M(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@=&%B;&4N("HO"B`@("`@("`@
M("`@(&EF("AM971H;V1?97AI<W1S*"1O8FIE8W0L("=?=&]!='1R:6)U=&5S
M)RDI('L*("`@("`@("`@("`@("`@("1D871A(#T@)R<["B`@("`@("`@("`@
M("`@("`D<V5R(#T@;G5L;#L*"B`@("`@("`@("`@("`@("`O*B!3970@82!F
M;&%G(&9O<B!L871E<B!S;R!T:&%T('=E(&MN;W<@=&\@:6YS97)T('1H90H@
M("`@("`@("`@("`@("`@("H@871T<FEB=71E(')O=W,N("HO"B`@("`@("`@
M("`@("`@("`D871T<FEB=71E<R`]('1R=64["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<FEA
M;&EZ92YP:'`G.PH@("`@("`@("`@("`@("`@)'-E<B`](%-%4DE!3$E:15]5
M5$8W7T)!4TE#.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!(;W)D95]397)I
M86QI>F4Z.G-E<FEA;&EZ92@D;V)J96-T+3YG971$871A*"DL("1S97(L($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F=6QL;F%M92`]("1O8FIE8W0["B`@("`@("`@
M("`@("1O<F1E<B`](&YU;&P["B`@("`@("`@("`@("1D871A(#T@)R<["B`@
M("`@("`@("`@("1S97(@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1V5T('1H92!N97AT('5N:7%U92!)1"X@*B\*("`@("`@("`D:60@/2`D=&AI
M<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@("`@
M("`@(&EF("AI<U]A*"1I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@D:60L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@
M("!]"@H@("`@("`@(&EF("AS=')P;W,H)&9U;&QN86UE+"`G.B<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)&9U
M;&QN86UE*3L*("`@("`@("`@("`@)'!A<F5N=',@/2`G)SL*("`@("`@("`@
M("`@)'!S=')I;F<@/2`G)SL*("`@("`@("`@("`@:68@*"1I9%]A<U]N86UE
M*2!["B`@("`@("`@("`@("`@("`O*B!297%U97-T960@=7-E(&]F($E$(&%S
M(&YA;64L('-O(&1I<V-A<F0@8W5R<F5N="!N86UE+B`J+PH@("`@("`@("`@
M("`@("`@87)R87E?<&]P*"1P87)T<RD["B`@("`@("`@("`@("`@("`O*B!3
M970@;F%M92!T;R!)1"X@*B\*("`@("`@("`@("`@("`@("1N86UE(#T@)&ED
M.PH@("`@("`@("`@("`@("`@+RH@36]D:69Y(&9U;&QN86UE('1O(')E9FQE
M8W0@;F5W(&YA;64N("HO"B`@("`@("`@("`@("`@("`D9G5L;&YA;64@/2!I
M;7!L;V1E*"<Z)RP@)'!A<G1S*2`N("<Z)R`N("1I9#L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A*"1O8FIE8W0L("=$871A5')E94]B:F5C="<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&]B:F5C="T^<V5T3F%M92@D9G5L;&YA;64I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D;V)J96-T(#T@)&9U;&QN86UE.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YA;64@/2!A<G)A
M>5]P;W`H)'!A<G1S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E
M86-H("@D<&%R=',@87,@)'!A<BD@>PH@("`@("`@("`@("`@("`@)'!S=')I
M;F<@+CT@*&5M<'1Y*"1P<W1R:6YG*2`_("<G(#H@)SHG*2`N("1P87(["B`@
M("`@("`@("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=$ED*"1P<W1R:6YG*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("`O*B!!=71O+6-R96%T92!P87)E;G1S
M+B`J+PH@("`@("`@("`@("`@("`@("`@("1P:60@/2`D=&AI<RT^861D*"1P
M<W1R:6YG*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<&ED+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<&ED.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1P87)E;G1S("X]("<Z)R`N("1P:60["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H
M)&ED7V%S7VYA;64I('L*("`@("`@("`@("`@("`@("\J(%)E<75E<W1E9"!U
M<V4@;V8@240@87,@;F%M92P@<V5T(&9U;&QN86UE(&%N9"!N86UE('1O($E$
M+B`J+PH@("`@("`@("`@("`@("`@)&9U;&QN86UE(#T@)&ED.PH@("`@("`@
M("`@("`@("`@)&YA;64@/2`D:60["B`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1O8FIE8W0M/G-E=$YA;64H)&9U;&QN86UE*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&]B:F5C="`]
M("1F=6QL;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1N86UE(#T@)&9U;&QN86UE.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1P87)E;G1S(#T@)R<["B`@("`@("`@
M("`@("1P:60@/2!$051!5%)%15]23T]4.PH@("`@("`@('T*"B`@("`@("`@
M:68@*'!A<F5N=#HZ97AI<W1S*"1F=6QL;F%M92DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B06QR96%D>2!E>&ES=',B*2D[
M"B`@("`@("`@?0H*("`@("`@("`D<75E<GD@/2`G24Y315)4($E.5$\@)R`N
M("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G
M("AD871A=')E95]I9"P@9W)O=7!?=6ED+"!D871A=')E95]N86UE+"!D871A
M=')E95]O<F1E<BPG("X*("`@("`@("`@("`@("`@("`G(&1A=&%T<F5E7V1A
M=&$L('5S97)?=6ED+"!D871A=')E95]S97)I86QI>F5D+"<@+@H@("`@("`@
M("`@("`@("`@("<@9&%T871R965?<&%R96YT<RDG("X*("`@("`@("`@("`@
M("`@("`G(%9!3%5%4R`H/RP@/RP@/RP@/RP@/RP@/RP@/RP@/RDG.PH@("`@
M("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21I9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&YA;64L($Y,
M4SHZ9V5T0VAA<G-E="@I+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@:7-?;G5L;"@D;W)D97(I(#\@3E5,
M3"`Z("AI;G0I)&]R9&5R+`H@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M82P*("`@("`@("`@("`@("`@("`@("`@("`@*'-T<FEN9RE!=71H.CIG971!
M=71H*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("AI;G0I)'-E<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F5N=',I.PH*("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ861D
M*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D
M<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("1R96]R9&5R(#T@)'1H:7,M/G)E;W)D97(H)'!A<F5N=',L("1O<F1E<BP@
M)&ED*3L*("`@("`@("!I9B`H:7-?82@D<F5O<F1E<BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5O<F1E<BP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@)')E;W)D97(["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@<&%R96YT.CI?861D*"1F=6QL;F%M92P@)&ED+"`D<&ED+"`D;W)D97(I
M.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!W92!S=6-C97-F=6QL>2!I;G-E<G1E9"!T:&4@;V)J96-T(&%N
M9"!I="!S=7!P;W)T<PH@("`@("`@("`J(&)E:6YG(&UA<'!E9"!T;R!T:&4@
M871T<FEB=71E<R!T86)L92P@9&\@=&AA="!N;W<Z("HO"B`@("`@("`@:68@
M*"%E;7!T>2@D871T<FEB=71E<RDI('L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YU<&1A=&5$871A*"1O8FIE8W0I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I9#L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG
M97,@=&AE(&]R9&5R(&]F('1H92!C:&EL9')E;B!O9B!A;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9G5L;"!I
M9"!P871H(&]F('1H92!P87)E;G0@;V)J96-T+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1O<F1E<B`@("!)9B!A;B!A<G)A>2!I="!S<&5C:69I97,@=&AE(&YE
M=R!P;W-I=&EO;G,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M(&%L;"!C:&EL9"!O8FIE8W1S+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!)9B!A;B!I;G1E9V5R(&%N9"`D8VED(&ES('-P96-I9FEE9"P@=&AE
M('!O<VET:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('=H97)E
M('1H92!C:&EL9"!S<&5C:69I960@8GD@)&-I9"!I<R!I;G-E<G1E9"X@268*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)&-I9"!I<R!N;W0@<W!E
M8VEF:65D+"!T:&4@<&]S:71I;VX@9V5T<R!D96QE=&5D+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!C875S:6YG('1H92!F;VQL;W=I;F<@<&]S
M:71I;VYS('1O('-H:69T('5P+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I
M9"`@("!3964@)&]R9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96]R9&5R
M*"1P87)E;G0L("1O<F1E<B`](&YU;&PL("1C:60@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@A)'!A<F5N="!\?"!I<U]A*"1P87)E;G0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@+R\@06)O<G0@:6UM961I871E;'D@:68@
M=&AE('!A<F5N="!S=')I;F<@:7,@96UP='D[('=E"B`@("`@("`@("`@("\O
M(&-A;FYO="!S869E;'D@<F5O<F1E<B!A;&P@=&]P+6QE=F5L(&5L96UE;G1S
M+@H@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D<'%U
M97)Y(#T@)R<["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;W)D97(I("8F("%I
M<U]N=6QL*"1O<F1E<BDI('L*("`@("`@("`@("`@+RH@4VEN9VQE('5P9&%T
M92`H861D+V1E;"DN("HO"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C:60I
M*2!["B`@("`@("`@("`@("`@("`O*B!.;R!O8FIE8W0@:60@9VEV96X@<V\@
M<VAU9F9L92!D;W=N+B`J+PH@("`@("`@("`@("`@("`@)&1I<F5C=&EO;B`]
M("<M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J
M(%=E(&AA=F4@86X@;V)J96-T(&ED('-O('-H=69F;&4@=7`N("HO"B`@("`@
M("`@("`@("`@("`D9&ER96-T:6]N(#T@)RLG.PH*("`@("`@("`@("`@("`@
M("\J($QE879I;F<@=&AE(&YE=VQY(&EN<V5R=&5D(&]B:F5C="!A;&]N92X@
M*B\*("`@("`@("`@("`@("`@("1P<75E<GD@/2!S<')I;G1F*"<@04Y$(&1A
M=&%T<F5E7VED("$]("5S)RP@*&EN="DD8VED*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=54$1!5$4@)7,@4T54(&1A
M=&%T<F5E7V]R9&5R(#T@9&%T871R965?;W)D97(@)7,@,2!72$5212!G<F]U
M<%]U:60@/2`E<R!!3D0@9&%T871R965?<&%R96YT<R`]("5S($%.1"!D871A
M=')E95]O<F1E<B`^/2`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1I<F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^7W!A<F%M<ULG9W)O
M=7`G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M8BT^<75O=&4H)'!A<F5N="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:7-?;G5L;"@D;W)D97(I(#\@)TY53$PG(#H@*&EN="DD;W)D97(I("X@
M)'!Q=65R>3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@
M475E<GD@8GD@1&%T851R965?<W%L.CIR96]R9&5R*"DZ("<@+B`D<75E<GDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@
M("`@("!](&5L<V5I9B`H:7-?87)R87DH)&]R9&5R*2D@>PH@("`@("`@("`@
M("`O*B!-=6QT:2!U<&1A=&4N("HO"B`@("`@("`@("`@("1Q=65R>2`]("=3
M14Q%0U0@0T]53E0H9&%T871R965?:60I)R`N"B`@("`@("`@("`@("`@("`@
M("`@("<@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@
M("`@("`@("`@("`@("`@("`G(%=(15)%(&=R;W5P7W5I9"`](#\@04Y$(&1A
M=&%T<F5E7W!A<F5N=',@/2`_)R`N"B`@("`@("`@("`@("`@("`@("`@("<@
M1U)/55`@0ED@9&%T871R965?<&%R96YT<R<["B`@("`@("`@("`@("1V86QU
M97,@/2!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)E;G0I.PH*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E
M;W)D97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!](&5L<V5I9B`H8V]U;G0H
M)&]R9&5R*2`A/2`D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R('-T;W)E9"XB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1O7VME>2`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1O<F1E<B!A<R`D
M;U]C:60I('L*("`@("`@("`@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N
M("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("<@4T54(&1A=&%T<F5E7V]R9&5R(#T@/R!72$5212!D871A=')E
M95]I9"`](#\G.PH@("`@("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1O
M7VME>2P@:7-?;G5L;"@D;U]C:60I(#\@3E5,3"`Z("AI;G0I)&]?8VED*3L*
M"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($1A=&%4<F5E7W-Q;#HZ<F5O<F1E<B@I.B`G("X@)'%U97)Y+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU
M97,I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1O7VME>2LK
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&ED(#T@)'1H:7,M/F=E
M=$ED*"1P87)E;G0I.PH*("`@("`@("`@("`@+RH@4F4M;W)D97(@;W5R(&-A
M8VAE+B`J+PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R96]R9&5R*"1P
M:60L("1O<F1E<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M17AP;&EC:71L>2!S970@=&AE(&]R9&5R(&9O<B!A(&1A=&%T<F5E(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@(%1H92!D
M871A=')E92!O8FIE8W0@:60@=&\@8VAA;F=E+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&]R9&5R("!4:&4@;F5W(&]R9&5R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971/<F1E<B@D:60L("1O<F1E<BD*("`@('L*("`@("`@("`D<75E
M<GD@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@
M("`@("`@("`@("`@("`@)R!3150@9&%T871R965?;W)D97(@/2`_(%=(15)%
M(&1A=&%T<F5E7VED(#T@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*&ES
M7VYU;&PH)&]R9&5R*2`_($Y53$P@.B`H:6YT*21O<F1E<BP*("`@("`@("`@
M("`@("`@("`@("`@("`@*&EN="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<V5T3W)D97(H
M*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&%N
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("`D;V)J96-T
M("!4:&4@;V)J96-T('1O(')E;6]V92X*("`@("`J($!P87)A;2!B;V]L96%N
M("1F;W)C92`@($9O<F-E(')E;6]V86P@;V8@979E<GD@8VAI;&0@;V)J96-T
M/PH@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F4H)&]B:F5C="P@)&9O<F-E
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1O
M8FIE8W0I.PH@("`@("`@("1O<F1E<B`]("1T:&ES+3YG971/<F1E<B@D;V)J
M96-T*3L*"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!D871A=')E95]I9"!&
M4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@
M("`@("`@)R!72$5212!G<F]U<%]U:60@/2`_($%.1"!D871A=')E95]P87)E
M;G1S($Q)2T4@/R<@+@H@("`@("`@("`@("`@("`@("<@3U)$15(@0ED@9&%T
M871R965?:60G.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^7W!A
M<F%M<ULG9W)O=7`G72P*("`@("`@("`@("`@("`@("`@("`@("`@)R4Z)R`N
M("AI;G0I)&ED("X@)R<I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E*"DZ("<@+B`D<75E
M<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@("1C:&EL9')E;B`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL("1V
M86QU97,L($1"7T9%5$-(34]$15]!4U-/0RD["@H@("`@("`@(&EF("AC;W5N
M="@D8VAI;&1R96XI*2!["B`@("`@("`@("`@(&EF("@D9F]R8V4I('L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1C:&EL9')E;B!A<R`D8VAI;&0I('L*
M("`@("`@("`@("`@("`@("`@("`D8V%T(#T@)'1H:7,M/F=E=$YA;64H)&-H
M:6QD6R=D871A=')E95]I9"==*3L*("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/G)E;6]V92@D8V%T+"!T<G5E*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(BDL(&-O=6YT*"1C:&EL9')E;BDI*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@4F5M;W9E(&%T=')I8G5T97,@9F]R('1H:7,@
M;V)J96-T+B`J+PH@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@("`@("`@
M("`@("`@("`@)R!72$5212!D871A=')E95]I9"`](#\G.PH@("`@("`@("1V
M86QU97,@/2!A<G)A>2@H:6YT*21I9"D["@H@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIR96UO=F4H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@
M9&%T871R965?:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH*&EN
M="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<&%R
M96YT<R`]("1T:&ES+3YG971087)E;G1)9%-T<FEN9R@D;V)J96-T*3L*("`@
M("`@("!I9B`H:7-?82@D<&%R96YT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'!A<F5N=',["B`@("`@("`@?0H*("`@("`@("`D
M<F5O<F1E<B`]("1T:&ES+3YR96]R9&5R*"1P87)E;G1S+"`D;W)D97(I.PH@
M("`@("`@(&EF("AI<U]A*"1R96]R9&5R+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5O<F1E<CL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!I<U]A*'!A<F5N=#HZ<F5M;W9E*"1O8FIE8W0I+"`G4$5!4E]%
M<G)O<B<I(#\@)&ED(#H@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;6]V97,@;VYE(&]R(&UO<F4@;V)J96-T<R!B>2!I9"X*("`@("`J"B`@("`@
M*B!4:&ES(&9U;F-T:6]N(&1O97,@*FYO="H@9&\@=&AE('9A;&ED871I;VXL
M(')E;W)D97)I;F<L(&5T8RX@=&AA=`H@("`@("H@<F5M;W9E*"D@9&]E<RX@
M268@>6]U(&YE960@=&\@8VAE8VL@9F]R(&-H:6QD<F5N+"!R92UD;R!O<F1E
M<FEN9RP@971C+BP*("`@("`J('1H96X@>6]U(&UU<W0@<F5M;W9E*"D@;V)J
M96-T<R!O;F4M8GDM;VYE+B!4:&ES(&ES(&9O<B!C;V1E('1H870@:VYO=W,*
M("`@("`J(&ET)W,@9&5A;&EN9R!W:71H('-I;F=L92`H;F]N+7!A<F5N=&5D
M*2!O8FIE8W1S(&%N9"!N965D<R!T;R!D96QE=&4@80H@("`@("H@8F%T8V@@
M;V8@=&AE;2!Q=6EC:VQY+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M:61S("!4:&4@;V)J96-T<R!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;6]V94)Y261S*"1I9',I"B`@("!["B`@("`@("`@+RH@4V%N:71I
M>F4@:6YP=70N("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:61S*2D@>PH@
M("`@("`@("`@("`D:61S(#T@87)R87DH*&EN="DD:61S*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!A<G)A>5]W86QK*"1I9',L("=I;G1V86PG
M*3L*("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V:6YG('IE<F\@;V)J96-T
M<R!A;'=A>7,@<W5C8V5E9',N("HO"B`@("`@("`@:68@*"$D:61S*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M4F5M;W9E(&%T=')I8G5T97,@9F]R("1I9',N("HO"B`@("`@("`@)'%U97)Y
M(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&5?871T
M<FEB=71E<R==("X*("`@("`@("`@("`@("`@("`G(%=(15)%(&1A=&%T<F5E
M7VED($E.("@_)R`N('-T<E]R97!E870H)RP@/R<L(&-O=6YT*"1I9',I("T@
M,2D@+B`G*2<["B`@("`@("`@)'9A;'5E<R`]("1I9',["@H@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIR
M96UO=F5">4ED<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&
M4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@
M("`@("`@)R!72$5212!D871A=')E95]I9"!)3B`H/R<@+B!S=')?<F5P96%T
M*"<L(#\G+"!C;W5N="@D:61S*2`M(#$I("X@)RDG.PH@("`@("`@("1V86QU
M97,@/2`D:61S.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U
M97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E0GE)9',H*3H@)R`N("1Q=65R
M>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&]N92!O<B!M;W)E(&]B
M:F5C=',@8GD@;F%M92X*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T:6]N(&1O
M97,@*FYO="H@9&\@=&AE('9A;&ED871I;VXL(')E;W)D97)I;F<L(&5T8RX@
M=&AA=`H@("`@("H@<F5M;W9E*"D@9&]E<RX@268@>6]U(&YE960@=&\@8VAE
M8VL@9F]R(&-H:6QD<F5N+"!R92UD;R!O<F1E<FEN9RP@971C+BP*("`@("`J
M('1H96X@>6]U(&UU<W0@<F5M;W9E*"D@;V)J96-T<R!O;F4M8GDM;VYE+B!4
M:&ES(&ES(&9O<B!C;V1E('1H870@:VYO=W,*("`@("`J(&ET)W,@9&5A;&EN
M9R!W:71H('-I;F=L92`H;F]N+7!A<F5N=&5D*2!O8FIE8W1S(&%N9"!N965D
M<R!T;R!D96QE=&4@80H@("`@("H@8F%T8V@@;V8@=&AE;2!Q=6EC:VQY+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;F%M97,@(%1H92!O8FIE8W1S
M('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0GE.86UE
M<R@D;F%M97,I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;F%M97,I
M*2!["B`@("`@("`@("`@("1N86UE<R`](&%R<F%Y*"1N86UE<RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!296UO=FEN9R!Z97)O(&]B:F5C=',@86QW87ES
M('-U8V-E961S+B`J+PH@("`@("`@(&EF("@A)&YA;65S*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@
M)U-%3$5#5"!D871A=')E95]I9"!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]N
M86UE($E.("@_)R`N('-T<E]R97!E870H)RP@/R<L(&-O=6YT*"1N86UE<RD@
M+2`Q*2`N("<I)SL*("`@("`@("`D=F%L=65S(#T@)&YA;65S.PH*("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q
M;#HZ<F5M;W9E0GE.86UE<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D:61S(#T@)'1H:7,M
M/E]D8BT^9V5T0V]L*"1Q=65R>2P@,"P@)'9A;'5E<RD["B`@("`@("`@:68@
M*&ES7V$H)&ED<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&ED<SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<F5M
M;W9E0GE)9',H)&ED<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E(&%N
M(&]B:F5C="!T;R!A(&YE=R!P87)E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("`D;V)J96-T("`@("!4:&4@;V)J96-T('1O(&UO=F4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N97=P87)E;G0@(%1H92!N97<@<&%R96YT(&]B
M:F5C="X@1&5F875L=',@=&\@=&AE(')O;W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO=F4H)&]B:F5C="P@)&YE=W!A<F5N="`](&YU;&PI"B`@("!["B`@
M("`@("`@)&]L9%]P87)E;G1?<&%T:"`]("1T:&ES+3YG971087)E;G1)9%-T
M<FEN9R@D;V)J96-T*3L*("`@("`@("`D<F5S=6QT(#T@<&%R96YT.CIM;W9E
M*"1O8FIE8W0L("1N97=P87)E;G0I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H@("`@("`@("1I9"`]("1T:&ES+3YG971)9"@D;V)J
M96-T*3L*("`@("`@("`D;F5W7W!A<F5N=%]P871H(#T@)'1H:7,M/F=E=%!A
M<F5N=$ED4W1R:6YG*"1O8FIE8W0I.PH*("`@("`@("`O*B!&971C:"!T:&4@
M;V)J96-T(&)E:6YG(&UO=F5D(&%N9"!A;&P@;V8@:71S(&-H:6QD<F5N+"!S
M:6YC90H@("`@("`@("`J('=E(&%L<V\@;F5E9"!T;R!U<&1A=&4@=&AE:7(@
M<&%R96YT('!A=&AS('1O(&%V;VED(&-R96%T:6YG"B`@("`@("`@("H@;W)P
M:&%N<RX@*B\*("`@("`@("`D<75E<GD@/2`G4T5,14-4(&1A=&%T<F5E7VED
M+"!D871A=')E95]P87)E;G1S)R`N"B`@("`@("`@("`@("`@("`@)R!&4D]-
M("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@
M("`@)R!72$5212!D871A=')E95]P87)E;G1S(#T@/R!/4B!D871A=')E95]P
M87)E;G1S($Q)2T4@/R<@+@H@("`@("`@("`@("`@("`@("<@3U(@9&%T871R
M965?:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH)&]L9%]P87)E
M;G1?<&%T:"`N("<Z)R`N("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]L9%]P87)E;G1?<&%T:"`N("<Z)R`N("1I9"`N("<Z)2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("AI;G0I)&ED*3L*"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.FUO=F4H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@)')O=W-E="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')O=W-E="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')O=W-E=#L*("`@("`@
M("!]"@H@("`@("`@("\J(%5P9&%T92!E86-H(&]B:F5C="P@<F5P;&%C:6YG
M('1H92!O;&0@<&%R96YT('!A=&@@=VET:"!T:&4*("`@("`@("`@*B!N97<@
M;VYE+B`J+PH@("`@("`@('=H:6QE("@D<F]W(#T@)')O=W-E="T^9F5T8VA2
M;W<H1$)?1D540TA-3T1%7T%34T]#*2D@>PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F]W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')O=SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]Q=65R>2`]
M("<G.PH@("`@("`@("`@("!I9B`H)')O=ULG9&%T871R965?:60G72`]/2`D
M:60I('L*("`@("`@("`@("`@("`@("1O<75E<GD@/2`G+"!D871A=')E95]O
M<F1E<B`](#`@)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@1&\@
M<W1R7W)E<&QA8V4H*2!O;FQY(&EF('1H:7,@:7,@;F]T(&$@9FER<W0@;&5V
M96P*("`@("`@("`@("`@("H@;V)J96-T+B`J+PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1R;W=;)V1A=&%T<F5E7W!A<F5N=',G72DI('L*("`@("`@("`@
M("`@("`@("1P<&%T:"`]('-T<E]R97!L86-E*"1O;&1?<&%R96YT7W!A=&@L
M("1N97=?<&%R96YT7W!A=&@L("1R;W=;)V1A=&%T<F5E7W!A<F5N=',G72D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<'!A=&@@
M/2`D;F5W7W!A<F5N=%]P871H.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@9&%T871R965?<&%R
M96YT<R`]("5S)R`N("1O<75E<GD@+B`G(%=(15)%(&1A=&%T<F5E7VED(#T@
M)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&(M/G%U;W1E*"1P<&%T:"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*&EN="DD<F]W6R=D871A=')E95]I9"==*3L*"B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?
M<W%L.CIM;W9E*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1O
M<F1E<B`]("1T:&ES+3YG971/<F1E<B@D;V)J96-T*3L*"B`@("`@("`@+RH@
M4VAU9F9L92!D;W=N('1H92!O;&0@;W)D97(@<&]S:71I;VYS+B`J+PH@("`@
M("`@("1R96]R9&5R(#T@)'1H:7,M/G)E;W)D97(H)&]L9%]P87)E;G1?<&%T
M:"P@)&]R9&5R*3L*"B`@("`@("`@+RH@4VAU9F9L92!U<"!T:&4@;F5W(&]R
M9&5R('!O<VET:6]N<RX@*B\*("`@("`@("`D<F5O<F1E<B`]("1T:&ES+3YR
M96]R9&5R*"1N97=?<&%R96YT7W!A=&@L(#`L("1I9"D["@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E(&%N(&]B
M:F5C="=S(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;VQD
M7V]B:F5C="`@("`@("!4:&4@;VQD(&]B:F5C="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YE=U]O8FIE8W1?;F%M92`@5&AE(&YE=R!O8FIE8W0@;F%M92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE*"1O;&1?;V)J96-T+"`D;F5W
M7V]B:F5C=%]N86UE*0H@("`@>PH@("`@("`@("\J($1O('1H92!C86-H92!R
M96YA;6EN9R!F:7)S="`J+PH@("`@("`@("1R97-U;'0@/2!P87)E;G0Z.G)E
M;F%M92@D;VQD7V]B:F5C="P@)&YE=U]O8FIE8W1?;F%M92D["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T
M:&4@;V)J96-T(&ED(&%N9"!S970@=7`@=&AE('-Q;"!Q=65R>2X@*B\*("`@
M("`@("`D:60@/2`D=&AI<RT^9V5T260H)&]L9%]O8FIE8W0I.PH@("`@("`@
M("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==
M("X*("`@("`@("`@("`@("`@("`G(%-%5"!D871A=')E95]N86UE(#T@/R!7
M2$5212!D871A=')E95]I9"`](#\G.PH@("`@("`@("1V86QU97,@/2!A<G)A
M>2A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1N97=?;V)J96-T7VYA;64L($Y,
M4SHZ9V5T0VAA<G-E="@I+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD:60I.PH*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ
M<F5N86UE*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("!R971U<FX@:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I(#\@)')E<W5L="`Z('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@9&%T82!F;W(@86X@;V)J96-T
M(&9R;VT@=&AE(&1A=&%T<F5E7V1A=&$@9FEE;&0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE(&]B:F5C="!I9"!T;R!F971C:"P@
M;W(@86X@87)R87D@;V8@;V)J96-T(&ED<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1&%T82@D8VED*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4V5R:6%L:7IE+G!H<"<["@H@("`@("`@(&EF("AI<U]A<G)A>2@D
M8VED*2D@>PH@("`@("`@("`@("!I9B`H(6-O=6YT*"1C:60I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4(&1A=&%T<F5E7VED
M+"!D871A=')E95]D871A+"!D871A=')E95]S97)I86QI>F5D($923TT@)7,@
M5TA%4D4@9&%T871R965?:60@24X@*"5S*2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D8VED*2D["@H@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A
M=&%4<F5E7W-Q;#HZ9V5T1&%T82@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/F=E=$%S<V]C*"1Q=65R>2D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9&%T82`]
M(&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@87,@)&ED
M(#T^("1R;W<I('L*("`@("`@("`@("`@("`@("1D871A6R1I9%T@/2!(;W)D
M95]397)I86QI>F4Z.G5N<V5R:6%L:7IE*"1R;W=;,%TL("1R;W=;,5TL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("`@
M("`O*B!#;VYV97)T(&]L9"!D871A('1O('1H92!N97<@9F]R;6%T+B`J+PH@
M("`@("`@("`@("`@("`@:68@*"1R;W=;,5T@/3T@4T5224%,25I%7T)!4TE#
M*2!["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)&ED72`](%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)&1A=&%;)&ED72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.3%,Z.F=E
M=$-H87)S970H=')U92DI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1D871A6R1I9%T@/2`H:7-?;G5L;"@D9&%T85LD:61=*2!\?"`A
M:7-?87)R87DH)&1A=&%;)&ED72DI"B`@("`@("`@("`@("`@("`@("`@/R!A
M<G)A>2@I"B`@("`@("`@("`@("`@("`@("`@.B`D9&%T85LD:61=.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!D871A=')E
M95]D871A+"!D871A=')E95]S97)I86QI>F5D)R`N"B`@("`@("`@("`@("`@
M("`@("`@("<@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@
M("`@("`@("`@("`@("`@("`@("`G(%=(15)%(&1A=&%T<F5E7VED(#T@/R<[
M"B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21C:60I.PH*("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A
M5')E95]S<6PZ.F=E=$1A=&$H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("1R;W<@/2`D
M=&AI<RT^7V1B+3YG9712;W<H)'%U97)Y+"`D=F%L=65S+"!$0E]&151#2$U/
M1$5?05-33T,I.PH*("`@("`@("`@("`@)&1A=&$@/2!(;W)D95]397)I86QI
M>F4Z.G5N<V5R:6%L:7IE*"1R;W=;)V1A=&%T<F5E7V1A=&$G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M;W=;)V1A=&%T<F5E7W-E<FEA;&EZ960G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E
M="@I*3L*("`@("`@("`@("`@+RH@0V]N=F5R="!O;&0@9&%T82!T;R!T:&4@
M;F5W(&9O<FUA="X@*B\*("`@("`@("`@("`@:68@*"1R;W=;)V1A=&%T<F5E
M7W-E<FEA;&EZ960G72`]/2!315))04Q)6D5?0D%324,I('L*("`@("`@("`@
M("`@("`@("1D871A(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&%T82P@
M3DQ3.CIG971#:&%R<V5T*'1R=64I*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@*&ES7VYU;&PH)&1A=&$I('Q\("%I<U]A<G)A>2@D9&%T
M82DI(#\@87)R87DH*2`Z("1D871A.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E<R!D871A(&9O<B!A;B!O8FIE8W0@9G)O;2!T
M:&4@:&]R9&5?9&%T871R965?871T<FEB=71E<R!T86)L92X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<GQA<G)A>2`D8VED("!4:&4@;V)J96-T(&ED
M('1O(&9E=&-H+"!O<B!A;B!A<G)A>2!O9@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;V)J96-T(&ED<RX*("`@("`J($!P87)A;2!A<G)A
M>2`D:V5Y<R`@("`@("`@(%1H92!A='1R:6)U=&5S(&ME>7,@=&\@9F5T8V@N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H(&]F(&%T=')I
M8G5T97,L(&]R(&$@;75L=&DM;&5V96P@:&%S:"!O9B!O8FIE8W0*("`@("`J
M("`@("`@("`@("`@("`@(&ED<R`]/B!T:&5I<B!A='1R:6)U=&5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5S*"1C:60L("1K97ES(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1C:60I*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1K97ES*2!["B`@("`@("`@("`@("1F:6QT97(@/2!S<')I;G1F*"<@04Y$
M(&%T=')I8G5T95]K97D@24X@*%PG)7-<)RDG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I;7!L;V1E*"(G+"`G(BP@)&ME>7,I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL=&5R(#T@)R<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-?87)R87DH)&-I9"DI('L*("`@("`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4(&1A=&%T<F5E7VED+"!A='1R:6)U
M=&5?;F%M92!!4R!N86UE+"!A='1R:6)U=&5?:V5Y($%3(")K97DB+"!A='1R
M:6)U=&5?=F%L=64@05,@=F%L=64@1E)/32`E<R!72$5212!D871A=')E95]I
M9"!)3B`H)7,I)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D8VED*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9FEL=&5R*3L*"B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L
M.CIG971!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F]W<R`]("1T
M:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL($1"7T9%5$-(34]$15]!4U-/0RD[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R;W=S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')O=W,["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)')O=W,@87,@)')O=RD@>PH@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1D871A6R1R;W=;)V1A=&%T<F5E7VED)UU=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1D871A6R1R;W=;)V1A=&%T<F5E7VED)UU=(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D871A6R1R
M;W=;)V1A=&%T<F5E7VED)UU=6UT@/2!A<G)A>2@G;F%M92<@/3X@)')O=ULG
M;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=K97DG(#T^("1R;W=;)VME>2==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=V86QU92<@/3X@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D<F]W6R=V86QU
M92==+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==+"!.3%,Z.F=E=$-H87)S
M970H*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9&%T
M83L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"=314Q%0U0@871T<FEB=71E7VYA;64@05,@;F%M92P@871T<FEB=71E
M7VME>2!!4R`B:V5Y(BP@871T<FEB=71E7W9A;'5E($%3('9A;'5E($923TT@
M)7,@5TA%4D4@9&%T871R965?:60@/2`E<R5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&5?871T<FEB=71E
M<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AI;G0I)&-I9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL=&5R*3L*"B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R
M965?<W%L.CIG971!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F]W
M<R`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL($1"7T9%5$-(34]$15]!
M4U-/0RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1R
M;W=S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)')O=W-;)&E=6R=V86QU
M92==(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D<F]W<ULD:5U;)W9A;'5E
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)')O=W,["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(&]B:F5C
M=',@;6%T8VAI;F<@82!S970@;V8@871T<FEB=71E(&-R:71E<FEA+@H@("`@
M("H*("`@("`J($!S964@8G5I;&1!='1R:6)U=&51=65R>2@I"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R:71E<FEA("`@5&AE(&%R<F%Y(&]F
M(&-R:71E<FEA+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@
M5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@4F5T=7)N(&%L;"!L979E
M;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@
M86QL(&QE=F5L<RX*("`@("`J($!P87)A;2!S=')I;F<@("1R97-T<FEC="`@
M($]N;'D@<F5T=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@;W(@
M871T<FEB=71E7VED+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=$)Y071T
M<FEB=71E<R@D8W)I=&5R:6$L("1P87)E;G0@/2!$051!5%)%15]23T]4+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L;$QE=F5L<R`]('1R
M=64L("1R97-T<FEC="`]("=N86UE)RD*("`@('L*("`@("`@("!I9B`H(6-O
M=6YT*"1C<FET97)I82DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@
M("`@?0H*("`@("`@("`D87$@/2`D=&AI<RT^8G5I;&1!='1R:6)U=&51=65R
M>2@D8W)I=&5R:6$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F5N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D86QL3&5V96QS+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1R97-T<FEC="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$051!5%)%15]"54E,1%]#
M3U5.5"D["B`@("`@("`@:68@*&ES7V$H)&%Q+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D87$["B`@("`@("`@?0H@("`@("`@(&QI
M<W0H)'%U97)Y+"`D=F%L=65S*2`]("1A<3L*"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F-O=6YT0GE!
M='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H@("`@("`@("1R;W<@/2`F)')E<W5L="T^9F5T8VA2;W<H*3L*("`@("`@
M("!I9B`H:7-?82@D<F]W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"1R;W<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1R;W<["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')O=ULP73L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!S970@;V8@;V)J96-T(&ED<R!B87-E9"!O;B!A
M('-E="!O9B!A='1R:6)U=&4@8W)I=&5R:6$N"B`@("`@*@H@("`@("H@0'-E
M92!B=6EL9$%T=')I8G5T95%U97)Y*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@("`D8W)I=&5R:6$@("`@(%1H92!A<G)A>2!O9B!C<FET97)I82X*
M("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("`@5&AE('!A<F5N
M="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%L;$QE=F5L<R`@("!2971U<FX@86QL(&QE=F5L<RP@;W(@
M:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;"!L
M979E;',N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S=')I8W0@("`@($]N
M;'D@<F5T=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&5?;F%M92!O<B!A
M='1R:6)U=&5?:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;2`@("`@
M("`@(%1H92!O8FIE8W0@=&\@<W1A<G0@=&\@9F5T8VAI;F<*("`@("`J($!P
M87)A;2!I;G1E9V5R("1C;W5N="`@("`@("`@5&AE(&YU;6)E<B!O9B!O8FIE
M8W1S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA
M;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J
M($!P87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T
M;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER
M96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G971">4%T=')I8G5T97,H)&-R:71E<FEA+"`D
M<&%R96YT(#T@1$%40512145?4D]/5"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D86QL3&5V96QS(#T@=')U92P@)')E<W1R:6-T(#T@)VYA;64G
M+"`D9G)O;2`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M=6YT(#T@,"P@)'-O<G1B>5]N86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@
M/2`P*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&-R:71E<FEA*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F\@8W)I=&5R
M:6$G*3L*("`@("`@("!]"@H@("`@("`@("1A<2`]("1T:&ES+3YB=6EL9$%T
M=')I8G5T95%U97)Y*"1C<FET97)I82P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R96YT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A;&Q,979E;',L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W1R:6-T+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1!5$%4
M4D5%7T)524Q$7U-%3$5#5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]K97DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO;BD[
M"B`@("`@("`@:68@*&ES7V$H)&%Q+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D87$["B`@("`@("`@?0H@("`@("`@(&QI<W0H)'%U
M97)Y+"`D=F%L=65S*2`]("1A<3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$)Y071T<FEB=71E
M<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@:68@*"1C;W5N="D@>PH@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^;&EM:711=65R>2@D<75E<GDL("1F<F]M
M+"`D8V]U;G0L("1V86QU97,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU
M97,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D
M<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("`D
M<F]W<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*"1R;W<@/2`F)')E<W5L
M="T^9F5T8VA2;W<H*2D@>PH@("`@("`@("`@("`D<F]W<ULD<F]W6S!=72`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')O=ULQ72P@)'1H:7,M/E]P87)A
M;7-;)V-H87)S970G72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')O
M=W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T<R!)1',@8GD@871T<FEB
M=71E('9A;'5E<RX@241S('=I=&AO=70@871T<FEB=71E<R!W:6QL(&)E(&%D
M9&5D('1O"B`@("`@*B!T:&4@96YD(&]F('1H92!S;W)T960@;&ES="X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'5N;W)D97)E9%]I9',@($%R<F%Y
M(&]F(&ED<R!T;R!S;W)T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?
M;F%M92`@("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@
M("`@*B!`<&%R86T@87)R87D@)'-O<G1B>5]K97D@("`@($%T=')I8G5T92!K
M97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1D
M:7)E8W1I;VX@("`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!3;W)T960@:61S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S;W)T0GE!='1R:6)U=&5S*"1U;F]R9&5R961?
M:61S+"`D<V]R=&)Y7VYA;64@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P
M*0H@("`@>PH@("`@("`@("\J(%-E;&5C="!I9',@;W)D97)E9"!B>2!A='1R
M:6)U=&4@=F%L=64N("HO"B`@("`@("`@)'=H97)E(#T@)R<["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1S;W)T8GE?;F%M92DI('L*("`@("`@("`@("`@)'=H
M97)E(#T@<W!R:6YT9B@G($%.1"!A='1R:6)U=&5?;F%M92`]("5S("<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H
M)'-O<G1B>5]N86UE*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L
M;"@D<V]R=&)Y7VME>2DI('L*("`@("`@("`@("`@)'=H97)E(#T@<W!R:6YT
M9B@G)7,@04Y$(&%T=')I8G5T95]K97D@/2`E<R`G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1W:&5R92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D<V]R=&)Y7VME>2DI.PH@("`@
M("`@('T*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4(&1A=&%T
M<F5E7VED($923TT@)7,@5TA%4D4@9&%T871R965?:60@24X@*"5S*2`E<R!/
M4D1%4B!"62!A='1R:6)U=&5?=F%L=64@)7,G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RPG+"`D=6YO<F1E
M<F5D7VED<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=VAE<F4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`H)&1I<F5C=&EO;B`]/2`Q*2`_("=$
M15-#)R`Z("=!4T,G*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-1
M3"!1=65R>2!B>2!$871A5')E95]S<6PZ.G-O<G1">4%T=')I8G5T97,H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@)&]R9&5R961?:61S(#T@)'1H:7,M/E]D8BT^9V5T0V]L
M*"1Q=65R>2D["@H@("`@("`@("\J($UA:V4@<W5R92!T:&%T('-O;64@:61S
M(&1I9&XG="!G970@;&]S="!B96-A=7-E(&AA<R!N;R!S=6-H"B`@("`@("`@
M("H@871T<FEB=71E(&YA;64O:V5Y+B!!<'!E;F0@=&AE;2!T;R!T:&4@96YD
M+B`J+PH@("`@("`@(&EF("AC;W5N="@D;W)D97)E9%]I9',I("$](&-O=6YT
M*"1U;F]R9&5R961?:61S*2D@>PH@("`@("`@("`@("`D;W)D97)E9%]I9',@
M/2!A<G)A>5]U;FEQ=64H87)R87E?;65R9V4H)&]R9&5R961?:61S+"`D=6YO
M<F1E<F5D7VED<RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O<F1E
M<F5D7VED<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T
M(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A;'5E<R!O9B!T:&4@9VEV96X@
M871T<FEB=71E"B`@("`@*B!N86UE+VME>2!C;VUB:6YA=&EO;BX@16ET:&5R
M(&%T=')I8G5T95]N86UE(&]R(&%T=')I8G5T95]K97D@35535"!B90H@("`@
M("H@<W5P<&QI960L(&%N9"!B;W1H($U!62!B92!S=7!P;&EE9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D871T<FEB=71E7VYA;64@(%1H92!N
M86UE(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M871T<FEB=71E7VME>2`@(%1H92!K97D@=F%L=64@;V8@=&AE(&%T=')I8G5T
M92X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("`@("`@5&AE
M('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("`@("!2971U<FX@86QL(&QE
M=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U
M;'1S('1O(&%L;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!L979E;',N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@;V8@86QL(&]F('1H92!A=F%I;&%B;&4@=F%L=65S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5686QU97,H)&%T=')I8G5T95]N
M86UE(#T@;G5L;"P@)&%T=')I8G5T95]K97D@/2!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0@/2!$051!5%)%15]23T]4
M+"`D86QL3&5V96QS(#T@=')U92D*("`@('L*("`@("`@("`O+R!"=6EL9"!T
M:&4@;F%M92]K97D@9FEL=&5R+@H@("`@("`@("1W:&5R92`]("<G.PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D871T<FEB=71E7VYA;64I*2!["B`@("`@("`@
M("`@("1W:&5R92`N/2`G82YA='1R:6)U=&5?;F%M92`]("<@+B`D=&AI<RT^
M7V1B+3YQ=6]T92@D871T<FEB=71E7VYA;64I.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES7VYU;&PH)&%T=')I8G5T95]K97DI*2!["B`@("`@("`@("`@
M(&EF("@D=VAE<F4I('L*("`@("`@("`@("`@("`@("1W:&5R92`N/2`G($%.
M1"`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1W:&5R92`N/2`G82YA
M='1R:6)U=&5?:V5Y(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1A='1R:6)U
M=&5?:V5Y*3L*("`@("`@("!]"@H@("`@("`@("\O(%)E='5R;B!I9B!W92!H
M879E(&YO(&-R:71E<FEA+@H@("`@("`@(&EF("@A)'=H97)E*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;R!C<FET97)I82<I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@061D(&9I;'1E<FEN9R!B>2!P87)E
M;G0L(&%N9"!F;W(@;VYE(&]R(&%L;"!L979E;',N"B`@("`@("`@)&QE=F5L
M475E<GD@/2`G)SL*("`@("`@("!I9B`H)'!A<F5N="`A/2!$051!5%)%15]2
M3T]4*2!["B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)SHG+"`D<&%R
M96YT*3L*("`@("`@("`@("`@)'!A<F5N=',@/2`G)SL*("`@("`@("`@("`@
M)'!S=')I;F<@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'!A<G1S(&%S
M("1P87)T*2!["B`@("`@("`@("`@("`@("`D<'-T<FEN9R`N/2`H96UP='DH
M)'!S=')I;F<I(#\@)R<@.B`G.B<I("X@)'!A<G0["B`@("`@("`@("`@("`@
M("`D<&ED(#T@)'1H:7,M/F=E=$ED*"1P<W1R:6YG*3L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'!I9#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1P87)E;G1S("X]("<Z)R`N("1P:60["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D86QL3&5V96QS*2!["B`@("`@("`@
M("`@("`@("`D;&5V96Q1=65R>2`]('-P<FEN=&8H)T%.1"`H9&%T871R965?
M<&%R96YT<R`]("5S($]2(&1A=&%T<F5E7W!A<F5N=',@3$E+12`E<RDG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G%U;W1E*"1P87)E;G1S*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D<&%R96YT<R`N("<Z
M)2<I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L
M979E;%%U97)Y(#T@<W!R:6YT9B@G04Y$(&1A=&%T<F5E7W!A<F5N=',@/2`E
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D8BT^<75O=&4H)'!A<F5N=',I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("@A)&%L;$QE=F5L<RD@>PH@("`@("`@("`@("`D;&5V
M96Q1=65R>2`](")!3D0@9&%T871R965?<&%R96YT<R`]("<G(CL*("`@("`@
M("!]"@H@("`@("`@("\O($)U:6QD('1H92!&4D]-+TI/24X@8VQA=7-E<RX*
M("`@("`@("`D:F]I;G,@/2`G3$5&5"!*3TE.("<@+B`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("<@8R!/3B!A+F1A=&%T<F5E7VED
M(#T@8RYD871A=')E95]I9"<["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"!$25-424Y#5"!A+F%T=')I8G5T95]V86QU92!&4D]-("5S(&$@
M)7,@5TA%4D4@8RYG<F]U<%]U:60@/2`E<R!!3D0@)7,@)7,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I
M8G5T97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1J;VEN<RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES
M+3Y?<&%R86US6R=G<F]U<"==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("1W:&5R92P*("`@("`@("`@("`@("`@("`@("`@("`@("1L979E;%%U97)Y
M*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$
M871A5')E95]S<6PZ.F=E=$%T=')I8G5T959A;'5E<R@I.B`G("X@)'%U97)Y
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@)')O=W,@/2`D=&AI<RT^7V1B+3YG971#;VPH)'%U97)Y*3L*("`@("`@
M("!I9B`H:7-?82@D<F]W<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@D<F]W<RP@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]%4E(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M;W=S.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&%N(&%T=')I8G5T
M92!Q=65R>2X@2&5R92!I<R!A;B!E>&%M<&QE("1C<FET97)I82!A<G)A>3H*
M("`@("`J"B`@("`@*B`\8V]D93X*("`@("`J("1C<FET97)I85LG3U(G72`]
M(&%R<F%Y*`H@("`@("H@("`@(&%R<F%Y*"=!3D0G(#T^(&%R<F%Y*`H@("`@
M("H@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP*("`@("`J("`@
M("`@("`@("`@("`@)V]P)R`@("`]/B`G/2<L"B`@("`@*B`@("`@("`@("`@
M("`@("=T97-T)R`@/3X@)V9O;R<I+`H@("`@("H@("`@("`@("!A<G)A>2@G
M9FEE;&0G(#T^("=K97DG+`H@("`@("H@("`@("`@("`@("`@("`G;W`G("`@
M(#T^("<])RP*("`@("`J("`@("`@("`@("`@("`@)W1E<W0G("`]/B`G86)C
M)RDI*2P*("`@("`J("`@("`@("`@87)R87DH)T%.1"<@/3X@87)R87DH"B`@
M("`@*B`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP*("`@
M("`J("`@("`@("`@("`@("`@("`@("=O<"<@("`@/3X@)STG+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@)W1E<W0G("`]/B`G8F%R)RDL"B`@("`@*B`@
M("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=K97DG+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G/2<L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`G=&5S="<@(#T^("=X>7HG*2DI*3L*("`@("`J(#PO8V]D
M93X*("`@("`J"B`@("`@*B!4:&ES('=O=6QD(&9E=&-H(&%L;"!O8FIE8W0@
M:61S('=H97)E(&%T=')I8G5T92!N86UE(&ES(")F;V\B($%.1"!K97D*("`@
M("`J(&ES(")A8F,B+"!/4B`B8F%R(B!!3D0@(GAY>B(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("`@)&-R:71E<FEA("`@("!4:&4@87)R87D@;V8@
M8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("`@
M(%1H92!P87)E;G0@;F]D92!T;R!S=&%R="!S96%R8VAI;F<@9G)O;2X*("`@
M("`J($!P87)A;2!B;V]L96%N("1A;&Q,979E;',@("`@4F5T=7)N(&%L;"!L
M979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT
M<R!T;R!A;&P@;&5V96QS+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')E<W1R
M:6-T("`@("!/;FQY(')E='5R;B!A='1R:6)U=&5S('=I=&@@=&AE('-A;64*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E
M7VYA;64@;W(@871T<FEB=71E7VED+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&]P97)A=&EO;B`@("!4>7!E(&]F('%U97)Y('1O(&)U:6QD"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O
M('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T
M8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("`@(%-O<G0@9&ER96-T
M:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@
M+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(%-13"!Q=65R>2!A;F0@82!L:7-T(&]F('9A;'5E<R!S=6ET86)L
M92!F;W(@8FEN9&EN9PH@("`@("H@("`@("`@("`@("`@("`@87,@86X@87)R
M87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD071T<FEB=71E475E<GDH
M)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512145?4D]/5"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%L;$QE=F5L<R`]('1R=64L("1R
M97-T<FEC="`]("=N86UE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&]P97)A=&EO;B`]($1!5$%44D5%7T)524Q$7U-%3$5#5"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]N86UE(#T@
M;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("!I
M9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"<G+"!A<G)A>2@I*3L*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD
M('1H92!Q=65R>2X@*B\*("`@("`@("`D=&AI<RT^7W1A8FQE0V]U;G0@/2`Q
M.PH@("`@("`@("1Q=65R>2`]("<G.PH@("`@("`@("1V86QU97,@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C<FET97)I82!A<R`D:V5Y(#T^("1V
M86QS*2!["B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=/4B<@?'P@)&ME>2`]
M/2`G04Y$)RD@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D<75E<GDI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'%U97)Y("X]("<@)R`N("1K97D@
M+B`G("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8FEN
M9',@/2`D=&AI<RT^7V)U:6QD071T<FEB=71E475E<GDH)&ME>2P@)'9A;',I
M.PH@("`@("`@("`@("`@("`@)'%U97)Y("X]("<H)R`N("1B:6YD<ULP72`N
M("<I)SL*("`@("`@("`@("`@("`@("1V86QU97,@*ST@)&)I;F1S6S%=.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!!9&0@9FEL=&5R
M:6YG(&)Y('!A<F5N="P@86YD(&9O<B!O;F4@;W(@86QL(&QE=F5L<RX*("`@
M("`@("`D;&5V96Q1=65R>2`]("<G.PH@("`@("`@("1L979E;%9A;'5E<R`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*"1P87)E;G0@(3T@1$%40512145?4D]/
M5"D@>PH@("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)'!A<F5N
M="D["B`@("`@("`@("`@("1P87)E;G1S(#T@)R<["B`@("`@("`@("`@("1P
M<W1R:6YG(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)T<R!A<R`D
M<&%R="D@>PH@("`@("`@("`@("`@("`@)'!S=')I;F<@+CT@*&5M<'1Y*"1P
M<W1R:6YG*2`_("<G(#H@)SHG*2`N("1P87)T.PH@("`@("`@("`@("`@("`@
M)'!I9"`]("1T:&ES+3YG971)9"@D<'-T<FEN9RD["B`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1P:60["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<&%R96YT<R`N/2`G.B<@+B`D<&ED.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&%L;$QE=F5L<RD@>PH@("`@("`@("`@
M("`@("`@)&QE=F5L475E<GD@/2`G04Y$("AD871A=')E95]P87)E;G1S(#T@
M/R!/4B!D871A=')E95]P87)E;G1S($Q)2T4@/RDG.PH@("`@("`@("`@("`@
M("`@)&QE=F5L5F%L=65S(#T@87)R87DH)'!A<F5N=',L("1P87)E;G1S("X@
M)SHE)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M;&5V96Q1=65R>2`]("=!3D0@9&%T871R965?<&%R96YT<R`](#\G.PH@("`@
M("`@("`@("`@("`@)&QE=F5L5F%L=65S(#T@87)R87DH)'!A<F5N=',I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"$D86QL3&5V96QS*2![
M"B`@("`@("`@("`@("1L979E;%%U97)Y(#T@(D%.1"!D871A=')E95]P87)E
M;G1S(#T@)R<B.PH@("`@("`@('T*"B`@("`@("`@+R\@0G5I;&0@=&AE($92
M3TTO2D])3B!C;&%U<V5S+@H@("`@("`@("1J;VEN<R`](&%R<F%Y*"D["B`@
M("`@("`@)'!A:7)S(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,3L@
M)&D@/#T@)'1H:7,M/E]T86)L94-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@
M("1J;VEN<UM=(#T@)TQ%1E0@2D])3B`G("X@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE7V%T=')I8G5T97,G72`N"B`@("`@("`@("`@("`@("`G(&$G("X@)&D@
M+B`G($].(&$G("X@)&D@+B`G+F1A=&%T<F5E7VED(#T@8RYD871A=')E95]I
M9"<["@H@("`@("`@("`@("!I9B`H)&D@(3T@,2D@>PH@("`@("`@("`@("`@
M("`@:68@*"1R97-T<FEC="`]/2`G;F%M92<I('L*("`@("`@("`@("`@("`@
M("`@("`D<&%I<G-;72`]("=!3D0@83$N871T<FEB=71E7VYA;64@/2!A)R`N
M("1I("X@)RYA='1R:6)U=&5?;F%M92<["B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)')E<W1R:6-T(#T]("=I9"<I('L*("`@("`@("`@("`@("`@("`@
M("`D<&%I<G-;72`]("=!3D0@83$N9&%T871R965?:60@/2!A)R`N("1I("X@
M)RYD871A=')E95]I9"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\O($]V97)R:61E('-O<G1I;F<N"B`@
M("`@("`@)'-O<G0@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-?;G5L;"@D
M<V]R=&)Y7VYA;64I('Q\("%I<U]N=6QL*"1S;W)T8GE?:V5Y*2D@>PH@("`@
M("`@("`@("`D;W)D97)?=&%B;&4@/2`G82<@+B`D:3L*("`@("`@("`@("`@
M)&IO:6YS6UT@/2`G3$5&5"!*3TE.("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&5?871T<FEB=71E<R==("X*("`@("`@("`@("`@("`@("<@)R`N("1O<F1E
M<E]T86)L92`N("<@3TX@)R`N("1O<F1E<E]T86)L92`N"B`@("`@("`@("`@
M("`@("`G+F1A=&%T<F5E7VED(#T@8RYD871A=')E95]I9"<["@H@("`@("`@
M("`@("!I9B`H(6ES7VYU;&PH)'-O<G1B>5]N86UE*2D@>PH@("`@("`@("`@
M("`@("`@)'!A:7)S6UT@/2!S<')I;G1F*"=!3D0@)7,N871T<FEB=71E7VYA
M;64@/2`_("<L("1O<F1E<E]T86)L92D["B`@("`@("`@("`@("`@("`D<V]R
M=%M=(#T@)'-O<G1B>5]N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VME>2DI('L*("`@("`@("`@("`@("`@
M("1P86ER<UM=(#T@<W!R:6YT9B@G04Y$("5S+F%T=')I8G5T95]K97D@/2`_
M("<L("1O<F1E<E]T86)L92D["B`@("`@("`@("`@("`@("`D<V]R=%M=(#T@
M)'-O<G1B>5]K97D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1O<F1E
M<B`]('-P<FEN=&8H)R5S+F%T=')I8G5T95]V86QU92`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&]R9&5R7W1A8FQE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("@D9&ER96-T:6]N(#T](#$I(#\@)T1%4T,G
M(#H@)T%30R<I.PH@("`@("`@("`@("`D9W)O=7!?8GD@/2`G8RYD871A=')E
M95]I9"P@8RYD871A=')E95]N86UE+"!C+F1A=&%T<F5E7V]R9&5R+"`G("X*
M("`@("`@("`@("`@("`@("1O<F1E<E]T86)L92`N("<N871T<FEB=71E7W9A
M;'5E)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;W)D97(@/2`G
M8RYD871A=')E95]O<F1E<BP@8RYD871A=')E95]N86UE+"!C+F1A=&%T<F5E
M7VED)SL*("`@("`@("`@("`@)&=R;W5P7V)Y(#T@)V,N9&%T871R965?:60L
M(&,N9&%T871R965?;F%M92P@8RYD871A=')E95]O<F1E<B<["B`@("`@("`@
M?0H*("`@("`@("`D:F]I;G,@/2!I;7!L;V1E*"<@)RP@)&IO:6YS*3L*("`@
M("`@("`D<&%I<G,@/2!I;7!L;V1E*"<@)RP@)'!A:7)S*3L*("`@("`@("`D
M=&%I;"`]('-P<FEN=&8H)T=23U50($)9("5S($]21$52($)9("5S)RP@)&=R
M;W5P7V)Y+"`D;W)D97(I.PH*("`@("`@("!S=VET8V@@*"1O<&5R871I;VXI
M('L*("`@("`@("!C87-E($1!5$%44D5%7T)524Q$7T-/54Y4.@H@("`@("`@
M("`@("`D=VAA="`]("=#3U5.5"A$25-424Y#5"!C+F1A=&%T<F5E7VED*2<[
M"B`@("`@("`@("`@("1T86EL(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=VAA="`]("=C+F1A=&%T
M<F5E7VED+"!C+F1A=&%T<F5E7VYA;64G.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*"=314Q%
M0U0@)7,@1E)/32`E<R!C("5S(%=(15)%(&,N9W)O=7!?=6ED(#T@/R!!3D0@
M)7,@)7,@)7,@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M:&%T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1J
M;VEN<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<75E<GDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L475E<GDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A:7)S+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T86EL*2P*("`@("`@("`@("`@("`@("`@("`@
M87)R87E?;65R9V4H87)R87DH)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96Q686QU97,L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!P:65C92!O9B!A;B!A='1R:6)U
M=&4@<75E<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9VQU92`@
M("`@5&AE(&=L=64@=&\@:F]I;B!T:&4@8W)I=&5R:6$@*$]2+T%.1"DN"B`@
M("`@*B!`<&%R86T@87)R87D@)&-R:71E<FEA("!4:&4@87)R87D@;V8@8W)I
M=&5R:6$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:F]I;B`@("!3:&]U;&0@
M=V4@:F]I;B!O;B!A(&-L96%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!H;W)D95]D871A=')E95]A='1R:6)U=&5S('1A8FQE/R!$969A=6QT
M<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@4U%,(&9R86=M96YT(&%N
M9"!A(&QI<W0@;V8@=F%L=65S('-U:71A8FQE(&9O<B!B:6YD:6YG"B`@("`@
M*B`@("`@("`@("`@("`@("!A<R!A;B!A<G)A>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V)U:6QD071T<FEB=71E475E<GDH)&=L=64L("1C<FET97)I82P@
M)&IO:6X@/2!F86QS92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+U-13"YP:'`G.PH*("`@("`@("`O+R!);FET:6%L:7IE('1H92!C;&%U
M<V4@=&AA="!W92=R92!B=6EL9&EN9RX*("`@("`@("`D8VQA=7-E(#T@)R<[
M"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["@H@("`@("`@("\O($=E="!T
M:&4@=&%B;&4@86QI87,@=&\@=7-E(&9O<B!T:&ES('-E="!O9B!C<FET97)I
M82X*("`@("`@("`D86QI87,@/2`D=&AI<RT^7V=E=$%L:6%S*"1J;VEN*3L*
M"B`@("`@("`@9F]R96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;',I
M('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D8VQA=7-E*2D@>PH@("`@("`@
M("`@("`@("`@)&-L875S92`N/2`G("<@+B`D9VQU92`N("<@)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86QS6R=/4B==*2!\
M?"`A96UP='DH)'9A;'-;)T%.1"==*2D@>PH@("`@("`@("`@("`@("`@)&)I
M;F1S(#T@)'1H:7,M/E]B=6EL9$%T=')I8G5T95%U97)Y*"1G;'5E+"`D=F%L
M<RD["B`@("`@("`@("`@("`@("`D8VQA=7-E("X]("<H)R`N("1B:6YD<ULP
M72`N("<I)SL*("`@("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>5]M97)G
M92@D=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1V86QS6R=*3TE.)UTI*2!["B`@("`@("`@("`@("`@("`D8FEN
M9',@/2`D=&AI<RT^7V)U:6QD071T<FEB=71E475E<GDH)&=L=64L("1V86QS
M6R=*3TE.)UTL('1R=64I.PH@("`@("`@("`@("`@("`@)&-L875S92`N/2`D
M8FEN9'-;,%T["B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87E?;65R
M9V4H)'9A;'5E<RP@)&)I;F1S6S%=*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L<ULG9FEE;&0G72DI('L*
M("`@("`@("`@("`@("`@("`@("`D8FEN9',@/2!(;W)D95]344PZ.F)U:6QD
M0VQA=7-E*"1T:&ES+3Y?9&(L("1A;&EA<R`N("<N871T<FEB=71E7R<@+B`D
M=F%L<ULG9FEE;&0G72P@)'9A;'-;)V]P)UTL("1V86QS6R=T97-T)UTL('1R
M=64I.PH@("`@("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)&)I;F1S6S!=
M.PH@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>5]M97)G92@D
M=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D8FEN9',@/2`D=&AI<RT^7V)U:6QD071T
M<FEB=71E475E<GDH)&ME>2P@)'9A;',I.PH@("`@("`@("`@("`@("`@("`@
M("1C;&%U<V4@+CT@)&)I;F1S6S!=.PH@("`@("`@("`@("`@("`@("`@("1V
M86QU97,@/2!A<G)A>5]M97)G92@D=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@87)R87DH)&-L875S92P@)'9A;'5E<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@86X@86QI87,@=&\@:&]R9&5?9&%T871R965?871T
M<FEB=71E<RP@:6YC<F5M96YT:6YG(&ET(&EF"B`@("`@*B!N96-E<W-A<GDN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN8W)E;65N="`@26YC
M<F5M96YT('1H92!A;&EA<R!C;W5N=#\@1&5F875L=',@=&\@;F\N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971!;&EA<R@D:6YC<F5M96YT(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@<W1A=&EC("1S965N(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*"1I;F-R96UE;G0@)B8@(65M<'1Y*"1S965N6R1T:&ES+3Y?=&%B
M;&5#;W5N=%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&%B;&5#;W5N="LK
M.PH@("`@("`@('T*"B`@("`@("`@)'-E96Y;)'1H:7,M/E]T86)L94-O=6YT
M72`]('1R=64["B`@("`@("`@<F5T=7)N("=A)R`N("1T:&ES+3Y?=&%B;&5#
M;W5N=#L*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!T:&4@9&%T82!I
M;B!A;B!O8FIE8W0N($1O97,@;F]T(&-H86YG92!T:&4@;V)J96-T)W,*("`@
M("`J('!A<F5N="!O<B!N86UE+"!J=7-T('-E<FEA;&EZ960@9&%T82!O<B!A
M='1R:6)U=&5S+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E92`D;V)J
M96-T("!!($1A=&%4<F5E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=7!D871E1&%T82@D;V)J96-T*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@("`@("`O*B!.
M;W1H:6YG('1O(&1O(&9O<B!N;VX@;V)J96-T<RX@*B\*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&]B
M:F5C="!I9"X@*B\*("`@("`@("`D:60@/2`D=&AI<RT^9V5T260H)&]B:F5C
M="T^9V5T3F%M92@I*3L*("`@("`@("!I9B`H:7-?82@D:60L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("!]"@H@
M("`@("`@("\J(%-E92!I9B!W92!C86X@8G)E86L@=&AE(&]B:F5C="!O=70@
M=&\@9&%T871R965?871T<FEB=71E<R!T86)L92X@*B\*("`@("`@("!I9B`H
M;65T:&]D7V5X:7-T<R@D;V)J96-T+"`G7W1O071T<FEB=71E<R<I*2!["B`@
M("`@("`@("`@("\J($EF('=E(&-A;BP@8VQE87(@;W5T('1H92!D871A=')E
M95]D871A(&9I96QD('1O(&UA:V4@<W5R92!I=`H@("`@("`@("`@("`@*B!D
M;V5S;B=T(&=E="!P:6-K960@=7`@8GD@9V5T1&%T82@I+B!);G1E;G1I;VYA
M;&QY(&1O;B=T(&-H96-K"B`@("`@("`@("`@("`J(&9O<B!E<G)O<G,@:&5R
M92!I;B!C87-E(&1A=&%T<F5E7V1A=&$@9V]E<R!A=V%Y(&EN('1H90H@("`@
M("`@("`@("`@*B!F=71U<F4N("HO"B`@("`@("`@("`@("1Q=65R>2`]("=5
M4$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@
M("`@("`@("`@("`@)R!3150@9&%T871R965?9&%T82`](#\@5TA%4D4@9&%T
M871R965?:60@/2`_)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*$Y5
M3$PL("AI;G0I)&ED*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIU<&1A=&5$871A*"DZ("<@
M+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU
M97,I.PH*("`@("`@("`@("`@+RH@4W1A<G0@82!T<F%N<V%C=&EO;BX@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AF86QS92D["@H@
M("`@("`@("`@("`O*B!$96QE=&4@;VQD(&%T=')I8G5T97,N("HO"B`@("`@
M("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@("`@("`@("`@("`@("`@("`@
M("<@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@("`@("`@("`@)'9A;'5E
M<R`](&%R<F%Y*"AI;G0I)&ED*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIU<&1A=&5$871A
M*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E
M<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D8BT^<F]L;&)A8VLH*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M
M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@1V5T('1H92!N
M97<@871T<FEB=71E('-E="P@86YD(&EN<V5R="!E86-H(&EN=&\@=&AE($1"
M+B!)9@H@("`@("`@("`@("`@*B!A;GET:&EN9R!F86EL<R!I;B!H97)E+"!R
M;VQL8F%C:R!T:&4@=')A;G-A8W1I;VXL(')E='5R;B!T:&4*("`@("`@("`@
M("`@("H@<F5L979A;G0@97)R;W(L(&%N9"!B86EL(&]U="X@*B\*("`@("`@
M("`@("`@)&%T=')I8G5T97,@/2`D;V)J96-T+3Y?=&]!='1R:6)U=&5S*"D[
M"B`@("`@("`@("`@("1Q=65R>2`]("=)3E-%4E0@24Y43R`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@("`@("`@("`@("`@
M("`@("`@("<@*&1A=&%T<F5E7VED+"!A='1R:6)U=&5?;F%M92P@871T<FEB
M=71E7VME>2P@871T<FEB=71E7W9A;'5E*2<@+@H@("`@("`@("`@("`@("`@
M("`@("`G(%9!3%5%4R`H/RP@/RP@/RP@/RDG.PH@("`@("`@("`@("`D<W1A
M=&5M96YT(#T@)'1H:7,M/E]D8BT^<')E<&%R92@D<75E<GDI.PH@("`@("`@
M("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@
M("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"AI;G0I)&ED+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R6R=N86UE)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%T=');)VME>2==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H)&%T=');)W9A;'5E)UTL($Y,4SHZ9V5T0VAA<G-E="@I+"`D=&AI<RT^
M7W!A<F%M<ULG8VAA<G-E="==*2D["@H@("`@("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G5P9&%T
M941A=&$H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/F5X96-U=&4H)'-T871E;65N="P@)'9A;'5E<RD["B`@("`@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<F]L;&)A8VLH*3L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YA=71O0V]M;6ET*'1R=64I
M.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#;VUM
M:70@=&AE('1R86YS86-T:6]N+"!A;F0@='5R;B!A=71O8V]M;6ET(&)A8VL@
M;VXN("HO"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YC;VUM
M:70H*3L*("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E
M*3L*"B`@("`@("`@("`@(')E='5R;B!I<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RD@/R`D<F5S=6QT(#H@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O*B!7<FET92!T;R!T:&4@9&%T871R965?9&%T82!F:65L9"X@
M*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397)I86QI>F4N
M<&AP)SL*("`@("`@("`@("`@)'-E<B`](%-%4DE!3$E:15]55$8W7T)!4TE#
M.PH@("`@("`@("`@("`D9&%T82`]($AO<F1E7U-E<FEA;&EZ93HZ<V5R:6%L
M:7IE*"1O8FIE8W0M/F=E=$1A=&$H*2P@)'-E<BP@3DQ3.CIG971#:&%R<V5T
M*"DI.PH*("`@("`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`G(%-%
M5"!D871A=')E95]D871A(#T@/RP@9&%T871R965?<V5R:6%L:7IE9"`](#\G
M("X*("`@("`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]I9"`]
M(#\G.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)&1A=&$L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21S97(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H:6YT*21I9"D["@H@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ=7!D
M871E1&%T82@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@("`@("!R971U
M<FX@:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I(#\@)')E<W5L="`Z('1R
M=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE(%-13"!S97)V97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@2&]R9&4Z.F%S<V5R
M=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@)W-T;W)A9V4G+`H@("`@
M("`@("`@("!A<G)A>2@G<&AP='EP92<L("=C:&%R<V5T)RDL"B`@("`@("`@
M("`@("=$871A5')E92!344PG*3L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@/2`G)SL*("`@
M("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG<&%S
M<W=O<F0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W
M;W)D)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:&]R9&5?9&%T871R
M964G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R
M86US6R=T86)L95]A='1R:6)U=&5S)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UT@/2`G:&]R9&5?9&%T871R
M965?871T<FEB=71E<R<["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYN96-T
M('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S=7!P;&EE9"!P87)A;65T
M97)S+B`J+PH@("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@
M("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!E<G-I
M<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==
M*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1T:&ES+3Y?9&(L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!3970@
M1$(@<&]R=&%B:6QI='D@;W!T:6]N<PH@("`@("`@('-W:71C:"`H)'1H:7,M
M/E]D8BT^<&AP='EP92D@>PH@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@
M("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"
M7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]2
M4R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T
M3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12!\($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&%4<F5E+VYU;&PN
M<&AP````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S,W-P`Q,#4Q
M-30S,3`V,0`P,C$T,3``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!$871A5')E95]N=6QL.CH@
M8VQA<W,@<')O=FED97,@82!D=6UM>2!I;7!L96UE;G1A=&EO;B!O9B!T:&4*
M("H@1&%T851R964Z.B!!4$D[(&YO(&1A=&$@=VEL;"!L87-T(&)E>6]N9"!A
M('-I;F=L92!P86=E(')E<75E<W0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+VYU;&PN<&AP+'8@,2XQ-2XR+C0@,C`P-2\Q
M,"\Q."`Q,3HP,3HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DL
M(#(P,#`L(#(P,#$L(#(P,#(@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I
M9V9O;W0N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,2P@,C`P,B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T1A=&%4<F5E
M"B`J+PIC;&%S<R!$871A5')E95]N=6QL(&5X=&5N9',@1&%T851R964@>PH*
M("`@("\J*@H@("`@("H@0V%C:&4@;V8@871T<FEB=71E<R!F;W(@86YY(&]B
M:F5C=',@8W)E871E9"!D=7)I;F<@=&AI<R!P86=E(')E<75E<W0N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A='1R:6)U
M=&5#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#86-H92!O9B!D
M871A(&9O<B!A;GD@;V)J96-T<R!C<F5A=&5D(&1U<FEN9R!T:&ES('!A9V4@
M<F5Q=65S="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V1A=&%#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!,
M;V%D("AA('-U8G-E="!O9BD@=&AE(&1A=&%T<F5E(&EN=&\@=&AE("1?9&%T
M82!A<G)A>2X@4&%R="!O9B!T:&4*("`@("`J($1A=&%4<F5E($%022!T:&%T
M(&UU<W0@8F4@;W9E<G)I9&1E;B!B>2!S=6)C;&%S<V5S+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1R;V]T("`@(%=H:6-H('!O<G1I;VX@;V8@
M=&AE('1R964@=&\@;&]A9"X@1&5F875L=',@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@(&%L;"!O9B!I="X*("`@("`J($!P87)A;2!B;V]L
M96%N("1R96QO860@(%)E+6QO860@86QR96%D>2!L;V%D960@=F%L=65S/PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO860H)')O;W0@
M/2!N=6QL+"`D<F5L;V%D(#T@9F%L<V4I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!,;V%D(&$@<W!E8VEF:6,@;V)J96-T(&ED96YT:69I960@8GD@
M:71S('5N:7%U92!)1"`H)&ED*2P@86YD"B`@("`@*B!I=',@<&%R96YT<RP@
M:6YT;R!T:&4@)%]D871A(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C:60@(%1H92!U;FEQ=64@240@;V8@=&AE(&]B:F5C="!T;R!L
M;V%D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861"
M>4ED*"1C:60I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!T
M<F5E('-O<G1E9"!B>2!T:&4@<W!E8VEF:65D(&%T=')I8G5T92!N86UE(&%N
M9"]O<B!K97DN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1R;V]T("`@("`@(%=H:6-H('!O
M<G1I;VX@;V8@=&AE('1R964@=&\@<V]R="X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!O9B!I="X*("`@("`J
M($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@(%-O<G0@=&AE('1R964@<W1A
M<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R97%U97-T960@;&5V96P@86YD(&1I<F5C="!P
M87)E;G1S/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F
M875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S
M;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?:V5Y("`@071T<FEB=71E
M(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R87D@
M)&1I<F5C=&EO;B`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G9713;W)T9614<F5E*"1R;V]T+"`D;&]A9%1R
M964@/2!F86QS92P@)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@
M/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;B!O8FIE8W0N
M(%!A<G0@;V8@=&AE($1A=&%4<F5E($%022!T:&%T(&UU<W0@8F4*("`@("`J
M(&]V97)R:61D96X@8GD@<W5B8VQA<W-E<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&9U;&QN86UE("!4:&4@;V)J96-T('1O(&%D9"`H<W1R:6YG
M(&]R($1A=&%4<F5E3V)J96-T*2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M*"1O8FIE8W0I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&]B:F5C="P@)T1A
M=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@)&9U;&QN86UE(#T@)&]B
M:F5C="T^9V5T3F%M92@I.PH@("`@("`@("`@("`D;W)D97(@/2`D;V)J96-T
M+3YO<F1E<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G5L;&YA
M;64@/2`D;V)J96-T.PH@("`@("`@("`@("`D;W)D97(@/2!N=6QL.PH@("`@
M("`@('T*"B`@("`@("`@)&ED(#T@;60U*&UT7W)A;F0H*2D["B`@("`@("`@
M:68@*'-T<G!O<R@D9G5L;&YA;64L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1P87)T<R`](&5X<&QO9&4H)SHG+"`D9G5L;&YA;64I.PH@("`@
M("`@("`@("`D;F%M92`](&%R<F%Y7W!O<"@D<&%R=',I.PH@("`@("`@("`@
M("`D<&%R96YT(#T@:6UP;&]D92@G.B<L("1P87)T<RD["B`@("`@("`@("`@
M("1P:60@/2`D=&AI<RT^9V5T260H)'!A<F5N="D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1P:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YA9&0H)'!A<F5N="D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<&ED(#T@1$%40512145?4D]/5#L*("`@
M("`@("!]"@H@("`@("`@(&EF("AP87)E;G0Z.F5X:7-T<R@D9G5L;&YA;64I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=!;')E
M861Y(&5X:7-T<R<I.PH@("`@("`@('T*"B`@("`@("`@)&%D9&5D(#T@<&%R
M96YT.CI?861D*"1F=6QL;F%M92P@)&ED+"`D<&ED+"`D;W)D97(I.PH@("`@
M("`@(&EF("AI<U]A*"1A9&1E9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&%D9&5D.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/G5P9&%T941A=&$H)&]B:F5C="D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&%N9V4@;W)D97(@;V8@=&AE(&-H:6QD<F5N(&]F(&%N(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)E;G1S("!4:&4@
M<&%R96YT(&ED('-T<FEN9R!P871H+@H@("`@("H@0'!A<F%M(&UI>&5D("1O
M<F1E<B`@("`@02!S<&5C:69I8R!N97<@;W)D97(@<&]S:71I;VX@;W(@86X@
M87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1A:6YI
M;F<@=&AE(&YE=R!P;W-I=&EO;G,@9F]R('1H92!G:79E;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F5N=',@;V)J96-T+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-I9"`@("`@268@<')O=FED960@:6YD:6-A=&5S
M(&EN<V5R=&EO;B!O9B!A(&YE=R!C:&EL9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@=&AE(&]B:F5C="P@86YD('=I;&P@8F4@=7-E9"!T
M;R!A=F]I9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@:6YC<F5M
M96YT:6YG(&ET('=H96X@<VAI9G1I;F<@=7`@86QL(&]T:&5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B=S(&]R9&5R+B!)9B!N
M;W0@<')O=FED960@:6YD:6-A=&5S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!D96QE=&EO;BP@:&5N8V4@<VAI9G0@86QL(&]T:&5R('!O<VET
M:6]N<R!D;W=N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!O;F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;W)D97(H)'!A<F5N=',L("1O<F1E
M<B`](&YU;&PL("1C:60@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D;W)D97(I("8F("%E;7!T>2@D;W)D97(I*2!["B`@("`@("`@("`@
M("\O($UU;'1I('5P9&%T92X*("`@("`@("`@("`@)'1H:7,M/E]R96]R9&5R
M*"1P:60L("1O<F1E<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@17AP;&EC:71L>2!S970@=&AE(&]R9&5R(&9O<B!A(&1A=&%T<F5E(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@(%1H
M92!D871A=')E92!O8FIE8W0@:60@=&\@8VAA;F=E+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&]R9&5R("!4:&4@;F5W(&]R9&5R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971/<F1E<B@D:60L("1O<F1E<BD*("`@('L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E;6]V97,@86X@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`@("1O8FIE8W0@(%1H92!O8FIE8W0@=&\@<F5M;W9E
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O<F-E("`@1F]R8V4@<F5M;W9A
M;"!O9B!E=F5R>2!C:&EL9"!O8FIE8W0_"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V92@D;V)J96-T+"`D9F]R8V4@/2!F86QS92D*("`@('L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V92!O;F4@;W(@;6]R92!O8FIE8W1S(&)Y
M(&ED+B!4:&ES(&9U;F-T:6]N(&1O97,@*FYO="H@9&\*("`@("`J('1H92!V
M86QI9&%T:6]N+"!R96]R9&5R:6YG+"!E=&,N('1H870@<F5M;W9E*"D@9&]E
M<RX@268@>6]U"B`@("`@*B!N965D('1O(&-H96-K(&9O<B!C:&EL9')E;BP@
M<F4M9&\@;W)D97)I;F<L(&5T8RXL('1H96X@>6]U(&UU<W0*("`@("`J(')E
M;6]V92@I(&]B:F5C=',@;VYE+6)Y+6]N92X@5&AI<R!I<R!F;W(@8V]D92!T
M:&%T(&MN;W=S(&ET)W,*("`@("`J(&1E86QI;F<@=VET:"!S:6YG;&4@*&YO
M;BUP87)E;G1E9"D@;V)J96-T<R!A;F0@;F5E9',@=&\@9&5L971E"B`@("`@
M*B!A(&)A=&-H(&]F('1H96T@<75I8VML>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&ED<R`@5&AE(&]B:F5C=',@=&\@<F5M;W9E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96UO=F5">4ED<R@D:61S*0H@("`@>PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5M;W9E(&]N92!O<B!M;W)E(&]B:F5C=',@8GD@
M;F%M92X@5&AI<R!F=6YC=&EO;B!D;V5S("IN;W0J(&1O"B`@("`@*B!T:&4@
M=F%L:61A=&EO;BP@<F5O<F1E<FEN9RP@971C+B!T:&%T(')E;6]V92@I(&1O
M97,N($EF('EO=0H@("`@("H@;F5E9"!T;R!C:&5C:R!F;W(@8VAI;&1R96XL
M(')E+61O(&]R9&5R:6YG+"!E=&,N+"!T:&5N('EO=2!M=7-T"B`@("`@*B!R
M96UO=F4H*2!O8FIE8W1S(&]N92UB>2UO;F4N(%1H:7,@:7,@9F]R(&-O9&4@
M=&AA="!K;F]W<R!I="=S"B`@("`@*B!D96%L:6YG('=I=&@@<VEN9VQE("AN
M;VXM<&%R96YT960I(&]B:F5C=',@86YD(&YE961S('1O(&1E;&5T90H@("`@
M("H@82!B871C:"!O9B!T:&5M('%U:6-K;'DN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1N86UE<R`@5&AE(&]B:F5C=',@=&\@<F5M;W9E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96UO=F5">4YA;65S*"1N86UE<RD*("`@('L*
M("`@('T*"B`@("`O*BH*("`@("`J($UO=F4@86X@;V)J96-T('1O(&$@;F5W
M('!A<F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1O8FIE8W0@
M("`@(%1H92!O8FIE8W0@=&\@;6]V92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YE=W!A<F5N="`@5&AE(&YE=R!P87)E;G0@;V)J96-T+B!$969A=6QT<R!T
M;R!T:&4@<F]O="X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D;V)J96-T
M+"`D;F5W<&%R96YT(#T@;G5L;"D*("`@('L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H86YG92!A;B!O8FIE8W0G<R!N86UE+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`@)&]L9%]O8FIE8W0@("`@("`@5&AE(&]L9"!O8FIE8W0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=?;V)J96-T7VYA;64@(%1H92!N
M97<@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D
M;VQD7V]B:F5C="P@)&YE=U]O8FIE8W1?;F%M92D*("`@('L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E=')I979E(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M
M('1H92!D871A=')E95]D871A(&9I96QD+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@:60@=&\@9F5T8V@L(&]R(&%N
M(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$1A=&$H)&-I9"D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M
M/E]D871A0V%C:&5;)&-I9%TI(#\*("`@("`@("`@("`@)'1H:7,M/E]D871A
M0V%C:&5;)&-I9%T@.@H@("`@("`@("`@("!A<G)A>2@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T<FEE=F4@9&%T82!F;W(@86X@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@:60@
M=&\@9F5T8V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T97,H
M)&-I9"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&-I9"DI('L*("`@
M("`@("`@("`@)&1A=&$@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H
M("@D8VED(&%S("1I9"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?871T<FEB=71E0V%C:&5;)&ED72DI('L*("`@("`@("`@("`@("`@
M("`@("`D9&%T85LD:61=(#T@)'1H:7,M/E]A='1R:6)U=&5#86-H95LD:61=
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!R971U<FX@)&1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&ES<V5T*"1T:&ES+3Y?871T<FEB=71E0V%C:&5;)&-I9%TI(#\*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E0V%C:&5;)&-I9%T@
M.@H@("`@("`@("`@("`@("`@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@;V)J96-T<R!M
M871C:&EN9R!A('-E="!O9B!A='1R:6)U=&4*("`@("`J(&-R:71E<FEA+@H@
M("`@("H*("`@("`J($!S964@8G5I;&1!='1R:6)U=&51=65R>2@I"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R:71E<FEA("`@5&AE(&%R<F%Y
M(&]F(&-R:71E<FEA+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@
M("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@4F5T=7)N(&%L;"!L
M979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@
M=&\@86QL(&QE=F5L<RX*("`@("`J($!P87)A;2!S=')I;F<@("1R97-T<FEC
M="`@($]N;'D@<F5T=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@
M;W(@871T<FEB=71E7VED+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=$)Y
M071T<FEB=71E<R@D8W)I=&5R:6$L("1P87)E;G0@/2!$051!5%)%15]23T]4
M+"`D86QL3&5V96QS(#T@=')U92P@)')E<W1R:6-T(#T@)VYA;64G*0H@("`@
M>PH@("`@("`@(&EF("@A8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@
M("!R971U<FX@,#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!C;W5N="@D
M=&AI<RT^7V%T=')I8G5T94-A8VAE*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!S970@;V8@;V)J96-T(&ED<R!B87-E9"!O;B!A('-E="!O
M9B!A='1R:6)U=&4@8W)I=&5R:6$N"B`@("`@*@H@("`@("H@0'-E92!B=6EL
M9$%T=')I8G5T95%U97)Y*"D*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M("`D8W)I=&5R:6$@("`@(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J
M($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("`@5&AE('!A<F5N="!N;V1E
M('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&%L;$QE=F5L<R`@("!2971U<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T
M:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;"!L979E;',N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S=')I8W0@("`@($]N;'D@<F5T
M=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&5?;F%M92!O<B!A='1R:6)U
M=&5?:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;2`@("`@("`@(%1H
M92!O8FIE8W0@=&\@<W1A<G0@=&\@9F5T8VAI;F<*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C;W5N="`@("`@("`@5&AE(&YU;6)E<B!O9B!O8FIE8W1S('1O
M(&9E=&-H"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@($%T
M=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A
M;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@
M9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N
M("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971">4%T=')I8G5T97,H)&-R:71E<FEA+"`D<&%R96YT
M(#T@1$%40512145?4D]/5"P@)&%L;$QE=F5L<R`]('1R=64L("1R97-T<FEC
M="`]("=N86UE)RP@)&9R;VT@/2`P+"`D8V]U;G0@/2`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T
M8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@
M:68@*"%C;W5N="@D8W)I=&5R:6$I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=N;R!C<FET97)I82<I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)'1H:7,M/E]A='1R:6)U=&5#86-H
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T<R!)1',@8GD@871T<FEB
M=71E('9A;'5E<RX@241S('=I=&AO=70@871T<FEB=71E<R!W:6QL(&)E"B`@
M("`@*B!A9&1E9"!T;R!T:&4@96YD(&]F('1H92!S;W)T960@;&ES="X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'5N;W)D97)E9%]I9',@($%R<F%Y
M(&]F(&ED<R!T;R!S;W)T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?
M;F%M92`@("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@
M("`@*B!`<&%R86T@87)R87D@)'-O<G1B>5]K97D@("`@($%T=')I8G5T92!K
M97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1D
M:7)E8W1I;VX@("`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!3;W)T960@:61S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S;W)T0GE!='1R:6)U=&5S*"1U;F]R9&5R961?
M:61S+"`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME>2`](&YU;&PL
M("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@(')E='5R;B`D=6YO<F1E
M<F5D7VED<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T
M(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A;'5E<R!O9B!T:&4@9VEV96X*
M("`@("`J(&%T=')I8G5T92!N86UE+VME>2!C;VUB:6YA=&EO;BX@16ET:&5R
M(&%T=')I8G5T95]N86UE(&]R"B`@("`@*B!A='1R:6)U=&5?:V5Y($U54U0@
M8F4@<W5P<&QI960L(&%N9"!B;W1H($U!62!B92!S=7!P;&EE9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U=&5?;F%M92`@5&AE(&YA
M;64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!P87)A;2!S=')I;F<@)&%T
M=')I8G5T95]K97D@("!4:&4@:V5Y('9A;'5E(&]F('1H92!A='1R:6)U=&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)E;G0@("`@("`@("`@5&AE('!A
M<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("`@(%)E='5R;B!A;&P@;&5V96QS
M+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R96YT/PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%L;"!O9B!T:&4@879A
M:6QA8FQE('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T071T<FEB
M=71E5F%L=65S*"1A='1R:6)U=&5?;F%M92`](&YU;&PL("1A='1R:6)U=&5?
M:V5Y(#T@;G5L;"P@)'!A<F5N="`]($1!5$%44D5%7U)/3U0L("1A;&Q,979E
M;',@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@57!D871E('1H92!D871A(&EN(&%N(&]B:F5C
M="X@1&]E<R!N;W0@8VAA;F=E('1H92!O8FIE8W0G<PH@("`@("H@<&%R96YT
M(&]R(&YA;64L(&IU<W0@<V5R:6%L:7IE9"!D871A+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]B:F5C="`@5&AE(&]B:F5C="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=7!D871E1&%T82@D;V)J96-T*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1C:60@
M/2`D=&AI<RT^9V5T260H)&]B:F5C="T^9V5T3F%M92@I*3L*("`@("`@("!I
M9B`H:7-?82@D8VED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8VED.PH@("`@("`@('T*"B`@("`@("`@+R\@5V4@:&%N9&QE(&1A
M=&$@9&EF9F5R96YT;'D@:68@=V4@8V%N(&UA<"!I="!T;PH@("`@("`@("\O
M(&%T=')I8G5T97,N"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&]B:F5C
M="P@)U]T;T%T=')I8G5T97,G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%T
M=')I8G5T94-A8VAE6R1C:61=(#T@)&]B:F5C="T^7W1O071T<FEB=71E<R@I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?9&%T84-A
M8VAE6R1C:61=(#T@)&]B:F5C="T^9V5T1&%T82@I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O0VEP:&5R+P``````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-S0S,0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O0FQO8VM-;V1E+P``````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`
M,#(Q,C<P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE
M<B]";&]C:TUO9&4O96-B+G!H<```````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#,S-@`Q,#4Q-30S,3`V,0`P,C(U,S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#
M:7!H97)?0FQO8VM-;V1E7V5C8CHZ(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T
M:&4*("H@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!U<VEN9R!T:&4@16QE8W1R
M;VYI8R!#;V1E($)O;VL@;65T:&]D(&]F"B`J(&5N8W)Y<'1I;F<@8FQO8VMS
M(&]F(&1A=&$N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H
M97(O0FQO8VM-;V1E+V5C8BYP:'`L=B`Q+C<N,3(N-2`R,#`V+S`Q+S`Q(#(Q
M.C(X.C$Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA
M9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?0FQO8VM-
M;V1E7V5C8B!E>'1E;F1S($AO<F1E7T-I<&AE<E]";&]C:TUO9&4@>PH*("`@
M("\J*@H@("`@("H@16YC<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<&%R86T@2&]R9&5?0VEP:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@
M=&\@=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!E;F-R>7!T:6]N+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&QA:6YT97AT
M("`@("!4:&4@9&%T82!T;R!E;F-R>7!T+@H@("`@("H*("`@("`J($!R971U
M<FX@(%1H92!E;F-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M96YC<GEP="@F)&-I<&AE<BP@)'!L86EN=&5X="D*("`@('L*("`@("`@("`D
M96YC<GEP=&5D(#T@)R<["B`@("`@("`@)&)L;V-K<VEZ92`]("1C:7!H97(M
M/F=E=$)L;V-K4VEZ92@I.PH*("`@("`@("`D:DUA>"`]('-T<FQE;B@D<&QA
M:6YT97AT*3L*("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"`D:DUA>#L@)&H@
M*ST@)&)L;V-K<VEZ92D@>PH@("`@("`@("`@("`D<&QA:6X@/2!S=6)S='(H
M)'!L86EN=&5X="P@)&HL("1B;&]C:W-I>F4I.PH*("`@("`@("`@("`@:68@
M*'-T<FQE;B@D<&QA:6XI(#P@)&)L;V-K<VEZ92D@>PH@("`@("`@("`@("`@
M("`@+R\@<&%D('1H92!B;&]C:R!W:71H(%PP)W,@:68@:70G<R!N;W0@;&]N
M9R!E;F]U9V@*("`@("`@("`@("`@("`@("1P;&%I;B`]('-T<E]P860H)'!L
M86EN+"`X+"`B7#`B*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&5N
M8W)Y<'1E9"`N/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'!L86EN*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5C<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<&%R86T@2&]R9&5?0VEP:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@
M=&\@=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D96-R>7!T:6]N+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VEP:&5R=&5X
M="`@("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U
M<FX@(%1H92!D96-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&5C<GEP="@F)&-I<&AE<BP@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@
M)&1E8W)Y<'1E9"`]("<G.PH@("`@("`@("1B;&]C:W-I>F4@/2`D8VEP:&5R
M+3YG971";&]C:U-I>F4H*3L*"B`@("`@("`@)&I-87@@/2!S=')L96XH)&-I
M<&AE<G1E>'0I.PH@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D
M:B`K/2`D8FQO8VMS:7IE*2!["B`@("`@("`@("`@("1P;&%I;B`]('-U8G-T
M<B@D8VEP:&5R=&5X="P@)&HL("1B;&]C:W-I>F4I.PH@("`@("`@("`@("`D
M9&5C<GEP=&5D("X]("1C:7!H97(M/F1E8W)Y<'1";&]C:R@D<&QA:6XI.PH@
M("`@("`@('T*"B`@("`@("`@+R\@4F5M;W9E('1R86EL:6YG(%PP)W,@=7-E
M9"!T;R!P860@=&AE(&QA<W0@8FQO8VLN"B`@("`@("`@=VAI;&4@*'-U8G-T
M<B@D9&5C<GEP=&5D+"`M,2P@,2D@/3T@(EPP(BD@>PH@("`@("`@("`@("`D
M9&5C<GEP=&5D(#T@<W5B<W1R*"1D96-R>7!T960L(#`L("TQ*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D9&5C<GEP=&5D.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O;V9B-C0N<&AP````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-#`W-@`Q,#4Q-30S,3`V,0`P,C(W,C4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V]F8C8T.CH@5&AI<R!C;&%S
M<R!I;7!L96UE;G1S('1H90H@*B!(;W)D95]#:7!H97)?0FQO8VM-;V1E('5S
M:6YG(&$@-C0@8FET(&]U='!U="!F965D8F%C:RX*("H*("H@5&AI<R!C86X@
M=7-E9"!T;R!E;F-R>7!T(&%N>2!L96YG=&@@<W1R:6YG(&%N9"!T:&4@96YC
M<GEP=&5D('9E<G-I;VX*("H@=VEL;"!B92!T:&4@<V%M92!L96YG=&@N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E
M+V]F8C8T+G!H<"QV(#$N-RXQ,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#
M:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]";&]C:TUO9&5?;V9B-C0@
M97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O*BH*("`@
M("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M($AO
M<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O('5S92!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YC<GEP
M=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@5&AE
M(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N("!4:&4@
M96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H
M)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("!["B`@("`@("`@)&5N8W)Y<'1E
M9"`]("<G.PH*("`@("`@("`D;B`](#`["B`@("`@("`@)&I-87@@/2!S=')L
M96XH)'!L86EN=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-
M87@[("1J*RLI('L*("`@("`@("`@("`@:68@*"1N(#T](#`I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:78@/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH
M)'1H:7,M/E]I=BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C(#T@
M)'!L86EN=&5X=%LD:ET@7B`D=&AI<RT^7VEV6R1N73L*("`@("`@("`@("`@
M)&5N8W)Y<'1E9"`N/2`D8SL*"B`@("`@("`@("`@("1N(#T@*"LK)&XI("8@
M,'@P-SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D96YC<GEP=&5D.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A('-T<FEN9RX*("`@("`J
M"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP:&5R("1C:7!H97(@($-I<&AE<B!A
M;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!D96-R>7!T:6]N+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VEP:&5R=&5X="`@("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H*("`@
M("`J($!R971U<FX@(%1H92!D96-R>7!T960@9&%T82X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5C<GEP="@F)&-I<&AE<BP@)&-I<&AE<G1E>'0I"B`@("![
M"B`@("`@("`@)&1E8W)Y<'1E9"`]("<G.PH*("`@("`@("`D;B`](#`["B`@
M("`@("`@)&I-87@@/2!S=')L96XH)&-I<&AE<G1E>'0I.PH@("`@("`@(&9O
M<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D:BLK*2!["B`@("`@("`@("`@(&EF
M("@D;B`]/2`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VEV(#T@)&-I
M<&AE<BT^96YC<GEP=$)L;V-K*"1T:&ES+3Y?:78I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D8R`]("1C:7!H97)T97AT6R1J72!>("1T:&ES+3Y?
M:79;)&Y=.PH@("`@("`@("`@("`D9&5C<GEP=&5D("X]("1C.PH*("`@("`@
M("`@("`@)&X@/2`H*RLD;BD@)B`P>#`W.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1D96-R>7!T960["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O8V9B-C0N<&AP
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8V-``Q,#4Q-30S,3`V,0`P,C(W
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V-F8C8T
M.CH@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H90H@*B!(;W)D95]#:7!H97)?
M0FQO8VM-;V1E('5S:6YG(&$@-C0@8FET(&-I<&AE<B!F965D8F%C:RX*("H*
M("H@5&AI<R!C86X@8F4@=7-E9"!T;R!E;F-R>7!T(&%N>2!L96YG=&@@<W1R
M:6YG(&%N9"!T:&4@96YC<GEP=&5D"B`J('9E<G-I;VX@=VEL;"!B92!T:&4@
M<V%M92!L96YG=&@N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#
M:7!H97(O0FQO8VM-;V1E+V-F8C8T+G!H<"QV(#$N-RXQ,BXU(#(P,#8O,#$O
M,#$@,C$Z,C@Z,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`
M<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]"
M;&]C:TUO9&5?8V9B-C0@97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E
M('L*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@
M("`@("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG
M;W)I=&AM('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!L
M86EN=&5X="`@("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5N8W)Y<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("!["B`@
M("`@("`@)&5N8W)Y<'1E9"`]("<G.PH*("`@("`@("`D;B`](#`["B`@("`@
M("`@)&I-87@@/2!S=')L96XH)'!L86EN=&5X="D["B`@("`@("`@9F]R("@D
M:B`](#`[("1J(#P@)&I-87@[("1J*RLI('L*("`@("`@("`@("`@:68@*"1N
M(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:78@/2`D8VEP:&5R
M+3YE;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1C(#T@)'!L86EN=&5X=%LD:ET@7B`D=&AI<RT^7VEV6R1N
M73L*("`@("`@("`@("`@)'1H:7,M/E]I=B`]('-U8G-T<B@D=&AI<RT^7VEV
M+"`P+"`D;BD@+B`D8R`N('-U8G-T<B@D=&AI<RT^7VEV+"`D;B`K(#$I.PH@
M("`@("`@("`@("`D96YC<GEP=&5D("X]("1C.PH*("`@("`@("`@("`@)&X@
M/2`H*RLD;BD@)B`P>#`W.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E
M;F-R>7!T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@<W1R
M:6YG+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]#:7!H97(@)&-I<&AE
M<B`@0VEP:&5R(&%L9V]R:71H;2!T;R!U<V4@9F]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&1E8W)Y<'1I;VXN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C:7!H97)T97AT("`@(%1H92!D871A('1O(&1E8W)Y<'0N
M"B`@("`@*@H@("`@("H@0')E='5R;B`@5&AE(&1E8W)Y<'1E9"!D871A+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T*"8D8VEP:&5R+"`D8VEP:&5R
M=&5X="D*("`@('L*("`@("`@("`D9&5C<GEP=&5D(#T@)R<["@H@("`@("`@
M("1N(#T@,#L*("`@("`@("`D:DUA>"`]('-T<FQE;B@D8VEP:&5R=&5X="D[
M"B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J*RLI('L*("`@
M("`@("`@("`@:68@*"1N(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:78@/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1C(#T@)&-I<&AE<G1E>'1;)&I=
M(%X@)'1H:7,M/E]I=ELD;ET["B`@("`@("`@("`@("1T:&ES+3Y?:78@/2!S
M=6)S='(H)'1H:7,M/E]I=BP@,"P@)&XI("X@<W5B<W1R*"1C:7!H97)T97AT
M+"`D:BP@,2D@+B!S=6)S='(H)'1H:7,M/E]I=BP@)&X@*R`Q*3L*("`@("`@
M("`@("`@)&1E8W)Y<'1E9"`N/2`D8SL*"B`@("`@("`@("`@("1N(#T@*"LK
M)&XI("8@,'@P-SL*("`@("`@("!]"@H@("`@("`@("\O(%)E;6]V92!T<F%I
M;&EN9R!<,"=S('5S960@=&\@<&%D('1H92!L87-T(&)L;V-K+@H@("`@("`@
M('=H:6QE("AS=6)S='(H)&1E8W)Y<'1E9"P@+3$L(#$I(#T](")<,"(I('L*
M("`@("`@("`@("`@)&1E8W)Y<'1E9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P
M+"`M,2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*
M("`@('T*"GT*````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO
M9&4O8V)C+G!H<```````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#<P,P`Q,#4Q
M-30S,3`V,0`P,C(U,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO
M8VM-;V1E7V-B8SHZ(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4*("H@2&]R
M9&5?0VEP:&5R7T)L;V-K36]D92!U<VEN9R!T:&4@0VEP:&5R($)L;V-K($-H
M86EN:6YG(&UE=&AO9"!O9@H@*B!E;F-R>7!T:6YG(&)L;V-K<R!O9B!D871A
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+T)L;V-K
M36]D92]C8F,N<&AP+'8@,2XW+C$R+C4@,C`P-B\P,2\P,2`R,3HR.#HQ,2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E
M7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP:&5R7T)L;V-K36]D95]C8F,@
M97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O*BH*("`@
M("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M($AO
M<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O('5S92!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YC<GEP
M=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@5&AE
M(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N("!4:&4@
M96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H
M)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("!["B`@("`@("`@)&5N8W)Y<'1E
M9"`]("<G.PH*("`@("`@("`D8FQO8VMS:7IE(#T@)&-I<&AE<BT^9V5T0FQO
M8VM3:7IE*"D["B`@("`@("`@)'!R979I;W5S0VEP:&5R(#T@)'1H:7,M/E]I
M=CL*"B`@("`@("`@)&I-87@@/2!S=')L96XH)'!L86EN=&5X="D["B`@("`@
M("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J("L]("1B;&]C:W-I>F4I
M('L*("`@("`@("`@("`@)'!L86EN(#T@<W5B<W1R*"1P;&%I;G1E>'0L("1J
M+"`D8FQO8VMS:7IE*3L*"B`@("`@("`@("`@(&EF("AS=')L96XH)'!L86EN
M*2`\("1B;&]C:W-I>F4I('L*("`@("`@("`@("`@("`@("\O('!A9"!T:&4@
M8FQO8VL@=VET:"!<,"=S(&EF(&ET)W,@;F]T(&QO;F<@96YO=6=H"B`@("`@
M("`@("`@("`@("`D<&QA:6X@/2!S=')?<&%D*"1P;&%I;BP@."P@(EPP(BD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1P;&%I;B`]("1P;&%I;B!>
M("1P<F5V:6]U<T-I<&AE<CL*("`@("`@("`@("`@)'!R979I;W5S0VEP:&5R
M(#T@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1P;&%I;BD["B`@("`@("`@("`@
M("1E;F-R>7!T960@+CT@)'!R979I;W5S0VEP:&5R.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1E;F-R>7!T960["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$96-R>7!T(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D
M95]#:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L9V]R:71H;2!T;R!U<V4@9F]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E8W)Y<'1I
M;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H97)T97AT("`@(%1H92!D
M871A('1O(&1E8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R;B`@5&AE(&1E
M8W)Y<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T*"8D
M8VEP:&5R+"`D8VEP:&5R=&5X="D*("`@('L*("`@("`@("`D9&5C<GEP=&5D
M(#T@)R<["@H@("`@("`@("1B;&]C:W-I>F4@/2`D8VEP:&5R+3YG971";&]C
M:U-I>F4H*3L*("`@("`@("`D<')E=FEO=7-#:7!H97(@/2`D=&AI<RT^7VEV
M.PH*("`@("`@("`D:DUA>"`]('-T<FQE;B@D8VEP:&5R=&5X="D["B`@("`@
M("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J("L]("1B;&]C:W-I>F4I
M('L*("`@("`@("`@("`@)'!L86EN(#T@<W5B<W1R*"1C:7!H97)T97AT+"`D
M:BP@)&)L;V-K<VEZ92D["B`@("`@("`@("`@("1D96-R>7!T960@+CT@)&-I
M<&AE<BT^9&5C<GEP=$)L;V-K*"1P;&%I;BD@7B`D<')E=FEO=7-#:7!H97([
M"B`@("`@("`@("`@("1P<F5V:6]U<T-I<&AE<B`]("1P;&%I;CL*("`@("`@
M("!]"@H@("`@("`@("\O(%)E;6]V92!T<F%I;&EN9R!<,"=S('5S960@=&\@
M<&%D('1H92!L87-T(&)L;V-K+@H@("`@("`@('=H:6QE("AS=6)S='(H)&1E
M8W)Y<'1E9"P@+3$L(#$I(#T](")<,"(I('L*("`@("`@("`@("`@)&1E8W)Y
M<'1E9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P+"`M,2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I
M<&AE<B]B;&]W9FES:"YP:'``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`U-S4P-``Q,#4Q-30S,3`V,0`P,C$W-C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!#:7!H
M97)?8FQO=V9I<V@Z.B!C;&%S<R!I;7!L96UE;G1S('1H92!#:7!H97(@:6YT
M97)F86-E(&5N8W)Y<'1I;VX@9&%T80H@*B!U<VEN9R!T:&4@0FQO=V9I<V@@
M86QG;W)I=&AM+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP
M:&5R+V)L;W=F:7-H+G!H<"QV(#$N,30N,3(N.2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@
M2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?8FQO=V9I<V@@
M97AT96YD<R!(;W)D95]#:7!H97(@>PH*("`@("\J*@H@("`@("H@4&D@07)R
M87D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M<"`](&%R<F%Y*`H@("`@("`@(#!X,C0S1C9!.#@L(#!X.#5!,S`X1#,L(#!X
M,3,Q.3A!,D4L(#!X,#,W,#<S-#0L"B`@("`@("`@,'A!-#`Y,S@R,BP@,'@R
M.3E&,S%$,"P@,'@P.#)%1D$Y."P@,'A%0S1%-D,X.2P*("`@("`@("`P>#0U
M,C@R,44V+"`P>#,X1#`Q,S<W+"`P>$)%-30V-D-&+"`P>#,T13DP0S9#+`H@
M("`@("`@(#!X0S!!0S(Y0C<L(#!X0SDW0S4P1$0L(#!X,T8X-$0U0C4L(#!X
M0C4T-S`Y,3<L"B`@("`@("`@,'@Y,C$V1#5$.2P@,'@X.3<Y1D(Q0BD["@H@
M("`@+RHJ"B`@("`@*B!3($)O>"`H<S$I"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)',Q(#T@87)R87DH"B`@("`@("`@,'A$
M,3,Q,$)!-BP@,'@Y.$1&0C5!0RP@,'@R1D9$-S)$0BP@,'A$,#%!1$9"-RP*
M("`@("`@("`P>$(X13%!1D5$+"`P>#9!,C8W13DV+"`P>$)!-T,Y,#0U+"`P
M>$8Q,D,W1CDY+`H@("`@("`@(#!X,C1!,3DY-#<L(#!X0C,Y,39#1C<L(#!X
M,#@P,48R13(L(#!X.#4X149#,38L"B`@("`@("`@,'@V,S8Y,C!$."P@,'@W
M,34W-$4V.2P@,'A!-#4X1D5!,RP@,'A&-#DS,T0W12P*("`@("`@("`P>#!$
M.34W-#A&+"`P>#<R.$5"-C4X+"`P>#<Q.$)#1#4X+"`P>#@R,34T045%+`H@
M("`@("`@(#!X-T(U-$$T,40L(#!X0S(U034Y0C4L(#!X.4,S,$0U,SDL(#!X
M,D%&,C8P,3,L"B`@("`@("`@,'A#-40Q0C`R,RP@,'@R.#8P.#5&,"P@,'A#
M030Q-SDQ."P@,'A".$1",SA%1BP*("`@("`@("`P>#A%-SE$0T(P+"`P>#8P
M,T$Q.#!%+"`P>#9#.44P13A"+"`P>$(P,44X03-%+`H@("`@("`@(#!X1#<Q
M-3<W0S$L(#!X0D0S,31",C<L(#!X-SA!1C)&1$$L(#!X-34V,#5#-C`L"B`@
M("`@("`@,'A%-C4U,C5&,RP@,'A!034U04(Y-"P@,'@U-S0X.3@V,BP@,'@V
M,T4X,30T,"P*("`@("`@("`P>#4U0T$S.39!+"`P>#)!04(Q,$(V+"`P>$(T
M0T,U0S,T+"`P>#$Q-#%%.$-%+`H@("`@("`@(#!X03$U-#@V048L(#!X-T,W
M,D4Y.3,L(#!X0C-%13$T,3$L(#!X-C,V1D)#,D$L"B`@("`@("`@,'@R0D$Y
M0S4U1"P@,'@W-#$X,S%&-BP@,'A#135#,T4Q-BP@,'@Y0C@W.3,Q12P*("`@
M("`@("`P>$%&1#9"03,S+"`P>#9#,C1#1C5#+"`P>#=!,S(U,S@Q+"`P>#(X
M.34X-C<W+`H@("`@("`@(#!X,T(X1C0X.3@L(#!X-D(T0D(Y048L(#!X0S1"
M1D4X,4(L(#!X-C8R.#(Q.3,L"B`@("`@("`@,'@V,40X,#E#0RP@,'A&0C(Q
M03DY,2P@,'@T.#=#04,V,"P@,'@U1$5#.#`S,BP*("`@("`@("`P>$5&.#0U
M1#5$+"`P>$4Y.#4W-4(Q+"`P>$1#,C8R,S`R+"`P>$5"-C4Q0C@X+`H@("`@
M("`@(#!X,C,X.3-%.#$L(#!X1#,Y-D%#0S4L(#!X,$8V1#9&1C,L(#!X.#-&
M-#0R,SDL"B`@("`@("`@,'@R13!"-#0X,BP@,'A!-#@T,C`P-"P@,'@V.4,X
M1C`T02P@,'@Y13%&.4(U12P*("`@("`@("`P>#(Q0S8V.#0R+"`P>$8V13DV
M0SE!+"`P>#8W,$,Y0S8Q+"`P>$%"1#,X.$8P+`H@("`@("`@(#!X-D$U,4$P
M1#(L(#!X1#@U-#)&-C@L(#!X.38P1D$W,C@L(#!X04(U,3,S03,L"B`@("`@
M("`@,'@V145&,$(V0RP@,'@Q,S=!,T)%-"P@,'A"03-"1C`U,"P@,'@W149"
M,D$Y."P*("`@("`@("`P>$$Q1C$V-3%$+"`P>#,Y048P,3<V+"`P>#8V0T$U
M.3-%+"`P>#@R-#,P13@X+`H@("`@("`@(#!X.$-%13@V,3DL(#!X-#4V1CE&
M0C0L(#!X-T0X-$$U0S,L(#!X,T(X0C5%0D4L"B`@("`@("`@,'A%,#9&-S5$
M."P@,'@X-4,Q,C`W,RP@,'@T,#%!-#0Y1BP@,'@U-D,Q-D%!-BP*("`@("`@
M("`P>#1%1#-!038R+"`P>#,V,T8W-S`V+"`P>#%"1D5$1C<R+"`P>#0R.4(P
M,C-$+`H@("`@("`@(#!X,S=$,$0W,C0L(#!X1#`P03$R-#@L(#!X1$(P1D5!
M1#,L(#!X-#E&,4,P.4(L"B`@("`@("`@,'@P-S4S-S)#.2P@,'@X,#DY,4(W
M0BP@,'@R-40T-SE$."P@,'A&-D4X1$5&-RP*("`@("`@("`P>$4S1D4U,#%!
M+"`P>$(V-SDT0S-"+"`P>#DW-D-%,$)$+"`P>#`T0S`P-D)!+`H@("`@("`@
M(#!X0S%!.31&0C8L(#!X-#`Y1C8P0S0L(#!X-44U0SE%0S(L(#!X,3DV03(T
M-C,L"B`@("`@("`@,'@V.$9"-D9!1BP@,'@S139#-3-"-2P@,'@Q,S,Y0C)%
M0BP@,'@S0C4R14,V1BP*("`@("`@("`P>#9$1D,U,3%&+"`P>#E",S`Y-3)#
M+"`P>$-#.#$T-30T+"`P>$%&-45"1#`Y+`H@("`@("`@(#!X0D5%,T0P,#0L
M(#!X1$4S,S1!1D0L(#!X-C8P1C(X,#<L(#!X,3DR131"0C,L"B`@("`@("`@
M,'A#,$-"03@U-RP@,'@T-4,X-S0P1BP@,'A$,C!"-48S.2P@,'A".40S1D)$
M0BP*("`@("`@("`P>#4U-SE#,$)$+"`P>#%!-C`S,C!!+"`P>$0V03$P,$,V
M+"`P>#0P,D,W,C<Y+`H@("`@("`@(#!X-C<Y1C(U1D4L(#!X1D(Q1D$S0T,L
M(#!X.$5!-44Y1C@L(#!X1$(S,C(R1C@L"B`@("`@("`@,'@S0S<U,39$1BP@
M,'A&1#8Q-D(Q-2P@,'@R1C4P,45#."P@,'A!1#`U-3)!0BP*("`@("`@("`P
M>#,R,T1"-49!+"`P>$9$,C,X-S8P+"`P>#4S,S$W0C0X+"`P>#-%,#!$1C@R
M+`H@("`@("`@(#!X.44U0S4W0D(L(#!X0T$V1CA#03`L(#!X,4$X-S4V,D4L
M(#!X1$8Q-S8Y1$(L"B`@("`@("`@,'A$-30R03A&-BP@,'@R.#=%1D9#,RP@
M,'A!0S8W,S)#-BP@,'@X0S1&-34W,RP*("`@("`@("`P>#8Y-4(R-T(P+"`P
M>$)"0T$U.$,X+"`P>$4Q1D9!,S5$+"`P>$(X1C`Q,4$P+`H@("`@("`@(#!X
M,3!&03-$.3@L(#!X1D0R,3@S0C@L(#!X-$%&0T(U-D,L(#!X,D1$,40S-4(L
M"B`@("`@("`@,'@Y034S130W.2P@,'A"-D8X-#4V-2P@,'A$,CA%-#E"0RP@
M,'@T0D9".3<Y,"P*("`@("`@("`P>$4Q1$1&,D1!+"`P>$$T0T(W13,S+"`P
M>#8R1D(Q,S0Q+"`P>$-%131#-D4X+`H@("`@("`@(#!X148R,$-!1$$L(#!X
M,S8W-S1#,#$L(#!X1#`W13E%1D4L(#!X,D)&,3%&0C0L"B`@("`@("`@,'@Y
M-41"1$$T1"P@,'A!13DP.3$Y."P@,'A%04%$.$4W,2P@,'@V0CDS1#5!,"P*
M("`@("`@("`P>$0P.$5$,40P+"`P>$%&0S<R-44P+"`P>#A%,T,U0C)&+"`P
M>#A%-S4Y-$(W+`H@("`@("`@(#!X.$9&-D4R1D(L(#!X1C(Q,C)"-C0L(#!X
M.#@X.$(X,3(L(#!X.3`P1$8P,4,L"B`@("`@("`@,'@T1D%$-45!,"P@,'@V
M.#A&0S,Q0RP@,'A$,4-&1C$Y,2P@,'A",T$X0S%!1"P*("`@("`@("`P>#)&
M,D8R,C$X+"`P>$)%,$4Q-S<W+"`P>$5!-S4R1$9%+"`P>#A",#(Q1D$Q+`H@
M("`@("`@(#!X135!,$-#,$8L(#!X0C4V1C<T13@L(#!X,3A!0T8S1#8L(#!X
M0T4X.44R.3DL"B`@("`@("`@,'A"-$$X-$9%,"P@,'A&1#$S13!"-RP@,'@W
M0T,T,T(X,2P@,'A$,D%$03A$.2P*("`@("`@("`P>#$V-49!,C8V+"`P>#@P
M.34W-S`U+"`P>#DS0T,W,S$T+"`P>#(Q,4$Q-#<W+`H@("`@("`@(#!X139!
M1#(P-C4L(#!X-S="-49!.#8L(#!X0S<U-#0R1C4L(#!X1D(Y1#,U0T8L"B`@
M("`@("`@,'A%0D-$048P0RP@,'@W0C-%.#E!,"P@,'A$-C0Q,4)$,RP@,'A!
M13%%-T4T.2P*("`@("`@("`P>#`P,C4P13)$+"`P>#(P-S%",S5%+"`P>#(R
M-C@P,$)"+"`P>#4W0CA%,$%&+`H@("`@("`@(#!X,C0V-#,V.4(L(#!X1C`P
M.4(Y,44L(#!X-34V,SDQ,40L(#!X-3E$1D$V04$L"B`@("`@("`@,'@W.$,Q
M-#,X.2P@,'A$.35!-3,W1BP@,'@R,#=$-4)!,BP@,'@P,D4U0CE#-2P*("`@
M("`@("`P>#@S,C8P,S<V+"`P>#8R.35#1D$Y+"`P>#$Q0S@Q.38X+"`P>#1%
M-S,T030Q+`H@("`@("`@(#!X0C,T-S)$0T$L(#!X-T(Q-$$Y-$$L(#!X,4(U
M,3`P-3(L(#!X.4$U,S(Y,34L"B`@("`@("`@,'A$-C!&-3<S1BP@,'A"0SE"
M0S9%-"P@,'@R0C8P030W-BP@,'@X,44V-S0P,"P*("`@("`@("`P>#`X0D$V
M1D(U+"`P>#4W,4)%.3%&+"`P>$8R.39%0S9"+"`P>#)!,$1$.3$U+`H@("`@
M("`@(#!X0C8V,S8U,C$L(#!X13=".48Y0C8L(#!X1D8S-#`U,D4L(#!X0S4X
M-34V-C0L"B`@("`@("`@,'@U,T(P,D0U1"P@,'A!.3E&.$9!,2P@,'@P.$)!
M-#<Y.2P@,'@V13@U,#<V02D["@H@("`@+RHJ"B`@("`@*B!3($)O>"`H<S(I
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',R
M(#T@87)R87DH"B`@("`@("`@,'@T0C=!-S!%.2P@,'A"-4(S,CDT-"P@,'A$
M0C<U,#DR12P@,'A#-#$Y,C8R,RP*("`@("`@("`P>$%$-D5!-D(P+"`P>#0Y
M03=$1C=$+"`P>#E#144V,$(X+"`P>#A&141",C8V+`H@("`@("`@(#!X14-!
M03A#-S$L(#!X-CDY03$W1D8L(#!X-38V-#4R-D,L(#!X0S)",3E%13$L"B`@
M("`@("`@,'@Q.3,V,#)!-2P@,'@W-3`Y-$,R.2P@,'A!,#4Y,3,T,"P@,'A%
M-#$X,T$S12P*("`@("`@("`P>#-&-30Y.#E!+"`P>#5"-#(Y1#8U+"`P>#9"
M.$9%-$0V+"`P>#DY1C<S1D0V+`H@("`@("`@(#!X03%$,CE#,#<L(#!X149%
M.#,P1C4L(#!X-$0R1#,X138L(#!X1C`R-35$0S$L"B`@("`@("`@,'@T0T1$
M,C`X-BP@,'@X-#<P14(R-BP@,'@V,S@R13E#-BP@,'@P,C%%0T,U12P*("`@
M("`@("`P>#`Y-C@V0C-&+"`P>#-%0D%%1D,Y+"`P>#-#.3<Q.#$T+"`P>#9"
M-D$W,$$Q+`H@("`@("`@(#!X-C@W1C,U.#0L(#!X-3)!,$4R.#8L(#!X0C<Y
M0S4S,#4L(#!X04$U,#`W,S<L"B`@("`@("`@,'@S13`W.#0Q0RP@,'@W1D1%
M044U0RP@,'@X13=$-#1%0RP@,'@U-S$V1C)"."P*("`@("`@("`P>$(P,T%$
M03,W+"`P>$8P-3`P0S!$+"`P>$8P,4,Q1C`T+"`P>#`R,#!",T9&+`H@("`@
M("`@(#!X044P0T8U,4$L(#!X,T-"-3<T0C(L(#!X,C4X,S=!-3@L(#!X1$,P
M.3(Q0D0L"B`@("`@("`@,'A$,3DQ,3-&.2P@,'@W0T$Y,D9&-BP@,'@Y-#,R
M-#<W,RP@,'@R,D8U-#<P,2P*("`@("`@("`P>#-!135%-3@Q+"`P>#,W0S)$
M041#+"`P>$,X0C4W-C,T+"`P>#E!1C-$1$$W+`H@("`@("`@(#!X03DT-#8Q
M-#8L(#!X,$9$,#`S,$4L(#!X14-#.$,W,T4L(#!X030W-3%%-#$L"B`@("`@
M("`@,'A%,C,X0T0Y.2P@,'@S0D5!,$4R1BP@,'@S,C@P0D)!,2P@,'@Q.#-%
M0C,S,2P*("`@("`@("`P>#1%-30X0C,X+"`P>#1&-D1".3`X+"`P>#9&-#(P
M1#`S+"`P>$8V,$$P-$)&+`H@("`@("`@(#!X,D-".#$R.3`L(#!X,C0Y-S=#
M-SDL(#!X-38W.4(P-S(L(#!X0D-!1C@Y048L"B`@("`@("`@,'A$13E!-S<Q
M1BP@,'A$.3DS,#@Q,"P@,'A",SA"044Q,BP@,'A$0T-&,T8R12P*("`@("`@
M("`P>#4U,3(W,C%&+"`P>#)%-D(W,3(T+"`P>#4P,4%$1$4V+"`P>#E&.#1#
M1#@W+`H@("`@("`@(#!X-T$U.#0W,3@L(#!X-S0P.$1!,3<L(#!X0D,Y1CE!
M0D,L(#!X13DT0C=$.$,L"B`@("`@("`@,'A%0S=!14,S02P@,'A$0C@U,41&
M02P@,'@V,S`Y-#,V-BP@,'A#-#8T0S-$,BP*("`@("`@("`P>$5&,4,Q.#0W
M+"`P>#,R,35$.3`X+"`P>$1$-#,S0C,W+"`P>#(T0S)"03$V+`H@("`@("`@
M(#!X,3)!,31$-#,L(#!X,D$V-4,T-3$L(#!X-3`Y-#`P,#(L(#!X,3,S044T
M1$0L"B`@("`@("`@,'@W,41&1C@Y12P@,'@Q,#,Q-$4U-2P@,'@X,4%#-S=$
M-BP@,'@U1C$Q,3DY0BP*("`@("`@("`P>#`T,S4U-D8Q+"`P>$0W03-#-S9"
M+"`P>#-#,3$Q.#-"+"`P>#4Y,C1!-3`Y+`H@("`@("`@(#!X1C(X1D4V140L
M(#!X.3=&,49"1D$L(#!X.45"04)&,D,L(#!X,44Q-3-#-D4L"B`@("`@("`@
M,'@X-D4S-#4W,"P@,'A%044Y-D9",2P@,'@X-C!%-44P02P@,'@U03-%,D%"
M,RP*("`@("`@("`P>#<W,49%-S%#+"`P>#1%,T0P-D9!+"`P>#(Y-C5$0T(Y
M+"`P>#DY13<Q1#!&+`H@("`@("`@(#!X.#`S13@Y1#8L(#!X-3(V-D,X,C4L
M(#!X,D4T0T,Y-S@L(#!X.4,Q,$(S-D$L"B`@("`@("`@,'A#-C$U,$5"02P@
M,'@Y-$4R14$W."P@,'A!-49#,T,U,RP@,'@Q13!!,D1&-"P*("`@("`@("`P
M>$8R1C<T14$W+"`P>#,V,40R0C-$+"`P>#$Y,SDR-C!&+"`P>#$Y0S(W.38P
M+`H@("`@("`@(#!X-3(R,T$W,#@L(#!X1C<Q,S$R0C8L(#!X14)!1$9%-D4L
M(#!X14%#,S%&-C8L"B`@("`@("`@,'A%,T)#-#4Y-2P@,'A!-C="0S@X,RP@
M,'A",3=&,S=$,2P@,'@P,3A#1D8R."P*("`@("`@("`P>$,S,S)$1$5&+"`P
M>$)%-D,U04$U+"`P>#8U-3@R,3@U+"`P>#8X04(Y.#`R+`H@("`@("`@(#!X
M145#14$U,$8L(#!X1$(R1CDU,T(L(#!X,D%%1C=$040L(#!X-4(V13)&.#0L
M"B`@("`@("`@,'@Q-3(Q0C8R."P@,'@R.3`W-C$W,"P@,'A%0T1$-#<W-2P@
M,'@V,3E&,34Q,"P*("`@("`@("`P>#$S0T-!.#,P+"`P>$5"-C%"1#DV+"`P
M>#`S,S1&13%%+"`P>$%!,#,V,T-&+`H@("`@("`@(#!X0C4W,S5#.3`L(#!X
M-$,W,$$R,SDL(#!X1#4Y13E%,$(L(#!X0T)!041%,30L"B`@("`@("`@,'A%
M14-#.#9"0RP@,'@V,#8R,D-!-RP@,'@Y0T%"-4-!0BP@,'A",D8S.#0V12P*
M("`@("`@("`P>#8T.$(Q14%&+"`P>#$Y0D1&,$-!+"`P>$$P,C,V.4(Y+"`P
M>#8U-4%"0C4P+`H@("`@("`@(#!X-#`V.#5!,S(L(#!X,T,R04(T0C,L(#!X
M,S$Y144Y1#4L(#!X0S`R,4(X1C<L"B`@("`@("`@,'@Y0C4T,$(Q.2P@,'@X
M-S5&03`Y.2P@,'@Y-48W.3DW12P@,'@V,C-$-T1!."P*("`@("`@("`P>$8X
M,S<X.#E!+"`P>#DW13,R1#<W+"`P>#$Q140Y,S5&+"`P>#$V-C@Q,C@Q+`H@
M("`@("`@(#!X,$4S-3@X,CDL(#!X0S=%-C%&1#8L(#!X.39$141&03$L(#!X
M-S@U.$)!.3DL"B`@("`@("`@,'@U-T8U.#1!-2P@,'@Q0C(R-S(V,RP@,'@Y
M0C@S0S-&1BP@,'@Q04,R-#8Y-BP*("`@("`@("`P>$-$0C,P045"+"`P>#4S
M,D4S,#4T+"`P>#A&1#DT.$4T+"`P>#9$0D,S,3(X+`H@("`@("`@(#!X-3A%
M0D8R148L(#!X,S1#-D9&14$L(#!X1D4R.$5$-C$L(#!X144W0S-#-S,L"B`@
M("`@("`@,'@U1#1!,31$.2P@,'A%.#8T0C=%,RP@,'@T,C$P-40Q-"P@,'@R
M,#-%,3-%,"P*("`@("`@("`P>#0U145%,D(V+"`P>$$S04%!0D5!+"`P>$1"
M-D,T1C$U+"`P>$9!0T(T1D0P+`H@("`@("`@(#!X0S<T,D8T-#(L(#!X148V
M04)"0C4L(#!X-C4T1C-",40L(#!X-#%#1#(Q,#4L"B`@("`@("`@,'A$.#%%
M-SDY12P@,'@X-C@U-$1#-RP@,'A%-#1"-#<V02P@,'@S1#@Q-C(U,"P*("`@
M("`@("`P>$-&-C)!,48R+"`P>#5".$0R-C0V+"`P>$9#.#@X,T$P+"`P>$,Q
M0S="-D$S+`H@("`@("`@(#!X-T8Q-3(T0S,L(#!X-CE#0C<T.3(L(#!X-#<X
M-#A!,$(L(#!X-38Y,D(R.#4L"B`@("`@("`@,'@P.35"0D8P,"P@,'A!1#$Y
M-#@Y1"P@,'@Q-#8R0C$W-"P@,'@R,S@R,$4P,"P*("`@("`@("`P>#4X-#(X
M1#)!+"`P>#!#-35&-45!+"`P>#%$041&-#-%+"`P>#(S,T8W,#8Q+`H@("`@
M("`@(#!X,S,W,D8P.3(L(#!X.$0Y,S=%-#$L(#!X1#8U1D5#1C$L(#!X-D,R
M,C-"1$(L"B`@("`@("`@,'@W0T1%,S<U.2P@,'A#0D5%-S0V,"P@,'@T,#@U
M1C)!-RP@,'A#13<W,S(V12P*("`@("`@("`P>$$V,#<X,#@T+"`P>#$Y1C@U
M,#E%+"`P>$4X149$.#4U+"`P>#8Q1#DY-S,U+`H@("`@("`@(#!X03DV.4$W
M04$L(#!X0S4P0S`V0S(L(#!X-4$P-$%"1D,L(#!X.#`P0D-!1$,L"B`@("`@
M("`@,'@Y130T-T$R12P@,'A#,S0U,S0X-"P@,'A&1$0U-C<P-2P@,'@P13%%
M.45#.2P*("`@("`@("`P>$1"-S-$0D0S+"`P>#$P-34X.$-$+"`P>#8W-49$
M03<Y+"`P>$4S-C<T,S0P+`H@("`@("`@(#!X0S5#-#,T-C4L(#!X-S$S13,X
M1#@L(#!X,T0R.$8X.44L(#!X1C$V1$9&,C`L"B`@("`@("`@,'@Q-3-%,C%%
M-RP@,'@X1D(P,T0T02P@,'A%-D4S.48R0BP@,'A$0C@S041&-RD["@H@("`@
M+RHJ"B`@("`@*B!3($)O>"`H<S,I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)',S(#T@87)R87DH"B`@("`@("`@,'A%.3-$
M-4$V."P@,'@Y-#@Q-#!&-RP@,'A&-C1#,C8Q0RP@,'@Y-#8Y,CDS-"P*("`@
M("`@("`P>#0Q,34R,$8W+"`P>#<V,#)$-$8W+"`P>$)#1C0V0C)%+"`P>$0T
M03(P,#8X+`H@("`@("`@(#!X1#0P.#(T-S$L(#!X,S,R,$8T-D$L(#!X-#-"
M-T0T0C<L(#!X-3`P,#8Q048L"B`@("`@("`@,'@Q13,Y1C8R12P@,'@Y-S(T
M-#4T-BP@,'@Q-#(Q-$8W-"P@,'A"1CA".#@T,"P*("`@("`@("`P>#1$.35&
M0S%$+"`P>#DV0C4Y,4%&+"`P>#<P1C1$1$0S+"`P>#8V03`R1C0U+`H@("`@
M("`@(#!X0D9"0S`Y14,L(#!X,#-"1#DW.#4L(#!X-T9!0S9$1#`L(#!X,S%#
M0C@U,#0L"B`@("`@("`@,'@Y-D5",C=",RP@,'@U-49$,SDT,2P@,'A$03(U
M-#=%-BP@,'A!0D-!,$$Y02P*("`@("`@("`P>#(X-3`W.#(U+"`P>#4S,#0R
M.48T+"`P>#!!,D,X-D1!+"`P>$4Y0C8V1$9"+`H@("`@("`@(#!X-CA$0S$T
M-C(L(#!X1#<T.#8Y,#`L(#!X-C@P14,P030L(#!X,C=!,3A$144L"B`@("`@
M("`@,'@T1C-&1D5!,BP@,'A%.#@W040X0RP@,'A"-3A#13`P-BP@,'@W048T
M1#9"-BP*("`@("`@("`P>$%!0T4Q13=#+"`P>$0S,S<U1D5#+"`P>$-%-SA!
M,SDY+"`P>#0P-D(R030R+`H@("`@("`@(#!X,C!&13E%,S4L(#!X1#E&,S@U
M0CDL(#!X144S.40W04(L(#!X,T(Q,C1%.$(L"B`@("`@("`@,'@Q1$,Y1D%&
M-RP@,'@T0C9$,3@U-BP@,'@R-D$S-C8S,2P@,'A%044S.3=",BP*("`@("`@
M("`P>#-!-D5&03<T+"`P>$1$-4(T,S,R+"`P>#8X-#%%-T8W+"`P>$-!-S@R
M,$9"+`H@("`@("`@(#!X1D(P048U-$4L(#!X1#A&14(S.3<L(#!X-#4T,#4V
M04,L(#!X0D$T.#DU,C<L"B`@("`@("`@,'@U-34S,T$S02P@,'@R,#@S.$0X
M-RP@,'A&139"03E"-RP@,'A$,#DV.34T0BP*("`@("`@("`P>#4U03@V-T)#
M+"`P>$$Q,34Y034X+"`P>$-#03DR.38S+"`P>#DY13%$0C,S+`H@("`@("`@
M(#!X038R031!-38L(#!X,T8S,3(U1CDL(#!X-45&-#=%,4,L(#!X.3`R.3,Q
M-T,L"B`@("`@("`@,'A&1$8X13@P,BP@,'@P-#(W,D8W,"P@,'@X,$)",34U
M0RP@,'@P-3(X,D-%,RP*("`@("`@("`P>#DU0S$Q-30X+"`P>$4T0S8V1#(R
M+"`P>#0X0S$Q,S-&+"`P>$,W,$8X-D1#+`H@("`@("`@(#!X,#=&.4,Y144L
M(#!X-#$P-#%&,$8L(#!X-#`T-S<Y030L(#!X-40X.#9%,3<L"B`@("`@("`@
M,'@S,C5&-3%%0BP@,'A$-3E"0S!$,2P@,'A&,D)#0S$X1BP@,'@T,3$Q,S4V
M-"P*("`@("`@("`P>#(U-T(W.#,T+"`P>#8P,D$Y0S8P+"`P>$1&1CA%.$$S
M+"`P>#%&-C,V0S%"+`H@("`@("`@(#!X,$4Q,D(T0S(L(#!X,#)%,3,R.44L
M(#!X048V-C1&1#$L(#!X0T%$,3@Q,34L"B`@("`@("`@,'@V0C(S.35%,"P@
M,'@S,S-%.3)%,2P@,'@S0C(T,$(V,BP@,'A%14)%0CDR,BP*("`@("`@("`P
M>#@U0C)!,C!%+"`P>$4V0D$P1#DY+"`P>$1%-S(P0SA#+"`P>#)$03)&-S(X
M+`H@("`@("`@(#!X1#`Q,C<X-#4L(#!X.35"-SDT1D0L(#!X-C0W1#`X-C(L
M(#!X13=#0T8U1C`L"B`@("`@("`@,'@U-#0Y03,V1BP@,'@X-S=$-#A&02P@
M,'A#,SE$1D0R-RP@,'A&,S-%.$0Q12P*("`@("`@("`P>#!!-#<V,S0Q+"`P
M>#DY,D5&1C<T+"`P>#-!-D8V14%"+"`P>$8T1CA&1#,W+`H@("`@("`@(#!X
M03@Q,D1#-C`L(#!X03%%0D1$1C@L(#!X.3DQ0D4Q-$,L(#!X1$(V139",$0L
M"B`@("`@("`@,'A#-C="-34Q,"P@,'@V1#8W,D,S-RP@,'@R-S8U1#0S0BP@
M,'A$0T0P13@P-"P*("`@("`@("`P>$8Q,CDP1$,W+"`P>$-#,#!&1D$S+"`P
M>$(U,SDP1CDR+"`P>#8Y,$9%1#!"+`H@("`@("`@(#!X-C8W0CE&1D(L(#!X
M0T5$0C=$.4,L(#!X03`Y,4-&,$(L(#!X1#DQ-35%03,L"B`@("`@("`@,'A"
M0C$S,D8X."P@,'@U,35"040R-"P@,'@W0CDT-SE"1BP@,'@W-C-"1#9%0BP*
M("`@("`@("`P>#,W,SDR14(S+"`P>$-#,3$U.3<Y+"`P>#@P,C9%,CDW+"`P
M>$8T,D4S,3)$+`H@("`@("`@(#!X-C@T,D%$03<L(#!X0S8V03)",T(L(#!X
M,3(W-31#0T,L(#!X-S@R148Q,4,L"B`@("`@("`@,'@V03$R-#(S-RP@,'A"
M-SDR-3%%-RP@,'@P-D$Q0D)%-BP@,'@T0D9"-C,U,"P*("`@("`@("`P>#%!
M-D(Q,#$X+"`P>#$Q0T%%1$9!+"`P>#-$,C5"1$0X+"`P>$4R13%#,T,Y+`H@
M("`@("`@(#!X-#0T,C$V-3DL(#!X,$$Q,C$S.#8L(#!X1#DP0T5#-D4L(#!X
M1#5!0D5!,D$L"B`@("`@("`@,'@V-$%&-C<T12P@,'A$03@V03@U1BP@,'A"
M14)&13DX."P@,'@V-$4T0S-&12P*("`@("`@("`P>#E$0D,X,#4W+"`P>$8P
M1C=#,#@V+"`P>#8P-S@W0D8X+"`P>#8P,#,V,#1$+`H@("`@("`@(#!X1#%&
M1#@S-#8L(#!X1C8S.#%&0C`L(#!X-S<T-4%%,#0L(#!X1#<S-D9#0T,L"B`@
M("`@("`@,'@X,S0R-D(S,RP@,'A&,#%%04(W,2P@,'A",#@P-#$X-RP@,'@S
M0S`P-44U1BP*("`@("`@("`P>#<W03`U-T)%+"`P>$)$13A!13(T+"`P>#4U
M-#8T,CDY+"`P>$)&-3@R138Q+`H@("`@("`@(#!X-$4U.$8T.$8L(#!X1C)$
M1$9$03(L(#!X1C0W-$5&,S@L(#!X.#<X.4)$0S(L"B`@("`@("`@,'@U,S8V
M1CE#,RP@,'A#.$(S.$4W-"P@,'A"-#<U1C(U-2P@,'@T-D9#1#E".2P*("`@
M("`@("`P>#=!14(R-C8Q+"`P>#A",41$1C@T+"`P>#@T-D$P13<Y+"`P>#DQ
M-48Y-44R+`H@("`@("`@(#!X-#8V134Y.$4L(#!X,C!"-#4W-S`L(#!X.$-$
M-34U.3$L(#!X0SDP,D1%-$,L"B`@("`@("`@,'A".3!"04-%,2P@,'A"0C@R
M,#5$,"P@,'@Q,4$X-C(T."P@,'@W-3<T03DY12P*("`@("`@("`P>$(W-T8Q
M.4(V+"`P>$4P03E$0S`Y+"`P>#8V,D0P.4$Q+"`P>$,T,S(T-C,S+`H@("`@
M("`@(#!X13@U03%&,#(L(#!X,#E&,$)%.$,L(#!X-$$Y.4$P,C4L(#!X,40V
M149%,3`L"B`@("`@("`@,'@Q04(Y,T0Q1"P@,'@P0D$U031$1BP@,'A!,3@V
M1C(P1BP@,'@R.#8X1C$V.2P*("`@("`@("`P>$1#0C=$03@S+"`P>#4W,SDP
M-D9%+"`P>$$Q13)#13E"+"`P>#1&0T0W1C4R+`H@("`@("`@(#!X-3`Q,35%
M,#$L(#!X03<P-C@S1D$L(#!X03`P,D(U0S0L(#!X,$1%-D0P,C<L"B`@("`@
M("`@,'@Y048X.$,R-RP@,'@W-S-&.#8T,2P@,'A#,S8P-$,P-BP@,'@V,4$X
M,#9"-2P*("`@("`@("`P>$8P,3<W03(X+"`P>$,P1C4X-D4P+"`P>#`P-C`U
M.$%!+"`P>#,P1$,W1#8R+`H@("`@("`@(#!X,3%%-CE%1#<L(#!X,C,S.$5!
M-C,L(#!X-3-#,D1$.30L(#!X0S)#,C$V,S0L"B`@("`@("`@,'A"0D-"144U
M-BP@,'@Y,$)#0C9$12P@,'A%0D9#-T1!,2P@,'A#134Y,40W-BP*("`@("`@
M("`P>#9&,#5%-#`Y+"`P>#1"-T,P,3@X+"`P>#,Y-S(P03-$+"`P>#=#.3(W
M0S(T+`H@("`@("`@(#!X.#9%,S<R-48L(#!X-S(T1#E$0CDL(#!X,4%#,35"
M0C0L(#!X1#,Y14(X1D,L"B`@("`@("`@,'A%1#4T-34W."P@,'@P.$9#035"
M-2P@,'A$.#-$-T-$,RP@,'@T1$%$,$9#-"P*("`@("`@("`P>#%%-3!%1C5%
M+"`P>$(Q-C%%-D8X+"`P>$$R.#4Q-$0Y+"`P>#9#-3$Q,S-#+`H@("`@("`@
M(#!X-D9$-4,W13<L(#!X-39%,31%0S0L(#!X,S8R04)&0T4L(#!X1$1#-D,X
M,S<L"B`@("`@("`@,'A$-SE!,S(S-"P@,'@Y,C8S.#(Q,BP@,'@V-S!%1D$X
M12P@,'@T,#8P,#!%,"D["@H@("`@+RHJ"B`@("`@*B!3($)O>"`H<S0I"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',T(#T@
M87)R87DH"B`@("`@("`@,'@S03,Y0T4S-RP@,'A$,T9!1C5#1BP@,'A!0D,R
M-S<S-RP@,'@U04,U,D0Q0BP*("`@("`@("`P>#5#0C`V-SE%+"`P>#1&03,S
M-S0R+"`P>$0S.#(R-S0P+"`P>#DY0D,Y0D)%+`H@("`@("`@(#!X1#4Q,3A%
M.40L(#!X0D8P1C<S,34L(#!X1#8R1#%#-T4L(#!X0S<P,$,T-T(L"B`@("`@
M("`@,'A"-SA#,4(V0BP@,'@R,4$Q.3`T-2P@,'A",C9%0C%"12P@,'@V03,V
M-D5"-"P*("`@("`@("`P>#4W-#A!0C)&+"`P>$)#.30V13<Y+"`P>$,V03,W
M-D0R+"`P>#8U-#E#,D,X+`H@("`@("`@(#!X-3,P1D8X144L(#!X-#8X1$1%
M-T0L(#!X1#4W,S!!,40L(#!X-$-$,#1$0S8L"B`@("`@("`@,'@R.3,Y0D)$
M0BP@,'A!.4)!-#8U,"P@,'A!0SDU,C9%."P@,'A"135%13,P-"P*("`@("`@
M("`P>$$Q1D%$-48P+"`P>#9!,D0U,3E!+"`P>#8S148X0T4R+"`P>#E!.#9%
M13(R+`H@("`@("`@(#!X0S`X.4,R0C@L(#!X-#,R-#)%1C8L(#!X034Q13`S
M04$L(#!X.4-&,D0P030L"B`@("`@("`@,'@X,T,P-C%"02P@,'@Y0D4Y-D$T
M1"P@,'@X1D4U,34U,"P@,'A"038T-4)$-BP*("`@("`@("`P>#(X,C9!,D8Y
M+"`P>$$W,T$S044Q+"`P>#1"03DY-3@V+"`P>$5&-34V,D4Y+`H@("`@("`@
M(#!X0S<R1D5&1#,L(#!X1C<U,D8W1$$L(#!X,T8P-#9&-CDL(#!X-S=&03!!
M-3DL"B`@("`@("`@,'@X,$4T03DQ-2P@,'@X-T(P.#8P,2P@,'@Y0C`Y139!
M1"P@,'@S0C-%134Y,RP*("`@("`@("`P>$4Y.3!&1#5!+"`P>#E%,S1$-SDW
M+"`P>#)#1C!"-T0Y+"`P>#`R,D(X0C4Q+`H@("`@("`@(#!X.39$-4%#,T$L
M(#!X,#$W1$$V-T0L(#!X1#%#1C-%1#8L(#!X-T,W1#)$,C@L"B`@("`@("`@
M,'@Q1CE&,C5#1BP@,'A!1$8R0C@Y0BP@,'@U040V0C0W,BP@,'@U03@X1C4T
M0RP*("`@("`@("`P>$4P,CE!0S<Q+"`P>$4P,3E!-44V+"`P>#0W0C!!0T9$
M+"`P>$5$.3-&03E"+`H@("`@("`@(#!X13A$,T,T.$0L(#!X,C@S0C4W0T,L
M(#!X1CA$-38V,CDL(#!X-SDQ,S)%,C@L"B`@("`@("`@,'@W.#5&,#$Y,2P@
M,'A%1#<U-C`U-2P@,'A&-SDV,$4T-"P@,'A%,T0S-44X0RP*("`@("`@("`P
M>#$U,#4V1$0T+"`P>#@X1C0V1$)!+"`P>#`S03$V,3(U+"`P>#`U-C1&,$)$
M+`H@("`@("`@(#!X0S-%0CE%,34L(#!X,T,Y,#4W03(L(#!X.3<R-S%!14,L
M(#!X03DS03`W,D$L"B`@("`@("`@,'@Q0C-&-D0Y0BP@,'@Q138S,C%&-2P@
M,'A&-3E#-C9&0BP@,'@R-D1#1C,Q.2P*("`@("`@("`P>#<U,S-$.3(X+"`P
M>$(Q-35&1$8U+"`P>#`S-38S-#@R+"`P>#A!0D$S0T)"+`H@("`@("`@(#!X
M,C@U,3<W,3$L(#!X0S(P040Y1C@L(#!X04)#0S4Q-C<L(#!X0T-!1#DR-48L
M"B`@("`@("`@,'@T1$4X,3<U,2P@,'@S.#,P1$,X12P@,'@S-SE$-3@V,BP@
M,'@Y,S(P1CDY,2P*("`@("`@("`P>$5!-T$Y,$,R+"`P>$9",T4W0D-%+"`P
M>#4Q,C%#138T+"`P>#<W-$9"13,R+`H@("`@("`@(#!X03A"-D4S-T4L(#!X
M0S,R.3-$-#8L(#!X-#A$134S-CDL(#!X-C0Q,T4V.#`L"B`@("`@("`@,'A!
M,D%%,#@Q,"P@,'A$1#9$0C(R-"P@,'@V.3@U,D1&1"P@,'@P.3`W,C$V-BP*
M("`@("`@("`P>$(S.4$T-C!!+"`P>#8T-#5#,$1$+"`P>#4X-D-$14-&+"`P
M>#%#,C!#.$%%+`H@("`@("`@(#!X-4)"148W1$0L(#!X,4(U.#A$-#`L(#!X
M0T-$,C`Q-T8L(#!X-D)"-$4S0D(L"B`@("`@("`@,'A$1$$R-D$W12P@,'@S
M034Y1D8T-2P@,'@S13,U,$$T-"P@,'A"0T(T0T1$-2P*("`@("`@("`P>#<R
M14%#14$X+"`P>$9!-C0X-$)"+"`P>#A$-C8Q,D%%+"`P>$)&,T,V1C0W+`H@
M("`@("`@(#!X1#(Y0D4T-C,L(#!X-30R1C5$.44L(#!X045#,C<W,4(L(#!X
M1C8T138S-S`L"B`@("`@("`@,'@W-#!%,$0X1"P@,'A%-S5",3,U-RP@,'A&
M.#<R,38W,2P@,'A!1C4S-T0U1"P*("`@("`@("`P>#0P-#!#0C`X+"`P>#1%
M0C1%,D-#+"`P>#,T1#(T-C9!+"`P>#`Q,35!1C@T+`H@("`@("`@(#!X13%"
M,#`T,C@L(#!X.34Y.#-!,40L(#!X,#9".#E&0C0L(#!X0T4V14$P-#@L"B`@
M("`@("`@,'@V1C-&,T(X,BP@,'@S-3(P04(X,BP@,'@P,3%!,40T0BP@,'@R
M-S<R,C=&."P*("`@("`@("`P>#8Q,34V,$(Q+"`P>$4W.3,S1D1#+"`P>$)"
M,T$W.3)"+"`P>#,T-#4R-4)$+`H@("`@("`@(#!X03`X.#,Y13$L(#!X-3%#
M13<Y-$(L(#!X,D8S,D,Y0C<L(#!X03`Q1D)!0SDL"B`@("`@("`@,'A%,#%#
M0S@W12P@,'A"0T,W1#%&-BP@,'A#1C`Q,3%#,RP@,'A!,44X04%#-RP*("`@
M("`@("`P>#%!.3`X-S0Y+"`P>$0T-$9"1#E!+"`P>$0P1$%$14-"+"`P>$0U
M,$%$03,X+`H@("`@("`@(#!X,#,S.4,S,D$L(#!X0S8Y,3,V-C<L(#!X.$1&
M.3,Q-T,L(#!X13!",3)"-$8L"B`@("`@("`@,'A&-SE%-3E"-RP@,'@T,T8U
M0D(S02P@,'A&,D0U,3E&1BP@,'@R-T0Y-#4Y0RP*("`@("`@("`P>$)&.3<R
M,C)#+"`P>#$U139&0S)!+"`P>#!&.3%&0S<Q+"`P>#E".30Q-3(U+`H@("`@
M("`@(#!X1D%%-3DS-C$L(#!X0T5"-CE#14(L(#!X0S)!.#8T-3DL(#!X,3)"
M04$X1#$L"B`@("`@("`@,'A"-D,Q,#<U12P@,'A%,S`U-D$P0RP@,'@Q,$0R
M-3`V-2P@,'A#0C`S030T,BP*("`@("`@("`P>$4P14,V13!%+"`P>#$V.3A$
M0C-"+"`P>#1#.3A!,$)%+"`P>#,R-SA%.38T+`H@("`@("`@(#!X.48Q1CDU
M,S(L(#!X13!$,SDR1$8L(#!X1#-!,#,T,D(L(#!X.#DW,48R,44L"B`@("`@
M("`@,'@Q0C!!-S0T,2P@,'@T0D$S,S0X0RP@,'A#-4)%-S$R,"P@,'A#,S<V
M,S)$."P*("`@("`@("`P>$1&,S4Y1CA$+"`P>#E".3DR1C)%+"`P>$4V,$(V
M1C0W+"`P>#!&13-&,3%$+`H@("`@("`@(#!X134T0T1!-30L(#!X,45$040X
M.3$L(#!X0T4V,C<Y0T8L(#!X0T0S13=%-D8L"B`@("`@("`@,'@Q-C$X0C$V
M-BP@,'A&1#)#,40P-2P@,'@X-#A&1#)#-2P@,'A&-D9",C(Y.2P*("`@("`@
M("`P>$8U,C-&,S4W+"`P>$$V,S(W-C(S+"`P>#DS03@S-3,Q+"`P>#4V0T-#
M1#`R+`H@("`@("`@(#!X04-&,#@Q-C(L(#!X-4$W-45"0C4L(#!X-D4Q-C,V
M.3<L(#!X.#A$,C<S0T,L"B`@("`@("`@,'A$13DV-C(Y,BP@,'@X,4(Y-#E$
M,"P@,'@T0S4P.3`Q0BP@,'@W,4,V-38Q-"P*("`@("`@("`P>$4V0S9#-T)$
M+"`P>#,R-T$Q-#!!+"`P>#0U13%$,#`V+"`P>$,S1C(W0CE!+`H@("`@("`@
M(#!X0SE!034S1D0L(#!X-C)!.#!&,#`L(#!X0D(R-4)&13(L(#!X,S5"1$0R
M1C8L"B`@("`@("`@,'@W,3$R-CDP-2P@,'A",C`T,#(R,BP@,'A"-D-"0T8W
M0RP@,'A#1#<V.4,R0BP*("`@("`@("`P>#4S,3$S14,P+"`P>#$V-#!%,T0S
M+"`P>#,X04)"1#8P+"`P>#(U-#=!1$8P+`H@("`@("`@(#!X0D$S.#(P.4,L
M(#!X1C<T-D-%-S8L(#!X-S=!1D$Q0S4L(#!X,C`W-38P-C`L"B`@("`@("`@
M,'@X-4-"1D4T12P@,'@X044X.$1$."P@,'@W04%!1CE","P@,'@T0T8Y04$W
M12P*("`@("`@("`P>#$Y-#A#,C5#+"`P>#`R1D(X03A#+"`P>#`Q0S,V044T
M+"`P>$0V14)%,48Y+`H@("`@("`@(#!X.3!$-$8X-CDL(#!X038U0T1%03`L
M(#!X,T8P.3(U,D0L(#!X0S(P.$4V.48L"B`@("`@("`@,'A"-S1%-C$S,BP@
M,'A#13<W13(U0BP@,'@U-SA&1$9%,RP@,'@S04,S-S)%-BD["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O=6YD<R!T;R!D;PH@("`@("H*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]R;W5N9',@/2`Q
M-CL*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:V5Y('1O(&)E('5S960@9F]R
M(&5N+V1E8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:V5Y("!4:&4@:V5Y('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M2V5Y*"1K97DI"B`@("!["B`@("`@("`@)&ME>2`]("1T:&ES+3Y?9F]R;6%T
M2V5Y*"1K97DI.PH@("`@("`@("1K97E0;W,@/2`P.PH@("`@("`@("1K97E8
M;W(@/2`P.PH*("`@("`@("`D:4UA>"`](&-O=6YT*"1T:&ES+3YP*3L*("`@
M("`@("`D:V5Y3&5N(#T@8V]U;G0H)&ME>2D["B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&E-87@[("1I*RLI('L*("`@("`@("`@("`@9F]R("@D="`]
M(#`[("1T(#P@-#L@)'0K*RD@>PH@("`@("`@("`@("`@("`@)&ME>5AO<B`]
M("@D:V5Y6&]R(#P\(#@I('P@*"@D:V5Y6R1K97E0;W-=*2`F(#!X,&9F*3L*
M("`@("`@("`@("`@("`@(&EF("@K*R1K97E0;W,@/3T@)&ME>4QE;BD@>PH@
M("`@("`@("`@("`@("`@("`@("1K97E0;W,@/2`P.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YP6R1I72`]
M("1T:&ES+3YP6R1I72!>("1K97E8;W(["B`@("`@("`@?0H*("`@("`@("`D
M96YC6F5R;R`](&%R<F%Y*"=,)R`]/B`P+"`G4B<@/3X@,"D["B`@("`@("`@
M9F]R("@D:2`](#`[("1I("L@,2`\("1I36%X.R`D:2`K/2`R*2!["B`@("`@
M("`@("`@("1E;F-:97)O(#T@)'1H:7,M/E]E;F-R>7!T0FQO8VLH)&5N8UIE
M<F];)TPG72P@)&5N8UIE<F];)U(G72D["B`@("`@("`@("`@("1T:&ES+3YP
M6R1I72`]("1E;F-:97)O6R=,)UT["B`@("`@("`@("`@("1T:&ES+3YP6R1I
M("L@,5T@/2`D96YC6F5R;ULG4B==.PH@("`@("`@('T*"B`@("`@("`@)&E-
M87@@/2!C;W5N="@D=&AI<RT^<S$I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1I36%X.R`D:2`K/2`R*2!["B`@("`@("`@("`@("1E;F-:97)O(#T@
M)'1H:7,M/E]E;F-R>7!T0FQO8VLH)&5N8UIE<F];)TPG72P@)&5N8UIE<F];
M)U(G72D["B`@("`@("`@("`@("1T:&ES+3YS,5LD:5T@/2`D96YC6F5R;ULG
M3"==.PH@("`@("`@("`@("`D=&AI<RT^<S%;)&D@*R`Q72`]("1E;F-:97)O
M6R=2)UT["B`@("`@("`@?0H*("`@("`@("`D:4UA>"`](&-O=6YT*"1T:&ES
M+3YS,BD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&E-87@[("1I("L]
M(#(I('L*("`@("`@("`@("`@)&5N8UIE<F\@/2`D=&AI<RT^7V5N8W)Y<'1"
M;&]C:R@D96YC6F5R;ULG3"==+"`D96YC6F5R;ULG4B==*3L*("`@("`@("`@
M("`@)'1H:7,M/G,R6R1I72`]("1E;F-:97)O6R=,)UT["B`@("`@("`@("`@
M("1T:&ES+3YS,ELD:2`K(#%=(#T@)&5N8UIE<F];)U(G73L*("`@("`@("!]
M"@H@("`@("`@("1I36%X(#T@8V]U;G0H)'1H:7,M/G,S*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D:4UA>#L@)&D@*ST@,BD@>PH@("`@("`@("`@
M("`D96YC6F5R;R`]("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,
M)UTL("1E;F-:97)O6R=2)UTI.PH@("`@("`@("`@("`D=&AI<RT^<S-;)&E=
M(#T@)&5N8UIE<F];)TPG73L*("`@("`@("`@("`@)'1H:7,M/G,S6R1I("L@
M,5T@/2`D96YC6F5R;ULG4B==.PH@("`@("`@('T*"B`@("`@("`@)&E-87@@
M/2!C;W5N="@D=&AI<RT^<S0I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1I36%X.R`D:2`K/2`R*2!["B`@("`@("`@("`@("1E;F-:97)O(#T@)'1H
M:7,M/E]E;F-R>7!T0FQO8VLH)&5N8UIE<F];)TPG72P@)&5N8UIE<F];)U(G
M72D["B`@("`@("`@("`@("1T:&ES+3YS-%LD:5T@/2`D96YC6F5R;ULG3"==
M.PH@("`@("`@("`@("`D=&AI<RT^<S1;)&D@*R`Q72`]("1E;F-:97)O6R=2
M)UT["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!S:7IE(&]F('1H92!B;&]C:W,@=&AA="!T:&ES(&-I<&AE<B!N965D<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@
M8VAA<F%C=&5R<R!P97(@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$)L;V-K4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N(#@["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@("`@(%1H92!D871A('1O
M(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@("`@(%1H
M92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@96YC<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC
M<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+
M97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("!L:7-T*"1,+"`D4BD@/2!A
M<G)A>5]V86QU97,H=6YP86-K*"=.*B<L("1B;&]C:RDI.PH@("`@("`@("1P
M87)T<R`]("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1,+"`D4BD["B`@("`@("`@
M<F5T=7)N('!A8VLH)TY.)RP@)'!A<G1S6R=,)UTL("1P87)T<ULG4B==*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@;&5F="!A;F0@<FEG:'0@
M:&%L=F5S(&]F(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D3"`@
M3&5F="!H86QF(&]F('1H92!D871A+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)%(@(%)I9VAT(&AA;&8@;V8@=&AE(&1A=&$N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@02!H87-H+"!W:71H(&ME>7,@)TPG(&%N9"`G4B<L(&%N
M9"!T:&4@96YC<GEP=&5D(&1A=&$@87,*("`@("`J("`@("`@("`@("`@("`@
M('1H92!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E;F-R>7!T0FQO
M8VLH)$PL("12*0H@("`@>PH@("`@("`@("1,(%X]("1T:&ES+3YP6S!=.PH@
M("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@
M*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;
M*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@
M7B`D=&AI<RT^<%LQ73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12
M(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F
M9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^
M<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,ET["B`@("`@("`@)%(@7CT@
M*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH
M)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P
M>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S-=
M.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&
M1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^
M<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F
M72D@7B`D=&AI<RT^<%LT73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;
M*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P
M>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI
M<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;-5T["B`@("`@("`@)$P@
M7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS
M,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@
M)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP
M6S9=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@
M,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI
M<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X
M,&9F72D@7B`D=&AI<RT^<%LW73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^
M<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@
M)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D
M=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;.%T["B`@("`@("`@
M)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES
M+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@
M."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES
M+3YP6SE=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I
M("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D
M=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F
M(#!X,&9F72D@7B`D=&AI<RT^<%LQ,%T["B`@("`@("`@)%(@7CT@*"@H)'1H
M:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@
M,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI
M("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S$Q73L*("`@
M("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@
M)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D
M4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@
M)'1H:7,M/G!;,3)=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@
M/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F
M72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS
M-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,UT["B`@("`@("`@)$P@7CT@
M*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH
M)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P
M>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S$T
M73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X
M1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M
M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F
M9ETI(%X@)'1H:7,M/G!;,35=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS
M,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F
M(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T
M:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ-ET["B`@("`@("`@
M)%(@7CT@)'1H:7,M/G!;,3==.PH*("`@("`@("!R971U<FX@87)R87DH)TPG
M(#T^("12+"`G4B<@/3X@)$PI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C
M<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8FQO8VL@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1K97D@("`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@;W5T<'5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96-R>7!T0FQO8VLH)&)L;V-K+"`D:V5Y(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@
M("`@(&QI<W0H)$PL("12*2`](&%R<F%Y7W9A;'5E<RAU;G!A8VLH)TXJ)RP@
M)&)L;V-K*2D["@H@("`@("`@("1,(%X]("1T:&ES+3YP6S$W73L*("`@("`@
M("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H
M:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^
M/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H
M:7,M/G!;,39=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@
M,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@
M7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD
M4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ-5T["B`@("`@("`@)%(@7CT@*"@H
M)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@
M/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F
M9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S$T73L*
M("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=
M("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S
M6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI
M(%X@)'1H:7,M/G!;,3-=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH
M)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X
M,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES
M+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,ET["B`@("`@("`@)$P@
M7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS
M,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@
M)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP
M6S$Q73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F
M(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H
M:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P
M>#!F9ETI(%X@)'1H:7,M/G!;,3!=.PH@("`@("`@("1,(%X]("@H*"1T:&ES
M+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V
M*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K
M("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LY73L*("`@("`@
M("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H
M:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^
M/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H
M:7,M/G!;.%T["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R
M-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>
M("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12
M("8@,'@P9F9=*2!>("1T:&ES+3YP6S==.PH@("`@("`@("12(%X]("@H*"1T
M:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^
M(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=
M*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LV73L*("`@
M("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@
M)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D
M4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@
M)'1H:7,M/G!;-5T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^
M/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=
M*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T
M6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S1=.PH@("`@("`@("1,(%X]("@H
M*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12
M(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P
M9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LS73L*
M("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=
M("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S
M6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI
M(%X@)'1H:7,M/G!;,ET["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D
M4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P
M9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M
M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S%=.PH*("`@("`@("`D9&5C
M<GEP=&5D(#T@<&%C:R@B3DXB+"`D4B!>("1T:&ES+3YP6S!=+"`D3"D["B`@
M("`@("`@<F5T=7)N("1D96-R>7!T960["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T<R!A('1E>'0@:V5Y(&EN=&\@86X@87)R87DN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!+97D@:6X@=&5X="!F;W)M870N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&ME>2!I;B!A<G)A
M>2!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;W)M871+97DH)&ME
M>2D*("`@('L*("`@("`@("!R971U<FX@87)R87E?=F%L=65S*'5N<&%C:R@G
M0RHG+"`D:V5Y*2D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92YP:'``````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C(R`#$P-3$U-#,Q,#8Q`#`R
M,C`P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-I<&AE<E]";&]C:TUO9&4Z.B!C
M;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C=&5D"B`J(&EN=&5R9F%C
M92!T;R!V87)I;W5S(&)L;V-K(&UO9&4@:&%N9&QE<G,@9F]R(&-I<&AE<G,N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-
M;V1E+G!H<"QV(#$N,30N,3(N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP
M:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O
M*BH*("`@("`J(%1H92!I;FET:6%L:7IA=&EO;B!V96-T;W(N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:78@/2`B7#!<
M,%PP7#!<,%PP7#!<,"(["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!C;VYC<F5T92!(;W)D95]#:7!H97)?0FQO8VM-;V1E(&EN<W1A
M;F-E(&)A<V5D(&]N"B`@("`@*B`D;6]D92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M;V1E("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?
M0VEP:&5R7T)L;V-K36]D90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('-U8F-L87-S('1O(')E='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!P87)A;65T
M97)S(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!M
M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0VEP:&5R
M7T)L;V-K36]D92`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0VEP:&5R0FQO8VM-
M;V1E(&EN<W1A;F-E+"!O<B!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@D;6]D92P@)'!A<F%M<R`](&YU;&PI"B`@("![
M"B`@("`@("`@)&UO9&4@/2!B87-E;F%M92@D;6]D92D["B`@("`@("`@:68@
M*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O0FQO8VM-;V1E
M+R<@+B`D;6]D92`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]";&]C:TUO9&4O)R`N("1M;V1E
M("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E
M7T-I<&AE<E]";&]C:TUO9&5?)R`N("1M;V1E.PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D8FQO8VMM;V1E(#T@
M)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&)L;V-K;6]D92`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E
M9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1B;&]C:VUO9&4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@=&AE($E6"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:78@(%1H92!N97<@258N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$E6*"1I=BD*("`@('L*("`@("`@("`D=&AI<RT^7VEV(#T@)&EV.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]D97,N<&AP````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S(P,@`Q,#4Q-30S,3`V,0`P,C`W,34`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!#:7!H97)?9&5S.CH@8VQA<W,@:6UP;&5M96YT<R!T
M:&4@0VEP:&5R(&EN=&5R9F%C92!E;F-R>7!T:6]N(&1A=&$*("H@=7-I;F<@
M=&AE($1A=&$@16YC<GEP=&EO;B!3=&%N9&%R9"`H1$53*2!A;&=O<FET:&T@
M87,@9&5F:6YE(&EN($9)4%,T-BTS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]#:7!H97(O0VEP:&5R+V1E<RYP:'`L=B`Q+C0N,3(N-R`R,#`V+S`Q+S`Q
M(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?9&5S
M(&5X=&5N9',@2&]R9&5?0VEP:&5R('L*"B`@("`O*BH*("`@("`J($EN:71I
M86P@4&5R;75T871I;VX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D:7`@/2!A<G)A>2@*("`@("`@("`U."P@-3`L(#0R+"`S
M-"P@,C8L(#$X+"`Q,"P@(#(L"B`@("`@("`@-C`L(#4R+"`T-"P@,S8L(#(X
M+"`R,"P@,3(L("`T+`H@("`@("`@(#8R+"`U-"P@-#8L(#,X+"`S,"P@,C(L
M(#$T+"`@-BP*("`@("`@("`V-"P@-38L(#0X+"`T,"P@,S(L(#(T+"`Q-BP@
M(#@L"B`@("`@("`@-3<L(#0Y+"`T,2P@,S,L(#(U+"`Q-RP@(#DL("`Q+`H@
M("`@("`@(#4Y+"`U,2P@-#,L(#,U+"`R-RP@,3DL(#$Q+"`@,RP*("`@("`@
M("`V,2P@-3,L(#0U+"`S-RP@,CDL(#(Q+"`Q,RP@(#4L"B`@("`@("`@-C,L
M(#4U+"`T-RP@,SDL(#,Q+"`R,RP@,34L("`W"B`@("`I.PH*("`@("\J*@H@
M("`@("H@1FEN86P@4&5R;75T871I;VX@25!>+3$*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9G`@/2!A<G)A>2@*("`@("`@
M("`T,"P@(#@L(#0X+"`Q-BP@-38L(#(T+"`V-"P@,S(L"B`@("`@("`@,SDL
M("`W+"`T-RP@,34L(#4U+"`R,RP@-C,L(#,Q+`H@("`@("`@(#,X+"`@-BP@
M-#8L(#$T+"`U-"P@,C(L(#8R+"`S,"P*("`@("`@("`S-RP@(#4L(#0U+"`Q
M,RP@-3,L(#(Q+"`V,2P@,CDL"B`@("`@("`@,S8L("`T+"`T-"P@,3(L(#4R
M+"`R,"P@-C`L(#(X+`H@("`@("`@(#,U+"`@,RP@-#,L(#$Q+"`U,2P@,3DL
M(#4Y+"`R-RP*("`@("`@("`S-"P@(#(L(#0R+"`Q,"P@-3`L(#$X+"`U."P@
M,C8L"B`@("`@("`@,S,L("`Q+"`T,2P@(#DL(#0Y+"`Q-RP@-3<L(#(U"B`@
M("`I.PH*("`@("\J*@H@("`@("H@12!":70@4V5L96-T:6]N(%1A8FQE"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&4@/2!A
M<G)A>2@*("`@("`@("`S,BP@(#$L("`R+"`@,RP@(#0L("`U+`H@("`@("`@
M("`T+"`@-2P@(#8L("`W+"`@."P@(#DL"B`@("`@("`@(#@L("`Y+"`Q,"P@
M,3$L(#$R+"`Q,RP*("`@("`@("`Q,BP@,3,L(#$T+"`Q-2P@,38L(#$W+`H@
M("`@("`@(#$V+"`Q-RP@,3@L(#$Y+"`R,"P@,C$L"B`@("`@("`@,C`L(#(Q
M+"`R,BP@,C,L(#(T+"`R-2P*("`@("`@("`R-"P@,C4L(#(V+"`R-RP@,C@L
M(#(Y+`H@("`@("`@(#(X+"`R.2P@,S`L(#,Q+"`S,BP@(#$*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!3(&)O>&5S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]S(#T@87)R87DH"B`@("`@("`@+RH@4S$@
M*B\*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@(#$T+"`@-"P@,3,L
M("`Q+"`@,BP@,34L(#$Q+"`@."P@(#,L(#$P+"`@-BP@,3(L("`U+"`@.2P@
M(#`L("`W+`H@("`@("`@("`@("`P+"`Q-2P@(#<L("`T+"`Q-"P@(#(L(#$S
M+"`@,2P@,3`L("`V+"`Q,BP@,3$L("`Y+"`@-2P@(#,L("`X+`H@("`@("`@
M("`@("`T+"`@,2P@,30L("`X+"`Q,RP@(#8L("`R+"`Q,2P@,34L(#$R+"`@
M.2P@(#<L("`S+"`Q,"P@(#4L("`P+`H@("`@("`@("`@(#$U+"`Q,BP@(#@L
M("`R+"`@-"P@(#DL("`Q+"`@-RP@(#4L(#$Q+"`@,RP@,30L(#$P+"`@,"P@
M(#8L(#$S"B`@("`@("`@*2P*"B`@("`@("`@+RH@4S(@*B\*("`@("`@("`R
M(#T^(&%R<F%Y*`H@("`@("`@("`@(#$U+"`@,2P@(#@L(#$T+"`@-BP@,3$L
M("`S+"`@-"P@(#DL("`W+"`@,BP@,3,L(#$R+"`@,"P@(#4L(#$P+`H@("`@
M("`@("`@("`S+"`Q,RP@(#0L("`W+"`Q-2P@(#(L("`X+"`Q-"P@,3(L("`P
M+"`@,2P@,3`L("`V+"`@.2P@,3$L("`U+`H@("`@("`@("`@("`P+"`Q-"P@
M(#<L(#$Q+"`Q,"P@(#0L(#$S+"`@,2P@(#4L("`X+"`Q,BP@(#8L("`Y+"`@
M,RP@(#(L(#$U+`H@("`@("`@("`@(#$S+"`@."P@,3`L("`Q+"`@,RP@,34L
M("`T+"`@,BP@,3$L("`V+"`@-RP@,3(L("`P+"`@-2P@,30L("`Y+`H@("`@
M("`@("DL"@H@("`@("`@("\J(%,S("HO"B`@("`@("`@,R`]/B!A<G)A>2@*
M("`@("`@("`@("`Q,"P@(#`L("`Y+"`Q-"P@(#8L("`S+"`Q-2P@(#4L("`Q
M+"`Q,RP@,3(L("`W+"`Q,2P@(#0L("`R+"`@."P*("`@("`@("`@("`Q,RP@
M(#<L("`P+"`@.2P@(#,L("`T+"`@-BP@,3`L("`R+"`@."P@(#4L(#$T+"`Q
M,BP@,3$L(#$U+"`@,2P*("`@("`@("`@("`Q,RP@(#8L("`T+"`@.2P@(#@L
M(#$U+"`@,RP@(#`L(#$Q+"`@,2P@(#(L(#$R+"`@-2P@,3`L(#$T+"`@-RP*
M("`@("`@("`@("`@,2P@,3`L(#$S+"`@,"P@(#8L("`Y+"`@."P@(#<L("`T
M+"`Q-2P@,30L("`S+"`Q,2P@(#4L("`R+"`Q,BP*("`@("`@("`I+`H*("`@
M("`@("`O*B!3-"`J+PH@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@
M(#<L(#$S+"`Q-"P@(#,L("`P+"`@-BP@(#DL(#$P+"`@,2P@(#(L("`X+"`@
M-2P@,3$L(#$R+"`@-"P@,34L"B`@("`@("`@("`@,3,L("`X+"`Q,2P@(#4L
M("`V+"`Q-2P@(#`L("`S+"`@-"P@(#<L("`R+"`Q,BP@(#$L(#$P+"`Q-"P@
M(#DL"B`@("`@("`@("`@,3`L("`V+"`@.2P@(#`L(#$R+"`Q,2P@(#<L(#$S
M+"`Q-2P@(#$L("`S+"`Q-"P@(#4L("`R+"`@."P@(#0L"B`@("`@("`@("`@
M(#,L(#$U+"`@,"P@(#8L(#$P+"`@,2P@,3,L("`X+"`@.2P@(#0L("`U+"`Q
M,2P@,3(L("`W+"`@,BP@,30L"B`@("`@("`@*2P*"B`@("`@("`@+RH@4S4@
M*B\*("`@("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`R+"`Q,BP@(#0L
M("`Q+"`@-RP@,3`L(#$Q+"`@-BP@(#@L("`U+"`@,RP@,34L(#$S+"`@,"P@
M,30L("`Y+`H@("`@("`@("`@(#$T+"`Q,2P@(#(L(#$R+"`@-"P@(#<L(#$S
M+"`@,2P@(#4L("`P+"`Q-2P@,3`L("`S+"`@.2P@(#@L("`V+`H@("`@("`@
M("`@("`T+"`@,BP@(#$L(#$Q+"`Q,"P@,3,L("`W+"`@."P@,34L("`Y+"`Q
M,BP@(#4L("`V+"`@,RP@(#`L(#$T+`H@("`@("`@("`@(#$Q+"`@."P@,3(L
M("`W+"`@,2P@,30L("`R+"`Q,RP@(#8L(#$U+"`@,"P@(#DL(#$P+"`@-"P@
M(#4L("`S+`H@("`@("`@("DL"@H@("`@("`@("\J(%,V("HO"B`@("`@("`@
M-B`]/B!A<G)A>2@*("`@("`@("`@("`Q,BP@(#$L(#$P+"`Q-2P@(#DL("`R
M+"`@-BP@(#@L("`P+"`Q,RP@(#,L("`T+"`Q-"P@(#<L("`U+"`Q,2P*("`@
M("`@("`@("`Q,"P@,34L("`T+"`@,BP@(#<L(#$R+"`@.2P@(#4L("`V+"`@
M,2P@,3,L(#$T+"`@,"P@,3$L("`S+"`@."P*("`@("`@("`@("`@.2P@,30L
M(#$U+"`@-2P@(#(L("`X+"`Q,BP@(#,L("`W+"`@,"P@(#0L(#$P+"`@,2P@
M,3,L(#$Q+"`@-BP*("`@("`@("`@("`@-"P@(#,L("`R+"`Q,BP@(#DL("`U
M+"`Q-2P@,3`L(#$Q+"`Q-"P@(#$L("`W+"`@-BP@(#`L("`X+"`Q,RP*("`@
M("`@("`I+`H*("`@("`@("`O*B!3-R`J+PH@("`@("`@(#<@/3X@87)R87DH
M"B`@("`@("`@("`@(#0L(#$Q+"`@,BP@,30L(#$U+"`@,"P@(#@L(#$S+"`@
M,RP@,3(L("`Y+"`@-RP@(#4L(#$P+"`@-BP@(#$L"B`@("`@("`@("`@,3,L
M("`P+"`Q,2P@(#<L("`T+"`@.2P@(#$L(#$P+"`Q-"P@(#,L("`U+"`Q,BP@
M(#(L(#$U+"`@."P@(#8L"B`@("`@("`@("`@(#$L("`T+"`Q,2P@,3,L(#$R
M+"`@,RP@(#<L(#$T+"`Q,"P@,34L("`V+"`@."P@(#`L("`U+"`@.2P@(#(L
M"B`@("`@("`@("`@(#8L(#$Q+"`Q,RP@(#@L("`Q+"`@-"P@,3`L("`W+"`@
M.2P@(#4L("`P+"`Q-2P@,30L("`R+"`@,RP@,3(L"B`@("`@("`@*2P*"B`@
M("`@("`@+RH@4S@@*B\*("`@("`@("`X(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`Q,RP@(#(L("`X+"`@-"P@(#8L(#$U+"`Q,2P@(#$L(#$P+"`@.2P@(#,L
M(#$T+"`@-2P@(#`L(#$R+"`@-RP*("`@("`@("`@("`@(#$L(#$U+"`Q,RP@
M(#@L(#$P+"`@,RP@(#<L("`T+"`Q,BP@(#4L("`V+"`Q,2P@(#`L(#$T+"`@
M.2P@(#(L"B`@("`@("`@("`@("`W+"`Q,2P@(#0L("`Q+"`@.2P@,3(L(#$T
M+"`@,BP@(#`L("`V+"`Q,"P@,3,L(#$U+"`@,RP@(#4L("`X+`H@("`@("`@
M("`@("`@,BP@(#$L(#$T+"`@-RP@(#0L(#$P+"`@."P@,3,L(#$U+"`Q,BP@
M(#DL("`P+"`@,RP@(#4L("`V+"`Q,0H@("`@("`@("D*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!0<FEM:71I=F4@9G5N8W1I;VX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<"`](&%R<F%Y*`H@("`@("`@
M(#$V+"`@-RP@,C`L(#(Q+`H@("`@("`@(#(Y+"`Q,BP@,C@L(#$W+`H@("`@
M("`@("`Q+"`Q-2P@,C,L(#(V+`H@("`@("`@("`U+"`Q."P@,S$L(#$P+`H@
M("`@("`@("`R+"`@."P@,C0L(#$T+`H@("`@("`@(#,R+"`R-RP@(#,L("`Y
M+`H@("`@("`@(#$Y+"`Q,RP@,S`L("`V+`H@("`@("`@(#(R+"`Q,2P@(#0L
M(#(U"B`@("`I.PH*("`@("\J*@H@("`@("H@4&5R;75T960@0VAO:6-E(%1A
M8FQE"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)'!C,2`](&%R<F%Y*`H@("`@("`@(#4W+"`T.2P@-#$L(#,S+"`R-2P@,3<L
M("`Y+`H@("`@("`@("`Q+"`U."P@-3`L(#0R+"`S-"P@,C8L(#$X+`H@("`@
M("`@(#$P+"`@,BP@-3DL(#4Q+"`T,RP@,S4L(#(W+`H@("`@("`@(#$Y+"`Q
M,2P@(#,L(#8P+"`U,BP@-#0L(#,V+`H*("`@("`@("`V,RP@-34L(#0W+"`S
M.2P@,S$L(#(S+"`Q-2P*("`@("`@("`@-RP@-C(L(#4T+"`T-BP@,S@L(#,P
M+"`R,BP*("`@("`@("`Q-"P@(#8L(#8Q+"`U,RP@-#4L(#,W+"`R.2P*("`@
M("`@("`R,2P@,3,L("`U+"`R."P@,C`L(#$R+"`@-`H@("`@*3L*"B`@("`O
M*BH*("`@("`J($YU;6)E<B!L969T(')O=&%T:6]N<R!O9B!P8S$*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<VAI9G1S(#T@
M87)R87DH"B`@("`@("`@,2P@,2P@,BP@,BP@,BP@,BP@,BP@,BP*("`@("`@
M("`Q+"`R+"`R+"`R+"`R+"`R+"`R+"`Q"B`@("`I.PH*("`@("\J*@H@("`@
M("H@4&5R;75T960@0VAO:6-E(%1A8FQE(#(*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<&,R(#T@87)R87DH"B`@("`@("`@
M,30L(#$W+"`Q,2P@,C0L("`Q+"`@-2P*("`@("`@("`@,RP@,C@L(#$U+"`@
M-BP@,C$L(#$P+`H@("`@("`@(#(S+"`Q.2P@,3(L("`T+"`R-BP@(#@L"B`@
M("`@("`@,38L("`W+"`R-RP@,C`L(#$S+"`@,BP*("`@("`@("`T,2P@-3(L
M(#,Q+"`S-RP@-#<L(#4U+`H@("`@("`@(#,P+"`T,"P@-3$L(#0U+"`S,RP@
M-#@L"B`@("`@("`@-#0L(#0Y+"`S.2P@-38L(#,T+"`U,RP*("`@("`@("`T
M-BP@-#(L(#4P+"`S-BP@,CDL(#,R"B`@("`I.PH*("`@("\J*@H@("`@("H@
M2V5Y(%-C:&5D=6QE"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]+<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!3970@
M=&AE(&ME>2!T;R!B92!U<V5D(&9O<B!E;B]D96-R>7!T:6]N+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@5&AE(&ME>2!T;R!U<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$ME>2@D:V5Y*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7TMS
M(#T@)'1H:7,M/E]K97E38VAE9'5L92@D:V5Y*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I>F4@;V8@=&AE(&)L;V-K
M<R!T:&%T('1H:7,@8VEP:&5R(&YE961S+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!C:&%R86-T97)S('!E<B!B;&]C
M:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VM3:7IE*"D*("`@('L*
M("`@("`@("!R971U<FX@.#L*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y
M<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&)L;V-K("!4:&4@9&%T82!T;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D(&]U='!U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@96YC<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?2W,@/2`D=&AI<RT^7VME>5-C:&5D=6QE*"1K97DI
M.PH@("`@("`@('T*"B`@("`@("`@)&)L;V-K(#T@)'1H:7,M/E]I;FET:6%L
M4&5R;2@D8FQO8VLI.PH*("`@("`@("`D3"`]('-U8G-T<B@D8FQO8VLL(#`L
M(#0I.PH@("`@("`@("12(#T@<W5B<W1R*"1B;&]C:RP@-"P@-"D["@H@("`@
M("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`Q-CL@)&DK*R`I('L*("`@("`@("`@
M("`@)%)?<')E=B`]("12.PH@("`@("`@("`@("`D3%]P<F5V(#T@)$P["@H@
M("`@("`@("`@("`D3"`]("12.PH@("`@("`@("`@("`D4B`]("1,7W!R978@
M7B`D=&AI<RT^7V8H)%)?<')E=BP@)&DI.PH@("`@("`@('T*"B`@("`@("`@
M)&)L;V-K(#T@)%(@+B`D3#L*("`@("`@("`D8FQO8VL@/2`D=&AI<RT^7V9I
M;F%L4&5R;2@D8FQO8VLI.PH*("`@("`@("!R971U<FX@)&)L;V-K.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O
M(&1E8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME
M>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D
M96-R>7!T960@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T
M0FQO8VLH)&)L;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("`D8FQO
M8VL@/2`D=&AI<RT^7VEN:71I86Q097)M*"1B;&]C:RD["@H@("`@("`@(&EF
M("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7TMS(#T@
M)'1H:7,M/E]K97E38VAE9'5L92@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@
M("1,(#T@<W5B<W1R*"1B;&]C:RP@,"P@-"D["B`@("`@("`@)%(@/2!S=6)S
M='(H)&)L;V-K+"`T+"`T*3L*"B`@("`@("`@9F]R("@D:2`](#$V.R`D:2`^
M/2`Q.R`D:2TM("D@>PH@("`@("`@("`@("`D4E]P<F5V(#T@)%(["B`@("`@
M("`@("`@("1,7W!R978@/2`D3#L*"B`@("`@("`@("`@("1,(#T@)%)?<')E
M=CL*("`@("`@("`@("`@)%(@/2`D3%]P<F5V(%X@)'1H:7,M/E]F*"127W!R
M978L("1I*3L*("`@("`@("!]"@H@("`@("`@("1B;&]C:R`]("12("X@)$P[
M"B`@("`@("`@)&)L;V-K(#T@)'1H:7,M/E]F:6YA;%!E<FTH)&)L;V-K*3L*
M"B`@("`@("`@<F5T=7)N("1B;&]C:SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%!U="!A;B!I;G!U="!S=')I;F<@=&AR;W5G:"!A;B!I;FET:6%L('!E<FUU
M=&%T:6]N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@($EN
M<'5T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4&5R
M;75T871E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET:6%L
M4&5R;2@D:6YP=70I"B`@("!["B`@("`@("`@+R\@5$]$3SH@4V]M92!S='EL
M:64@8FET=VES92!T:&EN9R!I;G-T96%D+@H*("`@("`@("`D:6YP=71?8FEN
M(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@.#L@)&DK*RD@>PH@
M("`@("`@("`@("`D:6YP=71?8FEN("X]('-T<E]P860H9&5C8FEN*&]R9"@D
M:6YP=71;)&E=*2DL(#@L("<P)RP@4U127U!!1%],1494*3L*("`@("`@("!]
M"@H@("`@("`@("1O=71P=71?8FEN(#T@)R<["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/FEP(&%S("1O9F9S970I('L*("`@("`@("`@("`@)&]U='!U=%]B
M:6X@+CT@)&EN<'5T7V)I;ELD;V9F<V5T("T@,5T["B`@("`@("`@?0H*("`@
M("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M.#L@)&DK*RD@>PH@("`@("`@("`@("`D;W5T<'5T("X](&-H<BAB:6YD96,H
M<W5B<W1R*"1O=71P=71?8FEN+"`X("H@)&DL(#@I*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!U="!A;B!I;G!U="!S=')I;F<@=&AR;W5G:"!A(&9I;F%L('!E<FUU=&%T
M:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!);G!U
M="!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%!E<FUU
M=&%T960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9FEN86Q097)M
M*"1I;G!U="D*("`@('L*("`@("`@("`O+R!43T1/.B!3;VUE('-T>6QI92!B
M:71W:7-E('1H:6YG(&EN<W1E860N"B`@("`@("`@)&EN<'5T7V)I;B`]("<G
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[("1I*RLI('L*("`@("`@
M("`@("`@)&EN<'5T7V)I;B`N/2!S=')?<&%D*&1E8V)I;BAO<F0H)&EN<'5T
M6R1I72DI+"`X+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@?0H*("`@
M("`@("`D;W5T<'5T7V)I;B`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YF<"!A<R`D;V9F<V5T*2!["B`@("`@("`@("`@("1O=71P=71?8FEN("X]
M("1I;G!U=%]B:6Y;)&]F9G-E="`M(#%=.PH@("`@("`@('T*"B`@("`@("`@
M)&]U='!U="`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[("1I
M*RLI('L*("`@("`@("`@("`@)&]U='!U="`N/2!C:'(H8FEN9&5C*'-U8G-T
M<B@D;W5T<'5T7V)I;BP@."`J("1I+"`X*2DI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O=71P=70["B`@("!]"@H*("`@("\J*@H@("`@("H@9B@I
M(%1H92!P97)M=71A=&EO;B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I;G!U="`@26YP=70@<W1R:6YG+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)')O=6YD("!4:&4@<F]U;F0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!O=71P=70@<W1R:6YG+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9B@D:6YP=70L("1R;W5N9"D*("`@('L*("`@("`@("`O+R!4
M3T1/.B!3;VUE('-T>6QI92!B:71W:7-E('1H:6YG(&EN<W1E860N"B`@("`@
M("`@)&ME>2`]("1T:&ES+3Y?2W-;)')O=6YD73L*"B`@("`@("`@)&EN<'5T
M7V)I;B`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#0[("1I*RLI
M('L*("`@("`@("`@("`@)&EN<'5T7V)I;B`N/2!S=')?<&%D*&1E8V)I;BAO
M<F0H)&EN<'5T6R1I72DI+"`X+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@
M("`@?0H*("`@("`@("`D97AP86YD961?8FEN(#T@)R<["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/F4@87,@)&]F9G-E="D@>PH@("`@("`@("`@("`D97AP
M86YD961?8FEN("X]("1I;G!U=%]B:6Y;)&]F9G-E="`M(#%=.PH@("`@("`@
M('T*"B`@("`@("`@)&5X<&%N9&5D(#T@87)R87DH*3L*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("1E>'!A;F1E
M9%LD:5T@/2!B:6YD96,H)S`P)R`N('-U8G-T<B@D97AP86YD961?8FEN+"`D
M:2`J(#8L(#8I*2!>("1K97E;)&E=.PH@("`@("`@('T*"B`@("`@("`@)&-O
M;6)I;F5D7V)I;B`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[
M("1I*RLI('L*("`@("`@("`@("`@)'-?:6YD97@@/2`H*"1E>'!A;F1E9%LD
M:5T@)B`P>#(P*2`^/B`T*2!\("@D97AP86YD961;)&E=("8@,'@P,2D["B`@
M("`@("`@("`@("1S7VEN9&5X(#T@,38@*B`D<U]I;F1E>"`K("@H)&5X<&%N
M9&5D6R1I72`F(#!X,44I(#X^(#$I.PH@("`@("`@("`@("`D=F%L(#T@)'1H
M:7,M/E]S6R1I("L@,5U;)'-?:6YD97A=.PH@("`@("`@("`@("`D8V]M8FEN
M961?8FEN("X]('-T<E]P860H9&5C8FEN*"1V86PI+"`T+"`G,"<L(%-44E]0
M041?3$5&5"D["B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T7V)I;B`]("<G
M.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YP(&%S("1O9F9S970I('L*("`@
M("`@("`@("`@)&]U='!U=%]B:6X@+CT@)&-O;6)I;F5D7V)I;ELD;V9F<V5T
M("T@,5T["B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@-#L@)&DK*RD@>PH@("`@("`@("`@("`D
M;W5T<'5T("X](&-H<BAB:6YD96,H<W5B<W1R*"1O=71P=71?8FEN+"`D:2`J
M(#@L(#@I*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@8V]M<&QE=&4@:V5Y
M('-H961U;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!4
M:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y($ME
M>2!S8VAE9'5L92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VME>5-C:&5D=6QE
M*"1K97DI"B`@("!["B`@("`@("`@)&ME>2`]('-T<E]P860H)&ME>2P@."P@
M(EPP(BD["B`@("`@("`@)&MS(#T@87)R87DH*3L*"B`@("`@("`@)&ME>5]B
M:6X@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2![
M"B`@("`@("`@("`@("1K97E?8FEN("X]('-T<E]P860H9&5C8FEN*&]R9"@D
M:V5Y6R1I72DI+"`X+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@?0H*
M("`@("`@("`D8R`]("<G.PH@("`@("`@("1D(#T@)R<["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@,C@[("1I*RLI('L*("`@("`@("`@("`@)&,@+CT@
M)&ME>5]B:6Y;)'1H:7,M/G!C,5LD:5T@+2`Q73L*("`@("`@("`@("`@)&0@
M+CT@)&ME>5]B:6Y;)'1H:7,M/G!C,5LR."`K("1I72`M(#%=.PH@("`@("`@
M('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@,38[("1I*RLI('L*("`@
M("`@("`@("`@)&,@/2!S=6)S='(H)&,L("1T:&ES+3YS:&EF='-;)&E=*2`N
M('-U8G-T<B@D8RP@,"P@)'1H:7,M/G-H:69T<ULD:5TI.PH@("`@("`@("`@
M("`D9"`]('-U8G-T<B@D9"P@)'1H:7,M/G-H:69T<ULD:5TI("X@<W5B<W1R
M*"1D+"`P+"`D=&AI<RT^<VAI9G1S6R1I72D["@H@("`@("`@("`@("`D8V0@
M/2`D8R`N("1D.PH*("`@("`@("`@("`@)'!E<FUU=&%T961?8FEN(#T@)R<[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YP8S(@87,@)&]F9G-E="D@
M>PH@("`@("`@("`@("`@("`@)'!E<FUU=&%T961?8FEN("X]("1C9%LD;V9F
M<V5T("T@,5T["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H)&H@
M/2`P.R`D:B`\(#@[("1J*RLI('L*("`@("`@("`@("`@("`@("1K<ULD:2`K
M(#%=6UT@/2!B:6YD96,H)S`P)R`N('-U8G-T<B@D<&5R;75T871E9%]B:6XL
M("1J("H@-BP@-BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&MS.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+V-A
M<W0Q,C@N<&AP````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3,R-3,V
M`#$P-3$U-#,Q,#8Q`#`R,3,S-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($-I<&AE<E]C87-T
M,3(X.CH@8VQA<W,@:6UP;&5M96YT<R!T:&4@0VEP:&5R(&EN=&5R9F%C92!E
M;F-R>7!T:6]N(&1A=&$*("H@=7-I;F<@=&AE($-!4U0Q,C@@*&%K82!#87-T
M-2D@86QG;W)I=&AM(&%S(&1E9FEN960@:6X@4D9#,C$T-"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO0VEP:&5R+T-I<&AE<B]C87-T,3(X+G!H<"QV(#$N
M-RXQ,BXX(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@
M($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S
M($AO<F1E7T-I<&AE<E]C87-T,3(X(&5X=&5N9',@2&]R9&5?0VEP:&5R('L*
M"B`@("`O*BH*("`@("`J(%,@8F]X("AS,2D*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S$@/2!A<G)A>2@*("`@("`@("`P
M>#,P9F(T,&0T+"`P>#EF83!F9C!B+"`P>#9B96-C9#)F+"`P>#-F,C4X8S=A
M+"`P>#%E,C$S9C)F+"`P>#EC,#`T9&0S+"`P>#8P,#-E-30P+"`P>&-F.69C
M.30Y+`H@("`@("`@(#!X8F9D-&%F,C<L(#!X.#AB8F)D8C4L(#!X93(P,S0P
M.3`L(#!X.3AD,#DV-S4L(#!X-F4V,V$P93`L(#!X,35C,S8Q9#(L(#!X8S)E
M-S8V,60L(#!X,C)D-&9F.&4L"B`@("`@("`@,'@R.#8X,V(V9BP@,'AC,#=F
M9#`U.2P@,'AF9C(S-SEC."P@,'@W-S5F-3!E,BP@,'@T,V,S-#!D,RP@,'AD
M9C)F.#8U-BP@,'@X.#=C830Q82P@,'AA,F0R8F0R9"P*("`@("`@("`P>&$Q
M8SEE,&0V+"`P>#,T-F,T.#$Y+"`P>#8Q8C<V9#@W+"`P>#(R-30P9C)F+"`P
M>#)A8F4S,F4Q+"`P>&%A-30Q-C9B+"`P>#(R-38X93-A+"`P>&$R9#,T,60P
M+`H@("`@("`@(#!X-C9D8C0P8S@L(#!X83<X-#,Y,F8L(#!X,#`T9&9F,F8L
M(#!X,F1B.60R9&4L(#!X.3<Y-#-F86,L(#!X-&$Y-V,Q9#@L(#!X-3(W-C0T
M8C<L(#!X8C5F-#,W83<L"B`@("`@("`@,'AB.#)C8F%E9BP@,'AD-S4Q9#$U
M.2P@,'@V9F8W9C!E9"P@,'@U83`Y-V$Q9BP@,'@X,C=B-CAD,"P@,'@Y,&5C
M9C4R92P@,'@R,F(P8S`U-"P@,'AB8SAE-3DS-2P*("`@("`@("`P>#1B-F0R
M9C=F+"`P>#4P8F(V-&$R+"`P>&0R-C8T.3$P+"`P>&)E934X,3)D+"`P>&(W
M,S,R,CDP+"`P>&4Y,V(Q-3EF+"`P>&(T.&5E-#$Q+"`P>#1B9F8S-#5D+`H@
M("`@("`@(#!X9F0T-6,R-#`L(#!X860S,3DW,V8L(#!X8S1F-F0P,F4L(#!X
M-35F8S@Q-C4L(#!X9#5B,6-A860L(#!X83%A8S)D864L(#!X83)D-&(W-F0L
M(#!X8S$Y8C!C-3`L"B`@("`@("`@,'@X.#(R-#!F,BP@,'@P8S9E-&8S."P@
M,'AA-&4T8F9D-RP@,'@T9C5B83(W,BP@,'@U-C1C,60R9BP@,'AC-3EC-3,Q
M.2P@,'AB.30Y93,U-"P@,'AB,#0V-CEF92P*("`@("`@("`P>&(Q8C9A8CAA
M+"`P>&,W,3,U.&1D+"`P>#8S.#5C-30U+"`P>#$Q,&8Y,S5D+"`P>#4W-3,X
M860U+"`P>#9A,SDP-#DS+"`P>&4V,V0S-V4P+"`P>#)A-31F-F(S+`H@("`@
M("`@(#!X,V$W.#=D-68L(#!X-C(W-F$P8C4L(#!X,3EA-F9C9&8L(#!X-V$T
M,C(P-F$L(#!X,CEF.60T9#4L(#!X9C8Q8C$X.3$L(#!X8F(W,C(W-64L(#!X
M86$U,#@Q-C<L"B`@("`@("`@,'@S.#DP,3`Y,2P@,'AC-F(U,#5E8BP@,'@X
M-&,W8V(X8RP@,'@R860W-6$P9BP@,'@X-S1A,30R-RP@,'AA,F0Q.3,V8BP@
M,'@R860R.#9A9BP@,'AA834V9#(Y,2P*("`@("`@("`P>&0W.#DT,S8P+"`P
M>#0R-6,W-3!D+"`P>#DS8C,Y93(V+"`P>#$X-S$X-&,Y+"`P>#9C,#!B,S)D
M+"`P>#<S93)B8C$T+"`P>&$P8F5B8S-C+"`P>#4T-C(S-S<Y+`H@("`@("`@
M(#!X-C0T-3EE86(L(#!X,V8S,CAB.#(L(#!X-S<Q.&-F.#(L(#!X-3EA,F-E
M838L(#!X,#1E93`P,F4L(#!X.#EF93<X938L(#!X,V9A8C`Y-3`L(#!X,S(U
M9F8V8S(L"B`@("`@("`@,'@X,3,X,V8P-2P@,'@V.38S8S5C."P@,'@W-F-B
M-6%D-BP@,'AD-#DY-S1C.2P@,'AC83$X,&1C9BP@,'@S.#`W.#)D-2P@,'AC
M-V9A-6-F-BP@,'@X86,S,34Q,2P*("`@("`@("`P>#,U93<Y93$S+"`P>#0W
M9&$Y,60P+"`P>&8T,&8Y,#@V+"`P>&$W93(T,3EE+"`P>#,Q,S8V,C0Q+"`P
M>#`U,65F-#DU+"`P>&%A-3<S8C`T+"`P>#1A.#`U9#AD+`H@("`@("`@(#!X
M-30X,S`P9#`L(#!X,#`S,C)A,V,L(#!X8F8V-&-D9&8L(#!X8F$U-V$V.&4L
M(#!X-S5C-C,W,F(L(#!X-3!A9F0S-#$L(#!X83=C,3,R-S4L(#!X.3$U83!B
M9C4L"B`@("`@("`@,'@V8C4T8F9A8BP@,'@R8C!B,30R-BP@,'AA8C1C8SED
M-RP@,'@T-#EC8V0X,BP@,'AF-V9B9C(V-2P@,'AA8C@U8S5F,RP@,'@Q8C4U
M9&(Y-"P@,'AA860T93,R-"P*("`@("`@("`P>&-F831B9#-F+"`P>#)D96%A
M,V4R+"`P>#EE,C`T9#`R+"`P>&,X8F0R-6%C+"`P>&5A9&8U-6(S+"`P>&0U
M8F0Y93DX+"`P>&4S,3(S,6(R+"`P>#)A9#5A9#9C+`H@("`@("`@(#!X.34T
M,S(Y9&4L(#!X861B930U,C@L(#!X9#@W,3!F-CDL(#!X86$U,6,Y,&8L(#!X
M86$W.#9B9C8L(#!X,C(U,3-F,64L(#!X86$U,6$W.6(L(#!X,F%D,S0T8V,L
M"B`@("`@("`@,'@W8C5A-#%F,"P@,'AD,S=C9F)A9"P@,'@Q8C`V.34P-2P@
M,'@T,65C930Y,2P@,'AB-&,S,S)E-BP@,'@P,S(R-CAD-"P@,'AC.38P,&%C
M8RP@,'AC93,X-V4V9"P*("`@("`@("`P>&)F-F)B,39C+"`P>#9A-S!F8C<X
M+"`P>#!D,#-D.6,Y+"`P>&0T9&8S.61E+"`P>&4P,3`V,V1A+"`P>#0W,S9F
M-#8T+"`P>#5A9#,R.&0X+"`P>&(S-#=C8SDV+`H@("`@("`@(#!X-S5B8C!F
M8S,L(#!X.3@U,3%B9F(L(#!X-&9F8F-C,S4L(#!X8C4X8F-F-F$L(#!X93$Q
M9C!A8F,L(#!X8F9C-69E-&$L(#!X83<P865C,3`L(#!X86,S.34W,&$L"B`@
M("`@("`@,'@S9C`T-#0R9BP@,'@V,3@X8C$U,RP@,'AE,#,Y-V$R92P@,'@U
M-S(W8V(W.2P@,'@Y8V5B-#$X9BP@,'@Q8V%C9#8X9"P@,'@R860S-V,Y-BP@
M,'@P,3<U8V(Y9"P*("`@("`@("`P>&,V.61F9C`Y+"`P>&,W-6(V-68P+"`P
M>&0Y9&(T,&0X+"`P>&5C,&4W-S<Y+"`P>#0W-#1E860T+"`P>&(Q,6,S,C<T
M+"`P>&1D,C1C8CEE+"`P>#=E,6,U-&)D+`H@("`@("`@(#!X9C`Q,30T9CDL
M(#!X9#(R-#!E8C$L(#!X.38W-6(S9F0L(#!X83-A8S,W-34L(#!X9#0W8S(W
M868L(#!X-3%C.#5F-&0L(#!X-38Y,#<U.38L(#!X835B8C$U938L"B`@("`@
M("`@,'@U.#`S,#1F,"P@,'AC83`T,F-F,2P@,'@P,3%A,S=E82P@,'@X9&)F
M86%D8BP@,'@S-6)A,V4T82P@,'@S-3(V9F9A,"P@,'AC,S=B-&0P.2P@,'AB
M8S,P-F5D.2P*("`@("`@("`P>#DX834R-C8V+"`P>#4V-#AF-S(U+"`P>&9F
M-64U-CED+"`P>#!C960V,V0P+"`P>#=C-C-B,F-F+"`P>#<P,&(T-64Q+"`P
M>&0U96$U,&8Q+"`P>#@U83DR.#<R+`H@("`@("`@(#!X868Q9F)D83<L(#!X
M9#0R,S0X-S`L(#!X83<X-S!B9C,L(#!X,F0S8C1D-SDL(#!X-#)E,#0Q.3@L
M(#!X,&-D,&5D93<L(#!X,C8T-S!D8C@L(#!X9C@X,3@Q-&,L"B`@("`@("`@
M,'@T-S1D-F%D-RP@,'@W8S!C-64U8RP@,'AD,3(S,3DU.2P@,'@S.#%B-S(Y
M."P@,'AF-60R9C1D8BP@,'AA8C@S.#8U,RP@,'@V93)F,64R,RP@,'@X,S<Q
M.6,Y92P*("`@("`@("`P>&)D.3%E,#0V+"`P>#EA-38T-39E+"`P>&1C,SDR
M,#!C+"`P>#(P8SAC-3<Q+"`P>#DV,F)D83%C+"`P>&4Q938Y-F9F+"`P>&(Q
M-#%A8C`X+"`P>#=C8V$X.6(Y+`H@("`@("`@(#!X,6$V.64W.#,L(#!X,#)C
M8S0X-#,L(#!X83)F-V,U-SDL(#!X-#(Y968T-V0L(#!X-#(W8C$V.6,L(#!X
M-6%C.68P-#DL(#!X9&0X9C!F,#`L(#!X-6,X,38U8F8I.PH*("`@("\J*@H@
M("`@("H@4R!B;W@@*',R*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1S,B`](&%R<F%Y*`H@("`@("`@(#!X,68R,#$P.30L
M(#!X968P8F$W-6(L(#!X-CEE,V-F-V4L(#!X,SDS9C0S.#`L(#!X9F4V,6-F
M-V$L(#!X965C-3(P-V$L(#!X-34X.#EC.30L(#!X-S)F8S`V-3$L"B`@("`@
M("`@,'AA9&$W968W.2P@,'@T93%D-S(S-2P@,'AD-35A-C-C92P@,'AD93`T
M,S9B82P@,'@Y.6,T,S!E9BP@,'@U9C!C,#<Y-"P@,'@Q.&1C9&(W9"P@,'AA
M,60V969F,RP*("`@("`@("`P>&$P8C4R9C=B+"`P>#4Y93@S-C`U+"`P>&5E
M,35B,#DT+"`P>&4Y9F9D.3`Y+"`P>&1C-#0P,#@V+"`P>&5F.30T-#4Y+"`P
M>&)A.#-C8V(S+"`P>&4P8S-C9&9B+`H@("`@("`@(#!X9#%D830Q.#$L(#!X
M,V(P.3)A8C$L(#!X9CDY-V8Q8S$L(#!X835E-F-F-V(L(#!X,#$T,C!D9&(L
M(#!X931E-V5F-6(L(#!X,C5A,69F-#$L(#!X93$X,&8X,#8L"B`@("`@("`@
M,'@Q9F,T,3`X,"P@,'@Q-SEB964W82P@,'AD,S=A8S9A.2P@,'AF934X,S!A
M-"P@,'@Y.&1E.&(W9BP@,'@W-V4X,V8T92P@,'@W.3DR.3(V.2P@,'@R-&9A
M.68W8BP*("`@("`@("`P>&4Q,3-C.#5B+"`P>&%C8S0P,#@S+"`P>&0W-3`S
M-3(U+"`P>&8W96$V,35F+"`P>#8R,30S,34T+"`P>#!D-34T8C8S+"`P>#5D
M-C@Q,3(Q+"`P>&,X-C9C,S4Y+`H@("`@("`@(#!X,V0V,V-F-S,L(#!X8V5E
M,C,T8S`L(#!X9#1D.#=E.#<L(#!X-6,V-S)B,C$L(#!X,#<Q9C8Q.#$L(#!X
M,SEF-S8R-V8L(#!X,S8Q93,P.#0L(#!X931E8C4W,V(L"B`@("`@("`@,'@V
M,#)F-C1A-"P@,'AD-C-A8V0Y8RP@,'@Q8F)C-#8S-2P@,'@Y93@Q,#,R9"P@
M,'@R-S`Q9C4P8RP@,'@Y.3@T-V%B-"P@,'AA,&4S9&8W.2P@,'AB839C9C,X
M8RP*("`@("`@("`P>#$P.#0S,#DT+"`P>#(U,S=A.35E+"`P>&8T-F8V9F9E
M+"`P>&$Q9F8S8C%F+"`P>#(P.&-F8C9A+"`P>#AF-#4X8S<T+"`P>&0Y93!A
M,C(W+"`P>#1E8S<S83,T+`H@("`@("`@(#!X9F,X.#1F-CDL(#!X,V4T9&4X
M9&8L(#!X968P93`P.#@L(#!X,S4U.38T.&0L(#!X.&$T-3,X.&,L(#!X,60X
M,#0S-C8L(#!X-S(Q9#EB9F0L(#!X834X-C@T8F(L"B`@("`@("`@,'AE.#(U
M-C,S,RP@,'@X-#1E.#(Q,BP@,'@Q,CAD.#`Y."P@,'AF960S,V9B-"P@,'AC
M93(X,&%E,2P@,'@R-V4Q.6)A-2P@,'AD-6$V8S(U,BP@,'AE-#DW-31B9"P*
M("`@("`@("`P>&,U9#8U-61D+"`P>&5B-C8W,#8T+"`P>#<W.#0P8C1D+"`P
M>&$Q8C9A.#`Q+"`P>#@T9&(R-F$Y+"`P>&4P8C4V-S$T+"`P>#(Q9C`T,V(W
M+"`P>&4U9#`U.#8P+`H@("`@("`@(#!X-31F,#,P.#0L(#!X,#8V9F8T-S(L
M(#!X83,Q86$Q-3,L(#!X9&%D8S0W-34L(#!X8C4V,C5D8F8L(#!X-C@U-C%B
M938L(#!X.#-C839B.30L(#!X,F0V960R,V(L"B`@("`@("`@,'AE8V-F,#%D
M8BP@,'AA-F0S9#!B82P@,'AB-C@P,V0U8RP@,'AA9C<W83<P.2P@,'@S,V(T
M83,T8RP@,'@S.3=B8SAD-BP@,'@U964R,F(Y-2P@,'@U9C!E-3,P-"P*("`@
M("`@("`P>#@Q960V9C8Q+"`P>#(P93<T,S8T+"`P>&(T-64Q,S<X+"`P>&1E
M,3@V,SEB+"`P>#@X,6-A,3(R+"`P>&(Y-C<R-F0Q+"`P>#@P-#EA-V4X+"`P
M>#(R8C=D83=B+`H@("`@("`@(#!X-64U-3)D,C4L(#!X-3(W,F0R,S<L(#!X
M-SED,CDU,6,L(#!X8S8P9#@Y-&,L(#!X-#@X8V(T,#(L(#!X,6)A-&9E-6(L
M(#!X831B,#EF-F(L(#!X,6-A.#$U8V8L"B`@("`@("`@,'AA,C!C,S`P-2P@
M,'@X.#<Q9&8V,RP@,'AB.61E,F9C8BP@,'@P8V,V8SEE.2P@,'@P8F5E9F8U
M,RP@,'AE,S(Q-#4Q-RP@,'AB-#4T,C@S-2P@,'@Y9C8S,CDS8RP*("`@("`@
M("`P>&5E-#%E-S(Y+"`P>#9E,60R9#=C+"`P>#4P,#0U,C@V+"`P>#%E-C8X
M-68S+"`P>&8S,S0P,6,V+"`P>#,P83(R8SDU+"`P>#,Q83<P.#4P+"`P>#8P
M.3,P9C$S+`H@("`@("`@(#!X-S-F.3@T,3<L(#!X83$R-CDX-3DL(#!X96,V
M-#5C-#0L(#!X-3)C.#<W83DL(#!X8V1F9C,S838L(#!X83`R8C$W-#$L(#!X
M-V-B860Y83(L(#!X,C$X,#`S-F8L"B`@("`@("`@,'@U,&0Y.6,P."P@,'AC
M8C-F-#@V,2P@,'AC,C9B9#<V-2P@,'@V-&$S9C9A8BP@,'@X,#,T,C8W-BP@
M,'@R-6$W-64W8BP@,'AE-&4V9#%F8RP@,'@R,&,W,3!E-BP*("`@("`@("`P
M>&-D9C!B-C@P+"`P>#$W.#0T9#-B+"`P>#,Q965F.#1D+"`P>#=E,#@R-&4T
M+"`P>#)C8V(T.65B+"`P>#@T-F$S8F%E+"`P>#AF9C<W.#@X+"`P>&5E-60V
M,&8V+`H@("`@("`@(#!X-V%F-S4V-S,L(#!X,F9D9#5C9&(L(#!X83$Q-C,Q
M8S$L(#!X,S!F-C9F-#,L(#!X8C-F865C-30L(#!X,34W9F0W9F$L(#!X968X
M-3<Y8V,L(#!X9#$U,F1E-3@L"B`@("`@("`@,'AD8C)F9F0U92P@,'@X9C,R
M8V4Q.2P@,'@S,#9A9CDW82P@,'@P,F8P,V5F."P@,'@Y.3,Q.6%D-2P@,'AC
M,C0R9F$P9BP@,'AA-V4S96)B,"P@,'AC-CAE-#DP-BP*("`@("`@("`P>&(X
M9&$R,S!C+"`P>#@P.#(S,#(X+"`P>&1C9&5F,V,X+"`P>&0S-69B,3<Q+"`P
M>#`X.&$Q8F,X+"`P>&)E8S!C-38P+"`P>#8Q83-C.64X+"`P>&)C83AF-31D
M+`H@("`@("`@(#!X8S<R9F5F9F$L(#!X,C(X,C)E.3DL(#!X.#)C-3<P8C0L
M(#!X9#AD.31E.#DL(#!X.&(Q8S,T8F,L(#!X,S`Q93$V938L(#!X,C<S8F4Y
M-SDL(#!X8C!F9F5A838L"B`@("`@("`@,'@V,60Y8CAC-BP@,'@P,&(R-#@V
M.2P@,'AB-V9F8V4S9BP@,'@P.&1C,C@S8BP@,'@T,V1A9C8U82P@,'AF-V4Q
M.3<Y."P@,'@W-C$Y8C<R9BP@,'@X9C%C.6)A-"P*("`@("`@("`P>&1C.#8S
M-V$P+"`P>#$V83=D,V(Q+"`P>#EF8S,Y,V(W+"`P>&$W,3,V965B+"`P>&,V
M8F-C-C-E+"`P>#%A-3$S-S0R+"`P>&5F-C@R.&)C+"`P>#4R,#,V-60V+`H@
M("`@("`@(#!X,F0V83<W86(L(#!X,S4R-V5D-&(L(#!X.#(Q9F0R,38L(#!X
M,#DU8S9E,F4L(#!X9&(Y,F8R9F(L(#!X-65E83(Y8V(L(#!X,30U.#DR9C4L
M(#!X.3$U.#1F-V8L"B`@("`@("`@,'@U-#@S-CDW8BP@,'@R-C8W83AC8RP@
M,'@X-3$Y-C`T."P@,'@X8S1B86-E82P@,'@X,S,X-C!D-"P@,'@P9#(S93!F
M.2P@,'@V8S,X-V4X82P@,'@P864V9#(T.2P*("`@("`@("`P>&(R.#0V,#!C
M+"`P>&0X,S4W,S%D+"`P>&1C8C%C-C0W+"`P>&%C-&,U-F5A+"`P>#-E8F0X
M,6(S+"`P>#(S,&5A8F(P+"`P>#8T,SAB8S@W+"`P>&8P8C5B,69A+`H@("`@
M("`@(#!X.&8U96$R8C,L(#!X9F,Q.#0V-#(L(#!X,&$P,S9B-V$L(#!X-&9B
M,#@Y8F0L(#!X-C0Y9&$U.#DL(#!X83,T-30Q-64L(#!X-6,P,S@S,C,L(#!X
M,V4U9#-B8CDL"B`@("`@("`@,'@T,V0W.34W,BP@,'@W939D9#`W8RP@,'@P
M-F1F9&8Q92P@,'@V8S9C8S1E9BP@,'@W,38P834S.2P@,'@W,V)F8F4W,"P@
M,'@X,S@W-S8P-2P@,'@T-3(S96-F,2D["@H@("`@+RHJ"B`@("`@*B!3(&)O
M>"`H<S,I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)',S(#T@87)R87DH"B`@("`@("`@,'@X9&5F8S(T,"P@,'@R-69A-60Y
M9BP@,'AE8CDP,V1B9BP@,'AE.#$P8SDP-RP@,'@T-S8P-V9F9BP@,'@S-CEF
M930T8BP@,'@X8S%F8S8T-"P@,'AA96-E8V$Y,"P*("`@("`@("`P>&)E8C%F
M.6)F+"`P>&5E9F)C865A+"`P>&4X8V8Q.34P+"`P>#4Q9&8P-V%E+"`P>#DR
M,&4X.#`V+"`P>&8P860P-30X+"`P>&4Q,V,X9#@S+"`P>#DR-S`Q,&0U+`H@
M("`@("`@(#!X,3$Q,#=D.68L(#!X,#<V-#=D8CDL(#!X8C)E,V4T9#0L(#!X
M,V0T9C(X-64L(#!X8CEA9F$X,C`L(#!X9F%D93@R93`L(#!X83`V-S(V.&(L
M(#!X.#(W,C<Y,F4L"B`@("`@("`@,'@U-3-F8C)C,"P@,'@T.#EA93(R8BP@
M,'AD-&5F.3<Y-"P@,'@Q,C5E,V9B8RP@,'@R,69F9F-E92P@,'@X,C5B,6)F
M9"P@,'@Y,C4U8S5E9"P@,'@Q,C4W83(T,"P*("`@("`@("`P>#1E,6$X,S`R
M+"`P>&)A93`W9F9F+"`P>#4R.#(T-F4W+"`P>#AE-3<Q-#!E+"`P>#,S-S-F
M-V)F+"`P>#AC.68X,3@X+"`P>&$V9F,T964X+"`P>&,Y.#)B-6$U+`H@("`@
M("`@(#!X83AC,#%D8C<L(#!X-3<Y9F,R-C0L(#!X-C<P.31F,S$L(#!X9C)B
M9#-F-68L(#!X-#!F9F8W8S$L(#!X,69B-SAD9F,L(#!X.&4V8F0R8S$L(#!X
M-#,W8F4U.6(L"B`@("`@("`@,'@Y.6(P,V1B9BP@,'AB-61B8S8T8BP@,'@V
M,SAD8S!E-BP@,'@U-3@Q.60Y.2P@,'AA,3DW8S@Q8RP@,'@T83`Q,F0V92P@
M,'AC-3@X-&$R."P@,'AC8V,S-F8W,2P*("`@("`@("`P>&(X-#-C,C$S+"`P
M>#9C,#<T,V8Q+"`P>#@S,#DX.3-C+"`P>#!F961D9#5F+"`P>#)F-V9E.#4P
M+"`P>&0W8S`W9C=E+"`P>#`R-3`W9F)F+"`P>#5A9F(Y83`T+`H@("`@("`@
M(#!X83<T-V0R9#`L(#!X,38U,3$Y,F4L(#!X868W,&)F,V4L(#!X-3AC,S$S
M.#`L(#!X-68Y.#,P,F4L(#!X-S(W8V,S8S0L(#!X,&$P9F(T,#(L(#!X,&8W
M9F5F.#(L"B`@("`@("`@,'@X8SDV9F1A9"P@,'@U9#)C,F%A92P@,'@X964Y
M.6$T.2P@,'@U,&1A.#AB."P@,'@X-#(W9C1A,"P@,'@Q96%C-3<Y,"P@,'@W
M.39F8C0T.2P@,'@X,C4R9&,Q-2P*("`@("`@("`P>&5F8F0W9#EB+"`P>&$V
M-S(U.3=D+"`P>&%D83@T,&0X+"`P>#0U9C4T-3`T+"`P>&9A-60W-#`S+"`P
M>&4X,V5C,S`U+"`P>#1F.3$W-3%A+"`P>#DR-38V.6,R+`H@("`@("`@(#!X
M,C-E9F4Y-#$L(#!X83DP,V8Q,F4L(#!X-C`R-S!D9C(L(#!X,#(W-F4T8C8L
M(#!X.31F9#8U-S0L(#!X.3(W.3@U8C(L(#!X.#(W-F1B8V(L(#!X,#(W-S@Q
M-S8L"B`@("`@("`@,'AF.&%F.3$X9"P@,'@T930X9C<Y92P@,'@X9C8Q-F1D
M9BP@,'AE,CED.#0P92P@,'@X-#)F-V0X,RP@,'@S-#!C935C."P@,'@Y-F)B
M8C8X,BP@,'@Y,V(T8C$T."P*("`@("`@("`P>&5F,S`S8V%B+"`P>#DX-&9A
M9C(X+"`P>#<W.69A9CEB+"`P>#DR9&,U-C!D+"`P>#(R-&0Q93(P+"`P>#@T
M,S=A83@X+"`P>#=D,CED8SDV+"`P>#(W-39D,V1C+`H@("`@("`@(#!X.&(Y
M,#=C964L(#!X8C4Q9F0R-#`L(#!X93=C,#=C93,L(#!X934V-F(T83$L(#!X
M8S-E.38Q-64L(#!X,V-F.#(P.60L(#!X-C`Y-&0Q93,L(#!X8V0Y8V$S-#$L
M"B`@("`@("`@,'@U8S<V-#8P92P@,'@P,&5A.3@S8BP@,'AD-&0V-S@X,2P@
M,'AF9#0W-3<R8RP@,'AF-S9C961D.2P@,'AB9&$X,C(Y8RP@,'@Q,C=D861A
M82P@,'@T,SAA,#<T92P*("`@("`@("`P>#%F.3=C,#DP+"`P>#`X,6)D8CAA
M+"`P>#DS83`W96)E+"`P>&(Y,SAC83$U+"`P>#DW8C`S8V9F+"`P>#-D8S)C
M,&8X+"`P>#AD,6%B,F5C+"`P>#8T,S@P934Q+`H@("`@("`@(#!X-CAC8S=B
M9F(L(#!X9#DP9C(W.#@L(#!X,3(T.3`Q.#$L(#!X-61E-69F9#0L(#!X9&0W
M968X-F$L(#!X-S9A,F4R,30L(#!X8CEA-#`S-C@L(#!X.3(U9#DU.&8L"B`@
M("`@("`@,'@T8C,Y9F9F82P@,'AB83,Y865E.2P@,'AA-&9F9#,P8BP@,'AF
M868W.3,S8BP@,'@V9#0Y.#8R,RP@,'@Q.3-C8F-F82P@,'@R-S8R-S4T-2P@
M,'@X,C5C9C0W82P*("`@("`@("`P>#8Q8F0X8F$P+"`P>&0Q,64T,F0Q+"`P
M>&-E860P-&8T+"`P>#$R-V5A,SDR+"`P>#$P-#(X9&(W+"`P>#@R-S)A.3<R
M+"`P>#DR-S!C-&$X+"`P>#$R-V1E-3!B+`H@("`@("`@(#!X,C@U8F$Q8S@L
M(#!X,V,V,F8T-&8L(#!X,S5C,&5A834L(#!X93@P-60R,S$L(#!X-#(X.3(Y
M9F(L(#!X8C1F8V1F.#(L(#!X-&9B-C9A-3,L(#!X,&4W9&,Q-6(L"B`@("`@
M("`@,'@Q9C`X,69A8BP@,'@Q,#@V,3AA92P@,'AF8V9D,#@V9"P@,'AF.69F
M,C@X.2P@,'@V.31B8V,Q,2P@,'@R,S9A-6-A92P@,'@Q,F1E8V$T9"P@,'@R
M8S-F.&-C-2P*("`@("`@("`P>&0R9#`R9&9E+"`P>&8X968U.#DV+"`P>&4T
M8V8U,F1A+"`P>#DU,34U8C8W+"`P>#0Y-&$T.#AC+"`P>&(Y8C9A.#!C+"`P
M>#5C.&8X,F)C+"`P>#@Y9#,V8C0U+`H@("`@("`@(#!X,V$V,#DT,S<L(#!X
M96,P,&,Y83DL(#!X-#0W,34R-3,L(#!X,&$X-S1B-#DL(#!X9#<W,V)C-#`L
M(#!X-V,S-#8W,6,L(#!X,#(W,3=E9C8L(#!X-&9E8C4U,S8L"B`@("`@("`@
M,'AA,F0P,F9F9BP@,'AD,F)F-C!C-"P@,'AD-#-F,#-C,"P@,'@U,&(T968V
M9"P@,'@P-S0W.&-D,2P@,'@P,#9E,3@X."P@,'AA,F4U,V8U-2P@,'AB.64V
M9#1B8RP*("`@("`@("`P>&$R,#0X,#$V+"`P>#DW-3<S.#,S+"`P>&0W,C`W
M9#8W+"`P>&1E,&8X9C-D+"`P>#<R9C@W8C,S+"`P>&%B8V,T9C,S+"`P>#<V
M.#AC-35D+"`P>#=B,#!A-F(P+`H@("`@("`@(#!X.30W8C`P,#$L(#!X-3<P
M,#<U9#(L(#!X9CEB8C@X9C@L(#!X.#DT,C`Q.64L(#!X-#(V-&$U9F8L(#!X
M.#4V,S`R93`L(#!X-S)D8F0Y,F(L(#!X964Y-S%B-CDL"B`@("`@("`@,'@V
M96$R,F9D92P@,'@U9C`X864R8BP@,'AA9C=A-C$V9"P@,'AE-6,Y.#<V-RP@
M,'AC9C%F96)D,BP@,'@V,65F8SAC,BP@,'AF,6%C,C4W,2P@,'AC8S@R,SEC
M,BP*("`@("`@("`P>#8W,C$T8V(X+"`P>&(Q934X,V0Q+"`P>&(W9&,S938R
M+"`P>#=F,3!B9&-E+"`P>&8Y,&$U8S,X+"`P>#!F9C`T-#-D+"`P>#8P-F4V
M9&,V+"`P>#8P-30S830Y+`H@("`@("`@(#!X-3<R-V,Q-#@L(#!X,F)E.3AA
M,60L(#!X.&%B-#$W,S@L(#!X,C!E,6)E,C0L(#!X868Y-F1A,&8L(#!X-C@T
M-3@T,C4L(#!X.3DX,S-B934L(#!X-C`P9#0U-V0L"B`@("`@("`@,'@R.#)F
M.3,U,"P@,'@X,S,T8C,V,BP@,'AD.3%D,3$R,"P@,'@R8C9D.&1A,"P@,'@V
M-#)B,64S,2P@,'@Y8S,P-6$P,"P@,'@U,F)C938X."P@,'@Q8C`S-3@X82P*
M("`@("`@("`P>&8W8F%E9F0U+"`P>#0Q-#)E9#EC+"`P>&$T,S$U8S$Q+"`P
M>#@S,S(S96,U+"`P>&1F968T-C,V+"`P>&$Q,S-C-3`Q+"`P>&4Y9#,U,S%C
M+"`P>&5E,S4S-S@S*3L*"B`@("`O*BH*("`@("`J(%,@8F]X("AS-"D*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S0@/2!A
M<G)A>2@*("`@("`@("`P>#ED8C,P-#(P+"`P>#%F8C9E.61E+"`P>&$W8F4W
M8F5F+"`P>&0R-S-A,CDX+"`P>#1A-&8W8F1B+"`P>#8T860X8S4W+"`P>#@U
M-3$P-#0S+"`P>&9A,#(P960Q+`H@("`@("`@(#!X-V4R.#=A9F8L(#!X938P
M9F(V-C,L(#!X,#DU9C,U83$L(#!X-SEE8F8Q,C`L(#!X9F0P-3ED-#,L(#!X
M-C0Y-V(W8C$L(#!X9C,V-#%F-C,L(#!X,C0Q931A9&8L"B`@("`@("`@,'@R
M.#$T-V8U9BP@,'@T9F$R8CAC9"P@,'AC.30S,#`T,"P@,'@P8V,S,C(R,"P@
M,'AF9&0S,&(S,"P@,'AC,&$U,S<T9BP@,'@Q9#)D,#!D.2P@,'@R-#$T-V(Q
M-2P*("`@("`@("`P>&5E-&0Q,3%A+"`P>#!F8V$U,38W+"`P>#<Q9F8Y,#1C
M+"`P>#)D,3DU9F9E+"`P>#%A,#4V-#5F+"`P>#!C,3-F969E+"`P>#`X,6(P
M.&-A+"`P>#`U,3<P,3(Q+`H@("`@("`@(#!X.#`U,S`Q,#`L(#!X93@S935E
M9F4L(#!X86,Y868T9C@L(#!X-V9E-S(W,#$L(#!X9#)B.&5E-68L(#!X,#9D
M9C0R-C$L(#!X8F(Y93EB.&$L(#!X-S(Y,V5A,C4L"B`@("`@("`@,'AC93@T
M9F9D9BP@,'AF-3<Q.#@P,2P@,'@S9&0V-&(P-"P@,'AA,C9F,C8S8BP@,'@W
M960T.#0P,"P@,'@U-#=E96)E-BP@,'@T-#9D-&-A,"P@,'@V8V8S9#9F-2P*
M("`@("`@("`P>#(V-#EA8F1F+"`P>&%E83!C-V8U+"`P>#,V,S,X8V,Q+"`P
M>#4P,V8W93DS+"`P>&0S-S<R,#8Q+"`P>#$Q8C8S.&4Q+"`P>#<R-3`P93`S
M+"`P>&8X,&5B,F)B+`H@("`@("`@(#!X86)E,#4P,F4L(#!X96,X9#<W9&4L
M(#!X-3<Y-S%E.#$L(#!X93$T9C8W-#8L(#!X8SDS,S4T,#`L(#!X-CDR,#,Q
M.&8L(#!X,#@Q9&)B.3DL(#!X9F9C,S`T834L"B`@("`@("`@,'@T9#,U,3@P
M-2P@,'@W9C-D-6-E,RP@,'AA-F,X-C9C-BP@,'@U9#5B8V-A.2P@,'AD865C
M-F9E82P@,'@Y9CDR-F8Y,2P@,'@Y9C0V,C(R9BP@,'@S.3DQ-#8W9"P*("`@
M("`@("`P>&$U8F8V9#AE+"`P>#$Q-#-C-#1F+"`P>#0S.34X,S`R+"`P>&0P
M,C$T965B+"`P>#`R,C`X,V(X+"`P>#-F8C8Q.#!C+"`P>#$X9C@Y,S%E+"`P
M>#(X,38U.&4V+`H@("`@("`@(#!X,C8T.#9E,V4L(#!X.&)D-SAA-S`L(#!X
M-S0W-V4T8S$L(#!X8C4P-F4P-V,L(#!X9C,R9#!A,C4L(#!X-SDP.3AB,#(L
M(#!X931E86)B.#$L(#!X,C@Q,C-B,C,L"B`@("`@("`@,'@V.61E860S."P@
M,'@Q-3<T8V$Q-BP@,'AD9C@W,6(V,BP@,'@R,3%C-#!B-RP@,'AA-3%A.65F
M.2P@,'@P,#$T,S<W8BP@,'@P-#%E.&%C."P@,'@P.3$Q-#`P,RP*("`@("`@
M("`P>&)D-3EE-&0R+"`P>&4S9#$U-F0U+"`P>#1F93@W-F0U+"`P>#)F.3%A
M,S0P+"`P>#4U-V)E.&1E+"`P>#`P96%E-&$W+"`P>#!C935C,F5C+"`P>#1D
M8C1B8F$V+`H@("`@("`@(#!X93<U-F)D9F8L(#!X9&0S,S8Y86,L(#!X96,Q
M-V(P,S4L(#!X,#8U-S(S,C<L(#!X.3EA9F,X8C`L(#!X-39C.&,S.3$L(#!X
M-F(V-3@Q,6,L(#!X-64Q-#8Q,3DL"B`@("`@("`@,'@V93@U8V(W-2P@,'AB
M93`W8S`P,BP@,'AC,C,R-34W-RP@,'@X.3-F9C1E8RP@,'@U8F)F8SDR9"P@
M,'AD,&5C,V(R-2P@,'AB-S@P,6%B-RP@,'@X9#9D,V(R-"P*("`@("`@("`P
M>#(P8S<V,V5F+"`P>&,S-C9A-69C+"`P>#EC,S@R.#@P+"`P>#!A8V4S,C`U
M+"`P>&%A8SDU-#AA+"`P>&5C83%D-V,W+"`P>#`T,6%F83,R+"`P>#%D,38V
M,C5A+`H@("`@("`@(#!X-C<P,3DP,F,L(#!X.6(W-3=A-30L(#!X,S%D-#<W
M9C<L(#!X.3$R-F(P,S$L(#!X,S9C8S9F9&(L(#!X8S<P8CAB-#8L(#!X9#EE
M-C9A-#@L(#!X-39E-35A-SDL"B`@("`@("`@,'@P,C9A-&-E8BP@,'@U,C0S
M-V5F9BP@,'@R9CAF-S9B-"P@,'@P9&8Y.#!A-2P@,'@X-C<T8V1E,RP@,'AE
M9&1A,#1E8BP@,'@Q-V$Y8F4P-"P@,'@R8S$X9C1D9BP*("`@("`@("`P>&(W
M-S0W9CED+"`P>&%B,F%F-V(T+"`P>&5F8S,T9#(P+"`P>#)E,#DV8C=C+"`P
M>#$W-#%A,C4T+"`P>&4U8C9A,#,U+"`P>#(Q,V0T,F8V+"`P>#)C,6,W8S(V
M+`H@("`@("`@(#!X-C%C,F8U,&8L(#!X-C4U,F1A9CDL(#!X9#)C,C,Q9C@L
M(#!X,C4Q,S!F-CDL(#!X9#@Q-C=F83(L(#!X,#0Q.&8R8S@L(#!X,#`Q83DV
M838L(#!X,&0Q-3(V86(L"B`@("`@("`@,'@V,S,Q-6,R,2P@,'@U93!A-S)E
M8RP@,'@T.6)A9F5F9"P@,'@Q.#<Y,#AD.2P@,'@X9#!D8F0X-BP@,'@S,3$Q
M-S!A-RP@,'@S93EB-C0P8RP@,'AC8S-E,3!D-RP*("`@("`@("`P>&0U8V%D
M,V(V+"`P>#!C865C,S@X+"`P>&8W,S`P,64Q+"`P>#9C-S(X869F+"`P>#<Q
M96%E,F$Q+"`P>#%F.6%F,S9E+"`P>&-F8V)D,3)F+"`P>&,Q9&4X-#$W+`H@
M("`@("`@(#!X86,P-V)E-F(L(#!X8V(T-&$Q9#@L(#!X.&(Y8C!F-38L(#!X
M,#$S.3@X8S,L(#!X8C%C-3)F8V$L(#!X8C1B93,Q8V0L(#!X9#@W.#(X,#8L
M(#!X,3)A,V$T93(L"B`@("`@("`@,'@V9C=D934S,BP@,'@U.&9D-V5B-BP@
M,'AD,#%E93DP,"P@,'@R-&%D9F9C,BP@,'AF-#DY,&9C-2P@,'@Y-S$Q86%C
M-2P@,'@P,#%D-V(Y-2P@,'@X,F4U93=D,BP*("`@("`@("`P>#$P.3@W,V8V
M+"`P>#`P-C$S,#DV+"`P>&,S,F0Y-3(Q+"`P>&%D83$R,69F+"`P>#(Y.3`X
M-#$U+"`P>#=F8F(Y-S=F+"`P>&%F.65B,V1B+"`P>#(Y8SEE9#)A+`H@("`@
M("`@(#!X-6-E,F$T-C4L(#!X83<S,&8S,F,L(#!X9#!A83-F93@L(#!X.&$U
M8V,P.3$L(#!X9#0Y93)C93<L(#!X,&-E-#4T83DL(#!X9#8P86-D.#8L(#!X
M,#$U9C$Y,3DL"B`@("`@("`@,'@W-S`W.3$P,RP@,'AD96$P,V%F-BP@,'@W
M.&$X-38U92P@,'AD964S-39D9BP@,'@R,68P-6-B92P@,'@X8C<U93,X-RP@
M,'AB,V,U,#8U,2P@,'AB.&$U8S-E9BP*("`@("`@("`P>&0X965B-F0R+"`P
M>&4U,C-B93<W+"`P>&,R,34T-3(Y+"`P>#)F-CEE9F1F+"`P>&%F938W869B
M+"`P>&8T-S!C-&(R+"`P>&8S93!E8C5B+"`P>&0V8V,Y.#<V+`H@("`@("`@
M(#!X,SEE-#0V,&,L(#!X,69D83@U,S@L(#!X,3DX-S@S,F8L(#!X8V$P,#<S
M-C<L(#!X83DY,30T9C@L(#!X,CDV8C(Y.64L(#!X-#DR9F,R.34L(#!X.3(V
M-F)E86(L"B`@("`@("`@,'AB-38W-F4V.2P@,'@Y8F0S9&1D82P@,'AD9C=E
M,#4R9BP@,'AD8C(U-S`Q8RP@,'@Q8C5E-3%E92P@,'AF-C4S,C1E-BP@,'@V
M869C93,V8RP@,'@P,S$V8V,P-"P*("`@("`@("`P>#@V-#0R,3-E+"`P>&(W
M9&,U.60P+"`P>#<Y-C4R.3%F+"`P>&-C9#9F9#0S+"`P>#0Q.#(S.3<Y+"`P
M>#DS,F)C9&8V+"`P>&(V-3=C,S1D+"`P>#1E9&9D,C@R+`H@("`@("`@(#!X
M-V%E-3(Y,&,L(#!X,V-B.34S-F(L(#!X.#4Q93(P9F4L(#!X.3@S,S4U-V4L
M(#!X,3-E8V8P8C`L(#!X9#-F9F(S-S(L(#!X,V8X-6,U8S$L(#!X,&%E9C=E
M9#(I.PH*("`@("\J*@H@("`@("H@4R!B;W@@*',U*0H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S-2`](&%R<F%Y*`H@("`@
M("`@(#!X-V5C.3!C,#0L(#!X,F,V93<T8CDL(#!X.6(P938V9&8L(#!X838S
M,S<Y,3$L(#!X8C@V83=F9F8L(#!X,61D,S4X9C4L(#!X-#1D9#ED-#0L(#!X
M,3<S,3$V-V8L"B`@("`@("`@,'@P.&9B9C%F82P@,'AE-V8U,3%C8RP@,'AD
M,C`U,6(P,"P@,'@W,S5A8F$P,"P@,'@R86(W,C)D."P@,'@S.#8S.#%C8BP@
M,'AA8V8V,C0S82P@,'@V.6)E9F0W82P*("`@("`@("`P>&4V83)E-S=F+"`P
M>&8P8S<R,&-D+"`P>&,T-#DT.#$V+"`P>&-C9C5C,3@P+"`P>#,X.#4Q-C0P
M+"`P>#$U8C!A.#0X+"`P>&4V.&(Q.&-B+"`P>#1C86%D969F+`H@("`@("`@
M(#!X-68T.#!A,#$L(#!X,#0Q,F(R86$L(#!X,C4Y.#$T9F,L(#!X-#%D,&5F
M93(L(#!X-&4T,&(T.&0L(#!X,C0X96(V9F(L(#!X.&1B83%C9F4L(#!X-#%A
M.3EB,#(L"B`@("`@("`@,'@Q834U,&$P-"P@,'AB83AF-C5C8BP@,'@W,C4Q
M9C1E-RP@,'@Y-6$U,3<R-2P@,'AC,3`V96-D-RP@,'@Y-V$U.3@P82P@,'AC
M-3,Y8CEA82P@,'@T9#<Y9F4V82P*("`@("`@("`P>&8R9C-F-S8S+"`P>#8X
M868X,#0P+"`P>&5D,&,Y934V+"`P>#$Q8C0Y-3AB+"`P>&4Q96(U83@X+"`P
M>#@W,#EE-F(P+"`P>&0W93`W,34V+"`P>#1E,CEF96$W+`H@("`@("`@(#!X
M-C,V-F4U,F0L(#!X,#)D,6,P,#`L(#!X8S1A8SAE,#4L(#!X.3,W-V8U-S$L
M(#!X,&,P-3,W,F$L(#!X-3<X-3,U9C(L(#!X,C(V,6)E,#(L(#!X9#8T,F$P
M8SDL"B`@("`@("`@,'AD9C$S83(X,"P@,'@W-&(U-6)D,BP@,'@V.#(Q.3EC
M,"P@,'AD-#(Q935E8RP@,'@U,V9B,V-E."P@,'AC.&%D961B,RP@,'@R.&$X
M-V9C.2P@,'@S9#DU.3DX,2P*("`@("`@("`P>#5C,69F.3`P+"`P>&9E,SAD
M,SDY+"`P>#!C-&5F9C!B+"`P>#`V,C0P-V5A+"`P>&%A,F8T9F(Q+"`P>#1F
M8CDV.3<V+"`P>#DP8S<Y-3`U+"`P>&(P83AA-S<T+`H@("`@("`@(#!X968U
M-6$Q9F8L(#!X934Y8V$R8S(L(#!X839B-C)D,C<L(#!X938V830R-C,L(#!X
M9&8V-3`P,68L(#!X,&5C-3`Y-C8L(#!X9&9D9#4U8F,L(#!X,CED93`V-34L
M"B`@("`@("`@,'@Y,3%E-S,Y82P@,'@Q-V%F.#DW-2P@,'@S,F,W.3$Q8RP@
M,'@X.68X.30V."P@,'@P9#`Q93DX,"P@,'@U,C0W-35F-"P@,'@P,V(V,V-C
M.2P@,'@P8V,X-#1B,BP*("`@("`@("`P>&)C9C-F,&%A+"`P>#@W86,S-F4Y
M+"`P>&4U,V$W-#(V+"`P>#`Q8C-D.#)B+"`P>#%A.64W-#0Y+"`P>#8T964R
M9#=E+"`P>&-D9&)B,61A+"`P>#`Q8SDT.3$P+`H@("`@("`@(#!X8C@V.&)F
M.#`L(#!X,&0R-F8S9F0L(#!X.3,T,F5D93<L(#!X,#1A-6,R.#0L(#!X-C,V
M-S,W8C8L(#!X-3!F-6(V,38L(#!X9C(T-S8V93,L(#!X.&5C83,V8S$L"B`@
M("`@("`@,'@Q,S9E,#5D8BP@,'AF968Q.#,Y,2P@,'AF8C@X-V$S-RP@,'AD
M-F4W9C=D-"P@,'AC-V9B-V1C.2P@,'@S,#8S9F-D9BP@,'AB-F8U.#ED92P@
M,'AE8S(Y-#%D82P*("`@("`@("`P>#(V930V-CDU+"`P>&(W-38V-#$Y+"`P
M>&8V-31E9F,U+"`P>&0P.&0U.&(W+"`P>#0X.3(U-#`Q+"`P>&,Q8F%C8C=F
M+"`P>&4U9F8U-3!F+"`P>&(V,#@S,#0Y+`H@("`@("`@(#!X-6)B-60P93@L
M(#!X.#=D-S)E-6$L(#!X86(V839E93$L(#!X,C(S838V8V4L(#!X8S8R8F8S
M8V0L(#!X.64P.#@U9CDL(#!X-CAC8C-E-#<L(#!X,#@V8S`Q,&8L"B`@("`@
M("`@,'AA,C%D93@R,"P@,'AD,3AB-CED92P@,'AF,V8V-3<W-RP@,'AF83`R
M8S-F-BP@,'@T,#=E9&%C,RP@,'AC8F(S9#4U,"P@,'@Q-SDS,#@T9"P@,'AB
M,&0W,&5B82P*("`@("`@("`P>#!A8C,W.&0U+"`P>&0Y-3%F8C!C+"`P>&1E
M9#=D834V+"`P>#0Q,C1B8F4T+"`P>#DT8V$P8C4V+"`P>#!F-3<U-60Q+"`P
M>&4P93%E-39E+"`P>#8Q.#1B-6)E+`H@("`@("`@(#!X-3@P83(T.68L(#!X
M.31F-S1B8S`L(#!X93,R-S@X.&4L(#!X.68W8C4U-C$L(#!X8S-D8S`R.#`L
M(#!X,#4V.#<W,34L(#!X-C0V8S9B9#<L(#!X-#0Y,#1D8C,L"B`@("`@("`@
M,'@V-F(T9C!A,RP@,'AC,&8Q-C0X82P@,'@V.3=E9#5A9BP@,'@T.64Y,F9F
M-BP@,'@S,#EE,S<T9BP@,'@R8V(V,S4V82P@,'@X-3@P.#4W,RP@,'@T.3DQ
M9C@T,"P*("`@("`@("`P>#<V9C!A93`R+"`P>#`X,V)E.#1D+"`P>#(X-#(Q
M8SEA+"`P>#0T-#@Y-#`V+"`P>#<S-F4T8V(X+"`P>&,Q,#DR.3$P+"`P>#AB
M8SDU9F,V+"`P>#=D.#8Y8V8T+`H@("`@("`@(#!X,3,T9C8Q-F8L(#!X,F4W
M-S$Q.&0L(#!X8C,Q8C)B93$L(#!X86$Y,&(T-S(L(#!X,V-A-60W,3<L(#!X
M-V0Q-C%B8F$L(#!X.6-A9#DP,3`L(#!X868T-C)B83(L"B`@("`@("`@,'@Y
M9F4T-3ED,BP@,'@T-60S-#4U.2P@,'AD.68R9&$Q,RP@,'AD8F,V-30X-RP@
M,'AF,V4T9CDT92P@,'@Q-S9D-#@V9BP@,'@P.3=C,3-E82P@,'@V,S%D835C
M-RP*("`@("`@("`P>#0T-68W,S@R+"`P>#$W-38X,V8T+"`P>&-D8S8V83DW
M+"`P>#<P8F4P,C@X+"`P>&(S8V1C9C<R+"`P>#9E-61D,F8S+"`P>#(P.3,V
M,#<Y+"`P>#0U.6(X,&$U+`H@("`@("`@(#!X8F4V,&4R9&(L(#!X83EC,C,Q
M,#$L(#!X96)A-3,Q-6,L(#!X,C(T930R9C(L(#!X,6,U8S$U-S(L(#!X9C8W
M,C%B,F,L(#!X,6%D,F9F9C,L(#!X.&,R-30P-&4L"B`@("`@("`@,'@S,C1E
M9#<R9BP@,'@T,#8W8C=F9"P@,'@P-3(S,3,X92P@,'@U8V$S8F,W."P@,'AD
M8S!F9#8V92P@,'@W-3DR,C(X,RP@,'@W.#1D-F(Q-RP@,'@U.&5B8C$V92P*
M("`@("`@("`P>#0T,#DT9C@U+"`P>#-F-#@Q9#@W+"`P>&9C9F5A93=B+"`P
M>#<W8C5F9C<V+"`P>#AC,C,P,F)F+"`P>&%A9C0W-34V+"`P>#5F-#9B,#)A
M+"`P>#)B,#DR.#`Q+`H@("`@("`@(#!X,V0S.&8U9C<L(#!X,&-A.#%F,S8L
M(#!X-3)A9C1A.&$L(#!X-C9D-64W8S`L(#!X9&8S8C`X-S0L(#!X.34P-34Q
M,3`L(#!X,6(U860W83@L(#!X9C8Q960U860L"B`@("`@("`@,'@V8V8V930W
M.2P@,'@R,#<U.#$X-"P@,'AD,&-E9F$V-2P@,'@X.&8W8F4U."P@,'@T83`T
M-C@R-BP@,'@P9F8V9CAF,RP@,'AA,#EC-V8W,"P@,'@U,S0V86)A,"P*("`@
M("`@("`P>#5C93DV8S(X+"`P>&4Q-S9E9&$S+"`P>#9B86,S,#=F+"`P>#,W
M-C@R.60R+"`P>#@U,S8P9F$Y+"`P>#$W93-F93)A+"`P>#(T8C<Y-S8W+"`P
M>&8U83DV8C(P+`H@("`@("`@(#!X9#9C9#(U.34L(#!X-CAF9C%E8F8L(#!X
M-S4U-30T,F,L(#!X9C$Y9C`V8F4L(#!X9CEE,#8U.6$L(#!X965B.30Y,60L
M(#!X,S0P,3`W,3@L(#!X8F(S,&-A8C@L"B`@("`@("`@,'AE.#(R9F4Q-2P@
M,'@X.#4W,#DX,RP@,'@W-3!E-C(T.2P@,'AD838R-V4U-2P@,'@U93<V9F9A
M."P@,'AB,34S-#4T-BP@,'@V9#0W9&4P."P@,'AE9F4Y93=D-"D["@H@("`@
M+RHJ"B`@("`@*B!3(&)O>"`H<S8I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)',V(#T@87)R87DH"B`@("`@("`@,'AF-F9A
M.&8Y9"P@,'@R8V%C-F-E,2P@,'@T8V$S-#@V-RP@,'AE,C,S-V8W8RP@,'@Y
M-61B,#AE-RP@,'@P,38X-#-B-"P@,'AE8V5D-6-B8RP@,'@S,C4U-3-A8RP*
M("`@("`@("`P>&)F.68P.38P+"`P>&1F83%E,F5D+"`P>#@S9C`U-SED+"`P
M>#8S960X-F(Y+"`P>#%A8C9A-F(X+"`P>&1E-65B93,Y+"`P>&8S.&9F-S,R
M+"`P>#@Y.#EB,3,X+`H@("`@("`@(#!X,S-F,30Y-C$L(#!X8S`Q.3,W8F0L
M(#!X9C4P-F,V9&$L(#!X930V,C5E-V4L(#!X83,P.&5A.3DL(#!X-&4R,V4S
M,V,L(#!X-SEC8F0W8V,L(#!X-#AA,30S-C<L"B`@("`@("`@,'AA,S$T.38Q
M.2P@,'AF96,Y-&)D-2P@,'AA,3$T,3<T82P@,'AE86$P,3@V-BP@,'AA,#@T
M9&(R9"P@,'@P.6$X-#@V9BP@,'AA.#@X-C$T82P@,'@R.3`P868Y."P*("`@
M("`@("`P>#`Q-C8U.3DQ+"`P>&4Q.3DR.#8S+"`P>&,X9C,P8S8P+"`P>#)E
M-SAE9C-C+"`P>&0P9#4Q.3,R+"`P>&-F,&9E8S$T+"`P>&8W8V$P-V0R+"`P
M>&0P83@R,#<R+`H@("`@("`@(#!X9F0T,3$Y-V4L(#!X.3,P-6$V8C`L(#!X
M93@V8F4S9&$L(#!X-S1B960S8V0L(#!X,S<R9&$U,V,L(#!X-&,W9C0T-#@L
M(#!X9&%B-60T-#`L(#!X-F1B83!E8S,L"B`@("`@("`@,'@P.#,Y,3EA-RP@
M,'@Y9F)A965D.2P@,'@T.61B8V9B,"P@,'@T938W,&,U,RP@,'@U8S-D.6,P
M,2P@,'@V-&)D8CDT,2P@,'@R8S!E-C,V82P@,'AB83=D9#EC9"P*("`@("`@
M("`P>&5A-F8W,S@X+"`P>&4W,&)C-S8R+"`P>#,U9C(Y861B+"`P>#5C-&-D
M9#AD+"`P>&8P9#0X9#AC+"`P>&(X.#$U,V4R+"`P>#`X83$Y.#8V+"`P>#%A
M93)E86,X+`H@("`@("`@(#!X,C@T8V%F.#DL(#!X86$Y,C@R,C,L(#!X.3,S
M-&)E-3,L(#!X,V(S83(Q8F8L(#!X,38T,S1B93,L(#!X.6%E83,Y,#8L(#!X
M969E.&,S-F4L(#!X9C@Y,&-D9#DL"B`@("`@("`@,'@X,#(R-F1A92P@,'AC
M,S0P831A,RP@,'AD9C=E.6,P.2P@,'AA-CDT83@P-RP@,'@U8C=C-65C8RP@
M,'@R,C%D8C-A-BP@,'@Y838Y83`R9BP@,'@V.#@Q.&$U-"P*("`@("`@("`P
M>&-E8C(R.39F+"`P>#4S8S`X-#-A+"`P>&9E.#DS-C4U+"`P>#(U8F9E-CAA
M+"`P>&(T-C(X86)C+"`P>&-F,C(R96)F+"`P>#(U86,V9C0X+"`P>&$Y83DY
M,S@W+`H@("`@("`@(#!X-3-B9&1B-C4L(#!X93<V9F9B93<L(#!X93DV-V9D
M-S@L(#!X,&)A.3,U-C,L(#!X.&4S-#)B8S$L(#!X93AA,3%B93DL(#!X-#DX
M,#<T,&0L(#!X8S@P.#=D9F,L"B`@("`@("`@,'@X9&4T8F8Y.2P@,'AA,3$Q
M,#%A,"P@,'@W9F0S-SDW-2P@,'AD835A,C9C,"P@,'AE.#%F.3DT9BP@,'@Y
M-3(X8V0X.2P@,'AF9#,S.69E9"P@,'AB.#<X,S1B9BP*("`@("`@("`P>#5F
M,#0T-39D+"`P>#(R,C4X-CDX+"`P>&,Y8S1C.#-B+"`P>#)D8S$U-F)E+"`P
M>#1F-C(X9&%A+"`P>#4W9C4U96,U+"`P>&4R,C(P86)E+"`P>&0R.3$V96)F
M+`H@("`@("`@(#!X-&5C-S5B.34L(#!X,C1F,F,S8S`L(#!X-#)D,35D.3DL
M(#!X8V0P9#=F83`L(#!X-V(V93(W9F8L(#!X83AD8SAA9C`L(#!X-S,T-6,Q
M,#8L(#!X9C0Q93(S,F8L"B`@("`@("`@,'@S-3$V,C,X-BP@,'AE-F5A.#DR
M-BP@,'@S,S,S8C`Y-"P@,'@Q-3=E8S9F,BP@,'@S-S)B-S1A9BP@,'@V.3(U
M-S-E-"P@,'AE.6$Y9#@T."P@,'AF,S$V,#(X.2P*("`@("`@("`P>#-A-C)E
M9C%D+"`P>&$W.#=E,C,X+"`P>&8S835F-C<V+"`P>#<T,S8T.#4S+"`P>#(P
M.34Q,#8S+"`P>#0U-S8V.3AD+"`P>&(V9F%D-#`W+"`P>#4Y,F%F.34P+`H@
M("`@("`@(#!X,S9F-S,U,C,L(#!X-&-F8C9E.#<L(#!X-V1A-&-E8S`L(#!X
M-F,Q-3)D86$L(#!X8V(P,SDV83@L(#!X8S4P9&9E-60L(#!X9F-D-S`W86(L
M(#!X,#DR,6,T,F8L"B`@("`@("`@,'@X.61F9C!B8BP@,'@U9F4R8F4W."P@
M,'@T-#AF-&8S,RP@,'@W-30V,3-C.2P@,'@R8C`U9#`X9"P@,'@T.&(Y9#4X
M-2P@,'AD8S`T.30T,2P@,'AC.#`Y.&8Y8BP*("`@("`@("`P>#=D961E-S@V
M+"`P>&,S.6$S,S<S+"`P>#0R-#$P,#`U+"`P>#9A,#DQ-S4Q+"`P>#!E9C-C
M.&$V+"`P>#@Y,#`W,F0V+"`P>#(X,C`W-C@R+"`P>&$Y83EF-V)E+`H@("`@
M("`@(#!X8F8S,C8W.60L(#!X9#0U8C5B-S4L(#!X8C,U,V9D,#`L(#!X8V)B
M,&4S-3@L(#!X.#,P9C(R,&$L(#!X,68X9F(R,30L(#!X9#,W,F-F,#@L(#!X
M8V,S8S1A,3,L"B`@("`@("`@,'@X8V8V,S$V-BP@,'@P-C%C.#=B92P@,'@X
M.&,Y.&8X."P@,'@V,#8R93,Y-RP@,'@T-V-F.&4W82P@,'AB-F,X-3(X,RP@
M,'@S8V,R86-F8BP@,'@S9F,P-CDW-BP*("`@("`@("`P>#1E.&8P,C4R+"`P
M>#8T9#@S,31D+"`P>&1A,S@W,&4S+"`P>#%E-C8U-#4Y+"`P>&,Q,#DP.&8P
M+"`P>#4Q,S`R,6$U+"`P>#9C-6(V.&(W+"`P>#@R,F8X86$P+`H@("`@("`@
M(#!X,S`P-V-D,V4L(#!X-S0W,3EE968L(#!X9&,X-S(V.#$L(#!X,#<S,S0P
M9#0L(#!X-V4T,S)F9#DL(#!X,&,U96,R-#$L(#!X.#@P.3(X-F,L(#!X9C4Y
M,F0X.3$L"B`@("`@("`@,'@P.&$Y,S!F-BP@,'@Y-3=E9C,P-2P@,'AB-V9B
M9F9B9"P@,'AC,C8V93DV9BP@,'@V9F4T86,Y."P@,'AB,3<S96-C,"P@,'AB
M8S8P8C0R82P@,'@Y-3,T.3AD82P*("`@("`@("`P>&9B83%A93$R+"`P>#)D
M-&)D-S,V+"`P>#!F,C5F86%B+"`P>&$T9C-F8V5B+"`P>&4R.38Y,3(S+"`P
M>#(U-V8P8S-D+"`P>#DS-#AA9C0Y+"`P>#,V,30P,&)C+`H@("`@("`@(#!X
M93@X,39F-&$L(#!X,S@Q-&8R,#`L(#!X83-F.30P-#,L(#!X.6,W834T8S(L
M(#!X8F,W,#1F-3<L(#!X9&$T,64W9CDL(#!X8S(U860S,V$L(#!X-31F-&$P
M.#0L"B`@("`@("`@,'AB,3=F-34P-2P@,'@U.3,U-V-B92P@,'AE9&)D,35C
M."P@,'@W9CDW8S5A8BP@,'AB835A8S=B-2P@,'AB-F8V9&5A9BP@,'@S830W
M.6,S82P@,'@U,S`R9&$R-2P*("`@("`@("`P>#8U,V0W939A+"`P>#4T,C8X
M9#0Y+"`P>#4Q830W-V5A+"`P>#4P,3=D-35B+"`P>&0W9#(U9#@X+"`P>#0T
M,3,V8S<V+"`P>#`T,#1A.&,X+"`P>&(X935A,3(Q+`H@("`@("`@(#!X8C@Q
M83DR.&$L(#!X-C!E9#4X-CDL(#!X.3=C-35B.38L(#!X96%E8SDY,6(L(#!X
M,CDY,S4Y,3,L(#!X,#%F9&(W9C$L(#!X,#@X93AD9F$L(#!X.6%B-F8V9C4L
M"B`@("`@("`@,'@S8C1C8F8Y9BP@,'@T835D93-A8BP@,'AE-C`U,60S-2P@
M,'AA,&4Q9#@U-2P@,'AD,S9B-&-F,2P@,'AF-30T961E8BP@,'AB,&4Y,S4R
M-"P@,'AB96)B.&9B9"P*("`@("`@("`P>&$R9#<V,F-F+"`P>#0Y8SDR9C4T
M+"`P>#,X8C5F,S,Q+"`P>#<Q,CAA-#4T+"`P>#0X,SDR.3`U+"`P>&$V-6(Q
M9&(X+"`P>#@U,6,Y-V)D+"`P>&0V-S5C9C)F*3L*"B`@("`O*BH*("`@("`J
M(%,@8F]X("AS-RD*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D<S<@/2!A<G)A>2@*("`@("`@("`P>#@U93`T,#$Y+"`P>#,S
M,F)F-38W+"`P>#8V,F1B9F9F+"`P>&-F8S8U-CDS+"`P>#)A.&0W9C9F+"`P
M>&%B.6)C.3$R+"`P>&1E-C`P.&$Q+"`P>#(P,CAD83%F+`H@("`@("`@(#!X
M,#(R-V)C93<L(#!X-&0V-#(Y,38L(#!X,3AF86,S,#`L(#!X-3!F,3AB.#(L
M(#!X,F-B,F-B,3$L(#!X8C(S,F4W-6,L(#!X-&(S-CDU9C(L(#!X8C(X-S`W
M9&4L"B`@("`@("`@,'AA,#5F8F-F-BP@,'AC9#0Q.#%E.2P@,'AE,34P,C$P
M8RP@,'AE,C1E9C%B9"P@,'AB,38X8S,X,2P@,'AF9&4T93<X.2P@,'@U8S<Y
M8C!D."P@,'@Q93AB9F0T,RP*("`@("`@("`P>#1D-#DU,#`Q+"`P>#,X8F4T
M,S0Q+"`P>#DQ,V-E93%D+"`P>#DR83<Y8S-F+"`P>#`X.3<V-F)E+"`P>&)A
M965A9&8T+"`P>#$R.#9B96-F+"`P>&(V96%C8C$Y+`H@("`@("`@(#!X,C8V
M,&,R,#`L(#!X-S4V-6)D930L(#!X-C0R-#%F-V$L(#!X.#(T.&1C83DL(#!X
M8S-B,V%D-C8L(#!X,C@Q,S8P.#8L(#!X,&)D.&1F83@L(#!X,S4V9#%C9C(L
M"B`@("`@("`@,'@Q,#<W.#EB92P@,'AB,V(R93EC92P@,'@P-3`R86$X9BP@
M,'@P8F,P,S4Q92P@,'@Q-C9B9C4R82P@,'AE8C$R9F8X,BP@,'AE,S0X-CDQ
M,2P@,'AD,S1D-S4Q-BP*("`@("`@("`P>#1E-V(S869F+"`P>#5F-#,V-S%B
M+"`P>#EC9C9E,#,W+"`P>#0Y.#%A8S@S+"`P>#,S-#(V-F-E+"`P>#AC.3,T
M,6(W+"`P>&0P9#@U-&,P+"`P>&-B,V$V8S@X+`H@("`@("`@(#!X-#=B8S(X
M,CDL(#!X-#<R-6)A,S<L(#!X838V860R,F(L(#!X-V%D-C%F,64L(#!X,&,U
M8V)A9F$L(#!X-#0S-V8Q,#<L(#!X8C9E-SDY-C(L(#!X-#)D,F0X,38L"B`@
M("`@("`@,'@P83DV,3(X."P@,'AE,6$U8S`V92P@,'@Q,S<T.64V-RP@,'@W
M,F9C,#@Q82P@,'AB,60Q,SEF-RP@,'AF.34X,S<T-2P@,'AC9C$Y9&8U."P@
M,'AB96,S9C<U-BP*("`@("`@("`P>&,P-F5B83,P+"`P>#`W,C$Q8C(T+"`P
M>#0U8S(X.#(Y+"`P>&,Y-64S,3=F+"`P>&)C.&5C-3$Q+"`P>#,X8F,T-F4Y
M+"`P>&,V939F83$T+"`P>&)A93@U.#1A+`H@("`@("`@(#!X860T96)C-#8L
M(#!X-#8X9C4P.&(L(#!X-S@R.30S-68L(#!X9C$R-#$X,V(L(#!X.#(Q9&)A
M.68L(#!X869F-C!F9C0L(#!X96$R8S1E-F0L(#!X,39E,SDR-C0L"B`@("`@
M("`@,'@Y,C4T-&$X8BP@,'@P,#EB-&9C,RP@,'AA8F$V.&-E9"P@,'@Y86,Y
M-F8W."P@,'@P-F$U8C<Y82P@,'AB,C@U-F4V92P@,'@Q865C,V-A.2P@,'AB
M93@S.#8X."P*("`@("`@("`P>#!E,#@P-&4Y+"`P>#4U9C%B934V+"`P>&4W
M934S-C-B+"`P>&(S83%F,C5D+"`P>&8W9&5B8C@U+"`P>#8Q9F4P,S-C+"`P
M>#$V-S0V,C,S+"`P>#-C,#,T8S(X+`H@("`@("`@(#!X9&$V9#!C-S0L(#!X
M-SEA86,U-F,L(#!X,V-E-&4Q860L(#!X-3%F,&,X,#(L(#!X.3AF.&8S-6$L
M(#!X,38R-F$T.68L(#!X965D.#)B,CDL(#!X,60S.#)F93,L"B`@("`@("`@
M,'@P8S1F8CDY82P@,'AB8C,R-3<W."P@,'@S96,V9#DW8BP@,'@V93<W839A
M.2P@,'AC8C8U.&(U8RP@,'AD-#4R,S!C-RP@,'@R8F0Q-#`X8BP@,'@V,&,P
M,V5B-RP*("`@("`@("`P>&(Y,#8X9#<X+"`P>&$S,S<U-&8T+"`P>&8T,S!C
M.#=D+"`P>&,X83<Q,S`R+"`P>&(Y-F0X8S,R+"`P>&5B9#1E-V)E+"`P>&)E
M.&(Y9#)D+"`P>#<Y-SEF8C`V+`H@("`@("`@(#!X93<R,C4S,#@L(#!X.&(W
M-6-F-S<L(#!X,3%E9CAD830L(#!X93`X,V,X-3@L(#!X.&0V8C<X-F8L(#!X
M-6$V,S$W838L(#!X9F$U8V8W83`L(#!X-61D83`P,S,L"B`@("`@("`@,'AF
M,CAE8F9B,"P@,'AF-6(Y8S,Q,"P@,'AA,&5A8S(X,"P@,'@P.&(Y-S8W82P@
M,'AA,V0Y9#)B,"P@,'@W.60S-#(Q-RP@,'@P,C%A-S$X9"P@,'@Y86,V,S,V
M82P*("`@("`@("`P>#(W,3%F9#8P+"`P>#0S.#`U,&4S+"`P>#`V.3DP.&$X
M+"`P>#-D-V9E9&,T+"`P>#@R-F0R8F5F+"`P>#1E96(X-#<V+"`P>#0X.&1C
M9C(U+"`P>#,V8SED-38V+`H@("`@("`@(#!X,CAE-S1E-#$L(#!X8S(V,3!A
M8V$L(#!X,V0T.6$Y8V8L(#!X8F%E,V(Y9&8L(#!X8C8U9CAD938L(#!X.3)A
M96%F-C0L(#!X,V%C-V0U938L(#!X.65A.#`U,#DL"B`@("`@("`@,'AF,C)B
M,#$W9"P@,'AA-#$W,V8W,"P@,'AD9#%E,39C,RP@,'@Q-64P9#=F.2P@,'@U
M,&(Q8C@X-RP@,'@R8CEF-&9D-2P@,'@V,C5A8F$X,BP@,'@V83`Q-SDV,BP*
M("`@("`@("`P>#)E8S`Q8CEC+"`P>#$U-#@X86$Y+"`P>&0W,39E-S0P+"`P
M>#0P,#4U83)C+"`P>#DS9#(Y83(R+"`P>&4S,F1B9CEA+"`P>#`U.#<T-6(Y
M+"`P>#,T-3-D8S%E+`H@("`@("`@(#!X9#8Y.3(Y-F4L(#!X-#DV8V9F-F8L
M(#!X,6,Y9C0Y.#8L(#!X9&9E,F5D,#<L(#!X8C@W,C0R9#$L(#!X,3ED93=E
M864L(#!X,#4S934V,6$L(#!X,35A9#9F.&,L"B`@("`@("`@,'@V-C8R-F,Q
M8RP@,'@W,34T8S(T8RP@,'AE83`X,F(R82P@,'@Y,V5B,CDS.2P@,'@Q-V1C
M8C!F,"P@,'@U.&0T9C)A92P@,'@Y96$R.31F8BP@,'@U,F-F-38T8RP*("`@
M("`@("`P>#DX.#-F938V+"`P>#)E8S0P-3@Q+"`P>#<V,SDU,V,S+"`P>#`Q
M9#8V.3)E+"`P>&0S83!C,3`X+"`P>&$Q93<Q-C!E+"`P>&4T9C)D9F$V+"`P
M>#8Y,V5D,C@U+`H@("`@("`@(#!X-S0Y,#0V.3@L(#!X-&,R8C!E9&0L(#!X
M-&8W-3<V-38L(#!X-60S.3,S-S@L(#!X83$S,C(S-&8L(#!X,V0S,C%C-60L
M(#!X8S-F-64Q.30L(#!X-&(R-CDS,#$L"B`@("`@("`@,'AC-SEF,#(R9BP@
M,'@S8SDY-V4W92P@,'@U931F.34P-"P@,'@S9F9A9F)B9"P@,'@W-F8W860P
M92P@,'@R.38V.3-F-"P@,'@S9#%F8V4V9BP@,'AC-C%E-#5B92P*("`@("`@
M("`P>&0S8C5A8C,T+"`P>&8W,F)F.6(W+"`P>#%B,#0S-&,P+"`P>#1E-S)B
M-38W+"`P>#4U.3)A,S-D+"`P>&(U,C(Y,S`Q+"`P>&-F9#)A.#=F+"`P>#8P
M865B-S8W+`H@("`@("`@(#!X,3@Q-#,X-F(L(#!X,S!B8V,S,V0L(#!X,SAA
M,&,P-V0L(#!X9F0Q-C`V9C(L(#!X8S,V,S4Q.6(L(#!X-3@Y9&0S.3`L(#!X
M-30W.68X938L(#!X,6-B.&0V-#<L"B`@("`@("`@,'@Y-V9D-C%A.2P@,'AE
M83<W-3EF-"P@,'@R9#4W-3,Y9"P@,'@U-CEA-3AC9BP@,'AE.#1E-C-A9"P@
M,'@T-C)E,6(W."P@,'@V-3@P9C@W92P@,'AF,S@Q-SDQ-"P*("`@("`@("`P
M>#DQ9&$U-68T+"`P>#0P83(S,&8S+"`P>&0Q.3@X9C,U+"`P>&(V93,Q.&0R
M+"`P>#-F9F$U,&)C+"`P>#-D-#!F,#(Q+"`P>&,S8S!B9&%E+"`P>#0Y-3AC
M,C1C+`H@("`@("`@(#!X-3$X9C,V8C(L(#!X.#1B,60S-S`L(#!X,&9E9&-E
M.#,L(#!X.#<X9&1A9&$L(#!X9C)A,C<Y8S<L(#!X.31E,#%B93@L(#!X.3`W
M,39F-&(L(#!X.34T8CAA83,I.PH*("`@("\J*@H@("`@("H@4R!B;W@@*',X
M*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S
M."`](&%R<F%Y*`H@("`@("`@(#!X93(Q-C,P,&0L(#!X8F)D9&9F9F,L(#!X
M83=E8F1A8F0L(#!X,S4V-#@P.34L(#!X-S<X.68X8C<L(#!X939C,3$R,6(L
M(#!X,&4R-#$V,#`L(#!X,#4R8V4X8C4L"B`@("`@("`@,'@Q,6$Y8V9B,"P@
M,'AE-3DU,F8Q,2P@,'AE8V4W.3DP82P@,'@Y,S@V9#$W-"P@,'@R830R.3,Q
M8RP@,'@W-F4S.#$Q,2P@,'AB,3)D968S82P@,'@S-V1D9&1F8RP*("`@("`@
M("`P>&1E.6%D96(Q+"`P>#!A,&-C,S)C+"`P>&)E,3DW,#(Y+"`P>#@T83`P
M.30P+"`P>&)B,C0S83!F+"`P>&(T9#$S-V-F+"`P>&(T-&4W.68P+"`P>#`T
M.65E9&9D+`H@("`@("`@(#!X,&(Q-6$Q-60L(#!X-#@P9#,Q-C@L(#!X.&)B
M8F1E-6$L(#!X-C8Y9&5D-#(L(#!X8S=E8V4X,S$L(#!X,V8X9CDU93<L(#!X
M-S)D9C$Y,6(L(#!X-S4X,#,S,&0L"B`@("`@("`@,'@Y-#`W-#(U,2P@,'@U
M8S=D8V1F82P@,'AA8F)E-F0V,RP@,'AA830P,C$V-"P@,'AB,S`Q9#0P82P@
M,'@P,F4W9#%C82P@,'@U,S4W,61A92P@,'@W83,Q.#)A,BP*("`@("`@("`P
M>#$R83AD9&5C+"`P>&9D86$S,S5D+"`P>#$W-F8T,V4X+"`P>#<Q9F(T-F0T
M+"`P>#,X,3(Y,#(R+"`P>&-E.30Y860T+"`P>&(X-#<V.6%D+"`P>#DV-6)D
M.#8R+`H@("`@("`@(#!X.#)F,V0P-34L(#!X-C9F8CDW-C<L(#!X,35B.#!B
M-&4L(#!X,60U8C0W83`L(#!X-&-F9&4P-F8L(#!X8S(X96,T8C@L(#!X-3=E
M.#<R-F4L(#!X-C0W83<X9F,L"B`@("`@("`@,'@Y.3@V-60T-"P@,'@V,#AB
M9#4Y,RP@,'@V8S(P,&4P,RP@,'@S.61C-69F-BP@,'@U9#!B,#!A,RP@,'AA
M938S869F,BP@,'@W93AB9#8S,BP@,'@W,#$P.&,P8RP*("`@("`@("`P>&)B
M9#,U,#0Y+"`P>#(Y.3AD9C`T+"`P>#DX,&-F-#)A+"`P>#EB-F1F-#DQ+"`P
M>#EE-V5D9#4S+"`P>#`V.3$X-30X+"`P>#4X8V(W93`W+"`P>#-B-S1E9C)E
M+`H@("`@("`@(#!X-3(R9F9F8C$L(#!X9#(T-S`X8V,L(#!X,6,W93(W8V0L
M(#!X831E8C(Q-6(L(#!X,V-F,60R93(L(#!X,3EB-#=A,S@L(#!X-#(T9C<V
M,3@L(#!X,S4X-38P,SDL"B`@("`@("`@,'@Y9#$W9&5E-RP@,'@R-V5B,S5E
M-BP@,'AC.6%F9C8W8BP@,'@S-F)A9C5B."P@,'@P.6,T-C=C9"P@,'AC,3@Y
M,3!B,2P@,'AE,3%D8F8W8BP@,'@P-F-D,6%F."P*("`@("`@("`P>#<Q-S!C
M-C`X+"`P>#)D-64S,S4T+"`P>&0T9&4T.35A+"`P>#8T8S9D,#`V+"`P>&)C
M8S!C-C)C+"`P>#-D9#`P9&(S+"`P>#<P.&8X9C,T+"`P>#<W9#4Q8C0R+`H@
M("`@("`@(#!X,C8T9C8R,&8L(#!X,C1B.&0R8F8L(#!X,35C,6(W.64L(#!X
M-#9A-3(U-C0L(#!X9CAD-V4U-&4L(#!X,V4S-S@Q-C`L(#!X-S@Y-6-D834L
M(#!X.#4Y8S$U834L"B`@("`@("`@,'AE-C0U.3<X."P@,'AC,S=B8S<U9BP@
M,'AD8C`W8F$P8RP@,'@P-C<V83-A8BP@,'@W9C(R.6(Q92P@,'@S,3@T,F4W
M8BP@,'@R-#(U.69D-RP@,'AF.&)E9C0W,BP*("`@("`@("`P>#@S-69F8V(X
M+"`P>#9D9C1C,68R+"`P>#DV9C5B,3DU+"`P>&9D,&%F,&9C+"`P>&(P9F4Q
M,S1C+"`P>&4R-3`V9#-D+"`P>#1F.6(Q,F5A+"`P>&8R,35F,C(U+`H@("`@
M("`@(#!X83(R,S<S-F8L(#!X.69B-&,T,C@L(#!X,C5D,#0Y-SDL(#!X,S1C
M-S$S9C@L(#!X8S0V,3@Q.#<L(#!X96$W839E.3@L(#!X-V-D,39E9F,L(#!X
M,30S-C@W-F,L"B`@("`@("`@,'AF,34T-#$P-RP@,'AB961E964Q-"P@,'@U
M-F4Y868R-RP@,'AA,#1A830T,2P@,'@S8V8W8S@Y.2P@,'@Y,F5C8F%E-BP@
M,'AD9#8W,#$V9"P@,'@Q-3$V.#)E8BP*("`@("`@("`P>&$X-#)E961F+"`P
M>&9D8F$V,&(T+"`P>&8Q.3`W8C<U+"`P>#(P93,P,S!F+"`P>#(T9#AC,CEE
M+"`P>&4Q,SDV-S-B+"`P>&5F838S9F(X+"`P>#<Q.#<S,#4T+`H@("`@("`@
M(#!X8C9F,F-F,V(L(#!X.68S,C8T-#(L(#!X8V(Q-6$T8V,L(#!X8C`Q830U
M,#0L(#!X9C%E-#=D.&0L(#!X.#0T83%B934L(#!X8F%E-V1F9&,L(#!X-#)C
M8F1A-S`L"B`@("`@("`@,'AC9#=D864P82P@,'@U-V4X-6(W82P@,'AD-3-F
M-6%F-BP@,'@R,&-F-&0X8RP@,'AC96$T9#0R."P@,'@W.60Q,S!A-"P@,'@S
M-#@V96)F8BP@,'@S,V0S8V1D8RP*("`@("`@("`P>#<W.#4S8C4S+"`P>#,W
M969F8V(U+"`P>&,U,#8X-S<X+"`P>&4U.#!B,V4V+"`P>#1E-CAB.&8T+"`P
M>&,U8SAB,S=E+"`P>#!D.#`Y96$R+"`P>#,Y.&9E8C=C+`H@("`@("`@(#!X
M,3,R831F.30L(#!X-#-B-SDU,&4L(#!X,F9E93=D,6,L(#!X,C(S-C$S8F0L
M(#!X9&0P-F-A83(L(#!X,S=D9CDS,F(L(#!X8S0R-#@R.#DL(#!X86-F,V5B
M8S,L"B`@("`@("`@,'@U-S$U9C9B-RP@,'AE9C,T-SAD9"P@,'AF,C8W-C$V
M9BP@,'AC,30X8V)E-"P@,'@Y,#4R.#$U92P@,'@U930Q,&9A8BP@,'AB-#AA
M,C0V-2P@,'@R961A-V9A-"P*("`@("`@("`P>&4X-V(T,&4T+"`P>&4Y.&5A
M,#@T+"`P>#4X.#EE.64Q+"`P>&5F9#,Y,&9C+"`P>&1D,#=D,S5B+"`P>&1B
M-#@U-CDT+"`P>#,X9#=E-6(R+"`P>#4W-S(P,3`Q+`H@("`@("`@(#!X-S,P
M961E8F,L(#!X-6(V-#,Q,3,L(#!X.30Y,3=E-&8L(#!X-3`S8S)F8F$L(#!X
M-C0V9C$R.#(L(#!X-S4R,V0R-&$L(#!X93`W-SDV.34L(#!X9CEC,3=A.&8L
M"B`@("`@("`@,'@W835B,C$R,2P@,'AD,3@W8C@Y-BP@,'@R.3(V,V$T9"P@
M,'AB834Q,&-D9BP@,'@X,68T-V,Y9BP@,'AA9#$Q-C-E9"P@,'AE83=B-3DV
M-2P@,'@Q83`P-S(V92P*("`@("`@("`P>#$Q-#`S,#DR+"`P>#`P9&$V9#<W
M+"`P>#1A,&-D9#8Q+"`P>&%D,68T-C`S+"`P>#8P-6)D9F(P+"`P>#EE961C
M,S8T+"`P>#(R96)E-F$X+"`P>&-E93=D,CAA+`H@("`@("`@(#!X83!E-S,V
M83`L(#!X-34V-&$V8CDL(#!X,3`X-3,R,#DL(#!X8S=E8CAF,S<L(#!X,F1E
M-S`U8V$L(#!X.#DU,34W,&8L(#!X9&8P.3@R,F(L(#!X8F0V.3%A-F,L"B`@
M("`@("`@,'AA83$R931F,BP@,'@X-S0U,6,P9BP@,'AE,&8V83(W82P@,'@S
M861A-#@Q.2P@,'@T8V8Q-S8T9BP@,'@P9#<W,6,R8BP@,'@V-V-D8C$U-BP@
M,'@S-3!D.#,X-"P*("`@("`@("`P>#4Y,SAF83!F+"`P>#0R,SDY968S+"`P
M>#,V.3DW8C`W+"`P>#!E.#0P.3-D+"`P>#1A83DS938Q+"`P>#@S-C!D.#=B
M+"`P>#%F83DX8C!C+"`P>#$Q-#DS.#)C+`H@("`@("`@(#!X93DW-C(U834L
M(#!X,#8Q-&0Q8C<L(#!X,&4R-3(T-&(L(#!X,&,W-C@S-#<L(#!X-3@Y93AD
M.#(L(#!X,&0R,#4Y9#$L(#!X830V-F)B,64L(#!X9CAD83!A.#(L"B`@("`@
M("`@,'@P-&8Q.3$S,"P@,'AB839E-&5C,"P@,'@Y.3(V-3$V-"P@,'@Q964W
M,C,P9"P@,'@U,&(R860X,"P@,'AE865E-C@P,2P@,'@X9&(R83(X,RP@,'AE
M83AB9C4Y92D["@H@("`@+RHJ"B`@("`@*B!-87-K:6YG($ME>7,*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7TMM(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J(%)O=&%T92!+97ES"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]+<B`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O=6YD<R!T;R!D;PH@
M("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]R
M;W5N9',@/2`Q-CL*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:V5Y('1O(&)E
M('5S960@9F]R(&5N+V1E8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:V5Y("!4:&4@:V5Y('1O('5S92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T2V5Y*"1K97DI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F]U;F1S(#T@*'-T<FQE
M;B@D:V5Y*2`\(#$Q*2`_(#$R(#H@,38["B`@("`@("`@("`@("1K97D@/2`D
M=&AI<RT^7V9O<FUA=$ME>2@D:V5Y*3L*("`@("`@("`@("`@)&ME>5-C:&5D
M=6QE(#T@)'1H:7,M/E]K97E38VAE9'5L92@D:V5Y*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I>F4@;V8@=&AE(&)L
M;V-K<R!T:&%T('1H:7,@8VEP:&5R(&YE961S+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!C:&%R86-T97)S('!E<B!B
M;&]C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VM3:7IE*"D*("`@
M('L*("`@("`@("!R971U<FX@.#L*("`@('T*"B`@("`O*BH*("`@("`J($5N
M8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!E;F-R>7!T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D(&]U='!U="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@96YC<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<F]U;F1S(#T@*'-T<FQE;B@D:V5Y*2`\(#$Q
M*2`_(#$R(#H@,38["B`@("`@("`@("`@("1K97D@/2`D=&AI<RT^7V9O<FUA
M=$ME>2@D:V5Y*3L*("`@("`@("`@("`@)&ME>5-C:&5D=6QE(#T@)'1H:7,M
M/E]K97E38VAE9'5L92@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@("1,(#T@
M)'1H:7,M/E]F;W)M871$871A*'-U8G-T<B@D8FQO8VLL(#`L(#0I*3L*("`@
M("`@("`D4B`]("1T:&ES+3Y?9F]R;6%T1&%T82AS=6)S='(H)&)L;V-K+"`T
M+"`T*2D["@H@("`@("`@("1,(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M/E]+
M;5LQ72P@("1T:&ES+3Y?2W);,5TI.PH@("`@("`@("12(%X]("1T:&ES+3YF
M,B@D3"P@)'1H:7,M/E]+;5LR72P@("1T:&ES+3Y?2W);,ETI.PH@("`@("`@
M("1,(%X]("1T:&ES+3YF,R@D4BP@)'1H:7,M/E]+;5LS72P@("1T:&ES+3Y?
M2W);,UTI.PH@("`@("`@("12(%X]("1T:&ES+3YF,2@D3"P@)'1H:7,M/E]+
M;5LT72P@("1T:&ES+3Y?2W);-%TI.PH@("`@("`@("1,(%X]("1T:&ES+3YF
M,B@D4BP@)'1H:7,M/E]+;5LU72P@("1T:&ES+3Y?2W);-5TI.PH@("`@("`@
M("12(%X]("1T:&ES+3YF,R@D3"P@)'1H:7,M/E]+;5LV72P@("1T:&ES+3Y?
M2W);-ETI.PH@("`@("`@("1,(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M/E]+
M;5LW72P@("1T:&ES+3Y?2W);-UTI.PH@("`@("`@("12(%X]("1T:&ES+3YF
M,B@D3"P@)'1H:7,M/E]+;5LX72P@("1T:&ES+3Y?2W);.%TI.PH@("`@("`@
M("1,(%X]("1T:&ES+3YF,R@D4BP@)'1H:7,M/E]+;5LY72P@("1T:&ES+3Y?
M2W);.5TI.PH@("`@("`@("12(%X]("1T:&ES+3YF,2@D3"P@)'1H:7,M/E]+
M;5LQ,%TL("1T:&ES+3Y?2W);,3!=*3L*("`@("`@("`D3"!>/2`D=&AI<RT^
M9C(H)%(L("1T:&ES+3Y?2VU;,3%=+"`D=&AI<RT^7TMR6S$Q72D["B`@("`@
M("`@)%(@7CT@)'1H:7,M/F8S*"1,+"`D=&AI<RT^7TMM6S$R72P@)'1H:7,M
M/E]+<ELQ,ETI.PH@("`@("`@(&EF("@D=&AI<RT^7W)O=6YD<R`^(#$R*2![
M"B`@("`@("`@("`@("1,(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M/E]+;5LQ
M,UTL("1T:&ES+3Y?2W);,3-=*3L*("`@("`@("`@("`@)%(@7CT@)'1H:7,M
M/F8R*"1,+"`D=&AI<RT^7TMM6S$T72P@)'1H:7,M/E]+<ELQ-%TI.PH@("`@
M("`@("`@("`D3"!>/2`D=&AI<RT^9C,H)%(L("1T:&ES+3Y?2VU;,35=+"`D
M=&AI<RT^7TMR6S$U72D["B`@("`@("`@("`@("12(%X]("1T:&ES+3YF,2@D
M3"P@)'1H:7,M/E]+;5LQ-ETL("1T:&ES+3Y?2W);,39=*3L*("`@("`@("!]
M"@H@("`@("`@("1E;F-R>7!T960@/2!P86-K*").(BP@)%(I("X@<&%C:R@B
M3B(L("1,*3L*"B`@("`@("`@<F5T=7)N("1E;F-R>7!T960["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE(&1A=&$@=&\@9&5C
M<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("!4:&4@:V5Y('1O
M('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y
M<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'1";&]C
M:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)O=6YD<R`]("AS
M=')L96XH)&ME>2D@/"`Q,2D@/R`Q,B`Z(#$V.PH@("`@("`@("`@("`D:V5Y
M(#T@)'1H:7,M/E]F;W)M871+97DH)&ME>2D["B`@("`@("`@("`@("1K97E3
M8VAE9'5L92`]("1T:&ES+3Y?:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@
M?0H*("`@("`@("`D4B`]("1T:&ES+3Y?9F]R;6%T1&%T82AS=6)S='(H)&)L
M;V-K+"`P+"`T*2D["B`@("`@("`@)$P@/2`D=&AI<RT^7V9O<FUA=$1A=&$H
M<W5B<W1R*"1B;&]C:RP@-"P@-"DI.PH*("`@("`@("!I9B`H)'1H:7,M/E]R
M;W5N9',@/B`Q,BD@>PH@("`@("`@("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL
M("1T:&ES+3Y?2VU;,39=+"`D=&AI<RT^7TMR6S$V72D["B`@("`@("`@("`@
M("1,(%X]("1T:&ES+3YF,R@D4BP@)'1H:7,M/E]+;5LQ-5TL("1T:&ES+3Y?
M2W);,35=*3L*("`@("`@("`@("`@)%(@7CT@)'1H:7,M/F8R*"1,+"`D=&AI
M<RT^7TMM6S$T72P@)'1H:7,M/E]+<ELQ-%TI.PH@("`@("`@("`@("`D3"!>
M/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;,3-=+"`D=&AI<RT^7TMR6S$S
M72D["B`@("`@("`@?0H*("`@("`@("`D4B!>/2`D=&AI<RT^9C,H)$PL("1T
M:&ES+3Y?2VU;,3)=+"`D=&AI<RT^7TMR6S$R72D["B`@("`@("`@)$P@7CT@
M)'1H:7,M/F8R*"12+"`D=&AI<RT^7TMM6S$Q72P@)'1H:7,M/E]+<ELQ,5TI
M.PH@("`@("`@("12(%X]("1T:&ES+3YF,2@D3"P@)'1H:7,M/E]+;5LQ,%TL
M("1T:&ES+3Y?2W);,3!=*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C,H)%(L
M("1T:&ES+3Y?2VU;.5TL("`D=&AI<RT^7TMR6SE=*3L*("`@("`@("`D4B!>
M/2`D=&AI<RT^9C(H)$PL("1T:&ES+3Y?2VU;.%TL("`D=&AI<RT^7TMR6SA=
M*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;-UTL
M("`D=&AI<RT^7TMR6S==*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C,H)$PL
M("1T:&ES+3Y?2VU;-ETL("`D=&AI<RT^7TMR6S9=*3L*("`@("`@("`D3"!>
M/2`D=&AI<RT^9C(H)%(L("1T:&ES+3Y?2VU;-5TL("`D=&AI<RT^7TMR6S5=
M*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;-%TL
M("`D=&AI<RT^7TMR6S1=*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C,H)%(L
M("1T:&ES+3Y?2VU;,UTL("`D=&AI<RT^7TMR6S-=*3L*("`@("`@("`D4B!>
M/2`D=&AI<RT^9C(H)$PL("1T:&ES+3Y?2VU;,ETL("`D=&AI<RT^7TMR6S)=
M*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;,5TL
M("`D=&AI<RT^7TMR6S%=*3L*"B`@("`@("`@)&1E8W)Y<'1E9"`]('!A8VLH
M(DXB+"`D3"D@+B!P86-K*").(BP@)%(I.PH*("`@("`@("!R971U<FX@)&1E
M8W)Y<'1E9#L*("`@('T*"B`@("`O*BH*("`@("`J(&8Q*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@9C$H)&0L("1+;2P@)$MR*0H@("`@>PH@("`@("`@("1)
M(#T@)$MM("L@)&0["@H@("`@("`@("\J($YA<W1Y($9I>"!A<PH@("`@("`@
M("`J("1)(#P\("1+<B!\("1)(#X^("@S,B`M("1+<BD*("`@("`@("`@*B!$
M;V5S;B=T(&%L=V%Y<R!G:79E('1H92!C;W)R96-T(&%N<W=E<@H@("`@("`@
M("`J+PH@("`@("`@("1B:6X@/2!S=')?<&%D*&1E8V)I;B@D22DL(#,R+"`G
M,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@)$D@/2!B:6YD96,H<W5B<W1R
M*"1B:6XL("1+<BD@+B!S=6)S='(H)&)I;BP@,"P@)$MR*2D["@H@("`@("`@
M("1F(#T@)'1H:7,M/G,Q6R@D22`^/B`R-"D@)B`P>$9&72!>("1T:&ES+3YS
M,ELH)$D@/CX@,38I("8@,'A&1ET["B`@("`@("`@)&8@/2`D9B`M("1T:&ES
M+3YS,ULH)$D@/CX@."D@)B`P>$9&73L*("`@("`@("`D9B`]("1F("L@)'1H
M:7,M/G,T6R1)("8@,'A&1ET["B`@("`@("`@<F5T=7)N("1F.PH@("`@?0H*
M("`@("\J*@H@("`@("H@9C(H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F,B@D
M9"P@)$MM+"`D2W(I"B`@("!["B`@("`@("`@)$D@/2`D2VT@7B`D9#L*"B`@
M("`@("`@+RH@3F%S='D@1FEX(&%S"B`@("`@("`@("H@)$D@/#P@)$MR('P@
M)$D@/CX@*#,R("T@)$MR*0H@("`@("`@("`J($1O97-N)W0@86QW87ES(&=I
M=F4@=&AE(&-O<G)E8W0@86YS=V5R"B`@("`@("`@("HO"B`@("`@("`@)&)I
M;B`]('-T<E]P860H9&5C8FEN*"1)*2P@,S(L("<P)RP@4U127U!!1%],1494
M*3L*("`@("`@("`D22`](&)I;F1E8RAS=6)S='(H)&)I;BP@)$MR*2`N('-U
M8G-T<B@D8FEN+"`P+"`D2W(I*3L*"B`@("`@("`@)&8@/2`D=&AI<RT^<S%;
M*"1)(#X^(#(T*2`F(#!X1D9=("T@)'1H:7,M/G,R6R@D22`^/B`Q-BD@)B`P
M>$9&73L*("`@("`@("`D9B`]("1F("L@)'1H:7,M/G,S6R@D22`^/B`X*2`F
M(#!X1D9=.PH@("`@("`@("1F(#T@)&8@7B`D=&AI<RT^<S1;)$D@)B`P>$9&
M73L*("`@("`@("!R971U<FX@)&8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!F
M,R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&8S*"1D+"`D2VTL("1+<BD*("`@
M('L*("`@("`@("`D22`](#!X1D9&1D9&1D8@)B`H)$MM("T@)&0I.PH*("`@
M("`@("`O*B!.87-T>2!&:7@@87,*("`@("`@("`@*B`D22`\/"`D2W(@?"`D
M22`^/B`H,S(@+2`D2W(I"B`@("`@("`@("H@1&]E<VXG="!A;'=A>7,@9VEV
M92!T:&4@8V]R<F5C="!A;G-W97(*("`@("`@("`@*B\*("`@("`@("`D8FEN
M(#T@<W1R7W!A9"AD96-B:6XH)$DI+"`S,BP@)S`G+"!35%)?4$%$7TQ%1E0I
M.PH@("`@("`@("1)(#T@8FEN9&5C*'-U8G-T<B@D8FEN+"`D2W(I("X@<W5B
M<W1R*"1B:6XL(#`L("1+<BDI.PH*("`@("`@("`D9B`]("@D=&AI<RT^<S%;
M*"1)(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D22`^/B`Q-BD@)B`P
M>$9&72D["B`@("`@("`@)&8@/2`D9B!>("1T:&ES+3YS,ULH)$D@/CX@."D@
M)B`P>$9&73L*("`@("`@("`D9B`](#!X1D9&1D9&1D8@)B`H)&8@+2`D=&AI
M<RT^<S1;)$D@)B`P>$9&72D["B`@("`@("`@<F5T=7)N("1F.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]N=F5R="!A('-T<FEN9R!I;G1O(&$@87)R87D@
M;V8@=&AE(&]R9&EN871E<R!O9B!I=',@8VAA<F%C=&5R<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D871A("!$871A('1O(&-O;G9E<G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-O;G9E<G1E9"!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9F]R;6%T1&%T82@D9&%T82D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUB:6YE-"AU;G!A8VLH)T,J
M)RP@)&1A=&$I+"`P>#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R
M=',@82!T97AT(&ME>2!I;G1O(&%N(&%R<F%Y('!A9&1E9"!W:71H(%PP)W,@
M=&\@82!L96YG=&@@;V8@,3(X"B`@("`@*B!B:71S+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@5&AE(&ME>2!T;R!F;W)M870N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('!A9&1E9"!K97DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]F;W)M871+97DH)&ME>2D*("`@('L*("`@("`@
M("`D<F5S(#T@87)R87E?=F%L=65S*'5N<&%C:R@G0RHG+"`D:V5Y*2D["B`@
M("`@("`@9F]R("@D:2`](&-O=6YT*"1R97,I.R`D:2`\(#$V.R`D:2LK*2![
M"B`@("`@("`@("`@("1R97-;)&E=(#T@,#L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE
M(&-O;7!L971E(&ME>2!S:&5D=6QE+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D:V5Y("!4:&4@:V5Y('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7VME>5-C:&5D=6QE*"1K97DI"B`@("!["B`@("`@("`@)'@P>#%X,G@S
M(#T@)'1H:7,M/E]C;VUB:6YE-"@D:V5Y+"`P>#`I.PH@("`@("`@("1X-'@U
M>#9X-R`]("1T:&ES+3Y?8V]M8FEN930H)&ME>2P@,'@T*3L*("`@("`@("`D
M>#AX.7A!>$(@/2`D=&AI<RT^7V-O;6)I;F4T*"1K97DL(#!X."D["B`@("`@
M("`@)'A#>$1X17A&(#T@)'1H:7,M/E]C;VUB:6YE-"@D:V5Y+"`P>$,I.PH*
M("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@
M)&);,%T[("1X,2`]("1B6S%=.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);,UT[
M"B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X-'@U>#9X-RD[("1X-"`]
M("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V(#T@)&);,ET[("1X-R`]("1B6S-=
M.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#AX.7A!>$(I.R`D>#@@
M/2`D8ELP73L@)'@Y(#T@)&);,5T[("1X02`]("1B6S)=.R`D>$(@/2`D8ELS
M73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'A#>$1X17A&*3L@)'A#
M(#T@)&);,%T[("1X1"`]("1B6S%=.R`D>$4@/2`D8ELR73L@)'A&(#T@)&);
M,UT["@H@("`@("`@("1Z,'HQ>C)Z,R`]("1X,'@Q>#)X,R!>("1T:&ES+3YS
M-5LD>$1=(%X@)'1H:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;)'A#72!>("1T
M:&ES+3YS.%LD>$5=(%X@)'1H:7,M/G,W6R1X.%T["B`@("`@("`@)&(@/2`D
M=&AI<RT^7W-P;&ET*"1Z,'HQ>C)Z,RD[("1Z,"`]("1B6S!=.R`D>C$@/2`D
M8ELQ73L@)'HR(#T@)&);,ET[("1Z,R`]("1B6S-=.PH@("`@("`@("1Z-'HU
M>C9Z-R`]("1X.'@Y>$%X0B!>("1T:&ES+3YS-5LD>C!=(%X@)'1H:7,M/G,V
M6R1Z,ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES+3YS.%LD>C-=(%X@)'1H
M:7,M/G,X6R1X05T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z-'HU
M>C9Z-RD[("1Z-"`]("1B6S!=.R`D>C4@/2`D8ELQ73L@)'HV(#T@)&);,ET[
M("1Z-R`]("1B6S-=.PH@("`@("`@("1Z.'HY>D%Z0B`]("1X0WA$>$5X1B!>
M("1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@7B`D=&AI<RT^<S=;
M)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,U6R1X.5T["B`@("`@
M("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z.'HY>D%Z0BD[("1Z."`]("1B6S!=
M.R`D>CD@/2`D8ELQ73L@)'I!(#T@)&);,ET[("1Z0B`]("1B6S-=.PH@("`@
M("`@("1Z0WI$>D5Z1B`]("1X-'@U>#9X-R!>("1T:&ES+3YS-5LD>D%=(%X@
M)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'I"72!>("1T:&ES+3YS.%LD
M>CA=(%X@)'1H:7,M/G,V6R1X0ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P
M;&ET*"1Z0WI$>D5Z1BD[("1Z0R`]("1B6S!=.R`D>D0@/2`D8ELQ73L@)'I%
M(#T@)&);,ET[("1Z1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMM6S%=
M(#T@)'1H:7,M/G,U6R1Z.%T@7B`D=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS
M-ULD>C==(%X@)'1H:7,M/G,X6R1Z-ET@7B`D=&AI<RT^<S5;)'HR73L*("`@
M("`@("`D=&AI<RT^7TMM6S)=(#T@)'1H:7,M/G,U6R1Z05T@7B`D=&AI<RT^
M<S9;)'I"72!>("1T:&ES+3YS-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D
M=&AI<RT^<S9;)'HV73L*("`@("`@("`D=&AI<RT^7TMM6S-=(#T@)'1H:7,M
M/G,U6R1Z0UT@7B`D=&AI<RT^<S9;)'I$72!>("1T:&ES+3YS-ULD>C-=(%X@
M)'1H:7,M/G,X6R1Z,ET@7B`D=&AI<RT^<S=;)'HY73L*("`@("`@("`D=&AI
M<RT^7TMM6S1=(#T@)'1H:7,M/G,U6R1Z15T@7B`D=&AI<RT^<S9;)'I&72!>
M("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z,%T@7B`D=&AI<RT^<SA;
M)'I#73L*"B`@("`@("`@)'@P>#%X,G@S(#T@)'HX>CEZ07I"(%X@)'1H:7,M
M/G,U6R1Z-5T@7B`D=&AI<RT^<S9;)'HW72!>("1T:&ES+3YS-ULD>C1=(%X@
M)'1H:7,M/G,X6R1Z-ET@7B`D=&AI<RT^<S=;)'HP73L*("`@("`@("`D8B`]
M("1T:&ES+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@)&);,%T[("1X,2`]
M("1B6S%=.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);,UT["B`@("`@("`@)'@T
M>#5X-G@W(#T@)'HP>C%Z,GHS(%X@)'1H:7,M/G,U6R1X,%T@7B`D=&AI<RT^
M<S9;)'@R72!>("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X6R1X,UT@7B`D
M=&AI<RT^<SA;)'HR73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@T
M>#5X-G@W*3L@)'@T(#T@)&);,%T[("1X-2`]("1B6S%=.R`D>#8@/2`D8ELR
M73L@)'@W(#T@)&);,UT["B`@("`@("`@)'@X>#EX07A"(#T@)'HT>C5Z-GHW
M(%X@)'1H:7,M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS
M-ULD>#5=(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^<S5;)'HQ73L*("`@
M("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"*3L@)'@X(#T@)&);
M,%T[("1X.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"(#T@)&);,UT["B`@
M("`@("`@)'A#>$1X17A&(#T@)'I#>D1Z17I&(%X@)'1H:7,M/G,U6R1X05T@
M7B`D=&AI<RT^<S9;)'@Y72!>("1T:&ES+3YS-ULD>$)=(%X@)'1H:7,M/G,X
M6R1X.%T@7B`D=&AI<RT^<S9;)'HS73L*("`@("`@("`D8B`]("1T:&ES+3Y?
M<W!L:70H)'A#>$1X17A&*3L@)'A#(#T@)&);,%T[("1X1"`]("1B6S%=.R`D
M>$4@/2`D8ELR73L@)'A&(#T@)&);,UT["@H@("`@("`@("1T:&ES+3Y?2VU;
M-5T@(#T@)'1H:7,M/G,U6R1X,UT@7B`D=&AI<RT^<S9;)'@R72!>("1T:&ES
M+3YS-ULD>$-=(%X@)'1H:7,M/G,X6R1X1%T@7B`D=&AI<RT^<S5;)'@X73L*
M("`@("`@("`D=&AI<RT^7TMM6S9=("`]("1T:&ES+3YS-5LD>#%=(%X@)'1H
M:7,M/G,V6R1X,%T@7B`D=&AI<RT^<S=;)'A%72!>("1T:&ES+3YS.%LD>$9=
M(%X@)'1H:7,M/G,V6R1X1%T["B`@("`@("`@)'1H:7,M/E]+;5LW72`@/2`D
M=&AI<RT^<S5;)'@W72!>("1T:&ES+3YS-ELD>#9=(%X@)'1H:7,M/G,W6R1X
M.%T@7B`D=&AI<RT^<SA;)'@Y72!>("1T:&ES+3YS-ULD>#-=.PH@("`@("`@
M("1T:&ES+3Y?2VU;.%T@(#T@)'1H:7,M/G,U6R1X-5T@7B`D=&AI<RT^<S9;
M)'@T72!>("1T:&ES+3YS-ULD>$%=(%X@)'1H:7,M/G,X6R1X0ET@7B`D=&AI
M<RT^<SA;)'@W73L*"B`@("`@("`@)'HP>C%Z,GHS(#T@)'@P>#%X,G@S(%X@
M)'1H:7,M/G,U6R1X1%T@7B`D=&AI<RT^<S9;)'A&72!>("1T:&ES+3YS-ULD
M>$-=(%X@)'1H:7,M/G,X6R1X15T@7B`D=&AI<RT^<S=;)'@X73L*("`@("`@
M("`D8B`]("1T:&ES+3Y?<W!L:70H)'HP>C%Z,GHS*3L@)'HP(#T@)&);,%T[
M("1Z,2`]("1B6S%=.R`D>C(@/2`D8ELR73L@)'HS(#T@)&);,UT["B`@("`@
M("`@)'HT>C5Z-GHW(#T@)'@X>#EX07A"(%X@)'1H:7,M/G,U6R1Z,%T@7B`D
M=&AI<RT^<S9;)'HR72!>("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z
M,UT@7B`D=&AI<RT^<SA;)'A!73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L
M:70H)'HT>C5Z-GHW*3L@)'HT(#T@)&);,%T[("1Z-2`]("1B6S%=.R`D>C8@
M/2`D8ELR73L@)'HW(#T@)&);,UT["B`@("`@("`@)'HX>CEZ07I"(#T@)'A#
M>$1X17A&(%X@)'1H:7,M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T
M:&ES+3YS-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^<S5;)'@Y
M73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HX>CEZ07I"*3L@)'HX
M(#T@)&);,%T[("1Z.2`]("1B6S%=.R`D>D$@/2`D8ELR73L@)'I"(#T@)&);
M,UT["B`@("`@("`@)'I#>D1Z17I&(#T@)'@T>#5X-G@W(%X@)'1H:7,M/G,U
M6R1Z05T@7B`D=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS-ULD>D)=(%X@)'1H
M:7,M/G,X6R1Z.%T@7B`D=&AI<RT^<S9;)'A"73L*("`@("`@("`D8B`]("1T
M:&ES+3Y?<W!L:70H)'I#>D1Z17I&*3L@)'I#(#T@)&);,%T[("1Z1"`]("1B
M6S%=.R`D>D4@/2`D8ELR73L@)'I&(#T@)&);,UT["@H@("`@("`@("1T:&ES
M+3Y?2VU;.5T@(#T@)'1H:7,M/G,U6R1Z,UT@7B`D=&AI<RT^<S9;)'HR72!>
M("1T:&ES+3YS-ULD>D-=(%X@)'1H:7,M/G,X6R1Z1%T@7B`D=&AI<RT^<S5;
M)'HY73L*("`@("`@("`D=&AI<RT^7TMM6S$P72`]("1T:&ES+3YS-5LD>C%=
M(%X@)'1H:7,M/G,V6R1Z,%T@7B`D=&AI<RT^<S=;)'I%72!>("1T:&ES+3YS
M.%LD>D9=(%X@)'1H:7,M/G,V6R1Z0UT["B`@("`@("`@)'1H:7,M/E]+;5LQ
M,5T@/2`D=&AI<RT^<S5;)'HW72!>("1T:&ES+3YS-ELD>C9=(%X@)'1H:7,M
M/G,W6R1Z.%T@7B`D=&AI<RT^<SA;)'HY72!>("1T:&ES+3YS-ULD>C)=.PH@
M("`@("`@("1T:&ES+3Y?2VU;,3)=(#T@)'1H:7,M/G,U6R1Z-5T@7B`D=&AI
M<RT^<S9;)'HT72!>("1T:&ES+3YS-ULD>D%=(%X@)'1H:7,M/G,X6R1Z0ET@
M7B`D=&AI<RT^<SA;)'HV73L*"B`@("`@("`@)'@P>#%X,G@S(#T@)'HX>CEZ
M07I"(%X@)'1H:7,M/G,U6R1Z-5T@7B`D=&AI<RT^<S9;)'HW72!>("1T:&ES
M+3YS-ULD>C1=(%X@)'1H:7,M/G,X6R1Z-ET@7B`D=&AI<RT^<S=;)'HP73L*
M("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@
M)&);,%T[("1X,2`]("1B6S%=.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);,UT[
M"B`@("`@("`@)'@T>#5X-G@W(#T@)'HP>C%Z,GHS(%X@)'1H:7,M/G,U6R1X
M,%T@7B`D=&AI<RT^<S9;)'@R72!>("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M
M/G,X6R1X,UT@7B`D=&AI<RT^<SA;)'HR73L*("`@("`@("`D8B`]("1T:&ES
M+3Y?<W!L:70H)'@T>#5X-G@W*3L@)'@T(#T@)&);,%T[("1X-2`]("1B6S%=
M.R`D>#8@/2`D8ELR73L@)'@W(#T@)&);,UT["B`@("`@("`@)'@X>#EX07A"
M(#T@)'HT>C5Z-GHW(%X@)'1H:7,M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V
M72!>("1T:&ES+3YS-ULD>#5=(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^
M<S5;)'HQ73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"
M*3L@)'@X(#T@)&);,%T[("1X.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"
M(#T@)&);,UT["B`@("`@("`@)'A#>$1X17A&(#T@)'I#>D1Z17I&(%X@)'1H
M:7,M/G,U6R1X05T@7B`D=&AI<RT^<S9;)'@Y72!>("1T:&ES+3YS-ULD>$)=
M(%X@)'1H:7,M/G,X6R1X.%T@7B`D=&AI<RT^<S9;)'HS73L*("`@("`@("`D
M8B`]("1T:&ES+3Y?<W!L:70H)'A#>$1X17A&*3L@)'A#(#T@)&);,%T[("1X
M1"`]("1B6S%=.R`D>$4@/2`D8ELR73L@)'A&(#T@)&);,UT["@H@("`@("`@
M("1T:&ES+3Y?2VU;,3-=(#T@)'1H:7,M/G,U6R1X.%T@7B`D=&AI<RT^<S9;
M)'@Y72!>("1T:&ES+3YS-ULD>#==(%X@)'1H:7,M/G,X6R1X-ET@7B`D=&AI
M<RT^<S5;)'@S73L*("`@("`@("`D=&AI<RT^7TMM6S$T72`]("1T:&ES+3YS
M-5LD>$%=(%X@)'1H:7,M/G,V6R1X0ET@7B`D=&AI<RT^<S=;)'@U72!>("1T
M:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,V6R1X-UT["B`@("`@("`@)'1H:7,M
M/E]+;5LQ-5T@/2`D=&AI<RT^<S5;)'A#72!>("1T:&ES+3YS-ELD>$1=(%X@
M)'1H:7,M/G,W6R1X,UT@7B`D=&AI<RT^<SA;)'@R72!>("1T:&ES+3YS-ULD
M>#A=.PH@("`@("`@("1T:&ES+3Y?2VU;,39=(#T@)'1H:7,M/G,U6R1X15T@
M7B`D=&AI<RT^<S9;)'A&72!>("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X
M6R1X,%T@7B`D=&AI<RT^<SA;)'A$73L*"B`@("`@("`@)'HP>C%Z,GHS(#T@
M)'@P>#%X,G@S(%X@)'1H:7,M/G,U6R1X1%T@7B`D=&AI<RT^<S9;)'A&72!>
M("1T:&ES+3YS-ULD>$-=(%X@)'1H:7,M/G,X6R1X15T@7B`D=&AI<RT^<S=;
M)'@X73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HP>C%Z,GHS*3L@
M)'HP(#T@)&);,%T[("1Z,2`]("1B6S%=.R`D>C(@/2`D8ELR73L@)'HS(#T@
M)&);,UT["B`@("`@("`@)'HT>C5Z-GHW(#T@)'@X>#EX07A"(%X@)'1H:7,M
M/G,U6R1Z,%T@7B`D=&AI<RT^<S9;)'HR72!>("1T:&ES+3YS-ULD>C%=(%X@
M)'1H:7,M/G,X6R1Z,UT@7B`D=&AI<RT^<SA;)'A!73L*("`@("`@("`D8B`]
M("1T:&ES+3Y?<W!L:70H)'HT>C5Z-GHW*3L@)'HT(#T@)&);,%T[("1Z-2`]
M("1B6S%=.R`D>C8@/2`D8ELR73L@)'HW(#T@)&);,UT["B`@("`@("`@)'HX
M>CEZ07I"(#T@)'A#>$1X17A&(%X@)'1H:7,M/G,U6R1Z-UT@7B`D=&AI<RT^
M<S9;)'HV72!>("1T:&ES+3YS-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D
M=&AI<RT^<S5;)'@Y73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HX
M>CEZ07I"*3L@)'HX(#T@)&);,%T[("1Z.2`]("1B6S%=.R`D>D$@/2`D8ELR
M73L@)'I"(#T@)&);,UT["B`@("`@("`@)'I#>D1Z17I&(#T@)'@T>#5X-G@W
M(%X@)'1H:7,M/G,U6R1Z05T@7B`D=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS
M-ULD>D)=(%X@)'1H:7,M/G,X6R1Z.%T@7B`D=&AI<RT^<S9;)'A"73L*("`@
M("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'I#>D1Z17I&*3L@)'I#(#T@)&);
M,%T[("1Z1"`]("1B6S%=.R`D>D4@/2`D8ELR73L@)'I&(#T@)&);,UT["@H@
M("`@("`@("1T:&ES+3Y?2W);,5T@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'HX
M72!>("1T:&ES+3YS-ELD>CE=(%X@)'1H:7,M/G,W6R1Z-UT@7B`D=&AI<RT^
M<SA;)'HV72!>("1T:&ES+3YS-5LD>C)=*3L*("`@("`@("`D=&AI<RT^7TMR
M6S)=("`](#!X,48@)B`H)'1H:7,M/G,U6R1Z05T@7B`D=&AI<RT^<S9;)'I"
M72!>("1T:&ES+3YS-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^
M<S9;)'HV72D["B`@("`@("`@)'1H:7,M/E]+<ELS72`@/2`P>#%&("8@*"1T
M:&ES+3YS-5LD>D-=(%X@)'1H:7,M/G,V6R1Z1%T@7B`D=&AI<RT^<S=;)'HS
M72!>("1T:&ES+3YS.%LD>C)=(%X@)'1H:7,M/G,W6R1Z.5TI.PH@("`@("`@
M("1T:&ES+3Y?2W);-%T@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'I%72!>("1T
M:&ES+3YS-ELD>D9=(%X@)'1H:7,M/G,W6R1Z,5T@7B`D=&AI<RT^<SA;)'HP
M72!>("1T:&ES+3YS.%LD>D-=*3L*"B`@("`@("`@)'@P>#%X,G@S(#T@)'HX
M>CEZ07I"(%X@)'1H:7,M/G,U6R1Z-5T@7B`D=&AI<RT^<S9;)'HW72!>("1T
M:&ES+3YS-ULD>C1=(%X@)'1H:7,M/G,X6R1Z-ET@7B`D=&AI<RT^<S=;)'HP
M73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P
M(#T@)&);,%T[("1X,2`]("1B6S%=.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);
M,UT["B`@("`@("`@)'@T>#5X-G@W(#T@)'HP>C%Z,GHS(%X@)'1H:7,M/G,U
M6R1X,%T@7B`D=&AI<RT^<S9;)'@R72!>("1T:&ES+3YS-ULD>#%=(%X@)'1H
M:7,M/G,X6R1X,UT@7B`D=&AI<RT^<SA;)'HR73L*("`@("`@("`D8B`]("1T
M:&ES+3Y?<W!L:70H)'@T>#5X-G@W*3L@)'@T(#T@)&);,%T[("1X-2`]("1B
M6S%=.R`D>#8@/2`D8ELR73L@)'@W(#T@)&);,UT["B`@("`@("`@)'@X>#EX
M07A"(#T@)'HT>C5Z-GHW(%X@)'1H:7,M/G,U6R1X-UT@7B`D=&AI<RT^<S9;
M)'@V72!>("1T:&ES+3YS-ULD>#5=(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI
M<RT^<S5;)'HQ73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX
M07A"*3L@)'@X(#T@)&);,%T[("1X.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@
M)'A"(#T@)&);,UT["B`@("`@("`@)'A#>$1X17A&(#T@)'I#>D1Z17I&(%X@
M)'1H:7,M/G,U6R1X05T@7B`D=&AI<RT^<S9;)'@Y72!>("1T:&ES+3YS-ULD
M>$)=(%X@)'1H:7,M/G,X6R1X.%T@7B`D=&AI<RT^<S9;)'HS73L*("`@("`@
M("`D8B`]("1T:&ES+3Y?<W!L:70H)'A#>$1X17A&*3L@)'A#(#T@)&);,%T[
M("1X1"`]("1B6S%=.R`D>$4@/2`D8ELR73L@)'A&(#T@)&);,UT["@H@("`@
M("`@("1T:&ES+3Y?2W);-5T@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'@S72!>
M("1T:&ES+3YS-ELD>#)=(%X@)'1H:7,M/G,W6R1X0UT@7B`D=&AI<RT^<SA;
M)'A$72!>("1T:&ES+3YS-5LD>#A=*3L*("`@("`@("`D=&AI<RT^7TMR6S9=
M("`](#!X,48@)B`H)'1H:7,M/G,U6R1X,5T@7B`D=&AI<RT^<S9;)'@P72!>
M("1T:&ES+3YS-ULD>$5=(%X@)'1H:7,M/G,X6R1X1ET@7B`D=&AI<RT^<S9;
M)'A$72D["B`@("`@("`@)'1H:7,M/E]+<ELW72`@/2`P>#%&("8@*"1T:&ES
M+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI<RT^<S=;)'@X72!>
M("1T:&ES+3YS.%LD>#E=(%X@)'1H:7,M/G,W6R1X,UTI.PH@("`@("`@("1T
M:&ES+3Y?2W);.%T@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'@U72!>("1T:&ES
M+3YS-ELD>#1=(%X@)'1H:7,M/G,W6R1X05T@7B`D=&AI<RT^<SA;)'A"72!>
M("1T:&ES+3YS.%LD>#==*3L*"B`@("`@("`@)'HP>C%Z,GHS(#T@)'@P>#%X
M,G@S(%X@)'1H:7,M/G,U6R1X1%T@7B`D=&AI<RT^<S9;)'A&72!>("1T:&ES
M+3YS-ULD>$-=(%X@)'1H:7,M/G,X6R1X15T@7B`D=&AI<RT^<S=;)'@X73L*
M("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HP>C%Z,GHS*3L@)'HP(#T@
M)&);,%T[("1Z,2`]("1B6S%=.R`D>C(@/2`D8ELR73L@)'HS(#T@)&);,UT[
M"B`@("`@("`@)'HT>C5Z-GHW(#T@)'@X>#EX07A"(%X@)'1H:7,M/G,U6R1Z
M,%T@7B`D=&AI<RT^<S9;)'HR72!>("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M
M/G,X6R1Z,UT@7B`D=&AI<RT^<SA;)'A!73L*("`@("`@("`D8B`]("1T:&ES
M+3Y?<W!L:70H)'HT>C5Z-GHW*3L@)'HT(#T@)&);,%T[("1Z-2`]("1B6S%=
M.R`D>C8@/2`D8ELR73L@)'HW(#T@)&);,UT["B`@("`@("`@)'HX>CEZ07I"
M(#T@)'A#>$1X17A&(%X@)'1H:7,M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV
M72!>("1T:&ES+3YS-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^
M<S5;)'@Y73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HX>CEZ07I"
M*3L@)'HX(#T@)&);,%T[("1Z.2`]("1B6S%=.R`D>D$@/2`D8ELR73L@)'I"
M(#T@)&);,UT["B`@("`@("`@)'I#>D1Z17I&(#T@)'@T>#5X-G@W(%X@)'1H
M:7,M/G,U6R1Z05T@7B`D=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS-ULD>D)=
M(%X@)'1H:7,M/G,X6R1Z.%T@7B`D=&AI<RT^<S9;)'A"73L*("`@("`@("`D
M8B`]("1T:&ES+3Y?<W!L:70H)'I#>D1Z17I&*3L@)'I#(#T@)&);,%T[("1Z
M1"`]("1B6S%=.R`D>D4@/2`D8ELR73L@)'I&(#T@)&);,UT["@H@("`@("`@
M("1T:&ES+3Y?2W);.5T@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'HS72!>("1T
M:&ES+3YS-ELD>C)=(%X@)'1H:7,M/G,W6R1Z0UT@7B`D=&AI<RT^<SA;)'I$
M72!>("1T:&ES+3YS-5LD>CE=*3L*("`@("`@("`D=&AI<RT^7TMR6S$P72`]
M(#!X,48@)B`H)'1H:7,M/G,U6R1Z,5T@7B`D=&AI<RT^<S9;)'HP72!>("1T
M:&ES+3YS-ULD>D5=(%X@)'1H:7,M/G,X6R1Z1ET@7B`D=&AI<RT^<S9;)'I#
M72D["B`@("`@("`@)'1H:7,M/E]+<ELQ,5T@/2`P>#%&("8@*"1T:&ES+3YS
M-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@7B`D=&AI<RT^<S=;)'HX72!>("1T
M:&ES+3YS.%LD>CE=(%X@)'1H:7,M/G,W6R1Z,ETI.PH@("`@("`@("1T:&ES
M+3Y?2W);,3)=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'HU72!>("1T:&ES+3YS
M-ELD>C1=(%X@)'1H:7,M/G,W6R1Z05T@7B`D=&AI<RT^<SA;)'I"72!>("1T
M:&ES+3YS.%LD>C9=*3L*"B`@("`@("`@)'@P>#%X,G@S(#T@)'HX>CEZ07I"
M(%X@)'1H:7,M/G,U6R1Z-5T@7B`D=&AI<RT^<S9;)'HW72!>("1T:&ES+3YS
M-ULD>C1=(%X@)'1H:7,M/G,X6R1Z-ET@7B`D=&AI<RT^<S=;)'HP73L*("`@
M("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@P>#%X,G@S*3L@)'@P(#T@)&);
M,%T[("1X,2`]("1B6S%=.R`D>#(@/2`D8ELR73L@)'@S(#T@)&);,UT["B`@
M("`@("`@)'@T>#5X-G@W(#T@)'HP>C%Z,GHS(%X@)'1H:7,M/G,U6R1X,%T@
M7B`D=&AI<RT^<S9;)'@R72!>("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X
M6R1X,UT@7B`D=&AI<RT^<SA;)'HR73L*("`@("`@("`D8B`]("1T:&ES+3Y?
M<W!L:70H)'@T>#5X-G@W*3L@)'@T(#T@)&);,%T[("1X-2`]("1B6S%=.R`D
M>#8@/2`D8ELR73L@)'@W(#T@)&);,UT["B`@("`@("`@)'@X>#EX07A"(#T@
M)'HT>C5Z-GHW(%X@)'1H:7,M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V72!>
M("1T:&ES+3YS-ULD>#5=(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^<S5;
M)'HQ73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"*3L@
M)'@X(#T@)&);,%T[("1X.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"(#T@
M)&);,UT["B`@("`@("`@)'A#>$1X17A&(#T@)'I#>D1Z17I&(%X@)'1H:7,M
M/G,U6R1X05T@7B`D=&AI<RT^<S9;)'@Y72!>("1T:&ES+3YS-ULD>$)=(%X@
M)'1H:7,M/G,X6R1X.%T@7B`D=&AI<RT^<S9;)'HS73L*("`@("`@("`D8B`]
M("1T:&ES+3Y?<W!L:70H)'A#>$1X17A&*3L@)'A#(#T@)&);,%T[("1X1"`]
M("1B6S%=.R`D>$4@/2`D8ELR73L@)'A&(#T@)&);,UT["@H@("`@("`@("1T
M:&ES+3Y?2W);,3-=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'@X72!>("1T:&ES
M+3YS-ELD>#E=(%X@)'1H:7,M/G,W6R1X-UT@7B`D=&AI<RT^<SA;)'@V72!>
M("1T:&ES+3YS-5LD>#-=*3L*("`@("`@("`D=&AI<RT^7TMR6S$T72`](#!X
M,48@)B`H)'1H:7,M/G,U6R1X05T@7B`D=&AI<RT^<S9;)'A"72!>("1T:&ES
M+3YS-ULD>#5=(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^<S9;)'@W72D[
M"B`@("`@("`@)'1H:7,M/E]+<ELQ-5T@/2`P>#%&("8@*"1T:&ES+3YS-5LD
M>$-=(%X@)'1H:7,M/G,V6R1X1%T@7B`D=&AI<RT^<S=;)'@S72!>("1T:&ES
M+3YS.%LD>#)=(%X@)'1H:7,M/G,W6R1X.%TI.PH@("`@("`@("1T:&ES+3Y?
M2W);,39=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'A%72!>("1T:&ES+3YS-ELD
M>$9=(%X@)'1H:7,M/G,W6R1X,5T@7B`D=&AI<RT^<SA;)'@P72!>("1T:&ES
M+3YS.%LD>$1=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5N<&%C:R!T:&4@
M,S(@8FET('9A;'5E(&EN=&\@86X@87)R87D@;V8@9F]U<B`X(&)I="!V86QU
M97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@(#,R(&)I="!V
M86QU92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!&;W5R(#@@8FET
M('9A;'5E<R!-4R!T;R!,4RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-P;&ET
M*"1X*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@H)'@@/CX@,C0I("8@
M,'A&1BP@*"1X(#X^(#$V*2`F(#!X1D8L("@D>"`^/B`X*2`F(#!X1D8L("1X
M("8@,'A&1BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!086-K(&9O=7(@."!B
M:70@=F%L=65S(&EN=&\@;VYE(#,R(&)I="!V86QU92X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&ME>2`@("`@($%R<F%Y(&]F(#@@8FET('9A;'5E
M<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R="`@4W1A<G0@<&]S:71I
M;VX@:6X@87)R87D@=&\@9V5T(#0@=F%L=65S(&9R;VTN"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("`S,B!B:70@=F%L=64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C;VUB:6YE-"@D:V5Y+"`D<W1A<G0@/2`P*0H@("`@>PH@
M("`@("`@("1R97,@(#T@,#L*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T
M<R@D<W1A<G0L("1K97DI*2!["B`@("`@("`@("`@("1R97,@?#T@*"1K97E;
M)'-T87)T72D@/#P@,C0["B`@("`@("`@?0H@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"1S=&%R="`K(#$L("1K97DI*2!["B`@("`@("`@("`@("1R
M97,@?#T@*"1K97E;)'-T87)T("L@,5TI(#P\(#$V.PH@("`@("`@('T*("`@
M("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D<W1A<G0@*R`R+"`D:V5Y*2D@
M>PH@("`@("`@("`@("`D<F5S('P]("@D:V5Y6R1S=&%R="`K(#)=*2`\/"`X
M.PH@("`@("`@('T*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D<W1A
M<G0@*R`S+"`D:V5Y*2D@>PH@("`@("`@("`@("`D<F5S('P]("@D:V5Y6R1S
M=&%R="`K(#-=*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]R8S(N<&AP````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S`W-P`Q,#4Q-30S,3`V
M,0`P,C`V-#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!#:7!H97)?<F,R.CH@8VQA<W,@:6UP
M;&5M96YT<R!T:&4@0VEP:&5R(&EN=&5R9F%C92!E;F-R>7!T:6]N(&1A=&$*
M("H@=7-I;F<@=&AE(%)#,B!A;&=O<FET:&T@87,@9&5S8W)I8F5D(&EN(%)&
M0S(R-C@N"B`J"B`J($)A<V5D(&]N('1H92!N;W1E<R!B>2!0971E<B!'=71M
M86YN(#QP9W5T,#%`8W,N875C:VQA;F0N86,N;GH^"B`J(&AT='`Z+R]W=W<N
M;6ER<F]R<RYW:7)E=&%P<&5D+FYE="]S96-U<FET>2]C<GEP=&]G<F%P:'DO
M"B`J("`@86QG;W)I=&AM<R]R8S(O8V]M;65N=',O9W5T;6%N+3DV,#(Q,0H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+W)C,BYP:'`L
M=B`Q+CDN,3(N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC
M;&%S<R!(;W)D95]#:7!H97)?<F,R(&5X=&5N9',@2&]R9&5?0VEP:&5R('L*
M"B`@("`O*BH*("`@("`J(%!E<FUU=&%T:6]N<R!A<G)A>0H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&5R;2`](&%R<F%Y
M*`H@("`@("`@(#!X1#DL(#!X-S@L(#!X1CDL(#!X0S0L(#!X,3DL(#!X1$0L
M(#!X0C4L(#!X140L"B`@("`@("`@,'@R."P@,'A%.2P@,'A&1"P@,'@W.2P@
M,'@T02P@,'A!,"P@,'A$."P@,'@Y1"P*("`@("`@("`P>$,V+"`P>#=%+"`P
M>#,W+"`P>#@S+"`P>#)"+"`P>#<V+"`P>#4S+"`P>#A%+`H@("`@("`@(#!X
M-C(L(#!X-$,L(#!X-C0L(#!X.#@L(#!X-#0L(#!X.$(L(#!X1D(L(#!X03(L
M"B`@("`@("`@,'@Q-RP@,'@Y02P@,'@U.2P@,'A&-2P@,'@X-RP@,'A",RP@
M,'@T1BP@,'@Q,RP*("`@("`@("`P>#8Q+"`P>#0U+"`P>#9$+"`P>#A$+"`P
M>#`Y+"`P>#@Q+"`P>#=$+"`P>#,R+`H@("`@("`@(#!X0D0L(#!X.$8L(#!X
M-#`L(#!X14(L(#!X.#8L(#!X0C<L(#!X-T(L(#!X,$(L"B`@("`@("`@,'A&
M,"P@,'@Y-2P@,'@R,2P@,'@R,BP@,'@U0RP@,'@V0BP@,'@T12P@,'@X,BP*
M("`@("`@("`P>#4T+"`P>$0V+"`P>#8U+"`P>#DS+"`P>$-%+"`P>#8P+"`P
M>$(R+"`P>#%#+`H@("`@("`@(#!X-S,L(#!X-38L(#!X0S`L(#!X,30L(#!X
M03<L(#!X.$,L(#!X1C$L(#!X1$,L"B`@("`@("`@,'@Q,BP@,'@W-2P@,'A#
M02P@,'@Q1BP@,'@S0BP@,'A"12P@,'A%-"P@,'A$,2P*("`@("`@("`P>#0R
M+"`P>#-$+"`P>$0T+"`P>#,P+"`P>$$S+"`P>#-#+"`P>$(V+"`P>#(V+`H@
M("`@("`@(#!X-D8L(#!X0D8L(#!X,$4L(#!X1$$L(#!X-#8L(#!X-CDL(#!X
M,#<L(#!X-3<L"B`@("`@("`@,'@R-RP@,'A&,BP@,'@Q1"P@,'@Y0BP@,'A"
M0RP@,'@Y-"P@,'@T,RP@,'@P,RP*("`@("`@("`P>$8X+"`P>#$Q+"`P>$,W
M+"`P>$8V+"`P>#DP+"`P>$5&+"`P>#-%+"`P>$4W+`H@("`@("`@(#!X,#8L
M(#!X0S,L(#!X1#4L(#!X,D8L(#!X0S@L(#!X-C8L(#!X,44L(#!X1#<L"B`@
M("`@("`@,'@P."P@,'A%."P@,'A%02P@,'A$12P@,'@X,"P@,'@U,BP@,'A%
M12P@,'A&-RP*("`@("`@("`P>#@T+"`P>$%!+"`P>#<R+"`P>$%#+"`P>#,U
M+"`P>#1$+"`P>#9!+"`P>#)!+`H@("`@("`@(#!X.38L(#!X,4$L(#!X1#(L
M(#!X-S$L(#!X-4$L(#!X,34L(#!X-#DL(#!X-S0L"B`@("`@("`@,'@T0BP@
M,'@Y1BP@,'A$,"P@,'@U12P@,'@P-"P@,'@Q."P@,'A!-"P@,'A%0RP*("`@
M("`@("`P>$,R+"`P>$4P+"`P>#0Q+"`P>#9%+"`P>#!&+"`P>#4Q+"`P>$-"
M+"`P>$-#+`H@("`@("`@(#!X,C0L(#!X.3$L(#!X048L(#!X-3`L(#!X03$L
M(#!X1C0L(#!X-S`L(#!X,SDL"B`@("`@("`@,'@Y.2P@,'@W0RP@,'@S02P@
M,'@X-2P@,'@R,RP@,'A"."P@,'A"-"P@,'@W02P*("`@("`@("`P>$9#+"`P
M>#`R+"`P>#,V+"`P>#5"+"`P>#(U+"`P>#4U+"`P>#DW+"`P>#,Q+`H@("`@
M("`@(#!X,D0L(#!X-40L(#!X1D$L(#!X.3@L(#!X13,L(#!X.$$L(#!X.3(L
M(#!X044L"B`@("`@("`@,'@P-2P@,'A$1BP@,'@R.2P@,'@Q,"P@,'@V-RP@
M,'@V0RP@,'A"02P@,'A#.2P*("`@("`@("`P>$0S+"`P>#`P+"`P>$4V+"`P
M>$-&+"`P>$4Q+"`P>#E%+"`P>$$X+"`P>#)#+`H@("`@("`@(#!X-C,L(#!X
M,38L(#!X,#$L(#!X,T8L(#!X-3@L(#!X13(L(#!X.#DL(#!X03DL"B`@("`@
M("`@,'@P1"P@,'@S."P@,'@S-"P@,'@Q0BP@,'A!0BP@,'@S,RP@,'A&1BP@
M,'A","P*("`@("`@("`P>$)"+"`P>#0X+"`P>#!#+"`P>#5&+"`P>$(Y+"`P
M>$(Q+"`P>$-$+"`P>#)%+`H@("`@("`@(#!X0S4L(#!X1C,L(#!X1$(L(#!X
M-#<L(#!X134L(#!X034L(#!X.4,L(#!X-S<L"B`@("`@("`@,'@P02P@,'A!
M-BP@,'@R,"P@,'@V."P@,'A&12P@,'@W1BP@,'A#,2P@,'A!1`H@("`@*3L*
M"B`@("`O*BH*("`@("`J($%R<F%Y('1O(&AO;&0@=&AE(&ME>2!S8VAE9'5L
M90H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M:V5Y4V-H961U;&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4V5T('1H
M92!K97D@=&\@8F4@=7-E9"!F;W(@96XO9&5C<GEP=&EO;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971+97DH)&ME>2D*("`@('L*("`@("`@("`D
M:V5Y(#T@87)R87E?=F%L=65S*'5N<&%C:R@G0RHG+"`D:V5Y*2D["B`@("`@
M("`@)&)I=',@/2`Q,#(T.PH*("`@("`@("`O*B!%>'!A;F0@:6YP=70@:V5Y
M('1O(#$R."!B>71E<R`J+PH@("`@("`@("1L96X@/2!C;W5N="@D:V5Y*3L*
M("`@("`@("`D;&%S="`]("1K97E;)&QE;B`M(#%=.PH@("`@("`@(&9O<B`H
M)&D@/2`D;&5N.R`D:2`\(#$R.#L@)&DK*RD@>PH@("`@("`@("`@("`D;&%S
M="`]("1T:&ES+3Y?<&5R;5LH)&ME>5LD:2`M("1L96Y=("L@)&QA<W0I("8@
M,'A&1ET["B`@("`@("`@("`@("1K97E;)&E=(#T@)&QA<W0["B`@("`@("`@
M?0H*("`@("`@("`O*B!0:&%S92`R("T@<F5D=6-E(&5F9F5C=&EV92!K97D@
M<VEZ92!T;R`B8FET<R(@*B\*("`@("`@("!I9B`H)&QE;B`A/2`X*2!["B`@
M("`@("`@("`@("1L96X@/2`D;&5N("H@.#L*("`@("`@("!]"B`@("`@("`@
M)&ME>5LQ,C@@+2`D;&5N72`]("1T:&ES+3Y?<&5R;5LD:V5Y6S$R."`M("1L
M96Y=("8@,'A&1ET["B`@("`@("`@9F]R("@D:2`](#$R-R`M("1L96X[("1I
M(#X](#`[("1I+2TI('L*("`@("`@("`@("`@)&ME>5LD:5T@/2`D=&AI<RT^
M7W!E<FU;)&ME>5LD:2`K("1L96Y=(%X@)&ME>5LD:2`K(#%=73L*("`@("`@
M("!]"@H@("`@("`@("\J(%!H87-E(#,@+2!C;VYV97)T('1O(#$V(&)I="!V
M86QU97,@*B\*("`@("`@("!F;W(@*"1I(#T@-C,[("1I(#X](#`[("1I+2TI
M('L*("`@("`@("`@("`@)'1H:7,M/E]K97E38VAE9'5L95LD:5T@/2`H)&ME
M>5LD:2`J(#(@*R`Q72`\/"`X('P@)&ME>5LD:2`J(#)=*2`F(#!X1D9&1CL*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I
M>F4@;V8@=&AE(&)L;V-K<R!T:&%T('1H:7,@8VEP:&5R(&YE961S+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!C:&%R
M86-T97)S('!E<B!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO
M8VM3:7IE*"D*("`@('L*("`@("`@("!R971U<FX@.#L*("`@('T*"B`@("`O
M*BH*("`@("`J($5N8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!E;F-R>7!T
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D
M(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP=$)L;V-K*"1B
M;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@
M("`@("`@?0H*("`@("`@("`D<&QA:6X@/2!U;G!A8VLH)W8J)RP@)&)L;V-K
M*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@,38[("1I*RLI('L*("`@
M("`@("`@("`@)'!L86EN6S%=("L]("@D<&QA:6Y;,ET@)B!^)'!L86EN6S1=
M*2`K("@D<&QA:6Y;,UT@)B`D<&QA:6Y;-%TI("L@)'1H:7,M/E]K97E38VAE
M9'5L95LT("H@)&D@*R`P73L*("`@("`@("`@("`@)&)I;B`]('-T<E]P860H
M9&5C8FEN*#!X1D9&1B`F("1P;&%I;ELQ72DL(#,R+"`G,"<L(%-44E]0041?
M3$5&5"D["B`@("`@("`@("`@("1P;&%I;ELQ72`](&)I;F1E8R@D8FEN("X@
M<W5B<W1R*"1B:6XL(#$V+"`Q*2D["@H@("`@("`@("`@("`D<&QA:6Y;,ET@
M*ST@*"1P;&%I;ELS72`F('XD<&QA:6Y;,5TI("L@*"1P;&%I;ELT72`F("1P
M;&%I;ELQ72D@*R`D=&AI<RT^7VME>5-C:&5D=6QE6S0@*B`D:2`K(#%=.PH@
M("`@("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)'!L
M86EN6S)=*2P@,S(L("<P)RP@4U127U!!1%],1494*3L*("`@("`@("`@("`@
M)'!L86EN6S)=(#T@8FEN9&5C*"1B:6X@+B!S=6)S='(H)&)I;BP@,38L(#(I
M*3L*"B`@("`@("`@("`@("1P;&%I;ELS72`K/2`H)'!L86EN6S1=("8@?B1P
M;&%I;ELR72D@*R`H)'!L86EN6S%=("8@)'!L86EN6S)=*2`K("1T:&ES+3Y?
M:V5Y4V-H961U;&5;-"`J("1I("L@,ET["B`@("`@("`@("`@("1B:6X@/2!S
M=')?<&%D*&1E8V)I;B@P>$9&1D8@)B`D<&QA:6Y;,UTI+"`Q-BP@)S`G+"!3
M5%)?4$%$7TQ%1E0I.PH@("`@("`@("`@("`D<&QA:6Y;,UT@/2!B:6YD96,H
M)&)I;B`N('-U8G-T<B@D8FEN+"`P+"`S*2D["@H@("`@("`@("`@("`D<&QA
M:6Y;-%T@*ST@*"1P;&%I;ELQ72`F('XD<&QA:6Y;,UTI("L@*"1P;&%I;ELR
M72`F("1P;&%I;ELS72D@*R`D=&AI<RT^7VME>5-C:&5D=6QE6S0@*B`D:2`K
M(#-=.PH@("`@("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH,'A&1D9&
M("8@)'!L86EN6S1=*2P@,38L("<P)RP@4U127U!!1%],1494*3L*("`@("`@
M("`@("`@)'!L86EN6S1=(#T@8FEN9&5C*"1B:6X@+B!S=6)S='(H)&)I;BP@
M,"P@-2DI.PH*("`@("`@("`@("`@:68@*"1I(#T](#0@?'P@)&D@/3T@,3`I
M('L*("`@("`@("`@("`@("`@("1P;&%I;ELQ72`K/2`D=&AI<RT^7VME>5-C
M:&5D=6QE6R1P;&%I;ELT72`F(#!X,T9=.PH@("`@("`@("`@("`@("`@)'!L
M86EN6S)=("L]("1T:&ES+3Y?:V5Y4V-H961U;&5;)'!L86EN6S%=("8@,'@S
M1ET["B`@("`@("`@("`@("`@("`D<&QA:6Y;,UT@*ST@)'1H:7,M/E]K97E3
M8VAE9'5L95LD<&QA:6Y;,ET@)B`P>#-&73L*("`@("`@("`@("`@("`@("1P
M;&%I;ELT72`K/2`D=&AI<RT^7VME>5-C:&5D=6QE6R1P;&%I;ELS72`F(#!X
M,T9=.PH@("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@)&5N8W)Y
M<'1E9"`]('!A8VLH(G8J(BP@)'!L86EN6S%=+"`D<&QA:6Y;,ETL("1P;&%I
M;ELS72P@)'!L86EN6S1=*3L*("`@("`@("!R971U<FX@)&5N8W)Y<'1E9#L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'0@82!B;&]C:R!O9B!D871A
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T
M82!T;R!D96-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H
M92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@9&5C<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C
M<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+
M97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D8VEP:&5R(#T@=6YP86-K
M*"=V*B<L("1B;&]C:RD["@H@("`@("`@(&9O<B`H)&D@/2`Q-3L@)&D@/CT@
M,#L@)&DM+2D@>PH@("`@("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH
M,'A&1D9&("8@)&-I<&AE<ELT72DL(#$V+"`G,"<L(%-44E]0041?3$5&5"D[
M"B`@("`@("`@("`@("1C:7!H97);-%T@/2!B:6YD96,H<W5B<W1R*"1B:6XL
M("TR,2P@,C$I("X@<W5B<W1R*"1B:6XL(#`L(#$Q*2D["B`@("`@("`@("`@
M("1C:7!H97);-%T@+3T@*"1C:7!H97);,5T@)B!^)&-I<&AE<ELS72D@*R`H
M)&-I<&AE<ELR72`F("1C:7!H97);,UTI("L@)'1H:7,M/E]K97E38VAE9'5L
M95LT("H@)&D@*R`S73L*"B`@("`@("`@("`@("1B:6X@/2!S=')?<&%D*&1E
M8V)I;B@P>$9&1D8@)B`D8VEP:&5R6S-=*2P@,38L("<P)RP@4U127U!!1%],
M1494*3L*("`@("`@("`@("`@)&-I<&AE<ELS72`](&)I;F1E8RAS=6)S='(H
M)&)I;BP@+3$Y+"`Q.2D@+B!S=6)S='(H)&)I;BP@,"P@,3,I*3L*("`@("`@
M("`@("`@)&-I<&AE<ELS72`M/2`H)&-I<&AE<ELT72`F('XD8VEP:&5R6S)=
M*2`K("@D8VEP:&5R6S%=("8@)&-I<&AE<ELR72D@*R`D=&AI<RT^7VME>5-C
M:&5D=6QE6S0@*B`D:2`K(#)=.PH*("`@("`@("`@("`@)&)I;B`]('-T<E]P
M860H9&5C8FEN*#!X1D9&1B`F("1C:7!H97);,ETI+"`Q-BP@)S`G+"!35%)?
M4$%$7TQ%1E0I.PH@("`@("`@("`@("`D8VEP:&5R6S)=(#T@8FEN9&5C*'-U
M8G-T<B@D8FEN+"`M,3@L(#$X*2`N('-U8G-T<B@D8FEN+"`P+"`Q-"DI.PH@
M("`@("`@("`@("`D8VEP:&5R6S)=("T]("@D8VEP:&5R6S-=("8@?B1C:7!H
M97);,5TI("L@*"1C:7!H97);-%T@)B`D8VEP:&5R6S%=*2`K("1T:&ES+3Y?
M:V5Y4V-H961U;&5;-"`J("1I("L@,5T["@H@("`@("`@("`@("`D8FEN(#T@
M<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)&-I<&AE<ELQ72DL(#$V+"`G,"<L
M(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1C:7!H97);,5T@/2!B:6YD
M96,H<W5B<W1R*"1B:6XL("TQ-RP@,3<I("X@<W5B<W1R*"1B:6XL(#`L(#$U
M*2D["B`@("`@("`@("`@("1C:7!H97);,5T@+3T@*"1C:7!H97);,ET@)B!^
M)&-I<&AE<ELT72D@*R`H)&-I<&AE<ELS72`F("1C:7!H97);-%TI("L@)'1H
M:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`P73L*"B`@("`@("`@("`@(&EF
M("@D:2`]/2`U('Q\("1I(#T](#$Q*2!["B`@("`@("`@("`@("`@("`D8VEP
M:&5R6S1=("T]("1T:&ES+3Y?:V5Y4V-H961U;&5;)&-I<&AE<ELS72`F(#!X
M,T9=.PH@("`@("`@("`@("`@("`@)&-I<&AE<ELS72`M/2`D=&AI<RT^7VME
M>5-C:&5D=6QE6R1C:7!H97);,ET@)B`P>#-&73L*("`@("`@("`@("`@("`@
M("1C:7!H97);,ET@+3T@)'1H:7,M/E]K97E38VAE9'5L95LD8VEP:&5R6S%=
M("8@,'@S1ET["B`@("`@("`@("`@("`@("`D8VEP:&5R6S%=("T]("1T:&ES
M+3Y?:V5Y4V-H961U;&5;)&-I<&AE<ELT72`F(#!X,T9=.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@<&%C:R@B=BHB+"`D8VEP
M:&5R6S%=+"`D8VEP:&5R6S)=+"`D8VEP:&5R6S-=+"`D8VEP:&5R6S1=*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#
M:7!H97(O<F,T+G!H<```````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#0T-#``,3`U,34T,S$P-C$`,#(P-C,Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@0VEP
M:&5R7W)C-#HZ(&-L87-S(&EM<&QE;65N=',@=&AE($-I<&AE<B!I;G1E<F9A
M8V4@96YC<GEP=&EO;B!D871A"B`J('5S:6YG('1H92!20S0@96YC<GEP=&EO
M;B!A;&=O<G1H:6TN(%1H:7,@8VQA<W,@=7-E<R!T:&4@4$5!4B!#<GEP=%]2
M0S0*("H@8VQA<W,@=&\@9&\@=&AE(&5N8W)Y<'1I;VXN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O<F,T+G!H<"QV(#$N-"XQ,BXW
M(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E
M(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E
M7T-I<&AE<E]R8S0@97AT96YD<R!(;W)D95]#:7!H97(@>PH*("`@("\J*@H@
M("`@("H@4&]I;G1E<B!T;R!A(%!%05(@0W)Y<'1?<F,T(&]B:F5C=`H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8VEP:&5R
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@
M*B\*("`@(&9U;F-T:6]N($AO<F1E7T-I<&AE<E]R8S0H)'!A<F%M<R`](&YU
M;&PI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=#<GEP="]28S0N<&AP
M)SL*("`@("`@("`D=&AI<RT^7V-I<&AE<B`]("9N97<@0W)Y<'1?4F,T*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&ME>2!T;R!B92!U<V5D
M(&9O<B!E;B]D96-R>7!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$ME>2@D:V5Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VEP:&5R+3YK
M97DH)&ME>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I
M>F4@;V8@=&AE(&)L;V-K<R!T:&%T('1H:7,@8VEP:&5R(&YE961S+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!C:&%R
M86-T97)S('!E<B!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO
M8VM3:7IE*"D*("`@('L*("`@("`@("!R971U<FX@.#L*("`@('T*"B`@("`O
M*BH*("`@("`J($5N8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!E;F-R>7!T
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D
M(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP=$)L;V-K*"1B
M;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@
M("`@("`@?0H*("`@("`@("`O+R!-86ME(&$@8V]P>2!O9B!T:&4@8VEP:&5R
M(&%S(&ET(&1E<W1R;WES(&ET<V5L9B!D=7)I;F<@82!C<GEP=`H@("`@("`@
M("1C:7!H97(@/2`D=&AI<RT^7V-I<&AE<CL*("`@("`@("`D8VEP:&5R+3YC
M<GEP="@D8FQO8VLI.PH*("`@("`@("!R971U<FX@)&)L;V-K.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5C<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O(&1E
M8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME>2!T
M;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R
M>7!T960@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T0FQO
M8VLH)&)L;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$ME>2@D:V5Y
M*3L*("`@("`@("!]"@H@("`@("`@("\O($UA:V4@82!C;W!Y(&]F('1H92!C
M:7!H97(@87,@:70@9&5S=')O>7,@:71S96QF(&1U<FEN9R!A"B`@("`@("`@
M+R\@8W)Y<'0N"B`@("`@("`@)&-I<&AE<B`]("1T:&ES+3Y?8VEP:&5R.PH@
M("`@("`@("1C:7!H97(M/F1E8W)Y<'0H)&)L;V-K*3L*"B`@("`@("`@<F5T
M=7)N("1B;&]C:SL*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]24$,O````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#$V-C0S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]R97-T+G!H<```````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S0Q,P`Q,#4Q-30S
M,3`V,0`P,C`S,S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]24$-?<F5S="!C;&%S
M<R!P<F]V:61E<R!A(%)%4U0@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E
M(%)00PH@*B!S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U)00R]2
M4$,O<F5S="YP:'`L=B`Q+C8N,BXR(#(P,#8O,#4O,#0@,3(Z,C0Z,30@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="!2869A96P@5F%R96QA(%!E="`\<F%F
M865L+G9A<F5L82YP971`=7-C+F5S/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@4F%F865L(%9A<F5L82`\<F%F865L+G9A<F5L82YP971`=7-C+F5S
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A8VMA9V4@2&]R9&5?4E!#
M"B`J+PIC;&%S<R!(;W)D95]24$-?<F5S="!E>'1E;F1S($AO<F1E7U)00R![
M"@H@("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]C;VYT96YT5'EP92`]("=T97AT+VAT;6PG.PH*("`@("\J*@H@("`@("H@
M0VAE8VL@875T:&5N=&EC871I;VXN($1I9F9E<F5N="!B86-K96YD<R!M87D@
M:&%N9&QE"B`@("`@*B!A=71H96YT:6-A=&EO;B!I;B!D:69F97)E;G0@=V%Y
M<RX@5&AE(&)A<V4@8VQA<W,@:6UP;&5M96YT871I;VX*("`@("`J(&-H96-K
M<R!F;W(@2%144"!!=71H96YT:6-A=&EO;B!A9V%I;G-T('1H92!(;W)D92!A
M=71H('-E='5P+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T
M=7)N<R!T<G5E(&EF(&%U=&AE;G1I8V%T:6]N(&ES('-U8V-E<W-F=6PN"B`@
M("`@*B`@("`@("`@("`@("`@("`@(%-H;W5L9"!S96YD(&%P<')O<')I871E
M(")N;W0@875T:&]R:7IE9"(@:&5A9&5R<PH@("`@("H@("`@("`@("`@("`@
M("`@("!O<B!O=&AE<B!R97-P;VYS92!C;V1E<R]B;V1Y(&EF(&%U=&@@9F%I
M;',L"B`@("`@*B`@("`@("`@("`@("`@("`@(&%N9"!T86ME(&-A<F4@;V8@
M97AI=&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T:&]R:7IE*"D*("`@
M('L*("`@("`@("!I9B`H(21T:&ES+3Y?875T:&]R:7IE*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@:68@*$%U=&@Z
M.F=E=$%U=&@H*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!P87)E;G0Z.F%U=&AO<FEZ92@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T+B!A;&P@=&AE($=%5"!I;G!U="!D871A
M+B!4:&4@)V-A;&PG('!A<F%M(&ES(&5X=')A8W1E9"!F<F]M('1H90H@("`@
M("H@87)R87D@86YD('1R96%T960@<V5P87)A=&5L>2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("`H;65T:&]D(&YA;64L(&%R<F%Y(&]F('!A<F%M
M971E<G,I"B`@("`@*@H@("`@("H@5$]$3SH@9&5S97)I86QI>FEN9R!O9B!C
M;VUP;&5X(&1A=&$@='EP97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN
M<'5T*"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O;G1E;G14>7!E(#T@571I
M;#HZ9V5T1V5T*"=R97-T0V]N=&5N=%1Y<&4G+"`G=&5X="]H=&UL)RD["@H@
M("`@"21G971$871A(#T@571I;#HZ9&ES<&5L36%G:6-1=6]T97,H)%]'150I
M.PH@("`@"75N<V5T*"1G971$871A6R=R97-T0V%L;"==*3L*("`@(`EU;G-E
M="@D9V5T1&%T85LG<F5S=$-O;G1E;G14>7!E)UTI.PH*("`@(`ER971U<FX@
M87)R87DH)VUE=&AO9"<@/3X@571I;#HZ9V5T1V5T*"=R97-T0V%L;"<I+`H@
M("`@"2`@("`@("`@("`@("`G<&%R86US)R`]/B`D9V5T1&%T82D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!396YD<R!A;B!24$,@<F5Q=65S="!T;R!T:&4@
M<V5R=F5R(&%N9"!R971U<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@5&AE(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5S<&]N<V4@9G)O;2!T:&4@
M<V5R=F5R(&]R(&%N(%!%05(@97)R;W(@;V)J96-T(&]N"B`@("`@*B`@("`@
M("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9712
M97-P;VYS92@D<F5Q=65S="D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y.PH*("`@("`@("`D;65T:&]D(#T@<W1R7W)E<&QA8V4H)RXG+"`G+R<L
M("1R97%U97-T6R=M971H;V0G72D["@H@("`@("`@(&EF("@A)')E9VES=')Y
M+3YH87--971H;V0H)&UE=&AO9"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")-971H;V0@;F]T(&1E9FEN960N
M($-A;&QE9"!M971H;V0Z("5S(BDL("1M971H;V0I*3L*("`@("`@("!]"@H@
M("`@("`@("\J($QO;VL@870@=&AE(&UE=&AO9"!S:6=N871U<F4@<V\@=&AA
M="!P87)A;65T97)S(&%R92!A<W-I9VYE9"!B>0H@("`@("`@("`J(&YA;64L
M(&EN<W1E860@;V8@<F5L>6EN9R!O;B!T:&4@;W)D97(@;V8@1T54('!A<F%M
M971E<G,@=&\@;6%T8V@*("`@("`@("`@*B!T:&4@;W)D97(@9&5F:6YE9"!I
M;B!T:&4@05!)(&UE=&AO9"X@*B\*("`@("`@("`D<VEG;F%T=7)E(#T@)')E
M9VES=')Y+3YG9713:6=N871U<F4H)&UE=&AO9"D["B`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<VEG
M;F%T=7)E6S!=*2!A<R`D<&%R86TI('L*("`@("`@("`@("`@)'!A<F%M<ULD
M<&%R86U=(#T@:7-S970H)')E<75E<W1;)W!A<F%M<R==6R1P87)A;5TI(#\@
M)')E<75E<W1;)W!A<F%M<R==6R1P87)A;5T@.B!N=6QL.PH@("`@("`@('T*
M"B`@("`@("`@)')E<W5L="`]("1R96=I<W1R>2T^8V%L;"@D;65T:&]D+"`D
M<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@5&AE(')E<W5L="!I<R!R971U<FYE9"!D97!E;F1I;F<@
M;VX@=&AE(')E<75E<W1E9"!C;VYT96YT('1Y<&4N("HO"B`@("`@("`@:68@
M*"1T:&ES+3Y?8V]N=&5N=%1Y<&4@/3T@)W1E>'0O:'1M;"<I('L*("`@("`@
M("`@("`@<F5T=7)N("<\:'1M;#X\8F]D>3XG("X@<')I;G1?<B@D<F5S=6QT
M+"!T<G5E*2`N("<\+V)O9'D^/"]H=&UL/B<["B`@("`@("`@?2!E;'-E:68@
M*"1T:&ES+3Y?8V]N=&5N=%1Y<&4@/3T@)W1E>'0O<&QA:6XG*2!["B`@("`@
M("`@("`@(')E='5R;B!P<FEN=%]R*"1R97-U;'0L('1R=64I.PH@("`@("`@
M('T@96QS96EF("@D=&AI<RT^7V-O;G1E;G14>7!E(#T]("=A<'!L:6-A=&EO
M;B]X+6AT='!D+7!H<"<I('L*("`@("`@("`@("`@<F5T=7)N('-E<FEA;&EZ
M92@D<F5S=6QT*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE($-O;G1E;G0M5'EP92!O9B!T:&4@<F5S<&]N<V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%($-O;G1E;G0M5'EP92!O
M9B!T:&4@4E!#(')E<W!O;G-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9712
M97-P;VYS94-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!S=VET8V@@*"1T
M:&ES+3Y?8V]N=&5N=%1Y<&4I('L*("`@("`@("!C87-E("=A<'!L:6-A=&EO
M;B]X+6AT='!D+7!H<"<Z"B`@("`@("`@("`@(')E='5R;B`G=&5X="]P;&%I
M;B<["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V]N=&5N=%1Y<&4["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,S$Q-@`Q,#4Q-30S,3`V,0`P,C`V-C``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(
M;W)D95]24$-?>&UL<G!C(&-L87-S('!R;W9I9&5S(&%N(%A-3%)00R!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4*("H@2&]R9&4@4E!#('-Y<W1E;2X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP+'8@,2XY+C$P
M+C@@,C`P-B\P-R\P,2`P-#HU-#HQ-B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?4E!#"B`J+PIC;&%S<R!(;W)D95]24$-?>&UL<G!C(&5X=&5N
M9',@2&]R9&5?4E!#('L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E(&AA;F1L
M97(@9F]R('1H92!834Q24$,@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@
M<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?<V5R=F5R.PH*("`@("\J*@H@
M("`@("H@6$U,4E!#('-E<G9E<B!C;VYS=')U8W1O<@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]2
M4$-?>&UL<G!C*"D*("`@('L*("`@("`@("!P87)E;G0Z.DAO<F1E7U)00R@I
M.PH*("`@("`@("`D=&AI<RT^7W-E<G9E<B`]('AM;')P8U]S97)V97)?8W)E
M871E*"D["@H@("`@("`@(&9O<F5A8V@@*"1'3$]"04Q36R=R96=I<W1R>2==
M+3YL:7-T365T:&]D<R@I(&%S("1M971H;V0I('L*("`@("`@("`@("`@>&UL
M<G!C7W-E<G9E<E]R96=I<W1E<E]M971H;V0H)'1H:7,M/E]S97)V97(L('-T
M<E]R97!L86-E*"<O)RP@)RXG+"`D;65T:&]D*2P@87)R87DH)TAO<F1E7U)0
M0U]X;6QR<&,G+"`G7V1I<W!A=&-H97(G*2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0VQE86YS('5P('1H92!24$,@<V5R=F5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S:'5T9&]W;B@I"B`@("!["B`@("`@("`@>&UL
M<G!C7W-E<G9E<E]D97-T<F]Y*"1T:&ES+3Y?<V5R=F5R*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E;F1S(&%N(%)00R!R97%U97-T('1O('1H92!S97)V
M97(@86YD(')E='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("!4:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@
M9G)O;2!T:&4@<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P
M;VYS92@D<F5Q=65S="D*("`@('L*("`@("`@("`D<F5S<&]N<V4@/2!N=6QL
M.PH@("`@("`@(')E='5R;B!X;6QR<&-?<V5R=F5R7V-A;&Q?;65T:&]D*"1T
M:&ES+3Y?<V5R=F5R+"`D<F5Q=65S="P@)')E<W!O;G-E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%=I;&P@8F4@<F5G:7-T97)E9"!A<R!T:&4@:&%N9&QE
M<B!F;W(@86QL(&%V86EL86)L92!M971H;V1S"B`@("`@*B!A;F0@=VEL;"!C
M86QL('1H92!A<'!R;W!R:6%T92!F=6YC=&EO;B!T:')O=6=H('1H92!R96=I
M<W1R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@(%1H92!N86UE(&]F('1H92!M
M971H;V0@8V%L;&5D(&)Y('1H92!24$,@<F5Q=65S="X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@5&AE('!A<W-E9"!P87)A;65T97)S+@H@("`@
M("H@0'!A<F%M(&UI>&5D("1D871A("`@("!5;FMN;W=N+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!R97-U;'0@;V8@=&AE(&-A;&QE9"!R
M96=I<W1R>2!M971H;V0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7-P871C
M:&5R*"1M971H;V0L("1P87)A;7,L("1D871A*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1M971H;V0@/2!S=')?<F5P;&%C
M92@G+B<L("<O)RP@)&UE=&AO9"D["B`@("`@("`@:68@*"$D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@D;65T:&]D*2D@>PH@("`@("`@("`@("!R971U<FX@<W!R
M:6YT9BA?*")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(BDL("1M971H
M;V0I.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1R96=I<W1R>2T^
M8V%L;"@D;65T:&]D+"`D<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2!A
M<G)A>2@G9F%U;'1#;V1E)R`]/B`H:6YT*21R97-U;'0M/F=E=$-O9&4H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F875L=%-T<FEN9R<@/3X@
M)')E<W5L="T^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&%N
M(%A-3%)00R!R97%U97-T(&%N9"!S96YD<R!I="!T;R!T:&4@6$U,4E!#('-E
M<G9E<BX*("`@("`J"B`@("`@*B!4:&ES('-T871I8V%L;'D@8V%L;&5D(&UE
M=&AO9"!I<R!A8W1U86QL>2!T:&4@6$U,4E!#(&-L:65N="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@(%1H92!P871H('1O('1H92!8
M34Q24$,@<V5R=F5R(&]N('1H92!C86QL960@:&]S="X*("`@("`J($!P87)A
M;2!S=')I;F<@)&UE=&AO9"`@5&AE(&UE=&AO9"!T;R!C86QL+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@
M;F5C97-S87)Y('!A<F%M971E<G,@9F]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!M971H;V0@8V%L;"X*("`@("`J($!P87)A;2`D;W!T
M:6]N<R`@3W!T:6]N86P@87-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R
M<R!W:&EC:"!C86X@8F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@('5S97(@
M("`@("`@("`@("T@0F%S:6,@075T:"!U<V5R;F%M90H@("`@("H@("`@("`@
M("`@("`@("`@("!P87-S("`@("`@("`@("`M($)A<VEC($%U=&@@<&%S<W=O
M<F0*("`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?:&]S="`@("`@+2!0
M<F]X>2!S97)V97(@:&]S=`H@("`@("H@("`@("`@("`@("`@("`@("!P<F]X
M>5]P;W)T("`@("`M(%!R;WAY('-E<G9E<B!P;W)T"B`@("`@*B`@("`@("`@
M("`@("`@("`@('!R;WAY7W5S97(@("`@("T@4')O>'D@875T:"!U<V5R;F%M
M90H@("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]P87-S("`@("`M(%!R
M;WAY(&%U=&@@<&%S<W=O<F0*("`@("`J("`@("`@("`@("`@("`@("`@=&EM
M96]U="`@("`@("`@+2!#;VYN96-T:6]N('1I;65O=70@:6X@<V5C;VYD<RX*
M("`@("`J("`@("`@("`@("`@("`@("`@86QL;W=2961I<F5C=',@+2!7:&5T
M:&5R('1O(&9O;&QO=R!R961I<F5C=',@;W(@;F]T"B`@("`@*B`@("`@("`@
M("`@("`@("`@(&UA>%)E9&ER96-T<R`@("T@36%X(&YU;6)E<B!O9B!R961I
M<F5C=',@=&\@9F]L;&]W"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M("`@("`@("`@(%1H92!R971U<FYE9"!R97-U;'0@9G)O;2!T:&4@;65T:&]D
M(&]R(&$@4$5!4@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M97%U97-T*"1U<FPL("1M971H;V0L("1P87)A;7,@/2!N=6QL+"`D;W!T:6]N
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&]P=&EO;G-;)VUE=&AO9"==
M(#T@)U!/4U0G.PH@("`@("`@("1L86YG=6%G92`](&ES<V5T*"1'3$]"04Q3
M6R=L86YG=6%G92==*2`_("1'3$]"04Q36R=L86YG=6%G92==(#H*("`@("`@
M("`@("`@("`@("`@("`H:7-S970H)%]315)615);)TQ!3D<G72D@/R`D7U-%
M4E9%4ELG3$%.1R==(#H@)R<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1O<'1I;VYS6R=T:6UE
M;W5T)UT@/2`U.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=A;&QO=U)E9&ER96-T<R==*2D@>PH@("`@("`@("`@("`D;W!T:6]N
M<ULG86QL;W=2961I<F5C=',G72`]('1R=64["B`@("`@("`@("`@("1O<'1I
M;VYS6R=M87A2961I<F5C=',G72`](#,["B`@("`@("`@?0H*("`@("`@("!R
M97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S="YP:'`G.PH*("`@("`@("`D:'1T
M<"`]("9N97<@2%144%]297%U97-T*"1U<FPL("1O<'1I;VYS*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1L86YG=6%G92DI('L*("`@("`@("`@("`@)&AT='`M
M/F%D9$AE861E<B@G06-C97!T+4QA;F=U86=E)RP@)&QA;F=U86=E*3L*("`@
M("`@("!]"B`@("`@("`@)&AT='`M/F%D9$AE861E<B@G57-E<BU!9V5N="<L
M("=(;W)D92!24$,@8VQI96YT)RD["B`@("`@("`@)&AT='`M/F%D9$AE861E
M<B@G0V]N=&5N="U4>7!E)RP@)W1E>'0O>&UL)RD["B`@("`@("`@)&AT='`M
M/F%D9%)A=U!O<W1$871A*'AM;')P8U]E;F-O9&5?<F5Q=65S="@D;65T:&]D
M+"`D<&%R86US*2D["@H@("`@("`@("1R97-U;'0@/2`D:'1T<"T^<V5N9%)E
M<75E<W0H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T@
M96QS96EF("@D:'1T<"T^9V5T4F5S<&]N<V5#;V1E*"D@(3T@,C`P*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(BD@
M+B`D:'1T<"T^9V5T4F5S<&]N<V5#;V1E*"DL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@('T@96QS96EF("AS=')P;W,H)&AT='`M/F=E=%)E<W!O;G-E0F]D
M>2@I+"`G/#]X;6PG*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N
M960B*2P@)VAO<F1E+F5R<F]R)RP@;G5L;"P@;G5L;"P@)&AT='`M/F=E=%)E
M<W!O;G-E0F]D>2@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<F5S<&]N<V4@/2!`>&UL<G!C7V1E8V]D92AS=6)S='(H)&AT='`M/F=E=%)E
M<W!O;G-E0F]D>2@I+"!S=')P;W,H)&AT='`M/F=E=%)E<W!O;G-E0F]D>2@I
M+"`G/#]X;6PG*2DI.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E<W!O
M;G-E*2`F)B!I<W-E="@D<F5S<&]N<V5;)V9A=6QT4W1R:6YG)UTI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<F5S<&]N
M<V5;)V9A=6QT4W1R:6YG)UTL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("!](&5L<V5I9B`H:7-?87)R87DH)')E<W!O;G-E*2`F)B!I<W-E="@D<F5S
M<&]N<V5;,%TI("8F"B`@("`@("`@("`@("`@("`@("`@("!I<U]A<G)A>2@D
M<F5S<&]N<V5;,%TI("8F(&ES<V5T*"1R97-P;VYS95LP75LG9F%U;'13=')I
M;F<G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"1R97-P;VYS95LP75LG9F%U;'13=')I;F<G72P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R97-P;VYS
M93L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#
M+W=E8F1A=BYP:'``````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$U-C0U`#$P-3$U-#,Q,#8Q`#`R,#8S-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=(
M5%10+U=E8D1!5B]397)V97(N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?4E!#
M7W=E8F1A=B!C;&%S<R!P<F]V:61E<R!A(%=E8D1!5B!I;7!L96UE;G1A=&EO
M;B!O9B!T:&4*("H@2&]R9&4@4E!#('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO4E!#+U)00R]W96)D878N<&AP+'8@,2XQ+C$R+C8@,C`P-B\P
M,2\P,2`R,3HR.#HS,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?4E!#"B`J+PIC;&%S<R!(;W)D95]24$-?=V5B9&%V(&5X=&5N9',@
M2&]R9&5?4E!#('L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E(&AA;F1L97(@
M9F]R('1H92!796)$058@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@2%14
M4%]796)$059?4V5R=F5R7TAO<F1E"B`@("`@*B\*("`@('9A<B`D7W-E<G9E
M<CL*"B`@("`O*BH*("`@("`J(%=E8D1A=B!S97)V97(@8V]N<W1R=6-T;W(N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N($AO<F1E7U)00U]W96)D878H*0H@("`@>PH@("`@("`@('!A<F5N
M=#HZ2&]R9&5?4E!#*"D["@H@("`@("`@("1T:&ES+3Y?<V5R=F5R(#T@)FYE
M=R!(5%107U=E8D1!5E]397)V97)?2&]R9&4H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E;F1S(&%N(%)00R!R97%U97-T('1O('1H92!S97)V97(@86YD
M(')E='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("!4:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T
M:&4@<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D
M<F5Q=65S="D*("`@('L*("`@("`@("`D=&AI<RT^7W-E<G9E<BT^4V5R=F52
M97%U97-T*"D["B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%=E8D1!5B!H86YD;&5S(&%U=&AE;G1I8V%T:6]N(&EN=&5R;F%L;'DL('-O
M(&)Y<&%S<R!T:&4*("`@("`J('-Y<W1E;2UL979E;"!A=71H(&-H96-K(&)Y
M(&IU<W0@<F5T=7)N:6YG('1R=64@:&5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@875T:&]R:7IE*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"GT*"B\J*@H@*B!(;W)D92!E>'1E;G-I;VX@;V8@=&AE(&)A<V4@2%14
M4%]796)$059?4V5R=F5R(&-L87-S+@H@*@H@*B!`<&%C:V%G92!(;W)D95]2
M4$,*("HO"F-L87-S($A45%!?5V5B1$%67U-E<G9E<E](;W)D92!E>'1E;F1S
M($A45%!?5V5B1$%67U-E<G9E<B!["@H@("`@+RHJ"B`@("`@*B!296%L;2!S
M=')I;F<@=&\@8F4@=7-E9"!I;B!A=71H96YT:69I8V%T:6]N('!O<'5P<PH@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:'1T
M<%]A=71H7W)E86QM(#T@)TAO<F1E(%=E8D1!5B<["@H@("`@+RHJ"B`@("`@
M*B!3=')I;F<@=&\@8F4@=7-E9"!I;B`B6"U$878M4&]W97)E9"U">2(@:&5A
M9&5R"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1D879?<&]W97)E9%]B>2`]("=(;W)D92!796)$058@4V5R=F5R)SL*"B`@
M("`O*BH*("`@("`J($=%5"!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&]P=&EO;G,@($%R<F%Y(&]F(&EN<'5T(&%N9"!O
M=71P=70@<&%R86UE=&5R<RX*("`@("`J(#QB<CX\<W1R;VYG/FEN<'5T/"]S
M=')O;F<^/'5L/@H@("`@("H@/&QI/B!P871H("T*("`@("`J(#PO=6P^"B`@
M("`@*B`\8G(^/'-T<F]N9SYO=71P=70\+W-T<F]N9SX\=6P^"B`@("`@*B`\
M;&D^('-I>F4@+0H@("`@("H@/"]U;#X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@($A45%`M4W1A='5S8V]D92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@1T54*"8D;W!T:6]N<RD*("`@('L*("`@("`@("!I9B`H)&]P=&EO;G-;
M)W!A=&@G72`]/2`G+R<I('L*("`@("`@("`@("`@)&]P=&EO;G-;)VUI;65T
M>7!E)UT@/2`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]L:7-T*"1O<'1I
M;VYS6R=P871H)UTL(#`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0550@;65T:&]D(&AA;F1L97(*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1O<'1I;VYS("!087)A;65T
M97(@<&%S<VEN9R!A<G)A>2X*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!0550H)B1O<'1I
M;VYS*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4%)/4$9)3D0@;65T:&]D(&AA;F1L97(*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&]P=&EO;G,@($=E;F5R86P@<&%R86UE=&5R('!A
M<W-I;F<@87)R87DN"B`@("`@*B!`<&%R86T@87)R87D@)B1F:6QE<R`@4F5T
M=7)N(&%R<F%Y(&9O<B!F:6QE('!R;W!E<G1I97,N"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@4%)/4$9)3D0H)&]P=&EO;G,L("8D9FEL97,I"B`@("!["B`@("`@("`@
M)&QI<W0@/2`D=&AI<RT^7VQI<W0H)&]P=&EO;G-;)W!A=&@G72P@)&]P=&EO
M;G-;)V1E<'1H)UTI.PH@("`@("`@(&EF("@D;&ES="`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D
M9FEL97-;)V9I;&5S)UT@/2`D;&ES=#L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("!F=6YC=&EO;B!?;&ES="@D<&%T:"P@)&1E<'1H*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1L:7-T(#T@
M87)R87DH"B`@("`@("`@("`@(&%R<F%Y*"=P871H)R`]/B`D=&AI<RT^<&%T
M:"P*("`@("`@("`@("`@("`@("=P<F]P<R<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G9&ES<&QA>6YA;64G+"`D=&AI
M<RT^<&%T:"DL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G
M8W)E871I;VYD871E)RP@=&EM92@I*2P*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;6MP<F]P*"=G971L87-T;6]D:69I960G+"!T:6UE*"DI+`H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)W)E<V]U<F-E='EP92<L
M("=C;VQL96-T:6]N)RDL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK
M<')O<"@G9V5T8V]N=&5N='1Y<&4G+"`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG
M*2P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT
M96YT;&5N9W1H)RP@,"DI*2D["B`@("`@("`@:68@*"1P871H(#T]("<O)RD@
M>PH@("`@("`@("`@("`D87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H;G5L
M;"P@9F%L<V4L(%!%4DU37U)%040I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M87!P<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1A
M<'!S(&%S("1A<'`I('L*("`@("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G8G)O=W-E)RP@)&%P<"DI('L*("`@("`@("`@("`@("`@
M("`@("`D<')O<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FUK<')O<"@G9&ES<&QA>6YA;64G+"!3=')I;F<Z.F-O;G9E<G1#
M:&%R<V5T*"1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"DL($Y,4SHZ9V5T
M0VAA<G-E="@I+"`G551&+3@G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YM:W!R;W`H)V-R96%T:6]N9&%T92<L('1I;64H*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&QA<W1M;V1I
M9FEE9"<L('1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YM:W!R;W`H)W)E<V]U<F-E='EP92<L("=C;VQL96-T:6]N)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E;G1T
M>7!E)RP@)VAT='!D+W5N:7@M9&ER96-T;W)Y)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E;G1L96YG=&@G+"`P
M*2D["B`@("`@("`@("`@("`@("`@("`@)&ET96T@/2!A<G)A>2@G<&%T:"<@
M/3X@)'1H:7,M/G!A=&@@+B`G+R<@+B`D87!P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W!R;W!S)R`]/B`D<')O<',I.PH@("`@("`@
M("`@("`@("`@("`@("1L:7-T6UT@/2`D:71E;3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EF("AS=6)S='(H)'!A=&@L(#`L(#$I(#T]("<O)RD@>PH@("`@("`@("`@
M("`@("`@)'!A=&@@/2!S=6)S='(H)'!A=&@L(#$I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1P:65C97,@/2!E>'!L;V1E*"<O)RP@)'!A=&@I.PH@
M("`@("`@("`@("`D:71E;7,@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H
M)'!I96-E<ULP72P@)V)R;W=S92<L(&%R<F%Y*"=P871H)R`]/B`D<&%T:"P@
M)W!R;W!E<G1I97,G(#T^(&%R<F%Y*"=N86UE)RP@)V)R;W=S96%B;&4G+"`G
M8V]N=&5N='1Y<&4G+"`G8V]N=&5N=&QE;F=T:"<L("=C<F5A=&5D)RP@)VUO
M9&EF:65D)RDI*3L*("`@("`@("`@("`@:68@*&ES7V$H)&ET96US+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2AR97-E="@D
M:71E;7,I*2D@>PH@("`@("`@("`@("`@("`@+RH@5V4@<F5T=7)N(&%N(&]B
M:F5C="=S(&-O;G1E;G0N("HO"B`@("`@("`@("`@("`@("!R971U<FX@)&ET
M96US.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5M
M<R!A<R`D<W5B7W!A=&@@/3X@)&DI('L*("`@("`@("`@("`@("`@("1P<F]P
M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H
M)V1I<W!L87EN86UE)RP@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D:5LG;F%M
M92==+"!.3%,Z.F=E=$-H87)S970H*2P@)U541BTX)RDI+`H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V-R96%T:6]N9&%T92<L(&5M<'1Y
M*"1I6R=C<F5A=&5D)UTI(#\@,"`Z("1I6R=C<F5A=&5D)UTI+`H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&QA<W1M;V1I9FEE9"<L
M(&5M<'1Y*"1I6R=M;V1I9FEE9"==*2`_(#`@.B`D:5LG;6]D:69I960G72DL
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G<F5S;W5R8V5T
M>7!E)RP@)&E;)V)R;W=S96%B;&4G72`_("=C;VQL96-T:6]N)R`Z("<G*2P*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT
M='EP92<L("1I6R=B<F]W<V5A8FQE)UT@/R`G:'1T<&0O=6YI>"UD:7)E8W1O
M<GDG(#H@*&5M<'1Y*"1I6R=C;VYT96YT='EP92==*2`_("=A<'!L:6-A=&EO
M;B]O8W1E="US=')E86TG(#H@)&E;)V-O;G1E;G1T>7!E)UTI*2P*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT;&5N9W1H
M)RP@96UP='DH)&E;)V-O;G1E;G1L96YG=&@G72D@/R`P(#H@)&E;)V-O;G1E
M;G1L96YG=&@G72DI.PH@("`@("`@("`@("`@("`@)&ET96T@/2!A<G)A>2@G
M<&%T:"<@/3X@)R\G("X@)'-U8E]P871H+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<')O<',G(#T^("1P<F]P<RD["B`@("`@("`@("`@("`@
M("`D;&ES=%M=(#T@)&ET96T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@D9&5P=&@I('L*("`@("`@("`@("`@:68@*"1D97!T:"`]
M/2`Q*2!["B`@("`@("`@("`@("`@("`D9&5P=&@@/2`P.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1A<'`@/3X@)&ET
M96TI('L*("`@("`@("`@("`@("`@("\O7VQI<W0H)'!A=&@@+B`G+R<@+B`D
M:71E;2P@)&1E<'1H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@
M875T:&5N=&EC871I;VXN(%=E(&%L=V%Y<R!R971U<FX@=')U92!H97)E('-I
M;F-E('=E"B`@("`@*B!H86YD;&4@<&5R;6ES<VEO;G,@8F%S960@;VX@=&AE
M(')E<V]U<F-E('1H870G<R!R97%U97-T960L(&)U=`H@("`@("H@=V4@9&\@
M<F5C;W)D('1H92!A=71H96YT:6-A=&5D('5S97(@9F]R(&QA=&5R('5S92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@075T:&5N
M=&EC871I;VX@='EP92P@92YG+B`B8F%S:6,B(&]R(")D:6=E<W0B"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92`@5')A;G-M:71T960@=7-E<FYA
M;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5')A;G-M:71T
M960@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!!
M=71H96YT:6-A=&EO;B!S=&%T=7,N($%L=V%Y<R!T<G5E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C:&5C:U]A=71H*"1T>7!E+"`D=7-E<FYA;64L("1P87-S
M=V]R9"D*("`@('L*("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH
M)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G72D["B`@("`@("`@
M<F5T=7)N("1A=71H+3YA=71H96YT:6-A=&4H)'5S97)N86UE+"!A<G)A>2@G
M<&%S<W=O<F0G(#T^("1P87-S=V]R9"DI.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W-Y;F-M;%]W8GAM;"YP
M:'``````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-S`W`#$P-3$U-#,Q
M,#8Q`#`R,C$P,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]S>6YC;6PN<&AP)SL*<F5Q=6ER95]O;F-E("=834PO5T)834PO1&5C
M;V1E<BYP:'`G.PIR97%U:7)E7V]N8V4@)UA-3"]70EA-3"]%;F-O9&5R+G!H
M<"<["@HO*BH*("H@5&AE($AO<F1E7U)00U]S>6YC;6Q?=V)X;6P@8VQA<W,@
M<')O=FED97,@82!3>6YC34P@:6UP;&5M96YT871I;VX@;V8@=&AE"B`J($AO
M<F1E(%)00R!S>7-T96T@=7-I;F<@5T)834P@96YC;V1I;F<N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U)00R]24$,O<WEN8VUL7W=B>&UL+G!H<"QV(#$N
M,3$N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C,S(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@
M/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U)00PH@*B\*
M8VQA<W,@2&]R9&5?4E!#7W-Y;F-M;%]W8GAM;"!E>'1E;F1S($AO<F1E7U)0
M0U]S>6YC;6P@>PH*("`@("\J*@H@("`@("H@4V5N9',@86X@4E!#(')E<75E
M<W0@=&\@=&AE('-E<G9E<B!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)')E<75E<W0@(%1H92!R87<@<F5Q
M=65S="!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!70EA-3"!E;F-O9&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<B`H8FEN
M87)Y*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H)')E<75E
M<W0I"B`@("!["B`@("`@("`@+RH@0V%T8V@@86YY(&5R<F]R<R]W87)N:6YG
M<R]N;W1I8V5S('1H870@;6%Y(&=E="!T:')O=VX@=VAI;&4*("`@("`@("`@
M*B!P<F]C97-S:6YG+B!$;VXG="!W86YT('1O(&QE="!A;GET:&EN9R!G;R!T
M;R!T:&4@8VQI96YT('1H870G<R!N;W0*("`@("`@("`@*B!P87)T(&]F('1H
M92!V86QI9"!R97-P;VYS92X@*B\*("`@("`@("!O8E]S=&%R="@I.PH*("`@
M("`@("`O*B!697)Y('5S969U;"!F;W(@9&5B=6=G:6YG+B!,;V=S(%="6$U,
M('!A8VME=',@=&\*("`@("`@("`@*B`D=&AI<RT^7V1E8G5G1&ER+B`J+PH@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]D96)U9T1I<BD@)B8@:7-?9&ER
M*"1T:&ES+3Y?9&5B=6=$:7(I*2!["B`@("`@("`@("`@("1P86-K971.=6T@
M/2!`:6YT=F%L*&9I;&5?9V5T7V-O;G1E;G1S*"1T:&ES+3Y?9&5B=6=$:7(@
M+B`G+W-Y;F-M;"YP86-K971N=6TG*2D["B`@("`@("`@("`@(&EF("@A:7-S
M970H)'!A8VME=$YU;2DI('L*("`@("`@("`@("`@("`@("1P86-K971.=6T@
M/2`P.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9G`@/2!F;W!E;B@D
M=&AI<RT^7V1E8G5G1&ER("X@)R]S>6YC;6Q?8VQI96YT7R<@+B`D<&%C:V5T
M3G5M("X@)RYW8GAM;"<L("=W8B<I.PH@("`@("`@("`@("!F=W)I=&4H)&9P
M+"`D<F5Q=65S="D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@
M('T*"@H@("`@("`@("1D96-O9&5R(#T@)FYE=R!834Q?5T)834Q?1&5C;V1E
M<B@I.PH@("`@("`@("1T:&ES+3Y?;W5T<'5T(#T@)FYE=R!834Q?5T)834Q?
M16YC;V1E<B@I.PH*("`@("`@("`D9&5C;V1E<BT^<V5T0V]N=&5N=$AA;F1L
M97(H)'1H:7,I.PH*("`@("`@("`D<B`]("1D96-O9&5R+3YD96-O9&4H)')E
M<75E<W0I.PH@("`@("`@(&EF("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3>6YC34PZ("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<BT^9V5T365S<V%G92@I
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7V]U='!U="T^<V5T5F5R<VEO;B@D9&5C;V1E
M<BT^9V5T5F5R<VEO;B@I*3L*("`@("`@("`D=&AI<RT^7V]U='!U="T^<V5T
M0VAA<G-E="@D9&5C;V1E<BT^9V5T0VAA<G-E=%-T<B@I*3L*("`@("`@("`D
M<F5S<&]N<V4@/2`D=&AI<RT^7V]U='!U="T^9V5T3W5T<'5T*"D["@H@("`@
M("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S<&]N<V4L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@)')E<W!O
M;G-E(#T@)')E<W!O;G-E+3YG971-97-S86=E*"D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?9&5B=6=$:7(I("8F(&ES7V1I<B@D
M=&AI<RT^7V1E8G5G1&ER*2D@>PH@("`@("`@("`@("`D9G`@/2!F;W!E;B@D
M=&AI<RT^7V1E8G5G1&ER("X@)R]S>6YC;6Q?<V5R=F5R7R<@+B`D<&%C:V5T
M3G5M("X@)RYW8GAM;"<L("=W8B<I.PH@("`@("`@("`@("!F=W)I=&4H)&9P
M+"`D<F5S<&]N<V4I.PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@
M("`@("`@("1F<"`]($!F;W!E;B@D=&AI<RT^7V1E8G5G1&ER("X@)R]S>6YC
M;6PN<&%C:V5T;G5M)RP@)W<G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@
M("`@("`@("`@("`@("`@9G=R:71E*"1F<"P@*RLD<&%C:V5T3G5M*3L*("`@
M("`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"@H@("`@
M("`@('T*"B`@("`@("`@+RH@0VQE87(@=&AE(&]U='!U="!B=69F97(@=&AA
M="!W92!S=&%R=&5D(&%B;W9E+"!A;F0@;&]G(&%N>71H:6YG"B`@("`@("`@
M("H@=&AA="!C86UE('5P(&9O<B!L871E<B!D96)U9V=I;F<N("HO"B`@("`@
M("`@)&5R<F]R3&]G9VEN9R`](&]B7V=E=%]C;&5A;B@I.PH@("`@("`@(&EF
M("@A96UP='DH)&5R<F]R3&]G9VEN9RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-Y;F--3#H@8V%U9VAT(&]U='!U=#TG("X@)&5R<F]R
M3&]G9VEN9RP*("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W!O
M;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@0V]N=&5N
M="U4>7!E(&]F('1H92!R97-P;VYS92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE($U)344@0V]N=&5N="U4>7!E(&]F('1H92!24$,@<F5S
M<&]N<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E0V]N=&5N
M=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G87!P;&EC871I;VXO=FYD
M+G-Y;F-M;"MW8GAM;"<["B`@("!]"@I]"@``````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S>6YC;6PN<&AP````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S8T-@`Q,#4Q-30S
M,3`V,0`P,C`V-S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G4WEN8TU,+G!H<"<["G)E
M<75I<F5?;VYC92`G4WEN8TU,+U-T871E+G!H<"<["G)E<75I<F5?;VYC92`G
M4WEN8TU,+T-O;6UA;F0O4W1A='5S+G!H<"<["@HO*BH*("H@5&AE($AO<F1E
M7U)00U]S>6YC;6P@8VQA<W,@<')O=FED97,@82!3>6YC34P@:6UP;&5M96YT
M871I;VX@;V8@=&AE($AO<F1E"B`J(%)00R!S>7-T96TN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U)00R]24$,O<WEN8VUL+G!H<"QV(#$N,3@N,3`N-R`R
M,#`V+S`U+S`Q(#$R.C`U.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P
M>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@06YT
M:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U)00PH@*B\*8VQA<W,@2&]R
M9&5?4E!#7W-Y;F-M;"!E>'1E;F1S($AO<F1E7U)00R!["@H@("`@+RHJ"B`@
M("`@*B!/=71P=70@0V]N=&5N=$AA;F1L97(@=7-E9"!T;R!O=71P=70@6$U,
M(&5V96YT<RX*("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@
M("!V87(@)%]O=71P=70["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1?>&UL4W1A8VL@/2`P.PH*("`@("\J*@H@("`@
M("H@1&5B=6<@9&ER96-T;W)Y+"!I9B!S970@=VEL;"!S=&]R92!C;W!I97,@
M;V8@86QL('!A8VME=',N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?9&5B=6=$:7(@/2`G+W1M<"]S>6YC)SL*"B`@("`O
M*BH*("`@("`J($1E9F%U;'0@8VAA<F%C=&5R('-E="X@($]N;'D@<W5P<&]R
M=',@551&+3@H05-#24D_*2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]C:&%R<V5T(#T@)U541BTX)SL*"B`@("`O*BH*
M("`@("`J(%-Y;F--3"!H86YD;&5S(&%U=&AE;G1I8V%T:6]N(&EN=&5R;F%L
M;'DL('-O(&)Y<&%S<R!T:&4@4E!#(&9R86UE=V]R:PH@("`@("H@875T:"!C
M:&5C:R!B>2!J=7-T(')E='5R;FEN9R!T<G5E(&AE<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%U=&AO<FEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R!A;B!24$,@<F5Q=65S
M="!T;R!T:&4@<V5R=F5R(&%N9"!R971U<FYS('1H92!R97-U;'0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q=65S="`@5&AE(')A=R!R97%U
M97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(%A-3"!E;F-O9&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H)')E<75E<W0I"B`@("!["B`@
M("`@("`@+RH@0V%T8V@@86YY(&5R<F]R<R]W87)N:6YG<R]N;W1I8V5S('1H
M870@;6%Y(&=E="!T:')O=VX@=VAI;&4*("`@("`@("`@*B!P<F]C97-S:6YG
M+B!$;VXG="!W86YT('1O(&QE="!A;GET:&EN9R!G;R!T;R!T:&4@8VQI96YT
M('1H870G<R!N;W0*("`@("`@("`@*B!P87)T(&]F('1H92!V86QI9"!R97-P
M;VYS92X@*B\*("`@("`@("!O8E]S=&%R="@I.PH*("`@("`@("`O*B!697)Y
M('5S969U;"!F;W(@9&5B=6=G:6YG+B!,;V=S(%="6$U,('!A8VME=',@=&\*
M("`@("`@("`@*B`D=&AI<RT^7V1E8G5G1&ER+B`J+PH@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]D96)U9T1I<BD@)B8@:7-?9&ER*"1T:&ES+3Y?9&5B
M=6=$:7(I*2!["B`@("`@("`@("`@("1P86-K971.=6T@/2!`:6YT=F%L*&9I
M;&5?9V5T7V-O;G1E;G1S*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;"YP
M86-K971N=6TG*2D["B`@("`@("`@("`@(&EF("@A:7-S970H)'!A8VME=$YU
M;2DI('L*("`@("`@("`@("`@("`@("1P86-K971.=6T@/2`P.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D9B`]($!F;W!E;B@D=&AI<RT^7V1E8G5G
M1&ER("X@)R]S>6YC;6Q?8VQI96YT7R<@+B`D<&%C:V5T3G5M("X@)RYX;6PG
M+"`G=V(G*3L*("`@("`@("`@("`@:68@*"1F*2!["B`@("`@("`@("`@("`@
M("!F=W)I=&4H)&8L("1R97%U97-T*3L*("`@("`@("`@("`@("`@(&9C;&]S
M92@D9BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I
M<F5?;VYC92`G6$U,+U="6$U,+T-O;G1E;G1(86YD;&5R+G!H<"<["B`@("`@
M("`@)'1H:7,M/E]O=71P=70@/2`F;F5W(%A-3%]70EA-3%]#;VYT96YT2&%N
M9&QE<B@I.PH*("`@("`@("`D=&AI<RT^7W!A<G-E*"1R97%U97-T*3L*("`@
M("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V]U='!U="T^9V5T3W5T<'5T*"D[
M"@H@("`@("`@("\J(%9E<GD@=7-E9G5L(&9O<B!D96)U9V=I;F<N("HO"B`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V1E8G5G1&ER*2`F)B!I<U]D:7(H
M)'1H:7,M/E]D96)U9T1I<BDI('L*("`@("`@("`@("`@)&8@/2!`9F]P96XH
M)'1H:7,M/E]D96)U9T1I<B`N("<O<WEN8VUL7W-E<G9E<E\G("X@)'!A8VME
M=$YU;2`N("<N>&UL)RP@)W=B)RD["B`@("`@("`@("`@(&EF("@D9BD@>PH@
M("`@("`@("`@("`@("`@9G=R:71E*"1F+"`D<F5S<&]N<V4I.PH@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&9P(#T@0&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;"YP
M86-K971N=6TG+"`G=R<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@
M("`@("`@("`@("!F=W)I=&4H)&9P+"`K*R1P86-K971.=6TI.PH@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\J($-L96%R('1H92!O=71P=70@8G5F9F5R('1H870@=V4@
M<W1A<G1E9"!A8F]V92P@86YD(&QO9R!A;GET:&EN9PH@("`@("`@("`J('1H
M870@8V%M92!U<"!F;W(@;&%T97(@9&5B=6=G:6YG+B`J+PH@("`@("`@("1E
M<G)O<DQO9V=I;F<@/2!O8E]G971?8VQE86XH*3L*("`@("`@("!I9B`H(65M
M<'1Y*"1E<G)O<DQO9V=I;F<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=3>6YC34PZ(&-A=6=H="!O=71P=70])R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<E]R97!L86-E*")<;B(L("<@)RP@)&5R
M<F]R3&]G9VEN9RDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<&%R<V4H)'AM;"D*("`@('L*("`@("`@("`O
M*B!T<GD@=&\@97AT<F%C="!C:&%R<V5T(&9R;VT@6$U,('1E>'0@*B\*("`@
M("`@("!I9BAP<F5G7VUA=&-H*"<O7EQS*CQ</WAM;%M>/ETJ96YC;V1I;F=<
M<RH]7',J(BA;7B)=*BDB+VDG+`H@("`@("`@("`@("`@("`@)'AM;"P@)&TI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8VAA<G-E="`]("1M6S%=.PH@("`@
M("`@('T*("`@("`@("!.3%,Z.G-E=$-H87)S970H)'1H:7,M/E]C:&%R<V5T
M*3L*("`@("`@("!3=')I;F<Z.G-E=$1E9F%U;'1#:&%R<V5T*"1T:&ES+3Y?
M8VAA<G-E="D["@H@("`@("`@("\J($-R96%T92!T:&4@6$U,('!A<G-E<B!A
M;F0@<V5T(&UE=&AO9"!R969E<F5N8V5S+B`J+PH@("`@("`@("1T:&ES+3Y?
M<&%R<V5R(#T@>&UL7W!A<G-E<E]C<F5A=&5?;G,H)'1H:7,M/E]C:&%R<V5T
M*3L*("`@("`@("!X;6Q?<V5T7V]B:F5C="@D=&AI<RT^7W!A<G-E<BP@)'1H
M:7,I.PH@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D=&AI<RT^7W!A
M<G-E<BP@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L(&9A;'-E*3L*("`@("`@
M("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]S
M=&%R=$5L96UE;G0G+"`G7V5N9$5L96UE;G0G*3L*("`@("`@("!X;6Q?<V5T
M7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("=?8VAA
M<F%C=&5R<R<I.PH@("`@("`@('AM;%]S971?<')O8V5S<VEN9U]I;G-T<G5C
M=&EO;E]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G)RD["B`@("`@("`@>&UL
M7W-E=%]E>'1E<FYA;%]E;G1I='E?<F5F7VAA;F1L97(H)'1H:7,M/E]P87)S
M97(L("<G*3L*"B`@("`@("`@:68@*"%X;6Q?<&%R<V4H)'1H:7,M/E]P87)S
M97(L("1X;6PI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<BAS<')I;G1F*"=834P@97)R;W(Z("5S(&%T(&QI;F4@)60G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!X;6Q?
M97)R;W)?<W1R:6YG*'AM;%]G971?97)R;W)?8V]D92@D=&AI<RT^7W!A<G-E
M<BDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!X;6Q?9V5T7V-U<G)E;G1?;&EN95]N=6UB97(H)'1H:7,M/E]P87)S
M97(I*2D["B`@("`@("`@?0H*("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'1H
M:7,M/E]P87)S97(I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$5L96UE
M;G0H)'!A<G-E<BP@)'1A9RP@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@
M;&ES="@D=7)I+"`D;F%M92D@/2`D=&AI<RT^7W-P;&ET55))*"1T86<I.PH*
M("`@("`@("`D=&AI<RT^<W1A<G1%;&5M96YT*"1U<FDL("1N86UE+"`D871T
M<FEB=71E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H87)A8W1E<G,H)'!A
M<G-E<BP@)&-H87)S*0H@("`@>PH@("`@("`@("1T:&ES+3YC:&%R86-T97)S
M*"1C:&%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V5N9$5L96UE;G0H)'!A
M<G-E<BP@)'1A9RD*("`@('L*("`@("`@("!L:7-T*"1U<FDL("1N86UE*2`]
M("1T:&ES+3Y?<W!L:7154DDH)'1A9RD["@H@("`@("`@("1T:&ES+3YE;F1%
M;&5M96YT*"1U<FDL("1N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<W!L
M:7154DDH)'1A9RD*("`@('L*("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z
M)RP@)'1A9RD["B`@("`@("`@)&YA;64@/2!A<G)A>5]P;W`H)'!A<G1S*3L*
M("`@("`@("`D=7)I(#T@:6UP;&]D92@G.B<L("1P87)T<RD["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"1U<FDL("1N86UE*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE($-O;G1E;G0M5'EP92!O9B!T:&4@<F5S<&]N<V4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%($-O;G1E
M;G0M5'EP92!O9B!T:&4@4E!#(')E<W!O;G-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971297-P;VYS94-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!R
M971U<FX@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PK>&UL)SL*("`@('T*"B`@
M("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R
M<RD*("`@('L*("`@("`@("`D=&AI<RT^7WAM;%-T86-K*RL["@H@("`@("`@
M('-W:71C:"`H)'1H:7,M/E]X;6Q3=&%C:RD@>PH@("`@("`@(&-A<V4@,3H*
M("`@("`@("`@("`@+R\@/%-Y;F--3#X*("`@("`@("`@("`@+R\@1&5F:6YE
M9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@
M,2XQ(#4N,BXQ"B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("\O($5I=&AE<B`\
M4WEN8TU,/CQ3>6YC2&1R/B!O<B`\4WEN8TU,/CQ3>6YC0F]D>3X*("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-O;G1E;G1(86YD;&5R*2D@>PH@
M("`@("`@("`@("`@("`@+R\@268@;F]T(&1E9FEN960@=&AE;B!C<F5A=&4@
M4WEN8TAD<BX*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L
M97(@/2`F;F5W(%-Y;F--3%]3>6YC;6Q(9'(H*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/G-E=$]U='!U="@D=&AI<RT^7V]U
M='!U="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=&5N=$AA;F1L97(M/G-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T
M=')S*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-O;G1E;G1(86YD;&5R*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^<W1A
M<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@
M("`@('-W:71C:"`H)'1H:7,M/E]X;6Q3=&%C:RD@>PH@("`@("`@(&-A<V4@
M,3H*("`@("`@("`@("`@+R\@/"]3>6YC34P^"B`@("`@("`@("`@("\O($1E
M9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S
M:6]N(#$N,2`U+C(N,0H@("`@("`@("`@("`D=&AI<RT^7V]U='!U="T^96YD
M16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("\O($5I=&AE<B`\+U-Y;F-(
M9'(^/"]3>6YC34P^(&]R(#PO4WEN8T)O9'D^/"]3>6YC34P^"B`@("`@("`@
M("`@(&EF("@D96QE;65N="`]/2`G4WEN8TAD<B<I('L*("`@("`@("`@("`@
M("`@("\O(%1H96X@=V4@9V5T('1H92!S=&%T92!F<F]M(%-Y;F--3$AD<BP@
M86YD(&-R96%T92!A(&YE=PH@("`@("`@("`@("`@("`@+R\@4WEN8TU,0F]D
M>2X*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/F5N
M9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH*("`@("`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I.PH*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(@/2`F;F5W(%-Y;F--3%]3>6YC;6Q"
M;V1Y*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R
M+3YS971/=71P=70H)'1H:7,M/E]O=71P=70I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+R\@3F\@;&]N9V5R('5S960N"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R+3YE;F1%;&5M96YT
M*"1U<FDL("1E;&5M96YT*3L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?8V]N=&5N=$AA;F1L97(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`O+R`\+RH^
M/"]3>6YC2&1R/CPO4WEN8TU,/B!O<B`\+RH^/"]3>6YC0F]D>3X\+U-Y;F--
M3#X*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L
M97(I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R
M+3YE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7V-H87)S*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M7V-H87)S*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?>&UL4W1A8VLM
M+3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S*"1S='(I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/F-H87)A8W1E
M<G,H)'-T<BD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(')A:7-E
M17)R;W(H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@2&]R9&4Z.FQO9TUE
M<W-A9V4H)'-T<BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]24$,O<V]A<"YP:'``````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,34Q-3<`,3`U,34T,S$P-C$`,#(P,S(T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M2&]R9&5?4E!#7W-O87`@8VQA<W,@<')O=FED97,@86X@4T]!4"!I;7!L96UE
M;G1A=&EO;B!O9B!T:&4*("H@2&]R9&4@4E!#('-Y<W1E;2X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<"QV(#$N,3,N,3`N-R`R
M,#`V+S`Q+S`Q(#(Q.C(X.C,S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?4E!#"B`J+PIC;&%S<R!(;W)D95]24$-?<V]A<"!E>'1E;F1S($AO<F1E
M7U)00R!["@H@("`@+RHJ"B`@("`@*B!297-O=7)C92!H86YD;&5R(&9O<B!T
M:&4@4E!#('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@
M("HO"B`@("!V87(@)%]S97)V97(["@H@("`@+RHJ"B`@("`@*B!(87-H(&AO
M;&1I;F<@86QL(&UE=&AO9',G('-I9VYA='5R97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]?9&ES<&%T8VA?;6%P(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-/05`@<V5R=F5R(&-O;G-T<G5C
M=&]R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7U)00U]S;V%P*"1P87)A;7,@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@D<&%R86US(#T]("=W<V1L)R!\?"`D<&%R86US(#T]
M("=D:7-C;R<I('L*("`@("`@("`@("`@)'1H:7,M/E]A=71H;W)I>F4@/2!F
M86QS93L*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ2&]R9&5?4E!#*"D[
M"@H@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@(')E<75I<F5?
M;VYC92`G4T]!4"]397)V97(N<&AP)SL*("`@("`@("`D=&AI<RT^7W-E<G9E
M<B`]("9N97<@4T]!4%]397)V97(H*3L*("`@("`@("`D=&AI<RT^7W-E<G9E
M<BT^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1FEL;',@82!H87-H('1H870@:7,@=7-E9"!B>2!T:&4@4T]!4"!S
M97)V97(@=VET:"!T:&4@<VEG;F%T=7)E<R!O9@H@("`@("H@86QL(&%V86EL
M86)L92!M971H;V1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T=7!$:7-P
M871C:$UA<"@I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@
M("`@("`@)&UE=&AO9',@/2`D<F5G:7-T<GDM/FQI<W1-971H;V1S*"D["B`@
M("`@("`@9F]R96%C:"`H)&UE=&AO9',@87,@)&UE=&AO9"D@>PH@("`@("`@
M("`@("`D<VEG;F%T=7)E(#T@)')E9VES=')Y+3YG9713:6=N871U<F4H)&UE
M=&AO9"D["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'-I9VYA='5R92DI
M('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1M971H;V0@/2!S=')?<F5P;&%C92@G+R<L("<N)RP@)&UE
M=&AO9"D["B`@("`@("`@("`@("1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LD;65T
M:&]D72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VEN)R`]/B`D<VEG;F%T
M=7)E6S!=+`H@("`@("`@("`@("`@("`@)V]U="<@/3X@87)R87DH)V]U='!U
M="<@/3X@)'-I9VYA='5R95LQ72D*("`@("`@("`@("`@*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?7W1Y<&5D968@/2`D<F5G:7-T<GDM/FQI<W14
M>7!E<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEG
M;F%T=7)E(&]F(&$@;65T:&]D+@H@("`@("H@26YT97)N86QL>2!U<V5D(&)Y
M('1H92!33T%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M971H;V0@($$@;65T:&]D(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@06X@87)R87D@9&5S8W)I8FEN9R!T:&4@;65T:&]D)W,@<VEG
M;F%T=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?7V1I<W!A=&-H*"1M971H
M;V0I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("`D
M;65T:&]D(#T@<W1R7W)E<&QA8V4H)RXG+"`G+R<L("1M971H;V0I.PH*("`@
M("`@("`D<VEG;F%T=7)E(#T@)')E9VES=')Y+3YG9713:6=N871U<F4H)&UE
M=&AO9"D["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<VEG;F%T=7)E*2D@>PH@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!A<G)A>2@G:6XG(#T^("1S:6=N871U<F5;,%TL"B`@("`@("`@("`@
M("`@("`@("`@("=O=70G(#T^(&%R<F%Y*"=O=71P=70G(#T^("1S:6=N871U
M<F5;,5TI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=I;&P@8F4@<F5G:7-T
M97)E9"!A<R!T:&4@:&%N9&QE<B!F;W(@86QL(&UE=&AO9',@8V%L;&5D(&EN
M('1H90H@("`@("H@4T]!4"!S97)V97(@86YD('=I;&P@8V%L;"!T:&4@87!P
M<F]P<FEA=&4@9G5N8W1I;VX@=&AR;W5G:"!T:&4@<F5G:7-T<GDN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;65T:&]D("`@(%1H92!N86UE(&]F('1H92!M971H;V0@8V%L
M;&5D(&)Y('1H92!24$,@<F5Q=65S="X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("`@("!4:&4@<&%S<V5D('!A<F%M971E<G,N"B`@("`@*B!`<&%R
M86T@;6EX960@)&1A=&$@("`@("`@56YK;F]W;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("`@("`@("`@("`@5&AE(')E<W5L="!O9B!T:&4@8V%L
M;&5D(')E9VES=')Y(&UE=&AO9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I
M<W!A=&-H97(H)&UE=&AO9"P@)'!A<F%M<RD*("`@('L*("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH@("`@("`@("1M971H;V0@/2!S=')?<F5P;&%C92@G
M+B<L("<O)RP@)&UE=&AO9"D["@H@("`@("`@(&EF("@A)')E9VES=')Y+3YH
M87--971H;V0H)&UE=&AO9"DI('L*("`@("`@("`@("`@<F5T=7)N('-P<FEN
M=&8H7R@B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(I+"`D;65T:&]D
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V5R=F5R+3YB:6YD5U-$
M3"A(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E
M)RD@+B`G+W)P8RYP:'`_=W-D;"<L('1R=64L(&9A;'-E*2D["B`@("`@("`@
M<F5T=7)N("1R96=I<W1R>2T^8V%L;"@D;65T:&]D+"`D<&%R86US*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%N(%)00R!R97%U97-T(&%N9"!R
M971U<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@5&AE(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I
M;F<@(%-T<FEN9R!S<&5C:69Y:6YG('=H870@:VEN9"!O9B!D871A('1O(')E
M='5R;BX@1&5F875L=',*("`@("`J("`@("`@("`@("`@("`@('1O(%-/05`@
M<F5Q=65S="X@4&]S<VEB;&4@;W1H97(@=F%L=65S.B`B=V1S;"(@86YD"B`@
M("`@*B`@("`@("`@("`@("`@("`B9&ES8V\B+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T
M:&4@<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D
M<F5Q=65S="P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]S97)V97(M/F%D9$]B:F5C=$UA<"@D=&AI<RP@)W5R;CIH;W)D92<I.PH*
M("`@("`@("!I9B`H(21P87)A;7,I('L*("`@("`@("`@("`@)'1H:7,M/E]S
M97)V97(M/G-E=$-A;&Q(86YD;&5R*&%R<F%Y*"1T:&ES+"`G7V1I<W!A=&-H
M97(G*2D["B`@("`@("`@("`@("\J(%=E(&-A;B=T('5S92!5=&EL.CIB=69F
M97)/=71P=70H*2!H97)E(&9O<B!S;VUE(')E87-O;BX@*B\*("`@("`@("`@
M("`@;V)?<W1A<G0H*3L*("`@("`@("`@("`@)'1H:7,M/E]S97)V97(M/G-E
M<G9I8V4H)')E<75E<W0I.PH@("`@("`@("`@("`D;W5T<'5T(#T@;V)?9V5T
M7V-O;G1E;G1S*"D["B`@("`@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4T]!4"]$
M:7-C;RYP:'`G.PH@("`@("`@("`@("`D9&ES8V\@/2!N97<@4T]!4%]$25-#
M3U]397)V97(H)'1H:7,M/E]S97)V97(L("=H;W)D92<I.PH@("`@("`@("`@
M("!I9B`H)'!A<F%M<R`]/2`G=W-D;"<I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V5T=7!$:7-P871C:$UA<"@I.PH@("`@("`@("`@("`@("`@)&]U
M='!U="`]("1D:7-C;RT^9V5T5U-$3"@I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&]U='!U="`]("1D:7-C;RT^9V5T1$E30T\H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O
M=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@86X@4T]!4"!R
M97%U97-T(&%N9"!S96YD<R!I="!T;R!T:&4@4T]!4"!S97)V97(N"B`@("`@
M*@H@("`@("H@5&AI<R!S=&%T:6-A;&QY(&-A;&QE9"!M971H;V0@:7,@86-T
M=6%L;'D@=&AE(%-/05`@8VQI96YT+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5R;"`@("`@5&AE('!A=&@@=&\@=&AE(%-/05`@<V5R=F5R(&]N
M('1H92!C86QL960@:&]S="X*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO
M9"`@5&AE(&UE=&AO9"!T;R!C86QL+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;F5C97-S87)Y('!A<F%M
M971E<G,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H92!M
M971H;V0@8V%L;"X*("`@("`J($!P87)A;2`D;W!T:6]N<R`@3W!T:6]N86P@
M87-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R<R!W:&EC:"!C86X@8F4Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@('5S97(@("`@("`@("`@("`@("`@
M+2!"87-I8R!!=71H('5S97)N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@
M('!A<W,@("`@("`@("`@("`@("`@+2!"87-I8R!!=71H('!A<W-W;W)D"B`@
M("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7VAO<W0@("`@("`@("`@+2!0
M<F]X>2!S97)V97(@:&]S=`H@("`@("H@("`@("`@("`@("`@("`@("!P<F]X
M>5]P;W)T("`@("`@("`@("T@4')O>'D@<V5R=F5R('!O<G0*("`@("`J("`@
M("`@("`@("`@("`@("`@<')O>'E?=7-E<B`@("`@("`@("`M(%!R;WAY(&%U
M=&@@=7-E<FYA;64*("`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?<&%S
M<R`@("`@("`@("`M(%!R;WAY(&%U=&@@<&%S<W=O<F0*("`@("`J("`@("`@
M("`@("`@("`@("`@=&EM96]U="`@("`@("`@("`@("`M($-O;FYE8W1I;VX@
M=&EM96]U="!I;B!S96-O;F1S+@H@("`@("H@("`@("`@("`@("`@("`@("!A
M;&QO=U)E9&ER96-T<R`@("`@("T@5VAE=&AE<B!T;R!F;VQL;W<@<F5D:7)E
M8W1S(&]R(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("!M87A2961I<F5C
M=',@("`@("`@("T@36%X(&YU;6)E<B!O9B!R961I<F5C=',@=&\@9F]L;&]W
M"B`@("`@*B`@("`@("`@("`@("`@("`@(&YA;65S<&%C90H@("`@("H@("`@
M("`@("`@("`@("`@("!S;V%P86-T:6]N"B`@("`@*B`@("`@("`@("`@("`@
M("`@(&9R;VT@("`@("`@("`@("`@("`@+2!33510+"!F<F]M(&%D9')E<W,*
M("`@("`J("`@("`@("`@("`@("`@("`@=')A;G-F97(M96YC;V1I;F<@("`M
M(%--5%`L('-E=',@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!#;VYT96YT+51R86YS9F5R+45N8V]D:6YG(&AE
M861E<@H@("`@("H@("`@("`@("`@("`@("`@("!S=6)J96-T("`@("`@("`@
M("`@("T@4TU44"P@<W5B:F5C="!H96%D97(*("`@("`J("`@("`@("`@("`@
M("`@("`@:&5A9&5R<R`@("`@("`@("`@("`M(%--5%`L(&%R<F%Y+6AA<V@@
M;V8@97AT<F$@<VUT<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:&5A9&5R<PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@("`@("`@("`@("!4:&4@<F5T=7)N960@<F5S=6QT(&9R;VT@=&AE
M(&UE=&AO9"!O<B!A(%!%05(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!E<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5Q=65S="@D=7)L+"`D;65T:&]D+"`D<&%R86US(#T@;G5L;"P@
M)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)W1I;65O=70G72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;
M)W1I;65O=70G72`](#4["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)V%L;&]W4F5D:7)E8W1S)UTI*2!["B`@("`@("`@("`@("1O
M<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@=')U93L*("`@("`@("`@("`@
M)&]P=&EO;G-;)VUA>%)E9&ER96-T<R==("`@/2`S.PH@("`@("`@('T*"B`@
M("`@("`@<F5Q=6ER95]O;F-E("=33T%0+T-L:65N="YP:'`G.PH@("`@("`@
M("1S;V%P(#T@)FYE=R!33T%07T-L:65N="@D=7)L+"!F86QS92P@9F%L<V4L
M("1O<'1I;VYS*3L*("`@("`@("!R971U<FX@)'-O87`M/F-A;&PH)&UE=&AO
M9"P@)'!A<F%M<RP@)&]P=&EO;G-;)VYA;65S<&%C92==*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]344PO````````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C$`,#$V-C4V`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U-13"]!='1R:6)U=&5S+G!H<```````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`S,#,R-0`Q,#4Q-30S,3`V,0`P,C$U,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M:7,@8VQA<W,@<')O=FED97,@871T<FEB=71E<R!M971H;V1S(&9O<B!A;GD@
M97AI<W1I;F<@4U%,(&-L87-S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3
M44PO4U%,+T%T=')I8G5T97,N<&AP+'8@,2XQ-"XQ,"XY(#(P,#8O,#$O,#$@
M,C$Z,C@Z,S,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D
M95]344P*("HO"F-L87-S($AO<F1E7U-13%]!='1R:6)U=&5S('L*"B`@("`O
M*BH*("`@("`J(%1H92!014%2.CI$0B!O8FIE8W0@=&\@<G5N('%U97)I97,@
M=VET:"X*("`@("`J"B`@("`@*B!`=F%R($1""B`@("`@*B\*("`@('9A<B`D
M7V1B.PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R<R!T;R!U<V4@=VAE;B!G
M96YE<F%T:6YG('%U97)I97,Z"B`@("`@*B`@(&ED7V-O;'5M;B`@("`@("`M
M(%1H92!P<FEM87)Y(&ED(&-O;'5M;B!T;R!U<V4@:6X@:F]I;G,N"B`@("`@
M*B`@('!R:6UA<GE?=&%B;&4@("`M(%1H92!M86EN('1A8FQE(&YA;64N"B`@
M("`@*B`@(&%T=')I8G5T95]T86)L92`M(%1H92!T86)L92!T:&%T('1H92!A
M='1R:6)U=&5S(&%R92!S=&]R960@:6XN"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!C;W!I97,@;V8@=&AE(&%T=')I
M8G5T97,@=&%B;&4@=&AA="!W92!N965D('1O(&IO:6X@;VX@:6X*("`@("`J
M('1H92!C=7)R96YT('%U97)Y+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]T86)L95]C;W5N="`](#$["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@1$(@
M)&1B:"`@("`@("`@02!014%2.CI$0B!O8FIE8W0N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@5&AE(&ED(&-O;'5M;BP@=&%B;&4@;F%M97,L(&5T
M8RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?4U%,7T%T=')I8G5T97,H
M)&1B:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7V1B(#T@)&1B
M:#L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!A='1R:6)U=&5S(&9O<B!A(&=I
M=F5N(&ED(&]R(&UU;'1I<&QE(&ED<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B!\(&%R<F%Y("1I9"`@5&AE(&ED('1O(&9E=&-H(&]R(&%N(&%R
M<F%Y(&]F(&ED<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA
M<V@@;V8@871T<FEB=71E<RP@;W(@82!M=6QT:2UL979E;"!H87-H"B`@("`@
M*B`@("`@("`@("`@("`@("!O9B!I9',@/3X@=&AE:7(@871T<FEB=71E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T071T<FEB=71E<R@D:60I"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G4T5,14-4("4Q)',L(&%T=')I8G5T95]N86UE(&%S
M(&YA;64L(&%T=')I8G5T95]K97D@87,@(FME>2(L(&%T=')I8G5T95]V86QU
M92!A<R!V86QU92!&4D]-("4R)',@5TA%4D4@)3$D<R!)3B`H)3,D<RDG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=I
M9%]C;VQU;6XG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG871T<FEB=71E7W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D:60I*3L*"B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@2&]R9&5?4U%,
M7T%T=')I8G5T97,Z.F=E=$%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("1R;W=S(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@1$)?1D540TA-
M3T1%7T%34T]#*3L*("`@("`@("`@("`@:68@*&ES7V$H)')O=W,L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F]W<SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&ED7V-O;'5M;B`]("1T:&ES+3Y?
M<&%R86US6R=I9%]C;VQU;6XG73L*("`@("`@("`@("`@)&1A=&$@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<F]W<R!A<R`D<F]W*2!["B`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)&1A=&%;)')O=ULD:61?8V]L=6UN
M75TI*2!["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)')O=ULD:61?8V]L
M=6UN75T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&1A=&%;)')O=ULD:61?8V]L=6UN75U;72`](&%R<F%Y*"=N86UE
M)R`@/3X@)')O=ULG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=K97DG("`@/3X@)')O=ULG:V5Y)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W9A;'5E)R`]/B`D<F]W6R=V86QU92==*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("4Q)',L(&%T=')I
M8G5T95]N86UE(&%S(&YA;64L(&%T=')I8G5T95]K97D@87,@(FME>2(L(&%T
M=')I8G5T95]V86QU92!A<R!V86QU92!&4D]-("4R)',@5TA%4D4@)3$D<R`]
M("4S)',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=I9%]C;VQU;6XG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG871T<FEB=71E7W1A8FQE)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD:60I.PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!
M='1R:6)U=&5S.CIG971!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@1$)?1D540TA-3T1%
M7T%34T]#*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@82!S970@;V8@:61S(&)A<V5D(&]N(&$@<V5T(&]F(&%T=')I8G5T92!C
M<FET97)I82X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-R:71E<FEA
M("!4:&4@87)R87D@;V8@8W)I=&5R:6$N($5X86UP;&4Z"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`D8W)I=&5R:6%;)T]2)UT@/2!A<G)A>2@*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEE;&0G(#T^("=N86UE)RP*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;W`G("`@(#T^("<])RP*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=&5S="<@(#T^("=F;V\G*2P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE
M)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;W`G("`@(#T^("<])RP*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5S="<@(#T^("=B87(G
M*2D["B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@5&AI<R!W;W5L
M9"!R971U<FX@86QL(&ED<R!F;W(@=VAI8V@@=&AE(&9I96QD"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@:7,@96ET
M:&5R("=F;V\G(&]R("=B87(G+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"
M>4%T=')I8G5T97,H)&-R:71E<FEA*0H@("`@>PH@("`@("`@(&EF("@A8V]U
M;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@("`@("!]"@H@("`@("`@("\J($)U:6QD('1H92!Q=65R>2X@*B\*("`@
M("`@("`D=&AI<RT^7W1A8FQE7V-O=6YT(#T@,3L*("`@("`@("`D<75E<GD@
M/2`G)SL*("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D
M=F%L<RD@>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G3U(G('Q\("1K97D@
M/3T@)T%.1"<I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'%U97)Y
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G("<@+B`D:V5Y
M("X@)R`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'%U
M97)Y("X]("<H)R`N("1T:&ES+3Y?8G5I;&1!='1R:6)U=&51=65R>2@D:V5Y
M+"`D=F%L<RD@+B`G*2<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J($)U:6QD('1H92!&4D]-+TI/24X@8VQA=7-E<RX@*B\*("`@("`@
M("`D:F]I;G,@/2!A<G)A>2@I.PH@("`@("`@("1P86ER<R`](&%R<F%Y*"D[
M"B`@("`@("`@9F]R("@D:2`](#$[("1I(#P]("1T:&ES+3Y?=&%B;&5?8V]U
M;G0[("1I*RLI('L*("`@("`@("`@("`@)&IO:6YS6UT@/2!S<')I;G1F*"=,
M1494($I/24X@)3$D<R!A)3(D<R!/3B!A)3(D<RXE,R1S(#T@;2XE,R1S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=A='1R:6)U=&5?=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)VED7V-O;'5M;B==*3L*"B`@("`@("`@("`@("1P86ER
M<UM=(#T@)T%.1"!A,2YA='1R:6)U=&5?;F%M92`](&$G("X@)&D@+B`G+F%T
M=')I8G5T95]N86UE)SL*("`@("`@("!]"B`@("`@("`@)&IO:6YS(#T@:6UP
M;&]D92@G("<L("1J;VEN<RD["B`@("`@("`@)'!A:7)S(#T@:6UP;&]D92@G
M("<L("1P86ER<RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#
M5"!$25-424Y#5"!A,2XE<R!&4D]-("5S(&T@)7,@5TA%4D4@)7,@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VED7V-O
M;'5M;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W!R:6UA<GE?=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("1J;VEN<RP*("`@("`@("`@("`@("`@("`@("`@("`@("1Q=65R>2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86ER<RD["@H@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@2&]R9&5?4U%,7T%T=')I8G5T
M97,Z.F=E=$)Y071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1VEV96X@82!N97<@871T<FEB=71E('-E="!A;F0@86X@:60L(&EN<V5R
M="!E86-H(&EN=&\@=&AE($1"+B!)9@H@("`@("H@86YY=&AI;F<@9F%I;',@
M:6X@:&5R92P@<F]L;&)A8VL@=&AE('1R86YS86-T:6]N+"!R971U<FX@=&AE
M(')E;&5V86YT"B`@("`@*B!E<G)O<B!A;F0@8F%I;"!O=70N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("`@("!4:&4@:60@;V8@=&AE
M(')E8V]R9"!F;W(@=VAI8V@@871T<FEB=71E<R!A<F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8F5I;F<@:6YS97)T960N"B`@("`@*B!`
M<&%R86T@87)R87D@)&%T=')I8G5T97,@($%N(&AA<V@@8V]N=&%I;FEN9R!T
M:&4@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YS97)T071T
M<FEB=71E<R@D:60L("1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@("1Q=65R
M>2`]("=)3E-%4E0@24Y43R`G("X@)'1H:7,M/E]P87)A;7-;)V%T=')I8G5T
M95]T86)L92==("X*("`@("`@("`@("`@("`@("`@("`@)R`H)R`N("1T:&ES
M+3Y?<&%R86US6R=I9%]C;VQU;6XG72`N("<L(&%T=')I8G5T95]N86UE+"<@
M+@H@("`@("`@("`@("`@("`@("`@("`G(&%T=')I8G5T95]K97DL(&%T=')I
M8G5T95]V86QU92D@5D%,5453("@_+"`_+"`_+"`_*2<["B`@("`@("`@("`@
M("1V86QU97,@/2!A<G)A>2@H:6YT*21I9"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A='1R6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D871T<ELG:V5Y)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D871T<ELG=F%L=64G72D["@H@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S.CII
M;G-E<G1!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&(M/G)O;&QB86-K*"D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YA=71O0V]M;6ET*'1R=64I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\J($-O;6UI="!T:&4@=')A;G-A8W1I;VXL(&%N9"!T=7)N
M(&%U=&]C;VUM:70@8F%C:R!O;BX@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]D8BT^8V]M;6ET*"D["B`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O
M;6UI="AT<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&%N(&ED
M+"!D96QE=&4@86QL(&%T=')I8G5T97,@9F]R('1H870@:60@9G)O;2!T:&4*
M("`@("`J(&%T=')I8G5T97,@=&%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&ED("!4:&4@:60@;V8@=&AE(')E8V]R9"!F;W(@=VAI8V@@
M871T<FEB=71E<R!A<F4@8F5I;F<*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@9&5L971E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E071T<FEB
M=71E<R@D:60I"B`@("!["B`@("`@("`@+RH@1&5L971E(&%T=')I8G5T97,N
M("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@
M5TA%4D4@)7,@/2`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG871T<FEB=71E7W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:61?8V]L=6UN)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`H:6YT*21I9"D["@H@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@2&]R9&5?4U%,7T%T=')I8G5T
M97,Z.F1E;&5T94%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:60L('5P9&%T92!A;&P@871T
M<FEB=71E<R!F;W(@=&AA="!I9"!I;B!T:&4@871T<FEB=71E<R!T86)L90H@
M("`@("H@=VET:"!T:&4@;F5W(&%T=')I8G5T97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&ED("`@("`@("!4:&4@:60@;V8@=&AE(')E8V]R
M9"!F;W(@=VAI8V@@871T<FEB=71E<R!A<F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F5I;F<@9&5L971E9"X*("`@("`J($!P87)A;2!A
M<G)A>2`D871T<FEB=71E<R`@06X@:&%S:"!C;VYT86EN:6YG('1H92!A='1R
M:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5!='1R:6)U=&5S
M*"1I9"P@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@+RH@1&5L971E('1H
M92!O;&0@871T<FEB=71E<RX@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/F1E;&5T94%T=')I8G5T97,H)&ED*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@26YS97)T('1H92!N97<@871T
M<FEB=71E('-E="X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/FEN<V5R
M=$%T=')I8G5T97,H)&ED+"`D871T<FEB=71E<RD["B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!A('!I96-E
M(&]F(&%N(&%T=')I8G5T92!Q=65R>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1G;'5E("`@("!4:&4@9VQU92!T;R!J;VEN('1H92!C<FET97)I
M82`H3U(O04Y$*2X*("`@("`J($!P87)A;2!A<G)A>2`D8W)I=&5R:6$@(%1H
M92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J($!P87)A;2!B;V]L96%N("1J
M;VEN("`@(%-H;W5L9"!W92!J;VEN(&]N(&$@8VQE86X@871T<FEB=71E<R!T
M86)L93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@06X@4U%,(&9R
M86=M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&1!='1R:6)U=&51
M=65R>2@D9VQU92P@)&-R:71E<FEA+"`D:F]I;B`](&9A;'-E*0H@("`@>PH@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4U%,+G!H<"<["@H@("`@("`@
M("\J($EN:71I86QI>F4@=&AE(&-L875S92!T:&%T('=E)W)E(&)U:6QD:6YG
M+B`J+PH@("`@("`@("1C;&%U<V4@/2`G)SL*"B`@("`@("`@+RH@1V5T('1H
M92!T86)L92!A;&EA<R!T;R!U<V4@9F]R('1H:7,@<V5T(&]F(&-R:71E<FEA
M+B`J+PH@("`@("`@(&EF("@D:F]I;BD@>PH@("`@("`@("`@("`D86QI87,@
M/2`D=&AI<RT^7V=E=$%L:6%S*'1R=64I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A;&EA<R`]("1T:&ES+3Y?9V5T06QI87,H*3L*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1C<FET97)I82!A<R`D:V5Y(#T^("1V
M86QS*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'9A;'-;)T]2)UTI('Q\
M("%E;7!T>2@D=F%L<ULG04Y$)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`@("`@)&-L875S
M92`N/2`G("<@+B`D9VQU92`N("<@)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1C;&%U<V4@+CT@)R@G("X@)'1H:7,M/E]B=6EL9$%T
M=')I8G5T95%U97)Y*"1G;'5E+"`D=F%L<RD@+B`G*2<["B`@("`@("`@("`@
M('T@96QS96EF("@A96UP='DH)'9A;'-;)TI/24XG72DI('L*("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)&-L875S92DI('L*("`@("`@("`@("`@("`@
M("`@("`D8VQA=7-E("X]("<@)R`N("1G;'5E("X@)R`G.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&-L875S92`N/2`D=&AI<RT^7V)U
M:6QD071T<FEB=71E475E<GDH)&=L=64L("1V86QS6R=*3TE.)UTL('1R=64I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1V86QS6R=F:65L9"==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&-L875S92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-L875S92`N/2`G("<@+B`D9VQU92`N("<@)SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&-L875S92`N/2!(;W)D95]3
M44PZ.F)U:6QD0VQA=7-E*"1T:&ES+3Y?9&(L("1A;&EA<R`N("<N871T<FEB
M=71E7R<@+B`D=F%L<ULG9FEE;&0G72P@)'9A;'-;)V]P)UTL("1V86QS6R=T
M97-T)UTI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=F%L<R!A<R`D=&5S="D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8VQA=7-E("X]("<@)R`N("1K97D@+B`G
M("<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-L875S92`N/2!(;W)D95]344PZ.F)U:6QD0VQA=7-E*"1T
M:&ES+3Y?9&(L("1A;&EA<R`N("<N871T<FEB=71E7R<@+B`D=&5S=%LG9FEE
M;&0G72P@)'1E<W1;)V]P)UTL("1T97-T6R=T97-T)UTI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;&%U<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@86X@86QI87,@=&\@86X@871T<FEB=71E<R!T86)L
M92P@:6YC<F5M96YT:6YG(&ET(&EF"B`@("`@*B!N96-E<W-A<GDN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN8W)E;65N="`@26YC<F5M96YT
M('1H92!A;&EA<R!C;W5N=#\@1&5F875L=',@=&\@9F%L<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971!;&EA<R@D:6YC<F5M96YT(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@<W1A=&EC("1S965N("`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("@D:6YC<F5M96YT("8F("%E;7!T>2@D<V5E;ELD=&AI<RT^7W1A8FQE
M7V-O=6YT72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T86)L95]C;W5N="LK
M.PH@("`@("`@('T*"B`@("`@("`@)'-E96Y;)'1H:7,M/E]T86)L95]C;W5N
M=%T@/2!T<G5E.PH@("`@("`@(')E='5R;B`G82<@+B`D=&AI<RT^7W1A8FQE
M7V-O=6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@4U%,($%T=')I8G5T97,*
M("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N('!A<F%M971E<G,@<&%S<V5D+B!)
M="!W:6QL(&]N;'D@8W)E871E(&$@;F5W"B`@("`@*B!I;G-T86YC92!I9B!N
M;R!!='1R:6)U=&5S(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R
M<PH@("`@("H@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES
M('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(%-13"!A='1R:6)U=&4@=&%B
M;&5S(&%R90H@("`@("H@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T*("`@("`J("9(;W)D
M95]344Q?071T<FEB=71E<SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`
M<&%R86T@1$(@)&1B:"`@("`@("`@06X@;V)J96-T('!O:6YT:6YG('1O(&$@
M4U%,(&1A=&%B87-E(&AA;F1L92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@4&%R86UE=&5R<R!F;W(@=&AE(&%T=')I8G5T97,@=&%B
M;&4L(&-O;G-I<W1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O
M9B!T:&4@9F]L;&]W:6YG(&ME>7,Z"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@)W!R:6UA<GE?=&%B;&4G("`@+2!T:&4@;6%I;B!344P@=&%B;&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E7W1A8FQE
M)R`M('1H92!S96-O;F0@=&%B;&4@8V]N=&%I;FEN9PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&%T=')I
M8G5T97,@=&\@=&AE(&UA:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1A8FQE+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("=I9%]C;VQU;6XG("`@("`@("T@=&AE(&YA;64@;V8@
M=&AE(&-O;'5M;B!W:71H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@240@;W(@:V5Y(&9I96QD+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D8F@L("1P87)A;7,I"B`@
M("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@(&EF("@A
M:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`]
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R
M:6%L:7IE*"1P87)A;7,I.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72`]("9N97<@2&]R9&5?4U%,7T%T=')I8G5T97,H)&1B:"P@)'!A
M<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD
M<VEG;F%T=7)E73L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]344PO
M2V5Y=V]R9',N<&AP````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,30U,S(`,3`U,34T,S$P-C$`,#(Q,C`P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&-L87-S
M('!R;W9I9&5S(&$@<&%R<V5R('=H:6-H(&-A;B!C;VYS=')U8W0@86X@4U%,
M(%=(15)%"B`J(&-L875S92!F<F]M(&$@1V]O9VQE+6QI:V4@<V5A<F-H(&5X
M<')E<W-I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP+'8@,2XR+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HS,R!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#
M(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@5&AE(&5X<')E<W-I;VX@<F5C;V=N:7IE<R!B;V]L96%N(")!3D0B+"`B
M3U(B+"!A;F0@(DY/5"(@*'!R;W9I9&EN9PH@*B!N;R!O<&5R871O<B!B971W
M965N(&ME>7=O<F1S(&EM<&QI97,@(D%.1"(I+"!L:6ME('-O.@H@*@H@*B`@
M(&-A="!A;F0@9&]G"B`J("`@8V%T(&]R(&1O9PH@*B`@(&-A="!A;F0@;F]T
M(&1O9PH@*@H@*B!)9B!N;R!O<&5R871O<B!A<'!E87)S(&)E='=E96X@:V5Y
M=V]R9',@;W(@<75O=&5D('-T<FEN9W,L(")!3D0B(&ES"B`J(&%S<W5M960N
M("!!(&-O;6UA(&-A;B!B92!U<V5D(&EN<W1E860@;V8@(D]2(CH*("H*("H@
M("!C870@9&]G"B`J("`@8V%T+"!D;V<*("H@("!C870@;F]T(&1O9PH@*@H@
M*B!4:&4@<&%R<V5R(')E8V]G;FEZ97,@<&%R96YT:&5S97,L('-O(&-O;7!L
M97@@97AP<F5S<VEO;G,@8V%N(&)E"B`J(&-R96%T960Z"B`J"B`J("`@8V%T
M(&%N9"!N;W0@*&1O9R!O<B!P=7!P>2D*("H*("H@475O=&5D('-T<FEN9W,@
M87)E(&%L<V\@<F5C;V=N:7IE9"P@86YD(&%R92!T86ME;B!A<R!L:71E<F%L
M"B`J(&ME>7=O<F1S.@H@*@H@*B`@(")C870@86YD(&1O9R(*("H*("H@4&%R
M<VEN9R!I<R!D97-I9VYE9"!T;R!B92!A<R!F=7IZ>2!A<R!P;W-S:6)L92P@
M<V\@:70@<VAO=6QD;B=T"B`J(&5R<F]R('5N;&5S<R!P96]P;&4@<V5A<F-H
M(&9O<B`B04Y$(BP@(D]2(BP@;W(@(DY/5"(@=VET:&]U=`H@*B!Q=6]T:6YG
M(&ET(&]R('5S92!U;F)A;&%N8V5D('!A<F5N=&AE<V5S+@H@*@H@*B!`875T
M:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4U%,"B`J
M+PIC;&%S<R!(;W)D95]344Q?2V5Y=V]R9',@>PH*("`@("\J*@H@("`@("H@
M4&%R<V4@82!K97EW;W)D(&5X<')E<W-I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]L=6UN("`@("`@("!4:&ES(&ES('1H92!344P@9FEE
M;&0@;F%M92!T:&4@<F5S=6QT:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5X<')E<W-I;VX@<VAO=6QD('1E<W0@86=A:6YS="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&5X<'(@("`@("`@("`@5&AI<R!I<R!T
M:&4@:V5Y=V]R9"!E>'!R97-S:6]N('=E('=A;G0@=&\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<&%R<V4N"B`@("`@*B!`<F5T=7)N
M(&UI>&5D('1H92!Q=65R>2!E>'!R97-S:6]N(&]R(&$@4$5!4E]%<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S92@D8V]L=6UN
M+"`D97AP<BD*("`@('L*("`@("`@("`O*B!&:7)S="!P87-S("T@<V-A;B!T
M:&4@<W1R:6YG(&9O<B!T;VME;G,N("!"87)E('=O<F1S(&%R90H@("`@("`@
M("`J('1O:V5N<RP@;W(@=&AE('5S97(@8V%N('%U;W1E('-T<FEN9W,@=&\@
M:&%V92!E;6)E9&1E9`H@("`@("`@("`J('-P86-E<RP@:V5Y=V]R9',L(&]R
M('!A<F5N=&AE<V5S+B`@4&%R96YT:&5S97,@8V%N(&)E('5S960*("`@("`@
M("`@*B!F;W(@9W)O=7!I;F<@8F]O;&5A;B!O<&5R871O<G,L(&%N9"!T:&4@
M8F]O;&5A;B!O<&5R871O<G,*("`@("`@("`@*B!!3D0L($]2+"!A;F0@3D]4
M(&%R92!A;&P@<F5C;V=N:7IE9"X*("`@("`@("`@*@H@("`@("`@("`J(%1H
M92!T;VME;G,@87)E(')E='5R;F5D(&EN('1H92`D=&]K96YS(&%R<F%Y("TM
M(&%N(&%R<F%Y(&]F"B`@("`@("`@("H@<W1R:6YG<RX@($5A8V@@<W1R:6YG
M(&EN('1H92!A<G)A>2!S=&%R=',@=VET:"!E:71H97(@82!@(2<*("`@("`@
M("`@*B!O<B!A(&`])RX@(&`])R!I<R!A(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<W1R:6YG('=E(&%R90H@("`@("`@("`J('-E87)C:&EN9R!F;W(L(&%N9"!@
M(2<@:6YD:6-A=&5S(&$@8F]O;&5A;B!O<&5R871O<B!O<@H@("`@("`@("`J
M('!A<F5N=&AE<VES+B`@02!T;VME;B!T:&%T('-T87)T<R!W:71H(&$@)RXG
M("!I;F1I8V%T97,@80H@("`@("`@("`J(%!O<W1G<F5344P@=V]R9"!B;W5N
M9&%R>2!S96%R8V@N("HO"B`@("`@("`@)'1O:V5N<R`](&%R<F%Y*"D["B`@
M("`@("`@=VAI;&4@*"%E;7!T>2@D97AP<BDI('L*("`@("`@("`@("`@)&5X
M<'(@/2!P<F5G7W)E<&QA8V4H(B]>7',K+R(L("(B+"`D97AP<BD["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D97AP<BDI('L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=6)S='(H)&5X
M<'(L,"PQ*2`]/2`G*"<I('L*("`@("`@("`@("`@("`@("1E>'!R(#T@<W5B
M<W1R*"1E>'!R+"`Q*3L*("`@("`@("`@("`@("`@("1T;VME;B`]("<A*"<[
M"B`@("`@("`@("`@('T@96QS96EF("AS=6)S='(H)&5X<'(L(#`L(#$I(#T]
M("<I)RD@>PH@("`@("`@("`@("`@("`@)&5X<'(@/2!S=6)S='(H)&5X<'(L
M(#$I.PH@("`@("`@("`@("`@("`@)'1O:V5N(#T@)R$I)SL*("`@("`@("`@
M("`@?2!E;'-E:68@*'-U8G-T<B@D97AP<BP@,"P@,2D@/3T@)RPG*2!["B`@
M("`@("`@("`@("`@("`D97AP<B`]('-U8G-T<B@D97AP<BP@,2D["B`@("`@
M("`@("`@("`@("`D=&]K96X@/2`G(4]2)SL*("`@("`@("`@("`@?2!E;'-E
M:68@*'!R96=?;6%T8V@H(B]>*$%.1'Q/4GQ.3U0I*%M>82UZ72XJ*3\D+VDB
M+"`D97AP<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@("`@("`D=&]K96X@/2`G(2<@+B!S=')T
M;W5P<&5R*"1M871C:&5S6S%=*3L*("`@("`@("`@("`@("`@("1E>'!R(#T@
M<W5B<W1R*"1E>'!R+"!S=')L96XH)&UA=&-H97-;,5TI*3L*("`@("`@("`@
M("`@?2!E;'-E:68@*'!R96=?;6%T8V@H(B]>7"(H*%M>7")=?%Q<6S`M-UTK
M?%Q<6UAX75LP+3EA+69!+49=*WQ<7%M>6'@P+3==*2HI7"(O(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X<'(L("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`@("`@)'1O:V5N(#T@)STG("X@<W1R:7!C<VQA<VAE
M<R@D;6%T8VAE<ULQ72D["B`@("`@("`@("`@("`@("`D97AP<B`]('-U8G-T
M<B@D97AP<BP@<W1R;&5N*"1M871C:&5S6S!=*2D["B`@("`@("`@("`@('T@
M96QS96EF("AP<F5G7VUA=&-H*"(O7EM>7%QS7%PH7%PI+%TK+R(L("1E>'!R
M+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1T;VME;B`]("<])R`N
M("1M871C:&5S6S!=.PH@("`@("`@("`@("`@("`@)&5X<'(@/2!S=6)S='(H
M)&5X<'(L<W1R;&5N*"1T;VME;BDM,2D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(BDI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@D=&]K96X@/3T@)R%!3D0G*2!["B`@("`@("`@
M("`@("`@("`O*B`A04Y$(&ES(&EM<&QI960@8GD@8V]N8V%T96YA=&EO;BX@
M*B\*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T;VME;G-;72`]("1T;VME;CL*("`@("`@("!]"@H@("`@
M("`@("\J($-A;&P@=&AE(&5X<')E<W-I;VX@<&%R<V5R+B`J+PH@("`@("`@
M(')E='5R;B!(;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S,2@D
M8V]L=6UN+"`D=&]K96YS*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R<V5+
M97EW;W)D<S$H)&-O;'5M;BP@)B1T;VME;G,I"B`@("!["B`@("`@("`@:68@
M*&-O=6YT*"1T;VME;G,I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B16UP='D@<V5A<F-H('1E<FUS(BDI.PH@("`@
M("`@('T*("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?<&%R
M<V5+97EW;W)D<S(H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@:68@*&ES
M7V$H)&QH<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&QH<SL*("`@("`@("!]"B`@("`@("`@:68@*&-O=6YT*"1T;VME;G,I(#T]
M(#`@?'P@)'1O:V5N<ULP72`A/2`G(4]2)RD@>PH@("`@("`@("`@("!R971U
M<FX@)&QH<SL*("`@("`@("!]"B`@("`@("`@87)R87E?<VAI9G0H)'1O:V5N
M<RD["B`@("`@("`@)')H<R`]($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A<G-E
M2V5Y=V]R9',Q*"1C;VQU;6XL("1T;VME;G,I.PH@("`@("`@(&EF("AI<U]A
M*"1R:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M:',["B`@("`@("`@?0H@("`@("`@(')E='5R;B`B*"`D;&AS($]2("1R:',@
M*2(["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<G-E2V5Y=V]R9',R*"1C;VQU
M;6XL("8D=&]K96YS*0H@("`@>PH@("`@("`@("1L:',@/2!(;W)D95]344Q?
M2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S,R@D8V]L=6UN+"`D=&]K96YS*3L*
M("`@("`@("!I9B`H:7-?82@D;&AS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D;&AS.PH@("`@("`@('T*("`@("`@("!I9B`H<VEZ
M96]F*"1T;VME;G,I(#T](#`@?'P@)'1O:V5N<ULP72`]/2`G(2DG('Q\("1T
M;VME;G-;,%T@/3T@)R%/4B<I('L*("`@("`@("`@("`@<F5T=7)N("1L:',[
M"B`@("`@("`@?0H@("`@("`@("1R:',@/2!(;W)D95]344Q?2V5Y=V]R9',Z
M.E]P87)S94ME>7=O<F1S,B@D8V]L=6UN+"`D=&]K96YS*3L*("`@("`@("!I
M9B`H:7-?82@D<FAS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<FAS.PH@("`@("`@('T*("`@("`@("!R971U<FX@(B@@)&QH<R!!
M3D0@)')H<R`I(CL*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R<V5+97EW;W)D
M<S,H)&-O;'5M;BP@)B1T;VME;G,I"B`@("!["B`@("`@("`@:68@*"1T;VME
M;G-;,%T@/3T@)R%.3U0G*2!["B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T
M;VME;G,I.PH@("`@("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O<F1S
M.CI?<&%R<V5+97EW;W)D<S0H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@
M("`@(&EF("AI<U]A*"1L:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D;&AS.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B`B*"!.3U0@)&QH<R`I(CL*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A<G-E2V5Y=V]R9',T*"1C;VQU
M;6XL("1T;VME;G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P87)S94ME>7=O
M<F1S-"@D8V]L=6UN+"`F)'1O:V5N<RD*("`@('L*("`@("`@("!I9B`H("1T
M;VME;G-;,%T@/3T@)R$H)R`I('L*("`@("`@("`@("`@87)R87E?<VAI9G0H
M)'1O:V5N<RD["B`@("`@("`@("`@("1L:',@/2!(;W)D95]344Q?2V5Y=V]R
M9',Z.E]P87)S94ME>7=O<F1S,2@D8V]L=6UN+"`D=&]K96YS*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)&QH<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1L:',["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*'-I>F5O9B@D=&]K96YS*2`]/2`P('Q\("1T;VME;G-;,%T@(3T@
M)R$I)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B17AP96-T960@)RDG(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&%R<F%Y7W-H:69T*"1T;VME;G,I.PH@("`@("`@("`@("!R971U<FX@
M)&QH<SL*("`@("`@("!]"B`@("`@("`@:68@*'-U8G-T<B@D=&]K96YS6S!=
M+"`P+"`Q*2`A/2`G/2<@)B8*("`@("`@("`@("`@<W5B<W1R*"1T;VME;G-;
M,%TL(#`L(#(I("$]("<]+B<I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;2(I*3L*("`@("`@("!]"B`@("`@("`@)'9A;"`]('-T<G1O
M;&]W97(H<W5B<W1R*&%R<F%Y7W-H:69T*"1T;VME;G,I+"`Q*2D["B`@("`@
M("`@)'9A;"`](&%D9'-L87-H97,H97)E9U]R97!L86-E*"(H6UQ<)5TI(BP@
M(EQ<7%PQ(BP@)'9A;"DI.PH@("`@("`@(')E='5R;B`B*"!,3U=%4B@D8V]L
M=6UN*2!,24M%("<E)'9A;"4G("DB.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O0G)O=W-E<B\`````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-S8T,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]"<F]W<V5R+VEM;V1E+G!H<```
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S$P-S(`,3`U,34T,S$P
M-C$`,#(Q-#4P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@0G)O=W-E<E]I;6]D93HZ(&-L87-S
M(&5X=&5N9',@=&AE($)R;W=S97(@05!)(&)Y('!R;W9I9&EN9PH@*B!S<&5C
M:69I8R!I;F9O<FUA=&EO;B!A8F]U="!);6]D92!H86YD<V5T<RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+VEM;V1E+G!H<"QV
M(#$N-RXQ,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z,#D@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`P+3(P,#8@36EK82!4=75P;VQA"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T)R;W=S97(*("HO"F-L87-S($)R;W=S97)?:6UO9&4@
M>PH*("`@("\J*@H@("`@("H@1&5V:6-E(&1A=&$N($9R;VT@:'1T<#HO+W=W
M=RYN='1D;V-O;6\N8V\N:G`O:2]T86<O<S4N:'1M;",U7S$*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V1A=&$@/2!A<G)A
M>2@*("`@("`@("`G1#(P.6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA
M9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@.3`L"B`@("`@("`@
M("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@
M("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1C(P
M.6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L
M("=I;6%G96AE:6=H="<@/3X@.3$L"B`@("`@("`@("`@("=T97AT=VED=&@G
M(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G
M(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH
M)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G3C(P.6DG(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3`X+"`G:6UA9V5H96EG:'0G
M(#T^(#@R+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Y+"`G=&5X=&AE
M:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@
M("`@("DL"B`@("`@("`@)U`R,#EI)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#@W+`H@("`@
M("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*
M("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)U`R,#EI<R<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H
M)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`X-RP*("`@("`@("`@("`@)W1E
M>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@
M("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]
M/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=2,C`Y:2<@/3X@
M87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E
M:&5I9VAT)R`]/B`W,BP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@
M)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R
M97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF
M)RD*("`@("`@("`I+`H@("`@("`@("=%4C(P.6DG(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^
M(#<R+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG
M:'0G(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I+`H@("`@("`@("=+3S(P.6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@.38L"B`@("`@
M("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`X+`H@
M("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E
M9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G
M1#(Q,&DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@
M.38L("=I;6%G96AE:6=H="<@/3X@.3$L"B`@("`@("`@("`@("=T97AT=VED
M=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L
M;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R
M87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1C(Q,&DG(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H
M="<@/3X@,3$S+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X
M=&AE:6=H="<@/3X@."P*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@
M("`@("DL"B`@("`@("`@)TXR,3!I)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]/B`Q,3,L"B`@
M("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@
M."P*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)U`R,3!I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DQ+`H@("`@("`@("`@("`G=&5X
M='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@
M)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^
M(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)TM/,C$P:2<@/3X@
M87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E
M:&5I9VAT)R`]/B`Y-BP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@
M)W1E>'1H96EG:'0G(#T^(#@L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V
M+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*
M("`@("`@("`I+`H@("`@("`@("=33S(Q,&DG(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^(#$Q
M,RP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G
M(#T^(#<L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@
M("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@
M("`@("`@("=$-3`Q:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I
M9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`W,BP*("`@("`@("`@("`@
M)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@
M("`@("=C;VQO<B<@/3X@)V)L86-K)RP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1C4P
M,6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$R
M+"`G:6UA9V5H96EG:'0G(#T^(#@T+`H@("`@("`@("`@("`G=&5X='=I9'1H
M)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R
M)R`]/B`G8FQA8VLG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A
M<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=.-3`Q:2<@/3X@87)R
M87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3@L("=I;6%G96AE
M:6=H="<@/3X@,3(X+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@
M)W1E>'1H96EG:'0G(#T^,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V)L
M86-K)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I
M9B<I"B`@("`@("`@*2P*("`@("`@("`G4#4P,6DG(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@
M,3(P+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H
M="<@/3X@."P*("`@("`@("`@("`@)V-O;&]R)R`]/B`G8FQA8VLG+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I+`H@("`@("`@("=$-3`R:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y,"P*("`@("`@
M("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@
M("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F
M;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=&
M-3`R:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y
M-BP@)VEM86=E:&5I9VAT)R`]/B`Y,2P*("`@("`@("`@("`@)W1E>'1W:61T
M:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C;VQO
M<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A
M>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=&-3`R:70G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H
M="<@/3X@.3$L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT
M:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@
M("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@
M("`@*2P*("`@("`@("`G3C4P,FDG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M:6UA9V5W:61T:"<@/3X@,3$X+"`G:6UA9V5H96EG:'0G(#T^(#$R."P*("`@
M("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]/B`Q
M,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@("`@("`@
M("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@
M("`@("`@)TXU,#)I="<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I
M9'1H)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@,3(X+`H@("`@("`@("`@
M("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@
M("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4#4P
M,FDG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L
M("=I;6%G96AE:6=H=&@G(#T^(#$Q-RP*("`@("`@("`@("`@)W1E>'1W:61T
M:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#@L"B`@("`@("`@("`@("=C;VQO
M<B<@/3X@)V=R97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A
M<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=.334P,FDG(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$Q+"`G:6UA9V5H
M96EG:'0G(#T^(#<W+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G
M=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`G8FQA
M8VLG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF
M)RD*("`@("`@("`I+`H@("`@("`@("=33S4P,FDG(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^
M(#$R,"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG
M:'0G(#T^(#@L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I+`H@("`@("`@("=33S4P,FEW;2<@/3X@87)R87DH"B`@("`@("`@("`@
M("=I;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@/3X@,3$S+`H@
M("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@
M-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)T8U,#-I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,S`L"B`@("`@("`@("`@("=T
M97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@("`@
M("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S
M)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=&-3`S:5,G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G
M:6UA9V5H96EG:'0G(#T^(#$S,"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@
M/3X@,3(L("=T97AT:&5I9VAT)R`]/B`Q,BP*("`@("`@("`@("`@)V-O;&]R
M)R`]/B`T,#DV+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A
M>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0-3`S:2<@/3X@87)R87DH
M"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H
M="<@/3X@,3,P+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,BP@)W1E
M>'1H96EG:'0G(#T^(#$P+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*
M("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@
M("`@("`@*2P*("`@("`@("`G4#4P,VE3)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,S`L
M"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$R+"`G=&5X=&AE:6=H="<@
M/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@
M("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@
M("`@("`@("=33S4P,VDG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W
M:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^(#$Q,RP*("`@("`@("`@
M("`@)W1E>'1W:61T:"<@/3X@."XU+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@
M("`@("`@("`@)V-O;&]R)R`]/B`V-34S-BP*("`@("`@("`@("`@)VEM86=E
M9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G
M1#4P,VDG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@
M,3,R+"`G:6UA9V5H96EG:'0G(#T^(#$R-BP*("`@("`@("`@("`@)W1E>'1W
M:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C
M;VQO<B<@/3X@-#`Y-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G3C4P,VDG(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$X+"`G:6UA9V5H
M96EG:'0G(#T^(#$R."P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L
M("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`T
M,#DV+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF
M)RP@)VIP9R<I"B`@("`@("`@*2P*("`@("`@("`G3C4P,VE3)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I
M9VAT)R`]/B`Q,C@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G
M=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@-#`Y
M-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<L
M("=J<&<G*0H@("`@("`@("DL"B`@("`@("`@)TXV.3%I)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G
M(#T^(#<R+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE
M:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@
M("`@("DL"B`@("`@("`@)U-(.#(Q:2<@/3X@87)R87DH"B`@("`@("`@("`@
M("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`W."P*("`@
M("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L
M"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA
M9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@
M("=..#(Q:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]
M/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@,3(X+`H@("`@("`@("`@("`G=&5X
M='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@("`@("`@
M("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T
M<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4#@R,6DG
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$X+"`G
M:6UA9V5H96EG:'0G(#T^(#$R."P*("`@("`@("`@("`@)W1E>'1W:61T:"<@
M/3X@,3`L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R
M)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R
M<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)W-A9F4G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.30L("=I;6%G96AE:6=H
M="<@/3X@-S(L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT
M:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=B;&%C:R<L
M"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@
M("`@("`@("D*("`@("D["@H@("`@=F%R("1?;6%N=69A8W1U<F5R;&ES="`]
M(&%R<F%Y*`H@("`@("`@("=$)R`]/B`G36ET<W5B:7-H:2<L"B`@("`@("`@
M)U`G(#T^("=086YA<V]N:6,@*$UA='-U<VAI=&$I)RP*("`@("`@("`G3DTG
M(#T^("=.;VMI82<L"B`@("`@("`@)U-/)R`]/B`G4V]N>2<L"B`@("`@("`@
M)T8G(#T^("=&=6II='-U)RP*("`@("`@("`G3B<@/3X@)TYE8R<L"B`@("`@
M("`@)U-()R`]/B`G4VAA<G`G+`H@("`@("`@("=%4B<@/3X@)T5R:6-S<V]N
M)RP*("`@("`@("`G4B<@/3X@)TIA<&%N(%)A9&EO)RP*("`@("`@("`G2T\G
M(#T^("=+;VMU<V%I("A(:71A8VAI*2<*("`@("D["@H@("`@=F%R("1?97AT
M<F$@/2!A<G)A>2@*("`@("`@("`G="<@/3X@)U1R86YS<&]R="!L87EE<B<L
M"B`@("`@("`@)V4G(#T^("=%;F=L:7-H(&QA;F=U86=E)RP*("`@("`@("`G
M<R<@/3X@)U-E8V]N9"!V97)S:6]N)PH@("`@*3L*"B`@("!V87(@)%]U<V5R
M7V%G96YT.PH@("`@=F%R("1?;6]D96P["B`@("!V87(@)%]M86YU9F%C='5R
M97(["B`@("!V87(@)%]H='1P=F5R<VEO;CL*("`@('9A<B`D7V-A8VAE(#T@
M-3L*"B`@("`O*BH*("`@("`J($1O97,@;F]T(&AA;F1L92!B;V=U<R!U<V5R
M7V%G96YT<R!O<B!M;W-T(&]F('1H92!O=&AE<B!E<G)O<@H@("`@("H@<VET
M=6%T:6]N('!R;W!E<FQY('EE="X*("`@("`J"B`@("`@*B!%>&%M<&QE('5S
M86=E.@H@("`@("H@("`D=6$@/2`F;F5W($)R;W=S97)?:6UO9&4H)%]315)6
M17);)TA45%!?55-%4E]!1T5.5"==*3L*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I;G!U="`@5&AE('5S97(@86=E;G0@=&\@;6%T8V@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($)R;W=S97)?:6UO9&4H)&EN<'5T*0H@("`@>PH@
M("`@("`@("1?97)R;W(@/2`P.PH@("`@("`@("1T96UP(#T@97AP;&]D92@G
M+R<L("1I;G!U="D["@H@("`@("`@("1T:&ES+3Y?=7-E<E]A9V5N="`]("1I
M;G!U=#L*("`@("`@("`D=&AI<RT^7VAT='!V97)S:6]N(#T@)'1E;7!;,5T[
M"B`@("`@("`@)'1H:7,M/E]M;V1E;"`]("1T96UP6S)=.PH@("`@("`@(&EF
M("@D=&5M<%LS72D@>PH@("`@("`@("`@("`D=&AI<RT^7V-A8VAE(#T@<W5B
M<W1R*"1T96UP6S-=+"`Q*3L*("`@("`@("!]"@H@("`@("`@('!R96=?;6%T
M8V@H)R\H7EMA+7I!+5I=*RDH6S`M.5TK:2DH+BHI7"\_*"XJ*2\G+"`D=&AI
M<RT^7VUO9&5L+"`D;6%T8VAE<RD["@H@("`@("`@("\O($!43T1/.B!&:7@@
M<VET=6%T:6]N(&]F('5N:VYO=VX@;6%N=69A8W1U<F5R+B!);7!L96UE;G0*
M("`@("`@("`O+R!E>'1R86EN9F\@<')O<&5R;'DN"B`@("`@("`@)'1H:7,M
M/E]M86YU9F%C='5R97(@/2`D=&AI<RT^7VUA;G5F86-T=7)E<FQI<W1;)&UA
M=&-H97-;,5U=.PH@("`@("`@("1T:&ES+3Y?97AT<F$@/2`D;6%T8VAE<ULS
M73L*"B`@("`@("`@:68@*"$H)'1H:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=
M*2D@>PH@("`@("`@("`@("`D7V5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M56YK;F]W;B!5<V5R($%G96YT)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@17AA;7!L92!U<V%G93H*("`@("`J("`D:6UA9V5D:6T@("`@
M/2`D=6$M/F=E=$EM86=E1&EM96YS:6]N<R@I.PH@("`@("H@("1I;6%G97=I
M9'1H("`]("1I;6%G961I;5LP73L*("`@("`J("`D:6UA9V5H96EG:'0@/2`D
M:6UA9V5D:6U;,5T["B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&UA>&EM=6T@:6UA9V5W:61T:"!A;F0@:6UA9V5H96EG:'0@=&AA=`H@("`@
M("H@("`@("`@("`@("`@("`@9FET(&]N('1H92!H86YD<V5T('-C<F5E;B!W
M:71H;W5T('-C<F]L;&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26UA
M9V5$:6UE;G-I;VYS*"D*("`@('L*("`@("`@("`D9&%T82`]("1T:&ES+3Y?
M9&%T85LD=&AI<RT^7VUO9&5L73L*("`@("`@("!R971U<FX@87)R87DH)&1A
M=&%;)VEM86=E=VED=&@G72P@)&1A=&%;)VEM86=E:&5I9VAT)UTI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@17AA;7!L92!U<V%G93H*("`@("`J("`D=&5X
M=&1I;2`@("`]("1U82T^9V5T5&5X=$1I;65N<VEO;G,H*3L*("`@("`J("`D
M=&5X='=I9'1H("`]("1T97AT9&EM6S!=.PH@("`@("H@("1T97AT:&5I9VAT
M(#T@)'1E>'1D:6U;,5T["B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE($UA>&EM=6T@=&5X='=I9'1H(&%N9"!T97AT:&5I9VAT('1H870*("`@
M("`J("`@("`@("`@("`@("`@(&9I="!O;B!T:&4@:&%N9'-E="!S8W)E96X@
M=VET:&]U="!S8W)O;&QI;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1E
M>'1$:6UE;G-I;VYS*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)'1H
M:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=6R=T97AT=VED=&@G72P*("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=6R=T
M97AT:&5I9VAT)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@86UO=6YT(&]F(&AA;F1S970@8V%C:&4@:6X@:VEL;V)Y
M=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#86-H92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("AI;G0I)'1H:7,M/E]C86-H93L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971-86YU9F%C='5R97(H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUA;G5F86-T=7)E<CL*("`@('T*"B`@("!F=6YC=&EO;B!G
M971%>'1R82@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AT<F$[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T26UA9V5&;W)M871S*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=6R=I
M;6%G969O<FUA=',G73L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5VAI8V@@8V]L;W(@;6]D96P@=&AE(&AA;F1S970@<W5P<&]R
M=',N"B`@("`@*B`@(%9A;'5E<R!H879E('1H92!F;VQL;W=I;F<@;65A;FEN
M9SH*("`@("`J("`@("`P("T^(&)L86-K(&%N9"!W:&ET90H@("`@("H@("`@
M(#$@+3X@-"!T;VYE(&=R97ES8V%L90H@("`@("H@("`@(#(@+3X@,C4V(&-O
M;&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;&]R*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=6R=C;VQO
M<B==.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$A45%!697)S:6]N*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]H='1P=F5R<VEO;CL*("`@('T*
M"B`@("!F=6YC=&EO;B!I<T-O;&]R*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=6R=C;VQO<B==(#T](#(U-CL*
M("`@('T*"B`@("!F=6YC=&EO;B!I<T=R97E38V%L92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L75LG8V]L;W(G
M72`]/2`G9W)E>2<["B`@("!]"@H@("`@9G5N8W1I;VX@:7-";&%C:T%N9%=H
M:71E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A6R1T:&ES
M+3Y?;6]D96Q=6R=C;VQO<B==(#T]("=B;&%C:R<["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]%9&ET;W(O````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-C$`,#$W-#0U`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T5D:71O<B]H=&UL87)E82YP:'``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-C8S,``Q,#4Q-30S,3`V,0`P,C$W-34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!%9&ET;W)?:'1M;&%R96$Z.B!C;&%S<R!P<F]V:61E<R!A;B!765-)
M5UE'(&5D:71O<B!F;W(@=7-E"B`J(&EN('1H92!(;W)D92!&<F%M97=O<FLN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T5D:71O<B]%9&ET;W(O:'1M;&%R
M96$N<&AP+'8@,2XR-"XT+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-"!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!.=6YO($QO=7)E:7)O(#QN
M=6YO0&-O+G-A<&\N<'0^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($YU;F\@3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T5D:71O<@H@*B\*8VQA
M<W,@2&]R9&5?161I=&]R7VAT;6QA<F5A(&5X=&5N9',@2&]R9&5?161I=&]R
M('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+B!);F-L=61E('1H92!N
M96-E<W-A<GD@:F%V87-C<FEP="!F:6QE<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?161I=&]R7VAT;6QA<F5A*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1N;W1I9FEC871I;VXL
M("1P<F5F<SL*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAT;6QA
M<F5A+FIS)RP@)VAO<F1E)RD["B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I
M;&4H)R]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M;&%R96$N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*("`@("`@("`D<V-R:7!T(#T@2&]R9&4Z.G5R;"A5
M=&EL.CIA9&1087)A;65T97(H)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N("<O<V5R=FEC97,O:F%V87-C<FEP="YP:'`G+"`G87!P)RP@
M)VAO<F1E)RDL('1R=64I.PH@("`@("`@("1J<R`]("=(5$U,07)E82YL;V%D
M4V-R:7!T*"(G("X@571I;#HZ861D4&%R86UE=&5R*"1S8W)I<'0L("=F:6QE
M)RP@("=H=&UL87)E85]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH*("`@
M("`@("`D<&QU9VEN<R`]("<G.PH@("`@("`@(&EF("@D<')E9G,M/F=E=%9A
M;'5E*"=T86)L96]P97)A=&EO;G,G*2D@>PH@("`@("`@("`@("`D:G,@+CT@
M)TA434Q!<F5A+FQO8610;'5G:6XH(E1A8FQE3W!E<F%T:6]N<R(I.R`G("X*
M("`@("`@("`@("`@("`@("`@("=(5$U,07)E82YL;V%D4V-R:7!T*"(G("X@
M571I;#HZ861D4&%R86UE=&5R*"1S8W)I<'0L("=F:6QE)RP@("=H=&UL87)E
M85]T86)L95]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@
M("`D<&QU9VEN<R`N/2`G961I=&]R+G)E9VES=&5R4&QU9VEN*%1A8FQE3W!E
M<F%T:6]N<RD[("<["B`@("`@("`@?0H@("`@("`@(&EF("@D<')E9G,M/F=E
M=%9A;'5E*"=C;VYT97AT;65N=2<I*2!["B`@("`@("`@("`@("1J<R`N/2`G
M2%1-3$%R96$N;&]A9%!L=6=I;B@B0V]N=&5X=$UE;G4B*3L@)R`N"B`@("`@
M("`@("`@("`@("`@("`G2%1-3$%R96$N;&]A9%-C<FEP="@B)R`N(%5T:6PZ
M.F%D9%!A<F%M971E<B@D<V-R:7!T+"`G9FEL92<L("`G:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D
M<&QU9VEN<R`N/2`G961I=&]R+G)E9VES=&5R4&QU9VEN*$-O;G1E>'1-96YU
M*3L@)SL*("`@("`@("!]"B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H
M)VQI<W1T>7!E)RDI('L*("`@("`@("`@("`@)&IS("X]("=(5$U,07)E82YL
M;V%D4&QU9VEN*"),:7-T5'EP92(I.R`G("X*("`@("`@("`@("`@("`@("`@
M("=(5$U,07)E82YL;V%D4V-R:7!T*"(G("X@571I;#HZ861D4&%R86UE=&5R
M*"1S8W)I<'0L("=F:6QE)RP@("=H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M)RP@9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D<&QU9VEN<R`N/2`G
M961I=&]R+G)E9VES=&5R4&QU9VEN*$QI<W14>7!E*3L@)SL*("`@("`@("!]
M"B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)V%N<V5L:6UA9V4G*2`F
M)B`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G:6UA9V5S+VQI<W1'86QL97)I97,G
M*2D@>PH@("`@("`@("`@("`D:G,@+CT@)TA434Q!<F5A+FQO8610;'5G:6XH
M(D%N<V5L26UA9V4B*3L@)R`N"B`@("`@("`@("`@("`@("`@("`G2%1-3$%R
M96$N;&]A9%-C<FEP="@B)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D<V-R:7!T
M+"`G9FEL92<L("`G:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS)RP@9F%L
M<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D<&QU9VEN<R`N/2`G961I=&]R
M+G)E9VES=&5R4&QU9VEN*$%N<V5L26UA9V4I.R`G.PH@("`@("`@('T*"B`@
M("`@("`@)&IS("X]("=(5$U,07)E82YO;FQO860@/2!F=6YC=&EO;B@I('L@
M)R`N"B`@("`@("`@("`@("`@("=V87(@8V]N9FEG(#T@;F5W($A434Q!<F5A
M+D-O;F9I9R@I(#LG("X*("`@("`@("`@("`@("`@)V-O;F9I9RYD96)U9R`]
M(&9A;'-E.R`G("X*("`@("`@("`@("`@("`@)V-O;F9I9RYH:61E4V]M94)U
M='1O;G,H(B!S:&]W:&5L<"`B*3L@)SL*("`@("`@("!I9B`H:7-S970H)'!A
M<F%M<ULG8V]N9FEG)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A
M;7-;)V-O;F9I9R==(&%S("1C;VYF:6<@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("`@("`D:G,@+CT@)V-O;F9I9RXG("X@)&-O;F9I9R`N("<@/2`B)R`N
M(&%D9'-L87-H97,H)'9A;'5E*2`N("<B.R<["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=I9"==*2D@>PH@
M("`@("`@("`@("`D:G,@+CT@)W9A<B!T97AT87)E87,@/2!;9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H(B<@+B`D<&%R86US6R=I9"==("X@)R(I73L@)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:G,@+CT@)W9A<B!T97AT
M87)E87,@/2!D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@B=&5X=&%R
M96$B*3L@)SL*("`@("`@("!]"B`@("`@("`@)&IS("X]("=F;W(@*'9A<B!I
M(#T@=&5X=&%R96%S+FQE;F=T:"`M(#$[(&D@/CT@,#L@:2TM*2![("<@+@H@
M("`@("`@("`@("`@("`G=F%R(&5D:71O<B`](&YE=R!(5$U,07)E82AT97AT
M87)E87-;:5TL(&-O;F9I9RD[("<@+@H@("`@("`@("`@("`@("`D<&QU9VEN
M<R`N"B`@("`@("`@("`@("`@("=E9&ET;W(N9V5N97)A=&4H*7U].R`G("X*
M("`@("`@("`@("`@("`@)TA434Q!<F5A+FEN:70H*3LG.PH*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*"1J<RP@)VIA=F%S8W)I<'0G*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]#86-H92\`````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#$W,C(R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-A8VAE+V9I;&4N<&AP````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#$U-P`Q,#4Q-30S,3`V
M,0`P,C`V-3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#86-H95]F:6QE.CH@8VQA
M<W,@<')O=FED97,@82!F:6QE<WES=&5M(&EM<&QE;65N=&%T:6]N(&]F('1H
M90H@*B!(;W)D92!C86-H:6YG('-Y<W1E;2X*("H*("H@3W!T:6]N86P@<&%R
M86UE=&5R<SH\<')E/@H@*B`@("=D:7(G("`@("!4:&4@9&ER96-T;W)Y('1O
M('-T;W)E('1H92!C86-H92!F:6QE<R!I;BX*("H@("`G<')E9FEX)R`@5&AE
M(&9I;&5N86UE('!R969I>"!T;R!U<V4@9F]R('1H92!C86-H92!F:6QE<RX\
M+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0V%C:&4O0V%C:&4O9FEL
M92YP:'`L=B`Q+C(X+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL
M+F]R9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D
M95]#86-H90H@*B\*8VQA<W,@2&]R9&5?0V%C:&5?9FEL92!E>'1E;F1S($AO
M<F1E7T-A8VAE('L*"B`@("`O*BH*("`@("`J(%1H92!L;V-A=&EO;B!O9B!T
M:&4@=&5M<"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?9&ER.PH*("`@("\J*@H@("`@("H@5&AE(&9I
M;&5N86UE('!R969I>"!F;W(@8V%C:&4@9FEL97,N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<')E9FEX(#T@)V-A8VAE
M7R<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W0@82!N97<@2&]R9&5?0V%C
M:&5?9FEL92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?0V%C:&5?9FEL92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)V1I<B==*2`F)B!`:7-?9&ER*"1P
M87)A;7-;)V1I<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1I<B`]("1P
M87)A;7-;)V1I<B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O571I;"YP:'`G.PH@("`@("`@("`@("`D=&AI
M<RT^7V1I<B`](%5T:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D<&%R86US6R=P<F5F:7@G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]P<F5F:7@@/2`D<&%R86US6R=P<F5F:7@G73L*("`@("`@
M("!]"@H@("`@("`@('!A<F5N=#HZ2&]R9&5?0V%C:&4H)'!A<F%M<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971R:65V92!C86-H
M960@9&%T82!F<F]M('1H92!F:6QE<WES=&5M(&%N9"!R971U<FX@:70@=&\*
M("`@("`J('1H92!C86QL97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@9F5T8V@N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!D871A(&EN
M('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@0V%C:&5D
M(&1A=&$L(&]R(&9A;'-E(&EF(&YO;F4@=V%S(&9O=6YD+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G970H)&ME>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/F5X:7-T<R@D:V5Y+"`D;&EF971I;64I*2!["B`@
M("`@("`@("`@("1F:6QE;F%M92`]("1T:&ES+3Y?:V5Y5&]&:6QE*"1K97DI
M.PH@("`@("`@("`@("`D<VEZ92`](&9I;&5S:7IE*"1F:6QE;F%M92D["B`@
M("`@("`@("`@(&EF("@A)'-I>F4I('L*("`@("`@("`@("`@("`@(')E='5R
M;B`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&%T82`](&9I;&5?
M9V5T7V-O;G1E;G1S*"1F:6QE;F%M92D["B`@("`@("`@("`@(&EF("@D9&%T
M82`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T83L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@3F]T:&EN9R!C
M86-H960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&1A
M=&$@=&\@=&AE(&9I;&5S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("`@0V%C:&4@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D("`D
M9&%T82`@1&%T82!T;R!S=&]R92!I;B!T:&4@8V%C:&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D:V5Y+"`D9&%T
M82D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U5T:6PN<&AP
M)SL*("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7VME>51O1FEL92@D:V5Y
M*3L*("`@("`@("`D=&UP7V9I;&4@/2!5=&EL.CIG971496UP1FEL92@G2&]R
M9&5#86-H92<L('1R=64L("1T:&ES+3Y?9&ER*3L*"B`@("`@("`@:68@*"1F
M9"`](&9O<&5N*"1T;7!?9FEL92P@)W<G*2D@>PH@("`@("`@("`@("!I9B`H
M9G=R:71E*"1F9"P@)&1A=&$I(#P@<W1R;&5N*"1D871A*2D@>PH@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F9"D["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F
M8VQO<V4H)&9D*3L*("`@("`@("`@("`@("`@($!R96YA;64H)'1M<%]F:6QE
M+"`D9FEL96YA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@9&ER96-T;'D@;W5T<'5T(&-A
M8VAE9"!D871A(&9R;VT@=&AE(&9I;&5S>7-T96TN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@;W5T<'5T
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E=&EM92!O
M9B!T:&4@9&%T82!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@($-A8VAE9"!D871A+"!O<B!F86QS92!I9B!N;VYE('=A<R!F;W5N
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T*"1K97DL("1L:69E=&EM
M92`](#$I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)&ME>2P@
M)&QI9F5T:6UE*2D@>PH@("`@("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^
M7VME>51O1FEL92@D:V5Y*3L*("`@("`@("`@("`@)&9D(#T@0&9O<&5N*"1F
M:6QE;F%M92P@)W(G*3L*("`@("`@("`@("`@:68@*"1F9"D@>PH@("`@("`@
M("`@("`@("`@9G!A<W-T:')U*"1F9"D["B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M3F]T:&EN9R!C86-H960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A
M(&=I=F5N(&ME>2!E>&ES=',@:6X@=&AE(&-A8VAE+"!V86QI9"!F;W(@=&AE
M(&=I=F5N"B`@("`@*B!L:69E=&EM92X@268@:70@97AI<W1S(&)U="!I<R!E
M>'!I<F5D+"!D96QE=&4@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@8VAE8VLN"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!K
M97D@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M($5X:7-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1K97DL
M("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@)&9I;&5N86UE(#T@)'1H
M:7,M/E]K97E4;T9I;&4H)&ME>2D["@H@("`@("`@("\J($ME>2!E>&ES=',@
M:6X@=&AE(&-A8VAE("HO"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE
M;F%M92DI('L*("`@("`@("`@("`@+RH@,"!M96%N<R!N;R!E>'!I<F4N("HO
M"B`@("`@("`@("`@(&EF("@D;&EF971I;64@/3T@,"D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J($EF('1H92!F:6QE('=A<R!B965N(&-R96%T960@869T97(@=&AE('-U
M<'!L:65D('9A;'5E+`H@("`@("`@("`@("`@*B!T:&4@9&%T82!I<R!V86QI
M9"`H9G)E<V@I+B`J+PH@("`@("`@("`@("!I9B`H=&EM92@I("T@)&QI9F5T
M:6UE(#P](&9I;&5M=&EM92@D9FEL96YA;64I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@($!U;FQI;FLH)&9I;&5N86UE*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@17AP:7)E(&%N>2!E>&ES=&EN9R!D871A(&9O<B!T:&4@9VEV96X@
M:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@0V%C:&4@
M:V5Y('1O(&5X<&ER92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP
M:7)E*"1K97DI"B`@("!["B`@("`@("`@)&9I;&5N86UE(#T@)'1H:7,M/E]K
M97E4;T9I;&4H)&ME>2D["B`@("`@("`@<F5T=7)N($!U;FQI;FLH)&9I;&5N
M86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($UA<"!A(&-A8VAE(&ME>2!T
M;R!A('5N:7%U92!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@($-A8VAE
M(&ME>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1G5L;'D@<75A
M;&EF:65D(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:V5Y5&]&
M:6QE*"1K97DI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&ER("X@
M)R\G("X@)'1H:7,M/E]P<F5F:7@@+B!M9#4H)&ME>2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$;R!A;GD@9V%R8F%G92!C;VQL96-T:6]N(&YE961E9"!F
M;W(@=&AE(&1R:79E<BX*("`@("`J"B`@("`@*B!`<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1S96-S("!4:&4@;6EN:6UU;2!A;6]U
M;G0@;V8@=&EM92`H:6X@<V5C;VYD<RD@<F5Q=6ER960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!B969O<F4@82!C86-H92!I=&5M(&ES(')E;6]V
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D;T=#*"1S96-S*0H@("`@>PH@
M("`@("`@("1F:6QE;F%M92`]("1T:&ES+3Y?9&ER("X@)R]H;W)D95]C86-H
M95]G8R<["B`@("`@("`@)&=C7W1I;64@/2!T:6UE*"D@+2`D<V5C<SL*("`@
M("`@("!I9B`H9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@
M("`D;VQD7W1I;64@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PH@
M("`@("`@("`@("!I9B`H*"1O;&1?=&EM92`A/3T@9F%L<V4I("8F"B`@("`@
M("`@("`@("`@("`H)&=C7W1I;64@/B`D;VQD7W1I;64I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1D(#T@9&ER*"1T:&ES+3Y?9&ER*3L*("`@("`@("!W:&EL92`H*"1E
M;G1R>2`]("1D+3YR96%D*"DI("$]/2!F86QS92D@>PH@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1E;G1R>2P@)'1H:7,M/E]P<F5F:7@I(#T]/2`P*2!["B`@
M("`@("`@("`@("`@("`D;71I;64@/2!F:6QE;71I;64H)'1H:7,M/E]D:7(@
M+B`G+R<@+B`D96YT<GDI.PH@("`@("`@("`@("`@("`@:68@*"1G8U]T:6UE
M(#X@)&UT:6UE*2!["B`@("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D=&AI
M<RT^7V1I<B`N("<O)R`N("1E;G1R>2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&0M/F-L;W-E*"D["B`*
M("`@("`@("`D9G`@/2!F;W!E;B@D9FEL96YA;64L("=W)RD["B`@("`@("`@
M9G=R:71E*"1F<"P@=&EM92@I*3L*("`@("`@("!F8VQO<V4H)&9P*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#86-H92]Z
M<',T+G!H<```````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T
M-S(`,3`U,34T,S$P-C$`,#(P-C,W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V%C
M:&5?>G!S-#HZ(&-L87-S('!R;W9I9&5S(&$@6F5N9"!097)F;W)M86YC92!3
M=6ET90H@*B`H=F5R<VEO;B`T+C`K*2!I;7!L96UE;G1A=&EO;B!O9B!T:&4@
M2&]R9&4@8V%C:&EN9R!S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T-A8VAE+T-A8VAE+WIP<S0N<&AP+'8@,2XQ+C$P+C0@,C`P-B\P,2\P,2`R
M,3HR.#HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M0V%C:&4*("HO"F-L87-S($AO<F1E7T-A8VAE7WIP<S0@97AT96YD<R!(;W)D
M95]#86-H92!["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971R:65V
M92!A('!I96-E(&]F(&-A8VAE9"!D871A(&%N9"!R971U<FX@:70@=&\@=&AE
M(&-A;&QE<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:V5Y("`@
M("`@($-A8VAE(&ME>2!T;R!F971C:"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1L:69E=&EM92`@3&EF971I;64@;V8@=&AE(&ME>2!I;B!S96-O;F1S+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($-A8VAE9"!D871A+"!O<B!F
M86QS92!I9B!N;VYE('=A<R!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T*"1K97DL("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@<F5T=7)N
M(&]U='!U=%]C86-H95]G970H)&ME>2P@)&QI9F5T:6UE*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&%N(&]B:F5C="!T;R!T
M:&4@8V%C:&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@
M0V%C:&4@:V5Y("AI9&5N=&EF:65R*2X*("`@("`J($!P87)A;2!M:7AE9"`@
M)&1A=&$@($1A=&$@=&\@<W1O<F4@:6X@=&AE(&-A8VAE+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&ME>2P@)&1A
M=&$I"B`@("!["B`@("`@("`@;W5T<'5T7V-A8VAE7W!U="@D:V5Y+"`D9&%T
M82D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!D:7)E8W1L>2!O=71P=70@8V%C:&5D(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K
M97D@=&\@;W5T<'5T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE
M("!,:69E=&EM92!O9B!T:&4@:V5Y(&EN('-E8V]N9',N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@0V%C:&5D(&1A=&$L(&]R(&9A;'-E(&EF(&YO
M;F4@=V%S(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=71P=70H)&ME
M>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("!E8VAO("1T:&ES+3YF
M971C:"@D:V5Y+"`D;&EF971I;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&EF(&$@9VEV96X@:V5Y(&5X:7-T<R!I;B!T:&4@8V%C:&4L('9A
M;&ED(&9O<B!T:&4@9VEV96X@;&EF971I;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@8VAE8VLN"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H
M92!K97D@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@($5X:7-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1K
M97DL("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@)&5X:7-T<R`](&]U
M='!U=%]C86-H95]E>&ES=',H)&ME>2P@)&QI9F5T:6UE*3L*("`@("`@("!O
M=71P=71?8V%C:&5?<W1O<"@I.PH@("`@("`@(')E='5R;B`D97AI<W1S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@17AP:7)E(&%N>2!E>&ES=&EN9R!D871A
M(&9O<B!T:&4@9VEV96X@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@0V%C:&4@:V5Y('1O(&5X<&ER92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@97AP:7)E*"1K97DI"B`@("!["B`@("`@("`@<F5T=7)N
M(&]U='!U=%]C86-H95]R96UO=F5?:V5Y*"1K97DI.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]";&]C:R\`````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#$W,C4Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+TQA>6]U="\`````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,0`P
M,C`U,C8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+U9I97<N<&AP````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P
M-3,R`#$P-3$U-#,Q,#8Q`#`R,C$T-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D
M92]"<F]W<V5R+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`G.PH*+RHJ"B`J(%1H92!(;W)D95]";&]C:U],87EO=71?
M5FEE=R!C;&%S<R!R97!R97-E;G1S('1H92!U<V5R(&1E9FEN960@<&]R=&%L
M(&QA>6]U="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+U9I97<N<&AP+'8@,2XT+C(N,R`R,#`V+S`V+S(S(#`T.C,U.C(Q
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXR"B`J($!P86-K
M86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U],87EO=71?
M5FEE=R!["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!B;&]C:R!L87EO
M=70N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]L87EO=70@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06QL(&%P<&QI
M8V%T:6]N<R!U<V5D(&EN('1H:7,@;&%Y;W5T+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87!P;&EC871I;VYS(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-34R!L:6YK('1A9W,@<'5L;&5D(&]U
M="!O9B!B;&]C:R!C;VYT96YT+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?;&EN:U1A9W,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7T)L;V-K7TQA>6]U=%]6:65W*"1L87EO=70@/2`G)RD*("`@('L*("`@
M("`@("`D=&AI<RT^7VQA>6]U="`]($!U;G-E<FEA;&EZ92@D;&%Y;W5T*3L*
M("`@("`@("!I9B`H(21T:&ES+3Y?;&%Y;W5T*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T(#T@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296YD97(@=&AE(&-U<G)E;G0@;&%Y;W5T(&%S($A434PN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@2%1-3"!L87EO=70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1O2'1M;"@I"B`@("!["B`@("`@("`@)&)R
M;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["B`@("`@("`@)'1P;$1I
M<B`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I.PH@("`@("`@("1I;G1E<G9A;"`]("1'3$]"04Q36R=P<F5F<R==
M+3YG971686QU92@G<W5M;6%R>5]R969R97-H7W1I;64G*3L*"B`@("`@("`@
M)&AT;6P@/2`G/'1A8FQE(&-L87-S/2)N;W!A9&1I;F<B(&-E;&QS<&%C:6YG
M/2(V(B!W:61T:#TB,3`P)2(^)SL*"B`@("`@("`@)&-O=F5R960@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&%Y;W5T(&%S("1R;W=?
M;G5M(#T^("1R;W<I('L*("`@("`@("`@("`@)'=I9'1H(#T@9FQO;W(H,3`P
M("\@8V]U;G0H)')O=RDI.PH@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/B<[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@)&-O;%]N=6T@/3X@)&ET
M96TI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8V]V97)E9%LD<F]W
M7VYU;5TI("8F(&ES<V5T*"1C;W9E<F5D6R1R;W=?;G5M75LD8V]L7VYU;5TI
M*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&ET96TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A<'!L:6-A=&EO;G-;)&ET
M96U;)V%P<"==72`]("1I=&5M6R=A<'`G73L*("`@("`@("`@("`@("`@("`@
M("`D8FQO8VL@/2`F2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ9V5T0FQO8VLH
M)&ET96U;)V%P<"==+"`D:71E;5LG<&%R86US)UU;)W1Y<&4G72P@)&ET96U;
M)W!A<F%M<R==6R=P87)A;7,G72D["B`@("`@("`@("`@("`@("`@("`@)')O
M=W-P86X@/2`D:71E;5LG:&5I9VAT)UT["B`@("`@("`@("`@("`@("`@("`@
M)&-O;'-P86X@/2`D:71E;5LG=VED=&@G73L*("`@("`@("`@("`@("`@("`@
M("`D=VED=&@@*CT@)&-O;'-P86X["B`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&ET96U;)VAE:6=H="==.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-O=F5R961;)')O=U]N
M=6T@*R`D:5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]V
M97)E9%LD<F]W7VYU;2`K("1I72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:B`]
M(#`[("1J(#P@)&ET96U;)W=I9'1H)UT[("1J*RLI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;W9E<F5D6R1R;W=?;G5M("L@)&E=6R1C;VQ?
M;G5M("L@)&I=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D8FQO8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&AE861E<B`](%\H(D5R<F]R(BD["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&)L;V-K+3YG971-97-S86=E*"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@)'1P;$1I<B`N("<O<&]R=&%L+V)L;V-K
M+FEN8R<["B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X](&]B7V=E
M=%]C;&5A;B@I.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A
M*"1B;&]C:RP@)TAO<F1E7T)L;V-K)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AE861E<B`]("1B;&]C:RT^9V5T5&ET;&4H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D8FQO8VLM/F=E=$-O;G1E;G0H
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:6YC;'5D92`D='!L1&ER("X@)R]P;W)T86PO
M8FQO8VLN:6YC)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M;V)?9V5T7V-L96%N*"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!W:61T:#TB
M)R`N("1W:61T:"`N("<E(CXF;F)S<#L\+W1D/B<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D('=I9'1H/2(G("X@)'=I9'1H("X@)R4B
M/B9N8G-P.SPO=&0^)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]T<CXG.PH@("`@("`@('T*("`@
M("`@("`D:'1M;"`N/2`G/"]T86)L93XG.PH*("`@("`@("`O+R!3=')I<"!A
M;GD@0U-3(#QL:6YK/B!T86=S(&]U="!O9B!T:&4@<F5T=7)N960@8V]N=&5N
M="!S;PH@("`@("`@("\O('1H97D@8V%N(&)E(&AA;F1L960@<V5P97)A=&5L
M>2X*("`@("`@("!I9B`H<')E9U]M871C:%]A;&PH)R\\;&EN:R`N*C]R96P]
M(G-T>6QE<VAE970B+BH_7"\^+R<L("1H=&UL+"`D;&EN:W,I*2!["B`@("`@
M("`@("`@("1H=&UL(#T@<W1R7W)E<&QA8V4H)&QI;FMS6S!=+"`G)RP@)&AT
M;6PI.PH@("`@("`@("`@("`D=&AI<RT^7VQI;FM486=S(#T@)&QI;FMS6S!=
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&%N>2!L:6YK('1A9W,@9F]U;F0@:6X@=&AE('9I
M97<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QI;FM486=S*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YK5&%G<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@86QL('1H92!A<'!L:6-A=&EO
M;G,@=7-E9"!B>2!B;&]C:W,@:6X@=&AI<R!L87EO=70N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2!,:7-T(&]F(&%P<&QI8V%T:6]N<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T07!P;&EC871I;VYS*"D*("`@('L*("`@("`@
M("!R971U<FX@87)R87E?:V5Y<R@D=&AI<RT^7V%P<&QI8V%T:6]N<RD["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'``````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S,R,3<`,3`U,34T
M,S$P-C$`,#(R-C$U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H
M<"<["@HO*BH*("H@5&AE($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R(&-L
M87-S(&%L;&]W<R!M86YI<'5L871I;VX@;V8*("H@2&]R9&5?0FQO8VL@;&%Y
M;W5T<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP+'8@,2XT+C(N,R`R,#`V+S`S+S`X(#$W.C4T.C`X
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXR"B`J($!P86-K
M86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U],87EO=71?
M36%N86=E<B!["@H@("`@+RHJ"B`@("`@*B!/=7(@2&]R9&5?0FQO8VM?0V]L
M;&5C=&EO;B!I;G-T86YC92X*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7T)L
M;V-K7T-O;&QE8W1I;VX*("`@("`J+PH@("`@=F%R("1?8V]L;&5C=&EO;CL*
M"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&)L;V-K(&QA>6]U="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VQA>6]U
M="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!(&-A8VAE(&9O<B!T:&4@
M8FQO8VL@;V)J96-T<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V)L;V-K<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;6%X:6UU;2!N=6UB97(@;V8@8V]L=6UN<RX*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8V]L=6UN<R`](#`[
M"@H@("`@+RHJ"B`@("`@*B!(87,@=&AE(&QA>6]U="!B965N('5P9&%T960@
M<VEN8V4@:70@=V%S(&EN<W1A;G1I871E9"X*("`@("`J"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=7!D871E9"`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@8FQO8VL@*&%R<F%Y.B!;<F]W
M+"!C;VQ=*2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V-U<G)E;G1";&]C:R`](&%R<F%Y*&YU;&PL(&YU;&PI.PH*("`@
M("\J*@H@("`@("H@5&AE(&YE=R!R;W<@;V8@=&AE(&QA<W0@8VAA;F=E9"!B
M;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?8VAA;F=E9%]R;W<@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE
M(&YE=R!C;VQU;6X@;V8@=&AE(&QA<W0@8VAA;F=E9"!B;&]C:RX*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8VAA;F=E
M9%]C;VP@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@
M("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX@)B1C
M;VQL96-T:6]N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R*"8D8V]L
M;&5C=&EO;BP@)&1A=&$@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7V-O
M;&QE8W1I;VX@/2`F)&-O;&QE8W1I;VX["B`@("`@("`@)'1H:7,M/G5N<V5R
M:6%L:7IE*"1D871A*3L*"B`@("`@("`@+R\@1FEL;"!T:&4@7V-O=F5R960@
M8V%C:&5S(&%N9"!E;7!T>2!R;W=S+@H@("`@("`@("1R;W=S(#T@8V]U;G0H
M)'1H:7,M/E]L87EO=70I.PH@("`@("`@("1E;7!T>2`](&%R<F%Y*"D["B`@
M("`@("`@9F]R("@D<F]W(#T@,#L@)')O=R`\("1R;W=S.R`D<F]W*RLI('L*
M("`@("`@("`@("`@)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA>6]U=%LD<F]W
M72D["B`@("`@("`@("`@(&EF("@A:7-S970H)&5M<'1Y6R1R;W==*2D@>PH@
M("`@("`@("`@("`@("`@)&5M<'1Y6R1R;W==(#T@=')U93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!F;W(@*"1C;VP@/2`P.R`D8V]L(#P@)&-O;',[
M("1C;VPK*RD@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VQA>6]U=%LD<F]W75LD8V]L72DI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V)L;V-K<ULD<F]W75LD8V]L72`](%!%05(Z.G)A:7-E17)R;W(H
M7R@B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-?87)R87DH)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&9I96QD(#T@)'1H:7,M/E]L87EO=71;)')O=UU;
M)&-O;%T["@H@("`@("`@("`@("`@("`@("`@("1E;7!T>5LD<F]W72`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEE;&1;)W=I
M9'1H)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`Q
M.R`D:2`\("1F:65L9%LG=VED=&@G73L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I
M72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&9I96QD6R=H96EG:'0G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D9FEE;&1;)W=I9'1H)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEE;&1;)W=I9'1H)UT@/2`Q.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&D@/2`Q.R`D:2`\("1F:65L9%LG:&5I9VAT)UT[("1I*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@
M*R`D:5U;)&-O;%T@/2`G8V]V97)E9"<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W(@*"1J(#T@,3L@)&H@/"`D9FEE;&1;)W=I9'1H)UT[("1J
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD<F]W("L@)&E=6R1C;VP@*R`D:ET@/2`G8V]V97)E9"<["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D96UP='E;)')O=R`K("1I72`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3
M=')I<"!E;7!T>2!B;&]C:W,@9G)O;2!T:&4@96YD(&]F('1H92!R;W=S+@H@
M("`@("`@("`@("!F;W(@*"1C;VP@/2`D8V]L<R`M(#$[("1C;VP@/CT@,#L@
M)&-O;"TM*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VQ=*2!\?`H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T]("=E;7!T>2<I('L*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D=&AI<RT^7V-O;'5M;G,@/2!M87@H)'1H:7,M/E]C;VQU
M;6YS+"!C;W5N="@D=&AI<RT^7VQA>6]U=%LD<F]W72DI.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1FEL;"!A;&P@<F]W<R!U<"!T;R!T:&4@<V%M92!L96YG
M=&@N"B`@("`@("`@)&QA>6]U="`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D
M<F]W(#T@,#L@)')O=R`\("1R;W=S.R`D<F]W*RLI('L*("`@("`@("`@("`@
M)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA>6]U=%LD<F]W72D["B`@("`@("`@
M("`@(&EF("@D8V]L<R`\("1T:&ES+3Y?8V]L=6UN<RD@>PH@("`@("`@("`@
M("`@("`@9F]R("@D8V]L(#T@)&-O;',[("1C;VP@/"`D=&AI<RT^7V-O;'5M
M;G,[("1C;VPK*RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W==6R1C;VQ=(#T@)V5M<'1Y)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&%Y;W5T6UT@/2`D=&AI<RT^
M7VQA>6]U=%LD<F]W73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T(#T@)&QA>6]U=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E<FEA;&EZ
M92!A;F0@<F5T=7)N('1H92!C=7)R96YT(&)L;V-K(&QA>6]U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"D*("`@('L*("`@("`@("!R971U
M<FX@<V5R:6%L:7IE*"1T:&ES+3Y?;&%Y;W5T*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E<V5T<R!T:&4@8W5R<F5N="!L87EO=70@=&\@=&AE('9A;'5E
M('-T;W)E9"!I;B!T:&4@<')E9F5R96YC97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('5N<V5R:6%L:7IE*"1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T(#T@0'5N<V5R:6%L:7IE*"1D871A*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!S:6YG;&4@:6YS=&%N8V4@;V8@=&AE($AO<F1E
M7T)L;V-K7TQA>6]U=%]-86YA9V5R(&-L87-S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64*("`@("`J($!P87)A;2!(;W)D95]";&]C:U]#
M;VQL96-T:6]N("8D8V]L;&5C=&EO;@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T80H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<F5T
M=7)N($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R("!4:&4@2&]R9&5?0FQO
M8VM?3&%Y;W5T7TUA;F%G97(@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH)&YA;64L("8D8V]L;&5C=&EO;BP@)&1A=&$@/2`G
M)RD*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1N86UE72DI('L*("`@
M("`@("`@("`@)&EN<W1A;F-E<ULD;F%M95T@/2!N97<@2&]R9&5?0FQO8VM?
M3&%Y;W5T7TUA;F%G97(H)&-O;&QE8W1I;VXL("1D871A*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)&YA;65=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4')O8V5S<R!A(&UO9&EF:6-A=&EO;B!T;R!T:&4@8W5R
M<F5N="!L87EO=70N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<@)&%C=&EO
M;@H@("`@("H@0'9A<B!I;G1E9V5R("1R;W<*("`@("`J($!V87(@:6YT96=E
M<B`D8V]L"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L92@D86-T:6]N+"`D
M<F]W+"`D8V]L*0H@("`@>PH@("`@("`@('-W:71C:"`H)&%C=&EO;BD@>PH@
M("`@("`@(&-A<V4@)VUO=F55<"<Z"B`@("`@("`@8V%S92`G;6]V941O=VXG
M.@H@("`@("`@(&-A<V4@)VUO=F5,969T)SH*("`@("`@("!C87-E("=M;W9E
M4FEG:'0G.@H@("`@("`@(&-A<V4@)V5X<&%N9%5P)SH*("`@("`@("!C87-E
M("=E>'!A;F1$;W=N)SH*("`@("`@("!C87-E("=E>'!A;F1,969T)SH*("`@
M("`@("!C87-E("=E>'!A;F12:6=H="<Z"B`@("`@("`@8V%S92`G<VAR:6YK
M3&5F="<Z"B`@("`@("`@8V%S92`G<VAR:6YK4FEG:'0G.@H@("`@("`@(&-A
M<V4@)W-H<FEN:U5P)SH*("`@("`@("!C87-E("=S:')I;FM$;W=N)SH*("`@
M("`@("!C87-E("=R96UO=F5";&]C:R<Z"B`@("`@("`@("`@("1R97-U;'0@
M/2!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,L("1A8W1I;VXI+"`D<F]W
M+"`D8V]L*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A
M=&EO;B==+3YP=7-H*"1R97-U;'0I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U<&1A=&5D(#T@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@+R\@4V%V92!T
M:&4@8VAA;F=E<R!M861E('1O(&$@8FQO8VLN"B`@("`@("`@8V%S92`G<V%V
M92<Z"B`@("`@("`@+R\@4V%V92!T:&4@8VAA;F=E<R!M861E('1O(&$@8FQO
M8VL@86YD(&-O;G1I;G5E(&5D:71I;F<N"B`@("`@("`@8V%S92`G<V%V92UR
M97-U;64G.@H@("`@("`@("`@("`O+R!'970@<F5Q=65S=&5D(&)L;V-K('1Y
M<&4N"B`@("`@("`@("`@(&QI<W0H)&YE=V%P<"P@)&YE=W1Y<&4I(#T@97AP
M;&]D92@G.B<L(%5T:6PZ.F=E=$9O<FU$871A*"=A<'`G*2D["@H@("`@("`@
M("`@("`O+R!)<R!T:&ES(&$@;F5W(&)L;V-K/PH@("`@("`@("`@("`D;F5W
M(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-%;7!T>2@D<F]W
M+"`D8V]L*2!\?`H@("`@("`@("`@("`@("`@(21T:&ES+3YR;W=%>&ES=',H
M)')O=RD@?'P*("`@("`@("`@("`@("`@("$D=&AI<RT^8V]L17AI<W1S*"1C
M;VPI*2!["B`@("`@("`@("`@("`@("`O+R!#:&5C:R!P97)M:7-S:6]N<RX*
M("`@("`@("`@("`@("`@(&EF("A(;W)D93HZ:&%S4&5R;6ES<VEO;B@G;6%X
M7V)L;V-K<R<I("$]/2!T<G5E("8F"B`@("`@("`@("`@("`@("`@("`@2&]R
M9&4Z.FAA<U!E<FUI<W-I;VXH)VUA>%]B;&]C:W,G*2`\/2`D=&AI<RT^8V]U
M;G0H*2D@>PH@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(I+"!(;W)D93HZ:&%S4&5R
M;6ES<VEO;B@G;6%X7V)L;V-K<R<I*2P@14Y47T-/35!!5"P@3DQ3.CIG971#
M:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-O
M;F9;)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1M97-S86=E(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?<&5R;7-?
M:&]O:U]D96YI960G+"!A<G)A>2@G:&]R9&4Z;6%X7V)L;V-K<R<I+"`G:&]R
M9&4G+"`D;65S<V%G92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"@D
M;65S<V%G92P@)VAO<F1E+F5R<F]R)RP@87)R87DH)V-O;G1E;G0N<F%W)RDI
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1N97<@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@+R\@36%K92!S=7)E('1H97)E(&ES('-O;65W:&5R92!T;R!P=70@:70N
M"B`@("`@("`@("`@("`@("`D=&AI<RT^861D0FQO8VLH)')O=RP@)&-O;"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($]R(&%N(&5X:7-T:6YG
M(&]N93\*("`@("`@("`@("`@)&5X:7-T<R`](&9A;'-E.PH@("`@("`@("`@
M("`D8VAA;F=E9"`](&9A;'-E.PH@("`@("`@("`@("!I9B`H(21N97<I('L*
M("`@("`@("`@("`@("`@("\O($=E="!T87)G970@8FQO8VL@:6YF;RX*("`@
M("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/F=E=$)L;V-K26YF;R@D<F]W
M+"`D8V]L*3L*("`@("`@("`@("`@("`@("1E>&ES=',@/2`D=&AI<RT^:7-"
M;&]C:R@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@("`@("\O($AA<R!A(&1I
M9F9E<F5N="!B;&]C:R!B965N('-E;&5C=&5D/PH@("`@("`@("`@("`@("`@
M:68@*"1E>&ES=',@)B8*("`@("`@("`@("`@("`@("`@("`H)&EN9F];)V%P
M<"==("$]("1N97=A<'`@?'P*("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)V)L;V-K)UT@(3T@)&YE=W1Y<&4I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&-H86YG960@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&YE=R!\?"`D8VAA;F=E9"D@>PH@("`@
M("`@("`@("`@("`@+R\@0VAA;F=E(&%P<"!O<B!T>7!E+@H@("`@("`@("`@
M("`@("`@)&EN9F\@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&EN9F];
M)V%P<"==(#T@)&YE=V%P<#L*("`@("`@("`@("`@("`@("1I;F9O6R=B;&]C
M:R==(#T@)&YE=W1Y<&4["B`@("`@("`@("`@("`@("`D<&%R86US(#T@)'1H
M:7,M/E]C;VQL96-T:6]N+3YG971087)A;7,H)&YE=V%P<"P@)&YE=W1Y<&4I
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D;F5W<&%R
M86TI('L*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<&%R86US)UU;)&YE
M=W!A<F%M72`]("1T:&ES+3Y?8V]L;&5C=&EO;BT^9V5T1&5F875L=%9A;'5E
M*"1N97=A<'`L("1N97=T>7!E+"`D;F5W<&%R86TI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)L;V-K26YF;R@D<F]W
M+"`D8V]L+"`D:6YF;RD["B`@("`@("`@("`@('T@96QS96EF("@D97AI<W1S
M*2!["B`@("`@("`@("`@("`@("`O+R!#:&%N9V4@=F%L=65S+@H@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$)L;V-K26YF;R@D<F]W+"`D8V]L+"!A<G)A
M>2@G<&%R86US)R`]/B!5=&EL.CIG971&;W)M1&%T82@G<&%R86US)RP@87)R
M87DH*2DI*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W5P
M9&%T960@/2!T<G5E.PH@("`@("`@("`@("!I9B`H)&%C=&EO;B`]/2`G<V%V
M92<I('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@
M("`@("`@("\O($UA:V4@82!B;&]C:R!T:&4@8W5R<F5N="!B;&]C:R!F;W(@
M961I=&EN9RX*("`@("`@("!C87-E("=E9&ET)SH*("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R96YT0FQO8VL@/2!A<G)A>2@D<F]W+"`D8V]L*3L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M2&%S('1H92!L87EO=70@8F5E;B!C:&%N9V5D('-I;F-E(&ET('=A<R!I;G-T
M86YT:6%T960_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('5P9&%T960H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W5P9&%T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M=&AE(&-U<G)E;G0@8FQO8VL@<F]W(&%N9"!C;VQU;6XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2!;<F]W+"!C;VQ="B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$-U<G)E;G1";&]C:R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8W5R<F5N=$)L;V-K.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@2&]R9&5?0FQO8VL@870@=&AE('-P96-I9FEE9"!P;W-I=&EO
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]";&]C:R`@5&AE
M(&)L;V-K(&9R;VT@=&AA="!P;W-I=&EO;B!O<B!A(%!%05)?17)R;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@(&EF('-O;65T:&EN9R!W96YT('=R
M;VYG+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T0FQO8VLH)')O=RP@)&-O
M;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1R
M;W==6R1C;VQ=*2D@>PH@("`@("`@("`@("`D9FEE;&0@/2`D=&AI<RT^7VQA
M>6]U=%LD<F]W75LD8V]L73L*("`@("`@("`@("`@)'1H:7,M/E]B;&]C:W-;
M)')O=UU;)&-O;%T@/0H@("`@("`@("`@("`@("`@)DAO<F1E7T)L;V-K7T-O
M;&QE8W1I;VXZ.F=E=$)L;V-K*"1F:65L9%LG87!P)UTL("1F:65L9%LG<&%R
M86US)UU;)W1Y<&4G72P@)&9I96QD6R=P87)A;7,G75LG<&%R86US)UTI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1R;W==
M6R1C;VQ=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]O
M<F1I;F%T97,@;V8@=&AE(&)L;V-K(&-O=F5R:6YG('1H92!S<&5C:69I960*
M("`@("`J(&9I96QD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R
M;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@
M($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@=&]P+6QE9G0@<F]W+6-O;'5M;BUC;V]R9&EN871E(&]F('1H92!B
M;&]C:PH@("`@("H@("`@("`@("`@("`@("`@8V]V97)I;F<@=&AE('-P96-I
M9FEE9"!F:65L9"!O<B!N=6QL(&EF('1H92!F:65L9`H@("`@("H@("`@("`@
M("`@("`@("`@:7,@96UP='DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L
M;V-K070H)')O=RP@)&-O;"D*("`@('L*("`@("`@("`O*B!4<FEV:6%L(&-A
M<V5S(&9I<G-T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^:7-%;7!T>2@D<F]W
M+"`D8V]L*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M(&5L<V5I9B`H(21T:&ES+3YI<T-O=F5R960H)')O=RP@)&-O;"DI('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"1R;W<L("1C;VPI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@5&AI<R!I<R!A(&-O=F5R960@9FEE;&0N("HO"B`@("`@
M("`@9F]R("@D=&5S="`]("1R;W<@+2`Q.R`D=&5S="`^/2`P.R`D=&5S="TM
M*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES0V]V97)E9"@D=&5S="P@
M)&-O;"D@)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^:7-%;7!T>2@D=&5S
M="P@)&-O;"D@)B8*("`@("`@("`@("`@("`@("1T97-T("L@)'1H:7,M/F=E
M=$AE:6=H="@D=&5S="P@)&-O;"D@+2`Q(#T]("1R;W<I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@D=&5S="P@)&-O;"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9F]R("@D=&5S="`]("1C;VP@+2`Q.R`D
M=&5S="`^/2`P.R`D=&5S="TM*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/FES0V]V97)E9"@D<F]W+"`D=&5S="D@)B8*("`@("`@("`@("`@("`@("$D
M=&AI<RT^:7-%;7!T>2@D=&5S="P@)&-O;"D@)B8*("`@("`@("`@("`@("`@
M("1T97-T("L@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1T97-T*2`M(#$@/3T@
M)&-O;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1R;W<L("1T
M97-T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<V]M92!U<V5F=6P@:6YF;W)M
M871I;VX@86)O=70@=&AE('-P96-I9FEE9`H@("`@("H@8FQO8VLN"B`@("`@
M*@H@("`@("H@4F5T=7)N960@:&%S:"!V86QU97,Z"B`@("`@*B`G87!P)SH@
M87!P;&EC871I;VX@;F%M90H@("`@("H@)V)L;V-K)SH@8FQO8VL@;F%M90H@
M("`@("H@)W!A<F%M<R<Z('!A<F%M971E<B!H87-H"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!I;F9O<FUA=&EO;B!H87-H+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971";&]C:TEN9F\H)')O=RP@)&-O;"D*("`@
M('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C
M;VQ=*2!\?`H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72`]/2`G96UP='DG*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=A<'`G(#T^("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C
M;VQ=6R=A<'`G72P*("`@("`@("`@("`@("`@("`@("`@)V)L;V-K)R`]/B`D
M=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG<&%R86US)UU;)W1Y<&4G72P*
M("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@)'1H:7,M/E]L87EO
M=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=P87)A;7,G72D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S(&$@8F%T8V@@;V8@:6YF;W)M871I;VX@86)O
M=70@=&AE('-P96-I9FEE9"!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B!`<&%R86T@87)R
M87D@)&EN9F\@("!!(&AA<V@@=VET:"!I;F9O<FUA=&EO;B!V86QU97,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!0;W-S:6)L92!E;&5M96YT<R!A
M<F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`G87!P)SH@87!P;&EC
M871I;VX@;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@)V)L;V-K
M)SH@8FQO8VL@;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@)W!A
M<F%M<R<Z('!A<F%M971E<B!H87-H"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$)L;V-K26YF;R@D<F]W+"`D8V]L+"`D:6YF;R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&EN9F];)V%P<"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W75LD8V]L75LG87!P)UT@/2`D:6YF;ULG87!P)UT["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D:6YF;ULG8FQO8VLG72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=T>7!E
M)UT@/2`D:6YF;ULG8FQO8VLG73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1I;F9O6R=P87)A;7,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=P87)A;7,G72`]("1I;F9O
M6R=P87)A;7,G73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E
M9%]R;W<@/2`D<F]W.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D
M8V]L.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R
M(&]F(&)L;V-K<R!I;B!T:&4@8W5R<F5N="!L87EO=70N"B`@("`@*@H@("`@
M("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(&YU;6)E<B!O9B!B;&]C:W,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O=6YT*"D*("`@('L*("`@("`@("`D<F]W<R`]("1T:&ES+3YR;W=S
M*"D["B`@("`@("`@)&-O=6YT(#T@,#L*"B`@("`@("`@9F]R("@D<F]W(#T@
M,#L@)')O=R`\("1R;W=S.R`D<F]W*RLI('L*("`@("`@("`@("`@)&-O;',@
M/2`D=&AI<RT^8V]L=6UN<R@D<F]W*3L*("`@("`@("`@("`@9F]R("@D8V]L
M(#T@,#L@)&-O;"`\("1C;VQS.R`D8V]L*RLI('L*("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/FES16UP='DH)')O=RP@)&-O;"D@)B8*("`@("`@("`@
M("`@("`@("`@("`A)'1H:7,M/FES0V]V97)E9"@D<F]W+"`D8V]L*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1C;W5N="LK.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O
M=6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R
M(&]F(')O=W,@:6X@=&AE(&-U<G)E;G0@;&%Y;W5T+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!R;W=S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R;W=S*"D*("`@('L*("`@("`@("!R971U<FX@8V]U
M;G0H)'1H:7,M/E]L87EO=70I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@=&AE('-P96-I9FEE9"!R
M;W<@;V8@=&AE"B`@("`@*B!C=7)R96YT(&QA>6]U="X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<F]W("!4:&4@<F]W('1O(')E='5R;B!T:&4@
M;G5M8F5R(&]F(&-O;'5M;G,@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8V]L=6UN<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]L=6UN<R@D<F]W*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]L87EO=71;)')O=UTI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B5&AE('-P96-I9FEE9"!R
M;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB*2P@)')O=RDL("=H;W)D92YE<G)O
M<B<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@8V]U;G0H)'1H:7,M/E]L
M87EO=71;)')O=UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O
M('-E92!I9B!A(&=I=F5N(&QO8V%T:6]N(&EF(&)E:6YG('5S960@8GD@82!B
M;&]C:PH@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y
M;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T
M(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AE(&QO8V%T:6]N(&ES(&5M<'1Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@($9A;'-E(&ES('1H92!L;V-A=&EO;B!I<R!B96EN9R!U<V5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<T5M<'1Y*"1R;W<L("1C;VPI"B`@("!["B`@
M("`@("`@<F5T=7)N("%I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72D@?'P@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%T@/3T@)V5M<'1Y)SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:68@=&AE(&9I96QD(&%T
M('1H92!S<&5C:69I960@<&]S:71I;VX@:7,@8V]V97)E9"!B>0H@("`@("H@
M86YO=&AE<B!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L
M("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&EF('1H92!S<&5C:69I960@9FEE;&0@:7,@8V]V97)E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;W9E<F5D*"1R;W<L("1C;VPI"B`@
M("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==
M6R1C;VQ=*2`_("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T]("=C;W9E
M<F5D)R`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I
M9B!T:&4@<W!E8VEF:65D(&QO8V%T:6]N(&ES('1H92!T;W`@;&5F="!F:65L
M9"!O9@H@("`@("H@82!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I960@<&]S:71I;VX@:7,@
M82!B;&]C:RP@9F%L<V4@:68*("`@("`J("`@("`@("`@("`@("`@("`@=&AE
M(&9I96QD(&1O97-N)W0@97AI<W0L(&ES(&5M<'1Y(&]R(&-O=F5R960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES0FQO8VLH)')O=RP@)&-O;"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G)O=T5X:7-T<R@D<F]W*2`F)B`D=&AI
M<RT^8V]L17AI<W1S*"1C;VPI("8F"B`@("`@("`@("`@("$D=&AI<RT^:7-%
M;7!T>2@D<F]W+"`D8V]L*2`F)B`A)'1H:7,M/FES0V]V97)E9"@D<F]W+"`D
M8V]L*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:68@=&AE('-P
M96-I9FEE9"!B;&]C:R!H87,@8F5E;B!C:&%N9V5D(&QA<W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&)L;V-K
M(&ES('1H92!L87-T(&]N92!T:&%T('=A<R!C:&%N9V5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T-H86YG960H)')O=RP@)&-O;"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]C:&%N9V5D7W)O=R`]/3T@)')O=R`F)B`D=&AI
M<RT^7V-H86YG961?8V]L(#T]/2`D8V]L.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!I9B!T:&4@<W!E8VEF:65D(&)L;V-K(&UA>2!B92!R96UO
M=F5D+@H@("`@("H*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W
M("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!
M(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H:7,@8FQO8VL@;6%Y(&)E(')E;6]V960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES4F5M;W9A8FQE*"1R;W<L("1C;VPI"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D87!P(#T@)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;%U;)V%P<"==.PH@("`@("`@("1T>7!E(#T@)'1H
M:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=T>7!E)UT["B`@
M("`@("`@)&)L;V-K(#T@)&%P<"`N("<Z)R`N("1T>7!E.PH*("`@("`@("`O
M*B!#:&5C:R!I9B!T:&4@8FQO8VL@:7,@82!F:7AE9"!B;&]C:RX@*B\*("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"1B;&]C:RP@)&-O;F9;)W!O<G1A;"==6R=F
M:7AE9%]B;&]C:W,G72DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!W92!H879E('-T:6QL(&%N
M;W1H97(@8FQO8VL@;V8@=&AE('-A;64@='EP92X@*B\*("`@("`@("`D9F]U
M;F0@/2!F86QS93L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQA>6]U="!A
M<R`D8W5R7W)O=RD@>PH@("`@("`@("`@("!F;W)E86-H("@D8W5R7W)O=R!A
M<R`D8W5R7V-O;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C=7)?
M8V]L6R=A<'`G72D@)B8*("`@("`@("`@("`@("`@("`@("`D8W5R7V-O;%LG
M87!P)UT@/3T@)&%P<"`F)@H@("`@("`@("`@("`@("`@("`@("1C=7)?8V]L
M6R=P87)A;7,G75LG='EP92==(#T]("1T>7!E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1F;W5N9"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;B!54DP@=')I9V=E<FEN9R!A;B!A8W1I;VX@
M=&\@82!B;&]C:PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%C=&EO
M;B`@06X@86-T:6]N('1O('1R:6=G97(N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@($%N(%523"!W:71H(&%L;"!N96-E<W-A<GD@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06-T:6]N57)L*"1A8W1I;VXL("1R
M;W<L("1C;VPI"B`@("!["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<BA(;W)D93HZ<V5L9E5R;"@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V-O;"<@/3X@)&-O;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R;W<G(#T^("1R;W<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G86-T:6]N
M)R`]/B`D86-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VYO8V%C:&4G(#T^(&)A<V5?8V]N=F5R="AM:6-R;W1I;64H
M*2P@,3`L(#,V*2DI.PH@("`@("`@(')E='5R;B`D=7)L("X@)R-B;&]C:R<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8V]N=')O;"`H;&EN
M:V5D(&%R<F]W*2!F;W(@82!C97)T86EN(&%C=&EO;B!O;B!T:&4*("`@("`J
M('-P96-I9FEE9"!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T>7!E("!!(&-O;G1R;VP@='EP92!I;B!T:&4@9F]R;0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(FUO9&EF:6-A=&EO;B]D:7)E8W1I;VXB+B!0
M;W-S:6)L92!V86QU97,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!M;V1I9FEC871I;VXZ(&5X<&%N9"P@<VAR:6YK+"!M;W9E+B!0;W-S:6)L
M92!V86QU97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&9O<B!D:7)E
M8W1I;VXZ('5P+"!D;W=N+"!L969T+"!R:6=H="X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@02!L:6YK(&-O;G1A:6YI;F<@86X@87)R;W<@<F5P<F5S
M96YT:6YG('1H92!R97%U97-T960*("`@("`J("`@("`@("`@("`@("`@("!C
M;VYT<F]L+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYT<F]L*"1T>7!E
M+"`D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@("1T>7!E(#T@97AP;&]D92@G
M+R<L("1T>7!E*3L*("`@("`@("`D86-T:6]N(#T@)'1Y<&5;,%T@+B!U8V9I
M<G-T*"1T>7!E6S%=*3L*("`@("`@("`D=7)L(#T@)'1H:7,M/F=E=$%C=&EO
M;E5R;"@D86-T:6]N+"`D<F]W+"`D8V]L*3L*"B`@("`@("`@<W=I=&-H("@D
M='EP95LP72D@>PH@("`@("`@(&-A<V4@)V5X<&%N9"<Z"B`@("`@("`@("`@
M("1T:71L92`](%\H(D5X<&%N9"(I.PH@("`@("`@("`@("`D:6UG(#T@)VQA
M<F=E7R<@+B`D='EP95LQ73L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)W-H<FEN:R<Z"B`@("`@("`@("`@("1T:71L92`](%\H(E-H<FEN
M:R(I.PH@("`@("`@("`@("`D:6UG(#T@)VQA<F=E7R<["@H@("`@("`@("`@
M("!S=VET8V@@*"1T>7!E6S%=*2!["B`@("`@("`@("`@(&-A<V4@)W5P)SH*
M("`@("`@("`@("`@("`@("1I;6<@+CT@)V1O=VXG.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=D;W=N)SH*("`@("`@("`@
M("`@("`@("1I;6<@+CT@)W5P)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G;&5F="<Z"B`@("`@("`@("`@("`@("`D:6UG
M("X]("=R:6=H="<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)W)I9VAT)SH*("`@("`@("`@("`@("`@("1I;6<@+CT@)VQE
M9G0G.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)VUO=F4G.@H@("`@("`@
M("`@("!S=VET8V@@*"1T>7!E6S%=*2!["B`@("`@("`@("`@(&-A<V4@)W5P
M)SH*("`@("`@("`@("`@("`@("1T:71L92`](%\H(DUO=F4@57`B*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9&]W;B<Z
M"B`@("`@("`@("`@("`@("`D=&ET;&4@/2!?*")-;W9E($1O=VXB*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;&5F="<Z
M"B`@("`@("`@("`@("`@("`D=&ET;&4@/2!?*")-;W9E($QE9G0B*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<FEG:'0G
M.@H@("`@("`@("`@("`@("`@)'1I=&QE(#T@7R@B36]V92!2:6=H="(I.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1I;6<@/2`D='EP95LQ73L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH)'5R;"P@)'1I=&QE
M*2`N"B`@("`@("`@("`@($AO<F1E.CII;6<H)V)L;V-K+R<@+B`D:6UG("X@
M)RYP;F<G+"`D=&ET;&4L("<G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&]E<R!A(')O=R!E>&ES=#\*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!4:&4@<F]W('1O(&QO;VL@9F]R"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!R;W<@97AI<W1S"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')O=T5X:7-T<R@D<F]W*0H@("`@>PH@("`@
M("`@(')E='5R;B`D<F]W(#P@8V]U;G0H)'1H:7,M/E]L87EO=70I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&]E<R!A(&-O;'5M;B!E>&ES=#\*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!4:&4@8V]L=6UN('1O(&QO
M;VL@9F]R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('1H92!C;VQU;6X@97AI<W1S"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;$5X
M:7-T<R@D8V]L*0H@("`@>PH@("`@("`@(')E='5R;B`D8V]L(#P@)'1H:7,M
M/E]C;VQU;6YS.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!W:61T
M:"!O9B!T:&4@8FQO8VL@870@82!G:79E;B!L;V-A=&EO;BX*("`@("`J(%1H
M:7,@<F5T=7)N<R!T:&4@=VED=&@@:68@=&AE<F4@:7,@82!B;&]C:R!A="!T
M:&ES"B`@("`@*B!L;V-A=&EO;BP@;W1H97)W:7-E(')E='5R;G,@,2X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F
M(&-O;'5M;G,@=&AI<R!B;&]C:R!S<&%N<PH@("`@("HO"B`@("!F=6YC=&EO
M;B!G9717:61T:"@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI*2!["B`@("`@("`@
M("`@(')E='5R;B`Q.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=W:61T:"==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG=VED=&@G72`](#$[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD8V]L75LG=VED=&@G73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@:&5I9VAT(&]F('1H92!B;&]C:R!A="!A(&=I=F5N(&QO8V%T:6]N+@H@
M("`@("H@5&AI<R!R971U<FYS('1H92!H96EG:'0@:68@=&AE<F4@:7,@82!B
M;&]C:R!A="!T:&ES"B`@("`@*B!L;V-A=&EO;BP@;W1H97)W:7-E(')E='5R
M;G,@,2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA
M>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U
M="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@
M;G5M8F5R(&]F(')O=W,@=&AI<R!B;&]C:R!S<&%N<PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971(96EG:'0H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2D@>PH@
M("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!]"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=H96EG
M:'0G72`](#$["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VQA
M>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT)UT["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&%N(&5M<'1Y(&)L;V-K(&%T('1H92!S<&5C:69I960@<&]S
M:71I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1";&]C:R@D<F]W
M+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/G)O=T5X:7-T<R@D
M<F]W*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D4F]W*"1R;W<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21T:&ES+3YC;VQ%>&ES=',H)&-O;"DI('L*
M("`@("`@("`@("`@)'1H:7,M/F%D9$-O;"@D8V]L*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T@87)R87DH)V%P
M<"<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H96EG:'0G(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@G(#T^(#$L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]
M/B!A<G)A>2@G='EP92<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A
M;7,G(#T^(&%R<F%Y*"DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M82!N97<@<F]W('1O('1H92!L87EO=70N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)')O=R`@5&AE(&YU;6)E<B!O9B!T:&4@<F]W('1O(&%D9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&12;W<H)')O=RD*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]C;VQU;6YS(#X@,"D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W72`](&%R<F%Y7V9I;&PH,"P@)'1H:7,M/E]C;VQU
M;6YS+"`G96UP='DG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&$@;F5W(&-O;'5M;B!T;R!T:&4@;&%Y;W5T+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C;VP@(%1H92!N=6UB97(@;V8@=&AE(&-O
M;'5M;B!T;R!A9&0*("`@("`J+PH@("`@9G5N8W1I;VX@861D0V]L*"1C;VPI
M"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]L87EO=70@87,@)&ED
M(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&ED75LD
M8V]L72`]("=E;7!T>2<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?8V]L
M=6UN<RLK.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A(&)L;V-K
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T
M(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O
M;'5M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0FQO8VLH)')O=RP@
M)&-O;"D*("`@('L*("`@("`@("`D=VED=&@@/2`D=&AI<RT^9V5T5VED=&@H
M)')O=RP@)&-O;"D["B`@("`@("`@)&AE:6=H="`]("1T:&ES+3YG971(96EG
M:'0H)')O=RP@)&-O;"D["B`@("`@("`@9F]R("@D:2`]("1H96EG:'0@+2`Q
M.R`D:2`^/2`P.R`D:2TM*2!["B`@("`@("`@("`@(&9O<B`H)&H@/2`D=VED
M=&@@+2`Q.R`D:B`^/2`P.R`D:BTM*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VP@*R`D:ET@/2`G96UP='DG.PH@
M("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1C;VP@*R`D
M:B`K(#$I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G)E;6]V94-O
M;$EF16UP='DH)&-O;"`K("1J*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(21T:&ES+3YR;W=%>&ES=',H)')O
M=R`K("1I("L@,2D@)B8@)'1H:7,M/G)O=T5X:7-T<R@D<F]W("L@)&DI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5M;W9E4F]W269%;7!T>2@D<F]W
M("L@)&DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG
M961?8V]L(#T@)&-O;#L*"B`@("`@("`@:68@*"$D=&AI<RT^<F]W17AI<W1S
M*"1R;W<I*2!["B`@("`@("`@("`@("1R;W<M+3L*("`@("`@("`@("`@=VAI
M;&4@*"1R;W<@/CT@,"`F)B`D=&AI<RT^<F5M;W9E4F]W269%;7!T>2@D<F]W
M*2D@>PH@("`@("`@("`@("`@("`@)')O=RTM.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/F-O;$5X:7-T<R@D8V]L*2D@
M>PH@("`@("`@("`@("`D8V]L+2T["B`@("`@("`@("`@('=H:6QE("@D8V]L
M(#X](#`@)B8@)'1H:7,M/G)E;6]V94-O;$EF16UP='DH)&-O;"DI('L*("`@
M("`@("`@("`@("`@("1C;VPM+3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!R;W<@:68@:70G<R!E
M;7!T>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!4:&4@
M;G5M8F5R(&]F('1H92!R;W<@=&\@=&\@8VAE8VL*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(')O=R!I<R!N;W<@<F5M;W9E
M9"X*("`@("`J("`@("`@("`@("`@("`@("`@1F%L<V4@:68@=&AE(')O=R!S
M=&EL;"!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V95)O=TEF
M16UP='DH)')O=RD*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YR;W=%>&ES
M=',H)')O=RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("`D<F]W<R`](&-O=6YT*"1T:&ES+3Y?;&%Y;W5T6R1R;W==
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<F]W<SL@)&DK*RD@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]L87EO=71;)')O=UU;)&E=
M*2`F)B`D=&AI<RT^7VQA>6]U=%LD<F]W75LD:5T@(3T@)V5M<'1Y)RD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@('5N<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96UO=F5S(&$@8V]L=6UN(&EF(&ET)W,@96UP='DN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-O;"`@5&AE(&YU;6)E<B!O9B!T:&4@8V]L=6UN
M('1O('1O(&-H96-K"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!C;VQU;6X@:7,@;F]W(')E;6]V960N"B`@("`@*B`@("`@
M("`@("`@("`@("`@($9A;'-E(&EF('1H92!C;VQU;6X@<W1I;&P@97AI<W1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5#;VQ)9D5M<'1Y*"1C;VPI
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1C;VPI*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA>6]U="D["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&-O;',[("1I*RLI('L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;&%Y;W5T6R1I75LD8V]L72D@)B8@)'1H:7,M/E]L87EO
M=71;)&E=6R1C;VQ=("$]("=E;7!T>2<I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)&-O;',[("1I*RLI('L*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]L87EO=71;)&E=6R1C;VQ=*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V
M97,@82!B;&]C:R!O;F4@<F]W('5P+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@;6]V955P*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YR;W=%>&ES=',H)')O=R`M(#$I*2!["B`@("`@("`@("`@("1W:61T:"`]
M("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@+R\@
M4V5E(&EF('1H97)E)W,@<F]O;2!T;R!M;W9E(&EN=&\*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1R;W<@+2`Q+"`D8V]L("L@)&DI
M*2!["B`@("`@("`@("`@("`@("`@("`@)&EN7W=A>2`]("1T:&ES+3YG971"
M;&]C:T%T*"1R;W<@+2`Q+"`D8V]L("L@)&DI.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-?;G5L;"@D:6Y?=V%Y*2`F)@H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6Y?=V%Y6S%=(#T]("1C;VP@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F=E=%=I9'1H*"1I;E]W87E;,%TL("1I;E]W87E;
M,5TI(#T]("1W:61T:"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!7
M92!N965D('1O('-W87`@=&AE(&)L;V-K<RX*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E8S$@/2!(;W)D95]!<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES
M+3Y?;&%Y;W5T+"`D<F]W+"`D8V]L+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=$AE:6=H="@D<F]W+"`D8V]L*2P@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C
M;VPI*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E8S(@/2!(;W)D95]!
M<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES+3Y?;&%Y;W5T+"`D:6Y?=V%Y6S!=
M+"`D:6Y?=V%Y6S%=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D
M:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2P@)'1H:7,M/F=E=%=I9'1H*"1I;E]W
M87E;,%TL("1I;E]W87E;,5TI*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S$I.R`D:BLK*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N
M="@D<F5C,5LD:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L87EO=71;)&EN7W=A>5LP72`K("1J75LD:6Y?
M=V%Y6S%=("L@)&M=(#T@)')E8S%;)&I=6R1K73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D
M<F5C,BD[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R96,R6R1J72D[("1K*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M:6Y?=V%Y6S!=("L@8V]U;G0H)')E8S$I("L@)&I=6R1I;E]W87E;,5T@*R`D
M:UT@/2`D<F5C,ELD:EU;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D:6Y?=V%Y6S!=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@
M)&EN7W=A>5LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O+R!.
M;W=H97)E('1O(&=O+@H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN
M9R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D;&%S=')O=R`]("1R;W<@*R`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L
M("1C;VPI("T@,3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I
M9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<')E=B`]("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T["B`@("`@("`@("`@("`@("`O+R!-
M;W9E('1O<"!E9&=E"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W("T@,5U;)&-O;"`K("1I72`]("1P<F5V.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I72`]("=C;W9E<F5D)SL*
M("`@("`@("`@("`@("`@("\O($UO=F4@8F]T=&]M(&5D9V4*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L87-T<F]W75LD8V]L("L@)&E=(#T@
M)V5M<'1Y)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^<F]W17AI<W1S*"1L87-T<F]W("L@,2DI('L*("`@("`@("`@("`@("`@
M("\O(%=A<R!O;B!T:&4@8F]T=&]M(')O=PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G)E;6]V95)O=TEF16UP='DH)&QA<W1R;W<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O
M=R`M(#$["B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&)L;V-K(&]N92!R;W<@9&]W
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F5$;W=N*"1R;W<L("1C
M;VPI"B`@("!["B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R
M;W<L("1C;VPI.PH@("`@("`@("1L87-T<F]W(#T@)')O=R`K("1T:&ES+3YG
M971(96EG:'0H)')O=RP@)&-O;"D["B`@("`@("`@:68@*"1T:&ES+3YR;W=%
M>&ES=',H)&QA<W1R;W<I*2!["B`@("`@("`@("`@("\O(%-E92!I9B!T:&5R
M92=S(')O;VT@=&\@;6]V92!I;G1O"B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1W:61T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"$D
M=&AI<RT^:7-%;7!T>2@D;&%S=')O=RP@)&-O;"`K("1I*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1I;E]W87D@/2`D=&AI<RT^9V5T0FQO8VM!="@D;&%S
M=')O=RP@)&-O;"`K("1I*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M7VYU;&PH)&EN7W=A>2D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M7W=A>5LQ72`]/2`D8V]L("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2`]/2`D=VED
M=&@I('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;F5E9"!T;R!S
M=V%P('1H92!B;&]C:W,N"B`@("`@("`@("`@("`@("`@("`@("`@("1R96,Q
M(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@
M)')O=RP@)&-O;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)')O
M=RP@)&-O;"DL("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1R96,R(#T@2&]R9&5?07)R87DZ.F=E=%)E
M8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@)&EN7W=A>5LP72P@)&EN7W=A>5LQ
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)&EN7W=A>5LP72P@
M)&EN7W=A>5LQ72DL("1T:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?
M=V%Y6S%=*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P
M.R`D:B`\(&-O=6YT*"1R96,R*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E8S);)&I=
M*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:EU;)&-O;"`K("1K72`]("1R96,R6R1J
M75LD:UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S$I.R`D:BLK*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N="@D
M<F5C,5LD:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K(&-O=6YT*"1R96,R*2`K("1J
M75LD8V]L("L@)&M=(#T@)')E8S%;)&I=6R1K73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)&EN
M7W=A>5LP73L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D7V-O;"`]("1I;E]W87E;,5T["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@+R\@3F\@=VAE<F4@=&\@9V\*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B*2P@)VAO
M<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($UA:V4@<F]O;2!T
M;R!M;W9E(&EN=&\*("`@("`@("`@("`@)'1H:7,M/F%D9%)O=R@D;&%S=')O
M=RD["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED
M=&@[("1I*RLI('L*("`@("`@("`@("`@)'!R978@/2`D=&AI<RT^7VQA>6]U
M=%LD<F]W75LD8V]L("L@)&E=.PH@("`@("`@("`@("`O+R!-;W9E(&)O='1O
M;2!E9&=E"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L87-T<F]W75LD
M8V]L("L@)&E=(#T@)V-O=F5R960G.PH@("`@("`@("`@("`O+R!-;W9E('1O
M<"!E9&=E"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`Q75LD
M8V]L("L@)&E=(#T@)'!R978["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W==6R1C;VP@*R`D:5T@/2`G96UP='DG.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<@*R`Q.PH@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@?0H*("`@("\J*@H@("`@
M("H@36]V97,@86QL(&)L;V-K<R!B96QO=R!A(&-E<G1A:6X@<F]W(&]N92!R
M;W<@9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!
M(&QA>6]U="!R;W<N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF(&%L;"!R;W=S(&-O=6QD(&)E(&UO=F5D(&1O=VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&UO=F5$;W=N0F5L;W<H)')O=RD*("`@('L*("`@("`@
M("`D;6]V960@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)'D@/2!C;W5N="@D
M=&AI<RT^7VQA>6]U="D@+2`Q.R`D>2`^("1R;W<[("1Y+2TI('L*("`@("`@
M("`@("`@9F]R("@D>"`](#`[("1X(#P@)'1H:7,M/E]C;VQU;6YS.R`D>"LK
M*2!["B`@("`@("`@("`@("`@("`D8FQO8VL@/2`D=&AI<RT^9V5T0FQO8VM!
M="@D>2P@)'@I.PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1B;&]C:RDI
M('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;6]V961;)&)L;V-K
M6S%=("X@)SHG("X@)&)L;V-K6S!=72DI('L*("`@("`@("`@("`@("`@("`@
M("`D;6]V961;)&)L;V-K6S%=("X@)SHG("X@)&)L;V-K6S!=72`]('1R=64[
M"B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YM;W9E1&]W
M;B@D8FQO8VM;,%TL("1B;&]C:ULQ72D["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M36]V97,@82!B;&]C:R!O;F4@8V]L=6UN(&QE9G0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!M;W9E3&5F="@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^8V]L17AI<W1S*"1C;VP@+2`Q*2D@>PH@("`@("`@("`@
M("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@
M("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O;2!T;R!M;W9E(&EN=&\N
M"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI
M('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES16UP='DH)')O=R`K
M("1I+"`D8V]L("T@,2DI('L*("`@("`@("`@("`@("`@("`@("`D:6Y?=V%Y
M(#T@)'1H:7,M/F=E=$)L;V-K070H)')O=R`K("1I+"`D8V]L("T@,2D["B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1I;E]W87DI("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;E]W87E;,%T@/3T@)')O=R`F)@H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1I;E]W
M87E;,%TL("1I;E]W87E;,5TI(#T]("1H96EG:'0I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@5V4@;F5E9"!T;R!S=V%P('1H92!B;&]C:W,N"B`@
M("`@("`@("`@("`@("`@("`@("`@("1R96,Q(#T@2&]R9&5?07)R87DZ.F=E
M=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@)')O=RP@)&-O;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"DL("1T:&ES+3YG
M9717:61T:"@D<F]W+"`D8V]L*2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R96,R(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA
M>6]U="P@)&EN7W=A>5LP72P@)&EN7W=A>5LQ72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG971(96EG:'0H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72DL("1T:&ES
M+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\(&-O=6YT*"1R96,Q
M*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D
M:R`](#`[("1K(#P@8V]U;G0H)')E8S%;)&I=*3L@)&LK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1I;E]W
M87E;,%T@*R`D:EU;)&EN7W=A>5LQ72`K("1K72`]("1R96,Q6R1J75LD:UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:B`]
M(#`[("1J(#P@8V]U;G0H)')E8S(I.R`D:BLK*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N="@D<F5C,ELD
M:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)&EN7W=A>5LP72`K("1J75LD:6Y?=V%Y6S%=("L@
M8V]U;G0H)')E8S%;)&I=*2`K("1K72`]("1R96,R6R1J75LD:UT["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D
M7W)O=R`]("1I;E]W87E;,%T["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9%]C;VP@/2`D:6Y?=V%Y6S%=.PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("\O($YO('=H97)E('1O(&=O"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1L87-T8V]L(#T@)&-O;"`K("1T
M:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@
M("`@("1P<F5V(#T@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L73L*
M("`@("`@("`@("`@("`@("\O($UO=F4@;&5F="!H86YD(&5D9V4*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&-O;"`M(#%=
M(#T@)'!R978["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W
M("L@)&E=6R1C;VQ=(#T@)V-O=F5R960G.PH@("`@("`@("`@("`@("`@+R\@
M36]V92!R:6=H="!H86YD(&5D9V4*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T6R1R;W<@*R`D:5U;)&QA<W1C;VQ=(#T@)V5M<'1Y)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1L
M87-T8V]L("L@,2DI('L*("`@("`@("`@("`@("`@("\O(%=A<R!O;B!T:&4@
M<FEG:'0M;6]S="!C;VQU;6X*("`@("`@("`@("`@("`@("1T:&ES+3YR96UO
M=F5#;VQ)9D5M<'1Y*"1L87-T8V]L*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<["B`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L("T@,3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&)L;V-K(&]N92!C;VQU;6X@
M<FEG:'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E4FEG:'0H)')O
M=RP@)&-O;"D*("`@('L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE
M:6=H="@D<F]W+"`D8V]L*3L*("`@("`@("`D;&%S=&-O;"`]("1C;VP@*R`D
M=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D["B`@("`@("`@:68@*"1T:&ES
M+3YC;VQ%>&ES=',H)&QA<W1C;VPI*2!["B`@("`@("`@("`@("\O(%-E92!I
M9B!T:&5R92=S(')O;VT@=&\@;6]V92!I;G1O+@H@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1R;W<@*R`D:2P@)&QA<W1C;VPI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&EN7W=A>2`]("1T:&ES+3YG971";&]C
M:T%T*"1R;W<@*R`D:2P@)&QA<W1C;VPI.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D:6Y?=V%Y*2`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6Y?=V%Y6S!=(#T]("1R;W<@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F=E=$AE:6=H="@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=
M*2`]/2`D:&5I9VAT*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E
M(&YE960@=&\@<W=A<"!T:&4@8FQO8VMS+@H@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5C,2`]($AO<F1E7T%R<F%Y.CIG971296-T86YG;&4H)'1H:7,M
M/E]L87EO=70L("1R;W<L("1C;VPL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T
M2&5I9VAT*"1R;W<L("1C;VPI+"`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O
M;"DI.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5C,B`]($AO<F1E7T%R
M<F%Y.CIG971296-T86YG;&4H)'1H:7,M/E]L87EO=70L("1I;E]W87E;,%TL
M("1I;E]W87E;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1I
M;E]W87E;,%TL("1I;E]W87E;,5TI+"`D=&AI<RT^9V5T5VED=&@H)&EN7W=A
M>5LP72P@)&EN7W=A>5LQ72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!F
M;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D<F5C,BD[("1J*RLI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O=6YT
M*"1R96,R6R1J72D[("1K*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&I=6R1C;VP@*R`D:UT@
M/2`D<F5C,ELD:EU;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\(&-O=6YT*"1R96,Q*3L@)&HK*RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:R`](#`[("1K
M(#P@8V]U;G0H)')E8S%;)&I=*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:EU;)&-O
M;"`K(&-O=6YT*"1R96,R6R1J72D@*R`D:UT@/2`D<F5C,5LD:EU;)&M=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9%]R;W<@/2`D:6Y?=V%Y6S!=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&EN7W=A>5LQ73L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`O+R!.;R!W:&5R92!T;R!G;PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+R\@36%K92!R;V]M('1O(&UO=F4@:6YT;RX*("`@("`@("`@("`@)'1H:7,M
M/F%D9$-O;"@D;&%S=&-O;"D["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("1P<F5V
M(#T@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L73L*("`@("`@("`@
M("`@+R\@36]V92!R:6=H="!H86YD(&5D9V4*("`@("`@("`@("`@)'1H:7,M
M/E]L87EO=71;)')O=R`K("1I75LD;&%S=&-O;%T@/2`G8V]V97)E9"<["B`@
M("`@("`@("`@("\O($UO=F4@;&5F="!H86YD(&5D9V4*("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L("L@,5T@/2`D<')E=CL*
M("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L72`]
M("=E;7!T>2<["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?
M<F]W(#T@)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O
M;"`K(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A;&P@8FQO8VMS
M(&%F=&5R(&$@8V5R=&%I;B!C;VQU;6X@;VYE(&-O;'5M;B!R:6=H="X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU
M;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&%L
M;"!C;VQU;6YS(&-O=6QD(&)E(&UO=F5D(')I9VAT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!M;W9E4FEG:'1!9G1E<B@D8V]L*0H@("`@>PH@("`@("`@("1M
M;W9E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D>"`]("1T:&ES+3Y?8V]L
M=6UN<R`M(#$[("1X(#X@)&-O;#L@)'@M+2D@>PH@("`@("`@("`@("!F;W(@
M*"1Y(#T@,#L@)'D@/"!C;W5N="@D=&AI<RT^7VQA>6]U="D[("1Y*RLI('L*
M("`@("`@("`@("`@("`@("1B;&]C:R`]("1T:&ES+3YG971";&]C:T%T*"1Y
M+"`D>"D["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&)L;V-K*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1M;W9E9%LD8FQO8VM;,5T@
M+B`G.B<@+B`D8FQO8VM;,%U=*2D@>PH@("`@("`@("`@("`@("`@("`@("1M
M;W9E9%LD8FQO8VM;,5T@+B`G.B<@+B`D8FQO8VM;,%U=(#T@=')U93L*("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/FUO=F52:6=H="@D
M8FQO8VM;,%TL("1B;&]C:ULQ72D["B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@36%K
M97,@82!B;&]C:R!O;F4@<F]W('1A;&QE<B!B>2!M;W9I;F<@=&AE('1O<"!U
M<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&%N9%5P*"1R;W<L("1C
M;VPI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YR;W=%>&ES=',H)')O=R`M
M(#$I*2!["B`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D
M<F]W+"`D8V]L*3L*("`@("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O
M;2!T;R!E>'!A;F0@:6YT;PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M
M/FES16UP='DH)')O=R`M(#$L("1C;VP@*R`D:2DI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H(21T:&ES+3YM;W9E1&]W;D)E;&]W*"1R;W<@+2`Q*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<F]W*RL["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1R;W<@+2`Q75LD8V]L("L@)&E=(#T@)'1H:7,M/E]L87EO
M=71;)')O=UU;)&-O;"`K("1I73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@/2`G8V]V97)E9"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`M(#%=6R1C
M;VQ=6R=H96EG:'0G72`]("1T:&ES+3YG971(96EG:'0H)')O=R`M(#$L("1C
M;VPI("L@,3L*"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D
M<F]W("T@,3L*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C
M;VP["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@82!B
M;&]C:R!O;F4@<F]W('1A;&QE<B!B>2!M;W9I;F<@=&AE(&)O='1O;2!D;W=N
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T
M(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O
M;'5M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@97AP86YD1&]W;B@D<F]W+"`D
M8V]L*0H@("`@>PH@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D
M<F]W+"`D8V]L*3L*("`@("`@("`D;&%S=')O=R`]("1R;W<@*R`D=&AI<RT^
M9V5T2&5I9VAT*"1R;W<L("1C;VPI("T@,3L*("`@("`@("!I9B`H(21T:&ES
M+3YR;W=%>&ES=',H)&QA<W1R;W<@*R`Q*2D@>PH@("`@("`@("`@("`O+R!!
M9&0@82!N97<@<F]W+@H@("`@("`@("`@("`D=&AI<RT^861D4F]W*"1L87-T
M<F]W("L@,2D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T
M:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&QA
M<W1R;W<@*R`Q75LD8V]L("L@)&E=(#T@)V-O=F5R960G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=H
M96EG:'0G72`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D@*R`Q.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%-E92!I9B!T:&5R92=S
M(')O;VT@=&\@97AP86YD(&EN=&\*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H(21T
M:&ES+3YI<T5M<'1Y*"1L87-T<F]W("L@,2P@)&-O;"`K("1I*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FUO=F5$;W=N0F5L;W<H)&QA
M<W1R;W<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN
M9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M=%LD;&%S=')O=R`K(#%=6R1C;VP@*R`D:5T@/2`G8V]V97)E9"<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O
M;%U;)VAE:6=H="==(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`K
M(#$["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@
M)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*("`@
M('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(&-O;'5M;B!W
M:61E<B!B>2!M;W9I;F<@=&AE(&QE9G0@<VED92!O=70N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>'!A;F1,969T*"1R;W<L("1C;VPI"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YC;VQ%>&ES=',H)&-O;"`M(#$I*2!["B`@("`@
M("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI
M.PH@("`@("`@("`@("`O+R!3964@:68@=&AE<F4G<R!R;V]M('1O(&5X<&%N
M9"!I;G1O"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[
M("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES16UP='DH
M)')O=R`K("1I+"`D8V]L("T@,2DI('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(21T:&ES+3YM;W9E4FEG:'1!9G1E<B@D8V]L("T@,2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;"LK.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO
M=71;)')O=R`K("1I75LD8V]L("T@,5T@/2`D=&AI<RT^7VQA>6]U=%LD<F]W
M("L@)&E=6R1C;VQ=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;
M)')O=R`K("1I75LD8V]L72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L("T@,5U;)W=I
M9'1H)UT@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"`M(#$I("L@,3L*
M"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@("`@
M("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;"`M(#$["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@
M8V]L=6UN('=I9&5R(&)Y(&UO=FEN9R!T:&4@<FEG:'0@<VED92!O=70N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!A;F12:6=H="@D<F]W+"`D8V]L
M*0H@("`@>PH@("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R
M;W<L("1C;VPI.PH@("`@("`@("1L87-T8V]L(#T@)&-O;"`K("1T:&ES+3YG
M9717:61T:"@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@:68@*"1T:&ES+3YC
M;VQ%>&ES=',H)&QA<W1C;VP@*R`Q*2D@>PH@("`@("`@("`@("`O+R!3964@
M:68@=&AE<F4G<R!R;V]M('1O(&5X<&%N9"!I;G1O"B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@
M("`@(&EF("@A)'1H:7,M/FES16UP='DH)')O=R`K("1I+"`D;&%S=&-O;"`K
M(#$I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^;6]V95)I
M9VAT069T97(H)&QA<W1C;VPI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G
M:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD;&%S=&-O;"`K(#%=(#T@)V-O
M=F5R960G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W==6R1C;VQ=6R=W:61T:"==(#T@)'1H:7,M/F=E=%=I9'1H*"1R
M;W<L("1C;VPI("L@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!!9&0@;F5W(&-O;'5M;@H@("`@("`@("`@("`D=&AI<RT^861D0V]L*"1L
M87-T8V]L("L@,2D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H
M96EG:'0[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`D:5U;)&QA<W1C;VP@*R`Q72`]("=C;W9E<F5D)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M75LG=VED=&@G72`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2`K(#$[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O
M=SL*("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*("`@('T*
M"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(')O=R!L;W=E<B!B
M>2!M;W9I;F<@=&AE('1O<"!D;W=N+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VAR:6YK57`H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`^(#$I('L*("`@("`@("`@("`@
M)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI.PH@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`Q75LD8V]L("L@)&E=
M(#T@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I73L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@/2`G96UP
M='DG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`Q75LD8V]L75LG:&5I9VAT)UT@/2`D=&AI<RT^9V5T2&5I9VAT
M*"1R;W<@*R`Q+"`D8V]L*2`M(#$["@H@("`@("`@("`@("`D=&AI<RT^7V-H
M86YG961?<F]W(#T@)')O=R`K(#$["B`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9%]C;VP@/2`D8V]L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($UA:V5S(&$@8FQO8VL@;VYE(')O=R!L;W=E<B!B>2!M;W9I;F<@=&AE
M(&)O='1O;2!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W
M("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!
M(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H<FEN:T1O
M=VXH)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E=$AE
M:6=H="@D<F]W+"`D8V]L*2`^(#$I('L*("`@("`@("`@("`@)&QA<W1R;W<@
M/2`D<F]W("L@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`M(#$["B`@
M("`@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L
M*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD;&%S=')O=UU;
M)&-O;"`K("1I72`]("=E;7!T>2<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)VAE:6=H="==(#T@)'1H
M:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@(&EF
M("@A)'1H:7,M/G)O=T5X:7-T<R@D;&%S=')O=R`K(#$I*2!["B`@("`@("`@
M("`@("`@("`O+R!787,@;VX@=&AE(&)O='1O;2!R;W<*("`@("`@("`@("`@
M("`@("1T:&ES+3YR96UO=F52;W=)9D5M<'1Y*"1L87-T<F]W*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R
M;W<["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@
M;VYE(&-O;'5M;B!N87)R;W=E<B!B>2!M;W9I;F<@=&AE(&QE9G0@<VED92!I
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H<FEN:TQE9G0H)')O=RP@
M)&-O;"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E=%=I9'1H*"1R;W<L
M("1C;VPI(#X@,2D@>PH@("`@("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=E
M=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]L87EO=71;)')O=R`K("1I75LD8V]L("L@,5T@/2`D=&AI<RT^7VQA>6]U
M=%LD<F]W("L@)&E=6R1C;VQ=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=R`K("1I75LD8V]L72`]("=E;7!T>2<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K(#%=
M6R=W:61T:"==(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VP@*R`Q*2`M
M(#$["@H@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*
M("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP@*R`Q.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@
M;VYE(&-O;'5M;B!N87)R;W=E<B!B>2!M;W9I;F<@=&AE(')I9VAT('-I9&4@
M:6XN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO
M=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@
M8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:')I;FM2:6=H="@D<F]W
M+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T5VED=&@H)')O
M=RP@)&-O;"D@/B`Q*2!["B`@("`@("`@("`@("1L87-T8V]L(#T@)&-O;"`K
M("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@
M("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1L87-T
M8V]L72`]("=E;7!T>2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W=I9'1H)UT@/2`D=&AI<RT^9V5T
M5VED=&@H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@("`@("`D=&AI<RT^<F5M
M;W9E0V]L269%;7!T>2@D;&%S=&-O;"D["@H@("`@("`@("`@("`D=&AI<RT^
M7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D7V-O;"`]("1C;VP["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R]522YP
M:'``````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4W-C<`
M,3`U,34T,S$P-C$`,#(P,S$S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!#;&%S<R!F;W(@<V5T=&EN
M9R!U<"!(;W)D92!";&]C:W,@=7-I;F<@=&AE($AO<F1E7T9O<FTZ.B!C;&%S
M<V5S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UA<FMO($1J=6MI8R`\
M;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`L=B`Q+C@N,3`N-2`R,#`V+S`Q
M+S`R(#$W.C0V.C,U(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K;R!$
M:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K
M7U5)('L*"B`@("!V87(@)%]B;&]C:W,@/2!A<G)A>2@I.PH@("`@=F%R("1?
M9F]R;2`](&YU;&P["B`@("!V87(@)%]V87)S(#T@;G5L;#L*"B`@("!F=6YC
M=&EO;B!(;W)D95]";&]C:U]522@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]";&]C:RYP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`G.PH@("`@("`@("1T:&ES+3Y?
M8FQO8VMS(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.G-I;F=L971O;B@I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$9O<FTH)B1F;W)M*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?9F]R;2`]("8D9F]R;3L*("`@('T*"B`@("!F=6YC
M=&EO;B!S971687)S*"8D=F%R<RD*("`@('L*("`@("`@("`D=&AI<RT^7W9A
M<G,@/2`F)'9A<G,["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T=7!%9&ET1F]R
M;2@D9FEE;&0@/2`G8FQO8VLG*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL
M*"1T:&ES+3Y?=F%R<RDI('L*("`@("`@("`@("`@+RH@3F\@97AI<W1I;F<@
M=F%R<R!S970L(&=E="!T:&5M(&YO=RX@*B\*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]687)I86)L97,N<&AP)SL*("`@("`@("`@("`@)'1H
M:7,M/E]V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]A*"1T:&ES+3Y?9F]R;2P@
M)TAO<F1E7T9O<FTG*2D@>PH@("`@("`@("`@("`O*B!.;R!E>&ES=&EN9R!V
M86QI9"!F;W)M(&]B:F5C="!S970@<V\@<V5T('5P(&$@;F5W(&]N92X@*B\*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<["B`@
M("`@("`@("`@("1T:&ES+3Y?9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T
M;VXH)R<L("1T:&ES+3Y?=F%R<RP@7R@B161I="!";&]C:R(I*3L*("`@("`@
M("!]"@H@("`@("`@("\J($=E="!T:&4@8W5R<F5N="!V86QU92!O9B!T:&4@
M8FQO8VL@<V5L96-T:6]N+B`J+PH@("`@("`@("1V86QU92`]("1T:&ES+3Y?
M=F%R<RT^9V5T*"1F:65L9"D["@H@("`@("`@("\J($9I96QD('1O('-E;&5C
M="!A<'!S+B`J+PH@("`@("`@("1A<'!S(#T@)'1H:7,M/E]B;&]C:W,M/F=E
M=$)L;V-K<TQI<W0H*3L*("`@("`@("`D=B`]("8D=&AI<RT^7V9O<FTM/F%D
M9%9A<FEA8FQE*%\H(D%P<&QI8V%T:6]N(BDL("1F:65L9"`N("=;87!P72<L
M("=E;G5M)RP@=')U92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1A<'!S*2D["B`@
M("`@("`@)'8M/G-E=$]P=&EO;B@G=')A8VMC:&%N9V4G+"!T<G5E*3L*"B`@
M("`@("`@:68@*&5M<'1Y*"1V86QU95LG87!P)UTI*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($EF(&$@8FQO8VL@:&%S
M(&)E96X@<V5L96-T960L(&]U='!U="!A;GD@;W!T:6]N<R!I;G!U="X@*B\*
M("`@("`@("!L:7-T*"1A<'`L("1B;&]C:RD@/2!E>'!L;V1E*"<Z)RP@)'9A
M;'5E6R=A<'`G72D["@H@("`@("`@("\J($=E="!T:&4@;W!T:6]N<R!F;W(@
M=&AE(')E<75E<W1E9"!B;&]C:RX@*B\*("`@("`@("`D;W!T:6]N<R`]("1T
M:&ES+3Y?8FQO8VMS+3YG971087)A;7,H)&%P<"P@)&)L;V-K*3L*"B`@("`@
M("`@+RH@1V\@=&AR;W5G:"!T:&4@;W!T:6]N<R!F;W(@=&AI<R!B;&]C:R!A
M;F0@<V5T('5P(&%N>2!R97%U:7)E9`H@("`@("`@("`J(&5X=')A(&EN<'5T
M+B`J+PH@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O<'1I;VXI('L*
M("`@("`@("`@("`@)&YA;64@/2`D=&AI<RT^7V)L;V-K<RT^9V5T4&%R86U.
M86UE*"1A<'`L("1B;&]C:RP@)&]P=&EO;BD["B`@("`@("`@("`@("1T>7!E
M(#T@)'1H:7,M/E]B;&]C:W,M/F=E=$]P=&EO;E1Y<&4H)&%P<"P@)&)L;V-K
M+"`D;W!T:6]N*3L*("`@("`@("`@("`@)')E<75I<F5D(#T@)'1H:7,M/E]B
M;&]C:W,M/F=E=$]P=&EO;E)E<75I<F5D*"1A<'`L("1B;&]C:RP@)&]P=&EO
M;BD["B`@("`@("`@("`@("1V86QU97,@/2`D=&AI<RT^7V)L;V-K<RT^9V5T
M3W!T:6]N5F%L=65S*"1A<'`L("1B;&]C:RP@)&]P=&EO;BD["B`@("`@("`@
M("`@("\J(%1/1$\Z('1H92!S971T:6YG("=S=')I;F<G('-H;W5L9"!B92!C
M:&%N9V5D(&EN(&%L;"!B;&]C:W,*("`@("`@("`@("`@("H@=&\@)W1E>'0G
M('-O('1H870@:70@8V]N9F]R;7,@=VET:"!(;W)D95]&;W)M('-Y;G1A>"X@
M*B\*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=S=')I;F<G*2!["B`@("`@
M("`@("`@("`@("`D='EP92`]("=T97AT)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`@("`@:68@*"1T
M>7!E(#T]("=E;G5M)R!\?"`D='EP92`]/2`G;6QE;G5M)RD@>PH@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"1V86QU97,L('1R=64I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B
M;&4H)&YA;64L("1F:65L9"`N("=;;W!T:6]N<UU;)R`N("1O<'1I;VX@+B`G
M72<L("1T>7!E+"`D<F5Q=6ER960L(&9A;'-E+"!N=6QL+"`D<&%R86US*3L*
M("`@("`@("!]"B`@("!]"@I]"@```````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-C4U,0`Q,#4Q-30S,3`V,0`P,C(P
M-C0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*"B\J*@H@
M*B!4:&4@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ(&-L87-S('!R;W9I9&5S
M(&%N($%022!T;R!T:&4@8FQO8VMS"B`J("AA<'!L971S*2!F<F%M97=O<FLN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP+'8@,2XS-BXT+C$W(#(P,#8O,#,O,#@@,3<Z-3,Z-3(@8VAU8VL@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX@>PH*
M("`@("\J*@H@("`@("H@5VAA="!K:6YD(&]F(&)L;V-K<R!A<F4@=V4@8V]L
M;&5C=&EN9S\@1&5F875L=',@=&\@86YY+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1Y<&4@/2`G<&]R=&%L)SL*"B`@
M("`O*BH*("`@("`J($$@:&%S:"!S=&]R:6YG('1H92!I;F9O<FUA=&EO;B!A
M8F]U="!A;&P@879A:6QA8FQE(&)L;V-K<R!F<F]M"B`@("`@*B!A;&P@87!P
M;&EC871I;VYS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?8FQO8VMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M(%1H92!K:6YD(&]F(&)L;V-K<R!T;R!L:7-T+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1A<'!S("`@5&AE(&%P<&QI8V%T:6]N<R!W:&]S92!B;&]C:W,@=&\@
M;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0FQO8VM?0V]L;&5C
M=&EO;B@D='EP92`](&YU;&PL("1A<'!S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H(6ES7VYU;&PH)'1Y<&4I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?='EP92`]("1T>7!E.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R
M92`]('-E<FEA;&EZ92@D87!P<RD["B`@("`@("`@:68@*&ES<V5T*"1?4T53
M4TE/3ELG:&]R9&4G75LG8FQO8VMS)UU;)'-I9VYA='5R95TI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8FQO8VMS(#T@)B1?4T534TE/3ELG:&]R9&4G75LG
M8FQO8VMS)UU;)'-I9VYA='5R95T["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]";&]C:RYP:'`G.PH*("`@("`@("!F;W)E86-H
M("@D<F5G:7-T<GDM/FQI<W1!<'!S*"D@87,@)&%P<"D@>PH@("`@("`@("`@
M("!I9B`H8V]U;G0H)&%P<',I("8F("%I;E]A<G)A>2@D87!P+"`D87!P<RDI
M('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!
M<'`H)&%P<"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B;&]C:V1I<B`]
M("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O0FQO
M8VLG.PH@("`@("`@("`@("`D9&@@/2!`;W!E;F1I<B@D8FQO8VMD:7(I.PH@
M("`@("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&1H*2D@>PH@("`@("`@("`@
M("`@("`@=VAI;&4@*"@D9FEL92`](')E861D:7(H)&1H*2D@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D9FEL92P@+30I
M(#T]("<N<&AP)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8FQO8VM?
M;F%M92`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@("`@("1B;&]C:U]T
M>7!E(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7W)E
M861A8FQE*"1B;&]C:V1I<B`N("<O)R`N("1F:6QE*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("1B;&]C:V1I<B`N("<O
M)R`N("1F:6QE.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D8FQO8VM?='EP92D@)B8@
M(6ES7VYU;&PH)'1H:7,M/E]T>7!E*2`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&)L;V-K7W1Y<&4@(3T@)'1H:7,M/E]T>7!E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1B;&]C:U]N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]B;&]C:W-;)&%P<%U;<W5B<W1R*"1F:6QE+"`P+"`M-"E=
M6R=N86UE)UT@/2`D8FQO8VM?;F%M93L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&-L;W-E9&ER*"1D:"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')E9VES=')Y+3YP;W!!<'`H)&%P<"D["B`@("`@("`@
M?0H*("`@("`@("!U:W-O<G0H)'1H:7,M/E]B;&]C:W,L"B`@("`@("`@("`@
M("`@(&-R96%T95]F=6YC=&EO;B@G)&$L("1B)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=G;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!S=')C87-E8VUP*"1R96=I
M<W1R>2T^9V5T*")N86UE(BP@)&$I+"`D<F5G:7-T<GDM/F=E="@B;F%M92(L
M("1B*2D[)RD*("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)%]315-324].
M6R=H;W)D92==6R=B;&]C:W,G75LD<VEG;F%T=7)E72`]("8D=&AI<RT^7V)L
M;V-K<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S:6YG;&4@
M:6YS=&%N8V4@;V8@=&AE($AO<F1E7T)L;V-K<R!C;&%S<RX*("`@("`J"B`@
M("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@5&AE(&MI;F0@;V8@8FQO8VMS('1O(&QI<W0N"B`@("`@*B!`<&%R86T@
M87)R87D@)&%P<',@("!4:&4@87!P;&EC871I;VYS('=H;W-E(&)L;V-K<R!T
M;R!L:7-T+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0FQO8VM?0V]L
M;&5C=&EO;B`@5&AE($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX@:6YS=&%N8V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)'1Y<&4@/2!N=6QL
M+"`D87!P<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T
M86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L
M:7IE*&%R<F%Y*"1T>7!E+"`D87!P<RDI.PH@("`@("`@(&EF("@A:7-S970H
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A
M;F-E<ULD<VEG;F%T=7)E72`](&YE=R!(;W)D95]";&]C:U]#;VQL96-T:6]N
M*"1T>7!E+"`D87!P<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN
M<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T
M0FQO8VLH)&%P<"P@)&YA;64L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1P871H(#T@)')E9VES
M=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]";&]C:R\G("X@
M)&YA;64@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)TAO<F1E7T)L;V-K
M7R<@+B`D87!P("X@)U\G("X@)&YA;64["B`@("`@("`@:68@*&ES7W)E861A
M8FQE*"1P871H*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)'!A=&@[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI
M('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(B5S(&YO="!F;W5N9"XB*2P@)&-L87-S*2D["B`@("`@("`@("`@
M(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`D8FQO8VL@/2`F
M;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!R971U<FX@)&)L;V-K.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('!R971T>2!P<FEN=&5D
M(&QI<W0@;V8@86QL(&%V86EL86)L92!B;&]C:W,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@8FQO8VL@241S(&%S(&ME>7,@
M86YD(&%P<&QI8V%T:6]N('!L=7,@8FQO8VL*("`@("`J("`@("`@("`@("`@
M("`@(&)L;V-K(&YA;65S(&%S('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0FQO8VMS3&ES="@I"B`@("!["B`@("`@("`@<W1A=&EC("1B;&]C
M:W,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A96UP='DH)&)L;V-K<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1B;&]C:W,["B`@("`@("`@?0H*("`@("`@
M("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O*B!'970@879A:6QA8FQE
M(&)L;V-K<R!F<F]M(&%L;"!A<'!S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?8FQO8VMS(&%S("1A<'`@/3X@)&%P<%]B;&]C:W,I('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&%P<%]B;&]C:W,@87,@)&)L;V-K7VED(#T^("1B
M;&]C:RD@>PH@("`@("`@("`@("`@("`@)&)L;V-K<ULD87!P("X@)SHG("X@
M)&)L;V-K7VED72`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D@+B`G
M.B`G("X@)&)L;V-K6R=N86UE)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8FQO8VMS.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(&QA>6]U="!H87-H('=I=&@@86QL(&9I>&5D(&)L;V-K
M<R!A<R!P97(@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!(&AA<V@@<F5P<F5S96YT:6YG(&$@9&5F875L="!L87EO=70@
M=VET:"!A;&P@9FEX960*("`@("`J("`@("`@("`@("`@("`@(&)L;V-K<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1FEX961";&]C:W,H*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&QA>6]U="`](&%R<F%Y
M*"D["B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=P;W)T86PG75LG9FEX961?
M8FQO8VMS)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYF6R=P;W)T
M86PG75LG9FEX961?8FQO8VMS)UT@87,@)&)L;V-K*2!["B`@("`@("`@("`@
M("`@("!L:7-T*"1A<'`L("1T>7!E*2`](&5X<&QO9&4H)SHG+"`D8FQO8VLL
M(#(I.PH@("`@("`@("`@("`@("`@)&QA>6]U=%M=(#T@87)R87DH87)R87DH
M)V%P<"<@/3X@)&%P<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P87)A;7,G(#T^(&9A;'-E*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H96EG:'0G(#T^(#$L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@G
M(#T^(#$I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1L87EO=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M<V5L96-T('=I9&=E="!W:71H(&%L;"!A=F%I;&%B;&4@8FQO8VMS+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&-U<E]A<'`@("`@5&AE(&)L;V-K
M(&9R;VT@=&AI<R!A<'!L:6-A=&EO;B!G971S('-E;&5C=&5D+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8W5R7V)L;V-K("!4:&4@8FQO8VL@=VET:"!T:&ES
M(&YA;64@9V5T<R!S96QE8W1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('-E;&5C="!T86<@=VET:"!A;&P@879A:6QA8FQE(&)L;V-K
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VMS5VED9V5T*"1C=7)?
M87!P(#T@;G5L;"P@)&-U<E]B;&]C:R`](&YU;&PL("1O;F-H86YG92`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@
M("1W:61G970@/2`G/'-E;&5C="!N86UE/2)A<'`B)SL*("`@("`@("!I9B`H
M)&]N8VAA;F=E*2!["B`@("`@("`@("`@("1W:61G970@+CT@)R!O;F-H86YG
M93TB9&]C=6UE;G0N8FQO8VMF;W)M+F%C=&EO;BYV86QU93U<)W-A=F4M<F5S
M=6UE7"<[9&]C=6UE;G0N8FQO8VMF;W)M+G-U8FUI="@I(B<["B`@("`@("`@
M?0H@("`@("`@("1W:61G970@+CT@(CY<;B(["B`@("`@("`@)&)L;V-K<U]L
M:7-T(#T@)'1H:7,M/F=E=$)L;V-K<TQI<W0H*3L*("`@("`@("!F;W)E86-H
M("@D8FQO8VMS7VQI<W0@87,@)&ED(#T^("1N86UE*2!["B`@("`@("`@("`@
M("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO;B!V86QU93U<(B5S7"(E<SXE
M<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*"1I9"`]/2`D8W5R7V%P<"`N("<Z)R`N("1C=7)?8FQO8VLI(#\@)R!S96QE
M8W1E9#TB<V5L96-T960B)R`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1N86UE*3L*("`@("`@("!]"B`@("`@("`@)'=I9&=E
M="`N/2`B/"]S96QE8W0^7&XB.PH*("`@("`@("!R971U<FX@)'=I9&=E=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&]P=&EO;B!T>7!E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971/<'1I;VY4>7!E*"1A<'`L("1B
M;&]C:RP@)'!A<F%M7VED*0H@("`@>PH@("`@("`@("1T:&ES+3YG971087)A
M;7,H)&%P<"P@)&)L;V-K*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]B;&]C
M:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UU;)'!A<F%M7VED75LG='EP92==
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H92!O
M<'1I;VX@:7,@<F5Q=6ER960@;W(@;F]T+B!$969A=6QT<R!T;R!T<G5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971/<'1I;VY297%U:7)E9"@D87!P+"`D
M8FQO8VLL("1P87)A;5]I9"D*("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R
M86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G75LD<&%R86U?:61=6R=R
M97%U:7)E9"==*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]B;&]C:W-;
M)&%P<%U;)&)L;V-K75LG<&%R86US)UU;)'!A<F%M7VED75LG<F5Q=6ER960G
M73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!V86QU97,@9F]R(&%N(&]P=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F=E=$]P=&EO;E9A;'5E<R@D87!P+"`D8FQO8VLL("1P87)A;5]I9"D*("`@
M('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A
M<F%M<R==6R1P87)A;5]I9%U;)W9A;'5E<R==.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@=VED9V5T(&YE8V5S<V%R>2!T;R!C;VYF:6=U
M<F4@=&AI<R!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N
M<U=I9&=E="@D87!P+"`D8FQO8VLL("1P87)A;5]I9"P@)'9A;"`](&YU;&PI
M"B`@("!["B`@("`@("`@)'=I9&=E="`]("<G.PH*("`@("`@("`D=&AI<RT^
M9V5T4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@)'!A<F%M(#T@)'1H
M:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UU;)'!A<F%M7VED
M73L*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;5LG9&5F875L="==*2D@>PH@
M("`@("`@("`@("`D<&%R86U;)V1E9F%U;'0G72`]("<G.PH@("`@("`@('T*
M"B`@("`@("`@<W=I=&-H("@D<&%R86U;)W1Y<&4G72D@>PH@("`@("`@(&-A
M<V4@)V)O;VQE86XG.@H@("`@("`@(&-A<V4@)V-H96-K8F]X)SH*("`@("`@
M("`@("`@)&-H96-K960@/2`A96UP='DH)'9A;%LD<&%R86U?:61=*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<["B`@("`@("`@("`@("1W:61G970@
M/2!S<')I;G1F*"<\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G!A<F%M
M<ULE<UTB)7,@+SXG+"`D<&%R86U?:60L("1C:&5C:V5D*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)V5N=6TG.@H@("`@("`@("`@("`D
M=VED9V5T(#T@<W!R:6YT9B@G/'-E;&5C="!N86UE/2)P87)A;7-;)7-=(CXG
M+"`D<&%R86U?:60I.PH@("`@("`@("`@("!F;W)E86-H("@D<&%R86U;)W9A
M;'5E<R==(&%S("1K97D@/3X@)&YA;64I('L*("`@("`@("`@("`@("`@(&EF
M("A3=')I;F<Z.FQE;F=T:"@D;F%M92D@/B`S,"D@>PH@("`@("`@("`@("`@
M("`@("`@("1N86UE(#T@<W5B<W1R*"1N86UE+"`P+"`R-RD@+B`G+BXN)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1W:61G970@+CT@
M<W!R:6YT9B@B/&]P=&EO;B!V86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E
M8VEA;&-H87)S*"1K97DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("AI<W-E="@D=F%L6R1P87)A;5]I9%TI("8F("1V86Q;)'!A<F%M
M7VED72`]/2`D:V5Y*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA
M;&-H87)S*"1N86UE*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1W
M:61G970@+CT@)SPO<V5L96-T/B<["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=M=6QT:65N=6TG.@H@("`@("`@("`@("`D=VED9V5T(#T@
M<W!R:6YT9B@G/'-E;&5C="!M=6QT:7!L93TB;75L=&EP;&4B(&YA;64](G!A
M<F%M<ULE<UU;72(^)RP@)'!A<F%M7VED*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)'!A<F%M6R=V86QU97,G72!A<R`D:V5Y(#T^("1N86UE*2!["B`@("`@
M("`@("`@("`@("!I9B`H4W1R:6YG.CIL96YG=&@H)&YA;64I(#X@,S`I('L*
M("`@("`@("`@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D;F%M92P@,"P@
M,C<I("X@)RXN+B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=VED9V5T("X]('-P<FEN=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB)7,^
M)7,\+V]P=&EO;CY<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H:7-S970H)'9A;%LD<&%R86U?:61=*2`F
M)B!I;E]A<G)A>2@D:V5Y+"`D=F%L6R1P87)A;5]I9%TI*2`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1W:61G970@+CT@)SPO<V5L96-T/B<["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=M;&5N=6TG.@H@("`@
M("`@("`@("`O+R!-=6QT:2UL979E;"!E;G5M+@H@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'9A;"D@)B8@:7-S970H)'9A;%LG7U\G("X@)'!A<F%M7VED
M72DI('L*("`@("`@("`@("`@("`@("1F:7)S='9A;"`]("1V86Q;)U]?)R`N
M("1P87)A;5]I9%T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&UP(#T@87)R87E?:V5Y<R@D<&%R86U;)W9A;'5E<R==*3L*("`@
M("`@("`@("`@("`@("1F:7)S='9A;"`](&-U<G)E;G0H)'1M<"D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&)L;V-K=F%L=65S(#T@)'!A<F%M6R=V
M86QU97,G75LD9FER<W1V86Q=.PH@("`@("`@("`@("!A<V]R="@D8FQO8VMV
M86QU97,I.PH*("`@("`@("`@("`@)'=I9&=E="`]('-P<FEN=&8H)SQS96QE
M8W0@;F%M93TB<&%R86US6U]?)7-=(B!O;F-H86YG93TB9&]C=6UE;G0N8FQO
M8VMF;W)M+F%C=&EO;BYV86QU93U<)W-A=F4M<F5S=6UE7"<[9&]C=6UE;G0N
M8FQO8VMF;W)M+G-U8FUI="@I(CXG+"`D<&%R86U?:60I("X@(EQN(CL*("`@
M("`@("`@("`@9F]R96%C:"`H)'!A<F%M6R=V86QU97,G72!A<R`D:V5Y(#T^
M("1V86QU97,I('L*("`@("`@("`@("`@("`@("1N86UE(#T@4W1R:6YG.CIL
M96YG=&@H)&ME>2D@/B`S,"`_(%-T<FEN9SHZ<W5B<W1R*"1K97DL(#`L(#(W
M*2`N("<N+BXG(#H@)&ME>3L*("`@("`@("`@("`@("`@("1W:61G970@+CT@
M<W!R:6YT9B@B/&]P=&EO;B!V86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E
M8VEA;&-H87)S*"1K97DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1K97D@/3T@)&9I<G-T=F%L(#\@)R!S96QE8W1E9#TB<V5L96-T
M960B)R`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=VED9V5T("X]("(\+W-E;&5C=#X\8G(@+SY<;B(["@H@("`@
M("`@("`@("`D=VED9V5T("X]('-P<FEN=&8H(CQS96QE8W0@;F%M93U<(G!A
M<F%M<ULE<UU<(CY<;B(L("1P87)A;5]I9"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1B;&]C:W9A;'5E<R!A<R`D:V5Y(#T^("1N86UE*2!["B`@("`@("`@
M("`@("`@("`D;F%M92`]("A3=')I;F<Z.FQE;F=T:"@D;F%M92D@/B`S,"D@
M/R!3=')I;F<Z.G-U8G-T<B@D;F%M92P@,"P@,C<I("X@)RXN+B<@.B`D;F%M
M93L*("`@("`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO
M;B!V86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1K97DI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86Q;)'!A
M<F%M7VED72`]/2`D:V5Y(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AT;6QS<&5C
M:6%L8VAA<G,H)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=VED9V5T("X]("(\+W-E;&5C=#X\8G(@+SY<;B(["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=C;VQO<B<Z"B`@("`@("`@("`@("1V86P@
M/2!I<W-E="@D8FQO8VLM/E]P87)A;7-;)'!A<F%M7VED72D@/R`D8FQO8VLM
M/E]P87)A;7-;)'!A<F%M7VED72`Z("<G.PH@("`@("`@("`@("`D=VED9V5T
M(#T@<W!R:6YT9B@G/&EN<'5T('-T>6QE/2)B86-K9W)O=6YD+6-O;&]R.B5S
M(B!T>7!E/2)T97AT(B!N86UE/2)P87)A;7-;)7-=(B!V86QU93TB)7,B("\^
M)RP@)'9A;"P@)'!A<F%M7VED+"`D=F%L*3L*("`@("`@("`@("`@)'5R;"`@
M/2`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I.PH@("`@("`@
M("`@("`D=7)L("X](%5T:6PZ.F%D9%!A<F%M971E<B@G+W-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`_=&%R9V5T/7!A<F%M<ULG("X@)'!A<F%M
M7VED("X@)UTG+"`G9F]R;2<L("=B;&]C:V9O<FTG*3L*("`@("`@("`@("`@
M)'=I9&=E="`N/2!S<')I;G1F*"<\82!H<F5F/2(E<R(@;VYC;&EC:STB=VEN
M9&]W+F]P96XH7"<E<UPG+"!<)V-O;&]R<&EC:V5R7"<L(%PG=&]O;&)A<CUN
M;RQL;V-A=&EO;CUN;RQS=&%T=7,];F\L<V-R;VQL8F%R<SUN;RQR97-I>F%B
M;&4];F\L=VED=&@],3(P+&AE:6=H=#TR-3`L;&5F=#TQ,#`L=&]P/3$P,%PG
M*3L@<F5T=7)N(&9A;'-E.R(@;VYM;W5S96]U=#TB=VEN9&]W+G-T871U<SU<
M)UPG.R(@;VYM;W5S96]V97(](G=I;F1O=RYS=&%T=7,]7"<E<UPG.R!R971U
M<FX@=')U93LB(&-L87-S/2)W:61G970B('1A<F=E=#TB8V]L;W)P:6-K97(B
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=7)L+"`D=7)L
M+"!?*")#;VQO<B!0:6-K97(B*2D["B`@("`@("`@("`@("1W:61G970@+CT@
M2&]R9&4Z.FEM9R@G8V]L;W)P:6-K97(N<&YG)RP@7R@B0V]L;W(@4&EC:V5R
M(BDL("=H96EG:'0](C$V(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO
M<F1E)RDI.PH@("`@("`@("`@("`D=VED9V5T("X]("<\+V$^)SL*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)VEN="<Z"B`@("`@("`@8V%S
M92`G=&5X="<Z"B`@("`@("`@("`@("1W:61G970@/2!S<')I;G1F*"<\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB<&%R86US6R5S72(@=F%L=64](B5S(B`O
M/B<L("1P87)A;5]I9"P@(6ES<V5T*"1V86Q;)'!A<F%M7VED72D@/R`D<&%R
M86U;)V1E9F%U;'0G72`Z("1V86Q;)'!A<F%M7VED72D["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=E<G)O<B<Z"B`@("`@("`@("`@("1W
M:61G970@/2`G/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/B<@+B`D<&%R86U;
M)V1E9F%U;'0G72`N("<\+W-P86X^)SL*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'=I9&=E=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&YA;64@;V8@=&AE('-P96-I9FEE9"!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@06X@
M87!P;&EC871I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K
M("!!(&)L;V-K(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!N86UE(&]F('1H92!S<&5C:69I960@8FQO8VLN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$YA;64H)&%P<"P@)&)L;V-K*0H@("`@>PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K72DI('L*
M("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H7R@B0FQO8VL@7"(E<UPB(&]F
M(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(BDL("1B;&]C:RP@)&%P
M<"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD
M87!P75LD8FQO8VM=6R=N86UE)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!P87)A;65T97(@;&ES="!O9B!T:&4@<W!E8VEF:65D(&)L
M;V-K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@("!!;B!A
M<'!L:6-A=&EO;B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@
M($$@8FQO8VL@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!
M;B!A<G)A>2!W:71H(&%L;"!P87)A;71E<B!N86UE<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&%R86US*"1A<'`L("1B;&]C:RD*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A
M<F%M<R==*2D@>PH@("`@("`@("`@("`D8FQO8VM/8B`]("8D=&AI<RT^9V5T
M0FQO8VLH)&%P<"P@)&)L;V-K*3L*("`@("`@("`@("`@:68@*&ES7V$H)&)L
M;V-K3V(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D8FQO8VM/8CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G72`]("1B;&]C:T]B+3YG
M971087)A;7,H*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G72D@)B8*("`@("`@
M("`@("`@:7-?87)R87DH)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG
M<&%R86US)UTI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1T
M:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92`H8VQE87(@
M=&5X="D@;F%M92!O9B!T:&4@<W!E8VEF:65D('!A<F%M971E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@06X@87!P;&EC871I;VX@
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!!(&)L;V-K(&YA
M;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A;2`@02!P87)A;65T97(@
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YA;64@
M;V8@=&AE('-P96-I9FEE9"!P87)A;65T97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!A<F%M3F%M92@D87!P+"`D8FQO8VLL("1P87)A;2D*("`@('L*
M("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M
M<R==6R1P87)A;5U;)VYA;64G73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&1E9F%U;'0@=F%L=64@;V8@=&AE('-P96-I9FEE9"!P87)A
M;65T97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@($%N
M(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C
M:R`@02!B;&]C:R!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86T@
M($$@<&%R86UE=&5R(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!D969A=6QT('9A;'5E(&]F('1H92!S<&5C:69I960@<&%R86UE
M=&5R(&]R(&YU;&PN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'16
M86QU92@D87!P+"`D8FQO8VLL("1P87)A;2D*("`@('L*("`@("`@("`D=&AI
M<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A
M;5U;)V1E9F%U;'0G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5U;)V1E9F%U
M;'0G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&EF('1H92!S<&5C:69I960@8FQO8VL@
M:7,@8W5S=&]M:7IE86)L92!B>2!T:&4@=7-E<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A<'`@("`@06X@87!P;&EC871I;VX@;F%M92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&ES('1H92!B;&]C:R!I
M<R!C=7-T;VUI>F5A8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5D:71A
M8FQE*"1A<'`L("1B;&]C:RD*("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R
M86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==*2`F)@H@("`@("`@
M("`@("!C;W5N="@D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A
M;7,G72D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+P``````````````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`
M,#$W,3(P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O
M<&%S<W=D+G!H<```````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-C$Q,``Q,#4Q-30S,3`V,0`P,C$Q,C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7W!A
M<W-W9#HZ(&-L87-S('!R;W9I9&5S(&$@<&%S<W=D+69I;&4@:6UP;&5M96YT
M871I;VX@;V8*("H@=&AE($AO<F1E(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*
M("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=F:6QE;F%M
M92<@(%1H92!P87-S=V0@9FEL92!T;R!U<V4N"B`J("`@("`@("`@("`@("`@
M1$5&055,5#H@+V5T8R]P87-S=V0*("H@("`G;&]C:R<@("`@("!3:&]U;&0@
M=V4@;&]C:R!T:&4@<&%S<W=D(&9I;&4_("AB;V]L96%N*0H@*B`@("`@("`@
M("`@("`@($1%1D%53%0Z(&9A;'-E/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP+'8@,2XQ-BXQ,"XQ,2`R
M,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DW+3(P,#8@4F%S;75S($QE<F1O<F8@/')A<VUU<T!P:'`N;F5T/@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F%S;75S
M($QE<F1O<F8@/')A<VUU<T!P:'`N;F5T/@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?<&%S
M<W=D(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O
M9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T
M('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC
M:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@
M("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A
M;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@4&%S<W=D
M(&9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?9FEL96YA;64@/2`G+V5T8R]P87-S=V0G.PH*("`@("\J*@H@("`@
M("H@2&%S:"!L:7-T(&]F('5S97)S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?=7-E<G,["@H@("`@+RHJ"B`@("`@*B!&
M:6QE:&%N9&QE(&9O<B!L;V-K9FEL92X*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1?9G!L;V-K.PH*("`@("\J*@H@("`@
M("H@3&]C:VEN9R!S=&%T92X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?;&]C:V5D.PH*("`@("\J*@H@("`@("H@3&ES
M="!O9B!U<V5R<R!T:&%T('-H;W5L9"!B92!E>&-L=61E9"!F<F]M(&)E:6YG
M(&QI<W1E9"]H86YD;&5D"B`@("`@*B!I;B!A;GD@=V%Y(&)Y('1H:7,@9')I
M=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?97AC;'5D92`](&%R<F%Y*"=R;V]T)RP@)V1A96UO;B<L("=B:6XG+"`G
M<WES)RP@)W-Y;F,G+"`G9V%M97,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("=M86XG+"`G;'`G+"`G;6%I;"<L("=N97=S)RP@)W5U8W`G+"`G<')O
M>'DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=P;W-T9W)E<R<L("=W
M=W<M9&%T82<L("=B86-K=7`G+"`G;W!E<F%T;W(G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("=L:7-T)RP@)VER8R<L("=G;F%T<R<L("=N;V)O9'DG
M+"`G:61E;G1D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G<W-H9"<L
M("=G9&TG+"`G<&]S=&9I>"<L("=M>7-Q;"<L("=C>7)U<R<L("=F='`G*3L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@4&%S<W=D(&%U=&AE
M;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7W!A<W-W9"@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P
M87)A;7,["B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=F:6QE;F%M92==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9I;&5N86UE(#T@)'!A<F%M<ULG
M9FEL96YA;64G73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9G!L;V-K
M(#T@9F]P96XH2&]R9&4Z.F=E=%1E;7!$:7(H*2`N("<O<&%S<W=D+FQO8VLG
M+"`G=R<I.PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG;&]C:R==*2D@
M>PH@("`@("`@("`@("!F;&]C:R@D=&AI<RT^7V9P;&]C:RP@3$]#2U]%6"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?;&]C:V5D(#T@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1F<"`](&9O<&5N*"1T:&ES+3Y?9FEL96YA;64L("=R)RD[
M"B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(D-O=6QD;B=T(&]P96X@)R(@+B`D=&AI<RT^7V9I;&5N
M86UE("X@(B<N(BD["B`@("`@("`@?0H@("`@("`@('=H:6QE("@A9F5O9B@D
M9G`I*2!["B`@("`@("`@("`@("1L:6YE(#T@9F=E=',H)&9P+"`Q,C@I.PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1L:6YE*2D@>PH@("`@("`@("`@("`@
M("`@;&ES="@D=7-E<BP@)'!A<W,L("1U:60L("1G:60L("1I;F9O+"`D:&]M
M92P@)'-H96QL*2`](&5X<&QO9&4H)SHG+"`D;&EN92D["B`@("`@("`@("`@
M("`@("!I9B`H<W1R;&5N*"1U<V5R*2`F)@H@("`@("`@("`@("`@("`@("`@
M("%I;E]A<G)A>2@D=7-E<BP@)'1H:7,M/E]E>&-L=61E*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S97)=6R=P87-S=V]R9"==
M(#T@)'!A<W,["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5R<ULD
M=7-E<EU;)W5I9"==(#T@)'5I9#L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W5S97)S6R1U<V5R75LG9VED)UT@/2`D9VED.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S97)=6R=I;F9O)UT@/2`D:6YF;SL*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97)S6R1U<V5R75LG:&]M
M92==(#T@)&AO;64["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5R
M<ULD=7-E<EU;)W-H96QL)UT@/2`D<VAE;&P["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9F-L;W-E*"1F<"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L
M;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E
M<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A
M<G)A>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I
M86QS+B!&;W(@34-!3"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O<F0@96YT<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@
M8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M=7-E<G-;)'5S97))9%TI*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W5S
M97)S6R1U<V5R261=6R=P87-S=V]R9"==(#T](&-R>7!T*"1C<F5D96YT:6%L
M<ULG<&%S<W=O<F0G72P@<W5B<W1R*"1T:&ES+3Y?=7-E<G-;)'5S97))9%U;
M)W!A<W-W;W)D)UTL(#`L(#(I*2D@<F5T=7)N('1R=64["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($QI
M<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D
M=&AI<RT^7W5S97)S*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!U
M<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@($YE
M=R!U<V5R($E$+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<R`@("`@4&%S
M<W=O<F0@9F]R(&YE=R!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W9S
M=7-E<B`@0U93('5S97(@:60@*&YE961E9"!F;W(@<'-E<G9E<B!P87-S=V0@
M9FEL97,I+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N
M<R!T<G5E(&]R(%!%05)?17)R;W(@:68@=&AE('5S97(@86QR96%D>0H@("`@
M("H@("`@("`@("`@("`@("`@("!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9%5S97(H)'5S97(L("1P87-S+"`D8W9S=7-E<B`]("<G*0H@("`@
M>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]U<V5R<ULD=7-E<ETI("8F
M("1T:&ES+3Y?;&]C:V5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;
M)'5S97)=(#T@8W)Y<'0H)'!A<W,I.PH@("`@("`@("`@("`D=&AI<RT^7V-V
M<ULD=7-E<ET@/2`D8W9S=7-E<CL*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(D-O=6QD;B=T(&%D9"!U<V5R("<D=7-E<B<L(&)E8V%U<V4@
M=&AE('5S97(@86QR96%D>2!E>&ES=',N(BD["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@36]D:69I97,@82!U<V5R+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'5S97(@("`@(%5S97(@240N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P87-S("`@("!087-S=V]R9"!F;W(@;F5W('5S97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C=G-U<V5R("!#5E,@=7-E<B!I9"`H;F5E
M9&5D(&9O<B!P<V5R=F5R('!A<W-W9"!F:6QE<RDN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;W(@4$5!4E]%<G)O<B!I
M9B!T:&4@=7-E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@(&5X
M:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;6]D57-E<B@D=7-E<BP@)'!A
M<W,L("1C=G-U<V5R(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?=7-E<G-;)'5S97)=*2`F)B`D=&AI<RT^7VQO8VME9"D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W5S97)S6R1U<V5R72`](&-R>7!T*"1P87-S*3L*
M("`@("`@("`@("`@)'1H:7,M/E]C=G-;)'5S97)=(#T@)&-V<W5S97(["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;W5L9&XG="!M;V1I
M9GD@=7-E<B`G)'5S97(G+"!B96-A=7-E('1H92!U<V5R(&1O97-N)W0@97AI
M<W0N(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!A('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@
M57-E<B!)1"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R
M;G,@=')U92!O<B!014%27T5R<F]R(&EF('1H92!U<V5R(&1O97-N)W0@97AI
M<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;%5S97(H)'5S97(I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=7-E<G-;)'5S97)=*2`F)B`D
M=&AI<RT^7VQO8VME9"D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W5S
M97)S6R1U<V5R72D["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8W9S6R1U
M<V5R72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H(D-O=6QD;B=T(&1E;&5T92!U<V5R("<D=7-E<B<L
M(&)E8V%U<V4@=&AE('5S97(@9&]E<VXG="!E>&ES="XB*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET97,@8VAA;F=E<R!T;R!P87-S
M=V0@9FEL92!A;F0@=6YL;V-K<R!I="X@(%1A:V5S(&YO(&%R9W5M96YT<R!A
M;F0*("`@("`J(&AA<R!N;R!D969I;F5D(')E='5R;B!V86QU92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7VQO8VME9"D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W5S
M97)S(&%S("1U<V5R(#T^("1P87-S*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]U<V5R<ULD=7-E<ETI('L*("`@("`@("`@("`@("`@("`@("!F
M<'5T<R@D=&AI<RT^7V9P;&]C:RP@(B1U<V5R.B1P87-S.B(@+B`D=&AI<RT^
M7W5S97)S6R1U<V5R72`N(")<;B(I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!F<'5T<R@D=&AI<RT^7V9P;&]C:RP@
M(B1U<V5R.B1P87-S7&XB*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R96YA;64H)'1H:7,M/E]L;V-K9FEL92P@)'1H
M:7,M/E]F:6QE;F%M92D["B`@("`@("`@("`@(&9L;V-K*"1T:&ES+3Y?9G!L
M;V-K+"!,3T-+7U5.*3L*("`@("`@("`@("`@)'1H:7,M/E]L;V-K960@/2!F
M86QS93L*("`@("`@("`@("`@9F-L;W-E*"1T:&ES+3Y?9G!L;V-K*3L*("`@
M("`@("!]"B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]I<&)A<VEC+G!H<```````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`V-S(V`#$P-3$U-#,Q,#8Q`#`R,3(U,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?
M:7!B87-I8R!C;&%S<R!P<F]V:61E<R!A8V-E<W,@8V]N=')O;"!B87-E9"!O
M;B!#2412(&UA<VMS"B`J("AC;&EE;G0@25`@861D<F5S<V5S*2X@270@:7,@
M;F]T(&UE86YT(&9O<B!U<V5R+6)A<V5D('-Y<W1E;7,L(&)U=`H@*B!F;W(@
M=&EM97,@=VAE;B!Y;W4@=V%N="!A(&)L;V-K(&]F($E0<R!T;R!B92!A8FQE
M('1O(&%C8V5S<R!A('-I=&4L"B`J(&%N9"!T:&%T(&%C8V5S<R!I<R!S:6UP
M;'D@;VXO;V9F("T@;F\@<')E9F5R96YC97,L(&5T8RX@268@>6]U(&YE960*
M("H@;6]R92!S;W!H:7-T:6-A=&5D($E0+6)A<V5D(&%U=&AE;G1I8V%T:6]N
M+"!Y;W4@<VAO=6QD(&QO;VL@870@=&AE"B`J($%U=&A?:7!M87`@8VQA<W,@
M=VAI8V@@;&5T<R!Y;W4@;6%P($E0(&)L;V-K<R!T;R!S<&5C:69I8PH@*B!U
M<V5R;F%M97,N"B`J"B`J(%!A<F%M971E<G,Z"B`J("`@)V)L;V-K<R<@("`@
M($%N(&%R<F%Y(&]F($-)1%(@;6%S:W,@=VAI8V@@87)E(&%L;&]W960@86-C
M97-S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I
M8RYP:'`L=B`Q+C(P+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@
M075T:%]I<&)A<VEC(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!
M;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C
M86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S
M(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D
M)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T
M)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1R86YS<&%R96YT)R`@(#T^('1R=64I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T<R!A(&YE=R!"87-I8R!)4"!A=71H96YT:6-A=&EO;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($%U=&A?:7!B87-I8R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!P87)A;65T97)S(&9O<B!T:&4@075T:%]I<&)A<VEC
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4VAO=6QD(&-O;G1A:6X@
M)V)L;V-K<R<L(&%N(&%R<F%Y(&]F($-)1%(@;6%S:W,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]S971087)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'!A<F%M<ULG8FQO8VMS)UTI*2!["B`@("`@("`@("`@("1P
M87)A;7-;)V)L;V-K<R==(#T@87)R87DH*3L*("`@("`@("!](&5L<V5I9B`H
M(6ES7V%R<F%Y*"1P87)A;7-;)V)L;V-K<R==*2D@>PH@("`@("`@("`@("`D
M<&%R86US6R=B;&]C:W,G72`](&%R<F%Y*"1P87)A;7-;)V)L;V-K<R==*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M871I8R!A=71H96YT:6-A=&EO
M;CH@1FEN9"!O=70@:68@=&AE(&-L:65N="!M871C:&5S(&%N(&%L;&]W960@
M25`*("`@("`J(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@
M:68@*"%I<W-E="@D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'
M12P@7R@B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(I*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&-L:65N="`]
M("1?4T525D526R=214U/5$5?041$4B==.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?<&%R86US6R=B;&]C:W,G72!A<R`D8VED<BD@>PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]A9&1R97-S5VET:&EN0TE$4B@D8VQI96YT+"`D8VED
M<BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971!=71H*"1C:61R+"!A
M<G)A>2@G=')A;G-P87)E;G0G(#T^(#$I*3L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?*"))
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(I*3L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M971E<FUI;F4@:68@86X@25`@861D<F5S<R!I<R!W:71H:6X@82!#2412(&)L
M;V-K+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@(%1H92!)4"!A9&1R97-S('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VED<B`@("`@5&AE(&)L
M;V-K("AE+F<N(#$Y,BXQ-C@N,"XP+S$V*2!T;R!T97-T(&%G86EN<W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T
M:&4@861D<F5S<R!M871C:&5S('1H92!M87-K+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?861D<F5S<U=I=&AI;D-)1%(H)&%D9')E<W,L("1C:61R*0H@("`@
M>PH@("`@("`@("1A9&1R97-S(#T@:7`R;&]N9R@D861D<F5S<RD["B`@("`@
M("`@;&ES="@D<75A9"P@)&)I=',I(#T@97AP;&]D92@G+R<L("1C:61R*3L*
M("`@("`@("`D8FET<R`](&EN='9A;"@D8FET<RD["B`@("`@("`@)'%U860@
M/2!I<#)L;VYG*"1Q=6%D*3L*"B`@("`@("`@<F5T=7)N("@H)&%D9')E<W,@
M/CX@*#,R("T@)&)I=',I*2`]/2`H)'%U860@/CX@*#,R("T@)&)I=',I*2D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'``````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`T-S$Q-@`Q,#4Q-30S,3`V,0`P,C`U-3<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H
M7VQD87`@8VQA<W,@<')O=FED97,@86X@3$1!4"!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M+@H@*@H@*B!2
M97%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V)A<V5D;B<@("`@("`@
M5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0('-E<G9E<BX*("H@("`G:&]S='-P
M96,G("`@("!4:&4@:&]S=&YA;64@;V8@=&AE($Q$05`@<V5R=F5R+@H@*B`@
M("=U:60G("`@("`@("`@(%1H92!U<V5R;F%M92!S96%R8V@@:V5Y+@H@*B`@
M("=F:6QT97(G("`@("`@(%1H92!,1$%0(&9O<FUA='1E9"!S96%R8V@@9FEL
M=&5R('1O('-E87)C:"!F;W(@=7-E<G,N(%1H:7,*("H@("`@("`@("`@("`@
M("`@("!S971T:6YG(&]V97)R:61E<R!T:&4@)V]B:F5C=&-L87-S)R!M971H
M;V0@8F5L;W<N"B`J("`@)V]B:F5C=&-L87-S)R`@5&AE(&]B:F5C=&-L87-S
M(&9I;'1E<B!U<V5D('1O('-E87)C:"!F;W(@=7-E<G,N($-A;B!B92!A"B`J
M("`@("`@("`@("`@("`@("`@<VEN9VQE(&]B:F5C=&-L87-S(&]R(&%N(&%R
M<F%Y+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J
M("`@)V)I;F1D;B<@("`@("`@5&AE($1.('5S960@=&\@8FEN9"!T;R!T:&4@
M3$1!4"!S97)V97(*("H@("`G<&%S<W=O<F0G("`@("!4:&4@<&%S<W=O<F0@
M=7-E9"!T;R!B:6YD('1O('1H92!,1$%0('-E<G9E<@H@*B`@("=V97)S:6]N
M)R`@("`@(%1H92!V97)S:6]N(&]F('1H92!,1$%0('!R;W1O8V]L('1O('5S
M92X*("H@("`@("`@("`@("`@("`@("!$149!54Q4.B!.3TY%("AS>7-T96T@
M9&5F875L="!W:6QL(&)E('5S960I/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<"QV(#$N-#<N,3`N,3D@,C`P
M-B\P."\Q-"`P,CHT.#HT."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T
M:`H@*B\*8VQA<W,@075T:%]L9&%P(&5X=&5N9',@075T:"!["@H@("`@+RHJ
M"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE
M(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET
M('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A
M<G)A>2@G861D)R`@("`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^('1R=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@
M("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L:7-T)R`@("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J
M*@H@("`@("H@3$1!4"!C;VYN96-T:6]N(&AA;F1L90H@("`@("H*("`@("`J
M($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?9',["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($Q$05`@875T:&5N=&EC871I;VX@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($%U=&A?;&1A<"@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;&1A
M<"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*")!=71H7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V5T
M4&%R86US*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&-O
M;F9I9W5R871I;VX@<&%R86UE=&5R<PH@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]S971087)A;7,H)'!A<F%M<RD*("`@('L*("`@
M("`@("`O*B!%;G-U<F4@=V4G=F4@8F5E;B!P<F]V:61E9"!W:71H(&%L;"!O
M9B!T:&4@;F5C97-S87)Y('!A<F%M971E<G,N("HO"B`@("`@("`@2&]R9&4Z
M.F%S<V5R=$1R:79E<D-O;F9I9R@D<&%R86US+"`G875T:"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:&]S='-P96,G+"`G
M8F%S961N)RP@)W5I9"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V%U=&AE;G1I8V%T:6]N($Q$05`G*3L*"B`@("`@("`@)'1H:7,M
M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E
M<R!A;B!L9&%P(&-O;FYE8W0@86YD(&)I;F1S(&%S('1H92!G=65S="!U<V5R
M(&]R(&%S('1H92!O<'1I;VYA;"!D;BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;W(@1F%L<V4@8F%S960@;VX@<W5C8V5S<R!O9B!C;VYN96-T(&%N9"!B:6YD
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@
M("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@
M)'1H:7,M/E]D<R`]($!L9&%P7V-O;FYE8W0H)'1H:7,M/E]P87)A;7-;)VAO
M<W1S<&5C)UTI.PH@("`@("`@(&EF("@A)'1H:7,M/E]D<RD@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72DI('L*("`@("`@
M("`@("`@:68@*"%L9&%P7W-E=%]O<'1I;VXH)'1H:7,M/E]D<RP@3$1!4%]/
M4%1?4%)/5$]#3TQ?5D524TE/3BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72DI('L*("`@("`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-E="!,1$%0
M('!R;W1O8V]L('9E<G-I;VX@=&\@)60@9F%I;&5D.B!;)61=("5S)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W9E<G-I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D8V]N;BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H
M)&-O;FXI*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=B:6YD9&XG72DI('L*("`@("`@("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD
M*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R86US6R=B:6YD9&XG72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S
M=V]R9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8FEN9"`]
M($!L9&%P7V)I;F0H)'1H:7,M/E]D<RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(21B:6YD*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1FEN9"!T:&4@=7-E<B!D;@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@
M("`@("!4:&4@=7-E<DED('1O(&9I;F0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!U<V5R<R!F=6QL($1."B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]F:6YD1$XH)'5S97))9"D*("`@('L*("`@("`@("`O*B!396%R8V@@
M9F]R('1H92!U<V5R)W,@9G5L;"!$3BX@*B\*("`@("`@("`D<V5A<F-H(#T@
M0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R86US6R=B87-E
M9&XG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=U:60G72`N("<])R`N("1U<V5R260L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG=6ED)UTI
M*3L*("`@("`@("!I9B`H(21S96%R8V@I('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H;&1A<%]E<G)O<B@D=&AI<RT^7V1S*2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB*2D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@0&QD
M87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1R97-U;'0I("8F("AC;W5N="@D<F5S=6QT*2`^(#$I
M*2!["B`@("`@("`@("`@("1D;B`]("1R97-U;'1;,%U;)V1N)UT["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B16UP='D@<F5S=6QT+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D9&X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@9F]R('-H
M861O=TQA<W1#:&%N9V4@86YD('-H861O=TUI;B]-87@@<W5P<&]R="!A;F0@
M<F5T=7)N<R!T:&5I<@H@("`@("H@=F%L=65S+B`@5V4@=VEL;"!A;'-O(&-H
M96-K(&9O<B!P=V1,87-T4V5T(&EF($%C=&EV92!$:7)E8W1O<GD@:7,*("`@
M("`J('-U<'!O<G0@:7,@<F5Q=65S=&5D+B`@1F]R('1H:7,@8VAE8VL@=&\@
M<W5C8V5E9"!W92!N965D('1O(&)E(&)O=6YD"B`@("`@*B!T;R!T:&4@9&ER
M96-T;W)Y"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&X@("`@(%1H92!D;B!O9B!T:&4@=7-E
M<@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%R<F%Y('=I=&@@:V5Y
M<R!B96EN9R`B<VAA9&]W;&%S=&-H86YG92(L(")S:&%D;W=M:6XB"B`@("`@
M*B`@("`@("`@("`@("`@("`B<VAA9&]W;6%X(BP@(G-H861O=W=A<FYI;F<B
M(&%N9"!C;VYT86EN:6YG('1H96ER"B`@("`@*B`@("`@("`@("`@("`@("!R
M97-P96-T:79E('9A;'5E<R!O<B!F86QS92!F;W(@;F\@<W5P<&]R="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7VQO;VMU<%-H861O=R@D9&XI"B`@("!["B`@
M("`@("`@+RH@26YI="!T:&4@<F5T=7)N(&%R<F%Y+B`J+PH@("`@("`@("1L
M;V]K=7!S:&%D;W<@/2!A<G)A>2@G<VAA9&]W;&%S=&-H86YG92<@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S:&%D;W=M:6XG
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<VAA
M9&]W;6%X)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W-H861O=W=A<FYI;F<G(#T^(&9A;'-E*3L*"@H@("`@("`@("1R97-U
M;'0@/2!`;&1A<%]R96%D*"1T:&ES+3Y?9',L("1D;BP@)V]B:F5C=$-L87-S
M/2HG*3L*"B`@("`@("`@:68@*"1R97-U;'0I('L*("`@("`@("`@("`@)&EN
M9F]R;6%T:6]N(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)')E
M<W5L="D["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V%D)UTI
M('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;W)M871I;VY;,%U;
M)W!W9&QA<W1S970G75LP72DI('L*("`@("`@("`@("`@("`@("`@("`O*B!!
M8W1I=F4@1&ER96-T;W)Y(&AA;F1L97,@=&EM97-T86UP<R!A(&)I=`H@("`@
M("`@("`@("`@("`@("`@("`J(&1I9F9E<F5N=&QY+B`@0V]N=F5R="!T:&4@
M=&EM97-T86UP('1O(&$@54Y)6`H@("`@("`@("`@("`@("`@("`@("`J('1I
M;65S=&%M<"X@*B\*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA9&]W
M6R=S:&%D;W=L87-T8VAA;F=E)UT@/2!F;&]O<B@H*"1I;F9O<FUA=&EO;ELP
M75LG<'=D;&%S='-E="==6S!=("\@,3`P,#`P,#`I("T@,3$V-#0T,#8W.#,I
M("\@.#8T,#`I("T@,3L*"B`@("`@("`@("`@("`@("`@("`@+RH@4&%S<W=O
M<F0@97AP:7)Y(&%T=')I8G5T97,@87)E(&EN(&$@<&]L:6-Y+B!790H@("`@
M("`@("`@("`@("`@("`@("`J(&-A;FYO="!R96%D('1H96T@<V\@=7-E('1H
M92!(;W)D92!C;VYF:6<N("HO"B`@("`@("`@("`@("`@("`@("`@)&QO;VMU
M<'-H861O=ULG<VAA9&]W=V%R;FEN9R==(#T@)'1H:7,M/E]P87)A;7-;)W=A
M<FYA9V4G73L*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA9&]W6R=S
M:&%D;W=M:6XG72`@("`@/2`D=&AI<RT^7W!A<F%M<ULG;6EN86=E)UT["B`@
M("`@("`@("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;6%X)UT@
M("`@(#T@)'1H:7,M/E]P87)A;7-;)VUA>&%G92==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;6%X)UU;,%TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;6%X)UT@
M/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;W)M871I;VY;,%U;)W-H861O=VUA>"==6S!=.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;W)M871I
M;VY;,%U;)W-H861O=VUI;B==6S!=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1L;V]K=7!S:&%D;W=;)W-H861O=VUI;B==(#T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F]R;6%T:6]N6S!=
M6R=S:&%D;W=M:6XG75LP73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T
M8VAA;F=E)UU;,%TI*2!["B`@("`@("`@("`@("`@("`@("`@)&QO;VMU<'-H
M861O=ULG<VAA9&]W;&%S=&-H86YG92==(#T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;W)M871I;VY;,%U;)W-H861O=VQA
M<W1C:&%N9V4G75LP73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=W87)N:6YG
M)UU;,%TI*2!["B`@("`@("`@("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG
M<VAA9&]W=V%R;FEN9R==(#T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;W)M871I;VY;,%U;)W-H861O=W=A<FYI;F<G
M75LP73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1L;V]K=7!S:&%D;W<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!T:&4@9VEV96X@<V5T(&]F(&QO9VEN
M(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A
M>2`@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E
M;G1I86QS*0H@("`@>PH@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@
M<V5R=F5R+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T
M*"D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%3
M3TY?34534T%'12P@)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J(%-E87)C
M:"!F;W(@=&AE('5S97(G<R!F=6QL($1.+B`J+PH@("`@("`@("1D;B`]("1T
M:&ES+3Y?9FEN9$1.*"1U<V5R260I.PH@("`@("`@(&EF("AI<U]A*"1D;BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%
M<G)O<BA!551(7U)%05-/3E]-15-304=%+"`D9&XM/F=E=$UE<W-A9V4H*2D[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\J($%T=&5M<'0@=&\@8FEN9"!T;R!T:&4@3$1!4"!S97)V97(@87,@=&AE
M('5S97(N("HO"B`@("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD*"1T:&ES+3Y?
M9',L("1D;BP@)&-R961E;G1I86QS6R=P87-S=V]R9"==*3L*("`@("`@("!I
M9B`H)&)I;F0@(3T@9F%L<V4I('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M<&%R86US6R=P87-S=V]R9%]E>'!I<F%T:6]N)UT@/3T@)WEE<R<I('L*"B`@
M("`@("`@("`@("`@("`D<VAA9&]W(#T@)'1H:7,M/E]L;V]K=7!3:&%D;W<H
M)&1N*3L*"B`@("`@("`@("`@("`@("!I9B`H)'-H861O=ULG<VAA9&]W;6%X
M)UT@)B8@)'-H861O=ULG<VAA9&]W;&%S=&-H86YG92==("8F"B`@("`@("`@
M("`@("`@("`@("`@)'-H861O=ULG<VAA9&]W=V%R;FEN9R==*2!["@H@("`@
M("`@("`@("`@("`@("`@("1T;V1A>2`](&9L;V]R*'1I;64H*2`O(#@V-#`P
M*3L*("`@("`@("`@("`@("`@("`@("`D=V%R;F1A>2`]("1S:&%D;W=;)W-H
M861O=VQA<W1C:&%N9V4G72`K"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<VAA9&]W6R=S:&%D;W=M87@G72`M("1S:&%D;W=;)W-H861O=W=A
M<FYI;F<G73L*"B`@("`@("`@("`@("`@("`@("`@)'1O97AP:7)E(#T@)'-H
M861O=ULG<VAA9&]W;&%S=&-H86YG92==("L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<VAA9&]W6R=S:&%D;W=M87@G72`M("1T;V1A>3L*
M"@H@("`@("`@("`@("`@("`@("`@(&EF("@D=&]D87D@/CT@)'=A<FYD87DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A
M=&EO;B==+3YP=7-H*'-P<FEN=&8H7R@B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(BDL("1T;V5X<&ER92DL)VAO<F1E+G=A<FYI;F<G
M*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@
M(&EF("@D=&]E>'!I<F4@/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?875T:$-R961E;G1I86QS6R=C:&%N9V5297%U97-T960G72`]
M('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1O97AP:7)E(#P@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]%6%!)4D5$
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("`D
M=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]&04E,140I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@061D(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I
M86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@
M(%1H92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D
M96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O(&)E('-E="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]P87)A;7-;)V%D)UTI('L*("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!=71H7VQD87`Z($%D9&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(BDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYN
M96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]
M("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("!G;&]B86P@)&-O;F8["B`@
M("`@("`@:68@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG875T:&QD87`G72DI
M('L*("`@("`@("`@("`@0&EN8VQU9&4@2$]21$5?0D%312`N("<O8V]N9FEG
M+VAO;VMS+G!H<"<["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H
M)U]H;W)D95]H;V]K7V%U=&AL9&%P)RDI('L*("`@("`@("`@("`@("`@("1E
M;G1R>2`](&-A;&Q?=7-E<E]F=6YC*"=?:&]R9&5?:&]O:U]A=71H;&1A<"<L
M("1U<V5R260L("1C<F5D96YT:6%L<RD["B`@("`@("`@("`@("`@("`D9&X@
M/2`D96YT<GE;)V1N)UT["B`@("`@("`@("`@("`@("`O*B!R96UO=F4@=&AE
M(&1N(&5N=')Y(&9R;VT@=&AE(&%R<F%Y+B`J+PH@("`@("`@("`@("`@("`@
M=6YS970H)&5N=')Y6R=D;B==*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\J(%1R>2!T:&ES('-I;7!L92!D969A=6QT
M(&%N9"!H;W!E(&ET('=O<FMS+B`J+PH@("`@("`@("`@("`D9&X@/2`D=&AI
M<RT^7W!A<F%M<ULG=6ED)UT@+B`G/2<@+B`D=7-E<DED("X@)RPG("X@)'1H
M:7,M/E]P87)A;7-;)V)A<V5D;B==.PH@("`@("`@("`@("`D96YT<GE;)V-N
M)UT@/2`D=7-E<DED.PH@("`@("`@("`@("`D96YT<GE;)W-N)UT@/2`D=7-E
M<DED.PH@("`@("`@("`@("`D96YT<GE;)'1H:7,M/E]P87)A;7-;)W5I9"==
M72`]("1U<V5R260["B`@("`@("`@("`@("1E;G1R>5LG;V)J96-T8VQA<W,G
M72`](&%R<F%Y7VUE<F=E*&%R<F%Y*"=T;W`G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VYE=W5S97)?
M;V)J96-T8VQA<W,G72D["B`@("`@("`@("`@("1E;G1R>5LG=7-E<E!A<W-W
M;W)D)UT@/2`D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L
M<ULG<&%S<W=O<F0G72PG)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R=64G
M*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?
M97AP:7)A=&EO;B==(#T]("=Y97,G*2!["B`@("`@("`@("`@("`@("`D96YT
M<GE;)W-H861O=TUI;B==(#T@)'1H:7,M/E]P87)A;7-;)VUI;F%G92==.PH@
M("`@("`@("`@("`@("`@)&5N=')Y6R=S:&%D;W=-87@G72`]("1T:&ES+3Y?
M<&%R86US6R=M87AA9V4G73L*("`@("`@("`@("`@("`@("1E;G1R>5LG<VAA
M9&]W5V%R;FEN9R==(#T@)'1H:7,M/E]P87)A;7-;)W=A<FYA9V4G73L*("`@
M("`@("`@("`@("`@("1E;G1R>5LG<VAA9&]W3&%S=$-H86YG92==(#T@9FQO
M;W(H=&EM92@I("\@.#8T,#`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@("1S=6-C97-S(#T@0&QD87!?861D*"1T:&ES+3Y?9',L("1D;BP@
M)&5N=')Y*3L*"B`@("`@("`@:68@*"$D<W5C8V5S<RD@>PH@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(I+"`D=7-E<DED*2`N($!L9&%P7V5R<F]R*"1T:&ES+3Y?
M9',I*3L*("`@("`@("!]"@H@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?
M9',I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;6]V92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4
M:&4@=7-E<DED('1O(&%D9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R
M260I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=A9"==*2![
M"B`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B075T:%]L
M9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*
M("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L
M("1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG875T:&QD87`G72DI('L*
M("`@("`@("`@("`@0&EN8VQU9&4@2$]21$5?0D%312`N("<O8V]N9FEG+VAO
M;VMS+G!H<"<["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)U]H
M;W)D95]H;V]K7V%U=&AL9&%P)RDI('L*("`@("`@("`@("`@("`@("1E;G1R
M>2`](&-A;&Q?=7-E<E]F=6YC*"=?:&]R9&5?:&]O:U]A=71H;&1A<"<L("1U
M<V5R260I.PH@("`@("`@("`@("`@("`@)&1N(#T@)&5N=')Y6R=D;B==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@
M4V5A<F-H(&9O<B!T:&4@=7-E<B=S(&9U;&P@1$XN("HO"B`@("`@("`@("`@
M("1D;B`]("1T:&ES+3Y?9FEN9$1.*"1U<V5R260I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D9&XL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L("1D
M;BT^9V5T365S<V%G92@I*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-U8V-E<W,@
M/2!`;&1A<%]D96QE=&4H)'1H:7,M/E]D<RPD9&XI.PH@("`@("`@(&EF("@A
M)'-U8V-E<W,I('L*("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(BDL("1U<V5R260I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@;V8@875T:&5N=&EC871I
M;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD240@("`@("`@5&AE(&]L9"!U<V5R260N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N97=)1"`@("`@("!4:&4@;F5W('5S97))9"X*("`@("`J($!P87)A
M;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!N97<@8W)E9&5N=&EA;',*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA
M;',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=A9"==*2![
M"B`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO
M"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S
M<V%G92@I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO
M;VMS)UU;)V%U=&AL9&%P)UTI*2!["B`@("`@("`@("`@($!I;F-L=61E($A/
M4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]A=71H;&1A<"<I*2![
M"B`@("`@("`@("`@("`@("`D96YT<GD@/2!C86QL7W5S97)?9G5N8R@G7VAO
M<F1E7VAO;VM?875T:&QD87`G+"`D;VQD240L("1C<F5D96YT:6%L<RD["B`@
M("`@("`@("`@("`@("`D;VQD9&X@/2`D96YT<GE;)V1N)UT["B`@("`@("`@
M("`@("`@("`D96YT<GD@/2!C86QL7W5S97)?9G5N8R@G7VAO<F1E7VAO;VM?
M875T:&QD87`G+"`D;F5W240L("1C<F5D96YT:6%L<RD["B`@("`@("`@("`@
M("`@("`D;F5W9&X@/2`D96YT<GE;)V1N)UT["B`@("`@("`@("`@("`@("!U
M;G-E="@D96YT<GE;)V1N)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH@4V5A<F-H(&9O<B!T:&4@=7-E<B=S(&9U
M;&P@1$XN("HO"B`@("`@("`@("`@("1D;B`]("1T:&ES+3Y?9FEN9$1.*"1O
M;&1)1"D["@H@("`@("`@("`@("!I9B`H:7-?82@D9&XL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1S=6-C97-S+3YG971-97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;VQD9&X@
M/2`D9&X["B`@("`@("`@("`@("`@("`D;F5W9&X@/2!P<F5G7W)E<&QA8V4H
M)R]U:60]+BH_+"\G+"=U:60])RXD;F5W240N)RPG+"1D;BPQ*3L*("`@("`@
M("`@("`@("`@("1S:&%D;W<@/2`D=&AI<RT^7VQO;VMU<%-H861O=R@D9&XI
M.PH*("`@("`@("`@("`@("`@("\J(&EF('-H861O=VUI;B!H87-N)W0@>65T
M(&5X<&ER960@;VYL>2!C:&%N9V4@=VAE;B!W92!A<F4*("`@("`@("`@("`@
M("`@("`@(&%D;6EN:7-T<F%T;W(@*B\*("`@("`@("`@("`@("`@(&EF("@D
M<VAA9&]W6R=S:&%D;W=L87-T8VAA;F=E)UT@)B8@)'-H861O=ULG<VAA9&]W
M;6EN)UTI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'-H861O=ULG<VAA
M9&]W;&%S=&-H86YG92==("L@)'-H861O=ULG<VAA9&]W;6EN)UT@/B`H=&EM
M92@I("\@.#8T,#`I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA
M<R!N;W0@>65T(&5X<&ER960B*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J(%-E="!T:&4@
M;&%S=&-H86YG92!F:65L9"`J+PH@("`@("`@("`@("`@("`@:68@*"1S:&%D
M;W=;)W-H861O=VQA<W1C:&%N9V4G72D@>PH@("`@("`@("`@("`@("`@("`@
M("1E;G1R>5LG<VAA9&]W;&%S=&-H86YG92==(#T@(&9L;V]R*'1I;64H*2`O
M(#@V-#`P*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M*B!%;F-R>7!T('1H92!N97<@<&%S<W=O<F0@*B\*("`@("`@("`@("`@("`@
M("1E;G1R>5LG=7-E<G!A<W-W;W)D)UT@/2`D=&AI<RT^9V5T0W)Y<'1E9%!A
M<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72PG)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=')U92<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&]L9$E$("$]("1N97=)1"D@>PH@("`@
M("`@("`@("!I9B`H3$1!4%]/4%1?4%)/5$]#3TQ?5D524TE/3B`]/2`S*2![
M"B`@("`@("`@("`@("`@("!L9&%P7W)E;F%M92@D=&AI<RT^7V1S+"`D;VQD
M9&XL("1N97=D;BP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+"!T<G5E*3L*
M"B`@("`@("`@("`@("`@("`D<W5C8V5S<R`](&QD87!?;6]D:69Y*"1T:&ES
M+3Y?9',L("1N97=D;BP@)&5N=')Y*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\J($=E="!T:&4@8V]M<&QE=&4@;VQD(')E8V]R
M9"!F:7)S="`J+PH@("`@("`@("`@("`@("`@)'-U8V-E<W,@/2!`;&1A<%]R
M96%D*"1T:&ES+3Y?9',L("1O;&1D;BP@)V]B:F5C=$-L87-S/2HG*3L*"B`@
M("`@("`@("`@("`@("!I9B`H)'-U8V-E<W,I('L*("`@("`@("`@("`@("`@
M("`@("`D:6YF;W)M871I;VX@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^
M7V1S+"`D<W5C8V5S<RD["@H@("`@("`@("`@("`@("`@("`@("\J(%)E;6]V
M92!T:&4@8V]U;G0@96QE;65N=',@9G)O;2!T:&4@87)R87D@*B\*("`@("`@
M("`@("`@("`@("`@("`D8V]U;G1E<B`](#`["B`@("`@("`@("`@("`@("`@
M("`@)&YE=W)E8V]R9"`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@
M=VAI;&4@*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LD8V]U;G1E<ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D:6YF;W)M871I;VY;,%U;)&EN
M9F]R;6%T:6]N6S!=6R1C;W5N=&5R75U;)V-O=6YT)UT@/3T@,2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YE=W)E8V]R9%LD:6YF;W)M871I
M;VY;,%U;)&-O=6YT97)=72`]("1I;F9O<FUA=&EO;ELP75LD:6YF;W)M871I
M;VY;,%U;)&-O=6YT97)=75LP73L*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=R96-O
M<F1;)&EN9F]R;6%T:6]N6S!=6R1C;W5N=&5R75T@/2`D:6YF;W)M871I;VY;
M,%U;)&EN9F]R;6%T:6]N6S!=6R1C;W5N=&5R75T["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D;F5W<F5C;W)D6R1I;F9O<FUA=&EO;ELP
M75LD8V]U;G1E<EU=6R=C;W5N="==*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D8V]U;G1E<BLK.PH@("`@
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@+RH@061J
M=7-T('1H92!C:&%N9V5D('!A<F%M971E<G,@*B\*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D;F5W<F5C;W)D6R=D;B==*3L*("`@("`@("`@("`@("`@
M("`@("`D;F5W<F5C;W)D6R1T:&ES+3Y?<&%R86US6R=U:60G75T@/2`D;F5W
M240["B`@("`@("`@("`@("`@("`@("`@)&YE=W)E8V]R9%LG=7-E<G!A<W-W
M;W)D)UT@/2`D96YT<GE;)W5S97)P87-S=V]R9"==.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D96YT<GE;)W-H861O=VQA<W1C:&%N9V4G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE=W)E8V]R9%LG<VAA9&]W
M;&%S=&-H86YG92==(#T@)&5N=')Y6R=S:&%D;W=L87-T8VAA;F=E)UT["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D<W5C
M8V5S<R`](&QD87!?861D*"1T:&ES+3Y?9',L)&YE=V1N+"1N97=R96-O<F0I
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<W5C8V5S<RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<W5C8V5S<R`]($!L9&%P7V1E;&5T92@D=&AI
M<RT^7V1S+"1O;&1D;BD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'-U8V-E<W,@/2!`;&1A<%]M;V1I9GDH)'1H:7,M/E]D<RP@
M)&]L9&1N+"`D96YT<GDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D<W5C
M8V5S<RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M(BDL("1N97=)1"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*
M("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(%5S97)S"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@3&ES="!O9B!5<V5R<PH@("`@
M("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@("\J
M($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U
M8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]P87)A;7-;)V9I;'1E<B==*2D@>PH@("`@("`@("`@("`D9FEL
M=&5R(#T@)'1H:7,M/E]P87)A;7-;)V9I;'1E<B==.PH@("`@("`@('T@96QS
M96EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A;7-;)V]B:F5C=&-L87-S)UTI
M*2!["B`@("`@("`@("`@("1F:6QT97(@/2`G;V)J96-T8VQA<W,])R`N("1T
M:&ES+3Y?<&%R86US6R=O8FIE8W1C;&%S<R==.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1F:6QT97(@/2`G)SL*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]P87)A;7-;)V]B:F5C=&-L87-S)UT@87,@)&]B:F5C=&-L
M87-S*2!["B`@("`@("`@("`@("`@("`D9FEL=&5R(#T@)R@F)R`N("1F:6QT
M97(["B`@("`@("`@("`@("`@("`D9FEL=&5R("X]("<H;V)J96-T8VQA<W,]
M)R`N("1O8FIE8W1C;&%S<R`N("<I*2<["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D
M<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+"`D9FEL=&5R+"!A<G)A>2@D
M=&AI<RT^7W!A<F%M<ULG=6ED)UTI*3L*("`@("`@("`D96YT<FEE<R`]($!L
M9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@("`@
M("1U<V5R;&ES="`](&%R<F%Y*"D["B`@("`@("`@)'5I9"`](%-T<FEN9SHZ
M;&]W97(H)'1H:7,M/E]P87)A;7-;)W5I9"==*3L*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D96YT<FEE<ULG8V]U;G0G73L@)&DK*RD@>PH@("`@("`@
M("`@("`D=7-E<FQI<W1;)&E=(#T@)&5N=')I97-;)&E=6R1U:61=6S!=.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<V5R;&ES=#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V-Y<G5S+G!H<```````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`P-S$`,3`U,34T,S$P-C$`,#(P
M-S<T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@075T:%]C>7)U<R!C;&%S<R!P<F]V:61E<R!H
M;W)D92!W:71H('1H92!A8FEL:71Y(&]F(&%D;6EN:7-T<F%T:6YG"B`J(&$@
M0WER=7,@;6%I;"!S97)V97(@875T:&5N=&EC871I;VYS(&%G86EN<W0@86YO
M=&AE<B!B86-K96YD('1H870@2&]R9&4*("H@8V%N('5P9&%T92`H96<@4U%,
M(&]R($Q$05`I+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J
M("`@)V-Y<F%D;6EN)R`@(%1H92!U<V5R;F%M92!O9B!T:&4@8WER=7,@861M
M:6YI<W1R871O<@H@*B`@("=C>7)P87-S)R`@("!4:&4@<&%S<W=O<F0@9F]R
M('1H92!C>7)U<R!A9&UI;FES=')A=&]R"B`J("`@)VEM87!?9'-N)R`@(%1H
M92!F=6QL($E-05`@1%-.("AI+F4N"B`@("`@("`@("`@("`@("`@('ML;V-A
M;&AO<W0Z.3DS+VEM87`O<W-L+VYO=F%L:61A=&4M8V5R='TI"B`J("`@)V)A
M8VME;F0G("`@(%1H92!C;VUP;&5T92!H87-H(&9O<B!T:&4@075T:%\J(&1R
M:79E<B!T:&%T(&-Y<G5S"B`J("`@("`@("`@("`@("`@(&%U=&AE;G1I8V%T
M97,@86=A:6YS="`H96<@4U%,+"!,1$%0*2X*("H@("`G<V5P87)A=&]R)R`@
M2&EE<F%R8VAY('-E<&%R871O<B!T;R!U<V4@*&4N9RXL(&ES(&ET('5S97(O
M;6%I;&)O>"!O<@H@*B`@("`@("`@("`@("`@("!U<V5R+FUA:6QB;W@I/"]P
M<F4^"B`J"B`J($]P=&EO;F%L('9A;'5E<SH\<')E/@H@*B`@("=U;FEX:&EE
M<B<@("!4:&4@=F%L=64@;V8@:6UA<&0N8V]N9B=S('5N:7AH:65R87)C:'ES
M97`@<V5T=&EN9RX*("H@("`@("`@("`@("`@("`@4V5T('1H:7,@=&\@)W1R
M=64G(&EF('1H92!V86QU92!I<R!T<G5E(&EN(&EM87!D+F-O;F8*("H@("`G
M9F]L9&5R<R<@("`@06X@87)R87D@;V8@9F]L9&5R<R!T;R!C<F5A=&4@=6YD
M97(@=7-E<FYA;64N"B`J("`@("`@("`@("`@("`@($1O97-N)W0@8W)E871E
M('-U8F9O;&1E<G,@8GD@9&5F875L="X*("H@("`G<75O=&$G("`@("`@5&AE
M('%U;W1A("AI;B!K:6QO8GET97,I('1O(&=R86YT(&]N('1H92!M86EL8F]X
M+@H@*B`@("`@("`@("`@("`@("!$;V5S(&YO="!E<W1A8FQI<V@@<75O=&$@
M8GD@9&5F875L="X\+W!R93X*("H*("H@17AA;7!L92!5<V%G93H\<')E/@H@
M*B`@("1C;VYF6R=A=71H)UU;)V1R:79E<B==(#T@)V-O;7!O<VET92<["B`J
M("`@)&-O;F9;)V%U=&@G75LG<&%R86US)UU;)VQO9VEN<V-R965N7W-W:71C
M:"==(#T@)U]H;W)D95]S96QE8W1?;&]G:6YS8W)E96XG.PH@*B`@("1C;VYF
M6R=A=71H)UU;)W!A<F%M<R==6R=A9&UI;E]D<FEV97(G72`]("=C>7)U<R<[
M"B`J("`@)&-O;F9;)V%U=&@G75LG<&%R86US)UU;)V1R:79E<G,G75LG:6UP
M)UT@/2!A<G)A>2@G9')I=F5R)R`]/B`G87!P;&EC871I;VXG+`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W!A<F%M<R<@/3X@87)R87DH)V%P<"<@/3X@)VEM<"<I*3L*("H@("`D
M8V]N9ELG875T:"==6R=P87)A;7,G75LG9')I=F5R<R==6R=C>7)U<R==(#T@
M87)R87DH)V1R:79E<B<@/3X@)V-Y<G5S)RP*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F%M
M<R<@/3X@87)R87DH)V-Y<F%D;6EN)R`]/B`G8WER=7,G+`H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8WER<&%S<R<@/3X@)W!A<W-W;W)D)RP*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-E<&%R871O<B<@/3X@
M)RXG+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6UA<%]D<VXG
M(#T^("=[;6%I:RYE>&%M<&QE+F-O;2]I;6%P?2<I*3L*("H@("`D8V]N9ELG
M875T:"==6R=P87)A;7,G75LG9')I=F5R<R==6R=C>7)U<R==6R=P87)A;7,G
M75LG8F%C:V5N9"==(#T@87)R87DH)V1R:79E<B<@/3X@)W-Q;"<L"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y
M*"=P:'!T>7!E)R`]/B`G;7ES<6PG+`H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("=D
M871A8F%S92YE>&%M<&QE+F-O;2<L"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P<F]T;V-O;"<@/3X@)W1C
M<"<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=U<V5R;F%M92<@/3X@)W5S97)N86UE)RP*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M<W-W;W)D)R`]/B`G<&%S<W=O<F0G+`H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("=M
M86EL)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1A8FQE)R`]/B`G86-C;W5N='5S97(G+`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M96YC<GEP=&EO;B<@/3X@)VUD-2UH97@G+`H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;65?9FEE
M;&0G(#T^("=U<V5R;F%M92<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9%]F:65L9"<@/3X@
M)W!A<W-W;W)D)RDI.PH@*@H@*B`@(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?
M:&]R9&5?<V5L96-T7VQO9VEN<V-R965N)RDI('L*("H@("`@("`@9G5N8W1I
M;VX@7VAO<F1E7W-E;&5C=%]L;V=I;G-C<F5E;B@I('L*("H@("`@("`@("`@
M(')E='5R;B`G:6UP)SL*("H@("`@("`@?0H@*B`@('T\+W!R93X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<"QV(#$N,34N
M,3`N,30@,C`P-B\P."\Q-"`P,CHT.#HT."!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($EL>6$@/&UA:6Q`:W)E;"YO<F<^"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($EL>6$@
M/&UA:6Q`:W)E;"YO<F<^"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7V-Y<G5S(&5X
M=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C
M=7)R96YT($E-05`@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E
M<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7VEM87!3=')E86T["@H@("`@+RHJ
M"B`@("`@*B!&;&%G(&EN9&EC871I;F<@:68@=&AE($E-05`@8V]N;F5C=&EO
M;B!I<R!C;VYN96-T960N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9#L*"B`@("`O*BH*("`@("`J(%!O
M:6YT97(@=&\@86YO=&AE<B!!=71H7R!B86-K96YD('1H870@0WER=7,@875T
M:&5N=&EC871E<R!A9V%I;G-T+@H@("`@("H*("`@("`J($!V87(@075T:`H@
M("`@("HO"B`@("`@=F%R("1?8F%C:V5N9#L*"B`@("`O*BH*("`@("`J($%N
M(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A
M;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@
M86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G
M("`@("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=7!D871E)R`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@
M=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9W)O=7!S)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P
M87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V-Y<G5S*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@)'!A<F%M<SL*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M
M<ULG<V5P87)A=&]R)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=S97!A<F%T;W(G72`]("<N)SL*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A<F%M<ULG=6YI>&AI97(G72D@)B8@)'1H:7,M/E]P
M87)A;7-;)W5N:7AH:65R)UT@/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<V5P87)A=&]R)UT@/2`G+R<["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G:6UA<"<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"A?*")!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@8F%C:V5N9"!I
M;G-T86YC92X*("`@("`@("`D=&AI<RT^7V)A8VME;F0@/2`F075T:#HZ<VEN
M9VQE=&]N*"1T:&ES+3Y?<&%R86US6R=B86-K96YD)UU;)V1R:79E<B==+"`D
M=&AI<RT^7W!A<F%M<ULG8F%C:V5N9"==6R=P87)A;7,G72D["B`@("`@("`@
M:68@*&ES7V$H)'1H:7,M/E]B86-K96YD+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V)A8VME;F0["B`@("`@("`@?0H*
M("`@("`@("`O+R!#:&5C:R!T:&4@8V%P86)I;&ET:65S(&]F('1H92!B86-K
M96YD+@H@("`@("`@(&EF("@A)'1H:7,M/E]B86-K96YD+3YH87-#87!A8FEL
M:71Y*"=A9&0G*2!\?`H@("`@("`@("`@("`A)'1H:7,M/E]B86-K96YD+3YH
M87-#87!A8FEL:71Y*"=U<&1A=&4G*2!\?`H@("`@("`@("`@("`A)'1H:7,M
M/E]B86-K96YD+3YH87-#87!A8FEL:71Y*"=R96UO=F4G*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH7R@B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F-A<&%B:6QI
M=&EE<ULG;&ES="==(#T@)'1H:7,M/E]B86-K96YD+3YH87-#87!A8FEL:71Y
M*"=L:7-T)RD["B`@("`@("`@)'1H:7,M/F-A<&%B:6QI=&EE<ULG9W)O=7!S
M)UT@/2`D=&AI<RT^7V)A8VME;F0M/FAA<T-A<&%B:6QI='DH)V=R;W5P<R<I
M.PH@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;)W1R86YS<&%R96YT)UT@
M/2`D=&AI<RT^7V)A8VME;F0M/FAA<T-A<&%B:6QI='DH)W1R86YS<&%R96YT
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N
M=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@=&\@861D+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T
M;R!A9&0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA
M;',I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("1R97,@/2`D=&AI<RT^7V)A8VME;F0M/F%D9%5S97(H)'5S97))9"P@)&-R
M961E;G1I86QS*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@
M("`@("`@)&YA;64@/2!I;6%P7W5T9C=?96YC;V1E*"1U<V5R260I.PH@("`@
M("`@(&EF("A`:6UA<%]C<F5A=&5M86EL8F]X*"1T:&ES+3Y?:6UA<%-T<F5A
M;2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;6%P7W5T9C=?
M96YC;V1E*"1T:&ES+3Y?<&%R86US6R=I;6%P7V1S;B==("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=7-E<B<@+B`D=&AI<RT^7W!A<F%M
M<ULG<V5P87)A=&]R)UT@+B`D;F%M92DI*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A<F%M<ULG9F]L9&5R<R==*2`F)B!I<U]A<G)A>2@D
M=&AI<RT^7W!A<F%M<ULG9F]L9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;)V9O;&1E<G,G72!A<R`D9F]L9&5R
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C<F5A=&53=6)&;VQD
M97(H)&YA;64L("1F;VQD97(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)TE-05`@;6%I;&)O>"!C<F5A=&EO;B!F;W(@)R`N("1N86UE
M("X@)R!F86EL960@)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(BDL(&EM87!?;&%S=%]E<G)O<B@I
M*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A
M;7-;)W%U;W1A)UTI("8F("1T:&ES+3Y?<&%R86US6R=Q=6]T82==(#X](#`I
M('L*("`@("`@("`@("`@:68@*"%`:6UA<%]S971?<75O=&$H)'1H:7,M/E]I
M;6%P4W1R96%M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=7-E<B<@+B`D=&AI<RT^7W-E<&%R871O<B`N("1N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<75O=&$G
M72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B*2P@:6UA<%]L87-T7V5R<F]R*"DI*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N
M=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4
M:&4@=7-E<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@("`@("`@(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/E]B86-K
M96YD+3YR96UO=F55<V5R*"1U<V5R260I.PH@("`@("`@(&EF("AI<U]A*"1R
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@?0H*("`@("`@("`O*B!3970@04-,(&9O<B!M86EL8F]X(&1E
M;&5T:6]N+B`J+PH@("`@("`@(&QI<W0H)&%D;6EN*2`](&5X<&QO9&4H)T`G
M+"`D=&AI<RT^7W!A<F%M<ULG8WER861M:6XG72D["B`@("`@("`@0&EM87!?
M<V5T86-L*"1T:&ES+3Y?:6UA<%-T<F5A;2P*("`@("`@("`@("`@("`@("`@
M("`@)W5S97(G("X@)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@)'5S
M97))9"P*("`@("`@("`@("`@("`@("`@("`@)&%D;6EN+"`G;')S=VEP8V1A
M)RD["@H@("`@("`@("\J($1E;&5T92!)34%0(&UA:6QB;W@N("HO"B`@("`@
M("`@)&EM87!R97-U;'0@/2!`:6UA<%]D96QE=&5M86EL8F]X*"1T:&ES+3Y?
M:6UA<%-T<F5A;2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VEM87!?9'-N)UT@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<B<@+B`D
M=&AI<RT^7W!A<F%M<ULG<V5P87)A=&]R)UT@+B`D=7-E<DED*3L*"B`@("`@
M("`@:68@*"$D:6UA<')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(BDL(&EM87!?;&%S=%]E<G)O<B@I*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V955S97)$871A*"1U<V5R
M260I.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!C
M;VYN96-T:6]N<R!T;R!T:&4@4U%,(&%N9"!)34%0('-E<G9E<G,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H
M*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]C;VYN96-T960I('L*"B`@
M("`@("`@("`@("1T:&ES+3Y?:6UA<%-T<F5A;2`]($!I;6%P7V]P96XH)'1H
M:7,M/E]P87)A;7-;)VEM87!?9'-N)UTL("1T:&ES+3Y?<&%R86US6R=C>7)A
M9&UI;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=C>7)P87-S)UTL($]07TA!3$9/4$5.
M*3L*"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]I;6%P4W1R96%M*2!["B`@
M("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH<W!R:6YT9BA?*")#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:6UA<%]L87-T7V5R<F]R*"DI+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@
M9G)O;2!T:&4@24U!4"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C
M;VYN96-T960I('L*("`@("`@("`@("`@0&EM87!?8VQO<V4H)'1H:7,M/E]I
M;6%P4W1R96%M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&UA:6QB;WAE<R!S=7!P
M;&EE9"!I;B!C;VYF:6=U<F%T:6]N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DYA;64@
M("!&;W(@=VAO;2!T:&4@9F]L9&5R('=I;&P@8F4@8W)E871E9`H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F]L9&5R3F%M92!.86UE(&]F(&9O;&1E<B!T;R!C
M<F5A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T95-U8D9O;&1E<B@D
M=7-E<DYA;64L("1F;VQD97).86UE*0H@("`@>PH@("`@("`@("!`:6UA<%]C
M<F5A=&5M86EL8F]X*"1T:&ES+3Y?:6UA<%-T<F5A;2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EM87!?=71F-U]E;F-O9&4H)'1H:7,M/E]P87)A
M;7-;)VEM87!?9'-N)UT@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W5S97(G("X@)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@)'5S97).
M86UE("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=S97!A<F%T;W(G72`N("1F;VQD97).86UE*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T:&4@<WES
M=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O
M9B!U<V5R261S+"!O<B!F86QS92!O;B!F86EL=7)E+W5N<W5P<&]R=&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V)A8VME;F0M/FQI<W15<V5R<R@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N
M(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L
M9$E$("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F5W240@("`@("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`<&%R86T@
M87)R87D@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)A8VME;F0M/G5P9&%T
M955S97(H)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R
M965N(&9O<B!T:&ES(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@
M;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I
M;B!S8W)E96X@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y3
M8W)E96XH)&%P<"`]("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]B86-K96YD+3Y?9V5T3&]G:6Y38W)E96XH)&%P
M<"P@)'5R;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!U
M<V5R260@97AI<W1S(&EN('1H92!S:7-T96TN"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@=7-E<DED(&%L<F5A
M9'D@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)'5S97))
M9"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B86-K96YD+3YE>&ES
M=',H)'5S97))9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6,@
M875T:&5N=&EC871I;VXZ($9I;F0@;W5T(&EF('1H92!C;&EE;G0@;6%T8VAE
M<R!A;B!A;&QO=V5D($E0"B`@("`@*B!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@
M86QL;W=E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)A8VME;F0M/G1R86YS<&%R
M96YT*"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#(R-#`P`#$P-3$U-#,Q,#8Q`#`R,3`W,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M<F5Q=6ER95]O;F-E("=(;W)D92]$871A5')E92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+T9O<FTN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M
M+U)E;F1E<F5R+G!H<"<["@HO*BH*("H@075T:%]3:6=N=7`Z.B!4:&ES(&-L
M87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C92!T;R!S:6=N('5P(&]R(&AA=F4*
M("H@;F5W('5S97)S('-I9VX@=&AE;7-E;'9E<R!U<"!I;G1O('1H92!H;W)D
M92!I;G-T86QL871I;VXL(&1E<&5N9&EN9PH@*B!O;B!H;W<@=&AE(&%D;6EN
M(&AA<R!C;VYF:6=U<F5D($AO<F1E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<"QV(#$N,S@N,BXQ,2`R,#`V+S`X+S$T
M(#`R.C0X.C0X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H
M"B`J+PIC;&%S<R!!=71H7U-I9VYU<"!["@H@("`@+RHJ"B`@("`@*B!0;VEN
M=&5R('1O(&$@1&%T851R964@:6YS=&%N8V4@=&\@;6%N86=E+W-T;W)E('-I
M9VYU<',*("`@("`J"B`@("`@*B!`=F%R($1A=&%4<F5E"B`@("`@*B\*("`@
M('9A<B`D7V1A=&%T<F5E.PH*("`@(&9U;F-T:6]N($%U=&A?4VEG;G5P*"D*
M("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AE;7!T
M>2@D8V]N9ELG9&%T871R964G75LG9')I=F5R)UTI*2!["B`@("`@("`@("`@
M($AO<F1E.CIF871A;"A?*")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E
M92!B86-K96YD('1O('5S92!3:6=N=7!S+B(I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*("`@("`@("`D9')I=F5R(#T@)&-O;F9;)V1A=&%T
M<F5E)UU;)V1R:79E<B==.PH@("`@("`@("1T:&ES+3Y?9&%T871R964@/2`F
M1&%T851R964Z.G-I;F=L971O;B@D9')I=F5R+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]M97)G92A(
M;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D<FEV97(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G9W)O=7`G(#T^("=H;W)D92YS:6=N=7`G
M*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@075T:%]3:6=N=7`*("`@("`J
M(&EN<W1A;F-E+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E
M(&EF(&YO($%U=&A?4VEG;G5P"B`@("`@*B!I;G-T86YC92!C=7)R96YT;'D@
M97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV
M;VME9"!A<SH@)'9A<B`]("9!=71H7U-I9VYU<#HZ<VEN9VQE=&]N*"D*("`@
M("`J"B`@("`@*B!`<F5T=7)N($%U=&A?4VEG;G5P("!4:&4@8V]N8W)E=&4@
M075T:%]3:6=N=7`@<F5F97)E;F-E+"!O<B!F86QS92!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@("!["B`@("`@("`@
M<W1A=&EC("1S:6=N=7`["@H@("`@("`@(&EF("@A:7-S970H)'-I9VYU<"DI
M('L*("`@("`@("`@("`@)'-I9VYU<"`](&YE=R!!=71H7U-I9VYU<"@I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S:6=N=7`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@;F5W('5S97(@=&\@=&AE('-Y<W1E;2!A;F0@
M:&%N9&QE<R!A;GD@97AT<F$@9FEE;&1S('1H870@;6%Y(&AA=F4*("`@("`J
M(&)E96X@8V]M<&EL960L(')E;'EI;F<@;VX@=&AE(&AO;VMS+G!H<"!F:6QE
M+@H@("`@("H*("`@("`J($!P87)A;7,@;6EX960@)&EN9F\@(%)E9F5R96YC
M92!T;R!A<G)A>2!O9B!P87)A;65T97)E<R!T;R!B92!P87-S960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@('1O(&AO;VL*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!014%27T5R<F]R(&EF(&%N>2!E<G)O<G,L(&]T:&5R
M=VES92!T<G5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&13:6=N=7`H)B1I
M;F9O*0H@("`@>PH@("`@("`@(&=L;V)A;"`D875T:"P@)&-O;F8["@H@("`@
M("`@("\O(%!E<F9O<FT@86YY('!R97!R;V-E<W-I;F<@:68@<F5Q=65S=&5D
M+@H@("`@("`@(&EF("@D8V]N9ELG<VEG;G5P)UU;)W!R97!R;V-E<W,G72D@
M>PH@("`@("`@("`@("`D:6YF;R`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E
M7VAO;VM?<VEG;G5P7W!R97!R;V-E<W,G+"!A<G)A>2@D:6YF;RDI.PH@("`@
M("`@("`@("!I9B`H:7-?82@D:6YF;RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!!='1E;7!T('1O(&%D9"!T:&4@=7-E<B!T;R!T
M:&4@<WES=&5M+@H@("`@("`@("1S=6-C97-S(#T@)&%U=&@M/F%D9%5S97(H
M)&EN9F];)W5S97)?;F%M92==+"!A<G)A>2@G<&%S<W=O<F0G(#T^("1I;F9O
M6R=P87-S=V]R9"==*2D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=6-C97-S.PH@
M("`@("`@('T*"B`@("`@("`@+R\@071T96UP="!T;R!A9&0O=7!D871E(&%N
M>2!E>'1R82!D871A(&AA;F1E9"!I;BX*("`@("`@("!I9B`H(65M<'1Y*"1I
M;F9O6R=E>'1R82==*2D@>PH@("`@("`@("`@("`D861D960@/2!F86QS93L*
M("`@("`@("`@("`@)&%D9&5D(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?
M:&]O:U]S:6=N=7!?861D97AT<F$G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)&EN9F];)W5S97)?;F%M92==+"`D:6YF
M;ULG97AT<F$G72DI.PH@("`@("`@("`@("!I9B`H(21A9&1E9"!\?"!I<U]A
M*"1A9&1E9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)&%D9&5D+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T5-15)'*3L*("`@("`@("`@("`@("`@($AO<F1E.CIF871A;"A?
M*")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%%U975E<R!T:&4@=7-E<B=S('-U8FUI='1E9"!R96=I
M<W1R871I;VX@:6YF;R!F;W(@;&%T97(@861M:6X@87!P<F]V86PN"B`@("`@
M*@H@("`@("H@0'!A<F%M<R!M:7AE9"`D:6YF;R`@4F5F97)E;F-E('1O(&%R
M<F%Y(&]F('!A<F%M971E<F5S('1O(&)E('!A<W-E9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@=&\@:&]O:PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%!%05)?17)R;W(@:68@86YY(&5R<F]R<RP@;W1H97)W:7-E('1R
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N("9Q=65U95-I9VYU<"@F)&EN9F\I
M"B`@("!["B`@("`@("`@9VQO8F%L("1A=71H+"1C;VYF.PH*("`@("`@("`O
M+R!097)F;W)M(&%N>2!P<F5P<F]C97-S:6YG(&EF(')E<75E<W1E9"X*("`@
M("`@("!I9B`H)&-O;F9;)W-I9VYU<"==6R=P<F5P<F]C97-S)UTI('L*("`@
M("`@("`@("`@)&EN9F\@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K
M7W-I9VYU<%]P<F5P<F]C97-S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)&EN9F\I*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&EN9F\L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D:6YF;SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@0VAE8VL@=&\@<V5E(&EF('1H92!U<V5R;F%M92!A;')E861Y(&5X:7-T
M<RX*("`@("`@("!I9B`H)&%U=&@M/F5X:7-T<R@D:6YF;ULG=7-E<E]N86UE
M)UTI('Q\"B`@("`@("`@("`@("1T:&ES+3Y?9&%T871R964M/F5X:7-T<R@D
M:6YF;ULG=7-E<E]N86UE)UTI*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B57-E<FYA;64@7"(E<UPB(&%L<F5A
M9'D@97AI<W1S+B(I+"`D:6YF;ULG=7-E<E]N86UE)UTI*3L*("`@("`@("!]
M"@H@("`@("`@("\O($EF(&ET)W,@82!U;FEQ=64@=7-E<FYA;64L(&=O(&%H
M96%D(&%N9"!Q=65U92!T:&4@<F5Q=65S="X*("`@("`@("`D<VEG;G5P(#T@
M)'1H:7,M/FYE=U-I9VYU<"@D:6YF;ULG=7-E<E]N86UE)UTI.PH@("`@("`@
M(&EF("@A96UP='DH)&EN9F];)V5X=')A)UTI*2!["B`@("`@("`@("`@("1S
M:6=N=7`M/F1A=&$@/2!A<G)A>5]M97)G92@D:6YF;ULG97AT<F$G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P
M87-S=V]R9"<@/3X@)&EN9F];)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&%T95)E8V5I=F5D
M)R`]/B!T:6UE*"DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<VEG;G5P+3YD871A(#T@87)R87DH)W!A<W-W;W)D)R`]/B`D:6YF;ULG<&%S
M<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M871E4F5C96EV960G(#T^('1I;64H*2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&-O;F9;)W-I9VYU<"==6R=Q=65U92==*2!["B`@("`@("`@("`@("1R
M97-U;'0@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]Q
M=65U960G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"1I;F9O6R=U<V5R7VYA;64G72P@)&EN9F\I*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)'-I
M9VYU<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!U<V5R)W,@<75E
M=65D('-I9VYU<"!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R;F%M92`@5&AE('5S97)N86UE('1O(')E=')I979E('1H
M92!Q=65U960@:6YF;R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A
M5')E94]B:F5C=%]3:6=N=7`@(%1H92!$871A5')E94]B:F5C="!F;W(@=&AE
M(')E<75E<W1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-I9VYU<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T475E=65D4VEG
M;G5P*"1U<V5R;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D
M871A=')E92T^9V5T3V)J96-T*"1U<V5R;F%M92P@)T1A=&%4<F5E3V)J96-T
M7U-I9VYU<"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!Q=65U
M960@:6YF;W)M871I;VX@9F]R(&%L;"!P96YD:6YG('-I9VYU<',N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@1&%T851R965/
M8FIE8W1?4VEG;G5P(&]B:F5C=',L(&]N92!F;W(*("`@("`J("`@("`@("`@
M("`@("`@(&5A8V@@<VEG;G5P(&EN('1H92!Q=65U92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T475E=65D4VEG;G5P<R@I"B`@("!["B`@("`@("`@)'-I
M9VYU<',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9&%T
M871R964M/F=E="A$051!5%)%15]&3U)-051?1DQ!5"P@1$%40512145?4D]/
M5"P@=')U92D@87,@)'5S97)N86UE*2!["B`@("`@("`@("`@(&EF("@D=7-E
M<FYA;64@(3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`@("`@)'-I
M9VYU<'-;72`]("1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C="@D=7-E<FYA
M;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<VEG;G5P<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A('%U975E
M9"!S:6=N=7`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA
M;64@(%1H92!U<V5R('1O(')E;6]V92!F<F]M('1H92!S:6=N=7`@<75E=64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V95%U975E9%-I9VYU<"@D=7-E
M<FYA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]D871A=')E92T^<F5M;W9E
M*"1U<V5R;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!N
M97<@<VEG;G5P(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@<VEG;G5P<R=S(&YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!$871A5')E94]B:F5C=%]3:6=N=7`@($$@;F5W('-I9VYU<"!O8FIE
M8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=3:6=N=7`H)&YA;64I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4VEG;G5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y)RD["B`@("`@("`@?0H@("`@("`@("1S:6=N=7`@/2`F;F5W
M($1A=&%4<F5E3V)J96-T7U-I9VYU<"@D;F%M92D["B`@("`@("`@<F5T=7)N
M("1S:6=N=7`["B`@("!]"@I]"@HO*BH*("H@17AT96YS:6]N(&]F('1H92!$
M871A5')E94]B:F5C="!C;&%S<R!F;W(@<W1O<FEN9R!3:6=N=7`*("H@:6YF
M;W)M871I;VX@:6X@=&AE($1A=&%4<F5E(&1R:79E<BX@268@>6]U('=A;G0@
M=&\@<W1O<F4*("H@<W!E8VEA;&EZ960@4VEG;G5P(&EN9F]R;6%T:6]N+"!Y
M;W4@<VAO=6QD(&5X=&5N9"!T:&ES(&-L87-S"B`J(&EN<W1E860@;V8@97AT
M96YD:6YG($1A=&%4<F5E3V)J96-T(&1I<F5C=&QY+@H@*@H@*B!`875T:&]R
M("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@1&%T
M851R965/8FIE8W1?4VEG;G5P(&5X=&5N9',@1&%T851R965/8FIE8W0@>PH*
M("`@("\J*@H@("`@("H@5V4@=V%N="!T;R!S964@<75E=65D('-I9VYU<',@
M:6X@9&5S8V5N9&EN9R!O<F1E<B!O9B!R96-E:7!T+@H@("`@("H@26YS97)T
M(&YE=R!S:6=N=7!S(&%T('!O<VET:6]N(#`@86YD('!U<V@@=&AE(')E<W0@
M9&]W;BX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1O<F1E<B`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@1&%T851R965/
M8FIE8W1?4VEG;G5P(&-O;G-T<G5C=&]R+B!*=7-T(&UA:V5S('-U<F4@=&\@
M8V%L;`H@("`@("H@=&AE('!A<F5N="!C;VYS=')U8W1O<B!S;R!T:&%T('1H
M92!S:6=N=7`G<R!I<R!I<R!S970*("`@("`J('!R;W!E<FQY+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@:60@;V8@=&AE('-I9VYU
M<"X*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R965/8FIE8W1?4VEG;G5P
M*"1I9"D*("`@('L*("`@("`@("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T*"1I
M9"D["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/F1A=&$I*2!["B`@("`@
M("`@("`@("1T:&ES+3YD871A(#T@87)R87DH*3L*("`@("`@("!]"B`@("!]
M"@I]"@HO*BH*("H@2&]R9&4@4VEG;G5P($9O<FTL(&5X=&5N9&EN9R!O9B!(
M;W)D95]&;W)M.CH*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$
M:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@
M2&]R9&53:6=N=7!&;W)M(&5X=&5N9',@2&]R9&5?1F]R;2!["@H@("`@=F%R
M("1?=7-E1F]R;51O:V5N(#T@=')U93L*"B`@("!F=6YC=&EO;B!(;W)D95-I
M9VYU<$9O<FTH)B1V87)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["@H@("`@("`@('!A<F5N=#HZ2&]R9&5?1F]R;2@D=F%R<RP@<W!R:6YT
M9BA?*"(E<R!3:6=N(%5P(BDL("1R96=I<W1R>2T^9V5T*"=N86UE)RDI*3L*
M"B`@("`@("`@)'1H:7,M/G-E=$)U='1O;G,H7R@B4VEG;B!U<"(I+"!T<G5E
M*3L*"B`@("`@("`@)'1H:7,M/F%D9$AI9&1E;B@G)RP@)W5R;"<L("=T97AT
M)RP@9F%L<V4I.PH@("`@("`@("1T:&ES+3YA9&1687)I86)L92A?*")#:&]O
M<V4@82!U<V5R;F%M92(I+"`G=7-E<E]N86UE)RP@)W1E>'0G+"!T<G5E*3L*
M("`@("`@("`D=&AI<RT^861D5F%R:6%B;&4H7R@B0VAO;W-E(&$@<&%S<W=O
M<F0B*2P@)W!A<W-W;W)D)RP@)W!A<W-W;W)D8V]N9FER;2<L('1R=64L(&9A
M;'-E+"!?*")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(BDI
M.PH*("`@("`@("`O*B!5<V4@:&]O:W,@9V5T(&%N>2!E>'1R82!F:65L9',@
M<F5Q=6ER960@:6X@<VEG;FEN9R!U<"X@*B\*("`@("`@("`D97AT<F$@/2!(
M;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]G971E>'1R82<I
M.PH@("`@("`@(&EF("@A:7-?82@D97AT<F$L("=014%27T5R<F]R)RD@)B8@
M(65M<'1Y*"1E>'1R82DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&5X=')A
M(&%S("1F:65L9%]N86UE(#T^("1F:65L9"D@>PH@("`@("`@("`@("`@("`@
M)')E861O;FQY(#T@:7-S970H)&9I96QD6R=R96%D;VYL>2==*2`_("1F:65L
M9%LG<F5A9&]N;'DG72`Z(&YU;&P["B`@("`@("`@("`@("`@("`D9&5S8R`]
M(&ES<V5T*"1F:65L9%LG9&5S8R==*2`_("1F:65L9%LG9&5S8R==(#H@;G5L
M;#L*("`@("`@("`@("`@("`@("1R97%U:7)E9"`](&ES<V5T*"1F:65L9%LG
M<F5Q=6ER960G72D@/R`D9FEE;&1;)W)E<75I<F5D)UT@.B!F86QS93L*("`@
M("`@("`@("`@("`@("1F:65L9%]P87)A;7,@/2!I<W-E="@D9FEE;&1;)W!A
M<F%M<R==*2`_("1F:65L9%LG<&%R86US)UT@.B!A<G)A>2@I.PH*("`@("`@
M("`@("`@("`@("1T:&ES+3YA9&1687)I86)L92@D9FEE;&1;)VQA8F5L)UTL
M("=E>'1R85LG("X@)&9I96QD7VYA;64@+B`G72<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I96QD6R=T>7!E)UTL("1R97%U:7)E
M9"P@)')E861O;FQY+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D97-C+"`D9FEE;&1?<&%R86US*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:7!M
M87`N<&AP````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0U
M-``Q,#4Q-30S,3`V,0`P,C`W-#$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O:7!B87-I8RYP:'`G.PH*+RHJ"B`J(%1H92!!=71H
M7VEP;6%P(&-L87-S('!R;W9I9&5S(&%C8V5S<R!C;VYT<F]L(&)A<V5D(&]N
M($-)1%(@;6%S:W,N"B`J"B`J(%!A<F%M971E<G,Z"B`J("`@3D].10H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!M87`N<&AP+'8@,2XQ
M-"XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS
M"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:7!M87`@
M97AT96YD<R!!=71H7VEP8F%S:6,@>PH*("`@("\J*@H@("`@("H@06X@87)R
M87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E
M<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@
M=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=7!D871E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<W!A<F5N="<@("`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=',@82!N97<@25`M;6%P<&EN9R!A=71H96YT:6-A=&EO;B!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S
M:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($%U=&A?:7!M87`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O075T:"]S87-L+G!H<```````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,#$Q`#$P-3$U-#,Q,#8Q`#`R,#4V-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE($%U=&A?<V%S;#HZ(&-L87-S('!R;W9I9&5S(&$@4T%3
M3"UB87-E9"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T:&5N
M=&EC871I;VX@<WES=&5M+@H@*@H@*B!305-,(&ES('1H92!3:6UP;&4@075T
M:&5N=&EC871I;VX@86YD(%-E8W5R:71Y($QA>65R("AA<R!D969I;F5D(&)Y
M(%)&0PH@*B`R,C(R*2X@270@<')O=FED97,@82!S>7-T96T@9F]R(&%D9&EN
M9R!P;'5G86)L92!A=71H96YT:6-A=&EN9R!S=7!P;W)T('1O"B`J(&-O;FYE
M8W1I;VXM8F%S960@<')O=&]C;VQS+@H@*@H@*B!4:&ES(&1R:79E<B!R96QI
M97,@;VX@=&AE(%!%0TP@<V%S;"!P86-K86=E.@H@*@H@*B`@("`@(&AT='`Z
M+R]P96-L+G!H<"YN970O<&%C:V%G92]S87-L"B`J"B`J($]P=&EO;F%L('!A
M<F%M971E<G,Z/'!R93X*("H@("`G87!P)R`@("`@(%1H92!N86UE(&]F('1H
M92!A=71H96YT:6-A=&EN9R!A<'!L:6-A=&EO;BX*("H@("`@("`@("`@("`@
M($1%1D%53%0Z(&AO<F1E"B`J("`@)W-E<G9I8V4G("!4:&4@;F%M92!O9B!T
M:&4@4T%33"!S97)V:6-E('1O('5S92!W:&5N(&%U=&AE;G1I8V%T:6YG+@H@
M*B`@("`@("`@("`@("`@1$5&055,5#H@<&AP/"]P<F4^"B`J"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<"QV(#$N-"XQ,"XY
M(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`T+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!087)I<V4@/&IO;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!
M=71H"B`J+PIC;&%S<R!!=71H7W-A<VP@97AT96YD<R!!=71H('L*"B`@("`O
M*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T
M:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@
M:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`]
M(&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO
M=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!305-,(&%U=&AE;G1I
M8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7W-A<VPH)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US
M.PH*("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H)W-A<VPG*2D@>PH@
M("`@("`@("`@("!D;"@G<V%S;"YS;R<I.PH@("`@("`@('T*"B`@("`@("`@
M)&%P<"`]("@A96UP='DH)'!A<F%M<ULG87!P)UTI*2`_("1P87)A;7-;)V%P
M<"==(#H@)VAO<F1E)SL*("`@("`@("!S87-L7W-E<G9E<E]I;FET*"1A<'`I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@
M;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S
M97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@
M87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT
M:6%L<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@
M;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D8W)E9&5N=&EA;'-;)W!A<W-W
M;W)D)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(BDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(65X
M=&5N<VEO;E]L;V%D960H)W-A<VPG*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH7R@B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M)'-E<G9I8V4@/2`H(65M<'1Y*"1P87)A;7-;)W-E<G9I8V4G72DI(#\@)'!A
M<F%M<ULG<V5R=FEC92==(#H@)W!H<"<["B`@("`@("`@)&-O;FX@/2!S87-L
M7W-E<G9E<E]N97<H)'-E<G9I8V4I.PH@("`@("`@(&EF("@A:7-?<F5S;W5R
M8V4H)&-O;FXI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(BDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(7-A<VQ?8VAE
M8VMP87-S*"1C;VYN+"`D=7-E<DED+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?
M4D5!4T].7TU%4U-!1T4L('-A<VQ?97)R9&5T86EL*"1C;VYN*2D["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8V]M<&]S:71E+G!H<```````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R,34T,P`Q,#4Q-30S,3`V,0`P,C$V,S4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!!=71H7V-O;7!O<VET92!C;&%S<R!P<F]V:61E<R!A
M('=R87!P97(@87)O=6YD"B`J(&%P<&QI8V%T:6]N+7!R;W9I9&5D($AO<F1E
M(&%U=&AE;G1I8V%T:6]N('=H:6-H(&9I=',@:6YS:61E('1H90H@*B!(;W)D
M92!!=71H.CH@05!)+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^
M"B`J("`@3F]N92X\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M075T:"]!=71H+V-O;7!O<VET92YP:'`L=B`Q+C(V+C$P+C$P(#(P,#8O,#@O
M,30@,#(Z-#@Z-#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]C;VUP;W-I=&4@97AT96YD<R!!
M=71H('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!A;GD@:6YS
M=&%N=&EA=&5D(&1R:79E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]D<FEV97)S(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=',@82!N97<@0V]M<&]S:71E(&%U=&AE;G1I8V%T
M:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V-O;7!O<VET92@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R
M86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-E=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@0V]M
M<&]S:71E(&%U=&AE;G1I8V%T:6]N+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&YA;65D('!A<F%M
M971E<B!F;W(@=&AE(&-U<G)E;G0@875T:"!D<FEV97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%R86T@(%1H92!P87)A;65T97(@=&\@9F5T
M8V@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)A;65T
M97(G<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86TH)'!A
M<F%M*0H@("`@>PH@("`@("`@(&EF("@H)&QO9VEN7V1R:79E<B`]($%U=&@Z
M.E]G971$<FEV97)">5!A<F%M*"=L;V=I;G-C<F5E;E]S=VET8V@G+"`D=&AI
M<RT^7W!A<F%M<RDI("8F"B`@("`@("`@("`@("1T:&ES+3Y?;&]A9$1R:79E
M<B@D;&]G:6Y?9')I=F5R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]D<FEV97)S6R1L;V=I;E]D<FEV97)=+3YG971087)A;2@D<&%R86TI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L
M<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S
M97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA
M;',@(%1H92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@
M87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E
M*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H*"1A
M=71H7V1R:79E<B`]($%U=&@Z.E]G971$<FEV97)">5!A<F%M*"=L;V=I;G-C
M<F5E;E]S=VET8V@G+"`D=&AI<RT^7W!A<F%M<RDI("8F"B`@("`@("`@("`@
M("1T:&ES+3Y?;&]A9$1R:79E<B@D875T:%]D<FEV97(I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1R:79E<G-;)&%U=&A?9')I=F5R72T^875T
M:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD["B`@("`@("`@?0H*
M("`@("`@("!I9B`H*"1A=71H7V1R:79E<B`]($%U=&@Z.E]G971$<FEV97)"
M>5!A<F%M*"=U<V5R;F%M95]S=VET8V@G+"`D=&AI<RT^7W!A<F%M<RP@87)R
M87DH)'5S97))9"DI*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV
M97(H)&%U=&A?9')I=F5R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]D<FEV97)S6R1A=71H7V1R:79E<ETM/FAA<T-A<&%B:6QI='DH)W1R86YS
M<&%R96YT)RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=$%U=&A%
M<G)O<BA!551(7U)%05-/3E]&04E,140I.PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%%U97)Y('1H92!C=7)R96YT($%U
M=&@@;V)J96-T('1O(&9I;F0@;W5T(&EF(&ET('-U<'!O<G1S('1H92!G:79E
M;@H@("`@("H@8V%P86)I;&ET>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C87!A8FEL:71Y("!4:&4@8V%P86)I;&ET>2!T;R!T97-T(&9O<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T
M('1H92!C87!A8FEL:71Y(&ES('-U<'!O<G1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:&%S0V%P86)I;&ET>2@D8V%P86)I;&ET>2D*("`@('L*("`@("`@
M("!S=VET8V@@*"1C87!A8FEL:71Y*2!["B`@("`@("`@8V%S92`G861D)SH*
M("`@("`@("!C87-E("=U<&1A=&4G.@H@("`@("`@(&-A<V4@)W)E;6]V92<Z
M"B`@("`@("`@8V%S92`G;&ES="<Z"B`@("`@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==*2`F)@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI
M;E]D<FEV97(G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1R:79E<G-;)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==72T^:&%S
M0V%P86)I;&ET>2@D8V%P86)I;&ET>2D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W1R86YS<&%R96YT
M)SH*("`@("`@("`@("`@:68@*"@D;&]G:6Y?9')I=F5R(#T@075T:#HZ7V=E
M=$1R:79E<D)Y4&%R86TH)VQO9VEN<V-R965N7W-W:71C:"<L("1T:&ES+3Y?
M<&%R86US*2D@)B8*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]A9$1R:79E
M<B@D;&]G:6Y?9')I=F5R*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9')I=F5R<ULD;&]G:6Y?9')I=F5R72T^:&%S0V%P86)I;&ET>2@G
M=')A;G-P87)E;G0G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!&:6YD
M(&]U="!I9B!T:&4@8VQI96YT(&UA=&-H97,@86X@86QL;W=E9"!)4`H@("`@
M("H@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!T:&4@8VQI96YT(&ES(&%L;&]W960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1R86YS<&%R96YT*"D*("`@('L*("`@("`@("!I9B`H*"1L
M;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G:6YS
M8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@("`@
M("`D=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD;&]G:6Y?9')I=F5R72T^
M=')A;G-P87)E;G0H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@55))(&]F('1H
M92!L;V=I;B!S8W)E96X@9F]R('1H:7,@875T:&5N=&EC871I;VX@;V)J96-T
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T:6]N('1O('5S92X*
M("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@5&AE(%523"!T;R!R961I<F5C
M="!T;R!A9G1E<B!L;V=I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&QO9VEN('-C<F5E;B!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971,;V=I;E-C<F5E;B@D87!P(#T@)VAO<F1E)RP@)'5R;"`]("<G*0H@
M("`@>PH@("`@("`@(&EF("@H)&QO9VEN7V1R:79E<B`]($%U=&@Z.E]G971$
M<FEV97)">5!A<F%M*"=L;V=I;G-C<F5E;E]S=VET8V@G+"`D=&AI<RT^7W!A
M<F%M<RDI("8F"B`@("`@("`@("`@("1T:&ES+3Y?;&]A9$1R:79E<B@D;&]G
M:6Y?9')I=F5R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV
M97)S6R1L;V=I;E]D<FEV97)=+3Y?9V5T3&]G:6Y38W)E96XH)&%P<"P@)'5R
M;"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('!A<F5N
M=#HZ7V=E=$QO9VEN4V-R965N*"1A<'`L("1U<FPI.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A=71H96YT:6-A=&EO
M;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R260@("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@
M87)R87D@("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L
M<RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A
M9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I
M=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG
M861M:6Y?9')I=F5R)UU=+3YA9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D)RD["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N
M(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L
M9$E$("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F5W240@("`@("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`<&%R86T@
M87)R87D@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS
M*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V%D
M;6EN7V1R:79E<B==*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV
M97(H)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D<FEV97)S6R1T:&ES+3Y?<&%R86US6R=A
M9&UI;E]D<FEV97(G75TM/G5P9&%T955S97(H)&]L9$E$+"`D;F5W240L("1C
M<F5D96YT:6%L<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D)RD["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@<V5T(&]F(&%U=&AE
M;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T;R!D96QE=&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==*2`F)@H@("`@("`@
M("`@("`D=&AI<RT^7VQO861$<FEV97(H)'1H:7,M/E]P87)A;7-;)V%D;6EN
M7V1R:79E<B==*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV
M97)S6R1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G75TM/G)E;6]V955S
M97(H)'5S97))9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D)RD["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE
M('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R
M87D@;V8@=7-E<DED<RP@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E
M<B==*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV97(H)'1H:7,M
M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D<FEV97)S6R1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV
M97(G75TM/FQI<W15<V5R<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U<'!O<G1E9"<I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A('5S
M97))9"!E>&ES=',@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@(%5S97(@240@=&\@8VAE8VL*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!U<V5R
M260@86QR96%D>2!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T
M<R@D=7-E<DED*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P
M87)A;7-;)V%D;6EN7V1R:79E<B==*2`F)@H@("`@("`@("`@("`D=&AI<RT^
M7VQO861$<FEV97(H)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV97)S6R1T:&ES+3Y?
M<&%R86US6R=A9&UI;E]D<FEV97(G75TM/F5X:7-T<R@D=7-E<DED*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G56YS=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!,;V%D<R!O;F4@;V8@=&AE(&1R:79E<G,@:6X@;W5R(&-O;F9I
M9W5R871I;VX@87)R87DL(&EF(&ET(&ES;B=T(&%L<F5A9'D*("`@("`J(&QO
M861E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%1H92!N86UE(&]F('1H92!D
M<FEV97(@=&\@;&]A9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M5')U92!I9B!D<FEV97(@<W5C8V5S<V9U;&QY(&EN:71I86QI>F5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?;&]A9$1R:79E<B@D9')I=F5R*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V1R:79E<G-;)&1R:79E<ETI*2![
M"B`@("`@("`@("`@("\O(%1H:7,@:7,@82!B:70@<W!E8VEA;&EZ960@9F]R
M($AO<F1E.CIG971$<FEV97)#;VYF:6<H*2P*("`@("`@("`@("`@+R\@<V\@
M;&]C86QI>F4@:70@:&5R93H*("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=D<FEV97)S
M)UU;)&1R:79E<EU;)W!A<F%M<R==*2D@>PH@("`@("`@("`@("`@("`@)'!A
M<F%M<R`]("1T:&ES+3Y?<&%R86US6R=D<FEV97)S)UU;)&1R:79E<EU;)W!A
M<F%M<R==.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYF6R1T:&ES
M+3Y?<&%R86US6R=D<FEV97)S)UU;)&1R:79E<EU;)V1R:79E<B==72DI('L*
M("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)&-O
M;F9;)'1H:7,M/E]P87)A;7-;)V1R:79E<G,G75LD9')I=F5R75LG9')I=F5R
M)UU=+"`D<&%R86US*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E:68@*"%E;7!T>2@D8V]N9ELD9')I=F5R72DI('L*("`@("`@("`@
M("`@("`@("1P87)A;7,@/2`D8V]N9ELD9')I=F5R73L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1P87)A;7,@/2!N=6QL.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V1R:79E<G-;)&1R:79E
M<ET@/2`F075T:#HZ<VEN9VQE=&]N*"1T:&ES+3Y?<&%R86US6R=D<FEV97)S
M)UU;)&1R:79E<EU;)V1R:79E<B==+"`D<&%R86US*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V1R:79E<G-;)&1R:79E<ETI
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]A=71O+G!H<```````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,S,W`#$P-3$U-#,Q,#8Q
M`#`R,#8P-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($%U=&A?875T;R!C;&%S<R!T<F%N<W!A
M<F5N=&QY(&QO9W,@=7-E<G,@:6X@=&\@2&]R9&4@=7-I;F<@3TY%"B`J('5S
M97)N86UE+"!E:71H97(@9&5F:6YE9"!I;B!T:&4@8V]N9FEG(&]R(&1E9F%U
M;'1I;F<@=&\*("H@)VAO<F1E7W5S97(G+B!4:&ES(&ES(&]N;'D@9F]R('5S
M92!I;B!T97-T:6YG(&]R(&)E:&EN9"!A(&9I<F5W86QL.PH@*B!I="!S:&]U
M;&0@3D]4(&)E('5S960@;VX@82!P=6)L:6,L('!R;V1U8W1I;VX@;6%C:&EN
M92X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R
M;F%M92<@("`@(%1H92!U<V5R;F%M92!T;R!A=71H96YT:6-A=&4@979E<GEO
M;F4@87,N"B`J("`@("`@("`@("`@("`@("`@1$5&055,5#H@)VAO<F1E7W5S
M97(G"B`J("`@)W!A<W-W;W)D)R`@("`@5&AE('!A<W-W;W)D('1O(')E8V]R
M9"!I;B!T:&4@=7-E<B=S(&-R961E;G1I86QS+@H@*B`@("`@("`@("`@("`@
M("`@($1%1D%53%0Z(&YO;F4*("H@("`G<F5Q=65S='5S97(G("!)9B!T<G5E
M+"!A;&QO=R!U<V5R;F%M92!T;R!B92!P87-S960@8GD@1T54+"!03U-4(&]R
M"B`J("`@("`@("`@("`@("`@("`@8V]O:VEE+CPO<')E/@H@*@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O875T;RYP:'`L=B`Q+C$R+C0N
M."`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`
M<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7V%U=&\@97AT96YD
M<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI
M=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@
M("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N
M)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G
M("`@/3X@=')U92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M($%U=&]M871I8R!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?875T;R@D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M
M<R@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!P87)A;65T
M97)S(&9O<B!T:&4@075T:%]A=71O(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@4&%R86UE=&5R<RX@3F]N92!C=7)R96YT;'D@<F5Q=6ER960["B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)RP@)W!A<W-W
M;W)D)RP@86YD("=R97%U97-T=7-E<B<@87)E(&]P=&EO;F%L+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@
M("`@:68@*"%I<W-E="@D<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@
M("`@("`D<&%R86US6R=U<V5R;F%M92==(#T@)VAO<F1E7W5S97(G.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6,@875T:&5N=&EC871I;VXZ(%-E
M="!T:&4@=7-E<B!A;&QO=V5D($E0(&)L;V-K+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A
M;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@
M("!["B`@("`@("`@)'5S97)N86UE(#T@*"%E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG<F5Q=65S='5S97(G72D@)B8@:7-S970H)%]215%515-46R=U<V5R;F%M
M92==*2D@/PH@("`@("`@("`@("`D7U)%455%4U1;)W5S97)N86UE)UT@.@H@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G73L*("`@("`@
M("`D=&AI<RT^<V5T075T:"@D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W1R86YS<&%R96YT)R`]/B`Q+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@:7-S970H)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UTI(#\@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D
M)UT@.B!N=6QL*2D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]!=71H+VAT='`N<&AP````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3(Q,#<`,3`U,34T,S$P-C$`,#(P-C`V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@075T:%]H='1P(&-L87-S('1R86YS<&%R96YT;'D@;&]G<R!U<V5R
M<R!I;B!T;R!(;W)D92!U<VEN9PH@*B!A;')E861Y('!R97-E;G0@2%144"!A
M=71H96YT:6-A=&EO;B!H96%D97)S+@H@*@H@*B!4:&4@)V5N8W)Y<'1I;VXG
M('!A<F%M971E<B!S<&5C:69I97,@=VAA="!K:6YD(&]F('!A<W-W;W)D<R!A
M<F4@:6X*("H@=&AE("YH='!A<W-W9"!F:6QE+B!4:&4@<W5P<&]R=&5D(&]P
M=&EO;G,@87)E("=C<GEP="UD97,G("AS=&%N9&%R9`H@*B!C<GEP=&5D(&AT
M<&%S<W=D(&5N=')I97,I(&%N9"`G87!R;60U)RX@5&AI<R!I;F9O<FUA=&EO
M;B!I<R!U<V5D(&EF"B`J('EO=2!W86YT('1O(&1I<F5C=&QY(&%U=&AE;G1I
M8V%T92!U<V5R<R!W:71H('1H:7,@9')I=F5R+"!I;G-T96%D"B`J(&]F(')E
M;'EI;F<@;VX@=')A;G-P87)E;G0@875T:"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP+'8@,2XR,2XQ,"XY(#(P,#8O,#$O
M,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:'1T<"!E>'1E;F1S($%U=&@@>PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T
M:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T
M:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET
M:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W
M;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!T<G5E
M*3L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F('5S97)N86UE<R!A;F0@:&%S
M:&5D('!A<W-W;W)D<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W5S97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=',@82!N97<@2%144"!A=71H96YT:6-A=&EO;B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U
M=&A?:'1T<"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7W!A<F%M<R`]("1P87)A;7,["@H@("`@("`@("\O($1E9F%U;'0@=&\@
M1$53('!A<W-W;W)D<RX*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A
M;7-;)V5N8W)Y<'1I;VXG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)V5N8W)Y<'1I;VXG72`]("=C<GEP="UD97,G.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG:'1P87-S=V1?9FEL
M92==*2D@>PH@("`@("`@("`@("`D=7-E<G,@/2!`9FEL92@D=&AI<RT^7W!A
M<F%M<ULG:'1P87-S=V1?9FEL92==*3L*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1U<V5R<RDI('L*("`@("`@("`@("`@("`@("\O($5N86)L92!T:&4@
M;&ES="!U<V5R<R!C87!A8FEL:71Y+@H@("`@("`@("`@("`@("`@)'1H:7,M
M/F-A<&%B:6QI=&EE<ULG;&ES="==(#T@=')U93L*"B`@("`@("`@("`@("`@
M("`O+R!0=70@=7-E<G,@:6YT;R!A;'!H86)E=&EC86P@;W)D97(N"B`@("`@
M("`@("`@("`@("!S;W)T*"1U<V5R<RD["@H@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'5S97)S(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`@("`@
M;&ES="@D=7-E<BP@)'!A<W,I(#T@97AP;&]D92@G.B<L("1L:6YE+"`R*3L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97)S6W1R:6TH)'5S97(I
M72`]('1R:6TH)'!A<W,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@
M:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+B!/;FQY
M('-U<'!O<G1S"B`@("`@*B!H='!A<W-W9"!F:6QE<R!W:71H($1%4R!P87-S
M=V]R9',@<FEG:'0@;F]W+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@("!4
M:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E
M9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS+B!&;W(@
M24U!4"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&ES
M(&UU<W0@8V]N=&%I;B!A('!A<W-W;W)D(&5N=')Y+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I
M86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I
M8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=7-E<G-;)'5S
M97))9%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%5
M5$A?4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)&AA<V@@/2`D=&AI<RT^9V5T0W)Y<'1E
M9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P@)'1H:7,M/E]U
M<V5R<ULD=7-E<DED72P@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P@
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI.PH@
M("`@("`@(&EF("@D:&%S:"`]/2`D=&AI<RT^7W5S97)S6R1U<V5R261=*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!
M1$Q/1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@55))(&]F('1H92!L
M;V=I;B!S8W)E96X@9F]R('1H:7,@875T:&5N=&EC871I;VX@;V)J96-T+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T:6]N('1O('5S92X*("`@
M("`J($!P87)A;2!S=')I;F<@)'5R;"`@5&AE(%523"!T;R!R961I<F5C="!T
M;R!A9G1E<B!L;V=I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&QO9VEN('-C<F5E;B!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971,;V=I;E-C<F5E;B@D87!P(#T@)VAO<F1E)RP@)'5R;"`]("<G*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)VQO9VEN4V-R
M965N)UTI*2!["B`@("`@("`@("`@(&EF("@D=7)L*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@571I;#HZ861D4&%R86UE=&5R*"1T:&ES+3Y?<&%R86US
M6R=L;V=I;E-C<F5E;B==+"`G=7)L)RP@)'5R;"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7-;
M)VQO9VEN4V-R965N)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CI?9V5T3&]G:6Y38W)E96XH
M)&%P<"P@)'5R;"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>5]K97ES
M*"1T:&ES+3Y?=7-E<G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@075T;VUA
M=&EC(&%U=&AE;G1I8V%T:6]N.B!&:6YD(&]U="!I9B!T:&4@8VQI96YT(&AA
M<R!(5%10"B`@("`@*B!A=71H96YT:6-A=&EO;B!I;F9O('!R97-E;G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T
M:&4@8VQI96YT(&ES(&%L;&]W960N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R
M86YS<&%R96YT*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1?4T525D52
M6R=02%!?05542%]54T52)UTI("8F"B`@("`@("`@("`@("%E;7!T>2@D7U-%
M4E9%4ELG4$A07T%55$A?4%<G72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$%U=&@H571I;#HZ9&ES<&5L36%G:6-1=6]T97,H)%]315)615);)U!(4%]!
M551(7U5315(G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=P87-S=V]R9"<@/3X@571I;#HZ9&ES<&5L36%G:6-1=6]T97,H)%]315)6
M15);)U!(4%]!551(7U!7)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=')A;G-P87)E;G0G(#T^(#$I*3L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=$%U=&A%
M<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?*")(5%10($%U=&AE;G1I8V%T
M:6]N(&YO="!F;W5N9"XB*2D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+W-M8BYP:'``
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<Q,C8`,3`U
M,34T,S$P-C$`,#(P-#$U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]S;6(@8VQA<W,@
M<')O=FED97,@86X@4TU"(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@
M*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J(%1H:7,@;6]D=6QE(')E
M<75I<F5S('1H92!S;6)A=71H(&5X=&5N<VEO;B!F;W(@4$A0.@H@*B`@(&AT
M='`Z+R]W=W<N=&5K<F%T+F-O;2]S;6)A=71H+PH@*@H@*B!!="!T:&4@=&EM
M92!O9B!T:&ES('=R:71I;F<L('1H92!E>'1E;G-I;VXL(&%N9"!T:'5S('1H
M:7,@;6]D=6QE+"!O;FQY"B`J('-U<'!O<G1E9"!A=71H96YT:6-A=&EO;B!A
M9V%I;G-T(&$@9&]M86EN+"!A;F0@<&1C(&%N9"!B9&,@;75S="!B92!N;VXM
M;G5L;`H@*B!A;F0@;F]T(&5Q=6%L('1O(&5A8V@@;W1H97(N($EN(&]T:&5R
M('=O<F1S+"!T;R!U<V4@=&AI<R!M;V1U;&4@>6]U(&UU<W0*("H@:&%V92!A
M(&1O;6%I;B!W:71H(&%T(&QE87-T(&]N92!01$,@86YD(&]N92!"1$,N"B`J
M"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S='-P96,G
M("!)4"P@1$Y3($YA;64L(&]R($YE=$)I;W,@3F%M92!O9B!T:&4@4TU"('-E
M<G9E<B!T;PH@*B`@("`@("`@("`@("`@(&%U=&AE;G1I8V%T92!W:71H+@H@
M*B`@("=D;VUA:6XG("`@(%1H92!D;VUA:6X@;F%M92!T;R!A=71H96YT:6-A
M=&4@=VET:"X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E
M/@H@*B`@("=G<F]U<"<@("`@($=R;W5P(&YA;64@=&AA="!T:&4@=7-E<B!M
M=7-T(&)E(&$@;65M8F5R(&]F+B!7:6QL(&)E"B`J("`@("`@("`@("`@("`@
M:6=N;W)E9"!I9B!T:&4@=F%L=64@<&%S<V5D(&ES(&$@>F5R;R!L96YG=&@@
M<W1R:6YG+CPO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<"QV(#$N,C`N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C`W
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I
M<V4@/&IO;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36%R
M8W5S($DN(%)Y86X@/&UA<F-U<T!R:6)O9FQA=FEN+FYE=#X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($UA<F-U<R!)+B!2>6%N(#QM87)C=7-`<FEB;V9L879I
M;BYN970^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]!=71H"B`J+PIC;&%S<R!!=71H7W-M8B!E>'1E;F1S($%U=&@@>PH*("`@
M("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T
M('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N
M<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S
M(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D
M)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%--0B!A=71H96YT
M:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]S;6(H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H)W-M8F%U=&@G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!%;G-U<F4@=V4G=F4@8F5E;B!P<F]V:61E9"!W:71H(&%L;"!O
M9B!T:&4@;F5C97-S87)Y('!A<F%M971E<G,N("HO"B`@("`@("`@2&]R9&4Z
M.F%S<V5R=$1R:79E<D-O;F9I9R@D<&%R86US+"`G875T:"<L"B`@("`@("`@
M("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=D;VUA:6XG*2P*("`@("`@("`@("`@
M)V%U=&AE;G1I8V%T:6]N(%-A;6)A)RD["@H@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T
M(&EF('1H92!G:79E;B!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@
M8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!!;B!A
M<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H
M96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@
M("`@("`@($AO<F1E.CIF871A;"A?*").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@075T:&5N=&EC871E+B`J+PH@("`@
M("`@("1R=F%L(#T@=F%L:61A=&4H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M9&]M86EN)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("!E;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG9W)O=7`G72D@/R`G)R`Z("1T:&ES+3Y?<&%R86US6R=G
M<F]U<"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'5S97))9"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G
M72D["@H@("`@("`@(&EF("@D<G9A;"`]/3T@,"D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H
M)')V86P@/3T](#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T
M:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(D9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%3
M3TY?34534T%'12P@97)R,G-T<B@I*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]!=71H+VQO9VEN+G!H<```````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#4V,C<`,3`U,34T,S$P-C$`,#(P-S4P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@075T:%]L;V=I;CHZ(&-L87-S('!R;W9I9&5S(&$@<WES=&5M(&QO9VEN
M(&EM<&QE;65N=&%T:6]N(&]F"B`J('1H92!(;W)D92!A=71H96YT:6-A=&EO
M;B!S>7-T96TN"B`J(%1H:7,@075T:"!D<FEV97(@:7,@=7-E9G5L(&EF('EO
M=2!H879E(&$@<VAA9&]W('!A<W-W;W)D('-Y<W1E;0H@*B!W:&5R92!T:&4@
M075T:%]P87-S=V0@9')I=F5R(&1O97-N)W0@=V]R:RX*("H*("H@3W!T:6]N
M86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=L;V-A=&EO;B<@($QO8V%T:6]N
M(&]F('1H92!S=2!B:6YA<GDN"B`J("`@("`@("`@("`@("`@1$5&055,5#H@
M+V)I;B]S=3PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&]G:6XN<&AP+'8@,2XS+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HP
M-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S
M($%U=&A?;&]G:6X@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N
M(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A
M;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@
M86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G
M("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G
M("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@
M("H@<W4@8FEN87)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VQO8V%T:6]N(#T@)R]B:6XO<W4G.PH*("`@("\J*@H@
M("`@("H@3&ES="!O9B!U<V5R<R!T:&%T('-H;W5L9"!B92!E>&-L=61E9"!F
M<F]M(&)E:6YG(&QI<W1E9"]H86YD;&5D"B`@("`@*B!I;B!A;GD@=V%Y(&)Y
M('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?97AC;'5D92`](&%R<F%Y*"=R;V]T)RP@)V1A96UO;B<L
M("=B:6XG+"`G<WES)RP@)W-Y;F,G+"`G9V%M97,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("=M86XG+"`G;'`G+"`G;6%I;"<L("=N97=S)RP@)W5U
M8W`G+"`G<')O>'DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=P;W-T
M9W)E<R<L("=W=W<M9&%T82<L("=B86-K=7`G+"`G;W!E<F%T;W(G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("=L:7-T)RP@)VER8R<L("=G;F%T<R<L
M("=N;V)O9'DG+"`G:61E;G1D)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<W-H9"<L("=G9&TG+"`G<&]S=&9I>"<L("=M>7-Q;"<L("=C>7)U<R<L
M("=F='`G*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@3&]G
M:6X@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?;&]G:6XH
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A
M;7,@/2`D<&%R86US.PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG;&]C
M871I;VXG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]L;V-A=&EO;B`]("1P
M87)A;7-;)VQO8V%T:6]N)UT["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@
M87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R
M260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS
M("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT
M:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT
M:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"A?*").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M3&]G:6X@875T:&5N=&EC871I;VXN(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`D<')O8R`]('!O<&5N*"1T:&ES+3Y?;&]C
M871I;VX@+B`G("UC("]B:6XO=')U92`G("X@)'5S97))9"P@)W<G*3L*("`@
M("`@("!I9B`H(6ES7W)E<V]U<F-E*"1P<F]C*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&9W<FET92@D<')O8RP@
M)&-R961E;G1I86QS6R=P87-S=V]R9"==*3L*"B`@("`@("`@<F5T=7)N('!C
M;&]S92@D<')O8RD@/3T](#`["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8W5S=&]M
M<W%L+G!H<```````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,S<V,``Q
M,#4Q-30S,3`V,0`P,C$V-S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?
M1DE,15]?*2`N("<O<W%L+G!H<"<["@HO*BH*("H@5&AE($%U=&A?8W5S=&]M
M<W%L(&-L87-S('!R;W9I9&5S(&$@<W%L(&EM<&QE;65N=&%T:6]N(&]F('1H
M92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96T@=VET:"!T:&4@<&]S
M<VEB:6QI='D@=&\@<V5T(&-U<W1O;2UM861E('%U97)I97,N"B`J"B`J(%)E
M<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G<&AP='EP92<@(%1H92!D
M871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P
M<F4^"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z("A#=7-T;VT@<75E<GDI
M/'!R93X*("H@4V]M92!S<&5C:6%L('1O:V5N<R!C86X@8F4@=7-E9"!I;B!T
M:&4@<W%L('%U97)Y+B!4:&5Y(&%R92!R97!L86-E9`H@*B!A="!T:&4@<75E
M<GD@<W1A9V4Z"B`J"B`J("`@+2`G7$PG('=I;&P@8F4@<F5P;&%C960@8GD@
M=&AE('5S97(G<R!L;V=I;@H@*B`@("T@)UQ0)R!W:6QL(&)E(')E<&QA8V5D
M(&)Y('1H92!U<V5R)W,@<&%S<W=O<F0N"B`J("`@+2`G7$\G('=I;&P@8F4@
M<F5P;&%C960@8GD@=&AE(&]L9"!U<V5R)W,@;&]G:6X@*')E<75I<F5D(&9O
M<B!U<&1A=&4I"B`J"B`J("`@16<Z(")314Q%0U0@*B!&4D]-('5S97)S(%=(
M15)%('5I9"`](%Q,"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.
M1"!P87-S=V0@/2!<4`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!!
M3D0@8FEL;&EN9R`]("=P86ED)PH@*@H@*B`@("=Q=65R>5]A=71H)R`@("!!
M=71H96YT:6-A=&4@=&AE('5S97(N("`@("`@("=<3"<@)B`G7$XG"B`J("`@
M)W%U97)Y7V%D9"<@("`@($%D9"!U<V5R+B`@("`@("`@("`@("`@("`@("`@
M)UQ,)R`F("=<3B<*("H@("`G<75E<GE?=7!D871E)R`@57!D871E('5S97(N
M("`@("`@("`@("`@("`@("`G7$\G+"`G7$PG("8@)UQ.)PH@*B`@("=Q=65R
M>5]R97-E='!A<W-W;W)D)R`@4F5S970@<&%S<W=O<F0N("`@("`@("=<3"<L
M("8@)UQ0)PH@*B`@("=Q=65R>5]R96UO=F4G("!296UO=F4@=7-E<BX@("`@
M("`@("`@("`@("`@("=<3"<*("H@("`G<75E<GE?;&ES="<@("`@3&ES="!U
M<V5R+B`@("`@("`@("`@("`@("`@("`G7$PG/"]P<F4^"B`J"B`J($]P=&EO
M;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G96YC<GEP=&EO;B<@("`@("`@
M5&AE(&5N8W)Y<'1I;VX@=&\@=7-E('1O('-T;W)E('1H92!P87-S=V]R9"!I
M;B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@=&%B;&4@*&4N9RX@<&QA
M:6XL(&-R>7!T+"!M9#4M:&5X+"!M9#4M8F%S938T+"!S;60U+`H@*B`@("`@
M("`@("`@("`@("`@("`@("!S:&$L('-S:&$I+@H@*B`@("`@("`@("`@("`@
M("`@("`@("!$149!54Q4.B`G;60U+6AE>"<*("H@("`G<VAO=U]E;F-R>7!T
M:6]N)R`@5VAE=&AE<B!O<B!N;W0@=&\@<')E<&5N9"!T:&4@96YC<GEP=&EO
M;B!I;B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@<&%S<W=O<F0@9FEE
M;&0N"B`J("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=F86QS92<\
M+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE
M;G1A=&EO;G,Z/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@
M;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O=&]C;VPG("!4:&4@
M8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN
M"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@
M*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O
M;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S=V]R9"<@(%1H92!P
M87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`G;W!T
M:6]N<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T
M86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@("`@("`@5&AE
M(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X\+W!R
M93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+V-U<W1O
M;7-Q;"YP:'`L=B`Q+C$V+C$P+C@@,C`P-2\Q,2\S,"`P,#HP,SHS.2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(@4F]N;FEE($=A<F-I82`\<F]N
M;FEE0&UK,BYN970^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!2;VYN
M:64@1V%R8VEA(#QR;VYN:65`;6LR+FYE=#X*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO96P@
M5F%N9&%L(#QJ=F%N9&%L0&EN9F]T96-K+G%C+F-A/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T
M:%]C=7-T;VUS<6P@97AT96YD<R!!=71H7W-Q;"!["@H@("`@+RHJ"B`@("`@
M*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E
M<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O
M<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G
M861D)R`@("`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!T<G5E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G
M("`@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1S(&$@;F5W(%-13"!A=71H96YT:6-A=&EO;B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@075T:%]C=7-T;VUS<6PH)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH*("`@("`@
M("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1P87)A;7,L("=A=71H)RP*
M("`@("`@("`@("`@87)R87DH)W%U97)Y7V%U=&@G*2P*("`@("`@("`@("`@
M)V%U=&AE;G1I8V%T:6]N(&-U<W1O;2!344PG*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS
M(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E
M<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L
M<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A
M<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H
M)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("\J(%]C;VYN
M96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU
M<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J
M($)U:6QD(&$@8W5S=&]M('%U97)Y+"!B87-E9"!O;B!T:&4@8V]N9FEG(&9I
M;&4N("HO"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y
M7V%U=&@G73L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7$PG+"`D
M=&AI<RT^7V1B+3YQ=6]T92@D=7-E<DED*2P@)'%U97)Y*3L*("`@("`@("`D
M<75E<GD@/2!S=')?<F5P;&%C92@G7%`G+"`D=&AI<RT^7V1B+3YQ=6]T92@D
M=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O
M<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI+"`D
M<75E<GDI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M)'%U97)Y*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H
M1$)?1T5434]$15]!4U-/0RD["B`@("`@("`@("`@("\J($EF('=E(&AA=F4@
M870@;&5A<W0@;VYE(')E='5R;F5D(')O=RP@=&AE;B!T:&4@=7-E<B!I<PH@
M("`@("`@("`@("`@*B!V86QI9"X@*B\*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1R;W<I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT+3YF<F5E*"D[
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0M/F9R964H*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!
M1$Q/1TE.*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?
M<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T9!24Q%1"D["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S
M97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS
M("!4:&4@8W)E9&5N=&EA;',@=&\@861D+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H
M)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!A(&-U<W1O;2!Q=65R>2P@
M8F%S960@;VX@=&AE(&-O;F9I9R!F:6QE+B`J+PH@("`@("`@("1Q=65R>2`]
M("1T:&ES+3Y?<&%R86US6R=Q=65R>5]A9&0G73L*("`@("`@("`D<75E<GD@
M/2!S=')?<F5P;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D=7-E<DED
M*2P@)'%U97)Y*3L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7%`G
M+"`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D
M*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S
M:&]W7V5N8W)Y<'1I;VXG72DI+"`D<75E<GDI.PH*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@;V8@875T:&5N=&EC
M871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;VQD240@("`@("`@5&AE(&]L9"!U<V5R260N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N97=)1"`@("`@("!4:&4@;F5W('5S97))9"X*("`@("`J($!P
M87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!N97<@8W)E9&5N=&EA;',*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N
M=&EA;',I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W
M:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@82!C=7-T;VT@
M<75E<GDL(&)A<V5D(&]N('1H92!C;VYF:6<@9FEL92X@*B\*("`@("`@("`D
M<75E<GD@/2`D=&AI<RT^7W!A<F%M<ULG<75E<GE?=7!D871E)UT["B`@("`@
M("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ/)RP@)'1H:7,M/E]D8BT^<75O
M=&4H)&]L9$E$*2P@)'%U97)Y*3L*("`@("`@("`D<75E<GD@/2!S=')?<F5P
M;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D;F5W240I+"`D<75E<GDI
M.PH@("`@("`@("1Q=65R>2`]('-T<E]R97!L86-E*"=<4"<L("1T:&ES+3Y?
M9&(M/G%U;W1E*"1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)&-R961E;G1I
M86QS6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP
M=&EO;B==*2DL("1Q=65R>2D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E<V5T<R!A('5S97(G<R!P87-S=V]R9"X@57-E9"!F;W(@
M97AA;7!L92!W:&5N('1H92!U<V5R(&1O97,@;F]T"B`@("`@*B!R96UE;6)E
M<B!T:&4@97AI<W1I;F<@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<E]I9"`@5&AE('5S97(@:60@9F]R('=H:6-H('1O(')E
M<V5T('1H92!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@;F5W('!A<W-W;W)D(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;@H@("`@("H@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5S971087-S=V]R9"@D=7-E<E]I9"D*("`@
M('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z
M.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`O*B!'970@82!N97<@<F%N9&]M('!A<W-W;W)D
M+B`J+PH@("`@("`@("1P87-S=V]R9"`]($%U=&@Z.F=E;E)A;F1O;5!A<W-W
M;W)D*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@
M("`@("`@)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y7W)E<V5T<&%S
M<W=O<F0G73L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7$PG+"`D
M=&AI<RT^7V1B+3YQ=6]T92@D=7-E<E]I9"DL("1Q=65R>2D["B`@("`@("`@
M)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ0)RP@)'1H:7,M/E]D8BT^<75O=&4H
M)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D<&%S<W=O<F0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*2P@)'%U97)Y*3L*"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!S
M970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E<DED('1O(&1E;&5T
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("`@("`@(%-U8V-E
M<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E57-E
M<B@D=7-E<DED*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D
M:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD(&$@8W5S
M=&]M('%U97)Y+"!B87-E9"!O;B!T:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@
M("`@)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y7W)E;6]V92==.PH@
M("`@("`@("1Q=65R>2`]('-T<E]R97!L86-E*"=<3"<L("1T:&ES+3Y?9&(M
M/G%U;W1E*"1U<V5R260I+"`D<75E<GDI.PH*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO
M=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI
M<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&9A;'-E(&]N
M(&9A:6QU<F4O=6YS=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W15<V5R<R@I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I
M92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@
M("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@82!C=7-T
M;VT@<75E<GDL(&)A<V5D(&]N('1H92!C;VYF:6<@9FEL92X@*B\*("`@("`@
M("`D<75E<GD@/2`D=&AI<RT^7W!A<F%M<ULG<75E<GE?;&ES="==.PH*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@;G5L
M;"P@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@86YD
M(&)U:6QD(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D=7-E<G,@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@87,@)&%R*2!["B`@("`@
M("`@("`@("1U<V5R<UM=(#T@)&%R6S!=.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1U<V5R<SL*("`@('T*"GT*`````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:V]L86(N<&AP
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S$P,P`Q,#4Q
M-30S,3`V,0`P,C`W,3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O075T:"]I
M;6%P+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O2&ES=&]R>2YP:'`G.PH*
M+RHJ"B`J($MO;&%B(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D92!A=71H
M96YT:6-A=&EO;B!S>7-T96TN($1E<FEV97,@9G)O;2!T:&4*("H@075T:%]I
M;6%P($E-05`@875T:&5N=&EC871I;VX@;V)J96-T+"!A;F0@<VEM<&QY('!R
M;W9I9&5S('!A<F%M971E<G,@=&\@:70*("H@8F%S960@;VX@=&AE(&=L;V)A
M;"!+;VQA8B!C;VYF:6=U<F%T:6]N+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:V]L86(N<&AP+'8@,2XQ+C$P+C@@,C`P-B\P,R\P,R`R
M,SHP,#HR."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V
M(%-T=6%R="!":6YG92`\<RYB:6YG94!C;V1E9G5S:6]N+F-O+GIA/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4W1U87)T($)I;F=E(#QS+F)I;F=E
M0&-O9&5F=7-I;VXN8V\N>F$^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`
M<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VMO;&%B(&5X=&5N
M9',@075T:%]I;6%P('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N
M97<@2V]L86(@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN
M96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?
M:V]L86(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'!A<F%M
M<ULG:&]S='-P96,G72`]("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VEM
M87`G75LG<V5R=F5R)UT["B`@("`@("`@)'!A<F%M<ULG<&]R="==(#T@)$=,
M3T)!3%-;)V-O;F8G75LG:V]L86(G75LG:6UA<"==6R=P;W)T)UT["B`@("`@
M("`@)'!A<F%M<ULG<')O=&]C;VPG72`]("=I;6%P+VYO=&QS+VYO=F%L:61A
M=&4M8V5R="<["@H@("`@("`@('!A<F5N=#HZ075T:%]I;6%P*"1P87)A;7,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@
M;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S
M97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@
M87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT
M:6%L<RX@1F]R($MO;&%B+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R9"!E;G1R>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H
M92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&QO9VEN7V]K(#T@<&%R
M96YT.CI?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD["@H@
M("`@("`@(&EF("@D8V]N9ELG875T:"==6R=P87)A;7,G75LG;&]G:6Y?8FQO
M8VLG72`A/2`Q*2!["B`@("`@("`@("`@("\O(%)E='5R;B!I9B!F96%T=7)E
M(&ES(&1I<V%B;&5D+@H@("`@("`@("`@("!R971U<FX@)&QO9VEN7V]K.PH@
M("`@("`@('T*"B`@("`@("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ
M<VEN9VQE=&]N*"D["@H@("`@("`@("1H:7-T;W)Y7VED96YT:69I97(@/2`B
M)'5S97))9$!L;V=I;G,N:V]L86(B.PH@("`@("`@("1H:7-T;W)Y7VQO9R`]
M("1H:7-T;W)Y+3YG971(:7-T;W)Y*"1H:7-T;W)Y7VED96YT:69I97(I.PH@
M("`@("`@("1H:7-T;W)Y7VQI<W0@/2!A<G)A>2@I.PH*("`@("`@("`O+R!%
M>'1R86-T(&AI<W1O<GD@;&ES="!F<F]M(&QO9RX*("`@("`@("!I9B`H)&AI
M<W1O<GE?;&]G("8F("%I<U]A*"1H:7-T;W)Y7VQO9RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`D9&%T82`]("1H:7-T;W)Y7VQO9RT^9V5T1&%T
M82@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1D871A*2D@>PH@("`@("`@
M("`@("`@("`@)&5N=')Y(#T@87)R87E?<VAI9G0H)&1A=&$I.PH@("`@("`@
M("`@("`@("`@)&AI<W1O<GE?;&ES="`]("1E;G1R>5LG:&ES=&]R>5]L:7-T
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-A;&-U
M;&%T92!T:&4@=&EM92!R86YG92X*("`@("`@("`D<W1A<G1?=&EM92`]("AT
M:6UE*"D@+2`D8V]N9ELG875T:"==6R=P87)A;7,G75LG;&]G:6Y?8FQO8VM?
M=&EM92==("H@-C`I.PH*("`@("`@("`D;F5W7VAI<W1O<GE?;&ES="`](&%R
M<F%Y*"D["B`@("`@("`@)&-O=6YT(#T@,#L*"B`@("`@("`@+R\@0V]P>2!A
M;F0@8V]U;G0@86QL(')E;&5V86YT('1I;65S=&%M<',N"B`@("`@("`@9F]R
M96%C:"`H)&AI<W1O<GE?;&ES="!A<R`D96YT<GDI('L*("`@("`@("`@("`@
M)'1I;65S=&%M<"`]("1E;G1R>5L@)W1I;65S=&%M<"<@73L*"B`@("`@("`@
M("`@(&EF("@D=&EM97-T86UP(#X@)'-T87)T7W1I;64I('L*("`@("`@("`@
M("`@("`@("1N97=?:&ES=&]R>5]L:7-T6UT@/2`D96YT<GD["B`@("`@("`@
M("`@("`@("`D8V]U;G0K*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&UA>%]C;W5N="`]("1C;VYF6R=A=71H)UU;)W!A<F%M<R==6R=L
M;V=I;E]B;&]C:U]C;W5N="==.PH*("`@("`@("!I9B`H)&-O=6YT(#X@)&UA
M>%]C;W5N="!\?"`A)&QO9VEN7V]K*2!["B`@("`@("`@("`@("\O($%D9"!E
M;G1R>2!F;W(@8W5R<F5N="!F86EL960@;&]G:6XN"B`@("`@("`@("`@("1E
M;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("1E;G1R>5L@)W1I;65S=&%M
M<"<@72`]('1I;64H*3L*("`@("`@("`@("`@)&YE=U]H:7-T;W)Y7VQI<W1;
M72`]("1E;G1R>3L*"B`@("`@("`@("`@("\O(%=R:71E(&)A8VL@:&ES=&]R
M>2X*("`@("`@("`@("`@)&AI<W1O<GDM/FQO9R@D:&ES=&]R>5]I9&5N=&EF
M:65R+"!A<G)A>2@G86-T:6]N)R`]/B`G861D)RP@)W=H;R<@/3X@)'5S97))
M9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:&ES=&]R>5]L:7-T)R`]/B`D;F5W7VAI<W1O<GE?;&ES
M="DL('1R=64I.PH*("`@("`@("`@("`@:68@*"1C;W5N="`^("1M87A?8V]U
M;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%5
M5$A?4D5!4T].7TU%4U-!1T4L(%\H(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS
M(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(I*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%5
M5$A?4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L
M;V=I;E]O:SL*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T%U=&@O<W%L+G!H<```````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`T,#4T-``Q,#4Q-30S,3`V,0`P,C`T,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!!=71H7W-Q;"!C;&%S<R!P<F]V:61E<R!A(%-13"!I;7!L96UE;G1A=&EO
M;B!O9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M+@H@*@H@
M*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@
M("`@5&AE(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E
M=&,N*2X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@
M*B`@("=E;F-R>7!T:6]N)R`@("`@("`@("`@("!4:&4@96YC<GEP=&EO;B!T
M;R!U<V4@=&\@<W1O<F4@=&AE('!A<W-W;W)D(&EN"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!T86)L92`H92YG+B!P;&%I;BP@8W)Y<'0L
M(&UD-2UH97@L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&UD-2UB
M87-E-C0L('-M9#4L('-H82P@<W-H82P@87!R;60U*2X*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@)VUD-2UH97@G"B`J("`@)W-H
M;W=?96YC<GEP=&EO;B<@("`@("`@(%=H971H97(@;W(@;F]T('1O('!R97!E
M;F0@=&AE(&5N8W)Y<'1I;VX@:6X@=&AE"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('!A<W-W;W)D(&9I96QD+@H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$149!54Q4.B`G9F%L<V4G"B`J("`@)W!A<W-W;W)D7V9I
M96QD)R`@("`@("`@(%1H92!N86UE(&]F('1H92!P87-S=V]R9"!F:65L9"!I
M;B!T:&4@875T:"!T86)L92X*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1$5&055,5#H@)W5S97)?<&%S<R<*("H@("`G=&%B;&4G("`@("`@("`@
M("`@("`@("`@5&AE(&YA;64@;V8@=&AE(%-13"!T86)L92!T;R!U<V4@:6X@
M)V1A=&%B87-E)RX*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$5&
M055,5#H@)VAO<F1E7W5S97)S)PH@*B`@("=U<V5R;F%M95]F:65L9"<@("`@
M("`@("!4:&4@;F%M92!O9B!T:&4@=7-E<FYA;64@9FEE;&0@:6X@=&AE(&%U
M=&@@=&%B;&4N"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%1D%5
M3%0Z("=U<V5R7W5I9"<*("H@("`G<V]F=%]E>'!I<F%T:6]N7V9I96QD)R`@
M5&AE(&YA;64@;V8@=&AE(&9I96QD(&-O;G1A:6YI;F<@82!D871E(&%F=&5R
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('=H:6-H('1H92!S>7-T
M96T@=VEL;"!R97%U97-T('1H92!U<V5R(&-H86YG92!H:7,*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;W(@:&5R('!A<W-W;W)D+@H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B!N;VYE"B`J("`@)VAA
M<F1?97AP:7)A=&EO;E]F:65L9"<@(%1H92!N86UE(&]F('1H92!F:65L9"!C
M;VYT86EN:6YG(&$@9&%T92!A9G1E<@H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!W:&EC:"!T:&4@86-C;W5N="!I<R!N;R!L;VYG97(@=F%L:60@
M86YD('1H92!U<V5R"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I
M;&P@;F]T(&)E(&%B;&4@=&\@;&]G(&EN(&%T(&%L;"X*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@;F]N93PO<')E/@H@*@H@*B!2
M97%U:7)E9"!B>2!S;VUE(&1A=&%B87-E(&EM<&QE;65N=&%T:6]N<SH\<')E
M/@H@*B`@("=H;W-T<W!E8R<@("`@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T
M86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@("`@(%1H92!C;VUM=6YI
M8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G
M9&%T86)A<V4G("`@("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N"B`J("`@
M)W5S97)N86UE)R`@("`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@("`@5&AE
M('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=O
M<'1I;VYS)R`@("`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O('1H
M92!D871A8F%S92X*("H@("`G<&]R="<@("`@("`@("!4:&4@<&]R="!O;B!W
M:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G='1Y)R`@
M("`@("`@("!4:&4@5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+CPO<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T
M:&4@075T:"!S>7-T96T@:7,@:6X*("H@<V-R:7!T<R]S<6PO:&]R9&5?=7-E
M<G,N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<"QV(#$N-CDN,3`N,3D@,C`P-B\P."\Q-"`P,CHT.#HT."!C:'5C:R!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S
M<R!!=71H7W-Q;"!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@06X@
M87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N
M(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A
M;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@
M("`@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=U<&1A=&4G("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@
M("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@2&%N
M9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T:6]N+@H@("`@
M("H*("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?9&(["@H@("`@
M+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!O<B!N;W0@
M=V4G<F4@8V]N;F5C=&5D('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T960@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@4U%,
M(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P
M87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7W-Q;"@D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]
M("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A
M('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J
M($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T
M;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R
M(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L
M<RD*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@
M2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES
M+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y
M+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"`J($923TT@
M)7,@5TA%4D4@)7,@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@
M("1V86QU97,@/2!A<G)A>2@D=7-E<DED*3L*"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7W-Q;#HZ7V%U=&AE;G1I8V%T
M92@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%
M<G)O<BA!551(7U)%05-/3E]&04E,140I.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F]W(#T@)')E<W5L="T^9F5T
M8VA2;W<H1$)?1T5434]$15]!4U-/0RD["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R;W<I*2!["B`@("`@("`@("`@("1R97-U;'0M/F9R964H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!
M551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/E]C;VUP87)E4&%S
M<W=O<F1S*"1R;W=;)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD)UU=
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C<F5D
M96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]S
M971!=71H17)R;W(H05542%]214%33TY?0D%$3$]'24XI.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D;F]W(#T@=&EM
M92@I.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)VAA<F1?
M97AP:7)A=&EO;E]F:65L9"==*2`F)@H@("`@("`@("`@("`A96UP='DH)')O
M=ULD=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7V9I96QD)UU=*2`F
M)@H@("`@("`@("`@("`H)&YO=R`^("1R;W=;)'1H:7,M/E]P87)A;7-;)VAA
M<F1?97AP:7)A=&EO;E]F:65L9"==72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]S971!=71H17)R;W(H05542%]214%33TY?15A025)%1"D["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]P87)A;7-;)W-O9G1?97AP:7)A=&EO;E]F:65L9"==*2`F
M)@H@("`@("`@("`@("`A96UP='DH)')O=ULD=&AI<RT^7W!A<F%M<ULG<V]F
M=%]E>'!I<F%T:6]N7V9I96QD)UU=*2`F)@H@("`@("`@("`@("`H)&YO=R`^
M("1R;W=;)'1H:7,M/E]P87)A;7-;)W-O9G1?97AP:7)A=&EO;E]F:65L9"==
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]A=71H0W)E9&5N=&EA;'-;)V-H
M86YG95)E<75E<W1E9"==(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@<V5T(&]F
M(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@861D+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I
M86QS('1O(&%D9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R260L("1C<F5D
M96YT:6%L<RD*("`@('L*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@
M("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H)7,L("5S*2!604Q515,@
M*#\L(#\I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72D["B`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1U<V5R260L"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)&-R961E;G1I
M86QS6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC
M<GEP=&EO;B==*2D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@
M475E<GD@8GD@075T:%]S<6PZ.F%D9%5S97(H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!A('-E
M="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@("`@("`@5&AE(&]L9"!U<V5R260N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=)1"`@("`@("`@5&AE(&YE=R!U
M<V5R260N"B`@("`@*B!`<&%R86T@87)R87D@("1C<F5D96YT:6%L<R`@5&AE
M(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T955S97(H)&]L9$E$
M+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("`O*B!?8V]N
M;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL
M=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O
M*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1T=7!L92`](&%R
M<F%Y*"D["B`@("`@("`@)'1U<&QE6R1T:&ES+3Y?<&%R86US6R=U<V5R;F%M
M95]F:65L9"==72`]("1N97=)1#L*("`@("`@("`D='5P;&5;)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D7V9I96QD)UU=(#T*("`@("`@("`@("`@)'1H:7,M
M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N
M)UTI.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W-O9G1?
M97AP:7)A=&EO;E]W:6YD;W<G72DI('L*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N7V9I96QD)UTI*2![
M"B`@("`@("`@("`@("`@("`D='5P;&5;)'1H:7,M/E]P87)A;7-;)W-O9G1?
M97AP:7)A=&EO;E]F:65L9"==72`](&YU;&P["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%T92`]('1I;64H*3L*("`@
M("`@("`@("`@)&1A=&5A(#T@;&]C86QT:6UE*"1D871E+"!T<G5E*3L*("`@
M("`@("`@("`@)&1A=&4@/2!M:W1I;64H)&1A=&5A6R=T;5]H;W5R)UTL("1D
M871E85LG=&U?;6EN)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871E85LG=&U?<V5C)UTL("1D871E85LG=&U?;6]N)UT@*R`Q+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&%T96%;)W1M7VUD87DG72`K("1T:&ES
M+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?=VEN9&]W)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D871E85LG=&U?>65A<B==*3L*"B`@("`@
M("`@("`@("1T=7!L95LD=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N
M7V9I96QD)UU=(#T@)&1A=&4["@H@("`@("`@("`@("!G;&]B86P@)&YO=&EF
M:6-A=&EO;CL*("`@("`@("`@("`@:68@*"%E;7!T>2@D;F]T:69I8V%T:6]N
M*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS=')F
M=&EM92A?*").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(BDL("1D
M871E*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=H87)D7V5X<&ER871I
M;VY?=VEN9&]W)UTI*2!["B`@("`@("`@("`@("`@("`D='5P;&5;)'1H:7,M
M/E]P87)A;7-;)VAA<F1?97AP:7)A=&EO;E]F:65L9"==72`](&YU;&P["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&%T96$@/2!L
M;V-A;'1I;64H)&1A=&4L('1R=64I.PH@("`@("`@("`@("`@("`@)&1A=&4@
M/2!M:W1I;64H)&1A=&5A6R=T;5]H;W5R)UTL("1D871E85LG=&U?;6EN)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T96%;)W1M7W-E
M8R==+"`D9&%T96%;)W1M7VUO;B==("L@,2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D871E85LG=&U?;61A>2==("L@)'1H:7,M/E]P87)A
M;7-;)W-O9G1?97AP:7)A=&EO;E]W:6YD;W<G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D871E85LG=&U?>65A<B==*3L*"B`@("`@("`@
M("`@("`@("`D='5P;&5;)'1H:7,M/E]P87)A;7-;)VAA<F1?97AP:7)A=&EO
M;E]F:65L9"==72`]("1D871E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-13"YP:'`G.PH@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@)7,@5TA%4D4@)7,@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?4U%,
M.CIU<&1A=&5686QU97,H)'1H:7,M/E]D8BP@)'1U<&QE*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L
M9"==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)&]L9$E$*3L*"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7W-Q;#IU
M<&1A=&55<V5R*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E<V5T(&$@=7-E<B=S('!A<W-W;W)D+B!5<V5D(&9O<B!E>&%M<&QE('=H
M96X@=&AE('5S97(@9&]E<R!N;W0*("`@("`J(')E;65M8F5R('1H92!E>&ES
M=&EN9R!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R7VED("!4:&4@=7-E<B!I9"!F;W(@=VAI8V@@=&\@<F5S970@=&AE('!A
M<W-W;W)D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!N97<@
M<&%S<W=O<F0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M"B`@("`@*B`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R97-E=%!A<W-W;W)D*"1U<V5R7VED*0H@("`@>PH@("`@("`@
M("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U
M<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@
M("`@("`@("\J($=E="!A(&YE=R!R86YD;VT@<&%S<W=O<F0N("HO"B`@("`@
M("`@)'!A<W-W;W)D(#T@075T:#HZ9V5N4F%N9&]M4&%S<W=O<F0H*3L*"B`@
M("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=54$1!5$4@)7,@4T54("5S(#T@/R!72$5212`E<R`]
M(#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F1?9FEE;&0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@
M("`D=F%L=65S(#T@87)R87DH)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D
M<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y
M<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N
M)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<E]I9"D["@H@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@075T:%]S<6PZ
M.G)E<V5T4&%S<W=O<F0H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<W-W
M;W)D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@<V5T(&]F(&%U
M=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T;R!D96QE=&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@("`@("!3=6-C97-S(&]R(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))
M9"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@
M2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES
M+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y
M+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S
M(%=(15)%("5S(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@("`D
M=F%L=65S(#T@87)R87DH)'5S97))9"D["@H@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@075T:%]S<6PZ.G)E;6]V955S97(H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E
M<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V955S97)$871A*"1U
M<V5R260I.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES="!A;&P@=7-E<G,@
M:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@87)R87D@;V8@=7-E<DED<RP@;W(@9F%L<V4@;VX@9F%I;'5R92]U;G-U
M<'!O<G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@
M('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z
M.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@
M("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R
M;F%M95]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTI.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($%U=&A?<W%L.CIL:7-T57-E<G,H*3H@)R`N("1Q
M=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YG971#;VPH)'%U97)Y*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A('5S97))9"!E>&ES=',@
M:6X@=&AE('-I<W1E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1H92!U<V5R260@86QR96%D>2!E>&ES=',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D=7-E<DED*0H@("`@>PH@("`@
M("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH
M*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%4D4@)7,@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=U<V5R;F%M95]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72D["B`@("`@
M("`@)'9A;'5E<R`](&%R<F%Y*"1U<V5R260I.PH*("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($%U=&A?<W%L.CIE>&ES=',H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YG971/;F4H)'%U97)Y
M+"`D=F%L=65S*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;7!A<F4@86X@
M96YC<GEP=&5D('!A<W-W;W)D('1O(&$@<&QA:6YT97AT('-T<FEN9R!T;R!S
M964@:68*("`@("`J('1H97D@;6%T8V@N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D96YC<GEP
M=&5D("!4:&4@8W)Y<'1E9"!P87-S=V]R9"!T;R!C;VUP87)E(&%G86EN<W0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@(%1H92!P;&%I;G1E
M>'0@<&%S<W=O<F0@=&\@=F5R:69Y+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!I9B!M871C:&5D+"!F86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VUP87)E4&%S<W=O<F1S*"1E;F-R>7!T
M960L("1P;&%I;G1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1E;F-R>7!T
M960@/3T@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D<&QA:6YT97AT+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N8W)Y<'1E9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO
M=U]E;F-R>7!T:6]N)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE(%-13"!S97)V97(N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE
M8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@($AO
M<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=A=71H
M)RP@87)R87DH)W!H<'1Y<&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=A=71H96YT:6-A=&EO;B!344PG*3L*"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*("`@("`@
M("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA
M;64G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE
M)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A<F%M<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=E;F-R>7!T
M:6]N)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T
M:6]N)UT@/2`G;60U+6AE>"<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UT@/2!F
M86QS93L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=T86)L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72`]("=H;W)D95]U<V5R<R<["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UT@
M/2`G=7-E<E]U:60G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==(#T@4W1R:6YG.CIL;W=E
M<B@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?
M9FEE;&0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W
M;W)D7V9I96QD)UT@/2`G=7-E<E]P87-S)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72`]
M(%-T<FEN9SHZ;&]W97(H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD
M)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@4U%,
M('-E<G9E<B!U<VEN9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@*B\*("`@
M("`@("!I;F-L=61E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@)'1H:7,M/E]D
M8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P97)S:7-T96YT)R`]/B`A
M96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI*3L*("`@("`@
M("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@($AO<F1E.CIF871A;"A?*")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N"B`@("`@
M("`@<W=I=&-H("@D=&AI<RT^7V1B+3YP:'!T>7!E*2!["B`@("`@("`@8V%S
M92`G;7-S<6PG.@H@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH
M)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?
M4$]25$%"24Q)5%E?15)23U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]2
M5$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]K<F(U+G!H<```````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`U-S(W`#$P-3$U-#,Q,#8Q`#`R,#4P-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?
M:W)B-2!C;&%S<R!P<F]V:61E<R!A;B!K97)B97)O<R!I;7!L96UE;G1A=&EO
M;B!O9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M+@H@*@H@
M*B!4:&ES(&1R:79E<B!R97%U:7)E<R!T:&4@)VMR8C4G(%!(4"!E>'1E;G-I
M;VX@=&\@8F4@;&]A9&5D+@H@*B!4:&4@;6]D=6QE(&-A;B!B92!D;W=N;&]A
M9&5D(&AE<F4Z"B`J("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O9&]W;FQO860O
M<&AP+W!H<&MR8C4N=&%R+F=Z"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z
M/'!R93X*("H@("!.;VYE+CPO<')E/@H@*@H@*B!);G-T96%D+"!+97)B97)O
M<R!M=7-T(&)E(&-O<G)E8W1L>2!C;VYF:6=U<F5D(&]N('EO=7(@<WES=&5M
M("AE+F<N"B`J("`@+V5T8R]K<F(U+F-O;F8I(&9O<B!T:&ES(&-L87-S('1O
M('=O<FL@8V]R<F5C=&QY+@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`L=B`Q+C(Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR
M.#HP-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E
M(#(N,@H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VMR
M8C4@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F
M(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@
M=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H
M(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P
M9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A
M;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T<R!A(&YE=R!+97)B97)O<R!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@075T:%]K<F(U*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=K<F(U)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@
M;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R
M86T@87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D
M96YT:6%L<RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($9O
M<B!K97)B97)O<RP@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YT<GDN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E
M9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T
M:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@
M("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`](&MR8C5?;&]G
M:6XH)'5S97))9"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==*3L*"B`@("`@
M("`@:68@*"1R97-U;'0@/3T]($M20C5?3TLI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1R
M97-U;'0@/3T]($M20C5?0D%$7U!!4U-73U)$*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?
M*")"860@:V5R8F5R;W,@<&%S<W=O<F0N(BDI.PH@("`@("`@("`@("!](&5L
M<V5I9B`H)')E<W5L="`]/3T@2U)"-5]"041?55-%4BD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'
M12P@7R@B0F%D(&ME<F)E<F]S('5S97)N86UE+B(I*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R
M*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(DME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BXB*2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"GT*````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VUC86PN<&AP````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4V,#,`,3`U,34T,S$P
M-C$`,#(P-30V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]M8V%L(&-L87-S('!R;W9I
M9&5S(&%N($U#04P@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U
M=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@34-!3"!(;VUE(%!A9V4Z(&AT
M='`Z+R]M8V%L+F-H96LN8V]M+PH@*@H@*B!297%U:7)E9"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)V-A;&5N9&%R)R`@5&AE($U#04P@8V%L96YD87(@;F%M
M92X\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H
M+VUC86PN<&AP+'8@,2XR-RXQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L
M87-S($%U=&A?;6-A;"!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@
M06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@
M8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T
M<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D
M9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=7!D871E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES
M="<@("`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=',@82!N97<@34-!3"!A=71H96YT:6-A=&EO;B!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S
M:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@075T:%]M8V%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=M8V%L)RDI
M('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1P87)A
M;7-;)V-A;&5N9&%R)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?
M*").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA
M;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U
M<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I
M86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@1F]R($U#04PL
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&ES(&UU<W0@
M8V]N=&%I;B!A('!A<W-W;W)D(&5N=')Y+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R
M92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D
M=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@)&UC86P@/2!`
M;6-A;%]O<&5N*"1T:&ES+3Y?<&%R86US6R=C86QE;F1A<B==+"`D=7-E<DED
M+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI.PH*("`@("`@("!I9B`H)&UC
M86PI('L*("`@("`@("`@("`@0&UC86Q?8VQO<V4H)&UC86PI.PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!`;6-A;%]C;&]S92@D;6-A;"D["B`@("`@("`@("`@("1T:&ES+3Y?<V5T
M075T:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("`D;&EN97,@/2!`9FEL92@G
M+V5T8R]M<&%S<W=D)RD["B`@("`@("`@:68@*"$D;&EN97,@?'P@(6ES7V%R
M<F%Y*"1L:6YE<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U5N86)L92!T;R!L:7-T('5S97)S+B<I.PH@("`@("`@('T*"B`@
M("`@("`@)'5S97)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D;&EN
M97,@87,@)&QI;F4I('L*("`@("`@("`@("`@)'5S97)S6UT@/2!S=6)S='(H
M)&QI;F4L(#`L('-T<G!O<R@D;&EN92P@)SHG*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'5S97)S.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@O9G1P+G!H<```````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-#(Q-P`Q,#4Q-30S,3`V,0`P,C`T,C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!!=71H7V9T<"!C;&%S<R!P<F]V:61E<R!A;B!&5%`@:6UP;&5M
M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E
M;2X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=H;W-T
M<W!E8R<@(%1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S(&]F('1H92!&5%`@
M<V5R=F5R+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("=L;V-A;&AO<W0G
M"B`J("`@)W!O<G0G("`@("`@5&AE('-E<G9E<B!P;W)T('1O(&-O;FYE8W0@
M=&\N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@,C$\+W!R93X*("H*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`L=B`Q+C(S
M+C$R+C@@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!-87@@2V%L:6MA(#QM87A`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($UA>"!+
M86QI:V$@/&UA>$!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7V9T<"!E>'1E
M;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!&
M5%`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?9G1P*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT
M96YS:6]N17AI<W1S*"=F='`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH7R@B075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M)&1E9F%U;'1?<&%R86US(#T@87)R87DH"B`@("`@("`@("`@("=H;W-T<W!E
M8R<@/3X@)VQO8V%L:&]S="<L"B`@("`@("`@("`@("=P;W)T)R`]/B`R,0H@
M("`@("`@("D["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M97)G
M92@D9&5F875L=%]P87)A;7,L("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@
M87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R
M260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS
M("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@1F]R($944"P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@;75S="!C;VYT
M86EN(&$@<&%S<W=O<F0@96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R
M260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("`D9G1P(#T@0&9T<%]C
M;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+"`D=&AI<RT^7W!A
M<F%M<ULG<&]R="==*3L*"B`@("`@("`@:68@*"1F='`@)B8@0&9T<%]L;V=I
M;B@D9G1P+"`D=7-E<DED+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI*2![
M"B`@("`@("`@("`@($!F='!?<75I="@D9G1P*3L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&9T<%]Q
M=6ET*"1F='`I.PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!
M551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'``````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S$Q,``Q,#4Q-30S,3`V,0`P
M,C`U-3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!!=71H7VEM87`Z.B!C;&%S<R!P<F]V:61E
M<R!A;B!)34%0(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H
M96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z
M/'!R93X*("H@("=H;W-T<W!E8R<@("`@("`@(%1H92!H;W-T;F%M92!O<B!)
M4"!A9&1R97-S(&]F('1H92!S97)V97(N"B`J("`@("`@("`@("`@("`@("`@
M("!$149!54Q4.B`G;&]C86QH;W-T)PH@*B`@)W!O<G0G("`@("`@("`@("`@
M5&AE('-E<G9E<B!P;W)T('1O('=H:6-H('=E('=I;&P@8V]N;F5C="X*("H@
M("`@("`@("`@("`@("`@("`@($E-05`@:7,@9V5N97)A;&QY(#$T,RP@=VAI
M;&4@24U!4"U34TP@:7,@9V5N97)A;&QY(#DY,RX*("H@("`@("`@("`@("`@
M("`@("`@($1%1D%53%0Z(#$T,PH@*B`@)W!R;W1O8V]L)R`@("`@("`@5&AE
M(&-O;FYE8W1I;VX@<')O=&]C;VP@*&4N9RX@)VEM87`G+"`G<&]P,R<L("=N
M;G1P)RDN"B`J("`@("`@("`@("`@("`@("`@("!0<F]T;V-O;"!I<R!O;F4@
M;V8@)VEM87`O;F]T;',G("AO<B!O;FQY("=I;6%P)R!I9B!Y;W4*("H@("`@
M("`@("`@("`@("`@("`@(&AA=F4@82!C+6-L:65N="!V97)S:6]N(#(P,#!C
M(&]R(&]L9&5R*2P@)VEM87`O<W-L)RP*("H@("`@("`@("`@("`@("`@("`@
M(&]R("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G("AF;W(@82!S96QF+7-I
M9VYE9`H@*B`@("`@("`@("`@("`@("`@("`@8V5R=&EF:6-A=&4I+@H@*B`@
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@)VEM87`G"B`J("`G861M:6Y?
M=7-E<B<@("`@("!4:&4@;F%M92!O9B!A('5S97(@=VET:"!A9&UI;B!P<FEV
M:6QE9V5S+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@;G5L;`H@
M*B`@)V%D;6EN7W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&]F('1H92!A9&UI
M;G-T<F%T;W(N"B`J("`@("`@("`@("`@("`@("`@("!$149!54Q4.B!N=6QL
M"B`J("`G=7-E<FAI97)A<F-H>2<@("!4:&4@:&EE<F%R8VAY('=H97)E('5S
M97(@;6%I;&)O>&5S(&%R92!S=&]R960N"B`J("`@("`@("`@("`@("`@("`@
M("!$149!54Q4.B`G=7-E<BXG"B`J("`G9'-N)R`@("`@("`@("`@("!4:&4@
M9G5L;"!)34%0(&-O;FYE8W1I;VX@<W1R:6YG+@H@*B`@("`@("`@("`@("`@
M("`@("`@268@;F]T('!R97-E;G0L('1H:7,@:7,@8G5I;'0@9G)O;2`G:&]S
M='-P96,G+"`G<&]R="<*("H@("`@("`@("`@("`@("`@("`@(&%N9"`G<')O
M=&]C;VPG('!A<F%M971E<G,N/"]P<F4^"B`J"B`J"B`J($EF('-E='1I;F<@
M=7`@87,@2&]R9&4@875T:"!H86YD;&5R(&EN(&-O;F8N<&AP+"!T:&ES(&ES
M(&$@<V%M<&QE(&5N=')Y.CQP<F4^"B`J("`@)&-O;F9;)V%U=&@G75LG<&%R
M86US)UU;)VAO<W1S<&5C)UT@/2`G:6UA<"YE>&%M<&QE+F-O;2<["B`J("`@
M)&-O;F9;)V%U=&@G75LG<&%R86US)UU;)W!O<G0G72`](#$T,SL*("H@("`D
M8V]N9ELG875T:"==6R=P87)A;7,G75LG<')O=&]C;VPG72`]("=I;6%P+VYO
M=&QS+VYO=F%L:61A=&4M8V5R="<[/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<"QV(#$N,C@N,3`N.2`R,#`V
M+S`U+S,Q(#$Y.C,Y.C0X('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!'875D96YZ(%-T96EN;&EN(#QG875D
M96YZ+G-T96EN;&EN0&ED+G5N:6)E+F-H/@H@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0&%U=&AO<B`@1V%U9&5N>B!3=&5I;FQI;B`\9V%U9&5N>BYS
M=&5I;FQI;D!I9"YU;FEB92YC:#X*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P
M86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:6UA<"!E>'1E;F1S
M($%U=&@@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!)34%0
M(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P
M87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VEM87`H)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E
M;G-I;VY%>&ES=',H)VEM87`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH7R@B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`D9&5F875L=%]P87)A;7,@/2!A<G)A>2@*("`@("`@("`@("`@)VAO
M<W1S<&5C)R`]/B`G;&]C86QH;W-T)RP*("`@("`@("`@("`@)W!O<G0G(#T^
M("<Q-#,G+`H@("`@("`@("`@("`G<')O=&]C;VPG(#T^("=I;6%P)RP*("`@
M("`@("`@("`@)W5S97)H:65R87)C:'DG(#T^("=U<V5R+B<*("`@("`@("`I
M.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)&1E9F%U
M;'1?<&%R86US+"`D<&%R86US*3L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG861M:6Y?=7-E<B==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^8V%P86)I;&ET:65S6R=A9&0G72`]('1R=64["B`@("`@("`@("`@("1T
M:&ES+3YC87!A8FEL:71I97-;)W)E;6]V92==(#T@=')U93L*("`@("`@("`@
M("`@)'1H:7,M/F-A<&%B:6QI=&EE<ULG;&ES="==(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J($-R96%T92!$4TX@<W1R:6YG+B`J+PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1S;B==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG9'-N)UT@/2!S<')I;G1F*"=[)7,Z)60O
M)7-])RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG<&]R="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O
M9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A
M;2!A<G)A>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E
M;G1I86QS+B!&;W(@24U!4"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O<F0@96YT<GDN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T
M:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*
M("`@("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(BDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D:6UA<"`]($!I;6%P7V]P
M96XH)'1H:7,M/E]P87)A;7-;)V1S;B==+"`D=7-E<DED+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL($]0
M7TA!3$9/4$5.*3L*"B`@("`@("`@:68@*"1I;6%P*2!["B`@("`@("`@("`@
M($!I;6%P7V-L;W-E*"1I;6%P*3L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H
M17)R;W(H05542%]214%33TY?0D%$3$]'24XI.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@("!4:&4@=7-E<DED
M('1O(&%D9"X*("`@("`J($!P87)A;2!A<G)A>2`@)&-R961E;G1I86QS("!4
M:&4@8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S
M97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O24U!4"]!9&UI;BYP:'`G.PH@("`@("`@("1I;6%P(#T@)FYE
M=R!)34%07T%D;6EN*"1T:&ES+3Y?<&%R86US*3L*("`@("`@("!R971U<FX@
M)&EM87`M/F%D9$UA:6QB;W@H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=7-E
M<DED+"!.3%,Z.F=E=$-H87)S970H*2P@)W5T9C<M:6UA<"<I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO
M;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M955S97(H)'5S97))9"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TE-05`O061M:6XN<&AP)SL*("`@("`@("`D:6UA<"`]("9N97<@24U!
M4%]!9&UI;B@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@)')E<W5L="`]("1I
M;6%P+3YR96UO=F5-86EL8F]X*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'5S
M97))9"P@3DQ3.CIG971#:&%R<V5T*"DL("=U=&8W+6EM87`G*2D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TE-05`O061M:6XN<&AP)SL*("`@("`@("`D:6UA<"`]
M("9N97<@24U!4%]!9&UI;B@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@<F5T
M=7)N("1I;6%P+3YL:7-T36%I;&)O>&5S*"D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0Q,C8U`#$P-3$U-#,Q,#8Q`#`R,3$U
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]!=71H+W-Q;"YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+TE-05`O061M:6XN<&AP)SL*"B\J*@H@*B!4:&4@
M075T:%]C>7)S<6P@8VQA<W,@<')O=FED97,@82!344P@:6UP;&5M96YT871I
M;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2!F;W(@
M=&AE($-Y<G5S($E-05`@<V5R=F5R+B!-;W-T(&]F('1H92!F=6YC=&EO;F%L
M:71Y"B`J(&ES('1H92!S86UE(&%S(&9O<B!T:&4@4U%,(&-L87-S.R!O;FQY
M('=H870@:7,@9&EF9F5R96YT(&]V97)R:61E<R!T:&4*("H@<&%R96YT(&-L
M87-S(&EM<&QE;65N=&%T:6]N<RX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=C>7)A9&UI;B<@(%1H92!U<V5R;F%M92!O9B!T:&4@
M8WER=7,@861M:6YI<W1R871O<BX*("H@("`G8WER<&%S<R<@("!4:&4@<&%S
M<W=O<F0@9F]R('1H92!C>7)U<R!A9&UI;FES=')A=&]R+@H@*B`@("=I;6%P
M7V1S;B<@(%1H92!F=6QL($E-05`@1%-."B`J("`@("`@("`@("`@("`@*&DN
M92X@>VQO8V%L:&]S=#HY.3,O:6UA<"]S<VPO;F]V86QI9&%T92UC97)T?2DN
M"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S
M<6PG+"`G;7ES<6PG+"!E=&,N*2X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R
M86UE=&5R<SH\<')E/@H@*B`@("=D;VUA:6Y?9FEE;&0G("`@($EF('-E="!T
M;R!A;GET:&EN9R!O=&AE<B!T:&%N("=N;VYE)R!T:&ES(&ES('5S960@87,*
M("H@("`@("`@("`@("`@("`@("`@("!F:65L9"!N86UE('=H97)E(&1O;6%I
M;B!I<R!S=&]R960N"B`J("`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@
M)V1O;6%I;E]N86UE)PH@*B`@("=E;F-R>7!T:6]N)R`@("`@(%1H92!E;F-R
M>7!T:6]N('1O('5S92!T;R!S=&]R92!T:&4@<&%S<W=O<F0@:6X@=&AE"B`J
M("`@("`@("`@("`@("`@("`@("`@=&%B;&4@*&4N9RX@<&QA:6XL(&-R>7!T
M+"!M9#4M:&5X+"!M9#4M8F%S938T+"!S;60U+`H@*B`@("`@("`@("`@("`@
M("`@("`@('-H82P@<W-H82DN"B`J("`@("`@("`@("`@("`@("`@("`@1$5&
M055,5#H@)VUD-2UH97@G"B`J("`@)V9O;&1E<G,G("`@("`@("`@06X@87)R
M87D@;V8@9F]L9&5R<R!T;R!C<F5A=&4@=6YD97(@=7-E<FYA;64N"B`J("`@
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@3D].10H@*B`@("=P87-S=V]R
M9%]F:65L9"<@(%1H92!N86UE(&]F('1H92!P87-S=V]R9"!F:65L9"!I;B!T
M:&4@875T:"!T86)L92X*("H@("`@("`@("`@("`@("`@("`@("!$149!54Q4
M.B`G<&%S<W=O<F0G"B`J("`@)W%U;W1A)R`@("`@("`@("`@5&AE('%U;W1A
M("AI;B!K:6QO8GET97,I('1O(&=R86YT(&]N('1H92!M86EL8F]X+@H@*B`@
M("`@("`@("`@("`@("`@("`@($1%1D%53%0Z($Y/3D4*("H@("`G=&%B;&4G
M("`@("`@("`@("!4:&4@;F%M92!O9B!T:&4@875T:"!T86)L92!I;B`G9&%T
M86)A<V4G+@H@*B`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=A8V-O
M=6YT=7-E<B<*("H@("`G=6YI>&AI97(G("`@("`@("!4:&4@=F%L=64@;V8@
M:6UA<&0N8V]N9B=S('5N:7AH:65R87)C:'ES97`@<V5T=&EN9RX*("H@("`@
M("`@("`@("`@("`@("`@("!3970@=&AI<R!T;R!T<G5E(&EF('1H92!V86QU
M92!I<R!T<G5E(&EN(&EM87!D+F-O;F8N"B`J("`@)W5S97)N86UE7V9I96QD
M)R`@5&AE(&YA;64@;V8@=&AE('5S97)N86UE(&9I96QD(&EN('1H92!A=71H
M('1A8FQE+@H@*B`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=U<V5R
M;F%M92<\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I
M;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M
M92!O9B!T:&4@9&%T86)A<V4N"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N
M86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J("`@)W!R;W1O8V]L)R`@
M5&AE(&-O;6UU;FEC871I;VX@<')O=&]C;VP@*"=T8W`G+"`G=6YI>"<L(&5T
M8RXI+@H@*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W:71H('=H:6-H
M('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S=V]R9"<@
M(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@
M("`G;W!T:6]N<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T
M:&4@9&%T86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;VX@=VAI
M8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@("`@
M("`@5&AE(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S
M92X\+W!R93X*("H*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE
M(&%U=&@@<WES=&5M(&ES(&%S(&9O;&QO=W,Z"B`J"B`J(#QP<F4^"B`J($-2
M14%412!404),12!A8V-O=6YT=7-E<B`H"B`J("`@("!U<V5R;F%M92`@("!6
M05)#2$%2*#(U-2D@0DE.05)9($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@
M("!P87-S=V]R9"`@("!605)#2$%2*#,R*2!"24Y!4ED@3D]4($Y53$P@1$5&
M055,5"`G)RP*("H@("`@('!R969I>"`@("`@(%9!4D-(05(H-3`I($Y/5"!.
M54Q,($1%1D%53%0@)R<L"B`J("`@("!D;VUA:6Y?;F%M92!605)#2$%2*#(U
M-2D@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@(%5.25%512!+15D@=7-E
M<FYA;64@*'5S97)N86UE*0H@*B`I.PH@*@H@*B!#4D5!5$4@5$%"3$4@861M
M:6YU<V5R("@*("H@("`@('5S97)N86UE("`@(%9!4D-(05(H-3`I($))3D%2
M62!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@<&%S<W=O<F0@("`@5D%2
M0TA!4B@U,"D@0DE.05)9($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!T
M>7!E("`@("`@("!)3E0H,3$I($Y/5"!.54Q,($1%1D%53%0@)S`G+`H@*B`@
M("`@4TE$("`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@
M)R<L"B`J("`@("!H;VUE("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$P@
M1$5&055,5"`G)RP*("H@("`@(%!224U!4ED@2T59("AU<V5R;F%M92D*("H@
M*3L*("H*("H@0U)%051%(%1!0DQ%(&%L:6%S("@*("H@("`@(&%L:6%S("`@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@
M9&5S="`@("`@("`@3$].1U1%6%0L"B`J("`@("!U<V5R;F%M92`@("!605)#
M2$%2*#4P*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@<W1A='5S("`@
M("`@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4("<Q)RP*("H@("`@(%!224U!
M4ED@2T59("AA;&EA<RD*("H@*3L*("H*("H@0U)%051%(%1!0DQ%(&1O;6%I
M;B`H"B`J("`@("!D;VUA:6Y?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$P@
M1$5&055,5"`G)RP*("H@("`@('!R969I>"`@("`@(%9!4D-(05(H-3`I($Y/
M5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!M87AA8V-O=6YT<R!)3E0H,3$I
M($Y/5"!.54Q,($1%1D%53%0@)S(P)RP*("H@("`@('%U;W1A("`@("`@($E.
M5"@Q,"D@3D]4($Y53$P@1$5&055,5"`G,C`P,#`G+`H@*B`@("`@=')A;G-P
M;W)T("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)V-Y<G5S)RP*
M("H@("`@(&9R965N86UE<R`@($5.54TH)UE%4R<L)TY/)RD@3D]4($Y53$P@
M1$5&055,5"`G3D\G+`H@*B`@("`@9G)E96%D9')E<W,@14Y532@G6453)RPG
M3D\G*2!.3U0@3E5,3"!$149!54Q4("=.3R<L"B`J("`@("!04DE-05)9($M%
M62`H9&]M86EN7VYA;64I+`H@*B`@("`@54Y)455%($M%62!P<F5F:7@@*'!R
M969I>"D*("H@*3L*("H*("H@0U)%051%(%1!0DQ%(&1O;6%I;F%D;6EN("@*
M("H@("`@(&1O;6%I;E]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!
M54Q4("<G+`H@*B`@("`@861M:6YU<V5R("`@5D%20TA!4B@R-34I($Y/5"!.
M54Q,($1%1D%53%0@)R<*("H@*3L*("H*("H@0U)%051%(%1!0DQ%('-E87)C
M:"`H"B`J("`@("!S96%R8VA?:60@("!605)#2$%2*#(U-2D@3D]4($Y53$P@
M1$5&055,5"`G)RP*("H@("`@('-E87)C:%]S<6P@(%1%6%0@3D]4($Y53$PL
M"B`J("`@("!P97)P86=E("`@("!)3E0H,3$I($Y/5"!.54Q,($1%1D%53%0@
M)S`G+`H@*B`@("`@=&EM97-T86UP("`@5$E-15-404U0*#$T*2!.3U0@3E5,
M3"P*("H@("`@(%!224U!4ED@2T59("AS96%R8VA?:60I+`H@*B`@("`@2T59
M('-E87)C:%]I9"`H<V5A<F-H7VED*0H@*B`I.PH@*@H@*B!#4D5!5$4@5$%"
M3$4@=FER='5A;"`H"B`J("`@("!A;&EA<R`@("`@("!605)#2$%2*#(U-2D@
M3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@(&1E<W0@("`@("`@($Q/3D=4
M15A4+`H@*B`@("`@=7-E<FYA;64@("`@5D%20TA!4B@U,"D@3D]4($Y53$P@
M1$5&055,5"`G)RP*("H@("`@('-T871U<R`@("`@($E.5"@Q,2D@3D]4($Y5
M3$P@1$5&055,5"`G,2<L"B`J("`@("!+15D@86QI87,@*&%L:6%S*0H@*B`I
M.PH@*@H@*B!#4D5!5$4@5$%"3$4@;&]G("@*("H@("`@(&ED("`@("`@("`@
M($E.5"@Q,2D@3D]4($Y53$P@05543U])3D-214U%3E0L"B`J("`@("!M<V<@
M("`@("`@("!415A4($Y/5"!.54Q,+`H@*B`@("`@=7-E<B`@("`@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!H;W-T("`@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@
M('1I;64@("`@("`@($1!5$5424U%($Y/5"!.54Q,($1%1D%53%0@)S(P,#`M
M,#`M,#`@,#`Z,#`Z,#`G+`H@*B`@("`@<&ED("`@("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!04DE-05)9($M%62`H
M:60I"B`J("D["B`J(#PO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<"QV(#$N,S,N,3`N,30@,C`P-B\P."\Q-"`P
M,CHT.#HT."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($EL>6$@/&UA:6Q`:W)E;"YO<F<^"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($EL>6$@/&UA:6Q`:W)E;"YO<F<^"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H
M7V-Y<G-Q;"!E>'1E;F1S($%U=&A?<W%L('L*"B`@("`O*BH*("`@("`J($AA
M;F1L92!F;W(@=&AE(&-U<G)E;G0@24U!4"!C;VYN96-T:6]N+@H@("`@("H*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?:6UA<%-T
M<F5A;3L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@86X@24U!4%]!9&UI
M;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!)34%07T%D;6EN"B`@("`@
M*B\*("`@('9A<B`D7V%D;6EN.PH*("`@("\J*@H@("`@("H@2&EE<F%R8VAY
M('-E<&%R871O<B!T;R!U<V4@*&4N9RXL(&ES(&ET('5S97(O;6%I;&)O>"!O
M<B!U<V5R+FUA:6QB;W@I"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?<V5P87)A=&]R(#T@)RXG.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]C>7)S<6PH)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%
M>&ES=',H)VEM87`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@
M<&%R96YT.CI!=71H7W-Q;"@D<&%R86US*3L*"B`@("`@("`@)&%D;6EN7W!A
M<F%M<R`](&%R<F%Y*"=A9&UI;E]U<V5R)R`]/B`D<&%R86US6R=C>7)A9&UI
M;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G861M:6Y?<&%S
M<W=O<F0G(#T^("1P87)A;7-;)V-Y<G!A<W,G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1S;B<@/3X@)'!A<F%M<ULG:6UA<%]D<VXG72D[
M"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG=6YI>&AI97(G
M72DI('L*("`@("`@("`@("`@)&%D;6EN7W!A<F%M<ULG=7-E<FAI97)A<F-H
M>2==(#T@)W5S97(O)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]A9&UI
M;B`]("9N97<@24U!4%]!9&UI;B@D861M:6Y?<&%R86US*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D
M96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@
M("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O(&%D9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTI("8F"B`@("`@("`@("`@
M("@D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UT@(3T@)VYO;F4G*2D@
M>PH@("`@("`@("`@("!L:7-T*"1N86UE+"`D9&]M86EN*2`](&5X<&QO9&4H
M)T`G+"`D=7-E<DED*3L*("`@("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G24Y315)4
M($E.5$\@)7,@*"5S+"`E<RP@)7,I(%9!3%5%4R`H/RP@/RP@/RDG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M95]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O
M<F1?9FEE;&0G72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;VUA:6XL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W
M;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI.PH*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7V-Y
M<G-Q;#HZ861D57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("1D8G)E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@
M("`@("1Q=65R>2`]("=)3E-%4E0@24Y43R!V:7)T=6%L("AA;&EA<RP@9&5S
M="P@=7-E<FYA;64L('-T871U<RD@5D%,5453("@_+"`_+"`_+"`Q*2<["B`@
M("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=7-E<DED+"`D;F%M92P@)&YA
M;64I.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R
M>2!B>2!!=71H7V-Y<G-Q;#HZ861D57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@
M("1D8G)E<W5L=#(@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU
M97,I.PH@("`@("`@("`@("!I9B`H:7-?82@D9&)R97-U;'0R+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&1B<F5S=6QT,CL*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D
M8G)E<W5L="`]('!A<F5N=#HZ861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA
M;',I.PH@("`@("`@("`@("`D;F%M92`]("1U<V5R260["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<U]A*"1D8G)E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&1B<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<U]A*"1R97-U;'0@/2`D=&AI<RT^7V%D;6EN+3YA9&1-86EL
M8F]X*"1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!`87)R
M87E?=V%L:R@D=&AI<RT^7W!A<F%M<ULG9F]L9&5R<R==+`H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@D=&AI<RP@)U]C<F5A=&53=6)&;VQD97)S
M)RDL("1N86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G24U!4"!M86EL8F]X(&-R96%T:6]N(&9O<B`G("X@
M)&YA;64@+B`G(&9A:6QE9#H@)R`N("1R97-U;'0M/F=E=$UE<W-A9V4H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(BDL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=Q=6]T82==
M*2`F)B`D=&AI<RT^7W!A<F%M<ULG<75O=&$G72`^/2`P*2!["B`@("`@("`@
M("`@(&EF("@A0&EM87!?<V5T7W%U;W1A*"1T:&ES+3Y?:6UA<%-T<F5A;2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97(G("X@)'1H
M:7,M/E]S97!A<F%T;W(@+B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W%U;W1A)UTI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(BDL(&EM
M87!?;&%S=%]E<G)O<B@I*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L
M971E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T
M;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@("`@
M("!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;6]V955S97(H)'5S97))9"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O;FYE
M8W0H*3L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG9&]M
M86EN7V9I96QD)UTI("8F"B`@("`@("`@("`@("@D=&AI<RT^7W!A<F%M<ULG
M9&]M86EN7V9I96QD)UT@(3T@)VYO;F4G*2D@>PH@("`@("`@("`@("!L:7-T
M*"1N86UE+"`D9&]M86EN*2`](&5X<&QO9&4H)T`G+"`D=7-E<DED*3L*("`@
M("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@)7,@
M/2`_(&%N9"`E<R`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D
M;VUA:6Y?9FEE;&0G72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D
M;F%M92P@)&1O;6%I;BD["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($%U=&A?8WER<W%L.CIR96UO=F55<V5R*"DZ("<@
M+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH*("`@("`@("`@("`@)&1B<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@)'%U97)Y(#T@)T1%3$54
M12!&4D]-('9I<G1U86P@5TA%4D4@9&5S="`](#\G.PH@("`@("`@("`@("`D
M=F%L=65S(#T@87)R87DH)&YA;64I.PH*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7V-Y<G-Q;#HZ<F5M;W9E57-E
M<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@("`@("1D8G)E<W5L=#(@/2`D=&AI<RT^7V1B
M+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D9&)R97-U;'0R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&1B<F5S=6QT,CL*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1D8G)E<W5L="`]('!A<F5N=#HZ<F5M;W9E
M57-E<B@D=7-E<DED*3L*("`@("`@("`@("`@)&YA;64@/2`D=7-E<DED.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)&1B<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9&)R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`O*B!$96QE=&4@24U!4"!M86EL8F]X+B`J+PH@("`@
M("`@("1I;6%P<F5S=6QT(#T@)'1H:7,M/E]A9&UI;BT^<F5M;W9E36%I;&)O
M>"@D;F%M92D["@H@("`@("`@(&EF("AI<U]A*"1I;6%P<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@
M)7,B*2P@)&EM87!R97-U;'0M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@8V]N
M;F5C=&EO;G,@=&\@=&AE(%-13"!A;F0@24U!4"!S97)V97)S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*
M("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@
M("`@("`@('!A<F5N=#HZ7V-O;FYE8W0H*3L*"B`@("`@("`@("`@("\O(%)E
M<V5T('1H92`D7V-O;FYE8W1E9"!F;&%G.R!W92!H879E;B=T('EE="!S=6-C
M97-S9G5L;'D@;W!E;F5D"B`@("`@("`@("`@("\O(&5V97)Y=&AI;F<N"B`@
M("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@("`@
M("`@("`D=&AI<RT^7VEM87!3=')E86T@/2!`:6UA<%]O<&5N*"1T:&ES+3Y?
M<&%R86US6R=I;6%P7V1S;B==+"`D=&AI<RT^7W!A<F%M<ULG8WER861M:6XG
M72P@)'1H:7,M/E]P87)A;7-;)V-Y<G!A<W,G72P@3U!?2$%,1D]014XI.PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?:6UA<%-T<F5A;2D@>PH@("`@("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*'-P<FEN=&8H7R@B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B*2P@:6UA<%]L87-T7V5R<F]R*"DI+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=U;FEX:&EE<B==*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S97!A<F%T;W(@/2`G+R<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R;VT@=&AE(%-13"!A;F0@24U!4"!S
M97)V97)S(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;G,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@<&%R96YT
M.CI?9&ES8V]N;F5C="@I.PH@("`@("`@("`@("!`:6UA<%]C;&]S92@D=&AI
M<RT^7VEM87!3=')E86TI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&%L;"!M86EL8F]X
M97,@<W5P<&QI960@:6X@8V]N9FEG=7)A=&EO;@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'9A
M;'5E"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@("!5;G5S960@8GD@
M=&AI<R!D<FEV97(*("`@("`J($!P87)A;2!S=')I;F<@=7-E<DYA;64*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-R96%T95-U8D9O;&1E<G,H)'9A;'5E+"`D
M:V5Y+"`D=7-E<DYA;64I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTI("8F"B`@("`@("`@("`@("@D
M=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UT@(3T@)VYO;F4G*2D@>PH@
M("`@("`@("`@("!L:7-T*"1U<V5R3F%M92D@/2!E>'!L;V1E*"=`)RP@)'5S
M97).86UE*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]A9&UI;BT^861D
M36%I;&)O>"@D=7-E<DYA;64@+B`D=&AI<RT^7W-E<&%R871O<B`N("1V86QU
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T
M:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A
M<G)A>2!O9B!U<V5R261S+"!O<B!F86QS92!O;B!F86EL=7)E+W5N<W5P<&]R
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@
M("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T
M86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M*"D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O
M;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@+RH@0G5I
M;&0@=&AE(%-13"!Q=65R>2!W:71H(&1O;6%I;BX@*B\*("`@("`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("5S+"`E<R!&4D]-("5S($]21$52
M($)9("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GD@=VET:&]U="!D;VUA
M:6XN("HO"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"`E
M<R!&4D]-("5S($]21$52($)9("5S)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@?0H*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($%U=&A?8WER<W%L.CIL
M:7-T57-E<G,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B
M+3YG971!;&PH)'%U97)Y+"!N=6QL+"!$0E]&151#2$U/1$5?3U)$15)%1"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("\J($QO;W`@=&AR;W5G:"!A;F0@8G5I;&0@<F5T=7)N(&%R<F%Y+B`J+PH@
M("`@("`@("1U<V5R<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTI("8F"B`@("`@("`@("`@
M("@D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UT@(3T@)VYO;F4G*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1A<BD@>PH@("`@
M("`@("`@("`@("`@)'5S97)S6UT@/2`D87);,%T@+B`G0"<@+B`D87);,5T[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F
M;W)E86-H("@D<F5S=6QT(&%S("1A<BD@>PH@("`@("`@("`@("`@("`@)'5S
M97)S6UT@/2`D87);,%T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=7-E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A
M=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@5&AE(&]L9"!U
M<V5R260N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=)1"`@("`@("!4:&4@
M;F5W('5S97))9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@
M(%1H92!N97<@8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O
M;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@+RH@
M7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@
M9F%I;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTI
M("8F"B`@("`@("`@("`@("@D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD
M)UT@(3T@)VYO;F4G*2D@>PH@("`@("`@("`@("!L:7-T*"1N86UE+"`D9&]M
M86EN*2`](&5X<&QO9&4H)T`G+"`D;VQD240I.PH@("`@("`@("`@("`O*B!"
M=6EL9"!T:&4@4U%,('%U97)Y('=I=&@@9&]M86EN+B`J+PH@("`@("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=54$1!5$4@)7,@4T54("5S(#T@/R!72$52
M12`E<R`](#\@86YD("5S(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*3L*("`@("`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3YG971#<GEP=&5D4&%S<W=O
M<F0H)&-R961E;G1I86QS6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N86UE+"`D9&]M86EN*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J
M+PH@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=54$1!5$4@)7,@4T54
M("5S(#T@/R!72$5212`E<R`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L
M9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)&-R961E;G1I86QS
M6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W-H;W=?96YC<GEP=&EO;B==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1O;&1)1"D["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G4U%,(%%U97)Y(&)Y($%U=&A?8WER<W%L.CIU<&1A=&55<V5R*"DZ
M("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y
M+"`D=F%L=65S*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O>6%H;V\N<&AP````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3`V,``Q,#4Q-30S
M,3`V,0`P,C`W-#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7WEA:&]O.CH@8VQA<W,@
M8VAE8VMS(&QO9VEN(&-R961E;G1I86QS(&%G86EN<W0@66%H;V\A(&UA:6P*
M("H@86-C;W5N=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T
M:"]Y86AO;RYP:'`L=B`Q+C$S+C$R+C<@,C`P-B\P,2\P,2`R,3HR.#HP-R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E('EA
M:&]O.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO
M"F-L87-S($%U=&A?>6%H;V\@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@
M("`J($!V87(@2%144%]297%U97-T"B`@("`@*B\*("`@('9A<B`D7VAT='`[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%EA:&]O(&%U=&AE
M;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]Y86AO;R@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C
M<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@
M("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@
M("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C
M<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A
M=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@
M("`@(')E<75I<F5?;VYC92`G2%144"]297%U97-T+G!H<"<["@H@("`@("`@
M("\O($UA:V4@<W5R92!T:&%T('=E(&AA=F4@82!B87)E('5S97)N86UE("T@
M<W1R:7`@;V9F(&%N>71H:6YG"B`@("`@("`@+R\@869T97(@*&%N9"!I;F-L
M=61I;F<I('1H92!F:7)S="!`+"!I9B!T:&5R92!I<R!O;F4N"B`@("`@("`@
M)'!O<R`]('-T<G!O<R@D=7-E<DED+"`G0"<I.PH@("`@("`@(&EF("@D<&]S
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=7-E<DED(#T@<W5B<W1R*"1U
M<V5R260L(#`L("1P;W,I.PH@("`@("`@('T*"B`@("`@("`@)&]P=&EO;G-;
M)VUE=&AO9"==(#T@2%144%]215%515-47TU%5$A/1%]03U-4.PH@("`@("`@
M("1O<'1I;VYS6R=T:6UE;W5T)UT@/2`U.PH@("`@("`@("1O<'1I;VYS6R=A
M;&QO=U)E9&ER96-T<R==(#T@=')U93L*"B`@("`@("`@)'1H:7,M/E]H='1P
M(#T@)FYE=R!(5%107U)E<75E<W0H)VAT='`Z+R]L;V=I;BYY86AO;RYC;VTO
M8V]N9FEG+VQO9VEN)RP@)&]P=&EO;G,I.PH@("`@("`@("1T:&ES+3Y?:'1T
M<"T^861D4&]S=$1A=&$H)VQO9VEN)RP@)'5S97))9"D["B`@("`@("`@)'1H
M:7,M/E]H='1P+3YA9&10;W-T1&%T82@G<&%S<W=D)RP@)&-R961E;G1I86QS
M6R=P87-S=V]R9"==*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:'1T
M<"T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D<F5S=6QT
M+3YG971-97-S86=E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"D["B`@
M("`@("`@("`@("1C;V]K:65S(#T@)'1H:7,M/E]H='1P+3YG971297-P;VYS
M94-O;VMI97,H*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1C;V]K:65S
M*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&-O;VMI97,@87,@)&-O
M;VMI92D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:'1T<"T^861D
M0V]O:VEE*"1C;V]K:65;)VYA;64G72P@)&-O;VMI95LG=F%L=64G72D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O(%1H:7,@:7,@7W-U8VA?(&$@:&%C:RP@8G5T(&ET('=O<FMS+@H@
M("`@("`@(&EF("@A<')E9U]M871C:"@G?&EN=F%L:60@<&%S<W=O<F1\:2<L
M("1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U
M;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,
M3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"]P86TN<&AP````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`U,S(S`#$P-3$U-#,Q,#8Q`#`R,#0P-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($%U=&A?<&%M.CH@8VQA<W,@<')O=FED97,@82!004TM8F%S
M960@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T
M:6]N('-Y<W1E;2X*("H*("H@4$%-("A0;'5G9V%B;&4@075T:&5N=&EC871I
M;VX@36]D=6QE<RD@:7,@82!F;&5X:6)L92!M96-H86YI<VT@9F]R"B`J(&%U
M=&AE;G1I8V%T:6YG('5S97)S+B`@270@:&%S(&)E8V]M92!T:&4@<W1A;F1A
M<F0@875T:&5N=&EC871I;VX@<WES=&5M(&9O<@H@*B!,:6YU>"P@4V]L87)I
M<R!A;F0@1G)E94)31"X*("H*("H@5&AI<R!I;7!L96UE;G1A=&EO;B!R97%U
M:7)E<R!#:&%D($-U;FYI;F=H86TG<R!P86U?875T:"!E>'1E;G-I;VXZ"B`J
M"B`J("`@("`@:'1T<#HO+W=W=RYM871H+F]H:6\M<W1A=&4N961U+WYC8W5N
M;FEN9R]P86U?875T:"\*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E
M/@H@*B`@("=S97)V:6-E)R`@5&AE(&YA;64@;V8@=&AE(%!!32!S97)V:6-E
M('1O('5S92!W:&5N(&%U=&AE;G1I8V%T:6YG+@H@*B`@("`@("`@("`@("`@
M1$5&055,5#H@<&AP/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP+'8@,2XS+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z
M,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IA;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!
M=71H7W!A;2!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R
M87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E
M<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@
M=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=7!D871E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W(%!!32!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@075T:%]P86TH)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@(&EF("@A96UP
M='DH)'!A<F%M<ULG<V5R=FEC92==*2D@>PH@("`@("`@("`@("!I;FE?<V5T
M*"=P86U?875T:"YS97)V:6-E;F%M92<L("1P87)A;7-;)W-E<G9I8V4G72D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H)W!A
M;5]A=71H)RDI('L*("`@("`@("`@("`@9&PH)W!A;5]A=71H+G-O)RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S
M970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C
M<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H
M971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E
M;G1I86QS*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D8W)E9&5N=&EA;'-;
M)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN
M(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65X=&5N<VEO;E]L;V%D960H)W!A;5]A=71H)RDI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%\H(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%P86U?875T:"@D=7-E<DED+"`D8W)E9&5N=&EA;'-;
M)W!A<W-W;W)D)UTL("8D97)R;W(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L("1E<G)O<BD["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H
M+VEM<W`N<&AP````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#4T-38`,3`U,34T,S$P-C$`,#(P-C$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]I
M;7-P(&-L87-S('!R;W9I9&5S(&)A<VEC(&%U=&AE;G1I8V%T:6]N(&%G86EN
M<W0@86X@24U34"!S97)V97(N"B`J(%1H:7,@=VEL;"!B92!M;W-T(&)E;FEF
M:6-I86P@:68@86QR96%D>2!U<VEN9R!A;B!)35-0(&)A<V5D('!R969E<F5N
M8V4*("H@<WES=&5M(&]R($E-4U`@8F%S960@861D<F5S<V)O;VL@<WES=&5M
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]I;7-P+G!H<"QV
M(#$N,BXQ,"XQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I
M;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI
M8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H@0'!A8VMA
M9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]I;7-P(&5X=&5N9',@075T
M:'L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@
M<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P
M97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B
M:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P
M87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@
M9F%L<V4I.PH@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B!F=6YC=&EO;BX@
M0W)E871E<R!N97<@075T:%]I;7-P(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VEM<W`H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A
M<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<FEV871E(&%U=&AE;G1I
M8V%T:6]N(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))1"!5<V5R;F%M
M92!F;W(@24U34"!S97)V97(N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E
M;G1I86QS($AA<V@@8V]N=&%I;FEN9R`G<&%S<W=O<F0G(&5L96UE;G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N(%1R=64@;VX@<W5C8V5S<R`O
M($9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H
M96YT:6-A=&4H)'5S97))1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G3F5T+TE-4U`O075T:"YP:'`G.PH*("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("1U<V5R240["B`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT@/2`D8W)E9&5N=&EA;'-;)W!A
M<W-W;W)D)UT["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U!?075T:#HZ<VEN
M9VQE=&]N*"1T:&ES+3Y?<&%R86US6R=A=71H7VUE=&AO9"==*3L*"B`@("`@
M("`@:68@*&ES7V$H)&EM<W`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1I;7-P.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M("1I;7-P+3YA=71H96YT:6-A=&4H)'1H:7,M/E]P87)A;7,L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!
M1$Q/1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@<&%R86US(&%R<F%Y(&%N
M9"!S971S(&1E9F%U;'0@=F%L=65S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@2&%S:"!C;VYT
M86EN:6YG($E-4U`@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W-E=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=S97)V97(G72`]("1P87)A;7-;)W-E<G9E<B==.PH@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=P;W)T)UT@/2`D<&%R86US6R=P;W)T)UT["B`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)V%U=&A?;65T:&]D)UT@/2`D<&%R86US6R=A
M=71H7VUE=&AO9"==.PH*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG875T
M:%]M96-H86YI<VTG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)V%U=&A?;65C:&%N:7-M)UT@/2`D<&%R86US6R=A=71H7VUE8VAA;FES;2==
M.PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<V]C:V5T)UT@/2`D<&%R
M86US6R=S;V-K970G73L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V-O
M;6UA;F0G72`]("1P87)A;7-;)V-O;6UA;F0G73L*("`@("`@("!]"B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<```````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#<Q-``Q,#4Q-30S,3`V
M,0`P,C$Q,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7W)A9&EU<R!C;&%S<R!P<F]V
M:61E<R!A(%)!1$E54R!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@
M875T:&5N=&EC871I;VX@<WES=&5M+@H@*@H@*B!4:&ES(&-L87-S(')E<75I
M<F5S('1H92`G<F%D:75S)R!014-,(&5X=&5N<VEO;BX*("H@4D%$2553(%!%
M0TP@97AT96YS:6]N.B!H='1P.B\O<&5C;"YP:'`N;F5T+W!A8VMA9V4O<F%D
M:75S"B`J"B`J($]N("IN:7@M>2!M86-H:6YE<RP@=&AI<R!E>'1E;G-I;VX@
M8V%N(&)E(&EN<W1A;&QE9"!A<R!F;VQL;W=S.CQP<F4^"B`J("`@(G!E87(@
M:6YS=&%L;"!R861I=7,B/"]P<F4^"B`J"B`J(%1H96XL(&5D:70@>6]U<B!P
M:'`N:6YI(&9I;&4@86YD(&UA:V4@<W5R92!T:&4@9F]L;&]W:6YG(&QI;F4@
M:7,@<')E<V5N=#H\<')E/@H@*B`@($9O<B!7:6YD;W=S(&UA8VAI;F5S.B`@
M97AT96YS:6]N/7!H<%]R861I=7,N9&QL"B`J("`@1F]R(&%L;"!O=&AE<G,Z
M("`@("`@("!E>'1E;G-I;VX]<F%D:75S+G-O/"]P<F4^"B`J"B`J(%)E<75I
M<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S="<@("`@5&AE(%)!1$E5
M4R!H;W-T('1O('5S92`H25`@861D<F5S<R!O<B!F=6QL>2!Q=6%L:69I960*
M("H@("`@("`@("`@("`@:&]S=&YA;64I+@H@*B`@("=M971H;V0G("!4:&4@
M4D%$2553(&UE=&AO9"!T;R!U<V4@9F]R('9A;&ED871I;F<@=&AE(')E<75E
M<W0N"B`J("`@("`@("`@("`@($5I=&AE<CH@)U!!4"<L("=#2$%07TU$-2<L
M("=-4T-(05!V,2<L(&]R("=-4T-(05!V,B<N"B`J("`@("`@("`@("`@("HJ
M($-54E)%3E1,62P@;VYL>2`G4$%0)R!I<R!S=7!P;W)T960N("HJ"B`J("`@
M)W-E8W)E="<@(%1H92!2041)55,@<VAA<F5D('-E8W)E="!S=')I;F<@9F]R
M('1H92!H;W-T+B!4:&4*("H@("`@("`@("`@("`@4D%$2553('!R;W1O8V]L
M(&EG;F]R97,@86QL(&)U="!T:&4@;&5A9&EN9R`Q,C@@8GET97,*("H@("`@
M("`@("`@("`@;V8@=&AE('-H87)E9"!S96-R970N/"]P<F4^"B`J"B`J($]P
M=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G;F%S)R`@("`@(%1H92!2
M041)55,@3D%3(&ED96YT:69I97(@=&\@=7-E+@H@*B`@("`@("`@("`@("`@
M1$5&055,5#H@5&AE('9A;'5E(&]F("1?4T525D526R=(5%107TA/4U0G72!O
M<BP@:68@;F]T"B`J("`@("`@("`@("`@("`@("`@("`@("!D969I;F5D+"!T
M:&5N("=L;V-A;&AO<W0G+@H@*B`@("=P;W)T)R`@("`@5&AE('!O<G0@=&\@
M=7-E(&]N('1H92!2041)55,@<V5R=F5R+@H@*B`@("`@("`@("`@("`@1$5&
M055,5#H@5VAA=&5V97(@=&AE(&QO8V%L('-Y<W1E;2!I9&5N=&EF:65S(&%S
M('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@)W)A9&EU<R<@5410('!O
M<G0*("H@("`G<F5T<FEE<R<@(%1H92!M87AI;75M(&YU;6)E<B!O9B!R97!E
M871E9"!R97%U97-T<R!T;R!M86ME(&)E9F]R90H@*B`@("`@("`@("`@("`@
M9VEV:6YG('5P+@H@*B`@("`@("`@("`@("`@1$5&055,5#H@,PH@*B`@("=S
M=69F:7@G("`@5&AE(&1O;6%I;B!N86UE('1O(&%D9"!T;R!U;G%U86QI9FEE
M9"!U<V5R(&YA;65S+@H@*B`@("`@("`@("`@("`@1$5&055,5#H@3D].10H@
M*B`@("=T:6UE;W5T)R`@5&AE('1I;65O=70@9F]R(')E8V5I=FEN9R!R97!L
M:65S(&9R;VT@=&AE('-E<G9E<B`H:6X*("H@("`@("`@("`@("`@('-E8V]N
M9',I+@H@*B`@("`@("`@("`@("`@1$5&055,5#H@,R!S96-O;F1S/"]P<F4^
M"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N
M<&AP+'8@,2XR-"XX+C@@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7W)A9&EU<R!E>'1E;F1S($%U
M=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S
M+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@
M;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P
M86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E
M='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]
M/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%)!
M1$E54R!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]R861I
M=7,H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%5=&EL
M.CIE>'1E;G-I;VY%>&ES=',H)W)A9&EU<R<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"@G075T:%]R861I=7,@<F5Q=6ER97,@=&AE(')A9&EU<R!0
M14-,(&5X=&5N<VEO;B!T;R!B92!L;V%D960N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V5T4&%R86US*"1P
M87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('!A<F%M971E<G,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97(@:&%S:"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-E=%!A<F%M<R@D<&%R86US*0H@("`@>PH@
M("`@("`@("\J($$@4D%$2553(&AO<W0@:7,@<F5Q=6ER960N("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1P87)A;7-;)VAO<W0G72DI('L*("`@("`@("`@("`@
M2&]R9&4Z.F9A=&%L*"=!=71H7W)A9&EU<R!R97%U:7)E<R!A(%)!1$E54R!H
M;W-T('1O(&-O;FYE8W0@=&\N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@("\J($$@4D%$2553('-E8W)E="!S=')I;F<@:7,@
M<F5Q=6ER960N("HO"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W-E8W)E
M="==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)T%U=&A?<F%D:75S
M(')E<75I<F5S(&$@4D%$2553('-E8W)E="!S=')I;F<N)RP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J($$@4D%$2553(&%U
M=&AE;G1I8V%T:6]N(&UE=&AO9"!I<R!R97%U:7)E9"X@*B\*("`@("`@("!I
M9B`H96UP='DH)'!A<F%M<ULG;65T:&]D)UTI*2!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"@G075T:%]R861I=7,@<F5Q=6ER97,@82!2041)55,@875T
M:&5N=&EC871I;VX@;65T:&]D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!2041)55,@3D%3($ED96YT:69I97(N("HO
M"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)VYA<R==*2D@>PH@("`@("`@
M("`@("`D<&%R86US6R=N87,G72`](&ES<V5T*"1?4T525D526R=(5%107TA/
M4U0G72D@/R`D7U-%4E9%4ELG2%144%](3U-4)PI=(#H@)VQO8V%L:&]S="<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!3=69F:7@@=&\@861D('1O('5N<75A
M;&EF:65D('5S97(@;F%M97,N("HO"B`@("`@("`@:68@*&5M<'1Y*"1P87)A
M;7-;)W-U9F9I>"==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=S=69F:7@G
M72`]("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@5&AE(%)!1$E54R!P;W)T
M('1O('5S92X@*B\*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<&]R="==
M*2D@>PH@("`@("`@("`@("`D<&%R86US6R=P;W)T)UT@/2`P.PH@("`@("`@
M('T*"B`@("`@("`@+RH@36%X:6UU;2!N=6UB97(@;V8@<F5T<FEE<RX@*B\*
M("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<F5T<FEE<R==*2D@>PH@("`@
M("`@("`@("`D<&%R86US6R=R971R:65S)UT@/2`S.PH@("`@("`@('T*"B`@
M("`@("`@+RH@4D%$2553('1I;65O=70N("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1P87)A;7-;)W1I;65O=70G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG
M=&EM96]U="==(#T@,SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T
M(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R;F%M92`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@
M;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!&;W(@<F%D:75S+"!T:&ES(&UU<W0@8V]N=&%I;B!A('!A<W-W
M;W)D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;G1R>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T
M('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]A=71H96YT:6-A=&4H)'5S97)N86UE+"`D8W)E9&5N=&EA;',I"B`@
M("!["B`@("`@("`@+RH@4&%S<W=O<F0@:7,@<F5Q=6ER960N("HO"B`@("`@
M("`@:68@*"%I<W-E="@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"A?*")087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)')E<R`](')A9&EU<U]A=71H7V]P
M96XH*3L*("`@("`@("!R861I=7-?861D7W-E<G9E<B@D<F5S+"`D=&AI<RT^
M7W!A<F%M<ULG:&]S="==+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==+"`D=&AI
M<RT^7W!A<F%M<ULG<V5C<F5T)UTL("1T:&ES+3Y?<&%R86US6R=T:6UE;W5T
M)UTL("1T:&ES+3Y?<&%R86US6R=R971R:65S)UTI.PH@("`@("`@(')A9&EU
M<U]C<F5A=&5?<F5Q=65S="@D<F5S+"!2041)55-?04-#15-37U)%455%4U0I
M.PH@("`@("`@(')A9&EU<U]P=71?871T<B@D<F5S+"!2041)55-?3D%37TE$
M14Y4249)15(L("1T:&ES+3Y?<&%R86US6R=N87,G72D["B`@("`@("`@<F%D
M:75S7W!U=%]A='1R*"1R97,L(%)!1$E54U].05-?4$]25%]465!%+"!2041)
M55-?5DE25%5!3"D["B`@("`@("`@<F%D:75S7W!U=%]A='1R*"1R97,L(%)!
M1$E54U]315)624-%7U194$4L(%)!1$E54U]&4D%-140I.PH@("`@("`@(')A
M9&EU<U]P=71?871T<B@D<F5S+"!2041)55-?1E)!345$7U!23U1/0T],+"!2
M041)55-?4%!0*3L*("`@("`@("!R861I=7-?<'5T7V%T='(H)')E<RP@4D%$
M25537T-!3$Q)3D=?4U1!5$E/3E])1"P@:7-S970H)%]315)615);)U)%34]4
M15](3U-4)UTI(#\@)%]315)615);)U)%34]415](3U-4)UT@.B`G,3(W+C`N
M,"XQ)RD["@H@("`@("`@("\J($EN<V5R="!U<V5R;F%M92]P87-S=V]R9"!I
M;G1O(')E<75E<W0N("HO"B`@("`@("`@<F%D:75S7W!U=%]A='1R*"1R97,L
M(%)!1$E54U]54T527TY!344L("1U<V5R;F%M92D["B`@("`@("`@<F%D:75S
M7W!U=%]A='1R*"1R97,L(%)!1$E54U]54T527U!!4U-73U)$+"`D8W)E9&5N
M=&EA;'-;)W!A<W-W;W)D)UTI.PH*("`@("`@("`O*B!396YD(')E<75E<W0N
M("HO"B`@("`@("`@)'-U8V-E<W,@/2!R861I=7-?<V5N9%]R97%U97-T*"1R
M97,I.PH*("`@("`@("!S=VET8V@@*"1S=6-C97-S*2!["B`@("`@("`@8V%S
M92!2041)55-?04-#15-37T%#0T505#H*("`@("`@("`@("`@<F5T=7)N('1R
M=64["@H@("`@("`@(&-A<V4@4D%$25537T%#0T534U]214I%0U0Z"B`@("`@
M("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!
M1T4L(%\H(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N(BDI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?
M4D5!4T].7TU%4U-!1T4L(')A9&EU<U]S=')E<G)O<B@D<F5S*2D["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V%P
M<&QI8V%T:6]N+G!H<```````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30T
M-3``,3`U,34T,S$P-C$`,#(R,3,U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]A<'!L
M:6-A=&EO;B!C;&%S<R!P<F]V:61E<R!A('=R87!P97(@87)O=6YD"B`J(&%P
M<&QI8V%T:6]N+7!R;W9I9&5D($AO<F1E(&%U=&AE;G1I8V%T:6]N('=H:6-H
M(&9I=',@:6YS:61E('1H90H@*B!(;W)D92!!=71H.CH@05!)+@H@*@H@*B!2
M97%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V%P<"<@(%1H92!A<'!L
M:6-A=&EO;B!W:&EC:"!I<R!P<F]V:61I;F<@875T:&5N=&EC871I;VXN/"]P
M<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]A<'!L
M:6-A=&EO;BYP:'`L=B`Q+C(W+C$P+C$R(#(P,#8O,#@O,30@,#(Z-#@Z-#@@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@
M*B\*8VQA<W,@075T:%]A<'!L:6-A=&EO;B!E>'1E;F1S($%U=&@@>PH*("`@
M("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T
M('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N
M<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S
M(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D
M)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($%P<&QI8V%T:6]N
M(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P
M87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V%P<&QI8V%T
M:6]N*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<V5T4&%R86US*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@475E
M<FEE<R!T:&4@8W5R<F5N="!!=71H(&]B:F5C="!T;R!F:6YD(&]U="!I9B!I
M="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A<&%B:6QI='DN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET>2`@5&AE(&-A<&%B
M:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P86)I;&ET>2!I<R!S=7!P;W)T
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH)&-A<&%B
M:6QI='DI"B`@("!["B`@("`@("`@<W1A=&EC("1L;V%D960@/2!A<G)A>2@I
M.PH*("`@("`@("`D;65T:&]D<R`](&%R<F%Y*"=L:7-T)R`]/B`G=7-E<DQI
M<W0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V%D9"<@/3X@)V%D9%5S
M97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@/3X@)W5P
M9&%T955S97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@
M/3X@)W)E;6]V955S97(G*3L*"B`@("`@("`@:68@*&5M<'1Y*"1L;V%D961;
M)&-A<&%B:6QI='E=*2`F)B!I<W-E="@D;65T:&]D<ULD8V%P86)I;&ET>5TI
M*2!["B`@("`@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;)&-A<&%B:6QI
M='E=(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FAA<TUE=&AO9"@D;65T:&]D
M<ULD8V%P86)I;&ET>5TL("1T:&ES+3Y?<&%R86US6R=A<'`G72D["B`@("`@
M("`@("`@("1L;V%D961;)&-A<&%B:6QI='E=(#T@=')U93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M/F-A<&%B:6QI=&EE<ULD
M8V%P86)I;&ET>5TI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@
M2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D<&%R86US+"`G875T:"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G87!P)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G875T:&5N=&EC
M871I;VX@87!P;&EC871I;VXG*3L*"B`@("`@("`@:68@*&5M<'1Y*"1'3$]"
M04Q36R=R96=I<W1R>2==+3YA<'!L:6-A=&EO;G-;)'!A<F%M<ULG87!P)UU=
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'!A<F%M<ULG87!P)UT@
M+B`G(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XG
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@
M8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@
M8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED
M+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"$D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^:&%S365T:&]D*"=A=71H96YT:6-A=&4G+"`D=&AI<RT^
M7W!A<F%M<ULG87!P)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@D
M=&AI<RT^7W!A<F%M<ULG87!P)UT@+B`G(&1O97,@;F]T('!R;W9I9&4@86X@
M875T:&5N=&EC871E*"D@;65T:&]D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^8V%L;$)Y4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG87!P)UTL("=A=71H
M96YT:6-A=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G=7-E<DED)R`]/B`D=7-E<DED+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8W)E9&5N=&EA;',G(#T^("1C<F5D96YT:6%L<RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!A<F%M<R<@/3X@)'1H:7,M/E]P87)A;7,I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@55))(&]F('1H92!L;V=I;B!S
M8W)E96X@9F]R('1H:7,@875T:&5N=&EC871I;VX@;65T:&]D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T:6]N('1O('5S92X*("`@("`J($!P
M87)A;2!S=')I;F<@)'5R;"`@5&AE(%523"!T;R!R961I<F5C="!T;R!A9G1E
M<B!L;V=I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QO
M9VEN('-C<F5E;B!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971,;V=I
M;E-C<F5E;B@D87!P(#T@)VAO<F1E)RP@)'5R;"`]("<G*0H@("`@>PH@("`@
M("`@(')E='5R;B!P87)E;G0Z.E]G971,;V=I;E-C<F5E;B@D=&AI<RT^7W!A
M<F%M<ULG87!P)UTL("1U<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES
M="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M:7-T57-E<G,H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S0V%P86)I
M;&ET>2@G;&ES="<I*2!["B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^8V%L;$)Y4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG87!P
M)UTL("=U<V5R3&ES="<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=U;G-U<'!O<G1E9"<I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A=71H
M96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@("`J
M($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T
M;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA
M;',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=A
M9&0G*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F-A;&Q">5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G861D
M57-E<B<L(&%R<F%Y*"1U<V5R260L("1C<F5D96YT:6%L<RDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=U;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%5P9&%T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@("`@("!4
M:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TE$("`@
M("`@(%1H92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D
M96YT:6%L<R`@5&AE(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T
M955S97(H)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH)W5P9&%T92<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;$)Y
M4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG87!P)UTL("=U<&1A=&55<V5R)RP@
M87)R87DH)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=U;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H92!U
M<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))
M9"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH)W)E
M;6]V92<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^8V%L;$)Y4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG87!P)UTL
M("=R96UO=F55<V5R)RP@87)R87DH)'5S97))9"DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=U;G-U
M<'!O<G1E9"<I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F55<V5R
M1&%T82@D=7-E<DED*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O:4-A;&5N9&%R+P``````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`R,#$P,0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=FYO=&4N<&AP````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-C(`,3`U,34T,S$P-C$`
M,#(Q-S0V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G
M.PH*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!V3F]T97,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L96YD87(O=FYO=&4N<&AP
M+'8@,2XS+C$P+C4@,C`P-B\P,R\P,R`P.3HP-SHS,2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M2V%R<W1E;B!&;W5R;6]N="`\9F]U<FUO;G1`9VUX+F1E/@H@*B!`<&%C:V%G
M92!(;W)D95]I0V%L96YD87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V
M;F]T92!E>'1E;F1S($AO<F1E7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@
M2&]R9&5?:4-A;&5N9&%R7W9N;W1E*"1V97)S:6]N(#T@)S$N,2<I"B`@("![
M"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ2&]R9&5?:4-A;&5N9&%R*"1V97)S
M:6]N*3L*("`@('T*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@
M("`@("!R971U<FX@)W9.;W1E)SL*("`@('T*"B`@("!F=6YC=&EO;B!P87)S
M979#86QE;F1A<B@D9&%T82D*("`@('L*("`@("`@("!R971U<FX@<&%R96YT
M.CIP87)S979#86QE;F1A<B@D9&%T82P@)U9.3U1%)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!5;FQI:V4@=F5V96YT(&%N9"!V=&]D;RP@82!V;F]T92!I
M<R!N;W)M86QL>2!N;W0@96YC;&]S960@:6X@86X*("`@("`J(&E#86QE;F1A
M<B!C;VYT86EN97(N("A"14=)3BXN14Y$*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@("1R97%U:7)E9$%T
M=')I8G5T97-;)T)/1%DG72`]("<G.PH@("`@("`@("1R97%U:7)E9$%T=')I
M8G5T97-;)U9%4E-)3TXG72`]("<Q+C$G.PH*("`@("`@("!F;W)E86-H("@D
M<F5Q=6ER961!='1R:6)U=&5S(&%S("1N86UE(#T^("1D969A=6QT7W9A;'5E
M*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3YG971A='1R:6)U=&4H
M)&YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T071T<FEB=71E*"1N86UE+"`D9&5F875L=%]V86QU92D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V5X
M<&]R='9$871A*"=63D]412<I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+VE#86QE;F1A<B]V:F]U<FYA;"YP:'``````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,30Q,0`Q,#4Q-30S,3`V,0`P,C(T-#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($-L87-S
M(')E<')E<V5N=&EN9R!V2F]U<FYA;',N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+VE#86QE;F1A<B]I0V%L96YD87(O=FIO=7)N86PN<&AP+'8@,2XX+C$P
M+C0@,C`P-B\P,2\P,2`R,3HR.#HT-R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@
M2&]R9&5?:4-A;&5N9&%R7W9J;W5R;F%L(&5X=&5N9',@2&]R9&5?:4-A;&5N
M9&%R('L*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R
M971U<FX@)W9*;W5R;F%L)SL*("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#
M86QE;F1A<B@D9&%T82D*("`@('L*("`@("`@("!P87)E;G0Z.G!A<G-E=D-A
M;&5N9&%R*"1D871A+"`G5DI/55).04PG*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E
M;G0Z.E]E>'!O<G1V1&%T82@G5DI/55).04PG*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+VE#86QE;F1A<B]V=&]D;RYP:'``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-#4R,0`Q,#4Q-30S,3`V,0`P,C$W-#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M($-L87-S(')E<')E<V5N=&EN9R!V5&]D;W,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+VE#86QE;F1A<B]I0V%L96YD87(O=G1O9&\N<&AP+'8@,2XQ,RXQ
M,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z-#<@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO"F-L87-S
M($AO<F1E7VE#86QE;F1A<E]V=&]D;R!E>'1E;F1S($AO<F1E7VE#86QE;F1A
M<B!["@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("=V5&]D;R<["B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD
M87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT.CIP87)S979#86QE;F1A
M<B@D9&%T82P@)U943T1/)RD["B`@("!]"@H@("`@9G5N8W1I;VX@97AP;W)T
M=D-A;&5N9&%R*"D*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CI?97AP
M;W)T=D1A=&$H)U943T1/)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV
M97)T('1H:7,@=&]D;R!T;R!A;B!A<G)A>2!O9B!A='1R:6)U=&5S+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&-O;G1A:6YI;F<@=&AE
M(&1E=&%I;',@;V8@=&AE('1O9&\@:6X@82!H87-H"B`@("`@*B`@("`@("`@
M("`@("`@("!A<R!U<V5D(&)Y($AO<F1E(&%P<&QI8V%T:6]N<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@=&]!<G)A>2@I"B`@("!["B`@("`@("`@)'1O9&\@
M/2!A<G)A>2@I.PH*("`@("`@("`D;F%M92`]("1T:&ES+3YG971!='1R:6)U
M=&4H)U-534U!4EDG*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1N86UE*2`F
M)B`A:7-?82@D;F%M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D
M=&]D;ULG;F%M92==(#T@)&YA;64["B`@("`@("`@?0H@("`@("`@("1D97-C
M(#T@)'1H:7,M/F=E=$%T=')I8G5T92@G1$530U))4%1)3TXG*3L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1D97-C*2`F)B`A:7-?82@D9&5S8RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`D=&]D;ULG9&5S8R==(#T@)&1E<V,[
M"B`@("`@("`@?0H*("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^9V5T071T
M<FEB=71E*"=04DE/4DE462<I.PH@("`@("`@(&EF("@A:7-?87)R87DH)'!R
M:6]R:71Y*2`F)B`A:7-?82@D<')I;W)I='DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)'1O9&];)W!R:6]R:71Y)UT@/2`D<')I;W)I='D["B`@
M("`@("`@?0H*("`@("`@("`D9'5E(#T@)'1H:7,M/F=E=$%T=')I8G5T92@G
M1%135$%-4"<I.PH@("`@("`@(&EF("@A:7-?87)R87DH)&1U92D@)B8@(6ES
M7V$H)&1U92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&]D;ULG
M9'5E)UT@/2`D9'5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T;V1O
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!A='1R:6)U=&5S(&9O
M<B!T:&ES('1O9&\@:71E;2!F<F]M(&%N(&%R<F%Y+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D=&]D;R`@07)R87D@8V]N=&%I;FEN9R!T:&4@9&5T
M86EL<R!O9B!T:&4@=&]D;R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("!T:&4@<V%M92!F;W)M870@=&AA="!T;T%R<F%Y*"D@97AP;W)T<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9G)O;4%R<F%Y*"1T;V1O*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&]D;ULG;F%M92==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5T071T<FEB=71E*"=354U-05)9)RP@)'1O9&];)VYA;64G72D[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&]D;ULG9&5S8R==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"=$15-#4DE05$E/
M3B<L("1T;V1O6R=D97-C)UTI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1T;V1O6R=P<FEO<FET>2==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5T071T<FEB=71E*"=04DE/4DE462<L("1T;V1O6R=P<FEO<FET>2==*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&]D;ULG9'5E)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)T144U1!35`G+"`D
M=&]D;ULG9'5E)UTI.PH@("`@("`@('T*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V979E;G0N<&AP````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#(U-``Q,#4Q-30S,3`V,0`P,C(Q
M,C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!V179E;G1S+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]I0V%L96YD87(O:4-A;&5N9&%R+W9E=F5N
M="YP:'`L=B`Q+C,Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HT-R!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE
M;F1A<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W9E=F5N="!E>'1E;F1S
M($AO<F1E7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("=V179E;G0G.PH@("`@?0H*("`@(&9U;F-T
M:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@('!A<F5N
M=#HZ<&%R<V5V0V%L96YD87(H)&1A=&$L("=6159%3E0G*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@("\O
M($1E9F%U;'0@=F%L=65S+@H@("`@("`@("1R97%U:7)E9$%T=')I8G5T97,@
M/2!A<G)A>2@I.PH@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T144U1!
M35`G72`]('1I;64H*3L*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=/
M4D=!3DE:15(G72`]("=5;FMN;W=N($]R9V%N:7IE<B<["B`@("`@("`@)')E
M<75I<F5D071T<FEB=71E<ULG54E$)UT@/2`D=&AI<RT^7V5X<&]R=$1A=&54
M:6UE*'1I;64H*2D@+B`G0"<@+B`H:7-S970H)%]315)615);)U-%4E9%4E].
M04U%)UTI(#\@)%]315)615);)U-%4E9%4E].04U%)UT@.B`G;&]C86QH;W-T
M)RD["@H@("`@("`@("1M971H;V0@/2`A96UP='DH)'1H:7,M/E]C;VYT86EN
M97(I(#\*("`@("`@("`@("`@)'1H:7,M/E]C;VYT86EN97(M/F=E=$%T=')I
M8G5T92@G34542$]$)RD@.B`G4%5"3$E32"<["@H@("`@("`@('-W:71C:"`H
M)&UE=&AO9"D@>PH@("`@("`@(&-A<V4@)U!50DQ)4T@G.@H@("`@("`@("`@
M("`D<F5Q=6ER961!='1R:6)U=&5S6R=$5%-405)4)UT@/2!T:6UE*"D["B`@
M("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)U-534U!4EDG72`]("<G
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G4D5154535"<Z
M"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T%45$5.1$5%)UT@
M/2`G)SL*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG1%135$%2
M5"==(#T@=&EM92@I.PH@("`@("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S
M6R=354U-05)9)UT@/2`G)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)U)%4$Q9)SH*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E
M<ULG051414Y$144G72`]("<G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G041$)SH*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E
M<ULG1%135$%25"==(#T@=&EM92@I.PH@("`@("`@("`@("`D<F5Q=6ER961!
M='1R:6)U=&5S6R=315%514Y#12==(#T@,3L*("`@("`@("`@("`@)')E<75I
M<F5D071T<FEB=71E<ULG4U5-34%262==(#T@)R<["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=#04Y#14PG.@H@("`@("`@("`@("`D<F5Q
M=6ER961!='1R:6)U=&5S6R=!5%1%3D1%12==(#T@)R<["B`@("`@("`@("`@
M("1R97%U:7)E9$%T=')I8G5T97-;)U-%455%3D-%)UT@/2`Q.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G4D5&4D532"<Z"B`@("`@("`@
M("`@("1R97%U:7)E9$%T=')I8G5T97-;)T%45$5.1$5%)UT@/2`G)SL*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M<F5Q=6ER961!='1R:6)U=&5S(&%S("1N86UE(#T^("1D969A=6QT7W9A;'5E
M*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3YG971!='1R:6)U=&4H
M)&YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T071T<FEB=71E*"1N86UE+"`D9&5F875L=%]V86QU92D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!P87)E;G0Z.E]E
M>'!O<G1V1&%T82@G5D5614Y4)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5
M<&1A=&4@=&AE('-T871U<R!O9B!A;B!A='1E;F1E92!O9B!A;B!E=F5N="X*
M("`@("`J"B`@("`@*B!`<&%R86T@)&5M86EL("`@(%1H92!E;6%I;"!A9&1R
M97-S(&]F('1H92!A='1E;F1E92X*("`@("`J($!P87)A;2`D<W1A='5S("`@
M5&AE('!A<G1I8VEP86YT('-T871U<R!T;R!S970N"B`@("`@*B!`<&%R86T@
M)&9U;&QN86UE(%1H92!F=6QL(&YA;64@;V8@=&AE('!A<G1I8VEP86YT('1O
M('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E071T96YD964H)&5M
M86EL+"`D<W1A='5S+"`D9G5L;&YA;64@/2`G)RD*("`@('L*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ME>2`]/B`D871T<FEB
M=71E*2!["B`@("`@("`@("`@(&EF("@D871T<FEB=71E6R=N86UE)UT@/3T@
M)T%45$5.1$5%)R`F)B`D871T<FEB=71E6R=V86QU92==(#T]("=-04E,5$\Z
M)R`N("1E;6%I;"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U
M=&5S6R1K97E=6R=P87)A;7,G75LG4$%25%-4050G72`]("1S=&%T=7,["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1F=6QL;F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)W!A<F%M
M<R==6R=#3B==(#T@)&9U;&QN86UE.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@=6YS970H)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P
M87)A;7,G75LG4E-64"==*3L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<&%R86US(#T@87)R87DH
M)U!!4E135$%4)R`]/B`D<W1A='5S*3L*("`@("`@("!I9B`H(65M<'1Y*"1F
M=6QL;F%M92DI('L*("`@("`@("`@("`@)'!A<F%M<ULG0TXG72`]("1F=6QL
M;F%M93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G
M051414Y$144G+"`G34%)3%1/.B<@+B`D96UA:6PL("1P87)A;7,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!O<F=A;FEZ97(@9&ES<&QA
M>2!N86UE(&]R(&5M86EL+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;W)G86YI>F5R(&YA;64@=&\@9&ES<&QA>2!F;W(@=&AI<R!E=F5N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@;W)G86YI>F5R3F%M92@I"B`@("![
M"B`@("`@("`@)&]R9V%N:7IE<B`]("1T:&ES+3YG971!='1R:6)U=&4H)T]2
M1T%.25I%4B<L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1O<F=A;FEZ97(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]R9V%N:7IE<ELP75LG0TXG
M72DI('L*("`@("`@("`@("`@<F5T=7)N("1O<F=A;FEZ97);,%U;)T-.)UT[
M"B`@("`@("`@?0H*("`@("`@("`D;W)G86YI>F5R(#T@<&%R<V5?=7)L*"1T
M:&ES+3YG971!='1R:6)U=&4H)T]21T%.25I%4B<I*3L*"B`@("`@("`@<F5T
M=7)N("1O<F=A;FEZ97);)W!A=&@G73L*("`@('T*"B`@("`O*BH*("`@("`J
M(%5P9&%T92!T:&ES(&5V96YT('=I=&@@9&5T86EL<R!F<F]M(&%N;W1H97(@
M979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A<E]V
M179E;G0@)'9E=F5N="`@5&AE('9%=F5N="!W:71H(&QA=&5S="!D971A:6QS
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5&<F]M=D5V96YT*"1V979E
M;G0I"B`@("!["B`@("`@("`@)&YE=T%T=')I8G5T97,@/2`D=F5V96YT+3YG
M971!;&Q!='1R:6)U=&5S*"D["B`@("`@("`@9F]R96%C:"`H)&YE=T%T=')I
M8G5T97,@87,@)&YE=T%T=')I8G5T92D@>PH@("`@("`@("`@("`D8W5R<F5N
M=%9A;'5E(#T@)'1H:7,M/F=E=$%T=')I8G5T92@D;F5W071T<FEB=71E6R=N
M86UE)UTI.PH@("`@("`@("`@("!I9B`H:7-?82@D8W5R<F5N=%9A;'5E+"`G
M4$5!4E]E<G)O<B<I*2!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y(&5X
M:7-T<R!S;R!J=7-T(&%D9"!I="X*("`@("`@("`@("`@("`@("1T:&ES+3YS
M971!='1R:6)U=&4H)&YE=T%T=')I8G5T95LG;F%M92==+"`D;F5W071T<FEB
M=71E6R=V86QU92==+"`D;F5W071T<FEB=71E6R=P87)A;7,G72D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y(&5X
M:7-T<R!S;R!L;V-A=&4@86YD(&UO9&EF>2X*("`@("`@("`@("`@("`@("1F
M;W5N9"`](&9A;'-E.PH*("`@("`@("`@("`@("`@("\O(%1R>2!M871C:&EN
M9R!T:&4@871T<FEB=&4@;F%M92!A;F0@=F%L=64@:6YC87-E"B`@("`@("`@
M("`@("`@("`O+R!O;FQY('1H92!P87)A;7,@8VAA;F=E9"`H96<@871T96YD
M964@=7!D871I;F<*("`@("`@("`@("`@("`@("\O('-T871U<RDN"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ED
M(#T^("1A='1R*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1A='1R6R=N
M86UE)UT@/3T@)&YE=T%T=')I8G5T95LG;F%M92==("8F"B`@("`@("`@("`@
M("`@("`@("`@("`@("1A='1R6R=V86QU92==(#T]("1N97=!='1R:6)U=&5;
M)W9A;'5E)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@;65R9V4@
M=&AE('!A<F%M<PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M;F5W071T<FEB=71E6R=P87)A;7,G72!A<R`D<&%R86U?:60@/3X@)'!A<F%M
M7VYA;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M871T<FEB=71E<ULD:61=6R=P87)A;7,G75LD<&%R86U?:61=(#T@)'!A<F%M
M7VYA;64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@=')U93L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"$D9F]U;F0I('L*("`@("`@
M("`@("`@("`@("`@("`O+R!%;'-E(&UA=&-H('1H92!F:7)S="!A='1R:6)U
M=&4@=VET:"!T:&4@<V%M90H@("`@("`@("`@("`@("`@("`@("\O(&YA;64@
M*&5G(&-H86YG:6YG('-T87)T('1I;64I+@H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D:60@/3X@)&%T='(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1A='1R6R=N86UE)UT@
M/3T@)&YE=T%T=')I8G5T95LG;F%M92==*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;)&ED75LG=F%L=64G72`]
M("1N97=!='1R:6)U=&5;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!-97)G92!T:&4@<&%R86US+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&YE=T%T=')I8G5T95LG<&%R86US)UT@
M87,@)'!A<F%M7VED(#T^("1P87)A;5]N86UE*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1I9%U;)W!A
M<F%M<R==6R1P87)A;5]I9%T@/2`D<&%R86U?;F%M93L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@57!D871E(&IU<W0@=&AE
M(&%T=&5N9&5S<R!O9B!E=F5N="!W:71H(&1E=&%I;',@9G)O;2!A;F]T:&5R
M"B`@("`@*B!E=F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?:4-A
M;&5N9&%R7W9%=F5N="`D=F5V96YT("!4:&4@=D5V96YT('=I=&@@;&%T97-T
M(&1E=&%I;',*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E071T96YD965S
M1G)O;79%=F5N="@D=F5V96YT*0H@("`@>PH@("`@("`@("1N97=!='1R:6)U
M=&5S(#T@)'9E=F5N="T^9V5T06QL071T<FEB=71E<R@I.PH@("`@("`@(&9O
M<F5A8V@@*"1N97=!='1R:6)U=&5S(&%S("1N97=!='1R:6)U=&4I('L*("`@
M("`@("`@("`@:68@*"1N97=!='1R:6)U=&5;)VYA;64G72`A/2`G051414Y$
M144G*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D8W5R<F5N=%9A;'5E(#T@)'1H:7,M/F=E=$%T=')I
M8G5T92@D;F5W071T<FEB=71E6R=N86UE)UTI.PH@("`@("`@("`@("!I9B`H
M:7-?82@D8W5R<F5N=%9A;'5E+"`G4$5!4E]E<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`O+R!!;')E861Y(&5X:7-T<R!S;R!J=7-T(&%D9"!I="X*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)&YE=T%T=')I8G5T
M95LG;F%M92==+"`D;F5W071T<FEB=71E6R=V86QU92==+"`D;F5W071T<FEB
M=71E6R=P87)A;7,G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`O+R!!;')E861Y(&5X:7-T<R!S;R!L;V-A=&4@86YD(&UO9&EF
M>2X*("`@("`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@+R\@5')Y(&UA=&-H:6YG('1H92!A='1R:6)T92!N86UE(&%N9"!V
M86QU92!I;F-A<V4*("`@("`@("`@("`@("`@("\O(&]N;'D@=&AE('!A<F%M
M<R!C:&%N9V5D("AE9R!A='1E;F1E92!U<&1A=&EN9PH@("`@("`@("`@("`@
M("`@+R\@<W1A='5S*2X*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?871T<FEB=71E<R!A<R`D:60@/3X@)&%T='(I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&%T=');)VYA;64G72`]/2`D;F5W071T<FEB=71E6R=N
M86UE)UT@)B8*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=');)W9A;'5E
M)UT@/3T@)&YE=T%T=')I8G5T95LG=F%L=64G72D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!-97)G92!T:&4@<&%R86US+@H@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D;F5W071T<FEB=71E6R=P87)A;7,G72!A
M<R`D<&%R86U?:60@/3X@)'!A<F%M7VYA;64I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:61=6R=P87)A;7,G
M75LD<&%R86U?:61=(#T@)'!A<F%M7VYA;64["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("`@("`@+R\@16QS92!M
M871C:"!T:&4@9FER<W0@871T<FEB=71E('=I=&@@=&AE('-A;64*("`@("`@
M("`@("`@("`@("`@("`O+R!N86UE("AE9R!C:&%N9VEN9R!S=&%R="!T:6UE
M*2X*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I
M8G5T97,@87,@)&ED(#T^("1A='1R*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D871T<ELG;F%M92==(#T]("1N97=!='1R:6)U=&5;)VYA;64G
M72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R
M:6)U=&5S6R1I9%U;)W9A;'5E)UT@/2`D;F5W071T<FEB=71E6R=V86QU92==
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@365R9V4@=&AE('!A
M<F%M<RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1N
M97=!='1R:6)U=&5;)W!A<F%M<R==(&%S("1P87)A;5]I9"`]/B`D<&%R86U?
M;F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?871T<FEB=71E<ULD:61=6R=P87)A;7,G75LD<&%R86U?:61=(#T@)'!A
M<F%M7VYA;64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+VE#86QE;F1A<B]V=&EM97IO;F4N<&AP````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C<Q-P`Q,#4Q-30S,3`V,0`P,C(V,S8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J($-L87-S(')E<')E<V5N=&EN9R!V5&EM97IO;F5S+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]I0V%L96YD87(O:4-A;&5N9&%R+W9T:6UE>F]N92YP
M:'`L=B`Q+C@N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C0W(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R
M"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?=G1I;65Z;VYE(&5X=&5N9',@
M2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)W94:6UE6F]N92<["B`@("!]"@H@("`@9G5N
M8W1I;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R
M96YT.CIP87)S979#86QE;F1A<B@D9&%T82P@)U9424U%6D].12<I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@
M("`@<F5T=7)N('!A<F5N=#HZ7V5X<&]R='9$871A*"=65$E-15I/3D4G*3L*
M("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO
M"F-L87-S($AO<F1E7VE#86QE;F1A<E]S=&%N9&%R9"!E>'1E;F1S($AO<F1E
M7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("=S=&%N9&%R9"<["B`@("!]"@H@("`@9G5N8W1I;VX@
M<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT.CIP
M87)S979#86QE;F1A<B@D9&%T82P@)U-404Y$05)$)RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("!R971U
M<FX@<&%R96YT.CI?97AP;W)T=D1A=&$H)U-404Y$05)$)RD["B`@("!]"@I]
M"@HO*BH*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PIC;&%S<R!(
M;W)D95]I0V%L96YD87)?9&%Y;&EG:'0@97AT96YD<R!(;W)D95]I0V%L96YD
M87(@>PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`G9&%Y;&EG:'0G.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E=D-A
M;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<&%R<V5V0V%L
M96YD87(H)&1A=&$L("=$05E,24=(5"<I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@("`@<F5T=7)N('!A<F5N
M=#HZ7V5X<&]R='9$871A*"=$05E,24=(5"<I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9F
M<F5E8G5S>2YP:'``````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S-C0Q`#$P
M-3$U-#,Q,#8Q`#`R,C8R-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG
M('9&<F5E8G5S>2!C;VUP;VYE;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]I0V%L96YD87(O:4-A;&5N9&%R+W9F<F5E8G5S>2YP:'`L=B`Q+C$V+C$P
M+CD@,C`P-B\P,B\P-B`Q-SHU,SHS.2!M<G5B:6YS:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I
M9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PIC
M;&%S<R!(;W)D95]I0V%L96YD87)?=F9R965B=7-Y(&5X=&5N9',@2&]R9&5?
M:4-A;&5N9&%R('L*"B`@("!V87(@)%]B=7-Y4&5R:6]D<R`](&%R<F%Y*"D[
M"@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("=V1G)E96)U<WDG.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&$@
M<W1R:6YG(&-O;G1A:6YI;F<@=D9R965B=7-Y(&1A=&$N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@5&AE(&1A=&$@=&\@<&%R<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A=&$L("=6
M1E)%14)54UDG*3L*"B`@("`@("`@+R\@1&\@<V]M971H:6YG('=I=&@@86QL
M('1H92!B=7-Y('!E<FEO9',N"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A
M='1R:6)U=&5S(&%S("1K97D@/3X@)&%T=')I8G5T92D@>PH@("`@("`@("`@
M("!I9B`H)&%T=')I8G5T95LG;F%M92==(#T]("=&4D5%0E5362<I('L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5;)W9A;'5E<R==(&%S
M("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L
M=65;)V1U<F%T:6]N)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F%D9$)U<WE097)I;V0H)T)54UDG+"`D=F%L=65;)W-T87)T)UTL(&YU
M;&PL("1V86QU95LG9'5R871I;VXG72D["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D0G5S
M>5!E<FEO9"@G0E5362<L("1V86QU95LG<W1A<G0G72P@)'9A;'5E6R=E;F0G
M72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?8G5S>5!E<FEO9',@87,@)'-T87)T(#T^("1E;F0I('L*("`@("`@
M("`@("`@)'!E<FEO9',@/2!A<G)A>2AA<G)A>2@G<W1A<G0G(#T^("1S=&%R
M="P@)V5N9"<@/3X@)&5N9"DI.PH@("`@("`@("`@("`D=&AI<RT^<V5T071T
M<FEB=71E*"=&4D5%0E5362<L("1P97)I;V1S*3L*("`@("`@("!]"@H@("`@
M("`@("1R97,@/2!P87)E;G0Z.E]E>'!O<G1V1&%T82@G5D92145"55-9)RD[
M"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D:V5Y
M(#T^("1A='1R:6)U=&4I('L*("`@("`@("`@("`@:68@*"1A='1R:6)U=&5;
M)VYA;64G72`]/2`G1E)%14)54UDG*2!["B`@("`@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^7V%T=')I8G5T97-;)&ME>5TI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!D:7-P;&%Y(&YA;64@9F]R('1H:7,@;V)J96-T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&-L96%R('1E>'0@
M;F%M92!F;W(@9&ES<&QA>6EN9R!T:&ES(&]B:F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@)&YA;64@/2`G)SL*
M("`@("`@("`D;65T:&]D(#T@(65M<'1Y*"1T:&ES+3Y?8V]N=&%I;F5R*2`_
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N=&%I;F5R+3YG971!='1R:6)U=&4H
M)TU%5$A/1"<I(#H@)U!50DQ)4T@G.PH*("`@("`@("!I9B`H:7-?82@D;65T
M:&]D+"`G4$5!4E]%<G)O<B<I('Q\("1M971H;V0@/3T@)U!50DQ)4T@G*2![
M"B`@("`@("`@("`@("1A='1R(#T@)T]21T%.25I%4B<["B`@("`@("`@?2!E
M;'-E:68@*"1M971H;V0@/3T@)U)%4$Q9)RD@>PH@("`@("`@("`@("`D871T
M<B`]("=!5%1%3D1%12<["B`@("`@("`@?0H*("`@("`@("`D;F%M92`]("1T
M:&ES+3YG971!='1R:6)U=&4H)&%T='(L('1R=64I.PH@("`@("`@(&EF("AI
M<W-E="@D;F%M95LP75LG0TXG72DI('L*("`@("`@("`@("`@<F5T=7)N("1N
M86UE6S!=6R=#3B==.PH@("`@("`@('T*"B`@("`@("`@)&YA;64@/2`D=&AI
M<RT^9V5T071T<FEB=71E*"1A='1R*3L*("`@("`@("!I9B`H:7-?82@D;F%M
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA;64@/2!P87)S95]U<FPH
M)&YA;64I.PH@("`@("`@("`@("!R971U<FX@)&YA;65;)W!A=&@G73L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!E;6%I
M;"!A9&1R97-S(&9O<B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&5M86EL(&%D9')E<W,@;V8@=&AI<R!O8FIE8W0G
M<R!O=VYE<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T16UA:6PH*0H@("`@
M>PH@("`@("`@("1N86UE(#T@)R<["B`@("`@("`@)&UE=&AO9"`]("%E;7!T
M>2@D=&AI<RT^7V-O;G1A:6YE<BD*("`@("`@("`@("`@("`@("`@/R`D=&AI
M<RT^7V-O;G1A:6YE<BT^9V5T071T<FEB=71E*"=-151(3T0G*2`Z("=054),
M25-()SL*"B`@("`@("`@:68@*&ES7V$H)&UE=&AO9"P@)U!%05)?17)R;W(G
M*2!\?"`D;65T:&]D(#T]("=054),25-()RD@>PH@("`@("`@("`@("`D871T
M<B`]("=/4D=!3DE:15(G.PH@("`@("`@('T@96QS96EF("@D;65T:&]D(#T]
M("=215!,62<I('L*("`@("`@("`@("`@)&%T='(@/2`G051414Y$144G.PH@
M("`@("`@('T*"B`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T071T<FEB=71E
M*"1A='1R*3L*("`@("`@("!I9B`H:7-?82@D;F%M92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&YA;64@/2!P87)S95]U<FPH)&YA;64I.PH@("`@("`@
M("`@("!R971U<FX@)&YA;65;)W!A=&@G73L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T0G5S>5!E<FEO9',H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V)U<WE097)I;V1S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A;&P@=&AE(&9R964@<&5R:6]D<R!O9B!T:6UE(&EN(&$@
M9VEV96X@<&5R:6]D+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S
M=&%R=%-T86UP("!4:&4@<W1A<G0@=&EM97-T86UP+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&5N9%-T86UP("`@(%1H92!E;F0@=&EM97-T86UP+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!W:71H(&9R964@=&EM
M92!P97)I;V1S+"!T:&4@<W1A<G0@=&EM97,@87,@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("!K97ES(&%N9"!T:&4@96YD('1I;65S(&%S('1H92!V86QU
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9R965097)I;V1S*"1S=&%R
M=%-T86UP+"`D96YD4W1A;7`I"B`@("!["B`@("`@("`@)'1H:7,M/G-I;7!L
M:69Y*"D["B`@("`@("`@)'!E<FEO9',@/2!A<G)A>2@I.PH*("`@("`@("`O
M+R!#:&5C:R!T:&%T('=E(&AA=F4@9&%T82!F;W(@<V]M92!P87)T(&]F('1H
M:7,@<&5R:6]D+@H@("`@("`@(&EF("@D=&AI<RT^9V5T16YD*"D@/"`D<W1A
M<G13=&%M<"!\?"`D=&AI<RT^9V5T4W1A<G0H*2`^("1E;F13=&%M<"D@>PH@
M("`@("`@("`@("!R971U<FX@)'!E<FEO9',["B`@("`@("`@?0H*("`@("`@
M("`O+R!,;V-A=&4@=&AE(&9I<G-T('1I;64@:6X@=&AE(')E<75E<W1E9"!P
M97)I;V0@=V4@:&%V92!D871A(&9O<BX*("`@("`@("`D;F5X='-T87)T(#T@
M;6%X*"1S=&%R=%-T86UP+"`D=&AI<RT^9V5T4W1A<G0H*2D["@H@("`@("`@
M("\O($-H96-K(&5A8V@@8G5S>2!P97)I;V0@86YD(&%D9"!F<F5E('!E<FEO
M9',@:6X@8F5T=V5E;BX*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V)U<WE0
M97)I;V1S(&%S("1S=&%R="`]/B`D96YD*2!["B`@("`@("`@("`@(&EF("@D
M<W1A<G0@/#T@)&5N9%-T86UP("8F("1E;F0@/CT@)&YE>'1S=&%R="D@>PH@
M("`@("`@("`@("`@("`@:68@*"1N97AT<W1A<G0@/#T@)'-T87)T*2!["B`@
M("`@("`@("`@("`@("`@("`@)'!E<FEO9'-;)&YE>'1S=&%R=%T@/2!M:6XH
M)'-T87)T+"`D96YD4W1A;7`I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&YE>'1S=&%R="`](&UI;B@D96YD+"`D96YD4W1A;7`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!)9B!W92!D:61N
M)W0@<F5A9"!T:&4@96YD(&]F('1H92!R97%U97-T960@<&5R:6]D(&)U="!S
M=&EL;"!H879E"B`@("`@("`@+R\@9&%T82!T:&5N(&UA<FL@87,@9G)E92!T
M;R!T:&4@96YD(&]F('1H92!P97)I;V0@;W(@879A:6QA8FQE(&1A=&$N"B`@
M("`@("`@:68@*"1N97AT<W1A<G0@/"`D96YD4W1A;7`@)B8@)&YE>'1S=&%R
M="`\("1T:&ES+3YG971%;F0H*2D@>PH@("`@("`@("`@("`D<&5R:6]D<ULD
M;F5X='-T87)T72`](&UI;B@D=&AI<RT^9V5T16YD*"DL("1E;F13=&%M<"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!E<FEO9',["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&1S(&$@8G5S>2!P97)I;V0@=&\@=&AE(&EN9F\N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@("`@("!4:&4@
M='EP92!O9B!T:&4@<&5R:6]D+B!%:71H97(@)T92144G(&]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("="55-9)SL@;VYL>2`G0E5362<@
M<W5P<&]R=&5D(&%T('1H92!M;VUE;G0N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<W1A<G0@("`@(%1H92!S=&%R="!T:6UE<W1A;7`@;V8@=&AE('!E<FEO
M9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1E;F0@("`@("`@5&AE(&5N9"!T
M:6UE<W1A;7`@;V8@=&AE('!E<FEO9"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1D=7)A=&EO;B`@5&AE(&1U<F%T:6]N(&]F('1H92!P97)I;V0N($EF('-P
M96-I9FEE9"P@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E;F0@<&%R86UE=&5R('=I;&P@8F4@:6=N;W)E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D0G5S>5!E<FEO9"@D='EP92P@)'-T87)T+"`D96YD(#T@
M;G5L;"P@)&1U<F%T:6]N(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)'1Y
M<&4@/3T@)T92144G*2!["B`@("`@("`@("`@("\O($UA:V4@<W5R92!T:&ES
M('!E<FEO9"!I<R!N;W0@;6%R:V5D(&%S(&)U<WDN"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O($-A;&-U;&%T92!T
M:&4@96YD('1I;64@:68@9'5R871I;VX@=V%S('-P96-I9FEE9"X*("`@("`@
M("`D=&5M<$5N9"`](&ES7VYU;&PH)&1U<F%T:6]N*2`_("1E;F0@.B`D<W1A
M<G0@*R`D9'5R871I;VX["@H@("`@("`@("\O($UA:V4@<W5R92!T:&4@<&5R
M:6]D(&QE;F=T:"!I<R!A;'=A>7,@<&]S:71I=F4N"B`@("`@("`@)&5N9"`]
M(&UA>"@D<W1A<G0L("1T96UP16YD*3L*("`@("`@("`D<W1A<G0@/2!M:6XH
M)'-T87)T+"`D=&5M<$5N9"D["@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V)U<WE097)I;V1S6R1S=&%R=%TI*2!["B`@("`@("`@("`@("\O($%L<F5A
M9'D@82!P97)I;V0@<W1A<G1I;F<@870@=&AI<R!T:6UE+B!%>'1E;F0@=&\@
M=&AE(&QE;F=T:"!O9@H@("`@("`@("`@("`O+R!T:&4@;&]N9V5S="!O9B!T
M:&4@='=O+@H@("`@("`@("`@("`D=&AI<RT^7V)U<WE097)I;V1S6R1S=&%R
M=%T@/2!M87@H)&5N9"P@)'1H:7,M/E]B=7-Y4&5R:6]D<ULD<W1A<G1=*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!!9&0@82!N97<@8G5S
M>2!P97)I;V0N"B`@("`@("`@("`@("1T:&ES+3Y?8G5S>5!E<FEO9'-;)'-T
M87)T72`]("1E;F0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1I;65S=&%M<"!O
M9B!T:&4@<W1A<G0@;V8@=&AE('1I;64@<&5R:6]D('1H:7,@9G)E92!B=7-Y
M"B`@("`@*B!I;F9O<FUA=&EO;B!C;W9E<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!!('1I;65S=&%M<"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4W1A<G0H*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D=&AI<RT^
M9V5T071T<FEB=71E*"=$5%-405)4)RDL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YG971!='1R:6)U=&4H)T144U1!4E0G
M*3L*("`@("`@("!](&5L<V5I9B`H8V]U;G0H)'1H:7,M/E]B=7-Y4&5R:6]D
M<RDI('L*("`@("`@("`@("`@<F5T=7)N(&UI;BAA<G)A>5]K97ES*"1T:&ES
M+3Y?8G5S>5!E<FEO9',I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=&EM97-T86UP(&]F('1H92!E;F0@;V8@=&AE('1I
M;64@<&5R:6]D('1H:7,@9G)E92!B=7-Y"B`@("`@*B!I;F9O<FUA=&EO;B!C
M;W9E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!!('1I;65S
M=&%M<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T16YD*"D*("`@('L*("`@
M("`@("!I9B`H(6ES7V$H)'1H:7,M/F=E=$%T=')I8G5T92@G1%1%3D0G*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E
M=$%T=')I8G5T92@G1%1%3D0G*3L*("`@("`@("!](&5L<V5I9B`H8V]U;G0H
M)'1H:7,M/E]B=7-Y4&5R:6]D<RDI('L*("`@("`@("`@("`@<F5T=7)N(&UA
M>"AA<G)A>5]V86QU97,H)'1H:7,M/E]B=7-Y4&5R:6]D<RDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-97)G97,@=&AE(&)U<WD@<&5R:6]D
M<R!O9B!A;F]T:&5R($AO<F1E7VE#86QE;F1A<E]V9G)E96)U<WD@;V)J96-T
M(&EN=&\*("`@("`J('1H:7,@;VYE+@H@("`@("H*("`@("`J($!P87)A;2!(
M;W)D95]I0V%L96YD87)?=F9R965B=7-Y("1F<F5E8G5S>2`@02!F<F5E8G5S
M>2!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<VEM<&QI9GD@("`@
M("`@("`@("`@("`@("`@($EF('1R=64L('-I;7!L:69Y*"D@=VEL;`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C86QL960@869T97(@=&AE(&UE<F=E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!M97)G92@D9G)E96)U<WDL("1S:6UP;&EF>2`]('1R=64I"B`@("!["B`@
M("`@("`@:68@*"%I<U]A*"1F<F5E8G5S>2P@)TAO<F1E7VE#86QE;F1A<E]V
M9G)E96)U<WDG*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D9G)E96)U<WDM/F=E=$)U<WE097)I
M;V1S*"D@87,@)'-T87)T(#T^("1E;F0I('L*("`@("`@("`@("`@)'1H:7,M
M/F%D9$)U<WE097)I;V0H)T)54UDG+"`D<W1A<G0L("1E;F0I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7-A='1R(#T@)'1H:7,M/F=E=$%T=')I8G5T92@G
M1%135$%25"<I.PH@("`@("`@("1T:&%T871T<B`]("1F<F5E8G5S>2T^9V5T
M071T<FEB=71E*"=$5%-405)4)RD["B`@("`@("`@:68@*&ES7V$H)'1H:7-A
M='1R+"`G4$5!4E]%<G)O<B<I("8F("%I<U]A*"1T:&%T871T<BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"=$
M5%-405)4)RP@)'1H871A='1R*3L*("`@("`@("!](&5L<V5I9B`H(6ES7V$H
M)'1H871A='1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(&EF("@D
M=&AA=&%T='(@/B`D=&AI<V%T='(I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971!='1R:6)U=&4H)T144U1!4E0G+"`D=&AA=&%T='(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<V%T='(@/2`D=&AI<RT^
M9V5T071T<FEB=71E*"=$5$5.1"<I.PH@("`@("`@("1T:&%T871T<B`]("1F
M<F5E8G5S>2T^9V5T071T<FEB=71E*"=$5$5.1"<I.PH@("`@("`@(&EF("AI
M<U]A*"1T:&ES871T<BP@)U!%05)?17)R;W(G*2`F)B`A:7-?82@D=&AA=&%T
M='(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T
M=')I8G5T92@G1%1%3D0G+"`D=&AA=&%T='(I.PH@("`@("`@('T@96QS96EF
M("@A:7-?82@D=&AA=&%T='(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@:68@*"1T:&%T871T<B`\("1T:&ES871T<BD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$%T=')I8G5T92@G1%1%3D0G+"`D=&AA=&%T='(I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'-I;7!L:69Y
M*2!["B`@("`@("`@("`@("1T:&ES+3YS:6UP;&EF>2@I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96UO=F5S(&%L;"!O=F5R;&%P<R!A;F0@<VEM<&QI9FEE<R!T:&4@8G5S>2!P
M97)I;V1S(&%R<F%Y(&%S(&UU8V@@87,*("`@("`J('!O<W-I8FQE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S:6UP;&EF>2@I"B`@("!["B`@("`@("`@)&-H
M96-K960@/2!A<G)A>2@I.PH@("`@("`@("1C:&5C:V5D16UP='D@/2!T<G5E
M.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V)U<WE097)I;V1S(&%S("1S
M=&%R="`]/B`D96YD*2!["B`@("`@("`@("`@(&EF("@D8VAE8VME9$5M<'1Y
M*2!["B`@("`@("`@("`@("`@("`D8VAE8VME9%LD<W1A<G1=(#T@)&5N9#L*
M("`@("`@("`@("`@("`@("1C:&5C:V5D16UP='D@/2!F86QS93L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1A9&1E9"`](&9A;'-E
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&-H96-K960@87,@)'1E<W13
M=&%R="`]/B`D=&5S=$5N9"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M<W1A<G0@/3T@)'1E<W13=&%R="D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D8VAE8VME9%LD=&5S=%-T87)T72`](&UA>"@D=&5S=$5N9"P@)&5N9"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A9&1E9"`]('1R=64["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1E;F0@/#T@)'1E<W1%;F0@)B8@
M)&5N9"`^/2`D=&5S=%-T87)T*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1C:&5C:V5D6R1T97-T4W1A<G1=*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-H96-K961;;6EN*"1T97-T4W1A<G0L("1S=&%R="E=(#T@
M;6%X*"1T97-T16YD+"`D96YD*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&%D9&5D(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1A9&1E9"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(21A9&1E9"D@>PH@("`@("`@
M("`@("`@("`@("`@("1C:&5C:V5D6R1S=&%R=%T@/2`D96YD.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!K
M<V]R="@D8VAE8VME9"P@4T]25%].54U%4DE#*3L*("`@("`@("`D=&AI<RT^
M7V)U<WE097)I;V1S(#T@)&-H96-K960["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9A;&%R
M;2YP:'``````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S<U`#$P-3$U
M-#,Q,#8Q`#`R,C`W-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG('9!
M;&%R;7,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L
M96YD87(O=F%L87)M+G!H<"QV(#$N."XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z
M-#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]I0V%L96YD87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V86QA
M<FT@97AT96YD<R!(;W)D95]I0V%L96YD87(@>PH*("`@(&9U;F-T:6]N(&=E
M=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=D%L87)M)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@('L*("`@
M("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G5D%,05)-)RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*
M("`@("`@("!R971U<FX@<&%R96YT.CI?97AP;W)T=D1A=&$H)U9!3$%232<I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R
M+W9C87)D+G!H<```````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,C0R
M`#$P-3$U-#,Q,#8Q`#`R,3<Q,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]I
M0V%L96YD87(N<&AP)SL*"B\O(%1H92!F;VQL;W=I;F<@=V5R92!S:&%M96QE
M<W-L>2!Y;VEN:V5D(&9R;VT@0V]N=&%C=%]68V%R9%]"=6EL9`HO+R!087)T
M(&YU;6)E<G,@9F]R($X@8V]M<&]N96YT<RX*9&5F:6YE*"=60T%21%].7T9!
M34E,62<L("`@("`P*3L*9&5F:6YE*"=60T%21%].7T=)5D5.)RP@("`@("`Q
M*3L*9&5F:6YE*"=60T%21%].7T%$1$PG+"`@("`@("`R*3L*9&5F:6YE*"=6
M0T%21%].7U!2149)6"<L("`@("`S*3L*9&5F:6YE*"=60T%21%].7U-51D9)
M6"<L("`@("`T*3L*"B\O(%!A<G0@;G5M8F5R<R!F;W(@0412(&-O;7!O;F5N
M=',N"F1E9FEN92@G5D-!4D1?04127U!/0B<L("`@("`@,"D["F1E9FEN92@G
M5D-!4D1?04127T585$5.1"<L("`@,2D["F1E9FEN92@G5D-!4D1?04127U-4
M4D5%5"<L("`@,BD["F1E9FEN92@G5D-!4D1?04127TQ/0T%,2519)RP@,RD[
M"F1E9FEN92@G5D-!4D1?04127U)%1TE/3B<L("`@-"D["F1E9FEN92@G5D-!
M4D1?04127U!/4U1#3T1%)RP@-2D["F1E9FEN92@G5D-!4D1?04127T-/54Y4
M4EDG+"`@-BD["@HO+R!087)T(&YU;6)E<G,@9F]R($=%3R!C;VUP;VYE;G1S
M+@ID969I;F4H)U9#05)$7T=%3U],050G+"`@("`@(#`I.PID969I;F4H)U9#
M05)$7T=%3U],3TXG+"`@("`@(#$I.PH*+RHJ"B`J($-L87-S(')E<')E<V5N
M=&EN9R!V0V%R9"!E;G1R:65S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]I
M0V%L96YD87(O:4-A;&5N9&%R+W9C87)D+G!H<"QV(#$N,RXQ,"XX(#(P,#8O
M,#4O,#D@,C,Z,#@Z,C(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!+87)S=&5N($9O=7)M;VYT("AK87)S=&5N0&AO<F1E+F]R9RD*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD
M87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V8V%R9"!E>'1E;F1S($AO
M<F1E7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@2&]R9&5?:4-A;&5N9&%R
M7W9C87)D*"1V97)S:6]N(#T@)S(N,2<I"B`@("!["B`@("`@("`@<F5T=7)N
M('!A<F5N=#HZ2&]R9&5?:4-A;&5N9&%R*"1V97)S:6]N*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W9C
M87)D)SL*("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T
M82D*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CIP87)S979#86QE;F1A
M<B@D9&%T82P@)W9C87)D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;FQI
M:V4@=F5V96YT(&%N9"!V=&]D;RP@82!V8V%R9"!I<R!N;W)M86QL>2!N;W0@
M96YC;&]S960@:6X@86X*("`@("`J(&E#86QE;F1A<B!C;VYT86EN97(N("A"
M14=)3BXN14Y$*0H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD
M87(H*0H@("`@>PH@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T)/1%DG
M72`]("<G.PH@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)U9%4E-)3TXG
M72`]("<R+C$G.PH*("`@("`@("!F;W)E86-H("@D<F5Q=6ER961!='1R:6)U
M=&5S(&%S("1N86UE(#T^("1D969A=6QT7W9A;'5E*2!["B`@("`@("`@("`@
M(&EF("AI<U]A*"1T:&ES+3YG971!='1R:6)U=&4H)&YA;64I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E
M*"1N86UE+"`D9&5F875L=%]V86QU92D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V5X<&]R='9$871A*"=60T%2
M1"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N
M=',@;V8@=&AE(").(B!T86<@87,@82!P<FEN=&%B;&4@3F%M93H*("`@("`J
M(&DN92X@8V]N=F5R=',Z"B`@("`@*@H@("`@("H@("!..D1U8VL[1&%G;V)E
M<G0[5#M0<F]F97-S;W([4V5N+@H@("`@("H@=&\*("`@("`J("`@(E!R;V9E
M<W-O<B!$86=O8F5R="!4($1U8VL@4V5N(@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!&=6QL(&YA;64@;V8@=F-A<F0@(DXB('1A9PH@("`@("H@
M("`@("`@("`@("`@("`@(&]R(&YU;&P@:68@;F\@3B!T86<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!R:6YT86)L94YA;64H*0H@("`@>PH@("`@("`@("1N
M86UE7W!A<G1S(#T@)'1H:7,M/F=E=$%T=')I8G5T959A;'5E<R@G3B<I.PH@
M("`@("`@(&EF("AI<U]A*"1N86UE7W!A<G1S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D;F%M95]P87)T<UM60T%21%].7U!2149)6%TI*2!["B`@
M("`@("`@("`@("1N86UE7V%R<EM=(#T@)&YA;65?<&%R='-;5D-!4D1?3E]0
M4D5&25A=.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1N86UE7W!A
M<G1S6U9#05)$7TY?1TE614Y=*2D@>PH@("`@("`@("`@("`D;F%M95]A<G);
M72`]("1N86UE7W!A<G1S6U9#05)$7TY?1TE614Y=.PH@("`@("`@('T*("`@
M("`@("!I9B`H(65M<'1Y*"1N86UE7W!A<G1S6U9#05)$7TY?041$3%TI*2![
M"B`@("`@("`@("`@("1N86UE7V%R<EM=(#T@)&YA;65?<&%R='-;5D-!4D1?
M3E]!1$1,73L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D;F%M95]P
M87)T<UM60T%21%].7T9!34E,65TI*2!["B`@("`@("`@("`@("1N86UE7V%R
M<EM=(#T@)&YA;65?<&%R='-;5D-!4D1?3E]&04U)3%E=.PH@("`@("`@('T*
M("`@("`@("!I9B`H(65M<'1Y*"1N86UE7W!A<G1S6U9#05)$7TY?4U5&1DE8
M72DI('L*("`@("`@("`@("`@)&YA;65?87)R6UT@/2`D;F%M95]P87)T<UM6
M0T%21%].7U-51D9)6%T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:6UP
M;&]D92@G("<L("1N86UE7V%R<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M=&%T:6,@9G5N8W1I;VX@=&\@;6%K92!A(&=I=F5N(&5M86EL(&%D9')E<W,@
M<F9C.#(R(&-O;7!L:6%N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A9&1R97-S("!!;B!E;6%I;"!A9&1R97-S+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@4D9#.#(R+69O<FUA='1E9"!E;6%I;"!A9&1R
M97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"87)E16UA:6PH)&%D9')E
M<W,I"B`@("!["B`@("`@("`@+R\@16UP='D@=F%L=65S(&%R92!S=&EL;"!E
M;7!T>2X*("`@("`@("!I9B`H(21A9&1R97-S*2!["B`@("`@("`@("`@(')E
M='5R;B`D861D<F5S<SL*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC
M92`G36%I;"]21D,X,C(N<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TU)344N<&AP)SL*"B`@("`@("`@<W1A=&EC("1R9F,X,C(["B`@("`@
M("`@:68@*&ES7VYU;&PH)')F8S@R,BDI('L*("`@("`@("`@("`@)')F8S@R
M,B`](&YE=R!-86EL7U)&0S@R,B@I.PH@("`@("`@('T*"B`@("`@("`@)')F
M8S@R,BT^=F%L:61A=&5-86EL8F]X*"1A9&1R97-S*3L*("`@("`@("!R971U
M<FX@34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S*"1A9&1R97-S+3YM86EL8F]X
M+"`D861D<F5S<RT^:&]S="D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O54DO````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C4S-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]687)296YD97)E<B\`````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P
M-C$`,#(P-S4S`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#(P,34V-0`Q,#4Q-30S,3`V,0`P,C(T,S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D
M95]525]687)296YD97)E<E]H=&UL.CH@8VQA<W,@<F5N9&5R<R!V87)I86)L
M97,@=&\@2%1-3"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`L=B`Q+CDX+C(N,C@@,C`P-B\P."\Q-B`Q,CHQ
M-SHR,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O
M;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y312!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN"B`J"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ"B`J
M($!P86-K86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525]687)296YD
M97)E<E]H=&UL(&5X=&5N9',@2&]R9&5?54E?5F%R4F5N9&5R97(@>PH*("`@
M('9A<B`D7V]N3&]A9$I3(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R26YP=71$969A=6QT*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@
M('L*("`@("`@("!R971U<FX@)SQS=')O;F<^5V%R;FEN9SH\+W-T<F]N9SX@
M56YK;F]W;B!V87)I86)L92!T>7!E("<@+@H@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG9714>7!E3F%M92@I+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]N=6UB97(H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@("1V86QU92`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@
M("!I9B`H:7-S970H)'9A<BT^='EP92T^7V9R86-T:6]N*2D@>PH@("`@("`@
M("`@("`D=F%L=64@/2!S<')I;G1F*"<E,#$N)R`N("1V87(M/G1Y<&4M/E]F
M<F%C=&EO;B`N("=F)RP@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@)&QI
M;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O*"D["B`@("`@("`@+RH@3VYL>2!I
M9B!T:&5R92!I<R!A(&UO;E]D96-I;6%L7W!O:6YT(&1O('1H90H@("`@("`@
M("`J('-U8G-T:71U=&EO;BX@*B\*("`@("`@("!I9B`H(65M<'1Y*"1L:6YF
M;ULG;6]N7V1E8VEM86Q?<&]I;G0G72DI('L*("`@("`@("`@("`@)'9A;'5E
M(#T@<W1R7W)E<&QA8V4H)RXG+"`D;&EN9F];)VUO;E]D96-I;6%L7W!O:6YT
M)UTL("1V86QU92D["B`@("`@("`@?0H@("`@("`@("1V87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\
M:6YP=70@='EP93TB=&5X="(@<VEZ93TB-2(@;F%M93TB)7,B(&ED/2(E<R(@
M=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@("`@
M("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]I;G0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M
M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E
M='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@<VEZ93TB-2(@;F%M
M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC
M:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES
M+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]O8W1A;"@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@
M/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(U(B!N86UE/2(E<R(@:60]
M(B5S(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H)S`E;R<L(&]C=&1E8R@D
M=F%R+3YG971686QU92@D=F%R<RDI*2P*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I"B`@("`@
M("`@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN
M<'5T7VEN=&QI<W0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@
M("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R
M3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M93TB)7,B
M(&ED/2(E<R(@=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I
M;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]T97AT*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D;6%X;&5N9W1H(#T@)'9A
M<BT^='EP92T^9V5T36%X3&5N9W1H*"D["B`@("`@("`@)'9A<FYA;64@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H
M)SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<R(@:60](B5S(B!S:7IE/2(E
M<R(@=F%L=64](B5S(B`E<R5S)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/F=E=%-I>F4H
M*2P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^:7-$:7-A8FQE
M9"@I(#\@)R!D:7-A8FQE9#TB9&ES86)L960B("<@.B`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("!E;7!T>2@D;6%X;&5N9W1H*2`_("<G(#H@)R!M87AL
M96YG=&@](B<@+B`D;6%X;&5N9W1H("X@)R(G+`H@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BD*
M("`@("`@("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R26YP=71?=V5A=&AE<F1O=&-O;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R5F%R26YP=71?
M=&5X="@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)687));G!U=%]S=')I;F=L:7-T*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H
M87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4]
M(G1E>'0B('-I>F4](C8P(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B
M)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S
M*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V
M87(I"B`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<DEN<'5T7V-E;&QP:&]N92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT
M(B!N86UE/2(E<R(@:60](B5S(B!S:7IE/2(Q-2(@=F%L=64](B5S(B`E<R5S
M("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<BT^:7-$:7-A8FQE9"@I(#\@)R!D:7-A8FQE9#TB9&ES
M86)L960B("<@.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I"B`@("`@("`@("`@("`@
M("D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VEP861D
M<F5S<R@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A
M<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N
M('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<R(@:60](B5S
M(B!S:7IE/2(Q-B(@=F%L=64](B5S(B`E<R5S("\^)RP*("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC
M:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES
M+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^:7-$
M:7-A8FQE9"@I(#\@)R!D:7-A8FQE9#TB9&ES86)L960B("<@.B`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H
M)&9O<FTL("1V87(I"B`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V9I;&4H)B1F;W)M+"`F)'9A<BP@)B1V
M87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA
M<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB
M9FEL92(@<VEZ93TB,S`B(&YA;64](B5S(B!I9#TB)7,B)7,@+SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0'1O9&\@4VAO=R!I;6%G92!D:6UE;G-I;VYS(&EN('1H
M92!W:61T:"]H96EG:'0@8F]X97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R
M96YD97)687));G!U=%]I;6%G92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@
M("!["B`@("`@("`@)'9A<FYA;64@/2!H=&UL<W!E8VEA;&-H87)S*"1V87(M
M/F=E=%9A<DYA;64H*2D["B`@("`@("`@)&EM86=E(#T@)'9A<BT^9V5T5F%L
M=64H)'9A<G,I.PH*("`@("`@("`O*B!#:&5C:R!I9B!E>&ES=&EN9R!I;6%G
M92!D871A(&ES(&)E:6YG(&QO861E9"X@*B\*("`@("`@("`D=F%R+3YT>7!E
M+3Y?;&]A9$EM86=E1&%T82@D:6UA9V4I.PH*("`@("`@("!(;W)D93HZ861D
M4V-R:7!T1FEL92@G:6UA9V4N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@
M("`D9W)A<&AI8W-?9&ER(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM
M86=E1&ER*"=H;W)D92<I.PH@("`@("`@("1I;6=?9&ER(#T@)&=R87!H:6-S
M7V1I<B`N("<O:6UA9V4G.PH*("`@("`@("`D:'1M;"`]("<G.PH*("`@("`@
M("`O*B!#:&5C:R!I9B!T:&5R92!I<R!E>&ES=&EN9R!I;6<@:6YF;W)M871I
M;VX@<W1O<F5D+B`J+PH@("`@("`@(&EF("AI<W-E="@D:6UA9V5;)VEM9R==
M*2D@>PH@("`@("`@("`@("`O*B!(:61D96X@=&%G('1O('-T;W)E('1H92!P
M<F5V:65W(&EM86=E(&9I;&5N86UE+B`J+PH@("`@("`@("`@("`D:'1M;"`]
M('-P<FEN=&8H)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B5S(B!I9#TB
M)7,B('9A;'5E/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A<FYA;64@+B`G6VEM9UTG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64@+B`G6VEM9UTG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)&EM86=E6R=I;6<G72P@14Y4
M7U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@("`@("`@("`@("\J(%5N
M<V5R:6%L:7IE('1H92!I;6<@:6YF;W)M871I;VX@=&\@9V5T('1H92!F=6QL
M(&%R<F%Y+B`J+PH@("`@("`@("`@("`D:6UA9V5;)VEM9R==(#T@0'5N<V5R
M:6%L:7IE*"1I;6%G95LG:6UG)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M3W5T<'5T('1H92!I;G!U="!T86<N("HO"B`@("`@("`@:68@*&5M<'1Y*"1I
M;6%G95LG:6UG)UTI*2!["B`@("`@("`@("`@("1J<R`](")V87(@<"`](&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"<B("X@)'9A<FYA;64@+B`B6W!R979I
M97==)RD[(&\@/2`G7%Q<7"<[(&$@/2`G+R<[('1M<"`]("<G("L@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H)R(@+B`D=F%R;F%M92`N(");;F5W72<I+G9A
M;'5E.R!I9B`H=&UP*2![('=H:6QE("AT;7`N:6YD97A/9BAO*2`^("TQ*2![
M('!O<R`]('1M<"YI;F1E>$]F*&\I.R!T;7`@/2`G)R`K("AT;7`N<W5B<W1R
M:6YG*#`L('!O<RD@*R!A("L@=&UP+G-U8G-T<FEN9R@H<&]S("L@;RYL96YG
M=&@I+"!T;7`N;&5N9W1H*2D[?3L@<"YS<F,@/2`G9FEL93HO+R\G("L@=&UP
M.R!P+F%L="`]("<B("X@861D<VQA<VAE<RA?*"))9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB*2D@
M+B`B)SL@?3LB.PH@("`@("`@("`@("`D8G)O=W-E<B`]("9"<F]W<V5R.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`@("`@:68@*"1B<F]W<V5R+3YI<T)R;W=S
M97(H)VUS:64G*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT
M9B@G/&EN<'5T('1Y<&4](F9I;&4B('-I>F4](C,P(B!N86UE/2(E<R(@:60]
M(B5S(B!O;F-H86YG93TB)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64@+B`G6VYE=UTG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;;F5W72<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1J<RD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\
M:6YP=70@='EP93TB9FEL92(@<VEZ93TB,S`B(&YA;64](B5S(B!I9#TB)7,B
M(&]N8VQI8VL](G=I;F1O=RYS9714:6UE;W5T*%PG9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H7%Q<)R5S7%Q<)RDN8FQU<B@I.UPG+"`U*3LB(&]N8FQU<CTB
M)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64@+B`G6VYE=UTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92`N("=;;F5W72<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V87)N86UE("X@)UMN97==)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&IS*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQI
M;G!U="!T>7!E/2)F:6QE(B!S:7IE/2(S,"(@;F%M93TB)7,B(&ED/2(E<R(@
M+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE("X@
M)UMN97==)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M
M92`N("=;;F5W72<I.PH@("`@("`@('T*"B`@("`@("`@+RH@3W5T<'5T('1H
M92!B=71T;VX@=&\@=7!L;V%D+W)E<V5T('1H92!I;6%G92X@*B\*("`@("`@
M("!I9B`H)'9A<BT^='EP92T^7W-H;W=?=7!L;V%D*2!["B`@("`@("`@("`@
M("1H=&UL("X]("<F;F)S<#LG.PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I
M;G1F*"<\:6YP=70@8VQA<W,](F)U='1O;B(@;F%M93TB)7,B(&ED/2(E<R(@
M='EP93TB<W5B;6ET(B!V86QU93TB)7,B("\^("<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U]D;U\G("X@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U]D;U\G("X@)'9A<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7R@B57!L;V%D(BDI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1I;6%G95LG:6UG)UTI*2!["B`@("`@("`@
M("`@("\J($YO(&EM86=E(&EN9F]R;6%T:6]N('-T;W)E9"!Y970L('-H;W<@
M82!B;&%N:R!P<F5V:65W+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D
M93HZ:6UG*"=T<F5E+V)L86YK+G!N9R<L(%\H(E!R979I97<B*2P@)W=I9'1H
M/2(U,"(@:&5I9VAT/2(T,"(@:60](B<@+B`D=F%R;F%M92`N("=;<')E=FEE
M=UTB)RP@)&=R87!H:6-S7V1I<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+RH@26UA9V4@:6YF;W)M871I;VX@<W1O<F5D+"!S:&]W('!R979I
M97<L(&%D9"!B=71T;VYS(&9O<B!I;6%G90H@("`@("`@("`@("`@*B!M86YI
M<'5L871I;VXN("HO"B`@("`@("`@("`@("1H=&UL("X]("<\8G(@+SXG.PH@
M("`@("`@("`@("`D:6UG(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VEM
M86=E<R]V:65W+G!H<"<I.PH@("`@("`@("`@("!I9B`H:7-S970H)&EM86=E
M6R=I;6<G75LG=F9S7VED)UTI*2!["B`@("`@("`@("`@("`@("`O*B!#86QL
M:6YG(&%N(&EM86=E(&9R;VT@5D93+B`J+PH@("`@("`@("`@("`@("`@)&EM
M9R`](%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"!A<G)A>2@G9B<@/3X@)&EM
M86=E6R=I;6<G75LG=F9S7VED)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S)R`]/B`G=F9S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W`G(#T^("1I;6%G95LG:6UG)UU;)W9F<U]P871H)UTI*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($-A;&QI
M;F<@86X@:6UA9V4@9G)O;2!A('1M<"!D:7)E8W1O<GD@*'5P;&]A9',I+B`J
M+PH@("`@("`@("`@("`@("`@)&EM9R`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M:6UG+"`G9B<L("1I;6%G95LG:6UG)UU;)V9I;&4G72D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J(%)E<V5T+B`J+PH@("`@("`@("`@("`D:'1M
M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(E)E<V5T(BDL("<G+"`G)RP@)W-H
M;W=);6%G92A<)R<@+B`D:6UG("X@)UPG+"!<)U]P7R<@+B`D=F%R;F%M92`N
M("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=R969R97-H+G!N9R<L(%\H
M(E)E<V5T(BDL("=A;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER*2`N("<\+V$^
M)SL*"B`@("`@("`@("`@("\J(%)O=&%T92`R-S`N("HO"B`@("`@("`@("`@
M("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B4F]T871E($QE9G0B*2P@
M)R<L("<G+"`G<VAO=TEM86=E*%PG)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D
M:6UG+"!A<G)A>2@G82<@/3X@)W)O=&%T92<L("=V)R`]/B`G,C<P)RDI("X@
M)UPG+"!<)U]P7R<@+B`D=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D
M93HZ:6UG*"=R;W1A=&4M,C<P+G!N9R<L(%\H(E)O=&%T92!,969T(BDL("=A
M;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER*2`N("<\+V$^)SL*"B`@("`@("`@
M("`@("\J(%)O=&%T92`Q.#`N("HO"B`@("`@("`@("`@("1H=&UL("X]($AO
M<F1E.CIL:6YK*"<C)RP@7R@B4F]T871E(#$X,"(I+"`G)RP@)R<L("=S:&]W
M26UA9V4H7"<G("X@571I;#HZ861D4&%R86UE=&5R*"1I;6<L(&%R<F%Y*"=A
M)R`]/B`G<F]T871E)RP@)W8G(#T^("<Q.#`G*2D@+B`G7"<L(%PG7W!?)R`N
M("1V87)N86UE("X@)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H)W)O=&%T
M92TQ.#`N<&YG)RP@7R@B4F]T871E(#$X,"(I+"`G86QI9VX](FUI9&1L92(G
M+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O*B!2;W1A=&4@
M.3`N("HO"B`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@
M7R@B4F]T871E(%)I9VAT(BDL("<G+"`G)RP@)W-H;W=);6%G92A<)R<@+B!5
M=&EL.CIA9&1087)A;65T97(H)&EM9RP@87)R87DH)V$G(#T^("=R;W1A=&4G
M+"`G=B<@/3X@)SDP)RDI("X@)UPG+"!<)U]P7R<@+B`D=F%R;F%M92`N("=<
M)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=R;W1A=&4M.3`N<&YG)RP@7R@B
M4F]T871E(%)I9VAT(BDL("=A;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER*2`N
M("<\+V$^)SL*"B`@("`@("`@("`@("\J($9L:7`@:6UA9V4N("HO"B`@("`@
M("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B1FQI<"(I+"`G
M)RP@)R<L("=S:&]W26UA9V4H7"<G("X@571I;#HZ861D4&%R86UE=&5R*"1I
M;6<L("=A)RP@)V9L:7`G*2`N("=<)RP@7"=?<%\G("X@)'9A<FYA;64@+B`G
M7"<L('1R=64I.R<I("X@2&]R9&4Z.FEM9R@G9FQI<"YP;F<G+"!?*")&;&EP
M(BDL("=A;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER*2`N("<\+V$^)SL*"B`@
M("`@("`@("`@("\J($UI<G)O<B!I;6%G92X@*B\*("`@("`@("`@("`@)&AT
M;6P@+CT@2&]R9&4Z.FQI;FLH)R,G+"!?*")-:7)R;W(B*2P@)R<L("<G+"`G
M<VAO=TEM86=E*%PG)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"`G82<L
M("=M:7)R;W(G*2`N("=<)RP@7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L('1R
M=64I.R<I("X@2&]R9&4Z.FEM9R@G;6ER<F]R+G!N9R<L(%\H(DUI<G)O<B(I
M+"`G86QI9VX](FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@
M("`@("`@("`O*B!!<'!L>2!G<F%Y<V-A;&4N("HO"B`@("`@("`@("`@("1H
M=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B1W)A>7-C86QE(BDL("<G+"`G
M)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@
M)V$G+"`G9W)A>7-C86QE)RD@+B`G7"<L(%PG7W!?)R`N("1V87)N86UE("X@
M)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H)V=R87ES8V%L92YP;F<G+"!?
M*")'<F%Y<V-A;&4B*2P@)V%L:6=N/2)M:61D;&4B)RP@)&EM9U]D:7(I("X@
M)SPO83XG.PH*("`@("`@("`@("`@+RH@4F5S:7IE('=I9'1H+B`J+PH@("`@
M("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<E<SQI;G!U="!T>7!E/2)T97AT
M(B!S:7IE/2(T(B!O;F-H86YG93TB<W)C/6=E=%)E<VEZ95-R8RA<)R5S7"<L
M(%PG)7-<)RD[<VAO=TEM86=E*'-R8RP@7"=?<%\E<UPG+"!T<G5E*3LB("5S
M("\^)RP*("`@("`@("`@("`@("`@("`@(%\H(G<Z(BDL"B`@("`@("`@("`@
M("`@("`@("!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@)V$G+"`G<F5S:7IE
M)RDL"B`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M96Y)1"@G7W=?)R`N("1V87)N86UE*2D["@H@("`@("`@("`@("`O*B!297-I
M>F4@:&5I9VAT+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<E
M<SQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(T(B!O;F-H86YG93TB<W)C/6=E
M=%)E<VEZ95-R8RA<)R5S7"<L(%PG)7-<)RD[<VAO=TEM86=E*'-R8RP@7"=?
M<%\E<UPG+"!T<G5E*3LB("5S("\^)RP*("`@("`@("`@("`@("`@("`@(%\H
M(F@Z(BDL"B`@("`@("`@("`@("`@("`@("!5=&EL.CIA9&1087)A;65T97(H
M)&EM9RP@)V$G+"`G<F5S:7IE)RDL"B`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G96Y)1"@G7VA?)R`N("1V87)N86UE*2D["@H@
M("`@("`@("`@("`O*B!!<'!L>2!F:7AE9"!R871I;R!R97-I>F4N("HO"B`@
M("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B1FEX(')A
M=&EO(BDL("<G+"`G)RP@)W-R8SUG971297-I>F53<F,H7"<G("X@571I;#HZ
M861D4&%R86UE=&5R*"1I;6<L("=A)RP@)W)E<VEZ92<I("X@)UPG+"!<)R<@
M+B`D=F%R;F%M92`N("=<)RP@7"<Q7"<I.W-H;W=);6%G92AS<F,L(%PG7W!?
M)R`N("1V87)N86UE("X@)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H)W)A
M=&EO+G!N9R<L(%\H(D9I>"!R871I;R(I+"`G86QI9VX](FUI9&1L92(G+"`D
M:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O*B!+965P(&%L<V\@
M;W)I9VEN86P@:68@:70@:&%S(&)E96X@<F5Q=65S=&5D+B`J+PH@("`@("`@
M("`@("!I9B`H)'9A<BT^='EP92T^7W-H;W=?:V5E<&]R:6<I('L*("`@("`@
M("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N86UE/2(E<R(@:60](B5S(B5S("\^
M)7,G("X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64@+B`G6VME97!?;W)I9UTG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92`N("=;:V5E<%]O<FEG72<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("%E;7!T>2@D:6UA9V5;)VME
M97!?;W)I9R==*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%\H(DME97`@;W)I9VEN86P_
M(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!4:&4@<')E=FEE
M=R!I;6%G92!E;&5M96YT+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2`G/&)R
M("\^/&EM9R!S<F,](B<@+B`D:6UG("X@)R(@)R`N("1T:&ES+3Y?9V5N240H
M)U]P7R<@+B`D=F%R;F%M92D@+B`B/EQN(CL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M26YP=71?;&]N9W1E>'0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8G)O=W-E<CL*"B`@("`@("`@)'9A<FYA;64@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@)&AT;6P@/2!S<')I;G1F
M*"<\=&5X=&%R96$@:60](B5S(B!N86UE/2(E<R(@8V]L<STB)7,B(')O=W,]
M(B5S(B5S)7,^)7,\+W1E>'1A<F5A/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD=F%R+3YT>7!E+3YG
M971#;VQS*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("AI;G0I)'9A<BT^
M='EP92T^9V5T4F]W<R@I+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R+3YI<T1I<V%B;&5D*"D@/R`G(&1I<V%B;&5D
M/2)D:7-A8FQE9"(G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["@H@("`@("`@(&EF("@D=F%R+3YT
M>7!E+3YH87-(96QP97(H)W)T92<I("8F("1B<F]W<V5R+3YH87-&96%T=7)E
M*"=R=&4G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T5D
M:71O<BYP:'`G.PH@("`@("`@("`@("`D961I=&]R(#T@)DAO<F1E7T5D:71O
M<CHZ<VEN9VQE=&]N*"=H=&UL87)E82<L(&%R<F%Y*"=I9"<@/3X@)'9A<FYA
M;64I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=F%R+3YT>7!E+3YH87-(
M96QP97(H*2`F)B`D8G)O=W-E<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I
M*2!["B`@("`@("`@("`@("1H=&UL("X]("<\8G(@+SX\=&%B;&4@8V5L;'-P
M86-I;F<](C`B/CQT<CX\=&0^)SL*("`@("`@("`@("`@2&]R9&4Z.F%D9%-C
M<FEP=$9I;&4H)V]P96Y?:'1M;%]H96QP97(N:G,G+"`G:&]R9&4G*3L*("`@
M("`@("`@("`@)&EM9TED(#T@)'1H:7,M/E]G96Y)1"@D=F%R+3YG971687).
M86UE*"DL(&9A;'-E*2`N("=E:&5L<&5R)SL*("`@("`@("`@("`@:68@*"1V
M87(M/G1Y<&4M/FAA<TAE;'!E<B@G96UO=&EC;VYS)RDI('L*("`@("`@("`@
M("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B16UO=&EC;VYS
M(BDL("<G+"`G)RP@)V]P96Y(=&UL2&5L<&5R*%PG96UO=&EC;VYS7"<L(%PG
M)R`N("1V87(M/F=E=%9A<DYA;64H*2`N("=<)RD[(')E='5R;B!F86QS93LG
M*2`N($AO<F1E.CII;6<H)W-M:6QE+G!N9R<L(%\H(D5M;W1I8V]N<R(I+"`G
M:60](B<@+B`D:6UG260@+B`G(B!A;&EG;CTB;6ED9&QE(B<L("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`N("<O96UO=&EC
M;VYS)RD@+B`G/"]A/B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT
M;6P@+CT@)SPO=&0^/"]T<CX\='(^/'1D/CQD:78@)R`N("1T:&ES+3Y?9V5N
M240H)VAT;6QH96QP97)?)R`N("1V87(M/F=E=%9A<DYA;64H*2D@+B`G(&-L
M87-S/2)C;VYT<F]L(CX\+V1I=CX\+W1D/CPO='(^/"]T86)L93XG("X@(EQN
M(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?8V]U;G1E9'1E>'0H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\
M=&5X=&%R96$@;F%M93TB)7,B(&ED/2(E<R(@8V]L<STB)7,B(')O=W,](B5S
M(B5S)7,^)7,\+W1E>'1A<F5A/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@*&EN="DD=F%R+3YT>7!E+3YG971#;VQS
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD=F%R+3YT>7!E+3YG
M9712;W=S*"DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!
M8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R+3YI<T1I<V%B;&5D*"D@/R`G(&1I<V%B;&5D/2)D:7-A8FQE
M9"(G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L
M8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M26YP=71?861D<F5S<R@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG9716
M87).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@
M("`@<F5T=7)N('-P<FEN=&8H)SQT97AT87)E82!N86UE/2(E<R(@:60](B5S
M(B!C;VQS/2(E<R(@<F]W<STB)7,B)7,E<SXE<SPO=&5X=&%R96$^)RP*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`H:6YT
M*21V87(M/G1Y<&4M/F=E=$-O;',H*2P*("`@("`@("`@("`@("`@("`@("`@
M("`H:6YT*21V87(M/G1Y<&4M/F=E=%)O=W,H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/FES1&ES86)L960H*2`_
M("<@9&ES86)L960](F1I<V%B;&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@
M("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R
M<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)687));G!U=%]D871E*"8D9F]R;2P@)B1V87(L
M("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA
M;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M
M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]T:6UE*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G
M/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C4B(&YA;64](B5S(B!I9#TB)7,B
M('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@
M("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T
M5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T
M<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]H;W5R;6EN=71E<V5C;VYD*"8D9F]R;2P@)B1V87(L("8D=F%R
M<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S
M*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*3L*("`@("`@("`D=&EM92`]("1V87(M/G1Y<&4M/F=E=%1I;65087)T
M<R@D=F%R+3YG971686QU92@D=F%R<RDI.PH*("`@("`@("`O*B!/=71P=70@
M:&]U<G,N("HO"B`@("`@("`@)&AO=7)S(#T@87)R87DH)R<@/3X@7R@B:&@B
M*2D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P](#(S.R`D:2LK*2!["B`@
M("`@("`@("`@("1H;W5R<ULD:5T@/2`D:3L*("`@("`@("!]"B`@("`@("`@
M)&AT;6P@/2!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S6VAO=7)=(B!I9#TB
M)7-;:&]U<ETB)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N
M4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D:&]U<G,L("@D=&EM95LG:&]U<B==
M(#T]/2`G)RD@/R`G)R`Z("1T:6UE6R=H;W5R)UTI*3L*"B`@("`@("`@+RH@
M3W5T<'5T(&UI;G5T97,N("HO"B`@("`@("`@)&UI;G5T97,@/2!A<G)A>2@G
M)R`]/B!?*")M;2(I*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/#T@-3D[
M("1I*RLI('L*("`@("`@("`@("`@)&T@/2!S<')I;G1F*"<E,#)D)RP@)&DI
M.PH@("`@("`@("`@("`D;6EN=71E<ULD;5T@/2`D;3L*("`@("`@("!]"B`@
M("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'-E;&5C="!N86UE/2(E<UMM:6YU
M=&5=(B!I9#TB)7-;;6EN=71E72(E<SXE<SPO<V5L96-T/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D;6EN=71E
M<RP@*"1T:6UE6R=M:6YU=&4G72`]/3T@)R<I(#\@)R<@.B!S<')I;G1F*"<E
M,#)D)RP@)'1I;65;)VUI;G5T92==*2DI.PH*("`@("`@("`O*B!2971U<FX@
M:68@<V5C;VYD<R!A<F4@;F]T(')E<75I<F5D+B`J+PH@("`@("`@(&EF("@A
M)'9A<BT^='EP92T^7W-H;W=?<V5C;VYD<RD@>PH@("`@("`@("`@("!R971U
M<FX@)&AT;6P["B`@("`@("`@?0H*("`@("`@("`O*B!/=71P=70@<V5C;VYD
M<RX@*B\*("`@("`@("`D<V5C;VYD<R`](&%R<F%Y*"<G(#T^(%\H(G-S(BDI
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\/2`U.3L@)&DK*RD@>PH@("`@
M("`@("`@("`D<V5C;VYD<ULD:5T@/2!S<')I;G1F*"<E,#)D)RP@)&DI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&AT;6P@+B!S<')I;G1F*"<\<V5L
M96-T(&YA;64](B5S6W-E8V]N9%TB(&ED/2(E<UMS96-O;F1=(B5S/B5S/"]S
M96QE8W0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C
M=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1S96-O;F1S+"`H
M)'1I;65;)W-E8V]N9"==(#T]/2`G)RD@/R`G)R`Z('-P<FEN=&8H)R4P,F0G
M+"`D=&EM95LG<V5C;VYD)UTI*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<DEN<'5T7VUO;G1H>65A<B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@)&1A=&5S(#T@87)R87DH*3L*("`@("`@("`D9&%T
M97-;)VUO;G1H)UT@/2!A<G)A>2@G)R`]/B!?*")-32(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#$@/3X@7R@B2F%N=6%R>2(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#(@/3X@7R@B1F5B<G5A<GDB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`S(#T^(%\H(DUA
M<F-H(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@-"`]/B!?
M*")!<')I;"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#4@
M/3X@7R@B36%Y(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M-B`]/B!?*")*=6YE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@-R`]/B!?*")*=6QY(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@."`]/B!?*")!=6=U<W0B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Y(#T^(%\H(E-E<'1E;6)E<B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#$P(#T^(%\H(D]C=&]B97(B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q,2`]/B!?*").;W9E;6)E<B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$R(#T^(%\H(D1E
M8V5M8F5R(BDI.PH@("`@("`@("1D871E<ULG>65A<B==(#T@87)R87DH)R<@
M/3X@7R@B65E962(I*3L*("`@("`@("!I9B`H)'9A<BT^='EP92T^7W-T87)T
M7WEE87(@/B`D=F%R+3YT>7!E+3Y?96YD7WEE87(I('L*("`@("`@("`@("`@
M9F]R("@D:2`]("1V87(M/G1Y<&4M/E]S=&%R=%]Y96%R.R`D:2`^/2`D=F%R
M+3YT>7!E+3Y?96YD7WEE87([("1I+2TI('L*("`@("`@("`@("`@("`@("1D
M871E<ULG>65A<B==6R1I72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`]("1V87(M/G1Y<&4M/E]S
M=&%R=%]Y96%R.R`D:2`\/2`D=F%R+3YT>7!E+3Y?96YD7WEE87([("1I*RLI
M('L*("`@("`@("`@("`@("`@("1D871E<ULG>65A<B==6R1I72`]("1I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!S<')I;G1F
M*"<\<V5L96-T(&YA;64](B5S(B!I9#TB)7,B)7,^)7,\+W-E;&5C=#XG+`H@
M("`@("`@("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/F=E=$UO;G1H5F%R
M*"1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/F=E
M=$UO;G1H5F%R*"1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1D871E<ULG;6]N
M=&@G72P@)'9A<G,M/F=E="@D=F%R+3YT>7!E+3YG971-;VYT:%9A<B@D=F%R
M*2DI*2`N"B`@("`@("`@("`@('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7,B
M(&ED/2(E<R(E<SXE<SPO<V5L96-T/B<L"B`@("`@("`@("`@("`@("`@("`@
M)'9A<BT^='EP92T^9V5T665A<E9A<B@D=F%R*2P*("`@("`@("`@("`@("`@
M("`@("`D=F%R+3YT>7!E+3YG971996%R5F%R*"1V87(I+`H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A
M<BDL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE8W1/<'1I;VYS
M*"1D871E<ULG>65A<B==+"`D=F%R<RT^9V5T*"1V87(M/G1Y<&4M/F=E=%EE
M87)687(H)'9A<BDI*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A
M<DEN<'5T7VUO;G1H9&%Y>65A<B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@
M("!["B`@("`@("`@)&1A=&5S(#T@87)R87DH*3L*("`@("`@("`D9&%T97-;
M)VUO;G1H)UT@/2!A<G)A>2@G)R`@(#T^(%\H(DU-(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)S$G("`]/B!?*")*86YU87)Y(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S(G("`]/B!?*")&96)R
M=6%R>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<S)R`@
M/3X@7R@B36%R8V@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G-"<@(#T^(%\H(D%P<FEL(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)S4G("`]/B!?*")-87DB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G-B<@(#T^(%\H(DIU;F4B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G-R<@(#T^(%\H(DIU;'DB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G."<@(#T^(%\H(D%U9W5S="(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Y)R`@/3X@7R@B
M4V5P=&5M8F5R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)S$P)R`]/B!?*")/8W1O8F5R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)S$Q)R`]/B!?*").;W9E;6)E<B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<Q,B<@/3X@7R@B1&5C96UB97(B*2D["B`@
M("`@("`@)&1A=&5S6R=D87DG72`](&%R<F%Y*"<G(#T^(%\H(D1$(BDI.PH@
M("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`S,3L@)&DK*RD@>PH@("`@("`@
M("`@("`D9&%T97-;)V1A>2==6R1I72`]("1I.PH@("`@("`@('T*("`@("`@
M("`D9&%T97-;)WEE87(G72`](&%R<F%Y*"<G(#T^(%\H(EE965DB*2D["B`@
M("`@("`@:68@*"1V87(M/G1Y<&4M/E]S=&%R=%]Y96%R(#X@)'9A<BT^='EP
M92T^7V5N9%]Y96%R*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`D=F%R+3YT
M>7!E+3Y?<W1A<G1?>65A<CL@)&D@/CT@)'9A<BT^='EP92T^7V5N9%]Y96%R
M.R`D:2TM*2!["B`@("`@("`@("`@("`@("`D9&%T97-;)WEE87(G75LD:5T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&9O<B`H)&D@/2`D=F%R+3YT>7!E+3Y?<W1A<G1?>65A<CL@)&D@/#T@
M)'9A<BT^='EP92T^7V5N9%]Y96%R.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`D9&%T97-;)WEE87(G75LD:5T@/2`D:3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`D9&%T92`]("1V87(M/G1Y<&4M/F=E=$1A=&5087)T
M<R@D=F%R+3YG971686QU92@D=F%R<RDI.PH*("`@("`@("`O+R!43T1/.B!U
M<V4@3DQ3('1O(&=E="!T:&4@;W)D97(@<FEG:'0@9F]R('1H92!297-T($]F
M(%1H90H@("`@("`@("\O(%=O<FQD+@H@("`@("`@("1H=&UL(#T@)R<["B`@
M("`@("`@)&1A=&5?<&%R=',@/2!A<G)A>2@G;6]N=&@G+"`G9&%Y)RP@)WEE
M87(G*3L*("`@("`@("!F;W)E86-H("@D9&%T95]P87)T<R!A<R`D<&%R="D@
M>PH@("`@("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V
M87(M/F=E=%9A<DYA;64H*2`N("=;)R`N("1P87)T("X@)UTG+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@("`D:'1M;"`N/2!S
M<')I;G1F*"<\<V5L96-T(&YA;64](B5S(B!I9#TB)7,B)7,^)7,\+W-E;&5C
M=#XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T
M<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1D871E<ULD<&%R=%TL("1D871E6R1P
M87)T72DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]P
M:6-K97(@)B8@)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S1F5A='5R92@G:F%V
M87-C<FEP="<I*2!["B`@("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE
M*"=O<&5N7V-A;&5N9&%R+FIS)RP@)VAO<F1E)RD["B`@("`@("`@("`@("1I
M;6=)9"`]("1T:&ES+3Y?9V5N240H)'9A<BT^9V5T5F%R3F%M92@I+"!F86QS
M92D@+B`G9V]T;R<["B`@("`@("`@("`@("1H=&UL("X]("<\9&EV(&ED/2)G
M;W1O(B!C;&%S<STB:&5A9&5R8F]X(B!S='EL93TB<&]S:71I;VXZ86)S;VQU
M=&4[=FES:6)I;&ET>3IH:61D96X[<&%D9&EN9SHP(CX\+V1I=CXG("X*("`@
M("`@("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@7R@B4V5L96-T(&$@9&%T
M92(I+"`G)RP@)R<L("=O<&5N0V%L96YD87(H7"<G("X@)&EM9TED("X@)UPG
M+"!<)R<@+B`D=F%R+3YG971687).86UE*"D@+B`G7"<I.R!R971U<FX@9F%L
M<V4[)RD@+B!(;W)D93HZ:6UG*"=C86QE;F1A<BYP;F<G+"!?*")#86QE;F1A
M<B(I+"`G:60](B<@+B`D:6UG260@+B`G(B!A;&EG;CTB;6ED9&QE(B<L("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`B
M/"]A/EQN(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?8V]L;W)P:6-K97(H
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M<F5G:7-T<GDL("1B<F]W<V5R.PH*("`@("`@("`D=F%R;F%M92`]($!H=&UL
M<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`D:'1M;"`]("<\=&%B;&4@8V5L
M;'-P86-I;F<](C`B/CQT<CX\=&0^)R`N"B`@("`@("`@("`@("<\:6YP=70@
M='EP93TB=&5X="(@<VEZ93TB,3`B(&UA>&QE;F=T:#TB-R(@;F%M93TB)R`N
M"B`@("`@("`@("`@("1V87)N86UE("X@)R(@:60](B<@+B`D=F%R;F%M92`N
M"B`@("`@("`@("`@("<B('9A;'5E/2(G("X@0&AT;6QS<&5C:6%L8VAA<G,H
M)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I("X@)R(@+SX\+W1D/B<["B`@("`@("`@:68@*"1B<F]W<V5R+3YH
M87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.F%D9%-C<FEP=$9I;&4H)V]P96Y?8V]L;W)P:6-K97(N:G,G+"`G:&]R9&4G
M+"!T<G5E*3L*("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!W:61T:#TB,C`B
M(&ED/2)C;VQO<F1E;6]?)R`N("1V87)N86UE("X@)R(@<W1Y;&4](F)A8VMG
M<F]U;F0Z)R`N($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V
M87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("<B/B`\+W1D
M/B<@+@H@("`@("`@("`@("`@("`@)SQT9#XG("X@2&]R9&4Z.FQI;FLH)R,G
M+"!?*")#;VQO<B!0:6-K97(B*2P@)W=I9&=E="<L("<G+"`G;W!E;D-O;&]R
M4&EC:V5R*%PG)R`N("1V87)N86UE("X@)UPG*3L@<F5T=7)N(&9A;'-E.R<I
M("X@2&]R9&4Z.FEM9R@G8V]L;W)P:6-K97(N<&YG)RP@7R@B0V]L;W(@4&EC
M:V5R(BDL("=H96EG:'0](C$V(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI("X@)SPO83X\+W1D/B<@+@H@("`@("`@("`@("`@("`@)SQT
M9#X\9&EV(&ED/2)C;VQO<G!I8VME<E\G("X@)'9A<FYA;64@+B`G(B!C;&%S
M<STB8V]N=')O;"(^/"]D:78^/"]T9#XG.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&AT;6P@+B`G/"]T<CX\+W1A8FQE/B<["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W-O<G1E<B@F)&9O<FTL("8D=F%R+"`F
M)'9A<G,I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@
M("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).
M86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@
M)&EN<W1A;F-E(#T@)'9A<BT^='EP92T^7VEN<W1A;F-E.PH*("`@("`@("!(
M;W)D93HZ861D4V-R:7!T1FEL92@G<V]R=&5R+FIS)RP@)VAO<F1E)RP@=')U
M92D["@H@("`@("`@(')E='5R;B`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB)R`N("1V87)N86UE("X*("`@("`@("`@("`@)UMA<G)A>5TB('9A;'5E
M/2(B("<@+B`D=&AI<RT^7V=E;DE$*"1V87)N86UE("X@)UMA<G)A>5TG*2`N
M("<O/B<@+@H@("`@("`@("`@("`G/'-E;&5C="!C;&%S<STB;&5F=$9L;V%T
M(B!M=6QT:7!L93TB;75L=&EP;&4B('-I>F4](B<@+@H@("`@("`@("`@("`H
M:6YT*21V87(M/G1Y<&4M/F=E=%-I>F4H*2`N("<B(&YA;64](B<@+B`D=F%R
M;F%M92`N"B`@("`@("`@("`@("=;;&ES=%TB(&]N8VAA;F=E/2(G("X@)&EN
M<W1A;F-E("X@)RYD97-E;&5C=$AE861E<B@I.R(@)R`N"B`@("`@("`@("`@
M("1T:&ES+3Y?9V5N240H)'9A<FYA;64@+B`G6VQI<W1=)RD@+B`G/B<@+@H@
M("`@("`@("`@("`D=F%R+3YT>7!E+3YG971/<'1I;VYS*"1V87(M/F=E=%9A
M;'5E*"1V87)S*2D@+B`G/"]S96QE8W0^/&1I=B!C;&%S<STB;&5F=$9L;V%T
M(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH)R,G+"!?*")-;W9E('5P
M(BDL("<G+"`G)RP@)&EN<W1A;F-E("X@)RYM;W9E0V]L=6UN57`H*3L@<F5T
M=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G;F%V+W5P+G!N9R<L(%\H(DUO
M=F4@=7`B*2P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI
M("X@)SPO83X\8G(@+SXG("X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH)R,G
M+"!?*")-;W9E('5P(BDL("<G+"`G)RP@)&EN<W1A;F-E("X@)RYM;W9E0V]L
M=6UN1&]W;B@I.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=N878O
M9&]W;BYP;F<G+"!?*")-;W9E(&1O=VXB*2P@)R<L("1R96=I<W1R>2T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83X\+V1I=CXG("X*("`@("`@("`@
M("`@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CXG("X@(EQN(B`N
M"B`@("`@("`@("`@('-P<FEN=&8H)R4Q)',@/2!N97<@2&]R9&5?1F]R;5]3
M;W)T97(H7"<E,21S7"<L(%PG)3(D<UPG+"!<)R4S)'-<)RD[)R`N(")<;B(L
M"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A;F-E+"`D=F%R;F%M92P@)'9A
M<BT^='EP92T^9V5T2&5A9&5R*"DI("X*("`@("`@("`@("`@<W!R:6YT9B@B
M)7,N<V5T2&ED9&5N*"D[7&X\+W-C<FEP=#Y<;B(L("1I;G-T86YC92D["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V%S<VEG;B@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V9O<FU?87-S
M:6=N+FIS)RP@)VAO<F1E)RP@=')U92D["@H@("`@("`@("1N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("1F;F%M92`]("1F;W)M+3YG
M971.86UE*"D@+B`G+B<@+B`D=F%R+3YG971687).86UE*"D["B`@("`@("`@
M)'-I>F4@/2`D=F%R+3YT>7!E+3YG9713:7IE*"D["B`@("`@("`@)'=I9'1H
M(#T@)'9A<BT^='EP92T^9V5T5VED=&@H*3L*("`@("`@("`D;&AD<B`]("AB
M;V]L*21V87(M/G1Y<&4M/F=E=$AE861E<B@P*3L*("`@("`@("`D<FAD<B`]
M("AB;V]L*21V87(M/G1Y<&4M/F=E=$AE861E<B@Q*3L*("`@("`@("`D=&AI
M<RT^7V%D9$]N3&]A9$IA=F%S8W)I<'0H)TAO<F1E7T9O<FU?07-S:6=N+G-E
M=$9I96QD*%PG)R`N("1F;F%M92`N("=<)RD[)RD["@H@("`@("`@(')E='5R
M;B`G/'1A8FQE/CQT<CX\=&0^)R`N"B`@("`@("`@("`@("<\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2(G("X@)&YA;64@+B`G7U]V86QU97,B("\^)R`N
M"B`@("`@("`@("`@('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7-?7VQE9G0B
M(&UU;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB)60B('-T>6QE/2)W:61T:#HE
M<R(E<SXG+`H@("`@("`@("`@("`@("`@("`@("1N86UE+"`D<VEZ92P@)'=I
M9'1H+`H@("`@("`@("`@("`@("`@("`@("1L:&1R(#\@)R!O;F-H86YG93TB
M2&]R9&5?1F]R;5]!<W-I9VXN9&5S96QE8W1(96%D97)S*%PG)R`N("1F;F%M
M92`N("=<)RP@,"D[(B<@.B`G)RD@+@H@("`@("`@("`@("`D=F%R+3YT>7!E
M+3YG971/<'1I;VYS*#`L("1F;F%M92D@+@H@("`@("`@("`@("`G/"]S96QE
M8W0^/"]T9#X\=&0^)R`N"B`@("`@("`@("`@("<\82!H<F5F/2(B(&]N8VQI
M8VL](DAO<F1E7T9O<FU?07-S:6=N+FUO=F4H7"<G("X@)&9N86UE("X*("`@
M("`@("`@("`@)UPG+"`P*3L@<F5T=7)N(&9A;'-E.R(^)R`N"B`@("`@("`@
M("`@($AO<F1E.CII;6<H)W)H86YD+G!N9R<L(%\H(D%D9"!C;VQU;6XB*2P@
M;G5L;"P@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+@H@("`@
M("`@("`@("`G/"]A/CQB<B`O/CQA(&AR968](B(@;VYC;&EC:STB2&]R9&5?
M1F]R;5]!<W-I9VXN;6]V92A<)R<@+@H@("`@("`@("`@("`D9FYA;64@+B`G
M7"<L(#$I.R!R971U<FX@9F%L<V4[(CXG("X*("`@("`@("`@("`@2&]R9&4Z
M.FEM9R@G;&AA;F0N<&YG)RP@7R@B4F5M;W9E(&-O;'5M;B(I+"!N=6QL+"`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N"B`@("`@("`@("`@
M("<\+V$^/"]T9#X\=&0^)R`N"B`@("`@("`@("`@('-P<FEN=&8H)SQS96QE
M8W0@;F%M93TB)7-?7W)I9VAT(B!M=6QT:7!L93TB;75L=&EP;&4B('-I>F4]
M(B5D(B!S='EL93TB=VED=&@Z)7,B)7,^)RP*("`@("`@("`@("`@("`@("`@
M("`D;F%M92P@)'-I>F4L("1W:61T:"P*("`@("`@("`@("`@("`@("`@("`D
M<FAD<B`_("<@;VYC:&%N9V4](DAO<F1E7T9O<FU?07-S:6=N+F1E<V5L96-T
M2&5A9&5R<RA<)R<@+B`D9FYA;64@+B`G7"<L(#$I.R(G(#H@)R<I("X*("`@
M("`@("`@("`@)'9A<BT^='EP92T^9V5T3W!T:6]N<R@Q+"`D9FYA;64I("X*
M("`@("`@("`@("`@)SPO<V5L96-T/CPO=&0^/"]T<CX\+W1A8FQE/B<["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VEN=F%L:60H)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)E;F1E<E9A<D1I<W!L87E?:6YV86QI9"@D9F]R;2P@)'9A<BP@)'9A
M<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]E;G5M
M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%L=65S
M(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@("`@("`@)'!R;VUP="`]("1V87(M
M/G1Y<&4M/F=E=%!R;VUP="@I.PH@("`@("`@("1H=&UL8VAA<G,@/2`D=F%R
M+3YG971/<'1I;VXH)VAT;6QC:&%R<R<I.PH@("`@("`@(&EF("@A96UP='DH
M)'!R;VUP="DI('L*("`@("`@("`@("`@)'!R;VUP="`]("<\;W!T:6]N('9A
M;'5E/2(B/B<@+B`H)&AT;6QC:&%R<R`_("1P<F]M<'0@.B!`:'1M;'-P96-I
M86QC:&%R<R@D<')O;7!T+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M*2`N("<\+V]P=&EO;CXG.PH@("`@("`@('T*("`@("`@("`D=F%R;F%M92`]
M($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT
M9B@G/'-E;&5C="!N86UE/2(E<R(@:60](B5S(B`E<SXE<R5S/"]S96QE8W0^
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("1P<F]M<'0L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1V86QU97,L("1V87(M/F=E
M=%9A;'5E*"1V87)S*2P@)&AT;6QC:&%R<RDI.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)687));G!U=%]M;&5N=6TH)B1F;W)M+"`F)'9A<BP@)B1V
M87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M
M92@I.PH@("`@("`@("1H=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V
M87)N86UE+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M("1V86QU97,@/2`D=F%R+3YG971686QU97,H*3L*("`@("`@("`D<')O;7!T
M<R`]("1V87(M/G1Y<&4M/F=E=%!R;VUP=',H*3L*("`@("`@("`D<V5L96-T
M960@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@+RH@268@<&%S
M<VEN9R!A(&YO;BUA<G)A>2!V86QU92!N965D('1O(&=E="!T:&4@:V5Y<RX@
M*B\*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S96QE8W1E9"DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D:V5Y7S$@/3X@)'9A;'5E<U\R
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;'5E<U\R6R1S96QE
M8W1E9%TI*2!["B`@("`@("`@("`@("`@("`@("`@)'-E;&5C=&5D(#T@87)R
M87DH)S$G(#T^("1K97E?,2P@)S(G(#T^("1S96QE8W1E9"D["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J($AI9&1E;B!T86<@=&\@<W1O
M<F4@=&AE(&-U<G)E;G0@9FER<W0@;&5V96PN("HO"B`@("`@("`@)&AT;6P@
M/2!S<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E<UMO;&1=
M(B!V86QU93TB)7,B("5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M)&AV87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I
M86QC:&%R<R@D<V5L96-T961;)S$G72P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G96Y)
M1"@D=F%R;F%M92`N("=;;VQD72<I*3L*"B`@("`@("`@+RH@1FER<W0@;&5V
M96PN("HO"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G
M.PH@("`@("`@("1V86QU97-?,2`]($AO<F1E7T%R<F%Y.CIV86QU97-4;TME
M>7,H87)R87E?:V5Y<R@D=F%L=65S*2D["B`@("`@("`@)&AT;6P@+CT@<W!R
M:6YT9B@G/'-E;&5C="`E<R!N86UE/2(E<ULQ72(@;VYC:&%N9V4](B5S(B5S
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E;DE$*"1V
M87)N86UE("X@)ULQ72<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&AV
M87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@)VEF("AT:&ES+G9A
M;'5E*2![(&1O8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M92@I("X@)RYF;W)M
M;F%M92YV86QU93U<)UPG.R<@+B`G9&]C=6UE;G0N)R`N("1F;W)M+3YG971.
M86UE*"D@+B`G+G-U8FUI="@I('TG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@*"1V87(M/FAA<T%C=&EO;B@I(#\@)R`G("X@)'1H:7,M/E]G96Y!8W1I
M;VY38W)I<'0H)&9O<FTL("1V87(M/E]A8W1I;VXL("1V87)N86UE*2`Z("<G
M*2D["B`@("`@("`@:68@*"%E;7!T>2@D<')O;7!T<RDI('L*("`@("`@("`@
M("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](B(^)R`N($!H=&UL<W!E8VEA
M;&-H87)S*"1P<F]M<'1S6S!=+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H@("`@("`@("1H=&UL("X]
M("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D=F%L=65S7S$L("1S96QE8W1E9%LG
M,2==*3L*("`@("`@("`D:'1M;"`N/2`G/"]S96QE8W0^)SL*"B`@("`@("`@
M+RH@4V5C;VYD(&QE=F5L+B`J+PH@("`@("`@("1H=&UL("X]('-P<FEN=&8H
M)SQS96QE8W0@)7,@;F%M93TB)7-;,ETB)7,^)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5N240H)'9A<FYA;64@+B`G6S)=)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D:'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`H)'9A<BT^:&%S06-T:6]N*"D@/R`G("<@+B`D=&AI
M<RT^7V=E;D%C=&EO;E-C<FEP="@D9F]R;2P@)'9A<BT^7V%C=&EO;BP@)'9A
M<FYA;64I(#H@)R<I*3L*("`@("`@("!I9B`H(65M<'1Y*"1P<F]M<'1S*2D@
M>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB(CXG("X@
M0&AT;6QS<&5C:6%L8VAA<G,H)'!R;VUP='-;,5TL($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="D@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"B`@("`@
M("`@)'9A;'5E<U\R(#T@87)R87DH*3L*("`@("`@("!I9B`H(65M<'1Y*"1S
M96QE8W1E9%LG,2==*2D@>PH@("`@("`@("`@("`D=F%L=65S7S(@/2`F)'9A
M;'5E<ULD<V5L96-T961;)S$G75T["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D:'1M;"`N("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D=F%L=65S7S(L("1S
M96QE8W1E9%LG,B==*2`N("<\+W-E;&5C=#XG.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)687));G!U=%]M=6QT:65N=6TH)B1F;W)M+"`F)'9A<BP@
M)B1V87)S*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG971686QU
M97,H*3L*("`@("`@("`D<V5L96-T960@/2`D=F%R<RT^9V5T17AI<W1S*"1V
M87(M/F=E=%9A<DYA;64H*2P@)'=A<W-E="D["B`@("`@("`@:68@*"$D=V%S
M<V5T*2!["B`@("`@("`@("`@("1S96QE8W1E9"`]("1V87(M/F=E=$1E9F%U
M;'0H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQS96QE
M8W0@;75L=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(E<R(@;F%M93TB)7-;72(@
M)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@("`@("AI;G0I
M)'9A<BT^='EP92T^<VEZ92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M
M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VUU;'1I4V5L96-T3W!T:6]N<R@D=F%L
M=65S+"`D<V5L96-T960I*2`N"B`@("`@("`@("`@("(\8G(@+SY<;B(@+B!?
M*")4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N
M=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG
M+B(I("X@(EQN(CL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP
M=71?<F%D:6\H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A9&EO0G5T=&]N<R@D=F%R+3YG971687).86UE
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87(M
M/F=E=%9A;'5E<R@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R+3YG971686QU92@D=F%R<RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]S970H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M("1H=&UL(#T@)'1H:7,M/E]C:&5C:T)O>&5S*"1V87(M/F=E=%9A<DYA;64H
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG
M971686QU97,H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R+3YG971686QU92@D=F%R<RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M
M+"`D=F%R*2D["@H@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?8VAE8VM!;&PI
M('L*("`@("`@("`@("`@)&9O<FU?;F%M92`]("1F;W)M+3YG971.86UE*"D[
M"B`@("`@("`@("`@("1V87)?;F%M92`]("1V87(M/F=E=%9A<DYA;64H*2`N
M("=;72<["B`@("`@("`@("`@("1F=6YC=&EO;E]N86UE(#T@)W-E;&5C="<@
M("X@)&9O<FU?;F%M92`N("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@
M("`@)&5N86)L92`](%\H(E-E;&5C="!A;&PB*3L*("`@("`@("`@("`@)&1I
M<V%B;&4@/2!?*")396QE8W0@;F]N92(I.PH@("`@("`@("`@("`D:6YV97)T
M(#T@7R@B26YV97)T('-E;&5C=&EO;B(I.PH@("`@("`@("`@("`D:'1M;"`N
M/2`\/#Q%3U0*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@IF=6YC
M=&EO;B`D9G5N8W1I;VY?;F%M92@I"GL*("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@9&]C=6UE;G0N)&9O<FU?;F%M92YE;&5M96YT<RYL96YG=&@[(&DK*RD@
M>PH@("`@("`@(&8@/2!D;V-U;65N="XD9F]R;5]N86UE+F5L96UE;G1S6VE=
M.PH@("`@("`@(&EF("AF+FYA;64@(3T@)R1V87)?;F%M92<I('L*("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@(&EF("AA<F=U;65N
M=',N;&5N9W1H*2!["B`@("`@("`@("`@(&8N8VAE8VME9"`](&%R9W5M96YT
M<ULP73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F+F-H96-K960@
M/2`A9BYC:&5C:V5D.PH@("`@("`@('T*("`@('T*?0H\+W-C<FEP=#X*/&$@
M:')E9CTB(R(@;VYC;&EC:STB)&9U;F-T:6]N7VYA;64H=')U92D[(')E='5R
M;B!F86QS93LB/B1E;F%B;&4\+V$^+`H\82!H<F5F/2(C(B!O;F-L:6-K/2(D
M9G5N8W1I;VY?;F%M92AF86QS92D[(')E='5R;B!F86QS93LB/B1D:7-A8FQE
M/"]A/BP*/&$@:')E9CTB(R(@;VYC;&EC:STB)&9U;F-T:6]N7VYA;64H*3L@
M<F5T=7)N(&9A;'-E.R(^)&EN=F5R=#PO83X*14]4.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687));G!U=%]L:6YK*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R96YD97)687)$:7-P;&%Y7VQI;FLH
M)&9O<FTL("1V87(L("1V87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R26YP=71?:'1M;"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R5F%R1&ES<&QA>5]H=&UL
M*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<DEN<'5T7V5M86EL*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@
M('L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B
M(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%R3F%M92@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("1V87(M/F=E=%9A<DYA;64H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R+3YG971686QU92@D=F%R<RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D
M=F%R*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VUA
M=')I>"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A
M<FYA;64@("`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`D=F%R7V%R
M<F%Y(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("1C;VQS("`@
M("`@/2`D=F%R+3YT>7!E+3YG971#;VQS*"D["B`@("`@("`@)')O=W,@("`@
M("`]("1V87(M/G1Y<&4M/F=E=%)O=W,H*3L*("`@("`@("`D;6%T<FEX("`@
M(#T@)'9A<BT^='EP92T^9V5T36%T<FEX*"D["B`@("`@("`@)&YE=U]I;G!U
M="`]("1V87(M/G1Y<&4M/F=E=$YE=TEN<'5T*"D["@H@("`@("`@("1H=&UL
M(#T@)SQT86)L92!C96QL<W!A8VEN9STB,"(^/'1R/B<["@H@("`@("`@("1H
M=&UL("X]("<\=&0@86QI9VX](G)I9VAT(B!W:61T:#TB,C`E(CX\+W1D/B<[
M"B`@("`@("`@9F]R96%C:"`H)&-O;',@87,@)&-O;%]T:71L92D@>PH@("`@
M("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\=&0@86QI9VX](F-E;G1E<B(@
M=VED=&@](C$E)2(^)7,\+W1D/B<L("1C;VQ?=&ET;&4I.PH@("`@("`@('T*
M("`@("`@("`D:'1M;"`N/2`G/'1D(&%L:6=N/2)R:6=H="(@=VED=&@](C8P
M)2(^/"]T9#X\+W1R/B<["@H@("`@("`@("\J($]F9F5R(&$@;F5W(')O=R!O
M9B!D871A('1O(&)E(&%D9&5D('1O('1H92!M871R:7@_("HO"B`@("`@("`@
M:68@*"1N97=?:6YP=70I('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQT<CX\
M=&0^)SL*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1N97=?:6YP=70I*2![
M"B`@("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\<V5L96-T("5S
M(&YA;64](B5S6VY=6W)=(CX\;W!T:6]N('9A;'5E/2(B/B5S/"]O<'1I;VX^
M)7,\+W-E;&5C=#X\8G(@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5N240H)'9A<FYA;64@+B`G6VY=6W)=)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M7R@B+2T@<V5L96-T("TM(BDL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S96QE8W1/<'1I;VYS*"1N97=?:6YP=70L("1V87)?87)R87E;)VXG
M75LG<B==*2D["B`@("`@("`@("`@('T@96QS96EF("@D;F5W7VEN<'5T(#T]
M('1R=64I('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQI
M;G!U="`E<R!T>7!E/2)T97AT(B!N86UE/2(E<UMN75MR72(@=F%L=64](B5S
M(B`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G96Y)1"@D
M=F%R;F%M92`N("=;;EU;<ETG*2P*("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R7V%R<F%Y6R=N
M)UU;)W(G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@
M)R`\+W1D/B<["B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VQS(&%S("1C;VQ?
M:60@/3X@)&-O;%]T:71L92D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M<W!R:6YT9B@G/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N86UE/2(E<UMN75MV75LE<UTB("\^
M/"]T9#XG+"`D=F%R;F%M92P@)&-O;%]I9"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&AT;6P@+CT@)SQT9#X@/"]T9#X\+W1R/B<["B`@("`@("`@
M?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=&AE(')O=W,@86YD(&-R96%T
M92!C:&5C:V)O>&5S(&9O<B!E86-H(&-O;'5M;BX@*B\*("`@("`@("!F;W)E
M86-H("@D<F]W<R!A<R`D<F]W7VED(#T^("1R;W=?=&ET;&4I('L*("`@("`@
M("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1R/CQT9#XE<SPO=&0^)RP@)')O
M=U]T:71L92D["B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VQS(&%S("1C;VQ?
M:60@/3X@)&-O;%]T:71L92D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M<W!R:6YT9B@G/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N86UE/2(E<UMR75LE<UU;)7-=(B5S
M("\^/"]T9#XG+"`D=F%R;F%M92P@)')O=U]I9"P@)&-O;%]I9"P@*"%E;7!T
M>2@D;6%T<FEX6R1R;W=?:61=6R1C;VQ?:61=*2`_("<@8VAE8VME9#TB8VAE
M8VME9"(G(#H@)R<I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M
M;"`N/2`G/'1D/B`\+W1D/CPO='(^)SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:'1M;"`N("<\+W1A8FQE/B<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<DEN<'5T7W!A<W-W;W)D*"8D9F]R;2P@)B1V87(L("8D=F%R
M<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S
M*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G!A
M<W-W;W)D(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?96UA:6QC;VYF:7)M
M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D96UA:6P@
M/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@)'9A<FYA;64@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H
M)SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<UMO<FEG:6YA;%TB(&ED/2(E
M<UMO<FEG:6YA;%TB('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA
M<G,H)&5M86EL6R=O<FEG:6YA;"==+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T
M:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI("X*("`@("`@("`@("`@)R`G("X@
M<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S6V-O;F9I<FU=
M(B!I9#TB)7-;8V]N9FER;5TB('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M0&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL6R=C;VYF:7)M)UTL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W!A<W-W;W)D8V]N
M9FER;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'!A
M<W-W;W)D(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("1V87)N
M86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S
M<')I;G1F*"<\:6YP=70@='EP93TB<&%S<W=O<F0B(&YA;64](B5S6V]R:6=I
M;F%L72(@:60](B5S6V]R:6=I;F%L72(@=F%L=64](B5S(B5S("\^)RP*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M
M;'-P96-I86QC:&%R<R@D<&%S<W=O<F1;)V]R:6=I;F%L)UTL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D@+@H@("`@
M("`@("`@("`G("<@+B!S<')I;G1F*"<\:6YP=70@='EP93TB<&%S<W=O<F0B
M(&YA;64](B5S6V-O;F9I<FU=(B!I9#TB)7-;8V]N9FER;5TB('9A;'5E/2(E
M<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'!A<W-W;W)D
M6R=C;VYF:7)M)UTL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I
M<'1S*"1F;W)M+"`D=F%R*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<DEN<'5T7V)O;VQE86XH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@
M("`@("`@("1H=&UL(#T@)SQI;G!U="!T>7!E/2)C:&5C:V)O>"(@8VQA<W,]
M(F-H96-K8F]X(B!N86UE/2(G("X@("1V87)N86UE("X@)R(G("X*("`@("`@
M("`@("`@)R!I9#TB)R`N("1V87)N86UE("X@)R(G("X@*"1V87(M/F=E=%9A
M;'5E*"1V87)S*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<I.PH@("`@
M("`@(&EF("@D=F%R+3YH87-!8W1I;VXH*2D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`D=&AI<RT^7V=E;D%C=&EO;E-C<FEP="@D9F]R;2P@)'9A<BT^7V%C
M=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1H=&UL("X@)R`O/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<DEN<'5T7V-R961I=&-A<F0H)B1F;W)M+"`F)'9A<BP@)B1V87)S
M*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H
M)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I.PH@("`@("`@("1H=&UL(#T@)SQI;G!U="!T>7!E/2)T97AT(B!N86UE
M/2(G("X@)'9A<FYA;64@+B`G(B!I9#TB)R`N("1V87)N86UE("X@)R(@=F%L
M=64](B<@+@H@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG
M971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@
M+B`G(B<["B`@("`@("`@:68@*"1V87(M/FAA<T%C=&EO;B@I*2!["B`@("`@
M("`@("`@("1H=&UL("X]("1T:&ES+3Y?9V5N06-T:6]N4V-R:7!T*"1F;W)M
M+"`D=F%R+3Y?86-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R+3YG971687).86UE*"DI.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&AT;6P@+B`G("\^)SL*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;V)R;W=S97(H)B1F;W)M+"`F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@)'9A<BT^9V5T
M5F%R3F%M92@I.PH@("`@("`@("1V87)V86QU92`]("1V87)S+3YG970H)'9A
M<FYA;64I.PH@("`@("`@("1F:65L9$ED(#T@)'1H:7,M/E]G96Y)1"AM9#4H
M=6YI<6ED*')A;F0H*2P@=')U92DI+"!F86QS92D@+B`G:60G.PH@("`@("`@
M("1H=&UL(#T@)PH@("`@("`@("`@("`\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(^"B`@("`@("`@("`@('9A<B!O8G)O=W-E<E=I;F1O=TYA;64[
M"B`@("`@("`@("`@(&9U;F-T:6]N(&]B<F]W<V5R0V%L;&)A8VLH;F%M92P@
M;VED*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!I9B`H;F%M92`]
M/2!O8G)O=W-E<E=I;F1O=TYA;64I('L*("`@("`@("`@("`@("`@("`@("!D
M;V-U;65N="YG971%;&5M96YT0GE)9"A<)R<@+B`D9FEE;&1)9"`N("=<)RDN
M=F%L=64@/2!O:60["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@(DEN=F%L:60@=VEN9&]W(&YA;64@<W5P<&QI960B.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(#PO<V-R
M:7!T/@H@("`@("`@("`@("`G.PH@("`@("`@("1H=&UL("X]('-P<FEN=&8H
M)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B5S(B!I9#TB)7,B)7,@=F%L
M=64](B5S(CXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C
M:6%L8VAA<G,H)'9A<FYA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&1)9"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D=F%R=F%L=64L($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DI.PH@("`@("`@(&EF("@A96UP='DH)'9A<G9A;'5E*2D@>PH@("`@
M("`@("`@("`D:'1M;"`N/2`D=F%R=F%L=64["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S1F5A='5R92@G:F%V87-C
M<FEP="<I*2!["B`@("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=P
M;W!U<"YJ<R<L("=H;W)D92<L('1R=64I.PH@("`@("`@("`@("`D:6UG260@
M/2`D=&AI<RT^7V=E;DE$*"1V87)N86UE+"!F86QS92D@+B`G9V]T;R<["B`@
M("`@("`@("`@("1H=&UL("X]("<\9&EV(&ED/2)G;W1O(B!C;&%S<STB:&5A
M9&5R8F]X(B!S='EL93TB<&]S:71I;VXZ86)S;VQU=&4[=FES:6)I;&ET>3IH
M:61D96X[<&%D9&EN9SHP(CX\+V1I=CXG("X*("`@("`@("`@("`@("`@($AO
M<F1E.CIL:6YK*"<C)RP@7R@B4V5L96-T(&%N(&]B:F5C="(I+"`G)RP@)R<L
M("=O8G)O=W-E<E=I;F1O=R`]('!O<'5P*%PG)R`N("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O
M;V)R;W=S97(O)R`N("=<)RD[(&]B<F]W<V5R5VEN9&]W3F%M92`](&]B<F]W
M<V5R5VEN9&]W+FYA;64[(')E='5R;B!F86QS93LG*2`N($AO<F1E.CII;6<H
M)W1R964O;&5A9BYP;F<G+"!?*")/8FIE8W0B*2P@)VED/2(G("X@)&EM9TED
M("X@)R(@86QI9VX](FUI9&1L92(G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@(CPO83Y<;B(["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<DEN<'5T7V1B;&]O:W5P*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R96YD97)687));G!U=%]E
M;G5M*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<DEN<'5T7V9I9VQE="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT
M(B!N86UE/2(E<R(@:60](B5S(B!S:7IE/2(E<R(@=F%L=64](B5S(B`O/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M<W1R;&5N*"1V87(M/G1Y<&4M/F=E=%1E>'0H*2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A
M<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I*2`N"B`@("`@("`@
M("`@("<\8G(@+SXG("X@7R@B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(BD@
M+B`G/&)R("\^)R`N"B`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R5F%R1&ES
M<&QA>5]F:6=L970H)&9O<FTL("1V87(L("1V87)S*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>41E9F%U;'0H)B1F;W)M+"`F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B!N;#)B<BA`:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687)$:7-P;&%Y7VAT;6PH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("\O(%-I;F-E('1H:7,@:7,@86X@2%1-3"!T>7!E('=E(&5X
M<&QI8VET;'D@9&]N)W0@97-C87!E"B`@("`@("`@+R\@:70N(%5S97(@8F5W
M87)E+@H@("`@("`@(')E='5R;B`D=F%R+3YG971686QU92@D=F%R<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?96UA:6PH)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1D:7-P;&%Y7V5M
M86EL(#T@)&5M86EL(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH*("`@("`@
M("!I9B`H)'9A<BT^='EP92T^7W-T<FEP7V1O;6%I;B`F)B!S=')P;W,H)&5M
M86EL+"`G0"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D9&ES<&QA>5]E
M;6%I;"`]('-T<E]R97!L86-E*&%R<F%Y*"=`)RP@)RXG*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G("AA="D@
M)RP@)R`H9&]T*2`G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D96UA:6PI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1V
M87(M/G1Y<&4M/E]L:6YK7V-O;7!O<V4I('L*("`@("`@("`@("`@)&5M86EL
M7W9A;"`]('1R:6TH)&5M86EL*3L*"B`@("`@("`@("`@("\O($9O<FUA="!T
M:&4@861D<F5S<R!A8V-O<F1I;F<@=&\@4D9#.#(R+@H@("`@("`@("`@("`D
M;6%I;&)O>%]H;W-T(#T@97AP;&]D92@G0"<L("1E;6%I;%]V86PI.PH@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1M86EL8F]X7VAO<W1;,5TI*2!["B`@("`@
M("`@("`@("`@("`D;6%I;&)O>%]H;W-T6S%=(#T@)R<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1N86UE(#T@;G5L;#L*("`@("`@("`@("`@:68@
M*"1V87(M/G1Y<&4M/E]L:6YK7VYA;64I('L*("`@("`@("`@("`@("`@("1N
M86UE(#T@)'9A<BT^='EP92T^7VQI;FM?;F%M93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["B`@
M("`@("`@("`@("1A9&1R97-S(#T@34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S
M*"1M86EL8F]X7VAO<W1;,%TL("1M86EL8F]X7VAO<W1;,5TL("1N86UE*3L*
M"B`@("`@("`@("`@("\O($=E="!R:60@;V8@=&AE('1R86EL:6YG($`@*'=H
M96X@;F\@:&]S="!I<R!I;F-L=61E9"!I;@H@("`@("`@("`@("`O+R!T:&4@
M96UA:6P@861D<F5S<RDN"B`@("`@("`@("`@("1A9&1R97-S(#T@<W1R7W)E
M<&QA8V4H)T`^)RP@)SXG+"`D861D<F5S<RD["B`@("`@("`@("`@("1M86EL
M7VQI;FL@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G;6%I;"]C;VUP
M;W-E)RP@87)R87DH87)R87DH)W1O)R`]/B!A9&1S;&%S:&5S*"1A9&1R97-S
M*2DI*3L*("`@("`@("`@("`@:68@*&ES7V$H)&UA:6Q?;&EN:RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&UA:6Q?;&EN:R`]("=M86EL
M=&\Z)R`N('5R;&5N8V]D92@D861D<F5S<RD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@D;6%I;%]L:6YK+"`D96UA
M:6Q?=F%L*2`N($!H=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y7V5M86EL+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I("X@)SPO83XG.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N;#)B<BA`:'1M;'-P96-I
M86QC:&%R<R@D9&ES<&QA>5]E;6%I;"P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687)$:7-P;&%Y7W!A<W-W;W)D*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("!R971U<FX@)RHJ*BHJ*BHJ)SL*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]P87-S=V]R9&-O;F9I<FTH)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`G*BHJ
M*BHJ*BHG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y
M7V]C=&%L*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R
M971U<FX@<W!R:6YT9B@G,"5O)RP@;V-T9&5C*"1V87(M/F=E=%9A;'5E*"1V
M87)S*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y
M7V)O;VQE86XH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=F%R+3YG971686QU92@D=F%R<RD@/R!?*")997,B*2`Z(%\H
M(DYO(BD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?
M96YU;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A
M;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@("1V86QU92`]("1V
M87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("!I9B`H8V]U;G0H)'9A;'5E
M<RD@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@7R@B3F\@=F%L=65S(BD[
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1V86QU97-;)'9A;'5E72D@)B8@
M)'9A;'5E("$]("<G*2!["B`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I
M86QC:&%R<R@D=F%L=65S6R1V86QU95TL($5.5%]154]415,L("1T:&ES+3Y?
M8VAA<G-E="D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687)$:7-P;&%Y7W)A9&EO*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@
M('L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@("`@
M("`@:68@*&-O=6YT*"1V86QU97,I(#T](#`I('L*("`@("`@("`@("`@<F5T
M=7)N(%\H(DYO('9A;'5E<R(I.PH@("`@("`@('T@96QS96EF("AI<W-E="@D
M=F%L=65S6R1V87(M/F=E=%9A;'5E*"1V87)S*5TI*2!["B`@("`@("`@("`@
M(')E='5R;B!`:'1M;'-P96-I86QC:&%R<R@D=F%L=65S6R1V87(M/F=E=%9A
M;'5E*"1V87)S*5TL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y
M7VUU;'1I96YU;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@("1O;B`]
M("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("!I9B`H(6-O=6YT*"1V
M86QU97,I('Q\("%C;W5N="@D;VXI*2!["B`@("`@("`@("`@(')E='5R;B!?
M*").;R!V86QU97,B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9&ES<&QA>2`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU
M97,@87,@)'9A;'5E(#T^("1N86UE*2!["B`@("`@("`@("`@("`@("!I9B`H
M:6Y?87)R87DH)'9A;'5E+"`D;VXI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&1I<W!L87E;72`]("1N86UE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R<RAI
M;7!L;V1E*"<L("<L("1D:7-P;&%Y*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<D1I<W!L87E?<V5T*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*
M("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@("`@("`@
M)&]N(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@(&EF("@A8V]U
M;G0H)'9A;'5E<RD@?'P@(6-O=6YT*"1O;BDI('L*("`@("`@("`@("`@<F5T
M=7)N(%\H(DYO('9A;'5E<R(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1D:7-P;&%Y(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H
M)'9A;'5E<R!A<R`D=F%L=64@/3X@)&YA;64I('L*("`@("`@("`@("`@("`@
M(&EF("AI;E]A<G)A>2@D=F%L=64L("1O;BDI('L*("`@("`@("`@("`@("`@
M("`@("`D9&ES<&QA>5M=(#T@)&YA;64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N($!H=&UL<W!E8VEA;&-H
M87)S*&EM<&QO9&4H)RP@)RP@)&1I<W!L87DI+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R1&ES<&QA>5]I;6%G92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@)&EM9U]P87)A;7,@/2`D=F%R+3YG971686QU92@D
M=F%R<RD["B`@("`@("`@)&EM9U]U<FP@/2!(;W)D93HZ=7)L*"1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R
M=FEC97,O:6UA9V5S+W9I97<N<&AP)RD["B`@("`@("`@)&EM9U]U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H)&EM9U]U<FPL("1I;6=?<&%R86US*3L*"B`@
M("`@("`@<F5T=7)N($AO<F1E.CII;6<H)&EM9U]U<FPL(&ES<V5T*"1I;6=?
M<&%R86US6R=F)UTI(#\@)&EM9U]P87)A;7-;)V8G72`Z("<G+"`G)RP@)R<I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7V-E;&QP
M:&]N92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>3L*"B`@("`@("`@)&YU;6)E<B`]("1V87(M/F=E=%9A
M;'5E*"1V87)S*3L*("`@("`@("`D:'1M;"`]($!H=&UL<W!E8VEA;&-H87)S
M*"1N=6UB97(L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["@H@("`@
M("`@(&EF("@D;G5M8F5R("8F("1R96=I<W1R>2T^:&%S365T:&]D*"=S;7,O
M8V]M<&]S92<I*2!["B`@("`@("`@("`@("1U<FP@/2`D<F5G:7-T<GDM/FQI
M;FLH)W-M<R]C;VUP;W-E)RP@87)R87DH)W1O)R`]/B`D;G5M8F5R*2D["B`@
M("`@("`@("`@("1H=&UL("X]("<@)R`N($AO<F1E.CIL:6YK*"1U<FPL(%\H
M(E-E;F0@4TU3(BDI("X@2&]R9&4Z.FEM9R@G;6]B:6QE+G!N9R<L(%\H(E-E
M;F0@4TU3(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`N("<\+V$^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]A9&1R97-S
M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!G;&]B86P@
M)')E9VES=')Y.PH*("`@("`@("`D861D<F5S<R`]("1V87(M/F=E=%9A;'5E
M*"1V87)S*3L*("`@("`@("`D875S7W-T871E7W)E9V5X(#T@)R@_.D%#5'Q.
M4U=\3E1\44Q$?%-!?%1!4WQ624-\5T$I)SL*"B`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R\H*#\Z05M"3%U\0EM!0D1(3$Y24U1=/WQ#6T%"1DA-3U)45E==
M?$1;041%1TA,3E1977Q%6T-(3EA=/WQ&6TM977Q'6TQ565T_?$A;041'4%)3
M55A=?$E;1TU05EU\2D5\2UM!5%=977Q,6T%$14Q.4U5=/WQ-6T5+3%T_?$Y;
M14=.4%)773]\3UM,6%U\4%M!14A,3U)=?%);1TA-77Q36T%%1TM,34Y/4%)3
M5%=973]\5%M!1$9.45)35UU\54)\5UM!0T1&3E)35ET_?%E/?%I%*5QD*#\Z
M7&1\6T$M6ETI/R!<9%M!+5I=>S)]*2\G+"`D861D<F5S<RP@)'!O<W1C;V1E
M*2D@>PH@("`@("`@("`@("`O*B!52R!P;W-T8V]D92!D971E8W1E9"X@*B\*
M("`@("`@("`@("`@+RH@375L=&EM87`N8V\N=6L@9V5N97)A=&5D(&UA<"`J
M+PH@("`@("`@("`@("`D;6%P=7)L(#T@)VAT='`Z+R]W=W<N;75L=&EM87`N
M8V]M+VUA<"]B<F]W<V4N8V=I/W!C/2<@+B!U<FQE;F-O9&4H)'!O<W1C;V1E
M6S%=*3L*("`@("`@("`@("`@)&1E<V,@/2!?*")-=6QT:6UA<"!52R!M87`B
M*3L*("`@("`@("`@("`@)&EC;VX@/2`G;6%P+G!N9R<["B`@("`@("`@?2!E
M;'-E:68@*'!R96=?;6%T8V@H)R]<8B<@+B`D875S7W-T871E7W)E9V5X("X@
M)UQB+R<L("1A9&1R97-S*2D@>PH@("`@("`@("`@("`O*B!!=7-T<F%L:6%N
M('-T871E(&1E=&5C=&5D+B`J+PH@("`@("`@("`@("`O*B!7:&5R96ES+F-O
M;2YA=2!G96YE<F%T960@;6%P("HO"B`@("`@("`@("`@("1M87!U<FP@/2`G
M:'1T<#HO+W=W=RYW:&5R96ES+F-O;2YA=2]W:&5R96ES+VUA<'!I;F<O9V5O
M8V]D94%D9')E<W,N9&\_)SL*("`@("`@("`@("`@)&1E<V,@/2!?*")7:&5R
M96ES($%U<W1R86QI82!M87`B*3L*("`@("`@("`@("`@)&EC;VX@/2`G;6%P
M+G!N9R<["B`@("`@("`@("`@("\J(%-P;&ET(&]U="!T:&4@861D<F5S<RP@
M;&EN92UB>2UL:6YE+B`J+PH@("`@("`@("`@("`D861D<F5S<TQI;F5S(#T@
M97AP;&]D92@B7&XB+"`D861D<F5S<RD["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1A9&1R97-S3&EN97,I.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`O*B!3964@:68@:70G<R!T:&4@<W1R965T(&YU;6)E<B`F
M(&YA;64N("HO"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA<
M9"M<<RI<+UQS*BD_*%QD*WQ<9"M;82UZ02U:72E<<RLH6V$M>D$M6B!=*BDO
M)RP@)&%D9')E<W-,:6YE<ULD:5TL("1L:6YE4&%R=',I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&UA<'5R;"`N/2`G)G-T<F5E=$YU;6)E<CTG("X@=7)L
M96YC;V1E*"1L:6YE4&%R='-;,ETI("X@)R9S=')E971.86UE/2<@+B!U<FQE
M;F-O9&4H)&QI;F5087)T<ULS72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`O*B!,;V]K(&9O<B`B4W5B=7)B+"!3=&%T92(N("HO"B`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;82UZ02U:(%TJ*2P_
M7',K)R`N("1A=7-?<W1A=&5?<F5G97@@+B`G+R<L("1A9&1R97-S3&EN97-;
M)&E=+"`D;&EN95!A<G1S*2D@>PH@("`@("`@("`@("`@("`@("`@("1M87!U
M<FP@+CT@)R9S=6)U<F(])R`N('5R;&5N8V]D92@D;&EN95!A<G1S6S%=*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\J($QO;VL@9F]R
M(")3=&%T92`\-"!D:6=I="!P;W-T8V]D93XB+B`J+PH@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\H)R`N("1A=7-?<W1A=&5?<F5G97@@+B`G
M*5QS*RA<9'LT?2DO)RP@)&%D9')E<W-,:6YE<ULD:5TL("1L:6YE4&%R=',I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)G-T871E/2<@
M+B!U<FQE;F-O9&4H)&QI;F5087)T<ULQ72D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G
M+R@N*BE<;B@N*BE<<RHL7',J*%QW*RE<+C]<<RLH7&0K?%MA+7I!+5I=7&1;
M82UZ02U:75QS/UQD6V$M>D$M6EU<9"DO)RP@)&%D9')E<W,L("1A9&1R97-S
M4&%R=',I*2!["B`@("`@("`@("`@("\J($%M97)I8V%N+T-A;F%D:6%N(&%D
M9')E<W,@<W1Y;&4N("HO"B`@("`@("`@("`@("\J($UA<'%U97-T(&=E;F5R
M871E9"!M87`@*B\*("`@("`@("`@("`@)&UA<'5R;"`]("=H='1P.B\O=W=W
M+FUA<'%U97-T+F-O;2]M87!S+VUA<"YA9'`_<VEZ93UB:6<F>F]O;3TW)SL*
M("`@("`@("`@("`@)&1E<V,@/2!?*")-87!1=65S="!M87`B*3L*("`@("`@
M("`@("`@)&EC;VX@/2`G;6%P+G!N9R<["B`@("`@("`@("`@("1C;W5N=')Y
M(#T@;G5L;#L*("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S
M6S1=*2`F)B!P<F5G7VUA=&-H*"=\6V$M>D$M6EU<9%MA+7I!+5I=7',_7&1;
M82UZ02U:75QD?"<L("1A9&1R97-S4&%R='-;-%TI*2!["B`@("`@("`@("`@
M("`@("`D8V]U;G1R>2`]("=#02<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S%=*2D@>PH@("`@("`@("`@
M("`@("`@)&UA<'5R;"`N/2`G)F%D9')E<W,])R`N('5R;&5N8V]D92@D861D
M<F5S<U!A<G1S6S%=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1A9&1R97-S4&%R='-;,ETI*2!["B`@("`@("`@("`@("`@("`D
M;6%P=7)L("X]("<F8VET>3TG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R='-;
M,ETI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&%D
M9')E<W-087)T<ULS72DI('L*("`@("`@("`@("`@("`@("1M87!U<FP@+CT@
M)R9S=&%T93TG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R='-;,UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T
M<ULT72DI('L*("`@("`@("`@("`@("`@(&EF("@D8V]U;G1R>2`]/2`G0T$G
M*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)F-O=6YT<GD]
M0T$G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UA<'5R
M;"`N/2`G)GII<&-O9&4])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S1=
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@66%H;V\A(&=E;F5R
M871E9"!M87`N("HO"B`@("`@("`@("`@("1M87!U<FPR(#T@)VAT='`Z+R]U
M<RYR9"YY86AO;RYC;VTO;6%P<R]H;VUE+W-U8FUI=%]A+RHM:'1T<#HO+VUA
M<',N>6%H;V\N8V]M+VUA<',_<W)C:'1Y<&4]829G971M87`]1V5T*TUA<"8G
M.PH@("`@("`@("`@("`D9&5S8S(@/2!?*")986AO;R$@;6%P(BD["B`@("`@
M("`@("`@("1I8V]N,B`]("=M87`N<&YG)SL*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D861D<F5S<U!A<G1S6S%=*2D@>PH@("`@("`@("`@("`@("`@)&UA
M<'5R;#(@+CT@)R9A9&1R/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULQ
M72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@+RH@1VEV92!P<F5C961E
M;F-E('1O('II<&-O9&4@;W9E<B!C:71Y+W-T871E("HO"B`@("`@("`@("`@
M(&EF("AE;7!T>2@D861D<F5S<U!A<G1S6S1=*2`F)B`A96UP='DH)&%D9')E
M<W-087)T<ULR72D@)B8@(65M<'1Y*"1A9&1R97-S4&%R='-;,UTI*2!["B`@
M("`@("`@("`@("`@("`D;6%P=7)L,B`N/2`G)F-S>CTG("X@=7)L96YC;V1E
M*"1A9&1R97-S4&%R='-;,ET@+B`G("<@+B`D861D<F5S<U!A<G1S6S-=*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S
M4&%R='-;-%TI*2!["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M?"A;82UZ02U:75QD6V$M>D$M6ETI7',_*%QD6V$M>D$M6EU<9"E\)RP@)&%D
M9')E<W-087)T<ULT72P@)'!C4&%R=',I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&UA<'5R;#(@+CT@)R9C;W5N=')Y/6-A)SL*("`@("`@("`@("`@("`@
M("`@("`O*B!M86ME('-U<F4@=&AE('!O<W1A;"UC;V1E(&AA<R!A('-P86-E
M("HO"B`@("`@("`@("`@("`@("`@("`@)&%D9')E<W-087)T<ULT72`]("1P
M8U!A<G1S6S%=("X@)R`G("X@)'!C4&%R='-;,ET["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D;6%P=7)L,B`N/2`G)F-S>CTG("X@=7)L
M96YC;V1E*"1A9&1R97-S4&%R='-;-%TI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!';V]G;&4@9V5N97)A=&5D(&UA<"X@*B\*("`@("`@("`@
M("`@)&UA<'5R;#,@/2`G:'1T<#HO+VUA<',N9V]O9VQE+F-O;2]M87!S/W$]
M)R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S!=*2`N("<F:&P]96XG.PH@
M("`@("`@("`@("`D9&5S8S,@/2!?*")';V]G;&4@36%P<R(I.PH@("`@("`@
M("`@("`D:6-O;C,@/2`G;6%P+G!N9R<["@H@("`@("`@('T@96QS96EF("AP
M<F5G7VUA=&-H*"<O*"XJ/RE<<C]<;BA;02U:77LQ+#-]*2TH7&1[-7TI7',K
M*"XJ*2]I)RP@)&%D9')E<W,L("1A9&1R97-S4&%R=',I*2!["B`@("`@("`@
M("`@("\J($5U<F]P96%N(&%D9')E<W,@<W1Y;&4N("HO"B`@("`@("`@("`@
M(&EN8VQU9&4@)TAO<F1E+TY,4R]C87)S:6=N<RYP:'`G.PH@("`@("`@("`@
M("`D8V]U;G1R>2`](&%R<F%Y7W-E87)C:"A3=')I;F<Z.G5P<&5R*"1A9&1R
M97-S4&%R='-;,ETI+"`D8V%R<VEG;G,I.PH*("`@("`@("`@("`@+RH@36%P
M,C0@9V5N97)A=&5D(&UA<"X@*B\*("`@("`@("`@("`@:68@*&EN7V%R<F%Y
M*"1C;W5N=')Y+"!A<G)A>2@G86PG+"`G860G+"`G86TG+"`G87HG+"`G8F4G
M+"`G8F$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=B9R<L("=D92<L("=D:R<L("=E92<L("=F;R<L("=F:2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9R)RP@)V=E
M)RP@)V=R)RP@)V=B)RP@)VEE)RP@)VES)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:70G+"`G:'(G+"`G;'8G+"`G;&DG
M+"`G;'0G+"`G;'4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=M="<L("=M:R<L("=M9"<L("=M8R<L("=N;"<L("=N;R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!L
M)RP@)W!T)RP@)W)O)RP@)W)U)RP@)W-E)RP@)V-H)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8W,G+"`G<VLG+"`G<VDG
M+"`G97,G+"`G8WHG+"`G='(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=U82<L("=H=2<L("=B>2<L("=C>2<L("=A="<I
M*2D@>PH@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1C;W5N=')Y+"!A
M<G)A>2@G870G+"`G8F4G+"`G8V@G+"`G9&4G+"`G9&LG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G97,G+"`G9FDG
M+"`G9G(G+"`G:70G+"`G;FPG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;F\G+"`G<V4G*2DI('L*("`@("`@("`@
M("`@("`@("`@("`D;6ER<F]R(#T@)&-O=6YT<GD["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1M:7)R;W(@/2`G=6LG
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UA<'5R;"`]
M("=H='1P.B\O=W=W+B<@+B`D;6ER<F]R("X@)RYM87`R-"YC;VTO<V]U<F-E
M+V%D9')E<W,O=C(N,"XP+V-N=%]N879?;6%P;&5T+G!H<#]C:60]=F%L:61A
M=&5A9&1R)F-O=6YT<GD])R`N("1C;W5N=')Y.PH@("`@("`@("`@("`@("`@
M)&1E<V,@/2!?*")-87`R-"!M87`B*3L*("`@("`@("`@("`@("`@("1I8V]N
M(#T@)VUA<%]E=2YP;F<G.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M861D<F5S<U!A<G1S6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@("1M87!U
M<FP@+CT@)R9S=')E970])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S%=
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&%D9')E<W-087)T<ULS72DI('L*("`@("`@("`@("`@("`@("`@("`D
M;6%P=7)L("X]("<F>FEP/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULS
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1A9&1R97-S4&%R='-;-%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&UA<'5R;"`N/2`G)F-I='D])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S
M6S1=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@36%P<75E<W0@9V5N97)A=&5D(&UA<"X@*B\*("`@("`@("`@
M("`@)&UA<'5R;#(@/2`G:'1T<#HO+W=W=RYM87!Q=65S="YC;VTO;6%P<R]M
M87`N861P/V-O=6YT<GD])R`N(%-T<FEN9SHZ=7!P97(H)&-O=6YT<GDI.PH@
M("`@("`@("`@("`D9&5S8S(@/2!?*")-87!1=65S="!M87`B*3L*("`@("`@
M("`@("`@)&EC;VXR(#T@)VUA<%]E=2YP;F<G.PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1A9&1R97-S4&%R='-;,5TI*2!["B`@("`@("`@("`@("`@("`D
M;6%P=7)L,B`N/2`G)F%D9')E<W,])R`N('5R;&5N8V]D92@D861D<F5S<U!A
M<G1S6S%=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1A9&1R97-S4&%R='-;,UTI*2!["B`@("`@("`@("`@("`@("`D;6%P=7)L
M,B`N/2`G)GII<&-O9&4])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S-=
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R
M97-S4&%R='-;-%TI*2!["B`@("`@("`@("`@("`@("`D;6%P=7)L,B`N/2`G
M)F-I='D])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S1=*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&AT;6P@/2!N;#)B<BA`:'1M
M;'-P96-I86QC:&%R<R@D861D<F5S<RP@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*2D["B`@("`@("`@:68@*"%E;7!T>2@D;6%P=7)L*2D@>PH@("`@
M("`@("`@("`D:'1M;"`N/2`G)FYB<W`[)FYB<W`[)R`N($AO<F1E.CIL:6YK
M*$AO<F1E.CIE>'1E<FYA;%5R;"@D;6%P=7)L*2P@)&1E<V,L(&YU;&PL("=?
M8FQA;FLG*2`N($AO<F1E.CII;6<H)&EC;VXL("1D97-C+"`G86QI9VX](FUI
M9&1L92(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\
M+V$^)SL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D;6%P=7)L,BDI
M('L*("`@("`@("`@("`@)&AT;6P@+CT@)R9N8G-P.R<@+B!(;W)D93HZ;&EN
M:RA(;W)D93HZ97AT97)N86Q5<FPH)&UA<'5R;#(I+"`D9&5S8S(L(&YU;&PL
M("=?8FQA;FLG*2`N($AO<F1E.CII;6<H)&EC;VXR+"`D9&5S8S(L("=A;&EG
M;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI
M("X@)SPO83XG.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1M87!U
M<FPS*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G)FYB<W`[)R`N($AO<F1E
M.CIL:6YK*$AO<F1E.CIE>'1E<FYA;%5R;"@D;6%P=7)L,RDL("1D97-C,RP@
M;G5L;"P@)U]B;&%N:R<I("X@2&]R9&4Z.FEM9R@D:6-O;C,L("1D97-C,RP@
M)V%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2D@+B`G/"]A/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT
M;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?9&%T
M92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N
M(&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^='EP92T^9V5T1F]R;6%T=&5D5&EM
M92@D=F%R+3YG971686QU92@D=F%R<RDI*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5N9&5R5F%R1&ES<&QA>5]H;W5R;6EN=71E<V5C;VYD*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=&EM92`]("1V87(M/G1Y
M<&4M/F=E=%1I;65087)T<R@D=F%R+3YG971686QU92@D=F%R<RDI.PH@("`@
M("`@(&EF("@A)'9A<BT^='EP92T^7W-H;W=?<V5C;VYD<RD@>PH@("`@("`@
M("`@("!R971U<FX@*&EN="DD=&EM95LG:&]U<B==("X@)SHG("X@<W!R:6YT
M9B@G)3`R9"<L("AI;G0I)'1I;65;)VUI;G5T92==*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@*&EN="DD=&EM95LG:&]U<B==("X@
M)SHG("X@<W!R:6YT9B@G)3`R9"<L("AI;G0I)'1I;65;)VUI;G5T92==*2`N
M("<Z)R`N('-P<FEN=&8H)R4P,F0G+"`H:6YT*21T:6UE6R=S96-O;F0G72D[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P
M;&%Y7VUO;G1H>65A<B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@<F5T=7)N("AI;G0I)'9A<G,M/F=E="@D=F%R+3YG971687).86UE
M*"D@+B`G6VUO;G1H72<I("X@)RP@)R`N("AI;G0I)'9A<G,M/F=E="@D=F%R
M+3YG971687).86UE*"D@+B`G6WEE87)=)RD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<D1I<W!L87E?;6]N=&AD87EY96%R*"8D9F]R;2P@)B1V
M87(L("8D=F%R<RD*("`@('L*("`@("`@("`D9&%T92`]("1V87(M/F=E=%9A
M;'5E*"1V87)S*3L*("`@("`@("!I9B`H*&ES7V%R<F%Y*"1D871E*2`F)B`A
M96UP='DH)&1A=&5;)WEE87(G72D@)B8*("`@("`@("`@("`@("%E;7!T>2@D
M9&%T95LG;6]N=&@G72D@)B8@(65M<'1Y*"1D871E6R=D87DG72DI"B`@("`@
M("`@("`@('Q\("@A:7-?87)R87DH)&1A=&4I("8F("%E;7!T>2@D9&%T92DI
M*2!["B`@("`@("`@("`@(')E='5R;B`D=F%R+3YT>7!E+3YF;W)M871$871E
M*"1D871E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7VEN=F%L:60H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`G/'-P86X@
M8VQA<W,](F9O<FTM97)R;W(B/B<@+B!`:'1M;'-P96-I86QC:&%R<R@D=F%R
M+3YT>7!E+3YM97-S86=E+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M("X@)SPO<W!A;CXG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$
M:7-P;&%Y7VQI;FLH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@
M("`@("1V86QU97,@/2`D=F%R+3YT>7!E+3YV86QU97,["B`@("`@("`@:68@
M*"%I<W-E="@D=F%L=65S6S!=*2D@>PH@("`@("`@("`@("`D=F%L=65S(#T@
M87)R87DH)'9A;'5E<RD["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!C
M;W5N="@D=F%L=65S*3L*("`@("`@("`D:'1M;"`]("<G.PH@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("!I
M9B`H96UP='DH)'9A;'5E<ULD:5U;)W5R;"==*2!\?"!E;7!T>2@D=F%L=65S
M6R1I75LG=&5X="==*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=F%L=65S6R1I
M75LG=&%R9V5T)UTI*2!["B`@("`@("`@("`@("`@("`D=F%L=65S6R1I75LG
M=&%R9V5T)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1V86QU97-;)&E=6R=O;F-L:6-K)UTI*2!["B`@("`@("`@("`@
M("`@("`D=F%L=65S6R1I75LG;VYC;&EC:R==(#T@)R<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=F%L=65S6R1I75LG=&ET;&4G
M72DI('L*("`@("`@("`@("`@("`@("1V86QU97-;)&E=6R=T:71L92==(#T@
M)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=F%L
M=65S6R1I75LG86-C97-S:V5Y)UTI*2!["B`@("`@("`@("`@("`@("`D=F%L
M=65S6R1I75LG86-C97-S:V5Y)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`G('P@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2!(
M;W)D93HZ;&EN:R@D=F%L=65S6R1I75LG=7)L)UTL("1V86QU97-;)&E=6R=T
M97AT)UTL("=W:61G970G+"`D=F%L=65S6R1I75LG=&%R9V5T)UTL("1V86QU
M97-;)&E=6R=O;F-L:6-K)UTL("1V86QU97-;)&E=6R=T:71L92==+"`D=F%L
M=65S6R1I75LG86-C97-S:V5Y)UTI("X@0&AT;6QS<&5C:6%L8VAA<G,H)'9A
M;'5E<ULD:5U;)W1E>'0G72P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*2`N("<\+V$^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]D8FQO;VMU
M<"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F5N9&5R5F%R1&ES<&QA>5]E;G5M*"1F;W)M+"`D=F%R+"`D
M=F%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?
M9FEG;&5T*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!S
M=&%T:6,@)&9I9VQE=#L*"B`@("`@("`@:68@*"%I<W-E="@D9FEG;&5T*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U1E>'0O1FEG;&5T+G!H<"<[
M"B`@("`@("`@("`@("1F:6=L970@/2`F;F5W(%1E>'1?1FEG;&5T*"D["B`@
M("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)&9I9VQE="T^;&]A9$9O;G0H
M)'9A<BT^='EP92T^9V5T1F]N="@I*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT+3YG971-97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)SQP<F4^)R`N("1F:6=L970M/FQI;F5%8VAO*"1V87(M/G1Y<&4M/F=E=%1E
M>'0H*2D@+B`G/"]P<F4^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R26YP=71?<V5L96-T1FEL97,H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@("\J($YE961E9"!F;W(@9V]L;&5M(&IS(&-A;&QS("HO
M"B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG
M971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@
M("`@("`@)&AT;6P@/2!S<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B("\^)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@)W-E;&5C=&QI<W1?<V5L96-T:60G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<V5L96-T;&ES=%]S96QE8W1I9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/E]S96QE8W1I9"D@+@H@("`@
M("`@("`@("!S<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E
M<R(@:60](B5S(B`O/B<L("=A8W1I;VY)1"<L("=A8W1I;VY)1"<I("X*"B`@
M("`@("`@("`@("\J($9O<FT@9FEE;&0N("HO"B`@("`@("`@("`@('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B5S(B!I9#TB)7,B('9A
M;'5E/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("1V87(M/G1Y<&4M/E]S96QE8W1I9"D["@H@("`@("`@("\J($]P96X@
M=VEN9&]W(&QI;FLN("HO"B`@("`@("`@)'!A<F%M(#T@87)R87DH)'9A<BT^
M='EP92T^7VQI;FM?=&5X="P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M+3YT>7!E+3Y?;&EN:U]S='EL92P*("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R;2T^9V5T3F%M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M
M/G1Y<&4M/E]I8V]N+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/G1Y
M<&4M/E]S96QE8W1I9"D["B`@("`@("`@)&AT;6P@+CT@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F-A;&PH)V9I;&5S+W-E;&5C=&QI<W1,:6YK)RP@)'!A<F%M
M*2`N("(\8G(@+SY<;B(["@H@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?<V5L
M96-T:60I('L*("`@("`@("`@("`@)'!A<F%M(#T@87)R87DH)'9A<BT^='EP
M92T^7W-E;&5C=&ED*3L*("`@("`@("`@("`@)&9I;&5S(#T@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F-A;&PH)V9I;&5S+W-E;&5C=&QI<W1297-U;'1S)RP@
M)'!A<F%M*3L*("`@("`@("`@("`@:68@*"1F:6QE<RD@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1I9"`]/B`D9FEL92D@>PH@("`@
M("`@("`@("`@("`@("`@("1D:7(@/2!K97DH)&9I;&4I.PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE;F%M92`](&-U<G)E;G0H)&9I;&4I.PH@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("@D:60@*R`Q*2`N("<N("<["B`@("`@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9&ER*2`F)B`H)&1I<B`A/2`G
M+B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE;F%M92`]("1D
M:7(@+B`G+R<@+B`D9FEL96YA;64["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1H=&UL("X]($!H=&UL<W!E8VEA;&-H87)S
M*"1F:6QE;F%M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("(\
M8G(@+SY<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<V5L96-T3W!T:6]N<R@F)'9A;'5E<RP@)'-E;&5C=&5D5F%L=64@
M/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL8VAA
M<G,@/2!F86QS92D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)R<["B`@("`@
M("`@)'-E;"`](&9A;'-E.PH@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@
M)'9A;'5E(#T^("1D:7-P;&%Y*2!["B`@("`@("`@("`@(&EF("@A:7-?;G5L
M;"@D<V5L96-T961686QU92D@)B8@(21S96P@)B8*("`@("`@("`@("`@("`@
M("1V86QU92`]/2`D<V5L96-T961686QU92`F)@H@("`@("`@("`@("`@("`@
M<W1R;&5N*"1V86QU92D@/3T@<W1R;&5N*"1S96QE8W1E9%9A;'5E*2D@>PH@
M("`@("`@("`@("`@("`@)'-E;&5C=&5D(#T@)R!S96QE8W1E9#TB<V5L96-T
M960B)SL*("`@("`@("`@("`@("`@("1S96P@/2!T<G5E.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-E;&5C=&5D(#T@)R<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`N/2`G(#QO<'1I;VX@
M=F%L=64](B<["B`@("`@("`@("`@("1R97-U;'0@+CT@)&AT;6QC:&%R<PH@
M("`@("`@("`@("`@("`@/R`D=F%L=64*("`@("`@("`@("`@("`@(#H@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A;'5E+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I.PH@("`@("`@("`@("`D<F5S=6QT("X]("<B)R`N("1S96QE8W1E
M9"`N("<^)SL*("`@("`@("`@("`@)')E<W5L="`N/2`D:'1M;&-H87)S"B`@
M("`@("`@("`@("`@("`_("1D:7-P;&%Y"B`@("`@("`@("`@("`@("`Z($!H
M=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y+"!%3E1?455/5$53+"`D=&AI<RT^
M7V-H87)S970I.PH@("`@("`@("`@("`D<F5S=6QT("X]("(\+V]P=&EO;CY<
M;B(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("!F=6YC=&EO;B!?;75L=&E396QE8W1/<'1I;VYS*"8D=F%L=65S+"`D
M<V5L96-T961686QU97,I"B`@("!["B`@("`@("`@)')E<W5L="`]("<G.PH@
M("`@("`@("1S96P@/2!F86QS93L*("`@("`@("!F;W)E86-H("@D=F%L=65S
M(&%S("1V86QU92`]/B`D9&ES<&QA>2D@>PH@("`@("`@("`@("!I9B`H0&EN
M7V%R<F%Y*"1V86QU92P@)'-E;&5C=&5D5F%L=65S*2D@>PH@("`@("`@("`@
M("`@("`@)'-E;&5C=&5D(#T@)R!S96QE8W1E9#TB<V5L96-T960B)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S96QE8W1E9"`]
M("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@+CT@(B`\
M;W!T:6]N('9A;'5E/5PB(B`N($!H=&UL<W!E8VEA;&-H87)S*"1V86QU92P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N(")<(B1S96QE8W1E9#XB
M("X@0&AT;6QS<&5C:6%L8VAA<G,H)&1I<W!L87DL($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="D@+B`B/"]O<'1I;VX^7&XB.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H
M96-K0F]X97,H)&YA;64L("1V86QU97,L("1C:&5C:V5D5F%L=65S+"`D86-T
M:6]N<R`]("<G*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`G)SL*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1C:&5C:V5D5F%L=65S*2D@>PH@("`@("`@("`@
M("`D8VAE8VME9%9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@
M("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V86QU92`]
M/B`D9&ES<&QA>2D@>PH@("`@("`@("`@("`D8VAE8VME9"`]("AI;E]A<G)A
M>2@D=F%L=64L("1C:&5C:V5D5F%L=65S*2D@/R`G(&-H96-K960](F-H96-K
M960B)R`Z("<G.PH@("`@("`@("`@("`D<F5S=6QT("X]('-P<FEN=&8H)SQI
M;G!U="!I9#TB)7,E<R(@='EP93TB8VAE8VMB;W@B(&-L87-S/2)C:&5C:V)O
M>"(@;F%M93TB)7-;72(@=F%L=64](B5S(B5S)7,@+SX\;&%B96P@9F]R/2(E
M<R5S(CXF;F)S<#LE<SPO;&%B96P^/&)R("\^)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1N86UE+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!`:'1M;'-P96-I86QC:&%R<R@D;F%M92P@14Y47U%53U1%4RP@)'1H:7,M
M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H
M=&UL<W!E8VEA;&-H87)S*"1V86QU92P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C:&5C
M:V5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%C=&EO;G,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC
M:&%R<R@D;F%M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)&1I<W!L87DL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@("`@("`@("`D
M:2LK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)A9&EO0G5T=&]N<R@D;F%M92P@)'9A;'5E<RP@
M)&-H96-K961686QU92`](&YU;&PL("1A8W1I;VYS(#T@)R<I"B`@("!["B`@
M("`@("`@)')E<W5L="`]("<G.PH@("`@("`@("1I(#T@,#L*("`@("`@("!F
M;W)E86-H("@D=F%L=65S(&%S("1V86QU92`]/B`D9&ES<&QA>2D@>PH@("`@
M("`@("`@("`D8VAE8VME9"`]("@A:7-?;G5L;"@D8VAE8VME9%9A;'5E*2`F
M)B`D=F%L=64@/3T@)&-H96-K961686QU92D@/R`G(&-H96-K960](F-H96-K
M960B)R`Z("<G.PH@("`@("`@("`@("`D<F5S=6QT("X]('-P<FEN=&8H)SQI
M;G!U="!I9#TB)7,E<R(@='EP93TB<F%D:6\B(&-L87-S/2)C:&5C:V)O>"(@
M;F%M93TB)7,B('9A;'5E/2(E<R(E<R5S("\^/&QA8F5L(&9O<CTB)7,E<R(^
M)FYB<W`[)7,\+VQA8F5L/CQB<B`O/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D;F%M92P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT
M;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D=F%L=64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VAE8VME9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1I;VYS+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H
M)&YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@("`@("`@("`@)&DK*SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]G96Y)1"@D;F%M92P@)&9U;&QT86<@/2!T<G5E*0H@("`@
M>PH@("`@("`@("1N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N("1F
M=6QL=&%G(#\@)VED/2(G("X@)&YA;64@+B`G(B<@.B`D;F%M93L*("`@('T*
M"B`@("!F=6YC=&EO;B!?9V5N06-T:6]N4V-R:7!T*"8D9F]R;2P@)&%C=&EO
M;BP@)'9A<FYA;64I"B`@("!["B`@("`@("`@)&AT;6P@/2`G)SL*("`@("`@
M("`D=')I9V=E<G,@/2`D86-T:6]N+3YG9714<FEG9V5R*"D["B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D=')I9V=E<G,I*2!["B`@("`@("`@("`@("1T<FEG
M9V5R<R`](&%R<F%Y*"1T<FEG9V5R<RD["B`@("`@("`@?0H@("`@("`@("1J
M<R`]("1A8W1I;VXM/F=E=$%C=&EO;E-C<FEP="@D9F]R;2P@)'1H:7,L("1V
M87)N86UE*3L*("`@("`@("!F;W)E86-H("@D=')I9V=E<G,@87,@)'1R:6=G
M97(I('L*("`@("`@("`@("`@:68@*"1T<FEG9V5R(#T]("=O;FQO860G*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$]N3&]A9$IA=F%S8W)I<'0H
M)&IS*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H
M=&UL("X]("<@)R`N("1T<FEG9V5R("X@)STB)R`N("1J<R`N("<B)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&AT;6P["B`@
M("!]"@H@("`@9G5N8W1I;VX@7V=E=$%C=&EO;E-C<FEP=',H)B1F;W)M+"`F
M)'9A<BD*("`@('L*("`@("`@("`D86-T:6]N<R`]("<G.PH@("`@("`@(&EF
M("@D=F%R+3YH87-!8W1I;VXH*2D@>PH@("`@("`@("`@("`D=F%R;F%M92`]
M("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@)&%C=&EO;B`])B`D
M=F%R+3Y?86-T:6]N.PH@("`@("`@("`@("`D=')I9V=E<G,@/2`D86-T:6]N
M+3YG9714<FEG9V5R*"D["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'1R
M:6=G97)S*2D@>PH@("`@("`@("`@("`@("`@)'1R:6=G97)S(#T@87)R87DH
M)'1R:6=G97)S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:G,@/2`D
M86-T:6]N+3YG971!8W1I;VY38W)I<'0H)&9O<FTL("1T:&ES+"`D=F%R;F%M
M92D["B`@("`@("`@("`@(&9O<F5A8V@@*"1T<FEG9V5R<R!A<R`D=')I9V=E
M<BD@>PH@("`@("`@("`@("`@("`@:68@*"1T<FEG9V5R(#T]("=O;FQO860G
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1/;DQO861*879A
M<V-R:7!T*"1J<RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1A8W1I;VYS("X]("<@)R`N("1T<FEG9V5R("X@)STB
M)R`N("1J<R`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&%C=&EO;G,["B`@("!]"@H@
M("`@9G5N8W1I;VX@7V%D9$]N3&]A9$IA=F%S8W)I<'0H)'-C<FEP="D*("`@
M('L*("`@("`@("`D=&AI<RT^7V]N3&]A9$I36UT@/2`D<V-R:7!T.PH@("`@
M?0H*("`@(&9U;F-T:6]N(')E;F1E<D5N9"@I"B`@("!["B`@("`@("`@:68@
M*&-O=6YT*"1T:&ES+3Y?;VY,;V%D2E,I*2!["B`@("`@("`@("`@(')E='5R
M;B`B/'-C<FEP="!T>7!E/5PB=&5X="]J879A<V-R:7!T7"(^(B`N"B`@("`@
M("`@("`@("`@("`B/"$M+5QN(B`N("!I;7!L;V1E*")<;B(L("1T:&ES+3Y?
M;VY,;V%D2E,I("X@(EQN+R\@+2T^7&XB("X*("`@("`@("`@("`@("`@("(\
M+W-C<FEP=#XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`G)SL*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]522]687)296YD97)E<B]T86)L97-E=%]H
M=&UL+G!H<```````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8P-#0`,3`U,34T,S$P-C$`,#(T
M,S$T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]T86)L97-E=%]H=&UL+G!H<"QV(#$N,RXR+C$@,C`P-2\Q,"\Q
M."`Q,3HP,3HS-B!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?54D*
M("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J+PIC;&%S<R!(;W)D95]525]687)2
M96YD97)E<E]T86)L97-E=%]H=&UL(&5X=&5N9',@2&]R9&5?54E?5F%R4F5N
M9&5R97)?:'1M;"!["@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W1A
M8FQE<V5T*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D
M:&5A9&5R(#T@)'9A<BT^='EP92T^9V5T2&5A9&5R*"D["B`@("`@("`@)&YA
M;64@("`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`D=F%L=65S(#T@
M)'9A<BT^9V5T5F%L=65S*"D["B`@("`@("`@)&-H96-K961686QU97,@/2`D
M=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@)&%C=&EO;G,@/2`D=&AI
M<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I.PH*("`@("`@("`D
M:'1M;"`]("<\=&%B;&4@=VED=&@](C$P,"4B(&-L87-S/2)I=&5M(B!C96QL
M<W!A8VEN9STB,2(^/'1R(&-L87-S/2)S96QE8W1E9"(^)R`N"B`@("`@("`@
M("`@("<\=&@@8VQA<W,](G=I9&=E="(@86QI9VX](G)I9VAT(B!W:61T:#TB
M,24B/B9N8G-P.SPO=&@^)SL*("`@("`@("!F;W)E86-H("@D:&5A9&5R(&%S
M("1C;VQ?=&ET;&4I('L*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G
M/'1H(&%L:6=N/2)L969T(B!C;&%S<STB=VED9V5T(CXE<SPO=&@^)RP@)&-O
M;%]T:71L92D["B`@("`@("`@?0H@("`@("`@("1H=&UL("X]("<\+W1R/B<[
M"@H@("`@("`@(&EF("@A:7-?87)R87DH)&-H96-K961686QU97,I*2!["B`@
M("`@("`@("`@("1C:&5C:V5D5F%L=65S(#T@87)R87DH*3L*("`@("`@("!]
M"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@
M)'9A;'5E(#T^("1D:7-P;&%Y<RD@>PH@("`@("`@("`@("`D8VQA<W,@/2`G
M:71E;2<@+B`H)&D@*R`Q*2`E(#(["B`@("`@("`@("`@("1C:&5C:V5D(#T@
M*&EN7V%R<F%Y*"1V86QU92P@)&-H96-K961686QU97,I*2`_("<@8VAE8VME
M9#TB8VAE8VME9"(G(#H@)R<["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN
M=&8H)SQT<B!C;&%S<STB)7,B/B<L("1C;&%S<RD@+@H@("`@("`@("`@("`@
M("`@<W!R:6YT9B@G/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!I9#TB)7,E
M<R(@='EP93TB8VAE8VMB;W@B(&YA;64](B5S6UTB('9A;'5E/2(E<R(E<R5S
M("\^/"]T9#XG+`H@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92P*("`@
M("`@("`@("`@("`@("`@("`@("`@)&DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C:&5C:V5D+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D86-T:6]N<RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M:7-P;&%Y<R!A<R`D8V]L*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2!S
M<')I;G1F*"<\=&0@86QI9VX](FQE9G0B/B9N8G-P.R5S/"]T9#XG+"`D8V]L
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]T<CXG
M.PH@("`@("`@("`@("`D:2LK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1H=&UL("X@)SPO=&%B;&4^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R1&ES<&QA>5]T86)L97-E="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@)&AE861E<B`]("1V87(M/G1Y<&4M/F=E=$AE861E
M<B@I.PH@("`@("`@("1N86UE("`@/2`D=F%R+3YG971687).86UE*"D["B`@
M("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@("1C
M:&5C:V5D5F%L=65S(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@
M("1A8W1I;VYS(#T@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D
M=F%R*3L*"B`@("`@("`@)&AT;6P@/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!C
M96QL<W!A8VEN9STB,2(^/'1R(&-L87-S/2)S96QE8W1E9"(^)R`N"B`@("`@
M("`@("`@("<\=&@@8VQA<W,](G=I9&=E="(@86QI9VX](G)I9VAT(B!W:61T
M:#TB,24B/B9N8G-P.SPO=&@^)SL*("`@("`@("!F;W)E86-H("@D:&5A9&5R
M(&%S("1C;VQ?=&ET;&4I('L*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT
M9B@G/'1H(&%L:6=N/2)L969T(B!C;&%S<STB=VED9V5T(CXE<SPO=&@^)RP@
M)&-O;%]T:71L92D["B`@("`@("`@?0H@("`@("`@("1H=&UL("X]("<\+W1R
M/B<["@H@("`@("`@(&EF("@A:7-?87)R87DH)&-H96-K961686QU97,I*2![
M"B`@("`@("`@("`@("1C:&5C:V5D5F%L=65S(#T@87)R87DH*3L*("`@("`@
M("!]"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1V86QU97,@
M87,@)'9A;'5E(#T^("1D:7-P;&%Y<RD@>PH@("`@("`@("`@("`D8VQA<W,@
M("`]("=I=&5M)R`N("@D:2`K(#$I("4@,CL*("`@("`@("`@("`@)&-H96-K
M960@/2`H:6Y?87)R87DH)'9A;'5E+"`D8VAE8VME9%9A;'5E<RDI(#\@)UL@
M/'-T<F]N9SX\9F]N="!C;VQO<CUG<F5E;CY6/"]F;VYT/CPO<W1R;VYG/B!=
M)R`Z("=;(#QS=')O;F<^/&9O;G0@8V]L;W(]<F5D/E@\+V9O;G0^/"]S=')O
M;F<^(%TG.PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\='(@8VQA
M<W,](B5S(CXG+"`D8VQA<W,I("X*("`@("`@("`@("`@("`@('-P<FEN=&8H
M)SQT9"!A;&EG;CTB8V5N=&5R(CXE<SPO=&0^)RP@)&-H96-K960I.PH@("`@
M("`@("`@("!F;W)E86-H("@D9&ES<&QA>7,@87,@)&-O;"D@>PH@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1D(&%L:6=N/2)L969T(CXF
M;F)S<#LE<SPO=&0^)RP@)&-O;"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&AT;6P@+CT@)SPO='(^)SL*("`@("`@("`@("`@)&DK*SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N("<\+W1A8FQE/B<["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5VED9V5T+G!H<```````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,S4R`#$P-3$U-#,Q,#8Q`#`R
M,#0W,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($AO<F1E7U5)7U=I9&=E=#HZ(&-L87-S('!R
M;W9I9&5S(&)A<V4@9G5N8W1I;VYA;&ET>2!F;W(@;W1H97(@2&]R9&4*("H@
M54D@96QE;65N=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U5)+U5)+U=I
M9&=E="YP:'`L=B`Q+C<N,3`N."`R,#`V+S`V+S(P(#`Y.C`X.C0U(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC
M92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M<VEN8V4@("!(;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@
M*B\*8VQA<W,@2&]R9&5?54E?5VED9V5T('L*"B`@("`O*BH*("`@("`J($%N
M>2!V87)I86)L97,@=&AA="!S:&]U;&0@8F4@<')E<V5R=F5D(&EN(&%L;"!O
M9B!T:&4@=VED9V5T)W,*("`@("`J(&QI;FMS+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<')E<V5R=F4@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AI<R!W:61G970N("!4
M:&ES(&ES('5S960@87,@=&AE(&)A<V5N86UE(&9O<B!V87)I86)L97,*("`@
M("`J('=E(&%C8V5S<R!A;F0@;6%N:7!U;&%T92X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]N86UE.PH*("`@("\J*@H@
M("`@("H@02!R969E<F5N8V4@=&\@82!687)I86)L97,Z.B!O8FIE8W0@=&AI
M<R!W:61G970@=VEL;"!U<V4@86YD"B`@("`@*B!M86YI<'5L871E+@H@("`@
M("H*("`@("`J($!V87(@5F%R:6%B;&5S"B`@("`@*B\*("`@('9A<B`D7W9A
M<G,["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!N86UE(#T^('9A;'5E
M('!A:7)S('=H:6-H(&-O;F9I9W5R92!H;W<@=&AI<R!W:61G970*("`@("`J
M(&)E:&%V97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]C;VYF:6<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W0@82!N
M97<@54D@5VED9V5T(&EN=&5R9F%C92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("`@5&AE(&YA;64@;V8@=&AE('9A<FEA8FQE('=H
M:6-H('=I;&P@=')A8VL@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(%5)('=I9&=E="=S('-T871E+@H@("`@("H@0'!A<F%M(%9A<FEA
M8FQE<R`F)'9A<G,@($$@5F%R:6%B;&5S.CH@;V)J96-T+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1C;VYF:6<@("`@(%1H92!W:61G970G<R!C;VYF:6=U<F%T
M:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]525]7:61G970H)&YA
M;64L("8D=F%R<RP@)&-O;F9I9R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]V87)S(#T@
M)B1V87)S.PH@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)&-O;F9I9SL*("`@
M('T*"B`@("`O*BH*("`@("`J($EN<W1R=6-T($AO<F1E7U5)7U=I9&=E=#HZ
M('1O('!R97-E<G9E(&$@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=F%R("`@5&AE(&YA;64@;V8@=&AE('9A<FEA8FQE('1O('!R
M97-E<G9E+@H@("`@("H@0'!A<F%M(&UI>&5D("1V86QU92`@5&AE('9A;'5E
M(&]F('1H92!V87)I86)L92!T;R!P<F5S97)V92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')E<V5R=F4H)'9A<BP@)'9A;'5E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<')E<V5R=F5;)'9A<ET@/2`D=F%L=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V%D9%!R97-E<G9E9"@D;&EN:RD*("`@('L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W!R97-E<G9E(&%S("1V87).86UE(#T^("1V87)686QU92D@>PH@
M("`@("`@("`@("`D;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<B@D;&EN:RP@
M)'9A<DYA;64L("1V87)686QU92D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D;&EN:SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<B!T:&4@=VED
M9V5T+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D9&%T82`@5&AE('=I9&=E="=S('-T871E(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@I('M]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5&%B<RYP:'``
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-C(P`#$P
M-3$U-#,Q,#8Q`#`R,#$S-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]7:61G970N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?54E?
M5&%B<SHZ(&-L87-S(&UA;F%G97,@86YD(')E;F1E<G,@82!T86(M;&EK92!I
M;G1E<F9A8V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U5)+U5)+U1A8G,N
M<&AP+'8@,2XR-RXV+C$P(#(P,#8O,#8O,C`@,#DZ,#@Z-#4@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#,@4F]B97)T($4N($-O>6QE(#QR
M;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ"B`J($!P
M86-K86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525]486)S(&5X=&5N
M9',@2&]R9&5?54E?5VED9V5T('L*"B`@("`O*BH*("`@("`J(%1H92!A<G)A
M>2!O9B!T86)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?=&%B<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!9&0@
M82!T86(@=&\@=&AE(&EN=&5R9F%C92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T:71L92`@("!4:&4@=&5X="!W:&EC:"!A<'!E87)S(&]N('1H
M92!T86(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1L:6YK("`@("!4:&4@=&%R
M9V5T('!A9V4N"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@("!%:71H
M97(@82!S=')I;F<@=F%L=64@=&\@<V5T('1H92!T86(@=F%R:6%B;&4@=&\L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!O<B!A(&AA<V@@;V8@
M<&%R86UE=&5R<RX@268@86X@87)R87DL('1H92!T86(@=F%R:6%B;&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-A;B!B92!S970@8GD@=&AE
M("=T86)N86UE)R!K97DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%1A8B@D
M=&ET;&4L("1L:6YK+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A
M;7,@/2!A<G)A>2@G=&%B;F%M92<@/3X@)'!A<F%M<RD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?=&%B<UM=(#T@87)R87E?;65R9V4H87)R87DH)W1I
M=&QE)R`]/B`D=&ET;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&EN:R<@/3X@)&QI;FLL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&%B;F%M92<@/3X@;G5L
M;"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!T:71L
M92!O9B!T:&4@=&%B('=I=&@@=&AE('-P96-I9FEE9"!N86UE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1A8FYA;64@(%1H92!N86UE(&]F('1H
M92!T86(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T86(G
M<R!T:71L92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&ET;&5&<F]M06-T
M:6]N*"1T86)N86UE*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M=&%B<R!A<R`D=&%B*2!["B`@("`@("`@("`@(&EF("@D=&%B6R=T86)N86UE
M)UT@/3T@)'1A8FYA;64I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&%B
M6R=T:71L92==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<G,@=&AE
M('1A8G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-T:79E7W1A
M8B`@268@<W!E8VEF:65D+"!T:&4@;F%M92!O9B!T:&4@86-T:79E('1A8BX@
M268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YO="P@=&AE
M(&%C=&EV92!T86(@:7,@9&5T97)M:6YE9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@875T;VUA=&EC86QL>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N9&5R*"1A8W1I=F5?=&%B(#T@;G5L;"D*("`@('L*("`@("`@
M("`D:'1M;"`]("(\9&EV(&-L87-S/5PB=&%B<V5T7"(^/'5L/EQN(CL*"B`@
M("`@("`@)&9I<G-T(#T@=')U93L*("`@("`@("`D86-T:79E(#T@)%]315)6
M15);)U!(4%]314Q&)UT@+B`D=&AI<RT^7W9A<G,M/F=E="@D=&AI<RT^7VYA
M;64I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1A8G,@87,@)'1A8BD@
M>PH@("`@("`@("`@("`D;&EN:R`]("1T:&ES+3Y?861D4')E<V5R=F5D*"1T
M86);)VQI;FLG72D["B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^
M7VYA;64I("8F("%I<U]N=6QL*"1T86);)W1A8FYA;64G72DI('L*("`@("`@
M("`@("`@("`@("1L:6YK(#T@571I;#HZ861D4&%R86UE=&5R*"1L:6YK+"`D
M=&AI<RT^7VYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&%B6R=T86)N86UE)UTI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D8VQA<W,@/2`G)SL*("`@("`@("`@("`@:68@*"@A:7-?
M;G5L;"@D86-T:79E7W1A8BD@)B8@)&%C=&EV95]T86(@/3T@)'1A8ELG=&%B
M;F%M92==*2!\?`H@("`@("`@("`@("`@("`@*"1A8W1I=F4@/3T@)'1A8ELG
M;&EN:R==("X@)'1A8ELG=&%B;F%M92==*2D@>PH@("`@("`@("`@("`@("`@
M)&-L87-S(#T@)R!C;&%S<STB86-T:79E5&%B(B<["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1A8ELG=&%R9V5T)UTI*2!["B`@
M("`@("`@("`@("`@("`D=&%B6R=T87)G970G72`]("<G.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T86);)V]N8VQI8VLG72DI
M('L*("`@("`@("`@("`@("`@("1T86);)V]N8VQI8VLG72`]("<G.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D86-C97-S:V5Y(#T@2&]R9&4Z.F=E
M=$%C8V5S<TME>2@D=&%B6R=T:71L92==*3L*"B`@("`@("`@("`@("1H=&UL
M("X]("<\;&DG("X@)&-L87-S("X@)SXG("X*("`@("`@("`@("`@("`@($AO
M<F1E.CIL:6YK*"1L:6YK+"`G)RP@)R<L("1T86);)W1A<F=E="==+"`D=&%B
M6R=O;F-L:6-K)UTL(&YU;&PL("1A8V-E<W-K97DI("X*("`@("`@("`@("`@
M("`@($AO<F1E.CIH:6=H;&EG:'1!8V-E<W-+97DH<W1R7W)E<&QA8V4H)R`G
M+"`G)FYB<W`[)RP@)'1A8ELG=&ET;&4G72DL("1A8V-E<W-K97DI("X*("`@
M("`@("`@("`@("`@("(\+V$^(#PO;&D^7&XB.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1H=&UL("X@(CPO=6P^/"]D:78^/&)R(&-L87-S/5PB8VQE
M87)<(B`O/EQN(CL*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+TQA;F=U86=E
M+G!H<```````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(T,``Q
M,#4Q-30S,3`V,0`P,C`W-C0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]525],86YG
M=6%G93HZ(&-L87-S('!R;W9I9&5S(&$@=VED9V5T(&9O<B!C:&%N9VEN9R!T
M:&4*("H@8W5R<F5N=&QY('-E;&5C=&5D(&QA;F=U86=E+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]522]522],86YG=6%G92YP:'`L=B`Q+C4N,3`N-R`R
M,#`V+S`V+S(P(#`Y.C`X.C0U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC
M;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<VEN8V4@("!(;W)D95]522`P+C`N
M,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*8VQA<W,@2&]R9&5?54E?3&%N
M9W5A9V4@>PH*("`@("\J*@H@("`@("H@4F5N9&5R('1H92!L86YG=6%G92!S
M96QE8W1I;VXN"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&9O<FT@(%)E='5R;B!T:&4@<V5L96-T:6]N
M(&)O>"!A<R!A;B!C;VUP;&5T92!S=&%N9&%L;VYE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@9F]R;2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE($A434P@<V5L96-T:6]N(&)O>"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N9&5R*"D*("`@('L*("`@("`@("`D:'1M;"`]("<G.PH@("`@
M("`@(&EF("@A)$=,3T)!3%-;)W!R969S)UTM/FES3&]C:V5D*"=L86YG=6%G
M92<I*2!["B`@("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=L86YG
M=6%G92YJ<R<L("=H;W)D92<I.PH@("`@("`@("`@("`D7U-%4U-)3TY;)VAO
M<F1E7VQA;F=U86=E)UT@/2!.3%,Z.G-E;&5C="@I.PH@("`@("`@("`@("`D
M:'1M;"`]('-P<FEN=&8H)SQF;W)M(&YA;64](FQA;F=U86=E(B!A8W1I;VX]
M(B5S(CXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.G5R
M;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E
M)RD@+B`G+W-E<G9I8V5S+VQA;F=U86=E+G!H<"<L(&9A;'-E+"`M,2DI.PH@
M("`@("`@("`@("`D:'1M;"`N/2`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB=7)L(B!V86QU93TB)R`N($!H=&UL<W!E8VEA;&-H87)S*$AO<F1E.CIS
M96QF57)L*&9A;'-E+"!F86QS92P@=')U92DI("X@)R(@+SXG.PH@("`@("`@
M("`@("`D:'1M;"`N/2`G/'-E;&5C="!N86UE/2)N97=?;&%N9R(@;VYC:&%N
M9V4](F1O8W5M96YT+FQA;F=U86=E+G-U8FUI="@I(CXG.PH@("`@("`@("`@
M("!F;W)E86-H("@D1TQ/0D%,4ULG;FQS)UU;)VQA;F=U86=E<R==(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'-E;"`]("@D:V5Y(#T]
M("1?4T534TE/3ELG:&]R9&5?;&%N9W5A9V4G72D@/R`G('-E;&5C=&5D/2)S
M96QE8W1E9"(G(#H@)R<["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`B/&]P
M=&EO;B!V86QU93U<(B1K97E<(B1S96P^)'9A;#PO;W!T:6]N/B(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SPO<V5L96-T/CPO9F]R
M;3XG.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]687)296YD97)E<BYP
M:'``````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`R,C$`,3`U,34T
M,S$P-C$`,#(Q-#4U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?54E?5F%R4F5N9&5R
M97(Z.B!C;&%S<R!P<F]V:61E<R!B87-E(&9U;F-T:6]N86QI='D@9F]R"B`J
M(&]T:&5R($AO<F1E(%5)(&5L96UE;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<BYP:'`L=B`Q+C$R+C$P+C$P(#(P,#8O
M,#8O,C`@,#DZ,#@Z-#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ"B`J
M($!P86-K86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525]687)296YD
M97)E<B!["@H@("`@+RHJ"B`@("`@*B!087)A;65T97)S('=H:6-H(&-H86YG
M92!T:&ES(')E;F1E<F5R)W,@8F5H879I;W(N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,["@H@("`@+RHJ"B`@
M("`@*B!#:&%R<V5T('1O('5S92!F;W(@;W5T<'5T+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-H87)S970["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(')E;F1E<F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@;F%M92!O9B!T:&4@
M=F%R:6%B;&4@=VAI8V@@=VEL;"!T<F%C:R!T:&ES(%5)"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@=VED9V5T)W,@<W1A=&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7U5)7U9A<E)E;F1E<F5R*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*
M("`@("`@("`D=&AI<RT^7V-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@2&]R9&5?
M54E?5F%R4F5N9&5R97(Z.B!I;G-T86YC92X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&1R:79E<B`@5&AI<R!I<R!T:&4@<F5N9&5R97(@<W5B8VQA
M<W,@=V4@=VEL;"!I;G-T86YT:6%T92X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!)9B!A;B!A<G)A>2!I<R!P87-S960L('1H92!F:7)S="!E;&5M
M96YT(&ES('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&QI8G)A
M<GD@<&%T:"!A;F0@=&AE('-E8V]N9"!E;&5M96YT(&ES('1H92!D<FEV97(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!N86UE+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<G,@<W!E8VEF:6,@=&\@=&AE
M('-U8F-L87-S+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?54E?5F%R
M4F5N9&5R97(@($$@2&]R9&5?54E?5F%R4F5N9&5R97(Z.B!S=6)C;&%S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N8V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I
M=F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@)&1R:79E<ELP73L*("`@("`@
M("`@("`@)&1R:79E<B`]("1D<FEV97);,5T["B`@("`@("`@?0H*("`@("`@
M("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("@A
M96UP='DH)&%P<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI
M8B]522]687)296YD97)E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]687)296YD97)E<B\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]687)2
M96YD97)E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]522]687)296YD
M97)E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@
M("1C;&%S<R`]("=(;W)D95]525]687)296YD97)E<E\G("X@)&1R:79E<CL*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)'9R(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'9R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@
M9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'9R.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@:6YS=&%N
M8V4L(&-O;G-T<G5C=&EN9R!O;F4@=VET:"!T:&4*("`@("`J('-P96-I9FEE
M9"!P87)A;65T97)S(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D<FEV97(@(%1H:7,@:7,@=&AE(')E;F1E<F5R('-U8F-L
M87-S('=E('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@:6YS
M=&%N=&EA=&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@(%!A<F%M
M971E<G,@<W!E8VEF:6,@=&\@=&AE('-U8F-L87-S+@H@("`@("H*("`@("`J
M($!R971U<FX@2&]R9&5?54E?5F%R4F5N9&5R97(@($$@2&]R9&5?54E?5F%R
M4F5N9&5R97(Z.B!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S
M:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@<W1A=&EC("1C86-H93L*"B`@("`@("`@:68@*&ES7VYU;&PH)&1R
M:79E<BDI('L*("`@("`@("`@("`@)&-L87-S(#T@)TAO<F1E7U5)7U9A<E)E
M;F1E<F5R)SL*("`@("`@("!]"B`@("`@("`@)&ME>2`]('-E<FEA;&EZ92AA
M<G)A>2`H)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H
M)&-A8VAE6R1K97E=*2D@>PH@("`@("`@("`@("`D8V%C:&5;)&ME>5T@/2`F
M2&]R9&5?54E?5F%R4F5N9&5R97(Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M
M<RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V%C:&5;)&ME>5T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296YD97)S(&$@=F%R:6%B;&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M($AO<F1E7T9O<FT@)B1F;W)M("`@("`@("`@("!2
M969E<F5N8V4@=&\@82!(;W)D95]&;W)M(&EN<W1A;F-E+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!N=6QL(&EF(&YO
M;F4@:7,@879A:6QA8FQE+@H@("`@("H@0'!A<F%M($AO<F1E7T9O<FU?5F%R
M:6%B;&4@)B1V87(@("!2969E<F5N8V4@=&\@82!(;W)D95]&;W)M7U9A<FEA
M8FQE+@H@("`@("H@0'!A<F%M(%9A<FEA8FQE<R`F)'9A<G,@("`@("`@("`@
M("!!(%9A<FEA8FQE<R!I;G-T86YC92X*("`@("`J($!P87)A;2!B;V]L96%N
M("1I<TEN<'5T("`@("`@("`@("`@5VAE=&AE<B!T:&ES(&ES(&%N(&EN<'5T
M(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S+"`D:7-);G!U="`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@D:7-);G!U="D@>PH@("`@("`@("`@("`D<W1A=&4@/2`G26YP=70G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=&%T92`]("=$:7-P
M;&%Y)SL*("`@("`@("!]"B`@("`@("`@)&UE=&AO9"`](")?<F5N9&5R5F%R
M)'MS=&%T97U?(B`N("1V87(M/G1Y<&4M/F=E=%1Y<&5.86UE*"D["B`@("`@
M("`@:68@*"%`;65T:&]D7V5X:7-T<R@D=&AI<RP@)&UE=&AO9"DI('L*("`@
M("`@("`@("`@)&UE=&AO9"`](")?<F5N9&5R5F%R)'MS=&%T97U$969A=6QT
M(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3XD;65T:&]D*"1F
M;W)M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YI
M<VAE<R!R96YD97)I;F<@869T97(@86QL(&9I96QD<R!A<F4@;W5T<'5T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)%;F0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`G)SL*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U!A9V5R+G!H<```````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S4V-@`Q,#4Q-30S,3`V,0`P,C`S
M,38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O5VED
M9V5T+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U5)7U!A9V5R.CH@<')O=FED
M97,@;&EN:W,@=&\@:6YD:79I9'5A;"!P86=E<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP+'8@,2XW+C$P+C@@,C`P-B\P-B\R
M,"`P.3HP.#HR-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C:RYQ8RYC83X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($)E;B!#:&%V970@/&)E;D!C:&%V970N
M;F5T/@H@*B!`875T:&]R("!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C
M:RYQ8RYC83X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ"B`J($!P86-K
M86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525]086=E<B!E>'1E;F1S
M($AO<F1E7U5)7U=I9&=E="!["@H@("`@9G5N8W1I;VX@2&]R9&5?54E?4&%G
M97(H)&YA;64L("8D=F%R<RP@)&-O;F9I9RD*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1C;VYF:6=;)W!A9V5?;&EM:70G72DI('L*("`@("`@("`@("`@
M)&-O;F9I9ULG<&%G95]L:6UI="==(#T@,3`["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-S970H)&-O;F9I9ULG<&5R<&%G92==*2D@>PH@("`@("`@("`@
M("`D8V]N9FEG6R=P97)P86=E)UT@/2`Q,#`["B`@("`@("`@?0H@("`@("`@
M('!A<F5N=#HZ2&]R9&5?54E?5VED9V5T*"1N86UE+"`D=F%R<RP@)&-O;F9I
M9RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@=&AE('!A9V5R+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!(5$U,(&-O9&4@8V]N=&%I
M;FEN9R!A(&-E;G1E<F5D('1A8FQE('=I=&@@=&AE('!A9V5R"B`@("`@*B`@
M("`@(&QI;FMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<')E9G,L("1R96=I<W1R>2P@)&-O;F8["@H@
M("`@("`@("1N=6T@/2`D=&AI<RT^7V-O;F9I9ULG;G5M)UT["B`@("`@("`@
M)'5R;"`]("1T:&ES+3Y?8V]N9FEG6R=U<FPG73L*("`@("`@("`D<&%G95]L
M:6UI="`]("1T:&ES+3Y?8V]N9FEG6R=P86=E7VQI;6ET)UT["B`@("`@("`@
M)'!E<G!A9V4@/2`D=&AI<RT^7V-O;F9I9ULG<&5R<&%G92==.PH*("`@("`@
M("`D8W5R<F5N=%]P86=E(#T@)'1H:7,M/E]V87)S+3YG970H)'1H:7,M/E]N
M86UE*3L*"B`@("`@("`@+R\@1FEG=7)E(&]U="!H;W<@;6%N>2!P86=E<R!T
M:&5R92!W:6QL(&)E+@H@("`@("`@("1P86=E<R`]("@D;G5M("\@)'!E<G!A
M9V4I.PH@("`@("`@(&EF("AI<U]I;G1E9V5R*"1P86=E<RDI('L*("`@("`@
M("`@("`@)'!A9V5S+2T["B`@("`@("`@?0H@("`@("`@("1P86=E<R`]("AI
M;G0I)'!A9V5S.PH*("`@("`@("`O+R!2971U<FX@;F]T:&EN9R!I9B!T:&5R
M92!I<R!O;FQY(&]N92!P86=E+@H@("`@("`@(&EF("@D<&%G97,@/3T@,"!\
M?"`D;G5M(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M('T*"B`@("`@("`@)&AT;6P@/2`G/&1I=B!C;&%S<STB<&%G97(B/B<["@H@
M("`@("`@("\O($-R96%T92!T:&4@)SP\(%!R978G(&QI;FL@:68@=V4@87)E
M(&YO="!O;B!T:&4@9FER<W0@<&%G92X*("`@("`@("`D;&EN:R`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D=7)L+"`D=&AI<RT^7VYA;64L("1C=7)R96YT7W!A
M9V4@+2`Q*3L*("`@("`@("`D;&EN:R`]("1T:&ES+3Y?861D4')E<V5R=F5D
M*"1L:6YK*3L*("`@("`@("!I9B`H)&-U<G)E;G1?<&%G92`^(#`I('L*("`@
M("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"1L:6YK*2P@)R<L("=P<F5V)RD@+B!H=&UL<W!E8VEA;&-H87)S
M*%\H(CQ0<F5V:6]U<R(I*2`N("<\+V$^)SL*("`@("`@("!]"@H@("`@("`@
M("\O($9I9W5R92!O=70@=&AE('1O<"`F(&)O='1O;2!D:7-P;&%Y(&QI;6ET
M<RX*("`@("`@("`D8F]T=&]M(#T@;6%X*#`L("1C=7)R96YT7W!A9V4@+2`H
M)'!A9V5?;&EM:70@+R`R*2`K(#$I.PH@("`@("`@("1T;W`@/2`D8F]T=&]M
M("L@)'!A9V5?;&EM:70@+2`Q.PH@("`@("`@(&EF("@D=&]P("T@,2`^("1P
M86=E<RD@>PH@("`@("`@("`@("`D8F]T=&]M("T]("@D=&]P("T@,2D@+2`D
M<&%G97,["B`@("`@("`@("`@("1T;W`@/2`D<&%G97,@*R`Q.PH@("`@("`@
M('T*"B`@("`@("`@+R\@0W)E871E(&)O='1O;2`G6W@M>5TG(&QI;FL@:68@
M;F5C97-S87)Y+@H@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V
M960H571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)&)O
M='1O;2`M(#$I*3L*("`@("`@("!I9B`H)&)O='1O;2`^(#`I('L*("`@("`@
M("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"1L:6YK*2P@)R<L("=P<F5V4F%N9V4G*2`N("=;)R`N("@D
M8F]T=&]M(#T](#$@/R`D8F]T=&]M(#H@)S$M)R`N("1B;W1T;VTI("X@)UT\
M+V$^)SL*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!L:6YK<R!T;R!I
M;F1I=FED=6%L('!A9V5S(&)E='=E96X@;&EM:71S+@H@("`@("`@(&9O<B`H
M)&D@/2`D8F]T=&]M.R`D:2`\/2`D=&]P("8F("1I(#P]("1P86=E<SL@*RLD
M:2D@>PH@("`@("`@("`@("!I9B`H)&D@/3T@)&-U<G)E;G1?<&%G92D@>PH@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B@G("X@*"1I("L@
M,2D@+B`G*3PO<W1R;VYG/B<["B`@("`@("`@("`@('T@96QS96EF("@D:2`^
M/2`P("8F("1I(#P]("1P86=E<RD@>PH@("`@("`@("`@("`@("`@)&QI;FL@
M/2`D=&AI<RT^7V%D9%!R97-E<G9E9"A5=&EL.CIA9&1087)A;65T97(H)'5R
M;"P@)'1H:7,M/E]N86UE+"`D:2DI.PH@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1L
M:6YK*2D@+B`H)&D@*R`Q*2`N("<\+V$^)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R\@0W)E871E('1O<"`G6W@M>5TG(&QI;FL@:68@
M;F5C97-S87)Y+@H@("`@("`@(&EF("@D=&]P(#P@)'!A9V5S*2!["B`@("`@
M("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H571I;#HZ861D
M4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)'1O<"`K(#$I*3L*("`@
M("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=N97AT4F%N9V4G*2`N("=;)R`N
M"B`@("`@("`@("`@("`@("`H)'1O<"`K(#(@/3T@)'!A9V5S("L@,2`_("1P
M86=E<R`K(#$@.B`H)'1O<"`K(#(I("X@)RTG("X@*"1P86=E<R`K(#$I*2`N
M("==/"]A/B<["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@=&AE("=.
M97AT/CXG(&QI;FL@:68@=V4@87)E(&YO="!O;B!T:&4@;&%S="!P86=E+@H@
M("`@("`@(&EF("@D8W5R<F5N=%]P86=E(#P@)'!A9V5S*2!["B`@("`@("`@
M("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)&-U<G)E;G1?<&%G92`K(#$I
M*3L*("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=N97AT)RD@+B!H=&UL
M<W!E8VEA;&-H87)S*%\H(DYE>'0^(BDI("X@)SPO83XG.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO9&EV/B<["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-C:&5D=6QE
M<B\`````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`V,0`P,C`Q,S4`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O4V-H961U;&5R+V-R;VXN<&AP````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(V-#(P`#$P-3$U-#,Q,#8Q`#`R,38Q,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E("=(;W)D92]38VAE9'5L97(N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]3=')I;F<N<&AP)SL*"B\J*@H@*B!(;W)D95]38VAE9'5L97)?
M8W)O;CHZ(%-O<G0@;V8@82!C<F]N(')E<&QA8V5M96YT(&EN(&$@4$A0(&-L
M:0H@*B!S8W)I<'0N"B`J"B`J($1A=&4@4WEN=&%X($5X86UP;&5S+@H@*@H@
M*B!296UE;6)E<CH*("H@("`M(%=H:71E<W!A8V4@*'-P86-E+"!T86(L(&YE
M=VQI;F4I(&1E;&EM:71E9"!F:65L9',*("H@("`M(%-I;F=L92!V86QU97,L
M('-E=',L(')A;F=E<RP@=VEL9&-A<F1S"B`J"B`J(%-%0T].1"`@($U)3E54
M12`@("`@("`@("`@("`@2$]54B`@("`@("`@1$%9("`@("!-3TY42`H@*B`J
M("`@("`@("`J("`@("`@("`@("`@("`@("`@("H@("`@("`@("`@("H@("`@
M("`@*B`@("`@("`H979E<GD@<V5C;VYD*0H@*B`P+#,P("`@("`J("`@("`@
M("`@("`@("`@("`@("H@("`@("`@("`@("H@("`@("`@*B`@("`@("`H979E
M<GD@,S`@<V5C;VYD<RD*("H@,"`@("`@("`@,"PQ,"PR,"PS,"PT,"PU,"`@
M("`J("`@("`@("`@("`J("`@("`@("H@("`@("`@*&5V97)Y(#$P(&UI;G5T
M97,I"B`J(#`@("`@("`@(#`@("`@("`@("`@("`@("`@("`@*B`@("`@("`@
M("`@*B`@("`@("`J("`@("`@("AB96=I;FYI;F<@;V8@979E<GD@:&]U<BD*
M("H@,"`@("`@("`@,"`@("`@("`@("`@("`@("`@("`P+#8L,3(L,3@@("`J
M("`@("`@("H@("`@("`@*&%T(&UI9&YI9VAT+"`V86TL(&YO;VXL(#9P;2D*
M("H@,"`@("`@("`@,"`@("`@("`@("`@("`@("`@("`P("`@("`@("`@("`Q
M+3<F1G)I("H@("`@("`@*&UI9&YI9VAT+"!F:7)S="!&<FD@;V8@=&AE(&UO
M;G1H*0H@*B`P("`@("`@("`P("`@("`@("`@("`@("`@("`@(#`@("`@("`@
M("`@(#$M-R%&<FD@*B`@("`@("`H;6ED;FEG:'0L(&9I<G-T($UO;BU4:'4L
M4V%T+5-U;B!O9B!T:&4@;6]N=&@I"B`J"B`J"B`J($5X86UP;&4@=7-A9V4Z
M"B`J"B`J($!S971?=&EM95]L:6UI="@P*3L*("H@<F5Q=6ER95]O;F-E("=(
M;W)D92]38VAE9'5L97(N<&AP)SL*("H@)&-R;VX@/2`F2&]R9&5?4V-H961U
M;&5R.CIS:6YG;&5T;VXH)V-R;VXG*3L*("H*("H@+R\@4G5N('1H:7,@8V]M
M;6%N9"!E=F5R>2`U(&UI;G5T97,N"B`J("1C<F]N+3YA9&1487-K*"=P97)L
M('-O;65S8W)I<'0N<&PG+"`G,"`P+#4L,3`L,34L,C`L,C4L,S`L,S4L-#`L
M-#4L-3`L-34@*B`J("HG*3L*("H*("H@+R\@4G5N('1H:7,@8V]M;6%N9"!M
M:61N:6=H="!O9B!T:&4@9FER<W0@1G)I9&%Y(&]F(&]D9"!N=6UB97)E9"!M
M;VYT:',N"B`J("1C<F]N+3YA9&1487-K*"=P:'`@+7$@<V]M97-C<FEP="YP
M:'`G+"`G,"`P(#`@,2TW)D9R:2`Q+#,L-2PW+#DL,3$G*3L*("H*("H@+R\@
M06QS;R!R=6X@=&AI<R!C;VUM86YD(&UI9&YI9VAT(&]F('1H92!S96-O;F0@
M5&AU<G-D87D@86YD(%-A='5R9&%Y(&]F('1H92!E=F5N(&YU;6)E<F5D(&UO
M;G1H<RX*("H@)&-R;VXM/F%D9%1A<VLH)W!H<"`M<2!S;VUE<V-R:7!T+G!H
M<"<L("<P(#`@,"`X+3$U)E1H=2PX+3$U)E-A="`R+#0L-BPX+#$P+#$R)RD[
M"B`J"B`J("1C<F]N+3YR=6XH*3L*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M4V-H961U;&5R+U-C:&5D=6QE<B]C<F]N+G!H<"QV(#$N,3,N,3`N,R`R,#`U
M+S$P+S$X(#$Q.C`Q.C(V(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!2>6%N
M($9L>6YN(#QR>6%N0')Y86YF;'EN;BYC;VT^"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D
M95]38VAE9'5L97(*("HO"F-L87-S($AO<F1E7U-C:&5D=6QE<E]C<F]N(&5X
M=&5N9',@2&]R9&5?4V-H961U;&5R('L*"B`@("!V87(@)%]T87-K<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!%=F5R>2!T:6UE(&$@=&%S:R!I<R!A
M9&1E9"!I="!W:6QL(&=E="!A(&9R97-H('5I9"!E=F5N(&EF"B`@("`@*B!I
M;6UE9&EA=&5L>2!R96UO=F5D+@H@("`@("HO"B`@("!V87(@)%]C;W5N=&5R
M(#T@,3L*"B`@("!F=6YC=&EO;B!A9&1487-K*"1C;60L("1R=6QE<RD*("`@
M('L*("`@("`@("`D9',@/2`F;F5W($AO<F1E7U-C:&5D=6QE<E]C<F]N1&%T
M92@D<G5L97,I.PH*("`@("`@("`D=&AI<RT^7V-O=6YT97(K*SL*"B`@("`@
M("`@)'1H:7,M/E]T87-K<UM=(#T*("`@("`@("`@("`@87)R87DH"B`@("`@
M("`@("`@("`@("`G=6ED)R`]/B`D=&AI<RT^7V-O=6YT97(L"B`@("`@("`@
M("`@("`@("`G<G5L97,G(#T^("1D<RP*("`@("`@("`@("`@("`@("=C;60G
M(#T^("1C;60*("`@("`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V]U;G1E<CL*("`@('T*"B`@("!F=6YC=&EO;B!R96UO=F5487-K*"1U
M:60I"B`@("!["B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)'1H:7,M/E]T87-K
M<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W1A<VMS6R=U:60G72`]/2`D=6ED
M*2!["B`@("`@("`@("`@("`@("`D9F]U;F0@/2`D:3L*("`@("`@("`@("`@
M("`@(&%R<F%Y7W-P;&EC92@D=&AI<RT^7W1A<VMS+"`D:2D["B`@("`@("`@
M("`@("`@("!R971U<FX@)&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`P.PH@("`@?0H*("`@(&9U;F-T:6]N(')U;B@I"B`@
M("!["B`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7W1A<VMS*2D@>PH@("`@
M("`@("`@("!E>&ET*")C<F]N9#H@3F]T:&EN9R!T;R!S8VAE9'5L93L@97AI
M=&EN9RY<;B(I.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*'1R=64I('L*
M("`@("`@("`@("`@)'0@/2!T:6UE*"D["@H@("`@("`@("`@("`O+R!#:&5C
M:R!E86-H('1A<VLN"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?=&%S
M:W,@87,@)'1A<VLI('L*("`@("`@("`@("`@("`@(&EF("@D=&%S:ULG<G5L
M97,G72T^;F]W36%T8VAE<R@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G)U;F-M9"@D=&%S:RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\O(%=A:70@=6YT:6P@=&AE(&YE>'0@<V5C
M;VYD+@H@("`@("`@("`@("!W:&EL92`H=&EM92@I(#T]("1T*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<VQE97`H,3`P,#`P*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!R=6YC;60H)B1T87-K
M*0H@("`@>PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=(;W)D95]38VAE
M9'5L97)?0W)O;CHZ<G5N8VUD*"DZ("<@+B`D=&%S:ULG8VUD)UT@+B`G(')U
M;B!B>2`G("X@)'1A<VM;)W5I9"==+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7TE.1D\I.PH@("`@("`@(')E='5R;B!S:&5L;%]E>&5C*"1T87-K
M6R=C;60G72D["B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@2&]R9&5?4V-H
M961U;&5R"B`J+PIC;&%S<R!(;W)D95]38VAE9'5L97)?8W)O;D1A=&4@>PH*
M("`@('9A<B`D;&5G86Q$87ES(#T@87)R87DH)TU/3B<L("=4544G+"`G5T5$
M)RP@)U1(52<L("=&4DDG+"`G4T%4)RP@)U-53B<I.PH*("`@('9A<B`D<V5C
M.PH@("`@=F%R("1M:6X["B`@("!V87(@)&AO=7(["B`@("!V87(@)&1A>3L*
M("`@('9A<B`D;6]N=&@["@H@("`@9G5N8W1I;VX@2&]R9&5?4V-H961U;&5R
M7V-R;VY$871E*"1R87<I"B`@("!["B`@("`@("`@)'1H:7,M/G!A<G-E*%-T
M<FEN9SHZ=7!P97(H)')A=RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(&YO=TUA
M=&-H97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<V-H961U;&5D
M070H=&EM92@I*3L*("`@('T*"B`@("!F=6YC=&EO;B!S8VAE9'5L961!="@D
M=',@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D=',@/3T](&YU;&PI('L*
M("`@("`@("`@("`@)'1S(#T@=&EM92@I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@*"1T:&ES+3YM;VYT:$UA=&-H97,H)'1S*2`F)@H@("`@("`@("`@
M("`@("`@)'1H:7,M/FUO;G1H36%T8VAE<R@D=',I("8F"B`@("`@("`@("`@
M("`@("`D=&AI<RT^9&%Y36%T8VAE<R@D=',I("8F"B`@("`@("`@("`@("`@
M("`D=&AI<RT^:&]U<DUA=&-H97,H)'1S*2`F)@H@("`@("`@("`@("`@("`@
M)'1H:7,M/FUI;DUA=&-H97,H)'1S*2`F)@H@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E8TUA=&-H97,H)'1S*2D["B`@("!]"@H@("`@9G5N8W1I;VX@;6]N
M=&A-871C:&5S*"1T<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FUO;G1H
M(#T]("<J)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1C=7)R96YT;6]N=&@@/2`G+2<@+B!D871E*"=N)RP@)'1S
M*2`N("<M)SL*"B`@("`@("`@<F5T=7)N("AB;V]L*7-T<G!O<R@D=&AI<RT^
M;6]N=&@L("1C=7)R96YT;6]N=&@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&1A
M>4UA=&-H97,H)'1S*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/F1A>5LG=F%L=64G72D@)B8@)'1H:7,M/F1A>5LG=F%L=64G72`]/2`G*B<I
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`D8W5R<F5N=&1A>6YU;2`]("<M)R`N(&1A=&4H)VHG+"`D=',I("X@)RTG
M.PH@("`@("`@("1C=7)R96YT9&%Y='AT(#T@4W1R:6YG.CIU<'!E<BAD871E
M*"=$)RDI.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%Y(&%S("1D87DI
M('L*("`@("`@("`@("`@:68@*$!S=')P;W,H)&1A>5LG;F]T)UTL("1C=7)R
M96YT9&%Y='AT*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1V,2`]
M("A`<W1R<&]S*"1D87E;)W9A;'5E)UTL("1C=7)R96YT9&%Y;G5M*2`A/3T@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@)'8R(#T@*$!S=')P;W,H)&1A>5LG
M86YD)UTL("1C=7)R96YT9&%Y='AT*2`A/3T@9F%L<V4I.PH*("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)&1A>5LG86YD)UTI("8F("@D=C$@)B8@)'8R
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1D87E;)V%N9"==*2`F)B`D=C$I
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N(&AO=7)-871C:&5S*"1T
M<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FAO=7(@/3T@)RHG*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&-U
M<G)E;G1H;W5R(#T@)RTG("X@9&%T92@G1R<L("1T<RD@+B`G+2<["@H@("`@
M("`@(')E='5R;B`H<W1R<&]S*"1T:&ES+3YH;W5R+"`D8W5R<F5N=&AO=7(I
M("$]/2!F86QS92D["B`@("!]"@H@("`@9G5N8W1I;VX@;6EN36%T8VAE<R@D
M=',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM:6X@/3T@)RHG*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&-U
M<G)E;G1M:6X@/2`G+2<@+B!I;G1V86PH9&%T92@G:2<L("1T<RDI("X@)RTG
M.PH*("`@("`@("!R971U<FX@*'-T<G!O<R@D=&AI<RT^;6EN+"`D8W5R<F5N
M=&UI;BD@(3T](&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO;B!S96--871C
M:&5S*"1T<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G-E8R`]/2`G*B<I
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`D8W5R<F5N='-E8R`]("<M)R`N(&EN='9A;"AD871E*"=S)RP@)'1S*2D@
M+B`G+2<["@H@("`@("`@(')E='5R;B`H<W1R<&]S*"1T:&ES+3YS96,L("1C
M=7)R96YT<V5C*2`A/3T@9F%L<V4I.PH@("`@?0H*("`@(&9U;F-T:6]N('!A
M<G-E*"1S='(I"B`@("!["B`@("`@("`@)',@/2!A<G)A>2@I.PH*("`@("`@
M("!L:7-T*"1S6R=S96,G72P@)'-;)VUI;B==+"`D<ULG:&]U<B==+"`D<ULG
M9&%Y)UTL("1S6R=M;VYT:"==*2`]('!R96=?<W!L:70H)WQ;7&Y<="!=*WPG
M+"`D<W1R*3L*"B`@("`@("`@9F]R96%C:"`H)',@87,@)&L@/3X@)'8I('L*
M("`@("`@("`@("`@:68@*'-T<G!O<R@D=BP@)RHG*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1S6R1K72`](&%R<F%Y*"<J)RD["B`@("`@("`@
M("`@('T@96QS96EF("@A)'1H:7,M/F=E;F5R86QL>41E8V5N=%-Y;G1A>"@D
M=BDI('L*("`@("`@("`@("`@("`@(&1I92@B26QL96=A;"!S>6YT87@@:6X@
M)R1V)UQN(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<ULD:UT@/2!E>'!L;V1E*"<L)RP@)'-;)&M=*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"1S6R=S96,G75LP72`]/2`G*B<I
M('L*("`@("`@("`@("`@)'1H:7,M/G-E8R`]("<J)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'-;
M)W-E8R==*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI
M<U)A;F=E*"1S6R=S96,G75LD:5TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-;)W-E8R==6R1I72`]("1T:&ES+3YE>'!A;F1286YG92@D=&AI<RT^<F%N
M9V5686QS*"1S6R=S96,G75LD:5TI*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<V5C(#T@)RTG("X@:F]I
M;B@G+2<L("1S6R=S96,G72D@+B`G+2<["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'-;)VUI;B==6S!=(#T]("<J)RD@>PH@("`@("`@("`@("`D=&AI<RT^
M;6EN(#T@)RHG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\('-I>F5O9B@D<ULG;6EN)UTI.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'-;)VUI;B==6R1I72DI
M('L*("`@("`@("`@("`@("`@("`@("`D<ULG;6EN)UU;)&E=(#T@)'1H:7,M
M/F5X<&%N9%)A;F=E*"1T:&ES+3YR86YG959A;',H)'-;)VUI;B==6R1I72DI
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YM:6X@/2`G+2<@+B!J;VEN*"<M)RP@)'-;)VUI;B==*2`N("<M
M)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D<ULG:&]U<B==6S!=(#T]("<J
M)RD@>PH@("`@("`@("`@("`D=&AI<RT^:&]U<B`]("<J)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)'-;)VAO=7(G72D[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^:7-286YG92@D<ULG:&]U<B==6R1I72DI('L*("`@("`@("`@("`@("`@
M("`@("`D<ULG:&]U<B==6R1I72`]("1T:&ES+3YE>'!A;F1286YG92@D=&AI
M<RT^<F%N9V5686QS*"1S6R=H;W5R)UU;)&E=*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/FAO=7(@/2`G
M+2<@+B!J;VEN*"<M)RP@)'-;)VAO=7(G72D@+B`G+2<["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'-;)V1A>2==6S!=(#T]("<J)RD@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%Y(#T@)RHG.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D<ULG9&%Y)UTI.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D=&UP(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@(&EF("@H)&-H87(@/2`D=&AI<RT^:7-#;VYD*"1S6R=D87DG75LD
M:5TI*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-H
M87(@/3T@)R8G*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)'1M
M<%LG=F%L=64G72P@)'1M<%LG86YD)UTI(#T@97AP;&]D92@D8VAA<BP@)'-;
M)V1A>2==6R1I72D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^:7-286YG92@D=&UP6R=A;F0G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T;7!;)V%N9"==(#T@)'1H:7,M/F5X<&%N9%)A;F=E*"1T
M:&ES+3YR86YG959A;',H)'1M<%LG86YD)UTI*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&QI<W0H)'1M<%LG=F%L=64G72P@)'1M<%LG
M;F]T)UTI(#T@97AP;&]D92@D8VAA<BP@)'-;)V1A>2==6R1I72D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-286YG92@D=&UP6R=N
M;W0G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;7!;)VYO
M="==(#T@)'1H:7,M/F5X<&%N9%)A;F=E*"1T:&ES+3YR86YG959A;',H)'1M
M<%LG;F]T)UTI*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1M<"`](&%R<F%Y*"=V86QU92<@/3X@)'-;)V1A
M>2==6R1I72D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)'-;)V1A>2==6R1I72`]("1T;7`["@H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YI<U)A;F=E*"1S6R=D87DG75LD:5U;)W9A;'5E)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'-;)V1A>2==6R1I75LG=F%L=64G72`]("1T:&ES
M+3YE>'!A;F1286YG92@D=&AI<RT^<F%N9V5686QS*"1S6R=D87DG75LD:5U;
M)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'1H:7,M/F1A>2`]("1S6R=D87DG73L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D<ULG;6]N=&@G75LP72`]/2`G*B<I('L*("`@("`@
M("`@("`@)'1H:7,M/FUO;G1H(#T@)RHG.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D<ULG;6]N=&@G
M72D[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-286YG
M92@D<ULG;6]N=&@G75LD:5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'-;
M)VUO;G1H)UU;)&E=(#T@)'1H:7,M/F5X<&%N9%)A;F=E*"1T:&ES+3YR86YG
M959A;',H)'-;)VUO;G1H)UU;)&E=*2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/FUO;G1H(#T@)RTG("X@
M:F]I;B@G+2<L("1S6R=M;VYT:"==*2`N("<M)SL*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@:7-#;VYD*"1S*0H@("`@>PH@("`@("`@(&EF("AS
M=')P;W,H)',L("<F)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R
M;B`G)B<["B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D<RP@)R$G*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("<A)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&ES4F%N9V4H)',I"B`@("!["B`@("`@("`@<F5T
M=7)N('!R96=?;6%T8V@H)R]>7'<K7"U<=RLO)RP@)',I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&ES0V]N9%)A;F=E*"1S*0H@("`@>PH@("`@("`@(')E='5R
M;B`H:7-#;VYD*"1S*2`F)B!I<U)A;F=E*"1S*2D["B`@("!]"@H@("`@9G5N
M8W1I;VX@:7-#;VYD5F%L*"1S*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-#
M;VYD*"1S*2`F)B`A:7-286YG92@D<RDI.PH@("`@?0H*("`@(&9U;F-T:6]N
M(')A;F=E5F%L<R@D<RD*("`@('L*("`@("`@("!R971U<FX@97AP;&]D92@G
M+2<L("1S*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>'!A;F1286YG92@D;"P@
M)&@@/2`G)RD*("`@('L*("`@("`@("`O+R!%>'!A;F0@<F%N9V4@9G)O;2`Q
M+34@+3X@)RTQ+3(M,RTT+34M)RX*("`@("`@("!I9B`H:7-?87)R87DH)&PI
M*2!["B`@("`@("`@("`@("1H(#T@)&Q;,5T["B`@("`@("`@("`@("1L(#T@
M)&Q;,%T["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/FES1&EG:70H
M)&PI*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES1&EG:70H)&@I*2![
M"B`@("`@("`@("`@("`@("!D:64H(DEN=F%L:60@=F%L=64@)R1H)R!I;B!R
M86YG92`G)&PM)&@G(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M($-U<G)E;G1L>2!T:&5R92!I<R!N;R!P;W-S:6)L92!R96%S;VX@=&\@;F5E
M9"!T;R!D;R!A"B`@("`@("`@("`@("\O(')A;F=E(&)E>6]N9"`P+34Y(&9O
M<B!A;GET:&EN9RX*("`@("`@("`@("`@:68@*"1L(#P@,"D@>PH@("`@("`@
M("`@("`@("`@)&P@/2`P.PH@("`@("`@("`@("!](&5L<V5I9B`H)&P@/B`U
M.2D@>PH@("`@("`@("`@("`@("`@)&P@/2`U.3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1H(#P@,"D@>PH@("`@("`@("`@("`@("`@)&@@
M/2`P.PH@("`@("`@("`@("!](&5L<V5I9B`H)&@@/B`U.2D@>PH@("`@("`@
M("`@("`@("`@)&@@/2`U.3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1L(#X@)&@I('L*("`@("`@("`@("`@("`@("1T;7`@/2`D;#L*("`@
M("`@("`@("`@("`@("1L(#T@)&@["B`@("`@("`@("`@("`@("`D:"`]("1T
M;7`["B`@("`@("`@("`@("`@("!U;G-E="@D=&UP*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+R\@1F]R('-O;64@<F5A<V]N(')A;F=E*"D@9&]E
M<VXG="!W;W)K('<O;R!T:&4@97AP;&EC:70*("`@("`@("`@("`@+R\@:6YT
M=F%L*"D@8V%L;',N"B`@("`@("`@("`@(')E='5R;B`G+2<@+B!J;VEN*"<M
M)RP@<F%N9V4H:6YT=F%L*"1L*2P@:6YT=F%L*"1H*2DI("X@)RTG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\O($EN=F%L:60N"B`@("`@("`@
M("`@(&1I92@B26YV86QI9"!V86QU92`G)&PG(&EN(')A;F=E("<D;"TD:"<B
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9&%Y5F%L=64H)',I
M"B`@("!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1H:7,M
M/FQE9V%L1&%Y<RD[("1I*RLI('L*("`@("`@("`@("`@:68@*"1T:&ES+3YL
M96=A;$1A>7-;)&E=(#T]("1S*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`M
M,3L*("`@('T*"B`@("!F=6YC=&EO;B!I<T1I9VET*"1S*0H@("`@>PH@("`@
M("`@(')E='5R;B!P<F5G7VUA=&-H*"<O7EQD*R0O)RP@)',I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&ES06QP:&$H)',I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YI<TQE9V%L1&%Y*"1S*3L*("`@('T*"B`@("!F=6YC=&EO;B!I
M<TQE9V%L1&%Y*"1S*0H@("`@>PH@("`@("`@(')E='5R;B!I;E]A<G)A>2@D
M<RP@)'1H:7,M/FQE9V%L1&%Y<RD["B`@("!]"@H@("`@9G5N8W1I;VX@9V5N
M97)A;&QY1&5C96YT4WEN=&%X*"1S*0H@("`@>PH@("`@("`@(')E='5R;B`H
M)',@/3T@)RHG('Q\"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7EQD
M*R@M7&0K*3\H6R$F75M!+5I<*ETK*"U;02U:7"I=*RD_*3\H+%QD*R@M7&0K
M*3\H6R$F75M!+5I<*ETK*"U;02U:7"I=*RD_*3\I*B0O)RP@)',I*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O2&5L<"YP:'``````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,V-3$W`#$P-3$U-#,Q,#8Q`#`Q-S8S,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J(%)A=R!H96QP(&EN('1H92!S=')I;F<N"B`J+PID969I;F4H)TA%
M3%!?4T]54D-%7U)!5R<L(#`I.PH*+RHJ"B`J($AE;'`@=&5X="!I<R!I;B!A
M(&9I;&4N"B`J+PID969I;F4H)TA%3%!?4T]54D-%7T9)3$4G+"`Q*3L*"B\J
M*@H@*B!4:&4@2&5L<#HZ(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C92!T
M;R!T:&4@;VYL:6YE(&AE;'`@<W5B<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<"QV(#$N-C@N."XQ."`R,#`V
M+S`S+S`R(#`U.C(W.C,U('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T9R
M86UE=V]R:PH@*B\*8VQA<W,@2&5L<"!["@H@("`@+RHJ"B`@("`@*B!(86YD
M;&4@9F]R('1H92!834P@<&%R<V5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W!A<G-E<B`](#`["@H@
M("`@+RHJ"B`@("`@*B!3=')I;F<@8G5F9F5R('1O(&AO;&0@=&AE(%A-3"!H
M96QP('-O=7)C92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]B=69F97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN
M9R!C;VYT86EN:6YG('1H92!)1"!O9B!T:&4@<F5Q=65S=&5D(&AE;'`@96YT
M<GDN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?<F5Q16YT<GD@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT
M86EN:6YG('1H92!)1"!O9B!T:&4@8W5R<F5N="!H96QP(&5N=')Y+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-U<D5N
M=')Y(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T
M:&4@9F]R;6%T=&5D(&]U='!U="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]O=71P=70@/2`G)SL*"B`@("`O*BH*("`@
M("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('=E)W)E(&EN<VED92!A
M(#QH96QP/B!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?:6Y(96QP(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!W92=R92!I;G-I9&4@=&AE
M(')E<75E<W1E9"!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?:6Y";&]C:R`](&9A;'-E.PH*("`@("\J*@H@
M("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=V4G<F4@:6YS:61E
M(&$@/'1I=&QE/B!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?:6Y4:71L92`](&9A;'-E.PH*("`@("\J*@H@
M("`@("H@2&%S:"!C;VYT86EN:6YG(&%N(&EN9&5X(&]F(&%L;"!O9B!T:&4@
M:&5L<"!E;G1R:65S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?96YT<FEE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@8VAA<G-E="!O9B!T:&4@6$U,(&1A
M=&$@<V]U<F-E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V-H87)S970@/2`G:7-O+3@X-3DM,2<["@H@("`@+RHJ"B`@
M("`@*B!(87-H(&]F('5S97(M9&5F:6YE9"!F=6YC=&EO;B!H86YD;&5R<R!F
M;W(@=&AE(%A-3"!E;&5M96YT<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7VAA;F1L97)S(#T@87)R87DH"B`@("`@("`@
M)VAE;'`G("`@("`]/B`@)U]H96QP2&%N9&QE<B<L"B`@("`@("`@)V5N=')Y
M)R`@("`]/B`@)U]E;G1R>4AA;F1L97(G+`H@("`@("`@("=T:71L92<@("`@
M/3X@("=?=&ET;&5(86YD;&5R)RP*("`@("`@("`G:&5A9&EN9R<@(#T^("`G
M7VAE861I;F=(86YD;&5R)RP*("`@("`@("`G<&%R82<@("`@(#T^("`G7W!A
M<F%(86YD;&5R)RP*("`@("`@("`G<F5F)R`@("`@(#T^("`G7W)E9DAA;F1L
M97(G+`H@("`@("`@("=E<F5F)R`@("`@/3X@("=?97)E9DAA;F1L97(G+`H@
M("`@("`@("=H<F5F)R`@("`@/3X@("=?:')E9DAA;F1L97(G+`H@("`@("`@
M("=B)R`@("`@("`@/3X@("=?8DAA;F1L97(G+`H@("`@("`@("=I)R`@("`@
M("`@/3X@("=?:4AA;F1L97(G+`H@("`@("`@("=P<F4G("`@("`@/3X@("=?
M<')E2&%N9&QE<B<L"B`@("`@("`@)W1I<"<@("`@("`]/B`@)U]T:7!(86YD
M;&5R)RP*("`@("`@("`G=V%R;B<@("`@(#T^("`G7W=A<FY(86YD;&5R)PH@
M("`@*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'-O=7)C92`@5&AE('-O=7)C92!O9B!T:&4@
M6$U,(&AE;'`@9&%T82P@8F%S960@;VX@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!(14Q07U-/55)#15\J(&-O;G-T86YT<RX*("`@("`J
M($!P87)A;2!S=')I;F<@)&%R9R`@("`@(%-O=7)C92UD97!E;F1E;G0@87)G
M=6UE;G0@9F]R('1H:7,@2&5L<`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N($AE;'`H)'-O
M=7)C92P@)&%R9R`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1L86YG
M=6%G92P@)&YL<SL*"B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H)WAM;"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR
M86ES945R<F]R*"=4:&4@6$U,(&9U;F-T:6]N<R!A<F4@;F]T(&%V86EL86)L
M92X@4F5B=6EL9"!02%`@=VET:"`M+7=I=&@M>&UL+B<I+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M8VAA<G-E="`](&ES<V5T*"1N;'-;)V-H87)S971S)UU;)&QA;F=U86=E72D@
M/R`D;FQS6R=C:&%R<V5T<R==6R1L86YG=6%G95T@.B`G25-/+3@X-3DM,2<[
M"@H@("`@("`@("\J(%!O<'5L871E("1T:&ES+3Y?8G5F9F5R(&)A<V5D(&]N
M("1S;W5R8V4N("HO"B`@("`@("`@<W=I=&-H("@D<V]U<F-E*2!["B`@("`@
M("`@8V%S92!(14Q07U-/55)#15]205<Z"B`@("`@("`@("`@("1T:&ES+3Y?
M8G5F9F5R(#T@)&%R9SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@2$5,4%]33U520T5?1DE,13H*("`@("`@("`@("`@:68@*$!F:6QE7V5X
M:7-T<R@D87)G6S!=*2`F)B!`9FEL97-I>F4H)&%R9ULP72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8G5F9F5R(#T@9FEL95]G971?8V]N=&5N=',H
M)&%R9ULP72D["B`@("`@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H
M)&%R9ULQ72D@)B8@0&9I;&5S:7IE*"1A<F=;,5TI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V)U9F9E<B`](&9I;&5?9V5T7V-O;G1E;G1S*"1A<F=;
M,5TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]B=69F97(@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/E]B
M=69F97(@/2`G)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!(5$U,(&QI;FL@=&AA
M="!W:6QL('!O<"!U<"!A(&AE;'`@=VEN9&]W(&9O<B!T:&4*("`@("`J(')E
M<75E<W1E9"!T;W!I8RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M;V1U;&4@(%1H92!N86UE(&]F('1H92!C=7)R96YT($AO<F1E(&UO9'5L92X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1O<&EC("`@5&AE(&AE;'`@=&]P:6,@
M=&\@8F4@9&ES<&QA>65D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@2%1-3"!T;R!C<F5A=&4@=&AE(&AE;'`@;&EN:RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&EN:R@D;6]D=6QE+"`D=&]P:6,I"B`@("!["B`@("`@
M("`@9VQO8F%L("1C;VYF+"`D<F5G:7-T<GDL("1B<F]W<V5R.PH*("`@("`@
M("!I9B`H(4AO<F1E.CIS:&]W4V5R=FEC92@G:&5L<"<I*2!["B`@("`@("`@
M("`@(')E='5R;B`G)FYB<W`[)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D
M8G)O=W-E<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D92<I
M.PH@("`@("`@('T*"B`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)')E9VES
M=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:&5L
M<"\G+"!T<G5E*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL(&%R<F%Y*"=M;V1U;&4G(#T^("1M;V1U;&4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&]P:6,G(#T^
M("1T;W!I8RDI.PH@("`@("`@("1H=&UL(#T@2&]R9&4Z.FQI;FLH)'5R;"P@
M7R@B2&5L<"(I+"`G)RP@)VAO<F1E:&5L<'=I;B<L("=P;W!U<"AT:&ES+FAR
M968I.R!R971U<FX@9F%L<V4[)RD["@H@("`@("`@(')E='5R;B`D:'1M;"`N
M($AO<F1E.CII;6<H)VAE;'`N<&YG)RP@7R@B2&5L<"(I+"`G=VED=&@](C$V
M(B!H96EG:'0](C$V(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI("X@)SPO83XG.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE86YS('5P
M('1H92!(96QP(&-L87-S(')E<V]U<F-E<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P*"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V)U9F9E<B`]("<G.PH@("`@("`@(')E='5R
M;B!X;6Q?<&%R<V5R7V9R964H)'1H:7,M/E]P87)S97(I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3&]O:W,@=7`@=&AE(')E<75E<W1E9"!E;G1R>2!I;B!T
M:&4@6$U,(&AE;'`@8G5F9F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&5N=')Y("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@96YT<GD@240N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QO;VMU<"@D96YT<GDI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]O=71P=70@/2`G)SL*("`@("`@("`D=&AI<RT^7W)E<45N
M=')Y(#T@4W1R:6YG.CIU<'!E<B@D96YT<GDI.PH@("`@("`@(&EF("@A)'1H
M:7,M/E]P87)S97(I('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET*"D["B`@
M("`@("`@?0H@("`@("`@('AM;%]P87)S92@D=&AI<RT^7W!A<G-E<BP@)'1H
M:7,M/E]B=69F97(L('1R=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A(&AA<V@@;V8@86QL(&]F('1H92!T;W!I8W,@:6X@=&AI<R!H96QP
M(&)U9F9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!(87-H(&]F
M(&%L;"!O9B!T:&4@=&]P:6-S(&EN('1H:7,@8G5F9F5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!T;W!I8W,H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M
M/E]P87)S97(I('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET*"D["B`@("`@
M("`@?0H@("`@("`@('AM;%]P87)S92@D=&AI<RT^7W!A<G-E<BP@)'1H:7,M
M/E]B=69F97(L('1R=64I.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]E;G1R
M:65S.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA>2!T:&4@8V]N=&5N
M=',@;V8@=&AE(&9O<FUA='1E9"!O=71P=70@8G5F9F5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("!E8VAO("1T:&ES
M+3Y?;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA;'IE<R!T
M:&4@6$U,('!A<G-E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O
M;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?:6YI="@I"B`@("!["B`@("`@("`@+RH@0W)E871E(&$@;F5W('!A
M<G-E<B!A;F0@<V5T(&ET<R!D969A=6QT('!R;W!E<G1I97,N("HO"B`@("`@
M("`@)'1H:7,M/E]P87)S97(@/2!X;6Q?<&%R<V5R7V-R96%T92@I.PH@("`@
M("`@('AM;%]S971?;V)J96-T*"1T:&ES+3Y?<&%R<V5R+"`D=&AI<RD["B`@
M("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1T:&ES+3Y?<&%R<V5R+"!8
M34Q?3U!424].7T-!4T5?1D],1$E.1RP@9F%L<V4I.PH@("`@("`@('AM;%]S
M971?96QE;65N=%]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G7W-T87)T16QE
M;65N="<L("=?96YD16QE;65N="<I.PH@("`@("`@('AM;%]S971?8VAA<F%C
M=&5R7V1A=&%?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]D969A=6QT2&%N
M9&QE<B<I.PH*("`@("`@("!R971U<FX@*"1T:&ES+3Y?<&%R<V5R("$](#`I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@57-E<BUD969I;F5D(&9U;F-T:6]N
M(&-A;&QB86-K(&9O<B!S=&%R="!E;&5M96YT<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1P
M87)S97(@($AA;F1L92!T;R!T:&4@<&%R<V5R(&EN<W1A;F-E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@;F%M92!O9B!T:&ES(%A-3"!E
M;&5M96YT+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("!,:7-T(&]F
M('1H:7,@96QE;65N="=S(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S=&%R=$5L96UE;G0H)'!A<G-E<BP@)&YA;64L("1A='1R<RD*("`@
M('L*("`@("`@("`O*B!#86QL('1H92!A<W-I9VYE9"!H86YD;&5R(&9O<B!T
M:&ES(&5L96UE;G0L(&EF(&]N92!I<PH@("`@("`@("`J(&%V86EL86)L92X@
M*B\*("`@("`@("!I9B`H:6Y?87)R87DH)&YA;64L(&%R<F%Y7VME>7,H)'1H
M:7,M/E]H86YD;&5R<RDI*2!["B`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC
M*&%R<F%Y*"8D=&AI<RP@)'1H:7,M/E]H86YD;&5R<ULD;F%M95TI+"!T<G5E
M+"`D871T<G,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5S
M97(M9&5F:6YE9"!F=6YC=&EO;B!C86QL8F%C:R!F;W(@96YD(&5L96UE;G1S
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!O8FIE8W0@)'!A<G-E<B`@2&%N9&QE('1O('1H92!P87)S97(@
M:6YS=&%N8V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@(%1H92!N
M86UE(&]F('1H:7,@6$U,(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]E;F1%;&5M96YT*"1P87)S97(L("1N86UE*0H@("`@>PH@("`@("`@("\J
M($-A;&P@=&AE(&%S<VEG;F5D(&AA;F1L97(@9F]R('1H:7,@96QE;65N="P@
M:68@;VYE(&ES(&%V86EL86)L92X@*B\*("`@("`@("!I9B`H:6Y?87)R87DH
M)&YA;64L(&%R<F%Y7VME>7,H)'1H:7,M/E]H86YD;&5R<RDI*2!["B`@("`@
M("`@("`@(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"8D=&AI<RP@)'1H:7,M/E]H
M86YD;&5R<ULD;F%M95TI+"!F86QS92D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@57-E<BUD969I;F5D(&9U;F-T:6]N(&-A;&QB86-K(&9O
M<B!C:&%R86-T97(@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1P87)S97(@($AA;F1L
M92!T;R!T:&4@<&%R<V5R(&EN<W1A;F-E+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%T82`@("!3=')I;F<@;V8@8VAA<F%C=&5R(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]D969A=6QT2&%N9&QE<B@D<&%R<V5R+"`D9&%T82D*
M("`@('L*("`@("`@("`D9&%T82`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)&1A=&$L('9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@)S(G+"`G
M/"<I(#\@)'1H:7,M/E]C:&%R<V5T(#H@)U541BTX)RD["B`@("`@("`@:68@
M*"1T:&ES+3Y?:6Y4:71L92D@>PH@("`@("`@("`@("`D=&AI<RT^7V5N=')I
M97-;)'1H:7,M/E]C=7)%;G1R>5T@+CT@)&1A=&$["B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*
M("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@:'1M;'-P96-I86QC:&%R
M<R@D9&%T82D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@6$U,
M(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QH96QP/B!T86<N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T
M:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@
M("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<R`H3F]T('5S960I
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&5L<$AA;F1L97(H)'-T87)T5&%G
M+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6Y(
M96QP(#T@)'-T87)T5&%G(#\@('1R=64@.B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\96YT<GD^
M('1A9RX*("`@("`J($%T=')I8G5T97,Z(&ED"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T
M87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A
M;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A
M<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I
M=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V5N=')Y2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"$D<W1A<G1486<I('L*("`@("`@("`@("`@
M)'1H:7,M/E]I;D)L;V-K(#T@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&ED(#T@4W1R:6YG.CIU<'!E<B@D871T<G-;)VED)UTI.PH@
M("`@("`@("`@("`D=&AI<RT^7V-U<D5N=')Y(#T@)&ED.PH@("`@("`@("`@
M("`D=&AI<RT^7V5N=')I97-;)&ED72`]("<G.PH@("`@("`@("`@("`D=&AI
M<RT^7VEN0FQO8VL@/2`H)&ED(#T]("1T:&ES+3Y?<F5Q16YT<GDI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L
M97(@9F]R('1H92`\=&ET;&4^('1A9RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A<G14
M86<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@
M:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R="!T
M86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D9&ET:6]N
M86P@96QE;65N="!A='1R:6)U=&5S("A.;W0@=7-E9"DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]T:71L94AA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6Y4:71L92`]("1S=&%R
M=%1A9SL*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I
M;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1S=&%R
M=%1A9R`_("<\:#$^)R`Z("<\+V@Q/B<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QH96%D
M:6YG/B!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN
M9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A
M<F%M("!A<G)A>2`D871T<G,@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T
M<FEB=71E<R`H3F]T('5S960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&5A
M9&EN9TAA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO
M8VLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G
M(#\@)SQH,CXG(#H@)SPO:#(^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@/'!A<F$^('1A
M9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN
M9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R
M87D@)&%T=')S("`@("`@($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S
M("A.;W0@=7-E9"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)A2&%N9&QE
M<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D<W1A<G1486<@/R`G/'`^)R`Z
M("<\+W`^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@
M96QE;65N="!H86YD;&5R(&9O<B!T:&4@/')E9CX@=&%G+@H@("`@("H@4F5Q
M=6ER960@871T<FEB=71E<SH@14Y44EDL($U/1%5,10H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I
M;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@
M061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]R969(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M
M/E]I;D)L;V-K*2!["B`@("`@("`@("`@(&EF("@D<W1A<G1486<@)B8@:7-S
M970H)&%T=')S6R=M;V1U;&4G72D@)B8@:7-S970H)&%T=')S6R=E;G1R>2==
M*2D@>PH@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E
M<BA(;W)D93HZ<V5L9E5R;"@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G<VAO=R<@/3X@)V5N=')Y)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VUO9'5L92<@/3X@)&%T=')S6R=M;V1U;&4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O<&EC)R`@/3X@
M)&%T=')S6R=E;G1R>2==*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2!(;W)D93HZ;&EN:R@D=7)L*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("<\+V$^)SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\97)E9CX@=&%G+@H@("`@
M("H@4F5Q=6ER960@96QE;65N=',Z(%523`H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R
M=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC
M92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T
M('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@061D:71I
M;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]E<F5F2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y"
M;&]C:RD@>PH@("`@("`@("`@("!I9B`H)'-T87)T5&%G*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!(;W)D93HZ;&EN:R@D871T<G-;
M)W5R;"==+"!N=6QL+"`G)RP@)U]B;&%N:R<I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SPO83XG
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QH<F5F/B!T86<N"B`@
M("`@*B!297%U:7)E9"!E;&5M96YT<SH@=7)L+"!A<'`N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES
M(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@
M("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7VAR969(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H
M:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@(&EF("@D<W1A<G1486<I('L*
M("`@("`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@
M("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O
M="<L("1A='1R<ULG87!P)UTI("X@)R\G("X@)&%T=')S6R=U<FPG72D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!(;W)D93HZ;&EN:R@D
M=7)L+"!N=6QL+"`G)RP@)U]B;&%N:R<I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SPO83XG.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE("9L=#MB)F=T.R!T86<N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE
M=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A
M='1R<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<R`H3F]T
M('5S960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8DAA;F1L97(H)'-T87)T
M5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*("`@("`@("`@("`@
M)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@)SQS=')O;F<^)R`Z("<\
M+W-T<F]N9SXG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-
M3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`F;'0[:29G=#L@=&%G+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H
M97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T
M<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]I2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F
M("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U
M="`N/2`D<W1A<G1486<@/R`G/&5M/B<@.B`G/"]E;3XG.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R
M('1H92`F;'0[<')E)F=T.R!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G
M("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I=&EO;F%L
M(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W!R
M94AA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI
M('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@
M)SQP<F4^)R`Z("<\+W!R93XG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\=&EP/B!T86<N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@
M=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A='1R<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W1I<$AA;F1L97(H)'-T87)T5&%G+"`D
M871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN
M2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@)SQE;2!C;&%S<STB:&5L<%1I<"(^
M)R`Z("<\+V5M/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QW87)N/B!T86<N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R
M<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W=A<FY(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@
M)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X]("1S=&%R=%1A9R`_("<\96T@8VQA<W,](FAE;'!787)N(CXG(#H@
M)SPO96T^)SL*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U5T:6PN<&AP````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`V-S(V,0`Q,#4Q-30S,3`V,0`P,3<V-38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\J*@H@*B!%<G)O<B!C;V1E(&9O<B!A(&UI<W-I;F<@9')I=F5R(&-O
M;F9I9W5R871I;VXN"B`J+PID969I;F4H)TA/4D1%7T524D]27T12259%4E]#
M3TY&24=?34E34TE.1R<L(#$I.PH*+RHJ"B`J($5R<F]R(&-O9&4@9F]R(&%N
M(&EN8V]M<&QE=&4@9')I=F5R(&-O;F9I9W5R871I;VXN"B`J+PID969I;F4H
M)TA/4D1%7T524D]27T12259%4E]#3TY&24<G+"`R*3L*"B\J*@H@*B!4:&4@
M571I;#HZ(&-L87-S('!R;W9I9&5S(&=E;F5R86QL>2!U<V5F=6P@;65T:&]D
M<R!O9B!D:69F97)E;G0@:VEN9',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U5T:6PO571I;"YP:'`L=B`Q+C,X-"XV+C$W(#(P,#8O,#4O,#4@,38Z,#(Z
M,3(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?571I;`H@
M*B\*8VQA<W,@571I;"!["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&]B
M:F5C="=S(&-L;VYE+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1O
M8FH@(%1H92!O8FIE8W0@=&\@8VQO;F4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!O8FIE8W0@(%1H92!C;&]N960@;V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F8VQO;F5/8FIE8W0H)B1O8FHI"B`@("!["B`@("`@("`@+RH@0VQO
M;FEN9R!D;V5S("IN;W0J(&-U<G)E;G1L>2!W;W)K(&EF('5S:6YG(%!(4"`U
M+@H@("`@("`@("`J(%1H:7,@:7,@82!K;F]W;B!02%`@:7-S=64Z(&AT='`Z
M+R]B=6=S+G!H<"YN970O8G5G+G!H<#]I9#TR-S(V.`H@("`@("`@("`J(%1H
M97)E9F]R92P@=V]R:R!A<F]U;F0@=&AI<R!I<W-U92!B>2!U<VEN9R!T:&4@
M4$A0(#0*("`@("`@("`@*B!S97)I86QI>F4O=6YS97)I86QI>F4@8VQO;F4@
M:&%C:RX@*B\*("`@("`@("`O*@H@("`@("`@(&EF("AV97)S:6]N7V-O;7!A
M<F4H>F5N9%]V97)S:6]N*"DL("<R)RP@)SXG*2D@>PH@("`@("`@("`@("!R
M971U<FX@8VQO;F4H)&]B:BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&YE=T]B:B`]("1O8FH["B`@("`@("`@("`@(')E='5R;B`D;F5W3V)J
M.PH@("`@("`@('T*("`@("`@("`J+PH@("`@("`@("1R970@/2!U;G-E<FEA
M;&EZ92AS97)I86QI>F4H)&]B:BDI.PH@("`@("`@(')E='5R;B`D<F5T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0G5F9F5R<R!T:&4@;W5T<'5T(&9R;VT@
M82!F=6YC=&EO;B!C86QL+"!L:6ME(')E861F:6QE*"D@;W(*("`@("`J(&AI
M9VAL:6=H=%]S=')I;F<H*2P@=&AA="!P<FEN=',@=&AE(&]U='!U="!D:7)E
M8W1L>2P@<V\@=&AA="!I;G-T96%D(&ET"B`@("`@*B!C86X@8F4@<F5T=7)N
M960@87,@82!S=')I;F<@86YD('5S960N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9G5N8W1I;VX@(%1H92!F=6YC=&EO;B!T;R!R=6XN"B`@("`@
M*B!`<&%R86T@;6EX960@)&%R9S$@("`@("`@1FER<W0@87)G=6UE;G0@=&\@
M)&9U;F-T:6]N*"DN"B`@("`@*B!`<&%R86T@;6EX960@)&%R9S(@("`@("`@
M4V5C;VYD(&%R9W5M96YT('1O("1F=6YC=&EO;B@I+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1A<F<N+BX@("`@("XN+@H@("`@("H@0'!A<F%M(&UI>&5D("1A
M<F=.("`@("`@($YT:"!A<F=U;65N="!T;R`D9G5N8W1I;VXH*2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&]U='!U="!O9B!T:&4@9G5N
M8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U9F9E<D]U='!U="@I"B`@
M("!["B`@("`@("`@:68@*&9U;F-?;G5M7V%R9W,H*2`]/2`P*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)&EN8VQU
M9&4@/2!F86QS93L*("`@("`@("`D87)G<R`](&9U;F-?9V5T7V%R9W,H*3L*
M("`@("`@("`D9G5N8W1I;VX@/2!A<G)A>5]S:&EF="@D87)G<RD["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1F=6YC=&EO;BDI('L*("`@("`@("`@("`@:68@
M*"%I<U]C86QL86)L92@D9G5N8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H
M*"1F=6YC=&EO;B`]/2`G:6YC;'5D92<I('Q\"B`@("`@("`@("`@("`@("`@
M("@D9G5N8W1I;VX@/3T@)VEN8VQU9&5?;VYC92<I('Q\"B`@("`@("`@("`@
M("`@("`@("@D9G5N8W1I;VX@/3T@)W)E<75I<F4G*2!\?`H@("`@("`@("`@
M("`@("`@("`H)&9U;F-T:6]N(#T]("=R97%U:7)E7V]N8V4G*2D@>PH@("`@
M("`@("`@("`D:6YC;'5D92`]('1R=64["B`@("`@("`@?2!E;'-E:68@*"%F
M=6YC=&EO;E]E>&ES=',H)&9U;F-T:6]N*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!O8E]S=&%R="@I.PH@("`@
M("`@(&EF("@D:6YC;'5D92D@>PH@("`@("`@("`@("`D9FEL92`](&EM<&QO
M9&4H)RPG+"`D87)G<RD["B`@("`@("`@("`@('-W:71C:"`H)&9U;F-T:6]N
M*2!["B`@("`@("`@("`@(&-A<V4@)VEN8VQU9&4G.@H@("`@("`@("`@("`@
M("`@:6YC;'5D92`D9FEL93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G:6YC;'5D95]O;F-E)SH*("`@("`@("`@("`@("`@
M(&EN8VQU9&5?;VYC92`D9FEL93L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G<F5Q=6ER92<Z"B`@("`@("`@("`@("`@("!R
M97%U:7)E("1F:6QE.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=R97%U:7)E7V]N8V4G.@H@("`@("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("1F:6QE.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!C86QL7W5S
M97)?9G5N8U]A<G)A>2@D9G5N8W1I;VXL("1A<F=S*3L*("`@("`@("!]"B`@
M("`@("`@)&]U='!U="`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@(&]B
M7V5N9%]C;&5A;B@I.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@:68@82!V86QU92!H87,@
M8F5E;B!S970@8GD@=&AE('-C<FEP="!A;F0@;F]T(&)Y($=%5"P*("`@("`J
M(%!/4U0L(&]R(&-O;VMI92!I;G!U="X@5&AE('9A;'5E(&)E:6YG(&-H96-K
M960@35535"!B92!I;B!T:&4@9VQO8F%L"B`@("`@*B!S8V]P92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87)N86UE("!4:&4@=F%R:6%B;&4@
M;F%M92!T;R!C:&5C:RX*("`@("`J($!P87)A;2!M:7AE9"`D9&5F875L="`@
M($1E9F%U;'0@=F%L=64@:68@=&AE('9A<FEA8FQE(&ES;B=T('!R97-E;G0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&]R('=A<R!S<&5C:69I
M960@8GD@=&AE('5S97(N($1E9F%U;'1S('1O(&YU;&PN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@)&1E9F%U;'0@:68@=&AE('9A<B!I<R!I
M;B!U<V5R(&EN<'5T(&]R(&YO="!P<F5S96YT+`H@("`@("H@("`@("`@("`@
M("`@("`@=&AE('9A<FEA8FQE('9A;'5E(&]T:&5R=VES92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;F]N26YP=71687(H)'9A<FYA;64L("1D969A=6QT(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]'151;)'9A<FYA;65=
M*2!\?`H@("`@("`@("`@("!I<W-E="@D7U!/4U1;)'9A<FYA;65=*2!\?`H@
M("`@("`@("`@("!I<W-E="@D7T-/3TM)15LD=F%R;F%M95TI*2!["B`@("`@
M("`@("`@(')E='5R;B`D9&5F875L=#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@:7-S970H)$=,3T)!3%-;)'9A<FYA;65=*2`_("1'
M3$]"04Q36R1V87)N86UE72`Z("1D969A=6QT.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9',@82!N86UE/79A;'5E('!A:7(@=&\@=&AE
M(&5N9"!O9B!A;B!54DPL('1A:VEN9R!C87)E(&]F('=H971H97(*("`@("`J
M('1H97)E(&%R92!E>&ES=&EN9R!P87)A;65T97)S(&%N9"!W:&5T:&5R('1O
M('5S92`_+"`F(&]R("9A;7`[(&%S('1H90H@("`@("H@9VQU92X@($%L;"!D
M871A('=I;&P@8F4@=7)L96YC;V1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<FP@("`@("`@5&AE(%523"!T;R!M;V1I9GD*("`@("`J($!P
M87)A;2!M:7AE9"`D<&%R86UE=&5R("!%:71H97(@=&AE(&YA;64]=F%L=64@
M<&%I<B!T;R!A9&0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`H
M1$504D5#051%1"D@+6]R+0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!N86UE('9A;'5E("UO<BT*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!A;B!A<G)A>2!O9B!N86UE+W9A;'5E('!A:7)S+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("`@($EF('-P96-I9FEE9"P@=&AE
M('9A;'5E('!A<G0@*"1P87)A;65T97(@:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&5N(&%S<W5M960@=&\@:G5S="!B92!T:&4@<&%R
M86UE=&5R(&YA;64I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&5N8V]D92`@
M($EF('1R=64L(&%N9"!W92!D;VXG="!H879E(&%R9W5M96YT('-E<&%R871O
M<G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!Y970L('1H92!A
M<F=U;65N="!S97!A<F%T;W(@9V5T<R!E;F-O9&5D+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@55),+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1087)A;65T97(H)'5R;"P@)'!A<F%M971E<BP@)'9A
M;'5E(#T@;G5L;"P@)&5N8V]D92`]('1R=64I"B`@("!["B`@("`@("`@<W1A
M=&EC("1T<F%N<VQA=&EO;E]T86)L93L*"B`@("`@("`@:68@*"%I<W-E="@D
M=')A;G-L871I;VY?=&%B;&4I*2!["B`@("`@("`@("`@("1T<F%N<VQA=&EO
M;E]T86)L92`](&%R<F%Y7V9L:7`H9V5T7VAT;6Q?=')A;G-L871I;VY?=&%B
M;&4H2%1-3%]%3E1)5$E%4RDI.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)'!A<F%M971E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1U<FP["B`@
M("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=&\@:&%V92!A;B!A<G)A
M>2X@*B\*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;65T97(I*2!["B`@
M("`@("`@("`@("1A9&0@/2!A<G)A>2@D<&%R86UE=&5R(#T^("1V86QU92D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%D9"`]("1P87)A;65T
M97(["B`@("`@("`@?0H*("`@("`@("`D87)G(#T@)&5N8V]D92`_("<F86UP
M.R<@.B`G)B<["B`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1U<FPL("<_
M)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D9VQU92`]("<_)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!#:&5C:R!I9B!T:&4@87)G
M=6UE;G0@<V5P87)A=&]R(&AA<R!B965N(&%L<F5A9'D*("`@("`@("`@("`@
M("H@:'1M;&5N=&ET:65S+6EZ960@:6X@=&AE(%523"X@*B\*("`@("`@("`@
M("`@)'%U97)Y(#T@<W5B<W1R*"1U<FPL("1P;W,@*R`Q*3L*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\]+BH_)F%M<#LN*C\]+R<L("1Q=65R>2DI
M('L*("`@("`@("`@("`@("`@("1A<F<@/2`G)F%M<#LG.PH@("`@("`@("`@
M("`@("`@)'%U97)Y(#T@<W1R='(H)'%U97)Y+"`D=')A;G-L871I;VY?=&%B
M;&4I.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+STN*C\F
M+BH_/2\G+"`D<75E<GDI*2!["B`@("`@("`@("`@("`@("`D87)G(#T@)R8G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P86ER<R`](&5X<&QO9&4H
M)&%R9RP@)'%U97)Y*3L*("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1P86ER<R!A<R`D<&%I<BD@>PH@("`@
M("`@("`@("`@("`@)'!A:7(@/2!E>'!L;V1E*"<])RP@)'!A:7(L(#(I.PH@
M("`@("`@("`@("`@("`@)'!A<F%M<ULD<&%I<ELP75T@/2!C;W5N="@D<&%I
M<BD@/3T@,B`_("1P86ER6S%=(#H@)R<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&=L=64@/2`D87)G.PH@("`@("`@('T*"B`@("`@("`@)'5R;%]P
M87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1A9&0@87,@)'!A
M<F%M971E<B`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*"%I<W-E="@D
M<&%R86US6R1P87)A;65T97)=*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D=F%L=64@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=7)L7W!A<F%M<UM=(#T@=7)L96YC;V1E*"1P87)A;65T97(I("X@)UM=/2<@
M+B!U<FQE;F-O9&4H)'9A;"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=7)L
M7W!A<F%M<UM=(#T@=7)L96YC;V1E*"1P87)A;65T97(I("X@)STG("X@=7)L
M96YC;V1E*"1V86QU92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D=7)L7W!A<F%M<RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1U<FP@+B`D9VQU92`N(&EM<&QO9&4H
M)&%R9RP@)'5R;%]P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=7)L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;6]V97,@;F%M93UV86QU92!P86ER<R!F<F]M(&$@55),+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("!4:&4@55),('1O(&UO
M9&EF>2X*("`@("`J($!P87)A;2!M:7AE9"`D<F5M;W9E("!%:71H97(@82!S
M:6YG;&4@<&%R86UE=&5R('1O(')E;6]V92!O<B!A;B!A<G)A>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&]F('!A<F%M971E<G,@=&\@<F5M;W9E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@
M55),+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5087)A;65T97(H)'5R
M;"P@)')E;6]V92D*("`@('L*("`@("`@("!S=&%T:6,@)'1R86YS;&%T:6]N
M7W1A8FQE.PH*("`@("`@("!I9B`H(6ES<V5T*"1T<F%N<VQA=&EO;E]T86)L
M92DI('L*("`@("`@("`@("`@)'1R86YS;&%T:6]N7W1A8FQE(#T@87)R87E?
M9FQI<"AG971?:'1M;%]T<F%N<VQA=&EO;E]T86)L92A(5$U,7T5.5$E42453
M*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?87)R87DH)')E;6]V92DI
M('L*("`@("`@("`@("`@)')E;6]V92`](&%R<F%Y*"1R96UO=F4I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4F5T=7)N(&EM;65D:6%T96QY(&EF('1H97)E
M(&%R92!N;R!P87)A;65T97)S('1O(')E;6]V92X@*B\*("`@("`@("!I9B`H
M*"1P;W,@/2!S=')P;W,H)'5R;"P@)S\G*2D@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@('T*"B`@("`@("`@)&5N=&ET
M:65S(#T@9F%L<V4["B`@("`@("`@;&ES="@D=7)L+"`D<75E<GDI(#T@97AP
M;&]D92@G/R<L("1U<FPL(#(I.PH*("`@("`@("`O*B!#:&5C:R!I9B!T:&4@
M87)G=6UE;G0@<V5P87)A=&]R(&AA<R!B965N(&%L<F5A9'D*("`@("`@("`@
M*B!H=&UL96YT:71I97,M:7IE9"!I;B!T:&4@55),+B`J+PH@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O/2XJ/R9A;7`[+BH_/2\G+"`D<75E<GDI*2!["B`@
M("`@("`@("`@("1E;G1I=&EE<R`]('1R=64["B`@("`@("`@("`@("1Q=65R
M>2`]('-T<G1R*"1Q=65R>2P@)'1R86YS;&%T:6]N7W1A8FQE*3L*("`@("`@
M("!]"@H@("`@("`@("\J($=E="!T:&4@;&ES="!O9B!P87)A;65T97)S+B`J
M+PH@("`@("`@("1P86ER<R`](&5X<&QO9&4H)R8G+"`D<75E<GDI.PH@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1P86ER
M<R!A<R`D<&%I<BD@>PH@("`@("`@("`@("`D<&%I<B`](&5X<&QO9&4H)STG
M+"`D<&%I<BP@,BD["B`@("`@("`@("`@("1P87)A;7-;)'!A:7);,%U=(#T@
M8V]U;G0H)'!A:7(I(#T](#(@/R`D<&%I<ELQ72`Z("<G.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5M;W9E('1H92!P87)A;65T97)S+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1R96UO=F4@87,@)'!A<F%M*2!["B`@("`@("`@("`@('5N
M<V5T*"1P87)A;7-;)'!A<F%M72D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6-O=6YT*"1P87)A;7,I*2!["B`@("`@("`@("`@(')E='5R;B`D=7)L.PH@
M("`@("`@('T*"B`@("`@("`@+RH@1FQA='1E;B!A<G)A>7,N"B`@("`@("`@
M("H@1DE8344Z('-H;W5L9"!H86YD;&4@;6]R92!T:&%N(&]N92!A<G)A>2!L
M979E;"!S;VUE:&]W+B`J+PH@("`@("`@("1A9&0@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'9A;"!A<R`D=BD@>PH@("`@("`@("`@("`@("`@("`@("1A
M9&1;72`]("1K97D@+B`G6UT])R`N("1V.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%D9%M=(#T@
M)&ME>2`N("<])R`N("1V86P["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1Q=65R>2`](&EM<&QO9&4H)R8G+"`D861D*3L*("`@("`@("!I
M9B`H)&5N=&ET:65S*2!["B`@("`@("`@("`@("1Q=65R>2`](&AT;6QE;G1I
M=&EE<R@D<75E<GDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP@
M+B`G/R<@+B`D<75E<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@=7)L('=I=&@@=&AE("=N;V-A8VAE)R!P87)A;65T97(@861D960L(&EF
M('1H92!B<F]W<V5R(&ES"B`@("`@*B!B=6=G>2!A;F0@8V%C:&5S(&]L9"!5
M4DQS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@5&AE(%52
M3"!T;R!M;V1I9GDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R97%U97-T960@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!N;V-A8VAE
M57)L*"1U<FPI"B`@("!["B`@("`@("`@<W1A=&EC("1R86YD7VYU;3L*"B`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"<F]W<V5R+G!H<"<["B`@("`@
M("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["@H@("`@("`@
M("\J(%=E(&UA>2!N965D('1O('-E="!A(&1U;6UY('!A<F%M971E<B`G;F]C
M86-H92<@<VEN8V4@<V]M90H@("`@("`@("`J(&)R;W=S97)S(&1O(&YO="!A
M;'=A>7,@:&]N;W(@=&AE("=N;RUC86-H92<@:&5A9&5R+B`J+PH@("`@("`@
M(&EF("@D8G)O=W-E<BT^:&%S475I<FLH)V-A8VAE7W-A;65?=7)L)RDI('L*
M("`@("`@("`@("`@:68@*"%I<W-E="@D<F%N9%]N=6TI*2!["B`@("`@("`@
M("`@("`@("`D<F%N9%]N=6T@/2!B87-E7V-O;G9E<G0H;6EC<F]T:6UE*"DL
M(#$P+"`S-BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(%5T
M:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;F]C86-H92<L("1R86YD7VYU;2D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1U<FP["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AI9&1E
M;B!F;W)M(&EN<'5T(&-O;G1A:6YI;F<@=&AE('-E<W-I;VX@;F%M92!A;F0@
M:60N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%P<&5N9%]S97-S
M:6]N("`P(#T@;VYL>2!I9B!N965D960L(#$@/2!A;'=A>7,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!H:61D96X@9F]R;2!I;G!U="P@
M:68@;F5E9&5D+W)E<75E<W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9F]R
M;4EN<'5T*"1A<'!E;F1?<V5S<VEO;B`](#`I"B`@("!["B`@("`@("`@:68@
M*"1A<'!E;F1?<V5S<VEO;B`]/2`Q('Q\"B`@("`@("`@("`@("%I<W-E="@D
M7T-/3TM)15MS97-S:6]N7VYA;64H*5TI*2!["B`@("`@("`@("`@(')E='5R
M;B`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H<V5S<VEO;E]N86UE*"DI("X@)R(@=F%L=64](B<@+B!H=&UL<W!E
M8VEA;&-H87)S*'-E<W-I;VY?:60H*2D@+B`B7"(@+SY<;B(["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%!R:6YT<R!A(&AI9&1E;B!F;W)M(&EN<'5T
M(&-O;G1A:6YI;F<@=&AE('-E<W-I;VX@;F%M92!A;F0@:60N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%P<&5N9%]S97-S:6]N("`P(#T@;VYL
M>2!I9B!N965D960L(#$@/2!A;'=A>7,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!F;W)M26YP=70H)&%P<&5N9%]S97-S:6]N(#T@,"D*("`@('L*("`@("`@
M("!E8VAO(%5T:6PZ.F9O<FU);G!U="@D87!P96YD7W-E<W-I;VXI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@268@;6%G:6-?<75O=&5S7V=P8R!I<R!I;B!U
M<V4L(')U;B!S=')I<'-L87-H97,H*2!O;B`D=F%R+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)B1V87(@(%1H92!S=')I;F<@=&\@=6XM<75O=&4L
M(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M)'9A<BP@;6EN=7,@86YY(&UA9VEC('%U;W1E<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&ES<&5L36%G:6-1=6]T97,H)B1V87(I"B`@("!["B`@("`@("`@
M<W1A=&EC("1M86=I8U]Q=6]T97,["@H@("`@("`@(&EF("@A:7-S970H)&UA
M9VEC7W%U;W1E<RDI('L*("`@("`@("`@("`@)&UA9VEC7W%U;W1E<R`](&=E
M=%]M86=I8U]Q=6]T97-?9W!C*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)&UA9VEC7W%U;W1E<RD@>PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V
M87(I*2!["B`@("`@("`@("`@("`@("`D=F%R(#T@<W1R:7!S;&%S:&5S*"1V
M87(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@87)R
M87E?=V%L:R@D=F%R+"!A<G)A>2@G571I;"<L("=D:7-P96Q-86=I8U%U;W1E
M<R<I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1V87(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S(&$@9F]R;2!V87)I
M86)L92!F<F]M($=%5"!O<B!03U-4(&1A=&$L('-T<FEP<&5D(&]F(&UA9VEC
M('%U;W1E<R!I9@H@("`@("H@;F5C97-S87)Y+B!)9B!T:&4@=F%R:6%B;&4@
M:7,@<V]M96AO=R!S970@:6X@8F]T:"!T:&4@1T54(&1A=&$@86YD('1H90H@
M("`@("H@4$]35"!D871A+"!T:&4@=F%L=64@9G)O;2!T:&4@4$]35"!D871A
M('=I;&P@8F4@<F5T=7)N960@86YD('1H92!'150*("`@("`J('9A;'5E('=I
M;&P@8F4@:6=N;W)E9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V
M87(@("`@("!4:&4@;F%M92!O9B!T:&4@9F]R;2!V87)I86)L92!T;R!L;V]K
M(&9O<BX*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@(%1H92!V86QU
M92!T;R!R971U<FX@:68@=&AE('9A<FEA8FQE(&ES(&YO=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE<F4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!C;&5A;F5D(&9O<FT@=F%R:6%B;&4L(&]R("1D
M969A=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&;W)M1&%T82@D=F%R
M+"`D9&5F875L="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N("@H)'9A
M;"`](%5T:6PZ.F=E=%!O<W0H)'9A<BDI("$]/2!N=6QL*0H@("`@("`@("`@
M("`_("1V86P@.B!5=&EL.CIG971'970H)'9A<BP@)&1E9F%U;'0I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T<R!A(&9O<FT@=F%R:6%B;&4@9G)O;2!'
M150@9&%T82P@<W1R:7!P960@;V8@;6%G:6,@<75O=&5S(&EF"B`@("`@*B!N
M96-E<W-A<GDN(%1H:7,@9G5N8W1I;VX@=VEL;"!.3U0@<F5T=7)N(&$@4$]3
M5"!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87(@
M("`@("!4:&4@;F%M92!O9B!T:&4@9F]R;2!V87)I86)L92!T;R!L;V]K(&9O
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@(%1H92!V86QU92!T
M;R!R971U<FX@:68@=&AE('9A<FEA8FQE(&ES(&YO=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE<F4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!C;&5A;F5D(&9O<FT@=F%R:6%B;&4L(&]R("1D969A
M=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'970H)'9A<BP@)&1E9F%U
M;'0@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-S970H)%]'151;
M)'9A<ETI*0H@("`@("`@("`@("`_(%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S
M*"1?1T546R1V87)=*0H@("`@("`@("`@("`Z("1D969A=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T<R!A(&9O<FT@=F%R:6%B;&4@9G)O;2!03U-4
M(&1A=&$L('-T<FEP<&5D(&]F(&UA9VEC('%U;W1E<R!I9@H@("`@("H@;F5C
M97-S87)Y+B!4:&ES(&9U;F-T:6]N('=I;&P@3D]4(')E='5R;B!A($=%5"!V
M87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87(@("`@
M("!4:&4@;F%M92!O9B!T:&4@9F]R;2!V87)I86)L92!T;R!L;V]K(&9O<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@(%1H92!V86QU92!T;R!R
M971U<FX@:68@=&AE('9A<FEA8FQE(&ES(&YO=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!C;&5A;F5D(&9O<FT@=F%R:6%B;&4L(&]R("1D969A=6QT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710;W-T*"1V87(L("1D969A=6QT
M(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@*&ES<V5T*"1?4$]35%LD
M=F%R72DI"B`@("`@("`@("`@(#\@571I;#HZ9&ES<&5L36%G:6-1=6]T97,H
M)%]03U-46R1V87)=*0H@("`@("`@("`@("`Z("1D969A=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;&]C871I;VX@;V8@=&AE
M('-Y<W1E;2!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!!(&1I<F5C=&]R>2!N86UE('=H:6-H(&-A;B!B92!U
M<V5D(&9O<B!T96UP(&9I;&5S+@H@("`@("H@("`@("`@("`@("`@("`@(%)E
M='5R;G,@9F%L<V4@:68@;VYE(&-O=6QD(&YO="!B92!F;W5N9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5&5M<$1I<B@I"B`@("!["B`@("`@("`@+RH@
M1FER<W0L('1R>2!02%`G<R!U<&QO861?=&UP7V1I<B!D:7)E8W1I=F4N("HO
M"B`@("`@("`@)'1M<"`](&EN:5]G970H)W5P;&]A9%]T;7!?9&ER)RD["@H@
M("`@("`@("\J($]T:&5R=VES92P@=')Y('1O(&1E=&5R;6EN92!T:&4@5$U0
M1$E2(&5N=FER;VYM96YT"B`@("`@("`@("H@=F%R:6%B;&4N("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("1T;7`@/2!G971E
M;G8H)U1-4$1)4B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@<W1I
M;&P@8V%N;F]T(&1E=&5R;6EN92!A('9A;'5E+"!T:&5N(&-Y8VQE('1H<F]U
M9V@@80H@("`@("`@("`J(&QI<W0@;V8@<')E<V5T('!O<W-I8FEL:71I97,N
M("HO"B`@("`@("`@)'1M<%]L;V-A=&EO;G,@/2!A<G)A>2@G+W1M<"<L("<O
M=F%R+W1M<"<L("=C.EQ7551E;7`G+"`G8SI<=&5M<"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8SI<=VEN9&]W<UQT96UP)RP@)V,Z7'=I
M;FYT7'1E;7`G*3L*("`@("`@("!W:&EL92`H96UP='DH)'1M<"D@)B8@8V]U
M;G0H)'1M<%]L;V-A=&EO;G,I*2!["B`@("`@("`@("`@("1T;7!?8VAE8VL@
M/2!A<G)A>5]S:&EF="@D=&UP7VQO8V%T:6]N<RD["B`@("`@("`@("`@(&EF
M("A`:7-?9&ER*"1T;7!?8VAE8VLI*2!["B`@("`@("`@("`@("`@("`D=&UP
M(#T@)'1M<%]C:&5C:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@268@:70@:7,@<W1I;&P@96UP='DL('=E(&AA=F4@9F%I;&5D+"!S
M;R!R971U<FX@9F%L<V4["B`@("`@("`@("H@;W1H97)W:7-E(')E='5R;B!T
M:&4@9&ER96-T;W)Y(&1E=&5R;6EN960N("HO"B`@("`@("`@<F5T=7)N(&5M
M<'1Y*"1T;7`I(#\@9F%L<V4@.B`D=&UP.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0W)E871E<R!A('1E;7!O<F%R>2!F:6QE;F%M92!F;W(@=&AE(&QI9F5T
M:6UE(&]F('1H92!S8W)I<'0L(&%N9`H@("`@("H@*&]P=&EO;F%L;'DI(')E
M9VES=&5R(&ET('1O(&)E(&1E;&5T960@870@<F5Q=65S="!S:'5T9&]W;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F:7@@("!0<F5F:7@@
M=&\@;6%K92!T:&4@=&5M<&]R87)Y(&YA;64@;6]R90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5C;V=N:7IA8FQE+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&1E;&5T92`@1&5L971E('1H92!F:6QE(&%T('1H92!E;F0@
M;V8@=&AE(')E<75E<W0_"B`@("`@*B!`<&%R86T@<W1R:6YG("1D:7(@("`@
M("!$:7)E8W1O<GD@=&\@8W)E871E('1H92!T96UP;W)A<GD@9FEL92!I;BX*
M("`@("`J($!P87)A;2!B;V]L96%N("1S96-U<F4@($EF(&1E;&5T:6YG(&9I
M;&4L('-H;W5L9"!W92!S96-U<F5L>2!D96QE=&4@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!F:6QE/PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("`@4F5T=7)N<R!T:&4@9G5L;"!P871H+6YA;64@=&\@=&AE
M('1E;7!O<F%R>2!F:6QE+@H@("`@("H@("`@("`@("`@("`@("`@("!2971U
M<FYS(&9A;'-E(&EF(&$@=&5M<"!F:6QE(&-O=6QD(&YO="!B92!C<F5A=&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971496UP1FEL92@D<')E9FEX(#T@
M)R<L("1D96QE=&4@/2!T<G5E+"`D9&ER(#T@)R<L("1S96-U<F4@/2!F86QS
M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1I<BD@?'P@(6ES7V1I<B@D
M9&ER*2D@>PH@("`@("`@("`@("`D=&UP7V1I<B`](%5T:6PZ.F=E=%1E;7!$
M:7(H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&UP7V1I<B`]
M("1D:7(["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'1M<%]D:7(I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1T;7!?9FEL92`]('1E;7!N86TH)'1M<%]D:7(L("1P<F5F:7@I.PH*
M("`@("`@("`O*B!)9B!T:&4@9FEL92!W87,@8W)E871E9"P@=&AE;B!R96=I
M<W1E<B!I="!F;W(@9&5L971I;VX@86YD(')E='5R;B`J+PH@("`@("`@(&EF
M("AE;7!T>2@D=&UP7V9I;&4I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&1E;&5T92D@
M>PH@("`@("`@("`@("`@("`@571I;#HZ9&5L971E0713:'5T9&]W;B@D=&UP
M7V9I;&4L('1R=64L("1S96-U<F4I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`D=&UP7V9I;&4["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A('1E;7!O<F%R>2!D:7)E8W1O<GD@:6X@=&AE
M('-Y<W1E;2=S('1E;7!O<F%R>2!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1E;&5T92`@($1E;&5T92!T:&4@=&5M<&]R87)Y
M(&1I<F5C=&]R>2!A="!T:&4@96YD(&]F"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(')E<75E<W0_"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T96UP7V1I<B`@57-E('1H:7,@=&5M<&]R87)Y(&1I<F5C=&]R>2!A<R!T
M:&4@9&ER96-T;W)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M=VAE<F4@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GD@=VEL;"!B92!C<F5A=&5D
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%T:&YA;64@
M=&\@=&AE(&YE=R!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("H@("`@("`@
M("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@9&ER96-T;W)Y(&YO="!C<F5A
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5496UP1&ER*"1D96QE
M=&4@/2!T<G5E+"`D=&5M<%]D:7(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("AI<U]N=6QL*"1T96UP7V1I<BDI('L*("`@("`@("`@("`@)'1E;7!?9&ER
M(#T@571I;#HZ9V5T5&5M<$1I<B@I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&5M<'1Y*"1T96UP7V1I<BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H92!F:7)S="`X(&-H87)A
M8W1E<G,@;V8@82!R86YD;VT@<W1R:6YG('1O('5S92!A<R!A('1E;7!O<F%R
M>0H@("`@("`@("`@(&1I<F5C=&]R>2!N86UE+B`J+PH@("`@("`@(&1O('L*
M("`@("`@("`@("`@)'1E;7!?9&ER("X]("<O)R`N('-U8G-T<BAB87-E7V-O
M;G9E<G0H;71?<F%N9"@I("X@;6EC<F]T:6UE*"DL(#$P+"`S-BDL(#`L(#@I
M.PH@("`@("`@('T@=VAI;&4@*&9I;&5?97AI<W1S*"1T96UP7V1I<BDI.PH*
M("`@("`@("`D;VQD7W5M87-K(#T@=6UA<VLH,#`P,"D["B`@("`@("`@:68@
M*"%M:V1I<B@D=&5M<%]D:7(L(#`W,#`I*2!["B`@("`@("`@("`@("1T96UP
M7V1I<B`](&9A;'-E.PH@("`@("`@('T@96QS96EF("@D9&5L971E*2!["B`@
M("`@("`@("`@(%5T:6PZ.F1E;&5T94%T4VAU=&1O=VXH)'1E;7!?9&ER*3L*
M("`@("`@("!]"B`@("`@("`@=6UA<VLH)&]L9%]U;6%S:RD["@H@("`@("`@
M(')E='5R;B`D=&5M<%]D:7(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!C86YO;FEC86P@<&%T:"!O9B!T:&4@<W1R:6YG+B`@3&EK92!0
M2%`G<R!B=6EL="UI;@H@("`@("H@<F5A;'!A=&@H*2!E>&-E<'0@=&AE(&1I
M<F5C=&]R>2!N965D(&YO="!E>&ES="!O;B!T:&4@;&]C86P@<V5R=F5R+@H@
M("`@("H*("`@("`J($%L9V]R:71H:6T@;&]O<V5L>2!B87-E9"!O;B!C;V1E
M(&9R;VT@=&AE(%!E<FP@1FEL93HZ4W!E8SHZ56YI>"!M;V1U;&4*("`@("`J
M("AV97)S:6]N(#$N-2DN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N
M,"XU"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@02!F:6QE
M('!A=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C86YO
M;FEC86QI>F5D(&9I;&4@<&%T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M;%!A=&@H)'!A=&@I"B`@("!["B`@("`@("`@+RH@4W1A;F1A<F1I>F4@;VX@
M54Y)6"!D:7)E8W1O<GD@<V5P87)A=&]R<RX@*B\*("`@("`@("!I9B`H<W5B
M<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<I('L*("`@("`@("`@("`@)'!A
M=&@@/2!S=')?<F5P;&%C92@G7%PG+"`G+R<L("1P871H*3L*("`@("`@("!]
M"@H@("`@("`@("\J('AX+R\O+WAX("T^('AX+WAX"B`@("`@("`@("H@>'@O
M+B\N+WAX("T^('AX+WAX("HO"B`@("`@("`@)'!A=&@@/2!P<F5G7W)E<&QA
M8V4H87)R87DH(GPO*WPB+"`B0"@O7"XI*R@O?%Q:*#\A7&XI*4`B*2P@87)R
M87DH)R\G+"`G+R<I+"`D<&%T:"D["@H@("`@("`@("\J("XO>'@@+3X@>'@@
M*B\*("`@("`@("!I9B`H)'!A=&@@(3T@)RXO)RD@>PH@("`@("`@("`@("`D
M<&%T:"`]('!R96=?<F5P;&%C92@B?%XH7"XO*2M\(BP@)R<L("1P871H*3L*
M("`@("`@("!]"@H@("`@("`@("\J("\N+B\N+B]X>"`M/B!X>"`J+PH@("`@
M("`@("1P871H(#T@<')E9U]R97!L86-E*")\7B\H7"Y<+B\_*2M\(BP@)R\G
M+"`D<&%T:"D["@H@("`@("`@("\J('AX+R`M/B!X>"`J+PH@("`@("`@(&EF
M("@D<&%T:"`A/2`G+R<I('L*("`@("`@("`@("`@)'!A=&@@/2!P<F5G7W)E
M<&QA8V4H(GPO7%HH/R%<;BE\(BP@)R<L("1P871H*3L*("`@("`@("!]"@H@
M("`@("`@("\J("]X>"\N+B`M/B`O("HO"B`@("`@("`@=VAI;&4@*'-T<G!O
M<R@D<&%T:"P@)R\N+B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%T
M:"`]('!R96=?<F5P;&%C92@B?"];7B]=*R]<+EPN?"(L("<G+"`D<&%T:"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@96UP='DH)'!A=&@I(#\@)R\G
M(#H@)'!A=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&=I=F5N
M(&5L96UE;G1S(&%T(')E<75E<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@
M268@8V%L;&5D('=I=&@@82!F:6QE;F%M92!W:6QL(&1E;&5T92!T:&%T(&9I
M;&4@870@<F5Q=65S="!S:'5T9&]W;CL@:68*("`@("`J(&-A;&QE9"!W:71H
M(&$@9&ER96-T;W)Y('=I;&P@<F5M;W9E('1H870@9&ER96-T;W)Y(&%N9"!A
M;&P@9FEL97,@:6X@=&AA=`H@("`@("H@9&ER96-T;W)Y(&%T(')E<75E<W0@
M<VAU=&1O=VXN"B`@("`@*@H@("`@("H@268@8V%L;&5D('=I=&@@;F\@87)G
M=6UE;G1S+"!R971U<FX@86QL(&5L96UE;G1S('1O(&)E(&1E;&5T960@*'1H
M:7,*("`@("`J('-H;W5L9"!O;FQY(&)E(&1O;F4@8GD@571I;#HZ7V1E;&5T
M94%T4VAU=&1O=VXI+@H@("`@("H*("`@("`J(%1H92!F:7)S="!T:6UE(&ET
M(&ES(&-A;&QE9"P@:70@:6YI=&EA;&EZ97,@=&AE(&%R<F%Y(&%N9"!R96=I
M<W1E<G,*("`@("`J(%5T:6PZ.E]D96QE=&5!=%-H=71D;W=N*"D@87,@82!S
M:'5T9&]W;B!F=6YC=&EO;B`M(&YO(&YE960@=&\@9&\@<V\*("`@("`J(&UA
M;G5A;&QY+@H@("`@("H*("`@("`J(%1H92!S96-O;F0@<&%R86UE=&5R(&%L
M;&]W<R!T:&4@=6YR96=I<W1E<FEN9R!O9B!P<F5V:6]U<VQY(')E9VES=&5R
M960*("`@("`J(&5L96UE;G1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&9I;&5N86UE("`@5&AE(&9I;&5N86UE('1O(&)E(&1E;&5T960@870@
M=&AE(&5N9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5Q=65S="X*("`@("`J($!P87)A;2!B;V]L96%N("1R96=I<W1E<B`@
M268@=')U92P@=&AE;B!R96=I<W1E<B!T:&4@96QE;65N="!F;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5L971I;VXL(&]T:&5R=VES
M92P@=6YR96=I<W1E<B!I="X*("`@("`J($!P87)A;2!B;V]L96%N("1S96-U
M<F4@("`@268@9&5L971I;F<@9FEL92P@<VAO=6QD('=E('-E8W5R96QY(&1E
M;&5T90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9FEL
M93\*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E0713:'5T9&]W;B@D9FEL
M96YA;64@/2!F86QS92P@)')E9VES=&5R(#T@=')U92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-E8W5R92`](&9A;'-E*0H@("`@>PH@("`@
M("`@('-T871I8R`D9&ER<RP@)&9I;&5S+"`D<V5C=7)E9&5L.PH*("`@("`@
M("`O*B!);FET:6%L:7IA=&EO;B!O9B!V87)I86)L97,@86YD('-H=71D;W=N
M(&9U;F-T:6]N<RX@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D9&ER<RDI('L*
M("`@("`@("`@("`@)&1I<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D9FEL
M97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D<V5C=7)E9&5L(#T@87)R87DH
M*3L*("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R
M87DH)U5T:6PG+"`G7V1E;&5T94%T4VAU=&1O=VXG*2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&9I;&5N86UE*2!["B`@("`@("`@("`@(&EF("@D<F5G
M:7-T97(I('L*("`@("`@("`@("`@("`@(&EF("A`:7-?9&ER*"1F:6QE;F%M
M92DI('L*("`@("`@("`@("`@("`@("`@("`D9&ER<ULD9FEL96YA;65=(#T@
M=')U93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)&9I;&5S6R1F:6QE;F%M95T@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"1S96-U<F4I('L*("`@("`@("`@
M("`@("`@("`@("`D<V5C=7)E9&5L6R1F:6QE;F%M95T@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@=6YS970H)&1I<G-;)&9I;&5N86UE72D["B`@("`@("`@("`@("`@
M("!U;G-E="@D9FEL97-;)&9I;&5N86UE72D["B`@("`@("`@("`@("`@("!U
M;G-E="@D<V5C=7)E9&5L6R1F:6QE;F%M95TI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1D:7)S
M+"`D9FEL97,L("1S96-U<F5D96PI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($1E;&5T97,@<F5G:7-T97)E9"!F:6QE<R!A="!R97%U97-T
M('-H=71D;W=N+@H@("`@("H*("`@("`J(%1H:7,@9G5N8W1I;VX@<VAO=6QD
M(&YE=F5R(&)E(&-A;&QE9"!M86YU86QL>3L@:70@:7,@<F5G:7-T97)E9"!A
M<R!A"B`@("`@*B!S:'5T9&]W;B!F=6YC=&EO;B!B>2!5=&EL.CID96QE=&5!
M=%-H=71D;W=N*"D@86YD(&-A;&QE9"!A=71O;6%T:6-A;&QY"B`@("`@*B!A
M="!T:&4@96YD(&]F('1H92!R97%U97-T+B!)="!W:6QL(')E=')I979E('1H
M92!L:7-T(&]F(&9O;&1E<G,@86YD"B`@("`@*B!F:6QE<R!T;R!D96QE=&4@
M9G)O;2!5=&EL.CID96QE=&5!=%-H=71D;W=N*"DG<R!S=&%T:6,@87)R87DL
M(&%N9"!T:&5N"B`@("`@*B!I=&5R871E('1H<F]U9V@L(&1E;&5T:6YG(&9O
M;&1E<G,@<F5C=7)S:79E;'DN"B`@("`@*@H@("`@("H@0V]N=&%I;G,@8V]D
M92!F<F]M(&=P9U]F=6YC=&EO;G,N<&AP+@H@("`@("H@0V]P>7)I9VAT("AC
M*2`R,#`R+3(P,#,@0G)A=F5R;V-K(%9E;G1U<F5S"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96QE=&5!
M=%-H=71D;W=N*"D*("`@('L*("`@("`@("`D<F5G:7-T97)E9"`](%5T:6PZ
M.F1E;&5T94%T4VAU=&1O=VXH*3L*("`@("`@("`D9&ER<R`]("1R96=I<W1E
M<F5D6S!=.PH@("`@("`@("1F:6QE<R`]("1R96=I<W1E<F5D6S%=.PH@("`@
M("`@("1S96-U<F4@/2`D<F5G:7-T97)E9%LR73L*"B`@("`@("`@9F]R96%C
M:"`H)&9I;&5S(&%S("1F:6QE(#T^("1V86PI('L*("`@("`@("`@("`@+RH@
M1&5L971E(&9I;&5S("HO"B`@("`@("`@("`@(&EF("@D=F%L("8F($!F:6QE
M7V5X:7-T<R@D9FEL92DI('L*("`@("`@("`@("`@("`@("\J(%-H;W5L9"!W
M92!S96-U<F5L>2!D96QE=&4@=&AE(&9I;&4@8GD@;W9E<G=R:71I;F<@=&AE
M"B`@("`@("`@("`@("`@("`@("!D871A('=I=&@@82!R86YD;VT@<W1R:6YG
M/R`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1S96-U<F5;)&9I;&5=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1R86YD;VU?<W1R(#T@)R<["B`@
M("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@9FEL97-I>F4H
M)&9I;&4I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R86YD
M;VU?<W1R("X](&-H<BAM=%]R86YD*#`L(#(U-2DI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL
M92P@)W(K)RD["B`@("`@("`@("`@("`@("`@("`@9G=R:71E*"1F<"P@)')A
M;F1O;5]S='(I.PH@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@0'5N;&EN:R@D9FEL
M92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1D:7)S(&%S("1D:7(@/3X@)'9A;"D@>PH@("`@("`@("`@("`O*B!$96QE
M=&4@9&ER96-T;W)I97,@*B\*("`@("`@("`@("`@:68@*"1V86P@)B8@0&9I
M;&5?97AI<W1S*"1D:7(I*2!["B`@("`@("`@("`@("`@("`O*B!-86ME('-U
M<F4@9&ER96-T;W)Y(&ES(&5M<'1Y+B`J+PH@("`@("`@("`@("`@("`@)&1I
M<E]C;&%S<R`](&1I<B@D9&ER*3L*("`@("`@("`@("`@("`@('=H:6QE("AF
M86QS92`A/3T@*"1E;G1R>2`]("1D:7)?8VQA<W,M/G)E860H*2DI('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&5N=')Y("$]("<N)R`F)B`D96YT<GD@
M(3T@)RXN)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!`=6YL:6YK*"1D
M:7(@+B`G+R<@+B`D96YT<GDI.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D:7)?8VQA<W,M/F-L
M;W-E*"D["B`@("`@("`@("`@("`@("!`<FUD:7(H)&1I<BD["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S
M(&IA=F%S8W)I<'0@8V]D92!T;R!C;&]S92!T:&4@8W5R<F5N="!W:6YD;W<N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]D92`@06YY(&%D9'1I
M;VYA;"!J879A<V-R:7!T(&-O9&4@=&\@<G5N(&)E9F]R90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@8VQO<VEN9R!T:&4@=VEN9&]W+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;&]S95=I;F1O=TI3*"1C;V1E(#T@)R<I"B`@("![
M"B`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/B<@+B`D8V]D92`N"B`@("`@("`@("`@("=W:6YD;W<N8VQO<V4H*3L\+W-C
M<FEP=#XG.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%C:&5S('1H92!R97-U
M;'0@;V8@97AT96YS:6]N7VQO861E9"@I(&-A;&QS+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&5X="`@5&AE(&5X=&5N<VEO;B!N86UE+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@27,@=&AE(&5X=&5N<VEO;B!L;V%D960_"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5X=&5N<VEO;D5X:7-T<R@D97AT*0H@("`@>PH@("`@
M("`@('-T871I8R`D8V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1C86-H95LD97AT72DI('L*("`@("`@("`@("`@)&-A8VAE6R1E>'1=
M(#T@97AT96YS:6]N7VQO861E9"@D97AT*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D8V%C:&5;)&5X=%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M<FEE<R!T;R!L;V%D(&$@4$A0(&5X=&5N<VEO;BP@8F5H879I;F<@8V]R<F5C
M=&QY(&9O<B!A;&P@;W!E<F%T:6YG"B`@("`@*B!S>7-T96US+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&5X="`@5&AE(&5X=&5N<VEO;B!T;R!L
M;V%D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T
M:&4@97AT96YS:6]N(&ES(&YO=R!L;V%D960L(&9A;'-E(&EF(&YO="X*("`@
M("`J("`@("`@("`@("`@("`@("`@5')U92!C86X@;65A;B!T:&%T('1H92!E
M>'1E;G-I;VX@=V%S(&%L<F5A9'D@;&]A9&5D+`H@("`@("H@("`@("`@("`@
M("`@("`@("!/4B!W87,@;&]A9&5D(&1Y;F%M:6-A;&QY+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L;V%D17AT96YS:6]N*"1E>'0I"B`@("!["B`@("`@("`@
M+RH@268@)&5X="!I<R!A;')E861Y(&QO861E9"P@;W5R('=O<FL@:7,@9&]N
M92X@*B\*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S*"1E>'0I
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4V5E(&EF('=E(&-A;B!C86QL(&1L*"D@870@86QL+"!B>2!T:&4@
M8W5R<F5N="!I;FD@<V5T=&EN9W,N("HO"B`@("`@("`@:68@*"AI;FE?9V5T
M*"=E;F%B;&5?9&PG*2`A/2`Q*2!\?"`H:6YI7V=E="@G<V%F95]M;V1E)RD@
M/3T@,2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2![
M"B`@("`@("`@("`@("1S=69F:7@@/2`G9&QL)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!S=VET8V@@*%!(4%]/4RD@>PH@("`@("`@("`@("!C
M87-E("=(4"U56"<Z"B`@("`@("`@("`@("`@("`D<W5F9FEX(#T@)W-L)SL*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G04E8
M)SH*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G82<["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T]36"<Z"B`@("`@("`@
M("`@("`@("`D<W5F9FEX(#T@)V)U;F1L92<["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D
M<W5F9FEX(#T@)W-O)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N($!D;"@D97AT("X@)RXG("X@)'-U9F9I>"D@?'P@0&1L*"=P
M:'!?)R`N("1E>'0@+B`G+B<@+B`D<W5F9FEX*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-H96-K<R!I9B!A;&P@;F5C97-S87)Y('!A<F%M971E<G,@9F]R
M(&$@9')I=F5R)W,@8V]N9FEG=7)A=&EO;B!A<F4@<V5T"B`@("`@*B!A;F0@
M<F5T=7)N<R!A(%!%05)?17)R;W(@:68@<V]M971H:6YG(&ES(&UI<W-I;F<N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!4:&4@8V]N
M9FEG=7)A=&EO;B!A<G)A>2!W:71H(&%L;"!P87)A;65T97)S+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1F:65L9',@("!!;B!A<G)A>2!W:71H(&UA;F1A=&]R
M>2!P87)A;65T97(@;F%M97,@9F]R('1H:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@9')I=F5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@("!4:&4@8VQE87(@=&5X="!N86UE(&]F('1H92!D<FEV97(N($EF(&YO
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I960L('1H
M92!A<'!L:6-A=&EO;B!N86UE('=I;&P@8F4@=7-E9"X*("`@("`J($!P87)A
M;2!A<G)A>2`D:6YF;R`@("`@02!H87-H(&-O;G1A:6YI;F<@9&5T86EL960@
M:6YF;W)M871I;VX@86)O=70@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&1R:79E<BX@5VEL;"!B92!P87-S960@87,@=&AE('5S97));F9O
M('1O('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!014%27T5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1$<FEV97)#;VYF:6<H
M)'!A<F%M<RP@)&9I96QD<RP@)&YA;64L("1I;F9O(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D:6YF;R`](&%R<F%Y7VUE<F=E*"1I;F9O+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A<F%M<R<@/3X@)'!A<F%M
M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:65L9',G
M(#T^("1F:65L9',L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F%M92<@/3X@)&YA;64I*3L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D
M<&%R86US*2!\?"`A8V]U;G0H)'!A<F%M<RDI('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIT:')O=T5R<F]R*'-P<FEN=&8H7R@B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(I+"`D;F%M92DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($A/4D1%7T524D]27T12259%
M4E]#3TY&24=?34E34TE.1RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F\I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)&9I96QD<R!A<R`D9FEE;&0I('L*("`@("`@("`@("`@:68@*"%I<W-E="@D
M<&%R86US6R1F:65L9%TI*2!["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIT
M:')O=T5R<F]R*'-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BXB*2P@)&9I96QD+"`D;F%M92DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(3U)$15]%
M4E)/4E]$4DE615)?0T].1DE'+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F\I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&9O<FUA="!S=')I
M;F<@=&\@8F4@=7-E9"!B>2!S=')F=&EM92@I+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9O<FUA="`@02!F;W)M870@<W1R:6YG(&%S('5S960@
M8GD@9&%T92@I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&9O
M<FUA="!S=')I;F<@87,@<VEM:6QA<B!A<R!P;W-S:6)L92!T;R`D9F]R;6%T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D871E,G-T<F9T:6UE*"1F;W)M870I
M"B`@("!["B`@("`@("`@)&1A=&53>6UB;VQS(#T@87)R87DH)V$G+"`G02<L
M("=D)RP@)T0G+"`G1B<L("=G)RP@)T<G+"`G:"<L("=()RP@)VDG+"`G:B<L
M("=L)RP@)VTG+"`G32<L("=N)RP@)W(G+"`G<R<L("=4)RP@)W<G+"`G5R<L
M("=Y)RP@)UDG+"`G>B<L("=M+V0O62<L("=-)RP@(EQN(BP@)V<Z:2!A)RP@
M)T<Z:2<L(")<="(L("=(.FDZ<R<L("<E)RD["B`@("`@("`@)'-T<F9T:6UE
M4WEM8F]L<R`](&%R<F%Y*"<E<"<L("<E<"<L("<E9"<L("<E82<L("<E0B<L
M("<E22<L("<E2"<L("<E22<L("<E2"<L("<E32<L("<E92<L("<E02<L("<E
M;2<L("<E8B<L("<E;2<L("<E82P@)64@)6(@)5D@)50@)5HG+"`G)5,G+"`G
M)5HG+"`G)7<G+"`G)58G+"`G)7DG+"`G)5DG+"`G)6HG+"`G)40G+"`G)6@G
M+"`G)6XG+"`G)7(G+"`G)5(G+"`G)70G+"`G)50G+"`G)24G*3L*"B`@("`@
M("`@)')E<W5L="`]("<G.PH@("`@("`@(&9O<B`H)'!O<R`](#`[("1P;W,@
M/"!S=')L96XH)&9O<FUA="D[*2!["B`@("`@("`@("`@(&9O<B`H)'-Y;6)O
M;"`](#`[("1S>6UB;VP@/"!C;W5N="@D9&%T95-Y;6)O;',I.R`D<WEM8F]L
M*RLI('L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&9O<FUA="P@)&1A
M=&53>6UB;VQS6R1S>6UB;VQ=+"`D<&]S*2`]/3T@)'!O<RD@>PH@("`@("`@
M("`@("`@("`@("`@("1R97-U;'0@+CT@)'-T<F9T:6UE4WEM8F]L<ULD<WEM
M8F]L73L*("`@("`@("`@("`@("`@("`@("`D<&]S("L]('-T<FQE;B@D9&%T
M95-Y;6)O;'-;)'-Y;6)O;%TI.PH@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E(#(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)')E<W5L="`N/2!S=6)S='(H)&9O<FUA="P@)'!O<RP@,2D["B`@
M("`@("`@("`@("1P;W,K*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&9O<FUA
M="!S=')I;F<@=&\@8F4@=7-E9"!B>2!D871E*"DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F]R;6%T("!!(&9O<FUA="!S=')I;F<@87,@=7-E
M9"!B>2!S=')F=&EM92@I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!!(&9O<FUA="!S=')I;F<@87,@<VEM:6QA<B!A<R!P;W-S:6)L92!T;R`D
M9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')F=&EM93)D871E*"1F
M;W)M870I"B`@("!["B`@("`@("`@)&1A=&53>6UB;VQS(#T@87)R87DH)V$G
M+"`G02<L("=D)RP@)T0G+"`G1B<L("=G)RP@)T<G+"`G:"<L("=()RP@)VDG
M+"`G:B<L("=L)RP@)VTG+"`G32<L("=N)RP@)W(G+"`G<R<L("=4)RP@)W<G
M+"`G5R<L("=Y)RP@)UDG+"`G>B<L("=M+V0O62<L("=-)RP@(EQN(BP@)V<Z
M:2!A)RP@)T<Z:2<L(")<="(L("=(.FDZ<R<L("<E)RD["B`@("`@("`@)'-T
M<F9T:6UE4WEM8F]L<R`](&%R<F%Y*"<E<"<L("<E<"<L("<E9"<L("<E82<L
M("<E0B<L("<E22<L("<E2"<L("<E22<L("<E2"<L("<E32<L("<E92<L("<E
M02<L("<E;2<L("<E8B<L("<E;2<L("<E82P@)64@)6(@)5D@)50@)5HG+"`G
M)5,G+"`G)5HG+"`G)7<G+"`G)58G+"`G)7DG+"`G)5DG+"`G)6HG+"`G)40G
M+"`G)6@G+"`G)6XG+"`G)7(G+"`G)5(G+"`G)70G+"`G)50G+"`G)24G*3L*
M"B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"1S=')F=&EM95-Y;6)O;',L
M("1D871E4WEM8F]L<RP@)&9O<FUA="D["B`@("!]"@I]"@II9B`H(69U;F-T
M:6]N7V5X:7-T<R@G7R<I*2!["B`@("!F=6YC=&EO;B!?*"1S=')I;F<I"B`@
M("!["B`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("!]"@H@("`@9G5N8W1I
M;VX@8FEN9'1E>'1D;VUA:6XH*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E>'1D;VUA:6XH*0H@("`@>PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-C:&5D
M=6QE<BYP:'``````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-34R-P`Q,#4Q-30S,3`V,0`P,C`V-34`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R
M9&4N<&AP)SL*<F5Q=6ER95]O;F-E("=61E,N<&AP)SL*"B\J*@H@*B!(;W)D
M95]38VAE9'5L97(*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V-H961U;&5R
M+U-C:&5D=6QE<BYP:'`L=B`Q+C(S+C$P+C@@,C`P-2\Q,B\P,2`Q-3HR-SHR
M,R!C:'5C:R!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]38VAE9'5L97(*
M("HO"F-L87-S($AO<F1E7U-C:&5D=6QE<B!["@H@("`@+RHJ"B`@("`@*B!.
M86UE(&]F('1H92!S;&5E<"!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S;&5E<#L*"B`@("`O*BH*("`@
M("`J($%D:G5S=&UE;G0@9F%C=&]R('1O('-L965P(&EN(&UI8W)O<V5C;VYD
M<RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1?<VQE97!?861J.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@
M("`@*@H@("`@("H@1FEG=7)E<R!O=70@:&]W('=E(&-A;B!B97-T('-L965P
M('=I=&@@;6EC<F]S96-O;F0@<')E8VES:6]N"B`@("`@*B!B87-E9"!O;B!W
M:&%T('!L871F;W)M('=E)W)E(')U;FYI;F<@;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N($AO<F1E7U-C:&5D=6QE<B@I"B`@("!["B`@("`@("`@:68@*'-U
M8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<VQE97`@/2`G<VQE97`G.PH@("`@("`@("`@("`D=&AI<RT^7W-L
M965P7V%D:B`](#$P,#`P,#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]S;&5E<"`]("=U<VQE97`G.PH@("`@("`@("`@("`D=&AI
M<RT^7W-L965P7V%D:B`](#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@36%I;B!L;V]P+V%C=&EO;B!F=6YC=&EO;BX*("`@("`J"B`@("`@
M*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N*"D*("`@('L*
M("`@('T*"B`@("`O*BH*("`@("`J(%!R97-E<G9E('1H92!I;G1E<FYA;"!S
M=&%T92!O9B!T:&4@<V-H961U;&5R(&]B:F5C="!T:&%T('=E(&%R90H@("`@
M("H@<&%S<V5D+"!A;F0@<V%V92!I="!T;R!T:&4@2&]R9&4@5D93(&)A8VME
M;F0N($AO<F1E7U-C:&5D=6QE<@H@("`@("H@;V)J96-T<R!S:&]U;&0@9&5F
M:6YE(%]?<VQE97`H*2!A;F0@7U]W86ME=7`H*2!S97)I86QI>F%T:6]N"B`@
M("`@*B!C86QL8F%C:W,@9F]R(&%N>71H:6YG('1H870@;F5E9',@=&\@8F4@
M9&]N92!A="!O8FIE8W0*("`@("`J('-E<FEA;&EZ871I;VX@;W(@9&5S97)I
M86QI>F%T:6]N("T@:&%N9&QI;F<@9&%T86)A<V4*("`@("`J(&-O;FYE8W1I
M;VYS+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ED("!!
M;B!I9"!T;R!U;FEQ=65L>2!I9&5N=&EF>2!T:&ES('-C:&5D=6QE<B!F<F]M
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&]T:&5R<R!O9B!T:&4@<V%M
M92!C;&%S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"1I9"`]
M("<G*0H@("`@>PH@("`@("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)$=,
M3T)!3%-;)V-O;F8G75LG=F9S)UU;)W1Y<&4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W9F<R<L
M("1'3$]"04Q36R=C;VYF)UU;)W9F<R==6R=T>7!E)UTI*3L*("`@("`@("!I
M9B`H:7-?82@D=F9S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"1V9G,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)')E<W5L="`]("1V9G,M/G=R:71E1&%T82@G+FAO<F1E
M+W-C:&5D=6QE<B<L(%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1T:&ES*2D@
M+B`D:60L('-E<FEA;&EZ92@D=&AI<RDL('1R=64I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E<W1O<F4@82!(;W)D95]38VAE9'5L97(@;V)J96-T(&9R;VT@=&AE
M(&-A8VAE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1C;&%S<R`@
M("`@5&AE(&YA;64@;V8@=&AE($AO<F1E7U-C:&5D=6QE<B!O8FIE8W0@=&\@
M<F5S=&]R92X*("`@("`J($!P87)A;2!S=')I;F<@("1I9"`@("`@("`@06X@
M:60@=&\@=6YI<75E;'D@:61E;G1I9GD@=&AI<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S8VAE9'5L97(@9G)O;2!O=&AE<G,@;V8@=&AE
M('-A;64@8VQA<W,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;W-A=F4@
M($%U=&]M871I8V%L;'D@<W1O<F4@*'-E<FEA;&EZ92D@=&AE(')E='5R;F5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="!A="!S
M8W)I<'0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'-E92!(;W)D95]38VAE
M9'5L97(Z.G-E<FEA;&EZ92@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9U;G-E
M<FEA;&EZ92@D8VQA<W,L("1I9"`]("<G+"`D875T;W-A=F4@/2!T<G5E*0H@
M("`@>PH@("`@("`@("\O($YE960@82!L;W=E<F-A<V4@=F5R<VEO;B!O9B!T
M:&4@8VQA<W-N86UE+"!A;F0@82!D969A=6QT"B`@("`@("`@+R\@:6YS=&%N
M8V4@;V8@=&AE('-C:&5D=6QE<B!O8FIE8W0@:6X@8V%S92!W92!C86XG="!R
M971R:65V90H@("`@("`@("\O(&]N92X*("`@("`@("`D8VQA<W,@/2!S=')T
M;VQO=V5R*"1C;&%S<RD["B`@("`@("`@)'-C:&5D=6QE<B`]("9N97<@)&-L
M87-S.PH*("`@("`@("`D=F9S(#T@)E9&4SHZ<VEN9VQE=&]N*"1'3$]"04Q3
M6R=C;VYF)UU;)W9F<R==6R=T>7!E)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=V9G,G+"`D1TQ/
M0D%,4ULG8V]N9B==6R=V9G,G75LG='EP92==*2D["B`@("`@("`@:68@*&ES
M7V$H)'9F<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@D=F9S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@/2`D
M=F9S+3YR96%D*"<N:&]R9&4O<V-H961U;&5R)RP@)&-L87-S("X@)&ED*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1D871A+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'-C:&5D=6QE<B`]($!U;G-E<FEA
M;&EZ92@D9&%T82D["B`@("`@("`@("`@("`@("!I9B`H(21S8VAE9'5L97(I
M('L*("`@("`@("`@("`@("`@("`@("`D<V-H961U;&5R(#T@)FYE=R`D8VQA
M<W,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@D875T;W-A=F4I('L*("`@("`@("`@("`@<F5G:7-T
M97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1S8VAE9'5L97(L("=S97)I
M86QI>F4G*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-C:&5D=6QE
M<CL*("`@('T*"B`@("`O*BH*("`@("`J(%!L871F;W)M+6EN9&5P96YD86YT
M('-L965P("1M<V5C(&UI8W)O<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;7-E8R`@36EC<F]S96-O;F1S('1O('-L965P+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S;&5E<"@D;7-E8RD*("`@('L*("`@("`@("!C
M86QL7W5S97)?9G5N8R@D=&AI<RT^7W-L965P+"`D;7-E8R`O("1T:&ES+3Y?
M<VQE97!?861J*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E='5R;B!A(&-O;F-R971E($AO<F1E7U-C:&5D=6QE<B!I;G-T86YC92!B
M87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]38VAE9'5L97(@
M<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L
M:6(O2&]R9&5?4V-H961U;&5R+R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)&1R
M:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!(;W)D95]38VAE9'5L97(@(%1H92!N97=L>2!C<F5A=&5D(&-O
M;F-R971E($AO<F1E7U-C:&5D=6QE<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EN<W1A;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2![
M"B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D
M9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV
M97(@/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D
M<FEV97(I('Q\("AS=')C;7`H)&1R:79E<BP@)VYO;F4G*2`]/2`P*2D@>PH@
M("`@("`@("`@("`D<V-H961U;&5R(#T@)FYE=R!(;W)D95]38VAE9'5L97(H
M*3L*("`@("`@("`@("`@<F5T=7)N("1S8VAE9'5L97(["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(&EN8VQU
M9&5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L
M("1A<'`I("X@)R]L:6(O4V-H961U;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G
M.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+U-C:&5D=6QE<B\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*
M("`@("`@("`@("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]38VAE9'5L97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@57-E(&EN8VQU9&5?;VYC92!H97)E('1O
M(&%V;VED(&$@9F%T86P@97)R;W(@:68@=&AE"B`@("`@("`@("`@("\O(&-L
M87-S(&ES;B=T(&9O=6YD+@H@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(
M;W)D92]38VAE9'5L97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M?0H@("`@("`@("1C;&%S<R`]("=(;W)D95]38VAE9'5L97)?)R`N("1D<FEV
M97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@
M("`@("`@("1S8VAE9'5L97(@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<V-H961U;&5R(#T@4$5!4CHZ
M<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@
M)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-C
M:&5D=6QE<CL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7U-C:&5D=6QE
M<@H@("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@270@=VEL;"!O
M;FQY(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@;F\@2&]R9&5?
M4V-H961U;&5R(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<PH@
M("`@("H@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H
M;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE('-C:&5D=6QE<G,@*&%N9"P@=&AU
M<RP@;75L=&EP;&4*("`@("`J($AO<F1E7U-C:&5D=6QE<B!I;G-T86YC97,I
M(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T
M(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R9&5?4V-H961U;&5R.CIS:6YG
M;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R('-U8F-L87-S
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI;F<@
M86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C
M;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M4V-H961U;&5R("!4:&4@8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R(')E9F5R
M96YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS
M92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O
M;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T
M:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@
M/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@
M(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]38VAE9'5L
M97(Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T5D:71O<BYP:'``````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S<Q-0`Q,#4Q-30S,3`V
M,0`P,C`Q-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($5D:71O<B!#;&%S<PH@*@H@*B!4:&4@161I
M=&]R.CH@<&%C:V%G92!P<F]V:61E<R!A;B!R=&4@961I=&]R(&9O<B!T:&4@
M2&]R9&4*("H@07!P;&EC871I;VX@1G)A;65W;W)K+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]%9&ET;W(O161I=&]R+G!H<"QV(#$N."XQ,"XX(#(P,#8O
M,#$O,#$@,C$Z,C@Z,30@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@3G5N;R!,;W5R96ER;R`\;G5N;T!C;RYS87!O+G!T/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@3G5N;R!,;W5R96ER;R`\;G5N;T!C;RYS
M87!O+G!T/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?161I=&]R"B`J+PIC;&%S<R!(;W)D95]%9&ET;W(@>PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7T5D:71O<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E
M7T5D:71O<B!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!(;W)D95]%9&ET;W(@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H
M96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M:6X@)&1R:79E<ELP72]L:6(O1')I=F5R+R!F;W(@=&AE('-U8F-L87-S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6UP;&5M96YT871I;VX@;F%M
M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A
M=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!(;W)D95]%9&ET;W(@(%1H92!N97=L>2!C<F5A=&5D
M(&-O;F-R971E($AO<F1E7T5D:71O<B!I;G-T86YC92P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!O<B!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@
M("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D9')I=F5R
M(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B
M87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I9B`H96UP='DH)&1R:79E<BD@
M?'P@)&1R:79E<B`]/2`G;F]N92<I('L*("`@("`@("`@("`@)&5D:71O<B`]
M("9N97<@2&]R9&5?161I=&]R*"1P87)A;7,I.PH@("`@("`@("`@("!R971U
M<FX@)&5D:71O<CL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N=6QL*"1P
M87)A;7,I("8F(&-L87-S7V5X:7-T<R@G2&]R9&4G*2D@>PH@("`@("`@("`@
M("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G961I=&]R)RP@
M)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I
M*2!["B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P
M*2`N("<O;&EB+T5D:71O<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]%9&ET;W(O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O161I=&]R+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T5D:71O<B\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]%
M9&ET;W)?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D
M8VQA<W,I*2!["B`@("`@("`@("`@("1E9&ET;W(@/2`F;F5W("1C;&%S<R@D
M<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D961I=&]R
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@
M)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&5D:71O<CL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7T5D
M:71O<@H@("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@270@=VEL
M;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@;F\@2&]R
M9&5?161I=&]R(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C
M=7)R96YT;'D*("`@("`J(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H
M;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(&-A8VAE(&)A8VME;F1S("AA;F0L
M('1H=7,L"B`@("`@*B!M=6QT:7!L92!(;W)D95]%9&ET;W(@:6YS=&%N8V5S
M*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S
M="!B92!I;G9O:V5D(&%S.@H@("`@("H@)'9A<B`]("9(;W)D95]%9&ET;W(Z
M.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T5D:71O<B!S=6)C;&%S
M<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@
M)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]%9&ET
M;W(O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA
M<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,BXR
M"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]%9&ET;W(@(%1H92!C;VYC
M<F5T92!(;W)D95]%9&ET;W(@<F5F97)E;F-E+"!O<B!F86QS92!O;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@
M/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU;&PH)'!A
M<F%M<RD@)B8@8VQA<W-?97AI<W1S*"=(;W)D92<I*2!["B`@("`@("`@("`@
M("1P87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=C86-H92<L("1D
M<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%A
M<G)A>5]K97E?97AI<W1S*"1S:6=N871U<F4L("1I;G-T86YC97,I*2!["B`@
M("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R9&5?161I
M=&]R.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUE
M;G4N<&AP````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R-#8V,0`Q,#4Q-30S,3`V,0`P,3<V-#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"F1E9FEN92@G2$]21$5?
M345.55]03U-?3$%35"<L(#DY.2D["@ID969I;F4H)TA/4D1%7TU%3E5?34%3
M2U].3TY%)RP@("`@(#`I.PID969I;F4H)TA/4D1%7TU%3E5?34%32U](14Q0
M)RP@("`@(#$I.PID969I;F4H)TA/4D1%7TU%3E5?34%32U],3T=)3B<L("`@
M(#(I.PID969I;F4H)TA/4D1%7TU%3E5?34%32U]04D5&4R<L("`@(#0I.PID
M969I;F4H)TA/4D1%7TU%3E5?34%32U]04D]"3$5-)RP@(#@I.PID969I;F4H
M)TA/4D1%7TU%3E5?34%32U]!3$PG+"`@("`@,34I.PH*+RHJ"B`J(%1H92!-
M96YU.CH@8VQA<W,@<')O=FED97,@<W1A;F1A<F1I>F5D(&UE=&AO9',@9F]R
M(&-R96%T:6YG(&UE;G5S(&EN"B`J($AO<F1E(&%P<&QI8V%T:6]N<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`L=B`Q
M+C,U+C(N,3$@,C`P-B\P-R\R,"`P-#HS,3HR-R!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES
M92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?1G)A;65W;W)K"B`J+PIC;&%S<R!-
M96YU('L*"B`@("`O*BH*("`@("`J($UE;G4@87)R87DN"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M96YU(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($UA<VL@9&5F:6YI;F<@=VAA="!G96YE<F%L
M($AO<F1E(&QI;FMS(&%R92!S:&]W;B!I;B!T:&ES($UE;G4N"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VUA<VL["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO
M;B!-96YU*"1M87-K(#T@2$]21$5?345.55]-05-+7T%,3"D*("`@('L*("`@
M("`@("`O*B!-96YU:71E;2!M87-K+B`J+PH@("`@("`@("1T:&ES+3Y?;6%S
M:R`]("1M87-K.PH*("`@("`@("`O*B!,;V-A=&EO;B!O9B!T:&4@;65N=69I
M;&4N("HO"B`@("`@("`@)'1H:7,M/E]M96YU9FEL92`]("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RD@+B`G+V-O;F9I9R]M96YU+G!H
M<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@:71E;2!T;R!T:&4@
M;65N=2!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@
M("`@("`@(%-T<FEN9R!C;VYT86EN:6YG('1H92!V86QU92!F;W(@=&AE(&AY
M<&5R;&EN:RX*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@4W1R
M:6YG(&-O;G1A:6YI;F<@=&AE(&QA8F5L(&9O<B!T:&ES(&UE;G4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:71E;2X*("`@("`J($!P87)A
M;2!S=')I;F<@)&EC;VX@("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9I
M;&5N86UE(&]F('1H92!I;6%G90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I8V]N('1O(&1I<W!L87D@9F]R('1H:7,@;65N=2!I=&5M+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:6-O;E]P871H("!)9B!T:&4@:6-O;B!L
M:79E<R!I;B!A(&YO;BUD969A=6QT(&1I<F5C=&]R>2P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=VAE<F4@:7,@:70_"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T87)G970@("`@($EF('1H92!L:6YK(&YE961S('1O(&]P
M96X@:6X@86YO=&AE<B!F<F%M92!O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!W:6YD;W<L('=H870@:7,@:71S(&YA;64_"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1O;F-L:6-K("`@($]N8VQI8VL@:F%V87-C<FEP="P@
M:68@9&5S:7)E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-L87-S("`@("`@
M0U-3(&-L87-S(&9O<B!T:&4@;65N=2!I=&5M+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE(&ED("A.3U0@9W5A<F%N=&5E9"!T;R!B92!A
M;B!A<G)A>2!I;F1E>"D@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&ET96T@:G5S="!A9&1E9"!T;R!T:&4@;65N=2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D*"1U<FPL("1T97AT+"`D:6-O;B`]("<G+"`D:6-O;E]P871H
M(#T@;G5L;"P*("`@("`@("`@("`@("`@("`D=&%R9V5T(#T@)R<L("1O;F-L
M:6-K(#T@;G5L;"P@)&-L87-S(#T@;G5L;"D*("`@('L*("`@("`@("`D<&]S
M(#T@8V]U;G0H)'1H:7,M/E]M96YU*3L*("`@("`@("!I9B`H(21P;W,@?'P@
M*"1P;W,@+2`Q("$](&UA>"AA<G)A>5]K97ES*"1T:&ES+3Y?;65N=2DI*2D@
M>PH@("`@("`@("`@("`D<&]S(#T@8V]U;G0H)'1H:7,M/E]M96YU*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?;65N=5LD<&]S72`]"B`@("`@("`@
M("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W5R;"<@/3X@)'5R;"P*("`@
M("`@("`@("`@("`@("=T97AT)R`]/B`D=&5X="P*("`@("`@("`@("`@("`@
M("=I8V]N)R`]/B`D:6-O;BP*("`@("`@("`@("`@("`@("=I8V]N7W!A=&@G
M(#T^("1I8V]N7W!A=&@L"B`@("`@("`@("`@("`@("`G=&%R9V5T)R`]/B`D
M=&%R9V5T+`H@("`@("`@("`@("`@("`@)V]N8VQI8VLG(#T^("1O;F-L:6-K
M+`H@("`@("`@("`@("`@("`@)V-L87-S)R`]/B`D8VQA<W,*("`@("`@("`@
M("`@*3L*"B`@("`@("`@<F5T=7)N("1P;W,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&0@86X@:71E;2!T;R!T:&4@;65N=2!A<G)A>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@(%-T<FEN9R!C;VYT86EN
M:6YG('1H92!V86QU92!F;W(@=&AE(&AY<&5R;&EN:RX*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&QA
M8F5L(&9O<B!T:&ES(&UE;G4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&EC;VX@("`@("`@
M4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9I;&5N86UE(&]F('1H92!I;6%G90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!I8V]N('1O(&1I<W!L
M87D@9F]R('1H:7,@;65N=2!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:6-O;E]P871H("!)9B!T:&4@:6-O;B!L:79E<R!I;B!A(&YO;BUD969A=6QT
M(&1I<F5C=&]R>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=VAE<F4@:7,@:70_"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87)G970@("`@
M($EF('1H92!L:6YK(&YE961S('1O(&]P96X@:6X@86YO=&AE<B!F<F%M92!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!W:6YD;W<L('=H
M870@:7,@:71S(&YA;64_"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;F-L:6-K
M("`@($]N8VQI8VL@:F%V87-C<FEP="P@:68@9&5S:7)E9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-L87-S("`@("`@0U-3(&-L87-S(&9O<B!T:&4@;65N
M=2!I=&5M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&ED
M("A.3U0@9W5A<F%N=&5E9"!T;R!B92!A;B!A<G)A>2!I;F1E>"D@;V8@=&AE
M(&ET96T*("`@("`J("`@("`@("`@("`@("`@("`@:G5S="!A9&1E9"!T;R!T
M:&4@;65N=2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D07)R87DH)&ET96TI
M"B`@("!["B`@("`@("`@)'!O<R`](&-O=6YT*"1T:&ES+3Y?;65N=2D["B`@
M("`@("`@:68@*"$D<&]S('Q\("@D<&]S("T@,2`A/2!M87@H87)R87E?:V5Y
M<R@D=&AI<RT^7VUE;G4I*2DI('L*("`@("`@("`@("`@)'!O<R`](&-O=6YT
M*"1T:&ES+3Y?;65N=2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VUE
M;G5;)'!O<UT@/2`D:71E;3L*"B`@("`@("`@<F5T=7)N("1P;W,["B`@("!]
M"@H@("`@9G5N8W1I;VX@<V5T4&]S:71I;VXH)&ED+"`D<&]S*0H@("`@>PH@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]M96YU6R1I9%TI('Q\(&ES<V5T
M*"1T:&ES+3Y?;65N=5LD<&]S72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)&ET96T@/2`D=&AI<RT^7VUE;G5;
M)&ED73L*("`@("`@("!U;G-E="@D=&AI<RT^7VUE;G5;)&ED72D["B`@("`@
M("`@)'1H:7,M/E]M96YU6R1P;W-=(#T@)&ET96T["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!U;F]R
M9&5R960@;&ES="!R97!R97-E;G1I;F<@=&AE(&QI<W0@;V8@;65N=2!I=&5M
M<RX@4W1Y;&EN9PH@("`@("H@:7,@9&]N92!T:')O=6=H($-34RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@06X@=6YO<F1E<F5D(&QI<W0@;V8@
M;65N=2!E;&5M96YT<R!T:&%T(&-A;B!B92!E;G1I<F5L>0H@("`@("H@("`@
M("`@("`@("`@("`@('-T>6QE9"!W:71H($-34RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N9&5R*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8L("1R
M96=I<W1R>2P@)'!R969S.PH*("`@("`@("`D9W)A<&AI8W,@/2`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I.PH@("`@("`@("1A<'`@/2`D<F5G
M:7-T<GDM/F=E=$%P<"@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]M87-K("$]
M/2!(3U)$15]-14Y57TU!4TM?3D].12D@>PH@("`@("`@("`@("`O*B!!9&0@
M86YY(&-U<W1O;2!M96YU(&ET96US+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M861D4VET94QI;FMS*"D["@H@("`@("`@("`@("`O*B!!9&0@86YY(&%P<"!M
M96YU(&ET96US+B`J+PH@("`@("`@("`@("`D=&AI<RT^861D07!P3&EN:W,H
M*3L*("`@("`@("!]"@H@("`@("`@("\J($%D9"!S971T:6YG<R!L:6YK+B`J
M+PH@("`@("`@(&EF("@D=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?
M4%)%1E,@)B8@)'5R;"`]($AO<F1E.CIG971397)V:6-E3&EN:R@G;W!T:6]N
M<R<L("1A<'`I*2!["B`@("`@("`@("`@("1T:&ES+3YA9&0H)'5R;"P@7R@B
M7T]P=&EO;G,B*2P@)W!R969S+G!N9R<L("1G<F%P:&EC<RD["B`@("`@("`@
M?0H*("`@("`@("`O*B!!9&0@<')O8FQE;2!L:6YK+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?4%)/0DQ%32`F)B`D
M<')O8FQE;5]L:6YK(#T@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=P<F]B;&5M
M)RP@)&%P<"DI('L*("`@("`@("`@("`@)'1H:7,M/F%D9"@D<')O8FQE;5]L
M:6YK+"!?*")0<F]B;&5M(BDL("=P<F]B;&5M+G!N9R<L("1G<F%P:&EC<RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!!9&0@:&5L<"!L:6YK+B`J+PH@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O2&5L<"YP:'`G.PH@("`@("`@(&EF
M("@D=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?2$5,4"`F)B`D:&5L
M<%]L:6YK(#T@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=H96QP)RP@)&%P<"DI
M('L*("`@("`@("`@("`@)'1H:7,M/F%D9"@D:&5L<%]L:6YK+"!?*")(96QP
M(BDL("=H96QP7VEN9&5X+G!N9R<L("1G<F%P:&EC<RP@)VAE;'`G+"`G<&]P
M=7`H=&AI<RYH<F5F*3L@<F5T=7)N(&9A;'-E.R<I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3&]G:6XO3&]G;W5T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?3$]'24XI('L*("`@("`@("`@("`@
M+RH@268@=&AE('-I9&5B87(@:7-N)W0@86QW87ES('-H;W=N+"!B=70@:7,@
M<V]M971I;65S"B`@("`@("`@("`@("`J('-H;W=N+"!T:&5N(&QO9V]U="!L
M:6YK<R!S:&]U;&0@8F4@=&\@=&AE('!A<F5N=`H@("`@("`@("`@("`@*B!F
M<F%M92X@*B\*("`@("`@("`@("`@)&%U=&A?=&%R9V5T(#T@;G5L;#L*("`@
M("`@("`@("`@:68@*"1C;VYF6R=M96YU)UU;)V%L=V%Y<R==('Q\("1P<F5F
M<RT^9V5T5F%L=64H)W-H;W=?<VED96)A<B<I*2!["B`@("`@("`@("`@("`@
M("`D875T:%]T87)G970@/2`G7W!A<F5N="<["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("A!=71H.CIG971!=71H*"DI('L*("`@("`@("`@("`@
M("`@(&EF("@D;&]G;W5T7VQI;FL@/2!(;W)D93HZ9V5T4V5R=FEC94QI;FLH
M)VQO9V]U="<L("1A<'`L("$D<')E9G,M/F=E=%9A;'5E*"=S:&]W7W-I9&5B
M87(G*2DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1L;V=O
M=71?;&EN:RP@7R@B7TQO9R!O=70B*2P@)VQO9V]U="YP;F<G+"`D9W)A<&AI
M8W,L("1A=71H7W1A<F=E="P@;G5L;"P@)U]?;F]S96QE8W1I;VXG*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&EF("@D;&]G:6Y?;&EN:R`]($AO<F1E.CIG971397)V:6-E3&EN
M:R@G;&]G:6XG+"`D87!P*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YA9&0H)&QO9VEN7VQI;FLL(%\H(E],;V<@:6XB*2P@)VQO9VEN+G!N9R<L
M("1G<F%P:&EC<RP@)&%U=&A?=&%R9V5T+"!N=6QL+"`G7U]N;W-E;&5C=&EO
M;B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!.;R!N965D('1O(')E='5R;B!A;B!E;7!T>2!L:7-T
M(&EF('1H97)E(&%R92!N;R!M96YU"B`@("`@("`@("H@:71E;7,N("HO"B`@
M("`@("`@:68@*"%C;W5N="@D=&AI<RT^7VUE;G4I*2!["B`@("`@("`@("`@
M(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\J(%-O<G0@=&\@;6%T
M8V@@97AP;&EC:71L>2!S970@<&]S:71I;VYS+B`J+PH@("`@("`@(&MS;W)T
M*"1T:&ES+3Y?;65N=2D["B`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG
M;FQS)UU;)W)T;"==6R1'3$]"04Q36R=L86YG=6%G92==72DI("!["B`@("`@
M("`@("`@("1T:&ES+3Y?;65N=2`](&%R<F%Y7W)E=F5R<V4H)'1H:7,M/E]M
M96YU*2`["B`@("`@("`@?0H*("`@("`@("`D;65N=5]V:65W(#T@)'!R969S
M+3YG971686QU92@G;65N=5]V:65W)RD["B`@("`@("`@)&]U='!U="`]("<\
M=6P^)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VUE;G4@87,@)&TI('L*
M("`@("`@("`@("`@+RH@271E;2!C;&%S<R!A;F0@<V5L96-T960@:6YD:6-A
M=&EO;BX@*B\*("`@("`@("`@("`@:68@*"%I<W-E="@D;5LG8VQA<W,G72DI
M('L*("`@("`@("`@("`@("`@("\J(%1R>2!T;R!M871C:"!T:&4@:71E;2=S
M('!A=&@@86=A:6YS="!T:&4@8W5R<F5N=`H@("`@("`@("`@("`@("`@("H@
M<V-R:7!T(&9I;&5N86UE(&%S('=E;&P@87,@;W1H97(@<&]S<VEB;&4@55),
M<R!T;PH@("`@("`@("`@("`@("`@("H@=&AI<R!S8W)I<'0N("HO"B`@("`@
M("`@("`@("`@("!I9B`H365N=3HZ:7-396QE8W1E9"@D;5LG=7)L)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&U;)V-L87-S)UT@/2`G8W5R<F5N="<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D;5LG
M8VQA<W,G72`]/3T@)U]?;F]S96QE8W1I;VXG*2!["B`@("`@("`@("`@("`@
M("!U;G-E="@D;5LG8VQA<W,G72D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($EC;VXN("HO"B`@("`@("`@("`@("1I8V]N(#T@)R<["B`@("`@
M("`@("`@(&EF("@D;65N=5]V:65W(#T]("=I8V]N)R!\?"`D;65N=5]V:65W
M(#T]("=B;W1H)RD@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;5LG
M:6-O;E]P871H)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&U;)VEC;VY?
M<&%T:"==(#T@;G5L;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1I8V]N(#T@2&]R9&4Z.FEM9R@D;5LG:6-O;B==+"!(;W)D93HZ<W1R
M:7!!8V-E<W-+97DH)&U;)W1E>'0G72DL("<G+"`D;5LG:6-O;E]P871H)UTI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!,:6YK+B`J+PH@("`@
M("`@("`@("`D86-C97-S:V5Y(#T@2&]R9&4Z.F=E=$%C8V5S<TME>2@D;5LG
M=&5X="==*3L*("`@("`@("`@("`@)&QI;FL@/2!(;W)D93HZ;&EN:R@D;5LG
M=7)L)UTL("1M96YU7W9I97<@/3T@)VEC;VXG(#\@)&U;)W1E>'0G72`Z("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1M6R=C
M;&%S<R==*2`_("1M6R=C;&%S<R==(#H@)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:7-S970H)&U;)W1A<F=E="==*2`_("1M6R=T87)G
M970G72`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES
M<V5T*"1M6R=O;F-L:6-K)UTI(#\@)&U;)V]N8VQI8VLG72`Z("<G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+"`D86-C97-S:V5Y*3L*
M"B`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B7&X\;&D^)7,E<SQB
M<B`O/B5S/"]A/CPO;&D^(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1L:6YK+"`D:6-O;BP@*"1M96YU7W9I97<@(3T@)VEC;VXG*2`_($AO
M<F1E.CIH:6=H;&EG:'1!8V-E<W-+97DH)&U;)W1E>'0G72P@)&%C8V5S<VME
M>2D@.B`G)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U="`N
M("<\+W5L/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!;GD@;&EN:W,@=&\@
M;W1H97(@2&]R9&4@87!P;&EC871I;VYS(&1E9FEN960@:6X@86X@87!P;&EC
M871I;VXG<R!C;VYF:6<*("`@("`J(&9I;&4@8GD@=&AE("1C;VYF6R=M96YU
M)UU;)V%P<',G72!A<G)A>2!A<F4@861D960@=&\@=&AE(&UE;G4@87)R87DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$%P<$QI;FMS*"D*("`@('L*("`@
M("`@("!G;&]B86P@)&-O;F8L("1R96=I<W1R>3L*"B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=M96YU)UU;)V%P<',G72D@)B8@:7-?87)R87DH)&-O;F9;
M)VUE;G4G75LG87!P<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D8V]N
M9ELG;65N=2==6R=A<'!S)UT@87,@)&%P<"D@>PH@("`@("`@("`@("`@("`@
M:68@*"1R96=I<W1R>2T^9V5T*"=S=&%T=7,G+"`D87!P*2`A/2`G:6YA8W1I
M=F4G("8F("1R96=I<W1R>2T^:&%S4&5R;6ES<VEO;B@D87!P+"!015)-4U]3
M2$]7*2D@>PH@("`@("`@("`@("`@("`@("`@("1U<FP@/2`D<F5G:7-T<GDM
M/F=E=$EN:71I86Q086=E*"1A<'`I.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-?82@D=7)L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YA9&0H2&]R9&4Z.G5R;"@D=7)L*2P@)')E9VES
M=')Y+3YG970H)VYA;64G+"`D87!P*2P@)')E9VES=')Y+3YG970H)VEC;VXG
M+"`D87!P*2P@)R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9"!A;GD@;W1H97(@;&EN:W,@9F]U;F0@:6X@)'1H:7,M
M/E]M96YU9FEL92!T;R!B92!I;F-L=61E9"!I;B!T:&4*("`@("`J(&UE;G4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%-I=&5,:6YK<R@I"B`@("!["B`@
M("`@("`@:68@*$!I<U]R96%D86)L92@D=&AI<RT^7VUE;G5F:6QE*2D@>PH@
M("`@("`@("`@("!I;F-L=61E("1T:&ES+3Y?;65N=69I;&4["B`@("`@("`@
M("`@(&EF("AI<W-E="@D7VUE;G4I("8F(&ES7V%R<F%Y*"1?;65N=2DI('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1?;65N=2!A<R`D;65N=6ET96TI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D07)R87DH)&UE;G5I
M=&5M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@:68@=&AE
M(&-U<G)E;G0@=7)L(&UA=&-H97,@=&AE(&=I=F5N('5R;"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE(&=I=F5N(%523"!I
M<R!T:&4@8W5R<F5N="!L;V-A=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M:7-396QE8W1E9"@D=7)L*0H@("`@>PH@("`@("`@("1S97)V97)?=7)L(#T@
M<&%R<V5?=7)L*"1?4T525D526R=02%!?4T5,1B==*3L*("`@("`@("`D8VAE
M8VM?=7)L(#T@<&%R<V5?=7)L*"1U<FPI.PH*("`@("`@("`O*B!4<GD@=&\@
M;6%T8V@@=&AE(&ET96TG<R!P871H(&%G86EN<W0@=&AE(&-U<G)E;G0@<V-R
M:7!T"B`@("`@("`@("`@9FEL96YA;64@87,@=V5L;"!A<R!O=&AE<B!P;W-S
M:6)L92!54DQS('1O('1H:7,@<V-R:7!T+B`J+PH@("`@("`@(&EF("AI<W-E
M="@D8VAE8VM?=7)L6R=P871H)UTI("8F"B`@("`@("`@("`@("@H)&-H96-K
M7W5R;%LG<&%T:"==(#T]("1S97)V97)?=7)L6R=P871H)UTI('Q\"B`@("`@
M("`@("`@("`H)&-H96-K7W5R;%LG<&%T:"==("X@)VEN9&5X+G!H<"<@/3T@
M)'-E<G9E<E]U<FQ;)W!A=&@G72D@?'P*("`@("`@("`@("`@("@D8VAE8VM?
M=7)L6R=P871H)UT@+B`G+VEN9&5X+G!H<"<@/3T@)'-E<G9E<E]U<FQ;)W!A
M=&@G72DI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O5')E92YP:'``````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,V-C<S`#$P-3$U-#,Q,#8Q`#`Q-S8T,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J($1I<W!L87D@97AT<F$@8V]L=6UN<R!T;R!T:&4@;&5F="!O9B!T
M:&4@;6%I;B!T<F5E+@H@*B\*9&5F:6YE*"=(3U)$15]44D5%7T585%)!7TQ%
M1E0G+"`P*3L*"B\J*@H@*B!$:7-P;&%Y(&5X=')A(&-O;'5M;G,@=&\@=&AE
M(')I9VAT(&]F('1H92!M86EN('1R964N"B`J+PID969I;F4H)TA/4D1%7U12
M145?15A44D%?4DE'2%0G+"`Q*3L*"B\J*@H@*B!4:&4@<')E8V5D:6YG('1E
M>'0L(&)E9F]R92!T:&4@2&]R9&5?5')E92!I;G-T86YC92!N86UE+"!U<V5D
M(&9O<@H@*B!C;VQL87!S92]E>'!A;F0@<W5B;6ES<VEO;G,N"B`J+PID969I
M;F4H)TA/4D1%7U12145?5$]'1TQ%)RP@)VAT7W1O9V=L95\G*3L*"B\J*@H@
M*B!4:&4@2&]R9&5?5')E93HZ(&-L87-S('!R;W9I9&5S(&$@=')E92!V:65W
M(&]F(&AI97)A<F-H:6-A;"!I;F9O<FUA=&EO;BX@270*("H@86QL;W=S(&9O
M<B!E>'!A;F1I;F<O8V]L;&%P<VEN9R!O9B!B<F%N8VAE<R!A;F0@;6%I;G1A
M:6YS('1H96ER('-T871E+B!)=`H@*B!C86X@=V]R:R!T;V=E=&AE<B!W:71H
M('1H92!(;W)D95]4<F5E(&IA=F%S8W)I<'0@8VQA<W,@=&\@86-H:65V92!T
M:&ES(&EN"B`J($1(5$U,(&]N('-U<'!O<G1E9"!B<F]W<V5R<RX*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N
M8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5')E
M92]4<F5E+G!H<"QV(#$N-#8N-BXQ,2`R,#`V+S`Q+S`Q(#(Q.C(X.C0P(&IA
M;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B!`<&%C:V%G92!(;W)D95]4<F5E"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?5')E92!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;F%M92!O9B!T:&ES(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEN<W1A;F-E(#T@;G5L;#L*
M"B`@("`O*BH*("`@("`J($AA<V@@=VET:"!H96%D97(@:6YF;W)M871I;VXN
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H
M96%D97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06X@87)R87D@8V]N
M=&%I;FEN9R!A;&P@=&AE('1R964@;F]D97,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]N;V1E<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!4:&4@=&]P+6QE=F5L(&YO9&5S(&EN('1H92!T<F5E
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<F]O=%]N;V1E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!+965P(&-O
M=6YT(&]F(&AO=R!M86YY(&5X=')A(&-O;'5M;G,@=&AE<F4@87)E(&]N('1H
M92!L969T('-I9&4*("`@("`J(&]F('1H92!N;V1E+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]E>'1R85]C;VQS7VQE
M9G0@/2`P.PH*("`@("\J*@H@("`@("H@2V5E<"!C;W5N="!O9B!H;W<@;6%N
M>2!E>'1R82!C;VQU;6YS('1H97)E(&%R92!O;B!T:&4@<FEG:'0@<VED90H@
M("`@("H@;V8@=&AE(&YO9&4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7V5X=')A7V-O;'-?<FEG:'0@/2`P.PH*("`@
M("\J*@H@("`@("H@3W!T:6]N('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A>2@G;&EN
M97,G(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@4W1O<F5S('1H92!S;W)T
M:6YG(&-R:71E<FEA('1E;7!O<F%R:6QY+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O<G1#<FET97)I83L*"B`@("`O
M*BH*("`@("`J(%5S92!S97-S:6]N('1O('-T;W)E(&-A8VAE9"!4<F5E(&1A
M=&$_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7W5S97-E<W-I;VX@/2!T<G5E.PH*("`@("\J*@H@("`@("H@4VAO=6QD
M('1H92!T<F5E(&)E(')E;F1E<F5D('-T871I8V%L;'D_"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W-T871I8R`](&9A
M;'-E.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F
M97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?5')E90H@("`@("H@:6YS=&%N
M8V4@8F%S960@;VX@)&YA;64@86YD("1R96YD97)E<BX@270@=VEL;"!O;FQY
M(&-R96%T92!A"B`@("`@*B!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?5')E
M92!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,*("`@("`J(&-U
M<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S
M="!B92!I;G9O:V5D(&%S.@H@("`@("H@("`D=F%R(#T@)DAO<F1E7U1R964Z
M.G-I;F=L971O;B@D;F%M95LL("1R96YD97)E<ETI.PH@("`@("H*("`@("`J
M($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1N86UE("`@
M("`@0'-E92!(;W)D95]4<F5E.CIF86-T;W)Y+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F5N9&5R97(@($!S964@2&]R9&5?5')E93HZ9F%C=&]R>2X*("`@
M("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@("!`<V5E($AO<F1E7U1R964Z
M.F9A8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]4<F5E("!4
M:&4@8V]N8W)E=&4@2&]R9&5?5')E92!R969E<F5N8V4L(&]R(%!%05)?17)R
M;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&YA;64L("1R96YD97)E<BP@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T
M86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D:60@/2`D;F%M92`N("<Z)R`N
M("1R96YD97)E<B`N("<Z)R`N('-E<FEA;&EZ92@D<&%R86US*3L*("`@("`@
M("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)&ED72DI('L*("`@("`@("`@("`@
M)&EN<W1A;F-E<ULD:61=(#T@)DAO<F1E7U1R964Z.F9A8W1O<GDH)&YA;64L
M("1R96YD97)E<BP@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("@A)&EN<W1A
M;F-E<ULD:61=+3YI<U-U<'!O<G1E9"@I*2!["B`@("`@("`@("`@("`@("`D
M<F5N9&5R97(@/2!(;W)D95]4<F5E.CIF86QL8F%C:R@D<F5N9&5R97(I.PH@
M("`@("`@("`@("`@("`@:68@*&ES7V$H)')E;F1E<F5R+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R96YD97)E<CL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!(;W)D
M95]4<F5E.CIS:6YG;&5T;VXH)&YA;64L("1R96YD97)E<BP@)'!A<F%M<RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS
M=&%N8V5S6R1I9%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]4<F5E(&EN<W1A;F-E+@H@("`@
M("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@("`@5&AE(&YA;64@;V8@=&AI<R!T<F5E(&EN<W1A;F-E+@H@
M("`@("H@0'!A<F%M(&UI>&5D("`D<F5N9&5R97(@(%1H92!T>7!E(&]F(&-O
M;F-R971E($AO<F1E7U1R964@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FXN(%1H:7,@:7,@8F%S960@;VX@=&AE
M(')E;F1E<FEN9R!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`H)')E;F1E<F5R*2X@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC
M;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("`@06YY(&%D
M9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@8V]N<W1R=6-T;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!N965D<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N($AO<F1E7U1R964@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E
M($AO<F1E7U1R964@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9F86-T;W)Y*"1N86UE+"`D<F5N9&5R97(L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("\J(%)E<75I<F4@=&AE(')E;F1E<F5R(&QI
M8BX@*B\*("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+U1R964O)R`N("1R96YD97)E<B`N("<N<&AP)SL*"B`@("`@("`@)&-L
M87-S(#T@)TAO<F1E7U1R965?)R`N("1R96YD97)E<CL*("`@("`@("!I9B`H
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'1R964@/2`F
M;F5W("1C;&%S<R@D;F%M92P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1R964@/2!014%2.CIR86ES945R<F]R*'-P<FEN=&8H
M7R@B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(I+"`D<F5N9&5R
M97(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=')E93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1R>2!T;R!F86QL(&)A8VL@=&\@82!S:6UP;&5R
M(')E;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;B!S=')I;F<@)')E;F1E
M<F5R("!4:&4@<F5N9&5R97(@=&AA="!W92!C86XG="!H86YD;&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@?"!014%27T5R<F]R("!4:&4@;F5X
M="!B97-T(')E;F1E<F5R+"!O<B!A;B!E<G)O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B!W92=V92!R=6X@;W5T(&]F(')E;F1E
M<F5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9F%L;&)A8VLH)')E;F1E<F5R
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)')E;F1E<F5R*2!["B`@("`@("`@
M8V%S92`G:F%V87-C<FEP="<Z"B`@("`@("`@("`@(')E='5R;B`G:'1M;"<[
M"@H@("`@("`@(&-A<V4@)VAT;6PG.@H@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G;W5T(&]F(')E;F1E<F5R<R<I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&YA;64@;V8@=&AI<R!T
M<F5E(&EN<W1A;F-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D<&%R86US("!!
M9&1I=&EO;F%L('!A<F%M971E<G,N"B`@("`@*B`\<')E/@H@("`@("H@)VYO
M<V5S<VEO;B<@("TM("`H8F]O;&5A;BD@268@=')U92P@9&\@;F]T('-T;W)E
M('1R964@9&%T82!I;B!S97-S:6]N+@H@("`@("H@/"]P<F4^"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7U1R964H)&YA;64L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6YS=&%N8V4@/2`D;F%M93L*
M("`@("`@("`D=&AI<RT^7W5S97-E<W-I;VX@/2!E;7!T>2@D<&%R86US6R=N
M;W-E<W-I;VXG72D["@H@("`@("`@("\J(%-E="!U<"!T:&4@<V5S<VEO;B!F
M;W(@;&%T97(@=&\@<V%V92!T<F5E('-T871E<RX@*B\*("`@("`@("!I9B`H
M)'1H:7,M/E]U<V5S97-S:6]N("8F"B`@("`@("`@("`@("%I<W-E="@D7U-%
M4U-)3TY;)VAO<F1E7W1R964G75LD=&AI<RT^7VEN<W1A;F-E72DI('L*("`@
M("`@("`@("`@)%]315-324].6R=H;W)D95]T<F5E)UU;)'1H:7,M/E]I;G-T
M86YC95T@/2!A<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;F1E<G,@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)'-T871I8R`@268@=')U92!T:&4@=')E92!N;V1E<R!C86XG="!B
M92!E>'!A;F1E9"!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;&QA<'-E9"!A;F0@=&AE('1R964@9V5T<R!R96YD97)E9"!E>'!A;F1E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R5')E92@D<W1A=&EC(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@96-H;R`D=&AI<RT^9V5T5')E92@D<W1A
M=&EC*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@86X@;W!T:6]N+@H@
M("`@("H@079A:6QA8FQE(&]P=&EO;G,Z"B`@("`@*B`\<')E/@H@("`@("H@
M("!A;'1E<FYA=&4@("`@+2T@($%L=&5R;F%T92!S:&%D:6YG(&EN('1H92!T
M86)L93\@*&)O;VQE86XI"B`@("`@*B`@(&AI9&5(96%D97)S("`M+2`@1&]N
M)W0@<F5N9&5R(&%N>2!(5$U,(&9O<B!T:&4@:&5A9&5R(')O=RP@:G5S="!U
M<V4@=&AE('=I9'1H<RX*("`@("`J("`@8VQA<W,@("`@("`@("TM("!4:&4@
M8VQA<W,@=&\@=7-E(&9O<B!T:&4@=&%B;&4N("AS=')I;F<I"B`@("`@*B`@
M(&QI;F5S("`@("`@("`M+2`@4VAO=R!T<F5E(&QI;F5S/R`H8F]O;&5A;BD*
M("`@("`J("`@;75L=&EL:6YE("`@("TM("!$;R!T:&4@;F]D92!L86)E;',@
M8V]N=&%I;B!L:6YE8G)E86MS/R`H8F]O;&5A;BD*("`@("`J(#PO<')E/@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;W!T:6]N("!4:&4@;W!T:6]N
M(&YA;64@+6]R+2!A;B!A<G)A>2!O9B!O<'1I;VX@;F%M92]V86QU90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@('!A:7)S+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1V86P@("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T3W!T:6]N*"1O<'1I;VYS+"`D=F%L=64@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&]P=&EO;G,I*2!["B`@
M("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH)&]P=&EO;G,@/3X@)'9A;'5E
M*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O
M<'1I;VX@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N
M<ULD;W!T:6]N72`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971S(&%N(&]P=&EO;B=S('9A;'5E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]P=&EO;B`@(%1H92!N86UE(&]F('1H92!O<'1I
M;VX@=&\@9F5T8V@N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:'1M;"`@("!4
M<G5E(&]R(&9A;'-E('=H971H97(@=&\@9F]R;6%T('1H92!R971U<FX@=F%L
M=64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&EN(&AT;6PN($1E
M9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5F875L
M="`@02!D969A=6QT('9A;'5E('1O('5S92!I;B!C87-E(&YO;F4@:7,@<V5T
M(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(')E<75E
M<W1E9"!O<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&]P=&EO;B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971/<'1I
M;VXH)&]P=&EO;BP@)&AT;6P@/2!F86QS92P@)&1E9F%U;'0@/2!N=6QL*0H@
M("`@>PH@("`@("`@("1V86QU92`](&YU;&P["@H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=*2`F)B`A:7-?;G5L;"@D9&5F
M875L="DI('L*("`@("`@("`@("`@+RH@4F5Q=65S=&5D(&]P=&EO;B!H87,@
M;F]T(&)E96X@8G5T('1H97)E(&ES(&$*("`@("`@("`@("`@("H@9&5F875L
M="X@*B\*("`@("`@("`@("`@)'9A;'5E(#T@)&1E9F%U;'0["B`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULD;W!T:6]N72DI('L*
M("`@("`@("`@("`@+RH@4F5Q=65S=&5D(&]P=&EO;B!H87,@8F5E;B!S970L
M(&=E="!I=',@=F%L=64N("HO"B`@("`@("`@("`@("1V86QU92`]("1T:&ES
M+3Y?;W!T:6]N<ULD;W!T:6]N73L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M:'1M;"`F)B`A:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@("`@("\J($9O
M<FUA="!V86QU92!F;W(@:'1M;"!O=71P=70N("HO"B`@("`@("`@("`@("1V
M86QU92`]('-P<FEN=&8H)R`E<STB)7,B)RP@)&]P=&EO;BP@)'9A;'5E*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@;F]D92!T;R!T:&4@;F]D92!T<F5E(&%R<F%Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1I9"`@("`@("`@("`@
M5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A
M<F5N="`@("`@("!4:&4@<&%R96YT)W,@=6YI<75E(&YO9&4@:60N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D;&%B96P@("`@("`@(%1H92!T97AT(&QA8F5L
M(&9O<B!T:&4@;F]D92X*("`@("`J($!P87)A;2!S=')I;F<@("1I;F1E;G0@
M("`@("`@1&5P<F5C871E9"P@=&AI<R!I<R!C86QC=6QA=&5D(&%U=&]M871I
M8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F%S
M960@;VX@=&AE('!A<F5N="!N;V1E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&5X<&%N9&5D("`@("!)<R!T:&ES(&QE=F5L(&5X<&%N9&5D(&]R(&YO="X*
M("`@("`J($!P87)A;2!A<G)A>2`@("1P87)A;7,@("`@("`@06YY(&]T:&5R
M('!A<F%M971E<G,@=&\@<V5T("A`<V5E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%D9$YO9&5087)A;7,H*2!F;W(@9G5L;"!D971A
M:6QS*2X*("`@("`J($!P87)A;2!A<G)A>2`@("1E>'1R85]R:6=H="`@06YY
M(&]T:&5R(&-O;'5M;G,@=&\@9&ES<&QA>2!T;R!T:&4@<FEG:'0@;V8*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1R964N"B`@
M("`@*B!`<&%R86T@87)R87D@("`D97AT<F%?;&5F="`@($%N>2!O=&AE<B!C
M;VQU;6YS('1O(&1I<W!L87D@=&\@=&AE(&QE9G0@;V8*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1R964N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9$YO9&4H)&ED+"`D<&%R96YT+"`D;&%B96PL("1I;F1E
M;G0L("1E>'!A;F1E9"`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@I+"`D97AT<F%?<FEG:'0@/2!A<G)A>2@I+`H@("`@
M("`@("`@("`@("`@("`@("`D97AT<F%?;&5F="`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=L86)E;"==(#T@)&QA8F5L
M.PH*("`@("`@("!I9B`H)'1H:7,M/E]U<V5S97-S:6]N*2!["B`@("`@("`@
M("`@("1S97-S:6]N7W-T871E(#T@)%]315-324].6R=H;W)D95]T<F5E)UU;
M)'1H:7,M/E]I;G-T86YC95T["B`@("`@("`@("`@("1T;V=G;&5?:60@/2!5
M=&EL.CIG971&;W)M1&%T82A(3U)$15]44D5%7U1/1T=,12`N("1T:&ES+3Y?
M:6YS=&%N8V4I.PH@("`@("`@("`@("!I9B`H)&ED(#T]("1T;V=G;&5?:60I
M('L*("`@("`@("`@("`@("`@("\J(%=E(&AA=F4@82!U<FP@=&]G9VQE(')E
M<75E<W0@9F]R('1H:7,@;F]D92X@*B\*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<V5S<VEO;E]S=&%T95LG97AP86YD960G75LD:61=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("\J(%5S92!S97-S:6]N('-T871E(&EF(&ET(&ES
M('-E="X@*B\*("`@("`@("`@("`@("`@("`@("`D97AP86YD960@/2`H(21S
M97-S:6]N7W-T871E6R=E>'!A;F1E9"==6R1I9%TI.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!/=&AE<G=I<V4@
M=7-E('=H870@=V%S('!A<W-E9"!T:')O=6=H('1H90H@("`@("`@("`@("`@
M("`@("`@("`J(&9U;F-T:6]N+B`J+PH@("`@("`@("`@("`@("`@("`@("1E
M>'!A;F1E9"`]("@A)&5X<&%N9&5D*3L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`O*B!3879E('1H:7,@<W1A=&4@=&\@<V5S<VEO;BX@
M*B\*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?=')E92==6R1T
M:&ES+3Y?:6YS=&%N8V5=6R=E>'!A;F1E9"==6R1I9%T@/2`D97AP86YD960[
M"B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<V5S<VEO;E]S=&%T95LG
M97AP86YD960G75LD:61=*2D@>PH@("`@("`@("`@("`@("`@+RH@268@=V4@
M:&%V92!A('-A=F5D('-E<W-I;VX@<W1A=&4@=7-E(&ET+B`J+PH@("`@("`@
M("`@("`@("`@)&5X<&%N9&5D(#T@)'-E<W-I;VY?<W1A=&5;)V5X<&%N9&5D
M)UU;)&ED73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]N;V1E<ULD:61=6R=E>'!A;F1E9"==(#T@)&5X<&%N9&5D.PH*("`@
M("`@("`O*B!)9B!A;GD@<&%R86US(&EN8VQU9&5D(&AE<F4@861D('1H96T@
M;F]W+B`J+PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<RDI('L*("`@("`@
M("`@("`@)'1H:7,M/F%D9$YO9&5087)A;7,H)&ED+"`D<&%R86US*3L*("`@
M("`@("!]"@H@("`@("`@("\J($EF(&%N>2!E>'1R82!C;VQU;6YS(&EN8VQU
M9&5D(&AE<F4@861D('1H96T@;F]W+B`J+PH@("`@("`@(&EF("@A96UP='DH
M)&5X=')A7W)I9VAT*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D3F]D945X
M=')A*"1I9"P@2$]21$5?5%)%15]%6%1205]224=(5"P@)&5X=')A7W)I9VAT
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D97AT<F%?;&5F="DI
M('L*("`@("`@("`@("`@)'1H:7,M/F%D9$YO9&5%>'1R82@D:60L($A/4D1%
M7U12145?15A44D%?3$5&5"P@)&5X=')A7VQE9G0I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7VYU;&PH)'!A<F5N="DI('L*("`@("`@("`@("`@:68@
M*"%I;E]A<G)A>2@D:60L("1T:&ES+3Y?<F]O=%]N;V1E<RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F]O=%]N;V1E<UM=(#T@)&ED.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?;F]D97-;)'!A<F5N=%U;)V-H:6QD<F5N)UTI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1P87)E;G1=6R=C:&EL9')E;B==
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6EN
M7V%R<F%Y*"1I9"P@)'1H:7,M/E]N;V1E<ULD<&%R96YT75LG8VAI;&1R96XG
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)'!A<F5N=%U;
M)V-H:6QD<F5N)UU;72`]("1I9#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@861D:71I;VYA;"!P87)A;65T
M97)S('1O(&$@;F]D92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@("`@5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N>2!O=&AE<B!P87)A;65T97)S('1O('-E="X*("`@("`J
M(#QP<F4^"B`@("`@*B!C;&%S<R`@("`@+2T@($-34R!C;&%S<R!T;R!U<V4@
M=VET:"!T:&ES(&YO9&4*("`@("`J(&EC;VX@("`@("`M+2`@26-O;B!T;R!D
M:7-P;&%Y(&YE>'0@;F]D90H@("`@("H@:6-O;F%L="`@("TM("!!;'0@=&5X
M="!T;R!U<V4@9F]R('1H92!I8V]N"B`@("`@*B!I8V]N9&ER("`@+2T@($EC
M;VX@9&ER96-T;W)Y"B`@("`@*B!I8V]N;W!E;B`@+2T@($EC;VX@=&\@:6YD
M:6-A=&4@=&AI<R!N;V1E(&%S(&5X<&%N9&5D"B`@("`@*B!O;F-L:6-K("`@
M+2T@($]N8VQI8VL@979E;G0@871T86-H960@=&\@=&AI<R!N;V1E"B`@("`@
M*B!U<FP@("`@("`@+2T@(%523"!T;R!L:6YK('1H92!N;V1E('1O"B`@("`@
M*B!U<FQC;&%S<R`@+2T@($-34R!C;&%S<R!F;W(@=&AE(&YO9&4G<R!54DP*
M("`@("`J('1A<F=E="`@("`M+2`@5&%R9V5T(&9O<B!T:&4@)W5R;"<@;&EN
M:PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$YO9&50
M87)A;7,H)&ED+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@
M/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@("1A;&QO=V5D
M(#T@87)R87DH"B`@("`@("`@("`@("=C;&%S<R<L("=I8V]N)RP@)VEC;VYA
M;'0G+"`G:6-O;F1I<B<L("=I8V]N;W!E;B<L"B`@("`@("`@("`@("=O;F-L
M:6-K)RP@)W5R;"<L("=U<FQC;&%S<R<L("=T87)G970G+`H@("`@("`@("D[
M"@H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M7VED(#T^("1P
M87)A;5]V86PI('L*("`@("`@("`@("`@+RH@4V5T(&]N;'D@86QL;W=E9"!A
M;F0@;F]N+6YU;&P@<&%R86US+B`J+PH@("`@("`@("`@("!I9B`H:6Y?87)R
M87DH)'!A<F%M7VED+"`D86QL;W=E9"D@)B8@(6ES7VYU;&PH)'!A<F%M7W9A
M;"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&ED75LD<&%R
M86U?:61=(#T@)'!A<F%M7W9A;#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@97AT<F$@8V]L=6UN<R!T;R!B
M92!D:7-P;&%Y960@=&\@=&AE('-I9&4@;V8@=&AE(&YO9&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("`@)&ED("`@("!4:&4@=6YI<75E(&YO9&4@
M:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VED92`@(%=H:6-H('-I9&4@
M=&\@<&QA8V4@=&AE(&5X=')A(&-O;'5M;G,@;VXN"B`@("`@*B!`<&%R86T@
M87)R87D@("`D97AT<F$@($5X=')A(&-O;'5M;G,@=&\@9&ES<&QA>2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D3F]D945X=')A*"1I9"P@)'-I9&4L("1E
M>'1R82D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1E>'1R82DI('L*
M("`@("`@("`@("`@)&5X=')A(#T@87)R87DH)&5X=')A*3L*("`@("`@("!]
M"@H@("`@("`@("1C;VQ?8V]U;G0@/2!C;W5N="@D97AT<F$I.PH*("`@("`@
M("!S=VET8V@@*"1S:61E*2!["B`@("`@("`@8V%S92!(3U)$15]44D5%7T58
M5%)!7TQ%1E0Z"B`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&ED75LG97AT
M<F$G75M(3U)$15]44D5%7T585%)!7TQ%1E1=(#T@)&5X=')A.PH@("`@("`@
M("`@("!I9B`H)&-O;%]C;W5N="`^("1T:&ES+3Y?97AT<F%?8V]L<U]L969T
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V5X=')A7V-O;'-?;&5F="`]
M("1C;VQ?8V]U;G0["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@2$]21$5?5%)%15]%6%1205]224=(5#H*("`@("`@
M("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=E>'1R82==6TA/4D1%7U12145?
M15A44D%?4DE'2%1=(#T@)&5X=')A.PH@("`@("`@("`@("!I9B`H)&-O;%]C
M;W5N="`^("1T:&ES+3Y?97AT<F%?8V]L<U]R:6=H="D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]E>'1R85]C;VQS7W)I9VAT(#T@)&-O;%]C;W5N=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T<R!T:&4@=')E92!B>2!T:&4@<W!E
M8VEF:65D(&YO9&4@<')O<&5R='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8W)I=&5R:6$@(%1H92!N;V1E('!R;W!E<G1Y('1O('-O<G0@8GDN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@("`@57-E9"!I;G1E<FYA
M;&QY(&9O<B!R96-U<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G0H
M)&-R:71E<FEA+"`D:60@/2`M,2D*("`@('L*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;F]D97-;)&ED75LG8VAI;&1R96XG72DI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C<FET97)I82`]
M/2`G:V5Y)RD@>PH@("`@("`@("`@("!K<V]R="@D=&AI<RT^7VYO9&5S6R1I
M9%U;)V-H:6QD<F5N)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3Y?<V]R=$-R:71E<FEA(#T@)&-R:71E<FEA.PH@("`@("`@("`@
M("!U<V]R="@D=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UTL(&%R<F%Y
M*"1T:&ES+"`G7W-O<G0G*2D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UT@87,@)&-H:6QD*2![
M"B`@("`@("`@("`@("1T:&ES+3YS;W)T*"1C<FET97)I82P@)&-H:6QD*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!(96QP97(@;65T:&]D
M(&9O<B!S;W)T*"D@=&\@8V]M<&%R92!T=V\@=')E92!E;&5M96YT<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-O<G0H)&$L("1B*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]N;V1E<ULD85U;)'1H:7,M/E]S;W)T0W)I=&5R:6%=*2D@>PH@("`@
M("`@("`@("!R971U<FX@,3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7VYO9&5S6R1B75LD=&AI<RT^7W-O<G1#<FET97)I85TI*2![
M"B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N('-T<F-O;&PH)'1H:7,M/E]N;V1E<ULD85U;)'1H:7,M/E]S;W)T0W)I
M=&5R:6%=+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;
M)&)=6R1T:&ES+3Y?<V]R=$-R:71E<FEA72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('=H971H97(@=&AE('-P96-I9FEE9"!N;V1E(&ES(&-U
M<G)E;G1L>2!E>'!A;F1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&ED("!4:&4@=6YI<75E(&YO9&4@:60N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I960@;F]D92!I<R!E>'!A
M;F1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-%>'!A;F1E9"@D:60I"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&ED72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F]D97-;)&ED75LG97AP86YD
M960G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!C;VQU;6X@:&5A9&5R<R!T;R!T:&4@=')E
M92!T86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&AE861E<B`@
M06X@87)R87D@8V]N=&%I;FEN9R!H87-H97,@=VET:"!H96%D97(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX@5&AE(&9O;&QO
M=VEN9R!K97ES(&%R92!A;&QO=V5D.@H@("`@("H@/'!R93X*("`@("`J(&AT
M;6P@("TM(%1H92!(5$U,(&-O;G1E;G0@;V8@=&AE(&AE861E<B!C96QL"B`@
M("`@*B!W:61T:"`M+2!4:&4@=VED=&@@;V8@=&AE(&AE861E<B!C96QL"B`@
M("`@*B!A;&EG;B`M+2!4:&4@86QI9VYM96YT(&EN<VED92!T:&4@:&5A9&5R
M(&-E;&P*("`@("`J(&-L87-S("TM(%1H92!#4U,@8VQA<W,@;V8@=&AE(&AE
M861E<B!C96QL"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T2&5A9&5R*"1H96%D97(I"B`@("!["B`@("`@("`@)'1H:7,M/E]H96%D
M97(@/2`D:&5A9&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!I
M;F1E;G0@;&5V96P@9F]R(&5A8V@@;F]D92!I;B!T:&4@=')E92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V)U:6QD26YD96YT<R@D;F]D97,L("1I;F1E;G0@
M/2`P*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1N;V1E<R!A<R`D:60I('L*
M("`@("`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=I;F1E;G0G72`]("1I
M;F1E;G0["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N;V1E<ULD
M:61=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B
M=6EL9$EN9&5N=',H)'1H:7,M/E]N;V1E<ULD:61=6R=C:&EL9')E;B==+"`D
M:6YD96YT("L@,2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-E<FEA;&EZ92YP:'``````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C$Q-P`Q,#4Q-30S,3`V,0`P,C`V-3<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"F1E9FEN92@G4T5224%,25I%7U5.2TY/5TXG+"`M,2D["F1E9FEN92@G
M4T5224%,25I%7TY/3D4G+"`P*3L*9&5F:6YE*"=315))04Q)6D5?5T1$6"<L
M(#$I.PID969I;F4H)U-%4DE!3$E:15]"6DE0)RP@,BD["F1E9FEN92@G4T52
M24%,25I%7TE-05`X)RP@,RD["F1E9FEN92@G4T5224%,25I%7TE-05!55$8W
M)RP@-"D["F1E9FEN92@G4T5224%,25I%7TE-05!55$8X)RP@-2D["F1E9FEN
M92@G4T5224%,25I%7T)!4TE#)RP@-BD["F1E9FEN92@G4T5224%,25I%7T=:
M7T1%1DQ!5$4G+"`W*3L*9&5F:6YE*"=315))04Q)6D5?1UI?0T]-4%)%4U,G
M+"`X*3L*9&5F:6YE*"=315))04Q)6D5?1UI?14Y#3T0G+"`Y*3L*9&5F:6YE
M*"=315))04Q)6D5?0D%3138T)RP@,3`I.PID969I;F4H)U-%4DE!3$E:15]3
M44Q834PG+"`Q,2D["F1E9FEN92@G4T5224%,25I%7U)!5R<L(#$R*3L*9&5F
M:6YE*"=315))04Q)6D5?55),)RP@,3,I.PID969I;F4H)U-%4DE!3$E:15]5
M5$8W)RP@,30I.PH*+RHJ(%5S92!315))04Q)6D5?551&-R!A;F0@4T5224%,
M25I%7T)!4TE#('-T86-K960N("`J+PID969I;F4H)U-%4DE!3$E:15]55$8W
M7T)!4TE#)RP@,34I.PH*"B\J*@H@*B!4:&4@4V5R:6%L:7IE.CH@8VQA<W,@
M<')O=FED97,@=F%R:6]U<R!M971H;V1S(&]F(&5N8V%P<W5L871I;F<@9&%T
M82X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5R:6%L:7IE+U-E<FEA;&EZ
M92YP:'`L=B`Q+C(U+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HS-"!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!3=&5P:&%N92!(=71H97(@
M/'-H=71H97)`8FEG9F]O="YC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M/@H@
M*B!`<VEN8V4@("!(;W)D92`R+C`*("H@0'!A8VMA9V4@2&]R9&5?4V5R:6%L
M:7IE"B`J+PIC;&%S<R!(;W)D95]397)I86QI>F4@>PH*("`@("\J*@H@("`@
M("H@4V5R:6%L:7IE(&$@=F%L=64N"B`@("`@*@H@("`@("H@4V5E('1H92!L
M:7-T(&]F(&-O;G-T86YT<R!A="!T:&4@=&]P(&]F('1H92!F:6QE(&9O<B!T
M:&4@<V5R:6%L:7II;F<*("`@("`J('1E8VAN:7%U97,@=&AA="!C86X@8F4@
M=7-E9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&$@("`@5&AE
M(&1A=&$@=&\@8F4@<V5R:6%L:7IE9"X*("`@("`J($!P87)A;2!M:7AE9"`D
M;6]D92`@("!4:&4@;6]D92!O9B!S97)I86QI>F%T:6]N+B!#86X@8F4@96ET
M:&5R(&$@<VEN9VQE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;6]D
M92!O<B!A<G)A>2!O9B!M;V1E<RX@($EF(&%R<F%Y+"!W:6QL(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@<V5R:6%L:7IE9"!I;B!T:&4@;W)D
M97(@<')O=FED960N"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M<R`@06YY
M(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@<V5R:6%L:7IA=&EO;B!M971H
M;V0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<FEA;&EZ960@9&%T
M82X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ92@D9&%T
M82P@)&UO9&4@/2!A<G)A>2A315))04Q)6D5?0D%324,I+"`D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1M;V1E*2D@>PH@
M("`@("`@("`@("`D;6]D92`](&%R<F%Y*"1M;V1E*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E='5R;B!N;W<@:68@;F\@9&%T82X@*B\*("`@("`@("!I
M9B`H96UP='DH)&1A=&$I("8F("%I<U]A<G)A>2@D9&%T82DI('L*("`@("`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R
M<V4@=&AR;W5G:"!T:&4@;&ES="!O9B!S97)I86QI>FEN9R!M;V1E<RX@*B\*
M("`@("`@("!F;W)E86-H("@D;6]D92!A<R`D=F%L*2!["B`@("`@("`@("`@
M("\J($-H96-K('1O(&UA:V4@<W5R92!T:&4@;6]D92!I<R!S=7!P;W)T960N
M("HO"B`@("`@("`@("`@(&EF("@A2&]R9&5?4V5R:6%L:7IE.CIH87-#87!A
M8FEL:71Y*"1V86PI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G56YS=7!P;W)T960@<V5R:6%L:7IA=&EO;B!T>7!E)RD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@2&]R9&5?4V5R:6%L:7IE.CI?
M<V5R:6%L:7IE*"1D871A+"`D=F%L+"`D<&%R86US*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!397)I86QI>F4@
M9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)B1D871A("`@("`@("`@("`@5&AE(&1A=&$@
M=&\@8F4@<V5R:6%L:7IE9"X*("`@("`J($!P87)A;2!M:7AE9"`D;6]D92`@
M("`@("`@("`@("!4:&4@;6]D92!O9B!S97)I86QI>F%T:6]N+B!#86X@8F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E:71H97(@
M82!S:6YG;&4@;6]D92!O<B!A<G)A>2!O9B!M;V1E<RX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!A<G)A>2P@=VEL;"!B92!S
M97)I86QI>F5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&]R9&5R('!R;W9I9&5D+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1P87)A;7,@($%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AE('-E<FEA
M;&EZ871I;VX@;65T:&]D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S97)I86QI>F4H)B1D
M871A+"`D;6]D92P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<W=I
M=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@4T5224%,25I%7TY/3D4Z"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]"6DE0
M.@H@("`@("`@("`@("`D9&%T82`](&)Z8V]M<')E<W,H)&1A=&$L(#DL(#,P
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%
M7U=$1%@Z"B`@("`@("`@("`@("1D871A(#T@=V1D>%]S97)I86QI>F5?=F%L
M=64H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!3
M15))04Q)6D5?24U!4#@Z"B`@("`@("`@("`@("1D871A(#T@:6UA<%\X8FET
M*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T52
M24%,25I%7TE-05!55$8W.@H@("`@("`@("`@("`D9&%T82`](&EM87!?=71F
M-U]E;F-O9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!315))04Q)6D5?24U!4%541C@Z"B`@("`@("`@("`@("1D871A(#T@
M:6UA<%]U=&8X*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@4T5224%,25I%7T=:7T1%1DQ!5$4Z"B`@("`@("`@("`@("1D871A
M(#T@9WID969L871E*"1D871A+"`Y*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@4T5224%,25I%7T)!4TE#.@H@("`@("`@("`@("`D9&%T
M82`]('-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E(%-%4DE!3$E:15]'6E]#3TU04D534SH*("`@("`@("`@("`@
M)&1A=&$@/2!G>F-O;7!R97-S*"1D871A+"`Y*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7T)!4T4V-#H*("`@("`@("`@
M("`@)&1A=&$@/2!B87-E-C1?96YC;V1E*"1D871A*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7T=:7T5.0T]$.@H@("`@
M("`@("`@("`D9&%T82`](&=Z96YC;V1E*"1D871A+"`Y*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7U)!5SH*("`@("`@
M("`@("`@)&1A=&$@/2!R87=U<FQE;F-O9&4H)&1A=&$I.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?55),.@H@("`@("`@
M("`@("`D9&%T82`]('5R;&5N8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]344Q834PZ"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)'-Q;#)X
M;6P@/2`F;F5W('AM;%]S<6PR>&UL*"D["B`@("`@("`@("`@("1D871A(#T@
M)'-Q;#)X;6PM/F=E=%A-3"@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15]55$8W.@H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH@("`@("`@("`@("`D9&%T
M82`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1A=&$L("1P87)A;7,L("=U
M=&8M-R<I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))
M04Q)6D5?551&-U]"05-)0SH*("`@("`@("`@("`@2&]R9&5?4V5R:6%L:7IE
M.CI?<V5R:6%L:7IE*"1D871A+"!315))04Q)6D5?551&-RP@)'!A<F%M<RD[
M"B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W-E<FEA;&EZ92@D9&%T
M82P@4T5224%,25I%7T)!4TE#+"`D<&%R86US*3L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@56YS97)I86QI
M>F4@82!V86QU92X*("`@("`J"B`@("`@*B!3964@=&AE(&QI<W0@;V8@8V]N
M<W1A;G1S(&%T('1H92!T;W`@;V8@=&AE(&9I;&4@9F]R('1H92!S97)I86QI
M>FEN9PH@("`@("H@=&5C:&YI<75E<R!T:&%T(&-A;B!B92!U<V5D+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@("`@("`@("`@("!4:&4@
M9&%T82!T;R!B92!U;G-E<FEA;&EZ960N"B`@("`@*B!`<&%R86T@;6EX960@
M)&UO9&4@("`@5&AE(&UO9&4@;V8@=6YS97)I86QI>F%T:6]N+B`@0V%N(&)E
M(&5I=&AE<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<VEN9VQE
M(&UO9&4@;W(@87)R87D@;V8@;6]D97,N("!)9B!A<G)A>2P@=VEL;"!B90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('5N<V5R:6%L:7IE9"!I;B!T
M:&4@;W)D97(@<')O=FED960N"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M
M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@=6YS97)I86QI>F%T
M:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;65T:&]D(')E<75I
M<F5S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=6YS97)I
M86QI>F5D(&1A=&$N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!0
M14%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;G-E
M<FEA;&EZ92@D9&%T82P@)&UO9&4@/2!315))04Q)6D5?0D%324,L("1P87)A
M;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&UO9&4I
M*2!["B`@("`@("`@("`@("1M;V1E(#T@87)R87DH)&UO9&4I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4F5T=7)N(&YO=R!I9B!N;R!D871A+B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N("1D
M871A.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AR;W5G:"!T:&4@
M;&ES="!O9B!U;G-E<FEA;&EZ:6YG(&UO9&5S+B`J+PH@("`@("`@(&9O<F5A
M8V@@*"1M;V1E(&%S("1V86PI('L*("`@("`@("`@("`@+RH@0VAE8VL@=&\@
M;6%K92!S=7)E('1H92!M;V1E(&ES('-U<'!O<G1E9"X@*B\*("`@("`@("`@
M("`@:68@*"%(;W)D95]397)I86QI>F4Z.FAA<T-A<&%B:6QI='DH)'9A;"DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5
M;G-U<'!O<G1E9"!U;G-E<FEA;&EZ871I;VX@='EP92<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W5N<V5R:6%L:7IE
M*"1D871A+"`D=F%L+"`D<&%R86US*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1A
M=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G-E<FEA;&EZ92!D871A+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`F)&1A=&$@("!4:&4@9&%T82!T;R!B92!U;G-E<FEA;&EZ
M960N"B`@("`@*B!`<&%R86T@;6EX960@)&UO9&4@("`@5&AE(&UO9&4@;V8@
M=6YS97)I86QI>F%T:6]N+B!#86X@8F4@96ET:&5R(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!S:6YG;&4@;6]D92!O<B!A<G)A>2!O9B!M;V1E
M<RX@($EF(&%R<F%Y+"!W:6QL(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@=6YS97)I86QI>F5D(&EN('1H92!O<F1E<B!P<F]V:61E9"X*("`@
M("`J($!P87)A;2!M:7AE9"`D<&%R86US("!!;GD@861D:71I;VYA;"!P87)A
M;65T97)S('1H92!U;G-E<FEA;&EZ871I;VX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!M971H;V0@<F5Q=6ER97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]U;G-E<FEA;&EZ92@F)&1A=&$L("1M;V1E+"`D<&%R86US(#T@;G5L
M;"D*("`@('L*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@("`@8V%S
M92!315))04Q)6D5?3D].13H*("`@("`@("!C87-E(%-%4DE!3$E:15]344Q8
M34PZ"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:
M15]205<Z"B`@("`@("`@("`@("1D871A(#T@<F%W=7)L9&5C;V1E*"1D871A
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%
M7U523#H*("`@("`@("`@("`@)&1A=&$@/2!U<FQD96-O9&4H)&1A=&$I.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?5T1$
M6#H*("`@("`@("`@("`@)&1A=&$@/2!W9&1X7V1E<V5R:6%L:7IE*"1D871A
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%
M7T):25`Z"B`@("`@("`@("`@("1D871A(#T@8GID96-O;7!R97-S*"1D871A
M+"!F86QS92D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%
M4DE!3$E:15])34%0551&-SH*("`@("`@("`@("`@)&1A=&$@/2!I;6%P7W5T
M9C=?9&5C;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@4T5224%,25I%7T)!4TE#.@H@("`@("`@("`@("`D9&%T82`]($!U
M;G-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(%-%4DE!3$E:15]'6E]$149,051%.@H@("`@("`@("`@("`D9&%T
M82`](&=Z:6YF;&%T92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E(%-%4DE!3$E:15]"05-%-C0Z"B`@("`@("`@("`@("1D871A
M(#T@8F%S938T7V1E8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]#3TU04D534SH*("`@("`@("`@
M("`@)&1A=&$@/2!G>G5N8V]M<')E<W,H)&1A=&$I.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?551&-SH*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*("`@("`@("`@
M("`@)&1A=&$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A+"`G=71F
M+3<G+"`D<&%R86US*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@4T5224%,25I%7U541C=?0D%324,Z"B`@("`@("`@("`@($AO<F1E7U-E
M<FEA;&EZ93HZ7W5N<V5R:6%L:7IE*"1D871A+"!315))04Q)6D5?0D%324,L
M("1P87)A;7,I.PH@("`@("`@("`@("!(;W)D95]397)I86QI>F4Z.E]U;G-E
M<FEA;&EZ92@D9&%T82P@4T5224%,25I%7U541C<L("1P87)A;7,I.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:R!W:&5T:&5R(&]R(&YO="!A('-E<FEA;&EZ871I;VX@;65T:&]D
M(&ES('-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M;6]D92`@5&AE('-E<FEA;&EZ871I;VX@;65T:&]D+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!S=7!P;W)T960L(&9A;'-E(&EF
M(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S0V%P86)I;&ET>2@D;6]D
M92D*("`@('L*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@("`@8V%S
M92!315))04Q)6D5?0EI)4#H*("`@("`@("`@("`@<F5T=7)N(%5T:6PZ.F5X
M=&5N<VEO;D5X:7-T<R@G8GHR)RD["@H@("`@("`@(&-A<V4@4T5224%,25I%
M7U=$1%@Z"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H)W=D9'@G*3L*"B`@("`@("`@8V%S92!315))04Q)6D5?24U!4%541C<Z
M"B`@("`@("`@8V%S92!315))04Q)6D5?24U!4%541C@Z"B`@("`@("`@8V%S
M92!315))04Q)6D5?24U!4#@Z"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIE
M>'1E;G-I;VY%>&ES=',H)VEM87`G*3L*"B`@("`@("`@8V%S92!315))04Q)
M6D5?1UI?1$5&3$%413H*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]#3TU0
M4D534SH*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]%3D-/1#H*("`@("`@
M("`@("`@<F5T=7)N(%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G>FQI8B<I.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15]344Q834PZ"B`@("`@("`@("`@(')E
M='5R;B!`:6YC;'5D95]O;F-E("=834PO<W%L,GAM;"YP:'`G.PH*("`@("`@
M("!C87-E(%-%4DE!3$E:15].3TY%.@H@("`@("`@(&-A<V4@4T5224%,25I%
M7T)!4TE#.@H@("`@("`@(&-A<V4@4T5224%,25I%7T)!4T4V-#H*("`@("`@
M("!C87-E(%-%4DE!3$E:15]205<Z"B`@("`@("`@8V%S92!315))04Q)6D5?
M55),.@H@("`@("`@(&-A<V4@4T5224%,25I%7U541C<Z"B`@("`@("`@8V%S
M92!315))04Q)6D5?551&-U]"05-)0SH*("`@("`@("`@("`@<F5T=7)N('1R
M=64["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A
M+G!H<```````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,S0U-C$`,3`U,34T,S$P-C$`,#$W-C`W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%
M05(N<&AP)SL*"B\O($EM<&]R="!C;VYS=&%N=',*+RHJ($EM<&]R="!A;')E
M861Y(&UA<'!E9"!C<W8@9&%T82X@("`@("`@("HO(&1E9FEN92@G24U03U)4
M7TU!4%!%1"<L(#$I.PHO*BH@36%P(&1A=&4@86YD('1I;64@96YT<FEE<R!O
M9B!C<W8@9&%T82X@*B\@9&5F:6YE*"=)35!/4E1?1$%4151)344G+"`R*3L*
M+RHJ($EM<&]R="!G96YE<FEC($-35B!D871A+B`@("`@("`@("`@("`@("HO
M(&1E9FEN92@G24U03U)47T-35B<L(#,I.PHO*BH@26UP;W)T($U3($]U=&QO
M;VL@9&%T82X@("`@("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?3U54
M3$]/2R<L(#0I.PHO*BH@26UP;W)T('9#86QE;F1A<B]I0V%L96YD87(@9&%T
M82X@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?24-!3$5.1$%2)RP@-2D["B\J
M*B!);7!O<G0@=D-A<F1S+B`@("`@("`@("`@("`@("`@("`@("`@("`J+R!D
M969I;F4H)TE-4$]25%]60T%21"<L(#8I.PHO*BH@26UP;W)T(&=E;F5R:6,@
M='-V(&1A=&$N("`@("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?5%-6
M)RP@-RD["B\J*B!);7!O<G0@375L8F5R<GD@861D<F5S<R!B;V]K(&1A=&$@
M("`@("`J+R!D969I;F4H)TE-4$]25%]-54Q"15)262<L(#@I.PHO*BH@26UP
M;W)T(%!I;F4@861D<F5S<R!B;V]K(&1A=&$N("`@("`@("`@*B\@9&5F:6YE
M*"=)35!/4E1?4$E.12<L(#DI.PHO*BH@26UP;W)T(&9I;&4N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?1DE,12<L(#$Q
M*3L*+RHJ($EM<&]R="!D871A+B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("HO(&1E9FEN92@G24U03U)47T1!5$$G+"`Q,BD["@HO+R!%>'!O<G0@8V]N
M<W1A;G1S"B\J*B!%>'!O<G0@9V5N97)I8R!#4U8@9&%T82X@*B\@9&5F:6YE
M*"=%6%!/4E1?0U-6)RP@,3`P*3L*+RHJ($5X<&]R="!I0V%L96YD87(@9&%T
M82X@("`J+R!D969I;F4H)T584$]25%])0T%,14Y$05(G+"`Q,#$I.PHO*BH@
M17AP;W)T('9#87)D<RX@("`@("`@("`@("HO(&1E9FEN92@G15A03U)47U9#
M05)$)RP@,3`R*3L*+RHJ($5X<&]R="!44U8@9&%T82X@("`@("`@("`J+R!D
M969I;F4H)T584$]25%]44U8G+"`Q,#,I.PHO*BH@17AP;W)T($]U=&QO;VL@
M0U-6(&1A=&$N("HO(&1E9FEN92@G15A03U)47T]55$Q/3TM#4U8G+"`Q,#0I
M.PH*+RHJ"B`J($%B<W1R86-T(&-L87-S('1O(&AA;F1L92!D:69F97)E;G0@
M:VEN9',@;V8@1&%T82!F;W)M871S(&%N9"!T;PH@*B!H96QP(&1A=&$@97AC
M:&%N9V4@8F5T=V5E;B!(;W)D92!A<'!L:6-A=&EO;G,@86YD(&5X=&5R;F%L
M('-O=7)C97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`L=B`Q+C@P+C$P+C$R(#(P,#8O,#@O,#@@,3<Z,34Z,C(@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q
M+C,*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@*B\*8VQA<W,@2&]R9&5?1&%T
M82!E>'1E;F1S(%!%05(@>PH*("`@('9A<B`D7V5X=&5N<VEO;CL*("`@('9A
M<B`D7V-O;G1E;G14>7!E(#T@)W1E>'0O<&QA:6XG.PH*("`@("\J*@H@("`@
M("H@02!L:7-T(&]F('=A<FYI;F=S(')A:7-E9"!D=7)I;F<@=&AE(&QA<W0@
M;W!E<F%T:6]N+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@
M("`J+PH@("`@=F%R("1?=V%R;FEN9W,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@4W1U8B!T;R!I;7!O<G0@<&%S<V5D(&1A=&$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&EM<&]R=$1A=&$H*0H@("`@>PH@("`@?0H*("`@("\J*@H@
M("`@("H@4W1U8B!T;R!R971U<FX@97AP;W)T960@9&%T82X*("`@("`J+PH@
M("`@9G5N8W1I;VX@97AP;W)T1&%T82@I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3='5B('1O(&EM<&]R="!A(&9I;&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&EM<&]R=$9I;&4H)&9I;&5N86UE+"`D:&5A9&5R(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL
M96YA;64I.PH@("`@("`@(')E='5R;B`D=&AI<RT^:6UP;W)T1&%T82@D9&%T
M82P@)&AE861E<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3='5B('1O(&5X
M<&]R="!D871A('1O(&$@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP
M;W)T1FEL92@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<FEE<R!T
M;R!D971E<FUI;F4@=&AE(&5X<&5C=&5D(&YE=VQI;F4@8VAA<F%C=&5R(&)A
M<V5D(&]N('1H90H@("`@("H@<&QA=&9O<FT@:6YF;W)M871I;VX@<&%S<V5D
M(&)Y('1H92!B<F]W<V5R)W,@86=E;G0@:&5A9&5R+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9W5E<W-E9"!E>'!E8W1E9"!N97=L:6YE
M(&-H87)A8W1E<G,L(&5I=&AE<B!<;BP@7'(*("`@("`J("`@("`@("`@("`@
M("`@("!O<B!<<EQN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.97=L:6YE
M*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S97(N
M<&AP)SL*("`@("`@("`D8G)O=W-E<B`]("9"<F]W<V5R.CIS:6YG;&5T;VXH
M*3L*"B`@("`@("`@<W=I=&-H("@D8G)O=W-E<BT^9V5T4&QA=&9O<FTH*2D@
M>PH@("`@("`@(&-A<V4@)W=I;B<Z"B`@("`@("`@("`@(')E='5R;B`B7')<
M;B(["@H@("`@("`@(&-A<V4@)VUA8R<Z"B`@("`@("`@("`@(')E='5R;B`B
M7'(B.PH*("`@("`@("!C87-E("=U;FEX)SH*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("!R971U<FX@(EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T1FEL96YA;64H)&)A<V5N86UE*0H@("`@>PH@("`@("`@
M(')E='5R;B`D8F%S96YA;64@+B`G+B<@+B`D=&AI<RT^7V5X=&5N<VEO;CL*
M("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=%1Y<&4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!W87)N:6YG<R!T:&%T(&AA
M=F4@8F5E;B!R86ES960@9'5R:6YG('1H92!L87-T"B`@("`@*B!O<&5R871I
M;VXN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($$@*'!O<W-I8FQY(&5M<'1Y*2!L:7-T(&]F
M('=A<FYI;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!W87)N:6YG<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=V%R;FEN9W,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(
M;W)D95]$871A(&EN<W1A;F-E(&)A<V5D(&]N("1F;W)M870N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1F;W)M870@(%1H92!T>7!E(&]F(&-O;F-R
M971E($AO<F1E7T1A=&$@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FXN($EF("1F;W)M870@:7,@86X@87)R87DL('1H
M96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M:6X@)&9O<FUA=%LP72]L:6(O1&%T82\@9F]R('1H92!S=6)C;&%S<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D
M("1F;W)M871;,5TN<&AP+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M1&%T82`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?1&%T82!I
M;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@9F%L<V4@
M;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1F
M;W)M870I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1F;W)M870I*2![
M"B`@("`@("`@("`@("1A<'`@/2`D9F]R;6%T6S!=.PH@("`@("`@("`@("`D
M9F]R;6%T(#T@)&9O<FUA=%LQ73L*("`@("`@("!]"@H@("`@("`@("1F;W)M
M870@/2!B87-E;F%M92@D9F]R;6%T*3L*"B`@("`@("`@:68@*&5M<'1Y*"1F
M;W)M870I('Q\("AS=')C;7`H)&9O<FUA="P@)VYO;F4G*2`]/2`P*2D@>PH@
M("`@("`@("`@("`D9&%T82`])B!N97<@2&]R9&5?1&%T82@I.PH@("`@("`@
M("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M
M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O
M1&%T82\G("X@)&9O<FUA="`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T1A=&$O)R`N("1F;W)M
M870@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C;&%S<R`]("=(;W)D
M95]$871A7R<@+B`D9F]R;6%T.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H
M)&-L87-S*2D@>PH@("`@("`@("`@("`D9&%T82`])B!N97<@)&-L87-S*"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@/2!014%2.CIR
M86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G
M(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&%T
M83L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7T1A=&$@:6YS=&%N8V4*
M("`@("`J(&)A<V5D(&]N("1F;W)M870N($ET('=I;&P@;VYL>2!C<F5A=&4@
M82!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?1&%T80H@("`@("H@:6YS=&%N
M8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N
M"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L
M92!D871A('-O=7)C97,@*&%N9"P@=&AU<RP@;75L=&EP;&4*("`@("`J($AO
M<F1E7T1A=&$@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)DAO
M<F1E7T1A=&$Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9F]R;6%T("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]$871A
M('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T1A=&$@(%1H92!C
M;VYC<F5T92!(;W)D95]$871A(')E9F5R96YC92P@;W(@9F%L<V4@;VX@86X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH)&9O<FUA="D*("`@('L*("`@("`@("!S
M=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC
M97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@
M("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92@D9F]R;6%T
M*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI
M*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R
M9&5?1&%T83HZ9F%C=&]R>2@D9F]R;6%T*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J
M*@H@("`@("H@36%P<R!A(&1A=&4O=&EM92!S=')I;F<@=&\@86X@87-S;V-I
M871I=F4@87)R87DN"B`@("`@*@H@("`@("H@5&AE(&UE=&AO9"!S:6=N871U
M<F4@:&%S(&-H86YG960@:6X@2&]R9&4@,RXQ+C,N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T92`@(%1H92!D871E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M($]N92!O9B`G9&%T92<L("=T:6UE)R!O<B`G9&%T971I;64G+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1W;RUD:6UE;G-I;VYA;"!A<G)A>2!W
M:71H(&%D9&ET:6]N86P@:6YF;W)M871I;VX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!A8F]U="!T:&4@9F]R;6%T=&EN9RX@4&]S<VEB;&4@:V5Y
M<R!A<F4Z/'!R93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!D96QI
M;6ET97(@+2T@5&AE(&-H87)A8W1E<B!T:&%T('-E<&5R871E<R!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&EF9F5R
M96YT(&1A=&4O=&EM92!P87)T<RX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!F;W)M870@+2T@268@)V%M<&TG(&%N9"`D9&%T92!C;VYT86EN<R!A
M('1I;64@=V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87-S=6UE('1H870@:70@:7,@:6X@04TO4$T@9F]R;6%T+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&]R9&5R("TM($EF("1T>7!E(&ES("=D
M871E=&EM92<@=&AE(&]R9&5R(&]F('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&1A>2!A;F0@=&EM92!P87)T<SH@+3$@*'1I
M;65S=&%M<"DL(#`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`H9&%Y+W1I;64I+"`Q("AT:6UE+V1A>2DN"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:V5Y("`@5&AE(&ME>2!T;R!U<V4@9F]R("1P87)A;7,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D871E(&]R('1I;64@
M:6X@25-/(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@;6%P1&%T92@D
M9&%T92P@)'1Y<&4L("1P87)A;7,L("1K97DI"B`@("!["B`@("`@("`@<W=I
M=&-H("@D='EP92D@>PH@("`@("`@(&-A<V4@)V1A=&4G.@H@("`@("`@(&-A
M<V4@)VUO;G1H9&%Y)SH*("`@("`@("!C87-E("=M;VYT:&1A>7EE87(G.@H@
M("`@("`@("`@("`D9&%T97,@/2!E>'!L;V1E*"1P87)A;7-;)V1E;&EM:71E
M<B==6R1K97E=+"`D9&%T92D["B`@("`@("`@("`@(&EF("AC;W5N="@D9&%T
M97,I("$](#,I('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:6YD97@@/2!A<G)A>5]F;&EP*&5X
M<&QO9&4H)R\G+"`D<&%R86US6R=F;W)M870G75LD:V5Y72DI.PH@("`@("`@
M("`@("!R971U<FX@)&1A=&5S6R1I;F1E>%LG>65A<B==72`N("<M)R`N("1D
M871E<ULD:6YD97A;)VUO;G1H)UU=("X@)RTG("X@)&1A=&5S6R1I;F1E>%LG
M;61A>2==73L*"B`@("`@("`@8V%S92`G=&EM92<Z"B`@("`@("`@("`@("1D
M871E<R`](&5X<&QO9&4H)'!A<F%M<ULG9&5L:6UI=&5R)UU;)&ME>5TL("1D
M871E*3L*("`@("`@("`@("`@:68@*&-O=6YT*"1D871E<RD@/"`R('Q\(&-O
M=6YT*"1D871E<RD@/B`S*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&1A
M=&4["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1P87)A;7-;)V9O
M<FUA="==6R1K97E=(#T]("=A;7!M)RD@>PH@("`@("`@("`@("`@("`@:68@
M*'-T<G!O<RAS=')T;VQO=V5R*"1D871E<UMC;W5N="@D9&%T97,I+3%=*2P@
M)W!M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1D
M871E<ULP72`A/3T@)S$R)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%T97-;,%T@*ST@,3(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1D871E<ULP72`]/2`G,3(G*2!["B`@("`@
M("`@("`@("`@("`@("`@)&1A=&5S6S!=(#T@)S`G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&1A=&5S6V-O=6YT*"1D871E<RD@+2`Q
M72`]('-P<FEN=&8H)R4P,F0G+"`D9&%T97-;8V]U;G0H)&1A=&5S*2TQ72D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1D871E<ULP72`N
M("<Z)R`N("1D871E<ULQ72`N("AC;W5N="@D9&%T97,I(#T](#,@/R`H)SHG
M("X@)&1A=&5S6S)=*2`Z("<Z,#`G*3L*"B`@("`@("`@8V%S92`G9&%T971I
M;64G.@H@("`@("`@("`@("!S=VET8V@@*"1P87)A;7-;)V]R9&5R)UU;)&ME
M>5TI('L*("`@("`@("`@("`@8V%S92`M,3H*("`@("`@("`@("`@("`@(')E
M='5R;B`H<W1R:6YG*2AI;G0I)&1A=&4@/3T@)&1A=&4*("`@("`@("`@("`@
M("`@("`@("`_(&1A=&4H)UDM;2UD($@Z:3IS)RP@)&1A=&4I"B`@("`@("`@
M("`@("`@("`@("`@.B`D9&%T93L*("`@("`@("`@("`@8V%S92`P.@H@("`@
M("`@("`@("`@("`@;&ES="@D9&%Y+"`D=&EM92D@/2!E>'!L;V1E*"<@)RP@
M)&1A=&4L(#(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@,3H*("`@("`@("`@("`@("`@;&ES="@D=&EM92P@)&1A>2D@/2!E
M>'!L;V1E*"<@)RP@)&1A=&4L(#(I.PH@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&%T92`]("1T:&ES+3YM87!$
M871E*"1D87DL("=D871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G9&5L:6UI=&5R)R`]/B`D<&%R86US6R=D87E?9&5L
M:6UI=&5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V9O<FUA="<@/3X@)'!A<F%M<ULG9&%Y7V9O<FUA="==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y*3L*("`@("`@
M("`@("`@)'1I;64@/2`D=&AI<RT^;6%P1&%T92@D=&EM92P@)W1I;64G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=D96QI
M;6ET97(G(#T^("1P87)A;7-;)W1I;65?9&5L:6UI=&5R)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<FUA="<@/3X@
M)'!A<F%M<ULG=&EM95]F;W)M870G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&ME>2D["B`@("`@("`@("`@(')E='5R;B`D9&%T
M92`N("<@)R`N("1T:6UE.PH*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!486ME<R!A;&P@;F5C97-S87)Y(&%C=&EO;G,@9F]R('1H92!G:79E
M;B!I;7!O<G0@<W1E<"P@<&%R86UE=&5R<R!A;F0*("`@("`J(&9O<FT@=F%L
M=65S(&%N9"!R971U<FYS('1H92!N97AT(&YE8V5S<V%R>2!S=&5P+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VX@(%1H92!C=7)R96YT
M('-T97`N($]N92!O9B!T:&4@24U03U)47RH@8V]N<W1A;G1S+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;2`@("`@06X@87-S;V-I871I=F4@87)R87D@
M8V]N=&%I;FEN9R!N965D960*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<F%M971E<G,@9F]R('1H92!C=7)R96YT('-T97`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R('1H92!N97AT('-T97`@87,@
M86X@:6YT96=E<B!C;VYS=&%N="!O<B!I;7!O<G1E9`H@("`@("H@("`@("`@
M("`@("`@("`@9&%T82!S970@869T97(@=&AE(&9I;F%L('-T97`N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YE>'13=&5P*"1A8W1I;VXL("1P87)A;2`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@+RH@1FER<W0@<W1E<"X@*B\*("`@("`@
M("!I9B`H:7-?;G5L;"@D86-T:6]N*2D@>PH@("`@("`@("`@("`D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!R971U
M<FX@24U03U)47T9)3$4["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1A
M8W1I;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@("`@("`@("`@
M("`O*B!386YI=&EZ92!U<&QO861E9"!F:6QE+B`J+PH@("`@("`@("`@("`D
M:6UP;W)T7V9O<FUA="`](%5T:6PZ.F=E=$9O<FU$871A*"=I;7!O<G1?9F]R
M;6%T)RD["B`@("`@("`@("`@("1C:&5C:U]U<&QO860@/2!"<F]W<V5R.CIW
M87-&:6QE57!L;V%D960H)VEM<&]R=%]F:6QE)RP@)'!A<F%M6R=F:6QE7W1Y
M<&5S)UU;)&EM<&]R=%]F;W)M871=*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&-H96-K7W5P;&]A9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1C:&5C:U]U<&QO860["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1?1DE,15-;)VEM<&]R=%]F:6QE)UU;)W-I>F4G72`\/2`P
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=F;W)M
M870G72`]("1I;7!O<G1?9F]R;6%T.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92!)35!/4E1?34%04$5$.@H@("`@("`@("`@("`D9&%T84ME
M>7,@/2!5=&EL.CIG971&;W)M1&%T82@G9&%T84ME>7,G+"`G)RD["B`@("`@
M("`@("`@("1A<'!+97ES(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P<$ME>7,G
M+"`G)RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D9&%T84ME>7,I('Q\(&5M
M<'1Y*"1A<'!+97ES*2D@>PH@("`@("`@("`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I
M;B`E<RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)')E9VES=')Y+3YG970H)VYA;64G*2DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1D871A2V5Y<R`](&5X<&QO9&4H(EQT(BP@
M)&1A=&%+97ES*3L*("`@("`@("`@("`@)&%P<$ME>7,@/2!E>'!L;V1E*")<
M="(L("1A<'!+97ES*3L*("`@("`@("`@("`@)&UA<"`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1A<'!+97ES(&%S("1K97D@/3X@)&%P<"D@>PH@("`@("`@("`@("`@
M("`@)&UA<%LD9&%T84ME>7-;)&ME>5U=(#T@)&%P<#L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<&%R86U;)W1I;65?9FEE;&1S)UTI("8F"B`@("`@
M("`@("`@("`@("`@("`@:7-S970H)'!A<F%M6R=T:6UE7V9I96QD<R==6R1A
M<'!=*2D@>PH@("`@("`@("`@("`@("`@("`@("1D871E<ULD9&%T84ME>7-;
M)&ME>5U=6R=T>7!E)UT@/2`D<&%R86U;)W1I;65?9FEE;&1S)UU;)&%P<%T[
M"B`@("`@("`@("`@("`@("`@("`@)&1A=&5S6R1D871A2V5Y<ULD:V5Y75U;
M)W9A;'5E<R==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D:2`]
M(#`["B`@("`@("`@("`@("`@("`@("`@+RH@0G5I;&0@86X@97AA;7!L92!A
M<G)A>2!O9B!U<"!T;R`Q,"!D871E+W1I;64@9FEE;&1S+B`J+PH@("`@("`@
M("`@("`@("`@("`@('=H:6QE("@D:2`\(&-O=6YT*"1?4T534TE/3ELG:6UP
M;W)T7V1A=&$G75LG9&%T82==*2`F)B!C;W5N="@D9&%T97-;)&1A=&%+97ES
M6R1K97E=75LG=F%L=65S)UTI(#P@,3`I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A
M=&$G75LD:5U;)&1A=&%+97ES6R1K97E=72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D871E<ULD9&%T84ME>7-;)&ME>5U=6R=V86QU97,G
M75M=(#T@)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;)&E=6R1D
M871A2V5Y<ULD:V5Y75T["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=M87`G72`]("1M87`["B`@
M("`@("`@("`@(&EF("AC;W5N="@D9&%T97,I(#X@,"D@>PH@("`@("`@("`@
M("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871E<R==(#T@)&1A
M=&5S.PH@("`@("`@("`@("`@("`@<F5T=7)N($E-4$]25%]$051%5$E-13L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FYE>'13
M=&5P*$E-4$]25%]$051!+"`D<&%R86TI.PH*("`@("`@("!C87-E($E-4$]2
M5%]$051%5$E-13H*("`@("`@("!C87-E($E-4$]25%]$051!.@H@("`@("`@
M("`@("!I9B`H)&%C=&EO;B`]/2!)35!/4E1?1$%4151)344I('L*("`@("`@
M("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@G9&5L:6UI=&5R)R`]/B!5=&EL
M.CIG971&;W)M1&%T82@G9&5L:6UI=&5R)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V9O<FUA="<@/3X@571I;#HZ9V5T1F]R;41A=&$H
M)V9O<FUA="<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O
M<F1E<B<@/3X@571I;#HZ9V5T1F]R;41A=&$H)V]R9&5R)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1A>5]D96QI;6ET97(G(#T^(%5T
M:6PZ.F=E=$9O<FU$871A*"=D87E?9&5L:6UI=&5R)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1A>5]F;W)M870G(#T^(%5T:6PZ.F=E
M=$9O<FU$871A*"=D87E?9F]R;6%T)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1I;65?9&5L:6UI=&5R)R`]/B!5=&EL.CIG971&;W)M
M1&%T82@G=&EM95]D96QI;6ET97(G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=&EM95]F;W)M870G(#T^(%5T:6PZ.F=E=$9O<FU$871A
M*"=T:6UE7V9O<FUA="<I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S
M('-T97`N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\J($)U:6QD
M('1H92!R97-U;'0@9&%T82!S970@87,@86X@87-S;V-I871I=F4@87)R87DN
M("HO"B`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@("`@("`@
M9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UT@87,@
M)')O=RD@>PH@("`@("`@("`@("`@("`@)&1A=&%?<F]W(#T@87)R87DH*3L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@)&ME>2`]/B`D=F%L
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG;6%P)UU;)&ME>5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1M87!P961?:V5Y(#T@)%]315-324].6R=I;7!O<G1?9&%T
M82==6R=M87`G75LD:V5Y73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1A8W1I;VX@/3T@24U03U)47T1!5$5424U%("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`A96UP='DH)'9A;"D@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1P87)A;5LG=&EM95]F:65L9',G72D@)B8*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1P87)A;5LG=&EM
M95]F:65L9',G75LD;6%P<&5D7VME>5TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L(#T@)'1H:7,M/FUA<$1A=&4H)'9A;"P@)'!A<F%M
M6R=T:6UE7V9I96QD<R==6R1M87!P961?:V5Y72P@)'!A<F%M<RP@)&ME>2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&%?<F]W6R1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P
M)UU;)&ME>5U=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&1A=&%?
M<F]W.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9&%T83L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=&AE('-E
M<W-I;VX@9&%T82!U<"!A;F0@<F5M;W9E<R!A;GD@=7!L;V%D960@86YD(&UO
M=F5D"B`@("`@*B!F:6QE<RX@268@82!F=6YC=&EO;B!C86QL960@(E]C;&5A
M;G5P*"DB(&5X:7-T<RP@=&AI<R!G971S"B`@("`@*B!C86QL960@=&]O+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($EF(%]C;&5A;G5P*"D@=V%S
M(&-A;&QE9"P@=&AE(')E='5R;B!V86QU92!O9B!T:&ES(&-A;&PN"B`@("`@
M*B`@("`@("`@("`@("`@("!4:&ES('-H;W5L9"!B92!T:&4@=F%L=64@;V8@
M=&AE(&9I<G-T(&EM<&]R="!S=&5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&5A;G5P*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=I
M;7!O<G1?9&%T82==6R=F:6QE7VYA;64G72DI('L*("`@("`@("`@("`@0'5N
M;&EN:R@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I;&5?;F%M92==*3L*
M("`@("`@("!]"B`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==(#T@
M87)R87DH*3L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?8VQE86YU
M<"<I*2!["B`@("`@("`@("`@(')E='5R;B!?8VQE86YU<"@I.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]$871E+G!H<```````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,S,U,S,`,3`U,34T,S$P-C$`,#$W-C$Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@ID
M969I;F4H)TA/4D1%7T1!5$5?4U5.1$%9)RP@("`@,"D["F1E9FEN92@G2$]2
M1$5?1$%415]-3TY$05DG+"`@("`Q*3L*9&5F:6YE*"=(3U)$15]$051%7U15
M15-$05DG+"`@(#(I.PID969I;F4H)TA/4D1%7T1!5$5?5T5$3D531$%9)RP@
M,RD["F1E9FEN92@G2$]21$5?1$%415]42%524T1!62<L("`T*3L*9&5F:6YE
M*"=(3U)$15]$051%7T92241!62<L("`@(#4I.PID969I;F4H)TA/4D1%7T1!
M5$5?4T%455)$05DG+"`@-BD["@ID969I;F4H)TA/4D1%7T1!5$5?34%32U]3
M54Y$05DG+"`@("`Q*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?34].1$%9
M)RP@("`@,BD["F1E9FEN92@G2$]21$5?1$%415]-05-+7U1515-$05DG+"`@
M(#0I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]7141.15-$05DG+"`X*3L*
M9&5F:6YE*"=(3U)$15]$051%7TU!4TM?5$A54E-$05DG+"`Q-BD["F1E9FEN
M92@G2$]21$5?1$%415]-05-+7T92241!62<L("`@,S(I.PID969I;F4H)TA/
M4D1%7T1!5$5?34%32U]305154D1!62<L(#8T*3L*9&5F:6YE*"=(3U)$15]$
M051%7TU!4TM?5T5%2T1!65,G+"`V,BD["F1E9FEN92@G2$]21$5?1$%415]-
M05-+7U=%14M%3D0G+"`@-C4I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]!
M3$Q$05E3)RP@,3(W*3L*"F1E9FEN92@G2$]21$5?1$%415]-05-+7U-%0T].
M1"<L("`@(#$I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]-24Y55$4G+"`@
M("`R*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?2$]54B<L("`@("`@-"D[
M"F1E9FEN92@G2$]21$5?1$%415]-05-+7T1!62<L("`@("`@(#@I.PID969I
M;F4H)TA/4D1%7T1!5$5?34%32U]-3TY42"<L("`@(#$V*3L*9&5F:6YE*"=(
M3U)$15]$051%7TU!4TM?645!4B<L("`@("`S,BD["F1E9FEN92@G2$]21$5?
M1$%415]-05-+7T%,3%!!4E13)RP@-C,I.PH*+RHJ"B`J($AO<F1E($1A=&4@
M=W)A<'!E<B]L;V=I8R!C;&%S<RP@:6YC;'5D:6YG('-O;64@8V%L8W5L871I
M;VX*("H@9G5N8W1I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871E
M+T1A=&4N<&AP+'8@,2XX+C$P+C<@,C`P-B\P-2\P-"`P,SHT,CHS,B!S96QS
M:WD@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?1&%T90H@*B\*8VQA<W,@
M2&]R9&5?1&%T92!["@H@("`@+RHJ"B`@("`@*B!996%R"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D>65A<CL*"B`@("`O
M*BH*("`@("`J($UO;G1H"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B\*("`@('9A<B`D;6]N=&@["@H@("`@+RHJ"B`@("`@*B!$87D*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1M9&%Y
M.PH*("`@("\J*@H@("`@("H@2&]U<@H@("`@("H*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("HO"B`@("!V87(@)&AO=7(@/2`P.PH*("`@("\J*@H@("`@
M("H@36EN=71E"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D;6EN(#T@,#L*"B`@("`O*BH*("`@("`J(%-E8V]N9`H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)'-E8R`]
M(#`["@H@("`@+RHJ"B`@("`@*B!"=6EL9"!A(&YE=R!D871E(&]B:F5C="X@
M268@)&1A=&4@8V]N=&%I;G,@9&%T92!P87)T<RP@=7-E('1H96T*("`@("`J
M('1O(&EN:71I86QI>F4@=&AE(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?1&%T92@D9&%T92`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1D871E*2!\?"!I<U]O8FIE8W0H)&1A=&4I*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1D871E(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1K97DL(&%R<F%Y*"=Y96%R)RP@
M)VUO;G1H)RP@)VUD87DG+"`G:&]U<B<L("=M:6XG+"`G<V5C)RDI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`H:6YT*21V86P["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I
M9B`H(6ES7VYU;&PH)&1A=&4I*2!["B`@("`@("`@("`@("\O($UA=&-H(%E9
M65DM34TM1$0@2$@Z34TZ4U,@86YD(%E965E-341$2$A-35-3+@H@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+RA<9'LT?2DM/RA<9'LR?2DM/RA<9'LR
M?2D@/RA<9'LR?2DZ/RA<9'LR?2DZ/RA<9'LR?2DO)RP@)&1A=&4L("1P87)T
M<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YY96%R(#T@*&EN="DD<&%R
M='-;,5T["B`@("`@("`@("`@("`@("`D=&AI<RT^;6]N=&@@/2`H:6YT*21P
M87)T<ULR73L*("`@("`@("`@("`@("`@("1T:&ES+3YM9&%Y(#T@*&EN="DD
M<&%R='-;,UT["B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`]("AI;G0I
M)'!A<G1S6S1=.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUI;B`]("AI;G0I
M)'!A<G1S6S5=.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E8R`]("AI;G0I
M)'!A<G1S6S9=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@5')Y(&%S(&$@=&EM97-T86UP+@H@("`@("`@("`@("`@("`@)'!A
M<G1S(#T@0&=E=&1A=&4H)&1A=&4I.PH@("`@("`@("`@("`@("`@:68@*"1P
M87)T<RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YY96%R(#T@)'!A
M<G1S6R=Y96%R)UT["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUO;G1H
M(#T@)'!A<G1S6R=M;VXG73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;61A>2`]("1P87)T<ULG;61A>2==.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YH;W5R(#T@)'!A<G1S6R=H;W5R<R==.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YM:6X@/2`D<&%R='-;)VUI;G5T97,G73L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5C(#T@)'!A<G1S6R=S96-O;F1S)UT["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('5N:7@@=&EM97-T86UP(')E
M<')E<V5N=&%T:6]N(&]F('1H:7,@9&%T92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@($$@=6YI>"!T:6UE<W1A;7`N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('1I;65S=&%M<"@I"B`@("!["B`@("`@("`@<F5T=7)N($!M:W1I
M;64H)'1H:7,M/FAO=7(L("1T:&ES+3YM:6XL("1T:&ES+3YS96,L("1T:&ES
M+3YM;VYT:"P@)'1H:7,M/FUD87DL("1T:&ES+3YY96%R*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@=6YI>"!T:6UE<W1A;7`@<F5P<F5S
M96YT871I;VX@;V8@=&AI<R!D871E+"`Q,CHP,&%M+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@02!U;FEX('1I;65S=&%M<"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&%T97-T86UP*"D*("`@('L*("`@("`@("!R971U<FX@
M0&UK=&EM92@P+"`P+"`P+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YM9&%Y+"`D
M=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<W1A=&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES3&5A<%EE87(H)'EE87(I"B`@("!["B`@
M("`@("`@:68@*'-T<FQE;B@D>65A<BD@(3T@-"!\?"!P<F5G7VUA=&-H*"<O
M7$0O)RP@)'EE87(I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`H*"1Y96%R("4@-"`]/2`P("8F("1Y
M96%R("4@,3`P("$](#`I('Q\("1Y96%R("4@-#`P(#T](#`I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&%Y(&]F('1H92!Y96%R("@Q
M+3,V-BD@=&AA="!C;W)R97-P;VYD<R!T;R!T:&4*("`@("`J(&9I<G-T(&1A
M>2!O9B!T:&4@9VEV96X@=V5E:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D=V5E:R`@5&AE('=E96L@;V8@=&AE('EE87(@=&\@9FEN9"!T:&4@
M9FER<W0@9&%Y(&]F+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'EE87(@(%1H
M92!Y96%R('1O(&-A;&-U;&%T92!F;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@9&%Y(&]F('1H92!Y96%R(&]F('1H92!F:7)S="!D
M87D@;V8@=&AE(&=I=F5N('=E96LN"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I
M<G-T1&%Y3V97965K*"1W965K+"`D>65A<BD*("`@('L*("`@("`@("`D:F%N
M,2`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G>65A<B<@/3X@)'EE87(L("=M
M;VYT:"<@/3X@,2P@)VUD87DG(#T^(#$I*3L*("`@("`@("`D<W1A<G0@/2`D
M:F%N,2T^9&%Y3V97965K*"D["B`@("`@("`@:68@*"1S=&%R="`^($A/4D1%
M7T1!5$5?5$A54E-$05DI('L*("`@("`@("`@("`@)'-T87)T("T](#<["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`H*"1W965K("H@-RD@+2`H-R`K("1S
M=&%R="DI("L@,3L*("`@('T*"B`@("`O*BH*("`@("`J($!S=&%T:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BD*
M("`@('L*("`@("`@("!I9B`H)&UO;G1H(#T](#(I('L*("`@("`@("`@("`@
M:68@*$AO<F1E7T1A=&4Z.FES3&5A<%EE87(H)'EE87(I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@,CD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@,C@["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H)&UO;G1H(#T](#0@?'P@)&UO;G1H(#T](#8@?'P@)&UO;G1H
M(#T](#D@?'P@)&UO;G1H(#T](#$Q*2!["B`@("`@("`@("`@(')E='5R;B`S
M,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,S$["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D87D@
M;V8@=&AE('=E96L@*#`@/2!3=6YD87DL(#8@/2!3871U<F1A>2D@;V8@=&AI
M<PH@("`@("H@;V)J96-T)W,@9&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!D87D@;V8@=&AE('=E96LN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1A>4]F5V5E:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM
M;VYT:"`^(#(I('L*("`@("`@("`@("`@)&UO;G1H(#T@)'1H:7,M/FUO;G1H
M("T@,CL*("`@("`@("`@("`@)'EE87(@/2`D=&AI<RT^>65A<CL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;6]N=&@@/2`D=&AI<RT^;6]N=&@@
M*R`Q,#L*("`@("`@("`@("`@)'EE87(@/2`D=&AI<RT^>65A<B`M(#$["B`@
M("`@("`@?0H*("`@("`@("`D9&%Y(#T@*&9L;V]R*"@Q,R`J("1M;VYT:"`M
M(#$I("\@-2D@*PH@("`@("`@("`@("`@("`@)'1H:7,M/FUD87D@*R`H)'EE
M87(@)2`Q,#`I("L*("`@("`@("`@("`@("`@(&9L;V]R*"@D>65A<B`E(#$P
M,"D@+R`T*2`K"B`@("`@("`@("`@("`@("!F;&]O<B@H)'EE87(@+R`Q,#`I
M("\@-"D@+2`R("H*("`@("`@("`@("`@("`@(&9L;V]R*"1Y96%R("\@,3`P
M*2`K(#<W*3L*"B`@("`@("`@<F5T=7)N("AI;G0I*"1D87D@+2`W("H@9FQO
M;W(H)&1A>2`O(#<I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&1A>2!N=6UB97(@;V8@=&AE('EE87(@*#`@=&\@,S8U+S,V-BDN"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@9&%Y(&]F('1H92!Y
M96%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D87E/9EEE87(H*0H@("`@>PH@
M("`@("`@("1M;VYT:%1O=&%L<R`](&%R<F%Y*#`L(#,Q+"`U.2P@.3`L(#$R
M,"P@,34Q+"`Q.#$L(#(Q,BP@,C0S+"`R-S,L(#,P-"P@,S,T*3L*("`@("`@
M("`D9&%Y3V9996%R(#T@)'1H:7,M/FUD87D@*R`D;6]N=&A4;W1A;'-;)'1H
M:7,M/FUO;G1H("T@,5T["B`@("`@("`@:68@*$AO<F1E7T1A=&4Z.FES3&5A
M<%EE87(H)'1H:7,M/GEE87(I("8F("1T:&ES+3YM;VYT:"`^(#(I('L*("`@
M("`@("`@("`@)&1A>4]F665A<BLK.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1D87E/9EEE87(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('=E96L@;V8@=&AE('EE87(L(&9I<G-T($UO;F1A>2!I<R!F:7)S="!D87D@
M;V8@9FER<W0*("`@("`J('=E96LN"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@=V5E:R!N=6UB97(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=E96M/9EEE87(H*0H@("`@>PH@("`@("`@(')E='5R;B!D871E*"=7)RP@
M)'1H:7,M/G1I;65S=&%M<"@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@;G5M8F5R(&]F('=E96MS(&EN('1H92!G:79E;B!Y96%R("@U
M,B!O<B`U,RDN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'EE87(@
M(%1H92!Y96%R('1O(&-O=6YT('1H92!N=6UB97(@;V8@=V5E:W,@:6XN"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("1N=6U7965K<R`@("`@(%1H
M92!N=6UB97(@;V8@=V5E:W,@:6X@)'EE87(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('=E96MS26Y996%R*"1Y96%R*0H@("`@>PH@("`@("`@("\O($9I;F0@
M=&AE(&QA<W0@5&AU<G-D87D@;V8@=&AE('EE87(N"B`@("`@("`@)&1A>2`]
M(#,Q.PH@("`@("`@('=H:6QE("AD871E*"=W)RP@;6MT:6UE*#`L(#`L(#`L
M(#$R+"`D9&%Y+"`D>65A<BDI("$]($A/4D1%7T1!5$5?5$A54E-$05DI('L*
M("`@("`@("`@("`@)&1A>2TM.PH@("`@("`@('T*"B`@("`@("`@)&1A=&4@
M/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)WEE87(G(#T^("1Y96%R+"`G;6]N
M=&@G(#T^(#$R+"`G;61A>2<@/3X@)&1A>2DI.PH@("`@("`@(')E='5R;B`D
M9&%T92T^=V5E:T]F665A<B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!D871E(&]F('1H:7,@;V)J96-T('1O('1H92`D;G1H('=E96MD87D@
M;V8@)'=E96MD87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=E
M96MD87D@(%1H92!D87D@;V8@=&AE('=E96L@*#`@/2!3=6YD87DL(&5T8RDN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;G1H("`@("`@5&AE("1N=&@@)'=E
M96MD87D@=&\@<V5T('1O("AD969A=6QT<R!T;R`Q*2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T3G1H5V5E:V1A>2@D=V5E:V1A>2P@)&YT:"`](#$I"B`@
M("!["B`@("`@("`@:68@*"1W965K9&%Y(#P@2$]21$5?1$%415]354Y$05D@
M?'P@)'=E96MD87D@/B!(3U)$15]$051%7U-!5%521$%9*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YM
M9&%Y(#T@,3L*("`@("`@("`D9FER<W0@/2`D=&AI<RT^9&%Y3V97965K*"D[
M"B`@("`@("`@:68@*"1W965K9&%Y(#P@)&9I<G-T*2!["B`@("`@("`@("`@
M("1T:&ES+3YM9&%Y(#T@."`K("1W965K9&%Y("T@)&9I<G-T.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YM9&%Y(#T@)'=E96MD87D@
M+2`D9FER<W0@*R`Q.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;61A>2`K
M/2`W("H@)&YT:"`M(#<["@H@("`@("`@("1T:&ES+3YC;W)R96-T*"D["@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&1U;7`H
M)'!R969I>"`]("<G*0H@("`@>PH@("`@("`@(&5C:&\@*"1P<F5F:7@@/R`D
M<')E9FEX("X@)SH@)R`Z("<G*2`N("1T:&ES+3YY96%R("X@)RTG("X@)'1H
M:7,M/FUO;G1H("X@)RTG("X@)'1H:7,M/FUD87D@+B`B/&)R("\^7&XB.PH@
M("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&1A=&4@8W5R<F5N=&QY(')E
M<')E<V5N=&5D(&)Y('1H:7,@;V)J96-T(&$@=F%L:60@9&%T93\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%9A;&ED:71Y+"!C;W5N=&EN9R!L
M96%P('EE87)S+"!E=&,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES5F%L:60H
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^>65A<B`\(#`@?'P@)'1H:7,M
M/GEE87(@/B`Y.3DY*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(&-H96-K9&%T92@D=&AI<RT^;6]N=&@L
M("1T:&ES+3YM9&%Y+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;W)R96-T(&%N>2!O=F5R+2!O<B!U;F1E<F9L;W=S(&EN(&%N>2!O
M9B!T:&4@9&%T92=S(&UE;6)E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&UA<VL@(%=E(&UA>2!N;W0@=V%N="!T;R!C;W)R96-T('-O;64@
M;W9E<F9L;W=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W)R96-T*"1M87-K
M(#T@2$]21$5?1$%415]-05-+7T%,3%!!4E13*0H@("`@>PH@("`@("`@(&EF
M("@D;6%S:R`F($A/4D1%7T1!5$5?34%32U]314-/3D0I('L*("`@("`@("`@
M("`@=VAI;&4@*"1T:&ES+3YS96,@/"`P*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;6EN+2T["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5C("L](#8P
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^<V5C
M(#X@-3DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YM:6XK*SL*("`@("`@
M("`@("`@("`@("1T:&ES+3YS96,@+3T@-C`["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D;6%S:R`F($A/4D1%7T1!5$5?34%32U]-
M24Y55$4I('L*("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3YM:6X@/"`P*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<BTM.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/FUI;B`K/2`V,#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!W:&EL92`H)'1H:7,M/FUI;B`^(#4Y*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^:&]U<BLK.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUI;B`M/2`V
M,#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1M87-K
M("8@2$]21$5?1$%415]-05-+7TA/55(I('L*("`@("`@("`@("`@=VAI;&4@
M*"1T:&ES+3YH;W5R(#P@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FUD
M87DM+3L*("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R("L](#(T.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^:&]U<B`^(#(S
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;61A>2LK.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/FAO=7(@+3T@,C0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@D;6%S:R`F($A/4D1%7T1!5$5?34%32U]-3TY4
M2"D@>PH@("`@("`@("`@("!W:&EL92`H)'1H:7,M/FUO;G1H(#X@,3(I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YY96%R*RL["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;6]N=&@@+3T@,3(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@=VAI;&4@*"1T:&ES+3YM;VYT:"`\(#$I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YY96%R+2T["B`@("`@("`@("`@("`@("`D=&AI<RT^;6]N=&@@
M*ST@,3(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D
M;6%S:R`F($A/4D1%7T1!5$5?34%32U]$05DI('L*("`@("`@("`@("`@=VAI
M;&4@*"1T:&ES+3YM9&%Y(#X@2&]R9&5?1&%T93HZ9&%Y<TEN36]N=&@H)'1H
M:7,M/FUO;G1H+"`D=&AI<RT^>65A<BDI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YM9&%Y("T]($AO<F1E7T1A=&4Z.F1A>7-);DUO;G1H*"1T:&ES+3YM
M;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUO
M;G1H*RL["B`@("`@("`@("`@("`@("`D=&AI<RT^8V]R<F5C="A(3U)$15]$
M051%7TU!4TM?34].5$@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H
M:6QE("@D=&AI<RT^;61A>2`\(#$I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YM;VYT:"TM.PH@("`@("`@("`@("`@("`@)'1H:7,M/F-O<G)E8W0H2$]2
M1$5?1$%415]-05-+7TU/3E1(*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM
M9&%Y("L]($AO<F1E7T1A=&4Z.F1A>7-);DUO;G1H*"1T:&ES+3YM;VYT:"P@
M)'1H:7,M/GEE87(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0V]M<&%R92!T:&ES(&1A=&4@=&\@86YO=&AE<B!D
M871E(&]B:F5C="!T;R!S964@=VAI8V@@;VYE(&ES"B`@("`@*B!G<F5A=&5R
M("AL871E<BDN($%S<W5M97,@=&AA="!T:&4@9&%T97,@87)E(&EN('1H92!S
M86UE"B`@("`@*B!T:6UE>F]N92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&1A=&4@(%1H92!D871E('1O(&-O;7!A<F4@=&\N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("`]/2`@,"!I9B!T:&4@9&%T97,@87)E(&5Q
M=6%L"B`@("`@*B`@("`@("`@("`@("`@("`@(#X]("`Q(&EF('1H:7,@9&%T
M92!I<R!G<F5A=&5R("AL871E<BD*("`@("`J("`@("`@("`@("`@("`@("`@
M/#T@+3$@:68@=&AE(&]T:&5R(&1A=&4@:7,@9W)E871E<B`H;&%T97(I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;7!A<F5$871E*"1D871E*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?82@D9&%T92P@)TAO<F1E7T1A=&4G*2D@>PH@("`@
M("`@("`@("`D9&%T92`]("9N97<@2&]R9&5?1&%T92@D9&%T92D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/GEE87(@(3T@)&1A=&4M/GEE87(I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YY96%R("T@)&1A=&4M/GEE
M87(["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YM;VYT:"`A/2`D9&%T92T^
M;6]N=&@I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM;VYT:"`M("1D
M871E+3YM;VYT:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUD87D@+2`D9&%T92T^;61A>3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E('1H:7,@=&\@86YO=&AE<B!D871E
M(&]B:F5C="!B>2!T:6UE+"!T;R!S964@=VAI8V@@;VYE"B`@("`@*B!I<R!G
M<F5A=&5R("AL871E<BDN($%S<W5M97,@=&AA="!T:&4@9&%T97,@87)E(&EN
M('1H92!S86UE"B`@("`@*B!T:6UE>F]N92X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&1A=&4@(%1H92!D871E('1O(&-O;7!A<F4@=&\N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`]/2`@,"!I9B!T:&4@9&%T97,@
M87)E(&5Q=6%L"B`@("`@*B`@("`@("`@("`@("`@("`@(#X]("`Q(&EF('1H
M:7,@9&%T92!I<R!G<F5A=&5R("AL871E<BD*("`@("`J("`@("`@("`@("`@
M("`@("`@/#T@+3$@:68@=&AE(&]T:&5R(&1A=&4@:7,@9W)E871E<B`H;&%T
M97(I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;7!A<F54:6UE*"1D871E*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?82@D9&%T92P@)TAO<F1E7T1A=&4G*2D@
M>PH@("`@("`@("`@("`D9&%T92`]("9N97<@2&]R9&5?1&%T92@D9&%T92D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/FAO=7(@(3T@)&1A=&4M
M/FAO=7(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YH;W5R("T@)&1A
M=&4M/FAO=7(["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YM:6X@(3T@)&1A
M=&4M/FUI;BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUI;B`M("1D
M871E+3YM:6X["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YS96,@+2`D9&%T92T^<V5C.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;7!A<F4@=&AI<R!T;R!A;F]T:&5R(&1A=&4@;V)J
M96-T+"!I;F-L=61I;F<@=&EM97,L('1O('-E90H@("`@("H@=VAI8V@@;VYE
M(&ES(&=R96%T97(@*&QA=&5R*2X@07-S=6UE<R!T:&%T('1H92!D871E<R!A
M<F4@:6X@=&AE"B`@("`@*B!S86UE('1I;65Z;VYE+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D9&%T92`@5&AE(&1A=&4@=&\@8V]M<&%R92!T;RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#T]("`P(&EF('1H92!D
M871E<R!A<F4@97%U86P*("`@("`J("`@("`@("`@("`@("`@("`@/CT@(#$@
M:68@=&AI<R!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@("H@("`@("`@
M("`@("`@("`@("`\/2`M,2!I9B!T:&4@;W1H97(@9&%T92!I<R!G<F5A=&5R
M("AL871E<BD*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<&%R941A=&54:6UE
M*"1D871E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9&%T92P@)TAO<F1E
M7T1A=&4G*2D@>PH@("`@("`@("`@("`D9&%T92`]("9N97<@2&]R9&5?1&%T
M92@D9&%T92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1I9F8@/2`D=&AI
M<RT^8V]M<&%R941A=&4H)&1A=&4I*2!["B`@("`@("`@("`@(')E='5R;B`D
M9&EF9CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F-O;7!A<F54:6UE*"1D871E*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE('1I;64@;V9F<V5T(&9O<B!L;V-A;"!T:6UE
M('IO;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-O;&]N("!0
M;&%C92!A(&-O;&]N(&)E='=E96X@:&]U<G,@86YD(&UI;G5T97,_"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1I;65Z;VYE(&]F9G-E="!A<R!A
M('-T<FEN9R!I;B!T:&4@9F]R;6%T("M(2#I-32X*("`@("`J+PH@("`@9G5N
M8W1I;VX@='I/9F9S970H)&-O;&]N(#T@=')U92D*("`@('L*("`@("`@("`D
M<V5C<R`](&1A=&4H)UHG+"`D=&AI<RT^=&EM97-T86UP*"DI.PH*("`@("`@
M("!I9B`H)'-E8W,@/"`P*2!["B`@("`@("`@("`@("1S:6=N(#T@)RTG.PH@
M("`@("`@("`@("`D<V5C<R`]("TD<V5C<SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<VEG;B`]("<K)SL*("`@("`@("!]"B`@("`@("`@)&-O
M;&]N(#T@)&-O;&]N(#\@)SHG(#H@)R<["B`@("`@("`@)&UI;G,@/2!I;G1V
M86PH*"1S96-S("L@,S`I("\@-C`I.PH@("`@("`@(')E='5R;B!S<')I;G1F
M*"<E<R4P,F0E<R4P,F0G+`H@("`@("`@("`@("`@("`@("`@("`@("1S:6=N
M+"`D;6EN<R`O(#8P+"`D8V]L;VXL("1M:6YS("4@-C`I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1F]R;6%T('1I;64@:6X@25-/+3@V,#$@9F]R;6%T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$871E(&%N9"!T:6UE(&EN
M($E33RTX-C`Q(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-O.#8P
M,41A=&54:6UE*"D*("`@('L*("`@("`@("`D='IO9F8@/2`D=&AI<RT^='I/
M9F9S970H*3L*("`@("`@("`D9&%T92`]("1T:&ES+3YY96%R("X@)RTG("X@
M)'1H:7,M/FUO;G1H("X@)RTG("X@)'1H:7,M/FUD87D["B`@("`@("`@)'1I
M;64@/2`D=&AI<RT^:&]U<B`N("<Z)R`N("1T:&ES+3YM:6X@+B`G.B<@+B`D
M=&AI<RT^<V5C.PH*("`@("`@("!R971U<FX@)&1A=&4@+B`G5"<@+B`D=&EM
M92`N("1T>F]F9CL*("`@('T*"B`@("`O*BH*("`@("`J($9O<FUA="!T:6UE
M(&EN(%)&0R`R.#(R(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@1&%T92!A;F0@=&EM92!I;B!21D,@,C@R,B!F;W)M870N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')F8S(X,C)$871E5&EM92@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&1A=&4H)T0L(&H@32!9($@Z:3IS("<L("1T:&ES+3YT:6UE
M<W1A;7`H*2D@+B`D=&AI<RT^='I/9F9S970H9F%L<V4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1F]R;6%T('1I;64@:6X@4D9#(#,S,SD@9F]R;6%T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$871E(&%N9"!T:6UE(&EN
M(%)&0R`S,S,Y(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F9C,S,S
M.41A=&54:6UE*"D*("`@('L*("`@("`@("!R971U<FX@9&%T92@G62UM+61<
M5$@Z:2<L("1T:&ES+3YT:6UE<W1A;7`H*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&;W)M870@=&EM92!T;R!S=&%N9&%R9"`G8W1I;64G(&9O<FUA="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1&%T92!A;F0@=&EM92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8U1I;64H)'1I;64@/2!F86QS92D*("`@
M('L*("`@("`@("!R971U<FX@9&%T92@G1"!-(&H@2#II.G,@62<L("1T:&ES
M+3YT:6UE<W1A;7`H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M870@
M9&%T92!A;F0@=&EM92!U<VEN9R!S=')F=&EM92@I(&9O<FUA="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@<W1R9G1I;64H*2!F;W)M871T960@
M9&%T92!A;F0@=&EM92X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R9G1I;64H
M)&9O<FUA="D*("`@('L*("`@("`@("!R971U<FX@<W1R9G1I;64H)&9O<FUA
M="P@)'1H:7,M/G1I;65S=&%M<"@I*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O4V5C<F5T+G!H<```````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$S,C(P`#$P-3$U-#,Q,#8Q`#`R,#$U,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE(%-E8W)E=#HZ(&-L87-S('!R;W9I9&5S(&%N($%022!F;W(@96YC
M<GEP=&EN9R!A;F0@9&5C<GEP=&EN9PH@*B!S;6%L;"!P:65C97,@;V8@9&%T
M82!W:71H('1H92!U<V4@;V8@82!S:&%R960@:V5Y+@H@*@H@*B!4:&4@4V5C
M<F5T.CH@9G5N8W1I;VYS('5S92!T:&4@2&]R9&4@0VEP:&5R.CH@8VQA<W,@
M:68@;6-R>7!T(&ES(&YO=`H@*B!A=F%I;&%B;&4N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U-E8W)E="]396-R970N<&AP+'8@,2XT-2XQ,"XW(#(P,#8O
M,#,O,#(@,#4Z,C4Z,3`@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]396-R970*("HO"F-L87-S(%-E8W)E="!["@H@("`@+RHJ
M"B`@("`@*B!486ME(&$@<VUA;&P@<&EE8V4@;V8@9&%T82!A;F0@96YC<GEP
M="!I="!W:71H(&$@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ME>2`@("`@(%1H92!K97D@=&\@=7-E(&9O<B!E;F-R>7!T:6]N+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@5&AE('!L86EN=&5X="!M97-S
M86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8VEP:&5R
M=&5X="!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D:V5Y
M+"`D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N
M17AI<W1S*"=M8W)Y<'0G*2D@>PH@("`@("`@("`@("`D=&0@/2!`;6-R>7!T
M7VUO9'5L95]O<&5N*$U#4EE05%]'3U-4+"`G)RP@34-265!47TU/1$5?14-"
M+"`G)RD["B`@("`@("`@("`@(&EF("@D=&0I('L*("`@("`@("`@("`@("`@
M("1I=B`]($!M8W)Y<'1?8W)E871E7VEV*&UC<GEP=%]E;F-?9V5T7VEV7W-I
M>F4H)'1D*2P@34-265!47U)!3D0I.PH@("`@("`@("`@("`@("`@0&UC<GEP
M=%]G96YE<FEC7VEN:70H)'1D+"`D:V5Y+"`D:78I.PH@("`@("`@("`@("`@
M("`@)&5N8W)Y<'1E9%]D871A(#T@0&UC<GEP=%]G96YE<FEC*"1T9"P@)&UE
M<W-A9V4I.PH@("`@("`@("`@("`@("`@0&UC<GEP=%]G96YE<FEC7V1E:6YI
M="@D=&0I.PH*("`@("`@("`@("`@("`@(')E='5R;B`D96YC<GEP=&5D7V1A
M=&$["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('-T871I8R`D
M8VEP:&5R0V%C:&4@/2!A<G)A>2@I.PH@("`@("`@("1C86-H94ED>"`](&UD
M-2@D:V5Y*3L*"B`@("`@("`@:68@*"%I<W-E="@D8VEP:&5R0V%C:&5;)&-A
M8VAE261X72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]#
M:7!H97(N<&AP)SL*"B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C:&5)
M9'A=(#T@)DAO<F1E7T-I<&AE<CHZ9F%C=&]R>2@G8FQO=V9I<V@G*3L*("`@
M("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/G-E=$)L;V-K36]D
M92@G;V9B-C0G*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED
M>%TM/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8VEP:&5R0V%C:&5;)&-A8VAE261X72T^96YC<GEP="@D;65S<V%G92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@;65S<V%G92!E;F-R>7!T
M960@=VET:"!396-R970Z.G=R:71E*"DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:V5Y("`@("`@5&AE(&ME>2!T;R!U<V4@9F]R(&1E8W)Y<'1I
M;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!4:&4@8VEP:&5R
M=&5X="!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<&QA:6YT97AT(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M860H)&ME>2P@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@:68@*%5T:6PZ
M.F5X=&5N<VEO;D5X:7-T<R@G;6-R>7!T)RDI('L*("`@("`@("`@("`@)'1D
M(#T@0&UC<GEP=%]M;V1U;&5?;W!E;BA-0U)94%1?1T]35"P@)R<L($U#4EE0
M5%]-3T1%7T5#0BP@)R<I.PH@("`@("`@("`@("!I9B`H)'1D*2!["B`@("`@
M("`@("`@("`@("`D:78@/2!`;6-R>7!T7V-R96%T95]I=BAM8W)Y<'1?96YC
M7V=E=%]I=E]S:7IE*"1T9"DL($U#4EE05%]204Y$*3L*("`@("`@("`@("`@
M("`@($!M8W)Y<'1?9V5N97)I8U]I;FET*"1T9"P@)&ME>2P@)&EV*3L*("`@
M("`@("`@("`@("`@("1D96-R>7!T961?9&%T82`]($!M9&5C<GEP=%]G96YE
M<FEC*"1T9"P@)&-I<&AE<G1E>'0I.PH@("`@("`@("`@("`@("`@0&UC<GEP
M=%]G96YE<FEC7V1E:6YI="@D=&0I.PH*("`@("`@("`@("`@("`@("\O(%-T
M<FEP('!A9&1I;F<@8VAA<F%C=&5R<RX*("`@("`@("`@("`@("`@(')E='5R
M;B!R=')I;2@D9&5C<GEP=&5D7V1A=&$L(")<,"(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!S=&%T:6,@)&-I<&AE<D-A8VAE.PH@("`@
M("`@("1C86-H94ED>"`](&UD-2@D:V5Y*3L*"B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D8VEP:&5R0V%C:&4I('Q\("%I<W-E="@D8VEP:&5R0V%C:&5;)&-A
M8VAE261X72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]#
M:7!H97(N<&AP)SL*"B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C:&5)
M9'A=(#T@)DAO<F1E7T-I<&AE<CHZ9F%C=&]R>2@G8FQO=V9I<V@G*3L*("`@
M("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/G-E=$)L;V-K36]D
M92@G;V9B-C0G*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED
M>%TM/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8VEP:&5R0V%C:&5;)&-A8VAE261X72T^9&5C<GEP="@D8VEP:&5R=&5X="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!A('-E8W)E="!K97D@
M*&9O<B!E;F-R>7!T:6]N*2P@96ET:&5R('5S:6YG(&$@<F%N9&]M"B`@("`@
M*B!M9#4@<W1R:6YG(&%N9"!S=&]R:6YG(&ET(&EN(&$@8V]O:VEE(&EF('1H
M92!U<V5R(&AA<R!C;V]K:65S"B`@("`@*B!E;F%B;&5D+"!O<B!M=6YG:6YG
M('-O;64@:VYO=VX@=F%L=65S(&EF('1H97D@9&]N)W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:V5Y;F%M92`@5&AE(&YA;64@;V8@=&AE(&ME
M>2!T;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S
M96-R970@:V5Y('1H870@:&%S(&)E96X@9V5N97)A=&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971+97DH)&ME>6YA;64@/2`G9V5N97)I8R<I"B`@("![
M"B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D=&EM96]U="`]("1C
M;VYF6R=S97-S:6]N)UU;)W1I;65O=70G72`_('1I;64H*2`K("1C;VYF6R=S
M97-S:6]N)UU;)W1I;65O=70G72`Z(#`["@H@("`@("`@(&EF("AI<W-E="@D
M7T-/3TM)15LD8V]N9ELG<V5S<VEO;B==6R=N86UE)UU=*2D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)%]#3T]+245;)&ME>6YA;64@+B`G7VME>2==*2D@
M>PH@("`@("`@("`@("`@("`@)&ME>2`]("1?0T]/2TE%6R1K97EN86UE("X@
M)U]K97DG73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1K97D@/2!M9#4H;71?<F%N9"@I*3L*("`@("`@("`@("`@("`@("1?0T]/
M2TE%6R1K97EN86UE("X@)U]K97DG72`]("1K97D["B`@("`@("`@("`@("`@
M("!`<V5T8V]O:VEE*"1K97EN86UE("X@)U]K97DG+"`D:V5Y+"`D=&EM96]U
M="P@)&-O;F9;)V-O;VMI92==6R=P871H)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTL("1C;VYF6R=U
M<V5?<W-L)UT@/3T@,2`_(#$@.B`P*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1K97D@/2!S97-S:6]N7VED*"D["B`@
M("`@("`@("`@($!S971C;V]K:64H)&ME>6YA;64@+B`G7VME>2<L("1K97DL
M("1T:6UE;W5T+"`D8V]N9ELG8V]O:VEE)UU;)W!A=&@G72P*("`@("`@("`@
M("`@("`@("`@("`@("`D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==+"`D8V]N
M9ELG=7-E7W-S;"==(#T](#$@/R`Q(#H@,"D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&ME>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A
M('-E8W)E="!K97DL(&5I=&AE<B!F<F]M(&$@8V]O:VEE+"!O<B!I9B!T:&4@
M8V]O:VEE"B`@("`@*B!I<VXG="!T:&5R92P@87-S=6UE('=E(&%R92!U<VEN
M9R!A(&UU;F=E9"!V97)S:6]N(&]F(&$@:VYO=VX*("`@("`J(&)A<V4@=F%L
M=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y;F%M92`@5&AE
M(&YA;64@;V8@=&AE(&ME>2!T;R!G970N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!S96-R970@:V5Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971+97DH)&ME>6YA;64@/2`G9V5N97)I8R<I"B`@("!["B`@("`@("`@
M<W1A=&EC("1K97EC86-H92`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A:7-S
M970H)&ME>6-A8VAE6R1K97EN86UE72DI('L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72DI('L*("`@("`@("`@
M("`@("`@("1K97EC86-H95LD:V5Y;F%M95T@/2`D7T-/3TM)15LD:V5Y;F%M
M92`N("=?:V5Y)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@("`@("`@("`D:V5Y8V%C:&5;
M)&ME>6YA;65=(#T@<V5S<VEO;E]I9"@I.PH@("`@("`@("`@("`@("`@0'-E
M=&-O;VMI92@D:V5Y;F%M92`N("=?:V5Y)RP@)&ME>6-A8VAE6R1K97EN86UE
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)W-E<W-I;VXG
M75LG=&EM96]U="==(#\@=&EM92@I("L@)&-O;F9;)W-E<W-I;VXG75LG=&EM
M96]U="==(#H@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;
M)V-O;VMI92==6R=P871H)UTL("1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTL
M("1C;VYF6R=U<V5?<W-L)UT@/3T@,2`_(#$@.B`P*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1K97EC86-H95LD:V5Y;F%M
M95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@82!S96-R970@:V5Y
M(&5N=')Y(&9R;VT@=&AE(&-U<G)E;G0@8V]O:VEE+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>6YA;64@(%1H92!N86UE(&]F('1H92!K97D@
M=&\@8VQE87(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF(&ME>2!E>&ES=&5D+"!F86QS92!I9B!N;W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-L96%R2V5Y*"1K97EN86UE(#T@)V=E;F5R:6,G*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D7T-/3TM)15LD1TQ/0D%,4ULG8V]N9B==6R=S
M97-S:6]N)UU;)VYA;64G75TI("8F"B`@("`@("`@("`@(&ES<V5T*"1?0T]/
M2TE%6R1K97EN86UE("X@)U]K97DG72DI('L*("`@("`@("`@("`@=6YS970H
M)%]#3T]+245;)&ME>6YA;64@+B`G7VME>2==*3L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]#3$DN<&AP````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,C,T,C0`,3`U,34T,S$P-C$`,#$W,S0Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!(
M;W)D95]#3$DZ.B!!4$D@9F]R(&)A<VEC(&-O;6UA;F0M;&EN92!F=6YC=&EO
M;F%L:71Y+V-H96-K<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`L=B`Q+C0R+C8N,3,@,C`P-B\P-2\S,2`Q,CHS,3HP,"!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#3$D*("HO"F-L
M87-S($AO<F1E7T-,22!["@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@<G5N;FEN
M9R!O;B!A(&-O;G-O;&4_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7V-O;G-O;&4["@H@("`@+RHJ"B`@("`@*B!4:&4@
M;F5W;&EN92!S=')I;F<@=&\@=7-E+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7VYE=VQI;F4["@H@("`@+RHJ"B`@("`@
M*B!4:&4@:6YD96YT('-T<FEN9R!T;R!U<V4N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6YD96YT.PH*("`@("\J*@H@
M("`@("H@5&AE('-T<FEN9R!T;R!M87)K('1H92!B96=I;FYI;F<@;V8@8F]L
M9"!T97AT+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7V)O;&1?<W1A<G0@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!S
M=')I;F<@=&\@;6%R:R!T:&4@96YD(&]F(&)O;&0@=&5X="X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]B;VQD7V5N9"`]
M("<G.PH*("`@("\J*@H@("`@("H@5&AE('-T<FEN9W,@=&\@;6%R:R!T:&4@
M8F5G:6YN:6YG(&]F(&-O;&]U<F5D('1E>'0N"B`@("`@*B\*("`@('9A<B`D
M7W)E9%]S=&%R="`@("`]("<G.PH@("`@=F%R("1?9W)E96Y?<W1A<G0@(#T@
M)R<["B`@("!V87(@)%]Y96QL;W=?<W1A<G0@/2`G)SL*("`@('9A<B`D7V)L
M=65?<W1A<G0@("`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('-T<FEN9W,@
M=&\@;6%R:R!T:&4@96YD(&]F(&-O;&]U<F5D('1E>'0N"B`@("`@*B\*("`@
M('9A<B`D7W)E9%]E;F0@("`@("`]("<G.PH@("`@=F%R("1?9W)E96Y?96YD
M("`@(#T@)R<["B`@("!V87(@)%]Y96QL;W=?96YD("`@/2`G)SL*("`@('9A
M<B`D7V)L=65?96YD("`@("`]("<G.PH*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A('-I;F=L92!I;G-T86YC92!O9B!T:&4@2&]R9&5?0TQ)(&-L87-S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"D*("`@('L*("`@("`@
M("!S=&%T:6,@)&EN<W1A;F-E.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A
M;F-E*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V4@/2!N97<@2&]R9&5?0TQ)
M*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:6YS=&%N8V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$971E8W0@=&AE(&-U<G)E;G0@96YV:7)O;FUE
M;G0@*'=E8B!S97)V97(@;W(@8V]N<V]L92D@86YD('-E=',*("`@("`J(&EN
M=&5R;F%L('9A;'5E<R!A8V-O<F1I;F=L>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?0TQ)*"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O;G-O;&4@
M/2`D=&AI<RT^<G5N;FEN9T9R;VU#3$DH*3L*"B`@("`@("`@:68@*"1T:&ES
M+3Y?8V]N<V]L92D@>PH@("`@("`@("`@("`D=&AI<RT^7VYE=VQI;F4@/2`B
M7&XB.PH@("`@("`@("`@("`D=&AI<RT^7VEN9&5N="`@/2`G("`@("<["@H@
M("`@("`@("`@("`D=&5R;2`](&=E=&5N=B@G5$5232<I.PH@("`@("`@("`@
M("!I9B`H)'1E<FTI('L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O7BAX=&5R;7QV=#(R,'QL:6YU>"DO)RP@)'1E<FTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]B;VQD7W-T87)T("`@/2`B7'@Q8ELQ;2([
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R961?<W1A<G0@("`@/2`B
M7'@Q8ELP,3LS,6TB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9W)E
M96Y?<W1A<G0@(#T@(EQX,6);,#$[,S)M(CL*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7WEE;&QO=U]S=&%R="`](")<>#%B6S`Q.S,S;2(["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]B;'5E7W-T87)T("`@/2`B7'@Q8ELP
M,3LS-&TB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8F]L9%]E;F0@
M/2`D=&AI<RT^7W)E9%]E;F0@/2`D=&AI<RT^7V=R965N7V5N9"`]("1T:&ES
M+3Y?>65L;&]W7V5N9"`]("1T:&ES+3Y?8FQU95]E;F0@/2`B7'@Q8ELP;2([
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UYV=#$P
M,"\G+"`D=&5R;2DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V)O
M;&1?<W1A<G0@/2`B7'@Q8ELQ;2(["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]B;VQD7V5N9"`@(#T@(EQX,6);,&TB.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]N97=L:6YE(#T@)SQB<B`O/B<["B`@("`@("`@("`@("1T:&ES
M+3Y?:6YD96YT("`]('-T<E]R97!E870H)R9N8G-P.R<L(#0I.PH*("`@("`@
M("`@("`@)'1H:7,M/E]B;VQD7W-T87)T("`@/2`G/'-T<F]N9SXG.PH@("`@
M("`@("`@("`D=&AI<RT^7V)O;&1?96YD("`@("`]("<\+W-T<F]N9SXG.PH@
M("`@("`@("`@("`D=&AI<RT^7W)E9%]S=&%R="`@("`]("<\<W!A;B!S='EL
M93TB8V]L;W(Z<F5D(CXG.PH@("`@("`@("`@("`D=&AI<RT^7V=R965N7W-T
M87)T("`]("<\<W!A;B!S='EL93TB8V]L;W(Z9W)E96XB/B<["B`@("`@("`@
M("`@("1T:&ES+3Y?>65L;&]W7W-T87)T(#T@)SQS<&%N('-T>6QE/2)C;VQO
M<CIY96QL;W<B/B<["B`@("`@("`@("`@("1T:&ES+3Y?8FQU95]S=&%R="`@
M(#T@)SQS<&%N('-T>6QE/2)C;VQO<CIB;'5E(CXG.PH@("`@("`@("`@("`D
M=&AI<RT^7W)E9%]E;F0@/2`D=&AI<RT^7V=R965N7V5N9"`]("1T:&ES+3Y?
M>65L;&]W7V5N9"`]("1T:&ES+3Y?8FQU95]E;F0@/2`G/"]S<&%N/B<["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4')I;G1S("1T97AT(&]N
M(&$@<VEN9VQE(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'1E>'0@(%1H92!T97AT('1O('!R:6YT+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'!R92`@($EF('1R=64@=&AE(&QI;F5B<F5A:R!I<R!P<FEN=&5D(&)E
M9F]R90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!T97AT(&EN
M<W1E860@;V8@869T97(@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E
M;&XH)'1E>'0@/2`G)RP@)'!R92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("@D<')E*2!["B`@("`@("`@("`@(&5C:&\@)'1H:7,M/E]N97=L:6YE("X@
M)'1E>'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`D=&5X
M="`N("1T:&ES+3Y?;F5W;&EN93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!I;F1E;G1E9"!S=')I;F<N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@:6YD96YT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;F1E;G0H)'1E>'0I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6YD96YT("X@)'1E>'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8F]L9"!V97)S:6]N(&]F("1T97AT
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT
M('1O(&)O;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)O;&0H)'1E>'0I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F]L9%]S=&%R="`N("1T97AT
M("X@)'1H:7,M/E]B;VQD7V5N9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!R960@=F5R<VEO;B!O9B`D=&5X="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!P<FEN="!I;B!R960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E9"@D=&5X="D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]R961?<W1A<G0@+B`D=&5X="`N("1T:&ES+3Y?
M<F5D7V5N9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!G<F5E
M;B!V97)S:6]N(&]F("1T97AT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@(%1H92!T97AT('1O('!R:6YT(&EN(&=R965N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G<F5E;B@D=&5X="D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]G<F5E;E]S=&%R="`N("1T97AT("X@)'1H:7,M/E]G<F5E
M;E]E;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8FQU92!V
M97)S:6]N(&]F("1T97AT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@(%1H92!T97AT('1O('!R:6YT(&EN(&)L=64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&)L=64H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8FQU95]S=&%R="`N("1T97AT("X@)'1H:7,M/E]B;'5E7V5N9#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!Y96QL;W<@=F5R<VEO
M;B!O9B`D=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("!4:&4@=&5X="!T;R!P<FEN="!I;B!Y96QL;W<N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('EE;&QO=R@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]Y96QL;W=?<W1A<G0@+B`D=&5X="`N("1T:&ES+3Y?>65L;&]W7V5N
M9#L*("`@('T*"B`@("`O*BH*("`@("`J($1I<W!L87ES(&$@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E=F5N="`@5&AE(&UE<W-A
M9V4@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@(%1H92!T
M>7!E(&]F(&UE<W-A9V4Z("=C;&DN97)R;W(G+"`G8VQI+G=A<FYI;F<G+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("=C;&DN<W5C8V5S<R<L(&]R
M("=C;&DN;65S<V%G92<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UE<W-A9V4H
M)&UE<W-A9V4L("1T>7!E(#T@)V-L:2YM97-S86=E)RD*("`@('L*("`@("`@
M("`D;65S<V%G92`]('=O<F1W<F%P*"1M97-S86=E+"`V."P@(EQN("`@("`@
M("`@("`B+"!T<G5E*3L*"B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@
M("`@(&-A<V4@)V-L:2YE<G)O<B<Z"B`@("`@("`@("`@("1T>7!E7VUE<W-A
M9V4@/2`D=&AI<RT^<F5D*"=;($524D]2(2!=("<I.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G8VQI+G=A<FYI;F<G.@H@("`@("`@("`@
M("`D='EP95]M97-S86=E(#T@)'1H:7,M/GEE;&QO=R@G6R`@5T%23B`@72`G
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V-L:2YS=6-C
M97-S)SH*("`@("`@("`@("`@)'1Y<&5?;65S<V%G92`]("1T:&ES+3YG<F5E
M;B@G6R`@($]+("`@72`G*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)V-L:2YM97-S86=E)SH*("`@("`@("`@("`@)'1Y<&5?;65S<V%G
M92`]("1T:&ES+3YB;'5E*"=;("!)3D9/("!=("<I.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YW<FET96QN*"1T>7!E
M7VUE<W-A9V4@+B`D;65S<V%G92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M:7-P;&%Y<R!A(&9A=&%L(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D97)R;W(@(%1H92!E<G)O<B!T97AT('1O(&1I<W!L
M87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&9A=&%L*"1E<G)O<BD*("`@('L*
M("`@("`@("`D=&AI<RT^=W)I=&5L;B@D=&AI<RT^<F5D*"<]/3T]/3T]/3T]
M/3T]/3T]/3T]/2<I*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@I.PH@("`@
M("`@("1T:&ES+3YW<FET96QN*"1T:&ES+3YR960H7R@B1F%T86P@17)R;W(Z
M(BDI*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@D=&AI<RT^<F5D*"1E<G)O
M<BDI.PH@("`@("`@("1T:&ES+3YW<FET96QN*"D["B`@("`@("`@)'1H:7,M
M/G=R:71E;&XH)'1H:7,M/G)E9"@G/3T]/3T]/3T]/3T]/3T]/3T]/3TG*2D[
M"B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*BH*("`@("`J(%!R;VUP=',@
M9F]R(&$@=7-E<B!R97-P;VYS92X*("`@("`J"B`@("`@*B!`=&]D;R!(;W)D
M92`T.B!S=VET8V@@)&-H;VEC97,@86YD("1D969A=6QT"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<')O;7!T("!4:&4@;65S<V%G92!T;R!D:7-P
M;&%Y('=H96X@<')O;7!T:6YG('1H92!U<V5R+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1C:&]I8V5S("!4:&4@8VAO:6-E<R!A=F%I;&%B;&4@=&\@=&AE('5S
M97(@;W(@;G5L;"!F;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!T97AT(&EN<'5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5F875L="!4
M:&4@9&5F875L="!V86QU92!I9B!N;R!V86QU92!S<&5C:69I960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!R97-P;VYS92!T
M;R!T:&4@<')O;7!T+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F]M<'0H)'!R
M;VUP="P@)&-H;VEC97,@/2!N=6QL+"`D9&5F875L="`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*"1D969A=6QT("$]/2!N=6QL*2!["B`@("`@("`@("`@
M("1P<F]M<'0@+CT@)R!;)R`N("1D969A=6QT("X@)UTG.PH@("`@("`@('T*
M"B`@("`@("`@+R\@36%I;B!E=F5N="!L;V]P('1O(&-A<'1U<F4@=&]P(&QE
M=F5L(&-O;6UA;F0N"B`@("`@("`@=VAI;&4@*'1R=64I('L*("`@("`@("`@
M("`@+R\@4')I;G0@;W5T('1H92!P<F]M<'0@;65S<V%G92X*("`@("`@("`@
M("`@)'1H:7,M/G=R:71E;&XH)'!R;VUP="`N("<@)RP@(6ES7V%R<F%Y*"1C
M:&]I8V5S*2D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D8VAO:6-E<RD@
M)B8@(65M<'1Y*"1C:&]I8V5S*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&-H;VEC97,@87,@)&ME>2`]/B`D8VAO:6-E*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G=R:71E;&XH)'1H:7,M/FEN9&5N="@G*"<@+B`D
M=&AI<RT^8F]L9"@D:V5Y*2`N("<I("<@+B`D8VAO:6-E*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^=W)I=&5L;BA?*")4
M>7!E('EO=7(@8VAO:6-E.B`B*2P@=')U92D["B`@("`@("`@("`@("`@("!`
M;V)?9FQU<V@H*3L*"B`@("`@("`@("`@("`@("`O+R!'970@=&AE('5S97(@
M8VAO:6-E+@H@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@=')I;2AF9V5T
M<RA35$1)3BDI.PH@("`@("`@("`@("`@("`@:68@*"1R97-P;VYS92`]/3T@
M)R<@)B8@)&1E9F%U;'0@(3T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@
M("`D<F5S<&]N<V4@/2`D9&5F875L=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D8VAO:6-E<ULD<F5S<&]N<V5=*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YW<FET96QN*'-P<FEN=&8H7R@B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H
M;VEC92XB*2P@)')E<W!O;G-E*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!T
M<FEM*&9G971S*%-41$E.*2D["B`@("`@("`@("`@("`@("!I9B`H)')E<W!O
M;G-E(#T]/2`G)R`F)B`D9&5F875L="`A/3T@;G5L;"D@>PH@("`@("`@("`@
M("`@("`@("`@("1R97-P;VYS92`]("1D969A=6QT.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296%D<R!E=F5R>71H:6YG('1H870@:7,@<V5N
M="!T:')O=6=H('-T86YD87)D(&EN<'5T(&%N9"!R971U<FYS(&ET"B`@("`@
M*B!A<R!A('-I;F=L92!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!C;VYT96YT<R!O9B!T:&4@<W1A;F1A<F0@:6YP=70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E8613=&1I;B@I"B`@("!["B`@("`@("`@
M)&EN(#T@)R<["B`@("`@("`@=VAI;&4@*"%F96]F*%-41$E.*2D@>PH@("`@
M("`@("`@("`D:6X@+CT@9F=E=',H4U1$24XL(#$P,C0I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&EN.PH@("`@?0H*("`@("\J*@H@("`@("H@0TQ)
M('-C<FEP=',@<VAO=6QD;B=T('1I;65O=70L('-O('1R>2!T;R!S970@=&AE
M('1I;64@;&EM:70@=&\*("`@("`J(&YO;F4N($%L<V\@:6YI=&EA;&EZ92!A
M(&9E=R!V87)I86)L97,@:6X@)%]315)615(@=&AA="!A<F5N)W0@<')E<V5N
M=`H@("`@("H@9G)O;2!T:&4@0TQ)+@H@("`@("H*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@+RH@
M4G5N(&-O;G-T<G5C=&]R(&YO=R!B96-A=7-E(&ET(')E<75I<F5S("1?4T52
M5D526R=315)615)?3D%-12==('1O"B`@("`@("`@("H@8F4@96UP='D@:68@
M8V%L;&5D('=I=&@@82!#1TD@4T%022X@*B\*("`@("`@("`D8VQI(#T@)DAO
M<F1E7T-,23HZ<VEN9VQE=&]N*"D["@H@("`@("`@($!S971?=&EM95]L:6UI
M="@P*3L*("`@("`@("!O8E]I;7!L:6-I=%]F;'5S:"AT<G5E*3L*("`@("`@
M("!I;FE?<V5T*"=H=&UL7V5R<F]R<R<L(&9A;'-E*3L*("`@("`@("`D7U-%
M4E9%4ELG2%144%](3U-4)UT@/2`G,3(W+C`N,"XQ)SL*("`@("`@("`D7U-%
M4E9%4ELG4T525D527TY!344G72`]("<Q,C<N,"XP+C$G.PH@("`@("`@("1?
M4T525D526R=315)615)?4$]25"==(#T@)R<["B`@("`@("`@)%]315)615);
M)U)%34]415]!1$12)UT@/2`G)SL*("`@("`@("`D7U-%4E9%4ELG4$A07U-%
M3$8G72`](&ES<V5T*"1A<F=V*2`_("1A<F=V6S!=(#H@)R<["B`@("`@("`@
M:68@*"%D969I;F5D*"=35$1)3B<I*2!["B`@("`@("`@("`@(&1E9FEN92@G
M4U1$24XG+"!F;W!E;B@G<&AP.B\O<W1D:6XG+"`G<B<I*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"%D969I;F5D*"=35$1/550G*2D@>PH@("`@("`@("`@
M("!D969I;F4H)U-41$]55"<L(&9O<&5N*"=P:'`Z+R]S=&1O=70G+"`G<B<I
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"%D969I;F5D*"=35$1%4E(G*2D@
M>PH@("`@("`@("`@("!D969I;F4H)U-41$524B<L(&9O<&5N*"=P:'`Z+R]S
M=&1E<G(G+"`G<B<I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!-86ME('-U<F4@=V4G<F4@8F5I;F<@8V%L;&5D(&9R;VT@=&AE(&-O;6UA
M;F0@;&EN92P@86YD(&YO="!V:6$*("`@("`J('1H92!W96(N"B`@("`@*@H@
M("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!I9B!W92!A<F4L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<G5N;FEN9T9R;VU#3$DH*0H@("`@>PH@("`@("`@("1S87!I
M(#T@<&AP7W-A<&E?;F%M92@I.PH@("`@("`@(&EF("@D<V%P:2`]/2`G8VQI
M)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)'-A<&D@/3T@)V-G:2<@)B8@96UP='DH
M)%]315)615);)U-%4E9%4E].04U%)UTI.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]#86-H92YP:'``````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,30P,3$`,3`U,34T,S$P-C$`,#$W-S(U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M2&]R9&5?0V%C:&4Z.B!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C
M=&5D(&EN=&5R9F%C92!I;G1O"B`J('1H92!V87)I;W5S(&-A8VAI;F<@8F%C
M:V5N9',N("!)="!A;'-O('!R;W9I9&5S(&9U;F-T:6]N<R!F;W(*("H@8VAE
M8VMI;F<@:6XL(')E=')I979I;F<L(&%N9"!F;'5S:&EN9R!A(&-A8VAE+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#86-H92]#86-H92YP:'`L=B`Q+C,Q
M+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?0V%C:&4*("HO
M"F-L87-S($AO<F1E7T-A8VAE('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M="!A(&YE=R!(;W)D95]#86-H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?0V%C:&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@+RH@3VYL>2!D;R!G87)B86=E(&-O;&QE8W1I;VX@:68@
M87-K960@9F]R+"!A;F0@=&AE;B!O;FQY(#$E(&]F('1H90H@("`@("`@("`J
M('1I;64@=V4@8W)E871E(&%N(&]B:F5C="X@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1P87)A;7-;)V=C)UTI("8F"B`@("`@("`@("`@("AR86YD*#`L(#DY
M*2`]/2`P*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1O1T,H)'!A<F%M<ULG
M9V,G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@<F5T<FEE=F4@82!C86-H960@;V)J96-T(&%N9"!R971U<FX@:70@
M=&\@=&AE"B`@("`@*B!C86QL97(N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!/8FIE
M8W0@240@=&\@<75E<GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I
M;64@($QI9F5T:6UE(&]F('1H92!O8FIE8W0@:6X@<V5C;VYD<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@
M:68@;F]N92!W87,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D
M:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&%N
M(&]B:F5C="!I;B!T:&4@8V%C:&4N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@3V)J96-T($E$
M('5S960@87,@=&AE(&-A8VAI;F<@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D
M("`D9&%T82`@1&%T82!T;R!S=&]R92!I;B!T:&4@8V%C:&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D:V5Y+"`D
M9&%T82D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(&1I<F5C=&QY(&]U='!U="!A(&-A8VAE
M9"!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!/8FIE8W0@240@=&\@<75E
M<GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE
M(&]F('1H92!O8FIE8W0@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@:68@;F]N92!W87,@
M9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D:V5Y+"`D;&EF
M971I;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A(&=I=F5N(&ME>2!E>&ES=',@
M:6X@=&AE(&-A8VAE+"!V86QI9"!F;W(@=&AE(&=I=F5N"B`@("`@*B!L:69E
M=&EM92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!C:&5C:RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I;64@;V8@
M=&AE(&ME>2!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@17AI<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H
M)&ME>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!I<F4@86YY(&5X:7-T:6YG
M(&1A=&$@9F]R('1H92!G:79E;B!K97DN"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!#86-H92!K
M97D@=&\@97AP:7)E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!I
M<F4H)&ME>2D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O(&%N>2!G87)B86=E(&-O;&QE8W1I;VX@;F5E9&5D
M(&9O<B!T:&4@9')I=F5R+@H@("`@("H*("`@("`J($!P<FEV871E"B`@("`@
M*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'-E8W,@(%1H92!M:6YI;75M(&%M;W5N="!O9B!T:6UE("AI;B!S96-O
M;F1S*2!R97%U:7)E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&)E
M9F]R92!A(&-A8VAE(&ET96T@:7,@<F5M;W9E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1O1T,H)'-E8W,I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]#86-H92!I
M;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]#
M86-H92!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL
M(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R
M6S!=+VQI8B]#86-H92\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);
M,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8V]N9FEG=7)A=&EO;B!O<B!C;VYN96-T:6]N('!A<F%M971E
M<G,@82!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UI
M9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#86-H92`@
M5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?0V%C:&4@:6YS=&%N
M8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!F86QS92!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1D<FEV97(I*2!["B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@
M("`@("`@("`@("`D9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@
M("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I
M9B`H96UP='DH)&1R:79E<BD@?'P@)&1R:79E<B`]/2`G;F]N92<I('L*("`@
M("`@("`@("`@)&-A8VAE(#T@)FYE=R!(;W)D95]#86-H92@D<&%R86US*3L*
M("`@("`@("`@("`@<F5T=7)N("1C86-H93L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E
M("1A<'`@+B`G+VQI8B]#86-H92\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]#86-H92\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@
M("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]#86-H92\G
M("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]#86-H92\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#
M86-H95\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C
M;&%S<RDI('L*("`@("`@("`@("`@)&-A8VAE(#T@)FYE=R`D8VQA<W,H)'!A
M<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A8VAE(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L
M87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&-A8VAE.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?0V%C:&4*
M("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL
M>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO($AO<F1E7T-A
M8VAE(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT
M;'D*("`@("`J(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B
M92!U<V5D(&EF(&UU;'1I<&QE(&-A8VAE(&)A8VME;F1S("AA;F0L('1H=7,L
M"B`@("`@*B!M=6QT:7!L92!(;W)D95]#86-H92!I;G-T86YC97,I(&%R92!R
M97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN
M=F]K960@87,Z"B`@("`@*B`D=F%R(#T@)DAO<F1E7T-A8VAE.CIS:6YG;&5T
M;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@
M='EP92!O9B!C;VYC<F5T92!(;W)D95]#86-H92!S=6)C;&%S<R!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I
M<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#86-H92\@9F]R('1H
M92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE
M;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N
M965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0V%C:&4@(%1H92!C
M;VYC<F5T92!(;W)D95]#86-H92!R969E<F5N8V4L(&]R(&9A;'-E(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D[
M"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E
M<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)DAO<F1E7T-A8VAE.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA
M='5R95T["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4')E9G,N<&AP````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#8P-S`V`#$P-3$U-#,Q,#8Q`#`R,#`Q-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*+RHJ"B`J(%!R969E<F5N8V4@:7,@861M:6YI<W1R871I=F5L>2!L;V-K
M960N"B`J+PID969I;F4H)U]04D5&7TQ/0TM%1"<L(#$I.PH*+RHJ"B`J(%!R
M969E<F5N8V4@:7,@<VAA<F5D(&%M;VYG<W0@87!P;&EC871I;VYS+@H@*B\*
M9&5F:6YE*"=?4%)%1E]32$%2140G+"`R*3L*"B\J*@H@*B!0<F5F97)E;F-E
M('9A;'5E(&AA<R!B965N(&-H86YG960N"B`J+PID969I;F4H)U]04D5&7T1)
M4E19)RP@-"D["@HO*BH*("H@4')E9F5R96YC92!V86QU92!I<R!T:&4@87!P
M;&EC871I;VX@9&5F875L="X*("HO"F1E9FEN92@G7U!2149?1$5&055,5"<L
M(#@I.PH*+RHJ"B`J(%1H92!0<F5F<SHZ(&-L87-S('!R;W9I9&5S(&$@8V]M
M;6]N(&%B<W1R86-T960@:6YT97)F86-E(&EN=&\@=&AE"B`J('9A<FEO=7,@
M<')E9F5R96YC97,@<W1O<F%G92!M961I=6US+B`@270@86QS;R!I;F-L=61E
M<R!A;&P@;V8@=&AE"B`J(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN9RP@<W1O
M<FEN9RP@86YD(&-H96-K:6YG('!R969E<F5N8V4@=F%L=65S+@H@*@H@*B!4
M3T1/.B!D;V-U;65N="!T:&4@9F]R;6%T(&]F('1H92`D7W!R969S(&AA<V@@
M:&5R90H@*@H@*B`D7W!R969S6RIP<F5F(&YA;64J72`](&%R<F%Y*`H@*B`@
M("`@)W9A;'5E)R`@/3X@*D1E9F%U;'0@=F%L=64J+`H@*B`@("`@)VQO8VME
M9"<@/3X@*F)O;VQE86XJ+`H@*B`@("`@)W-H87)E9"<@/3X@*F)O;VQE86XJ
M+`H@*B`@("`@)W1Y<&4G("`@/3X@)V-H96-K8F]X)PH@*B`@("`@("`@("`@
M("`@("`@)W1E>'0G"B`J("`@("`@("`@("`@("`@("`G<&%S<W=O<F0G"B`J
M("`@("`@("`@("`@("`@("`G=&5X=&%R96$G"B`J("`@("`@("`@("`@("`@
M("`G<V5L96-T)PH@*B`@("`@("`@("`@("`@("`@)VYU;6)E<B<*("H@("`@
M("`@("`@("`@("`@("=I;7!L:6-I="<*("H@("`@("`@("`@("`@("`@("=S
M<&5C:6%L)PH@*B`@("`@("`@("`@("`@("`@)VQI;FLG("T@5&AE<F4@;75S
M="!B92!A(&9I96QD(&YA;65D(&5I=&AE<B`G=7)L)PH@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@*&EN=&5R;F%L(&%P<&QI8V%T:6]N(&QI;FLI(&]R
M("=X=7)L)PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@*&5X=&5R;F%L
M(&%P<&QI8V%T:6]N(&QI;FLI(&EF('1H:7,@='EP92!I<R!U<V5D+@H@*B`@
M("`@("`@("`@("`@("`@)V5N=6TG"B`J("`@("`G96YU;2<@("`]/B!43T1/
M+`H@*B`@("`@)V1E<V,G("`@/3X@7R@J1&5S8W)I<'1I;VX@<W1R:6YG*BDL
M"B`J("`@("`G:&5L<"<@("`]/B`J3F%M92!O9B!T:&4@96YT<GD@:6X@=&AE
M(%A-3"!H96QP(&9I;&4J"B`J("D["B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U!R969S+U!R969S+G!H<"QV(#$N,3,W+C$P+C(W(#(P,#8O,#<O,#,@,3<Z
M,S@Z,3$@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S
M<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@*B!(87-H(&AO;&1I;F<@86QL(&]F
M('1H92!U<V5R)W,@<')E9F5R96YC97,N($5A8V@@<')E9F5R96YC92!I<PH@
M("`@("H@:71S96QF(&$@:&%S:"P@<V\@=&AI<R!W:6QL('5L=&EM871E;'D@
M8F4@;75L=&DM9&EM96YS:6]N86PN"B`@("`@*@H@("`@("H@6RIP<F5F(&YA
M;64J72`]/B!!<G)A>2@*("`@("`J("`@("!;9%T@(#T^("`J9&5F875L="!V
M86QU92H*("`@("`J("`@("!;;5T@(#T^("`J<')E9B!M87-K*@H@("`@("H@
M("`@(%MV72`@/3X@("IP<F5F('9A;'5E*@H@("`@("H@*0H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?<')E9G,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@=&AI<R!S8V]P
M92X@5&AI<R!I<R!U<V5D('1O"B`@("`@*B!M86EN=&%I;B!T:&4@87!P;&EC
M871I;VX@<V-O<&4@8F5T=V5E;B!S971S(&]F('!R969E<F5N8V5S+B!">0H@
M("`@("H@9&5F875L="P@86QL('!R969E<F5N8V5S(&)E;&]N9R!T;R!T:&4@
M(F=L;V)A;"(@*$AO<F1E*2!S8V]P92X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]S8V]P92`]("=H;W)D92<["@H@("`@
M+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@8W5R<F5N="!U<V5R
M;F%M92X@5&AI<R!I;F1I8V%T97,@=&AE(&]W;F5R(&]F('1H90H@("`@("H@
M<')E9F5R96YC97,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?=7-E<B`]("<G.PH*("`@("\J*@H@("`@("H@0F]O;&5A
M;B!I;F1I8V%T:6YG('=H971H97(@<')E9F5R96YC92!C86-H:6YG('-H;W5L
M9"!B92!U<V5D+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]C86-H:6YG(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!(
M87-H(&AO;&1I;F<@<')E9F5R96YC97,@=VET:"!H;V]K(&9U;F-T:6]N<R!D
M969I;F5D+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?:&]O:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@2&%V92!W
M92!R=6X@:&]O:R!F=6YC=&EO;G,@>65T/PH@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]H;V]K<T-A;&QE9"`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!$969A=6QT(&-O;G-T<G5C=&]R("AM=7-T(&)E
M(&-A;&QE9"!F<F]M(&5A8V@@97AT96YD:6YG(&-L87-S(&EN('1H96ER"B`@
M("`@*B!C;VYS=')U8W1O<G,@=FEA('!A<F5N=#HZ4')E9G,H*2DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%!R969S*"D*("`@('L*("`@("`@("`D=&AI<RT^
M7W-H=71D;W=N*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!C:&%R<V5T('5S960@8GD@=&AE(&-O;F-R971E('!R969E<F5N8V4@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R969E
M<F5N8V4@8F%C:V5N9"=S(&-H87)S970N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$-H87)S970H*0H@("`@>PH@("`@("`@(')E='5R;B!.3%,Z.F=E=$-H
M87)S970H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@=&AE('-E
M<W-I;VXM8F%S960@<')E9F5R96YC97,@8V%C:&4@*&EF(&%V86EL86)L92DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE('!R969E
M<F5N8V4@=&\@=7!D871E+B`@268@96UP='DL('=I;&P@=7!D871E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!T:&4@96YT:7)E(&-A8VAE('=I=&@@
M=&AE(&-U<G)E;G0@<V5T(&]F('!R969S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C86-H955P9&%T92@D<')E9B`](&YU;&PI"B`@("!["B`@("`@("`@+RH@
M4F5T=7)N(&EM;65D:6%T96QY(&EF(&-A8VAI;F<@:7,@9&ES86)L960N("HO
M"B`@("`@("`@:68@*"$D=&AI<RT^7V-A8VAI;F<I('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/
M3ELG<')E9G-?8V%C:&4G72DI('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)'!R968I*2!["B`@("`@("`@("`@("`@("`D<')E9G,@/2`D=&AI<RT^7W!R
M969S.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!R
M969S(#T@87)R87DH)'!R968@/3X@)'1H:7,M/E]P<F5F<ULD<')E9ETI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!0;&%C92!E86-H('!R969E
M<F5N8V4@:6X@=&AE(&-A8VAE(&%C8V]R9&EN9R!T;R!I=',*("`@("`@("`@
M("`@("H@<V-O<&4N("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1P<F5F<R!A
M<R`D;F%M92`]/B`D<')E9BD@>PH@("`@("`@("`@("`@("`@)%]315-324].
M6R=P<F5F<U]C86-H92==6R1T:&ES+3YG97138V]P92@D;F%M92E=6R1N86UE
M72`]("1P<F5F.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5')I97,@=&\@9FEN9"!T:&4@<F5Q=65S=&5D('!R969E
M<F5N8V5S(&EN('1H92!C86-H92X@268@=&AE>2!E>&ES="P*("`@("`J('5P
M9&%T92!T:&4@)'!R969S(&AA<V@@=VET:"!T:&4@8V%C:&5D('9A;'5E<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V%C
M:&5,;V]K=7`H*0H@("`@>PH@("`@("`@("\J(%)E='5R;B!I;6UE9&EA=&5L
M>2!I9B!C86-H:6YG(&ES(&1I<V%B;&5D+B`J+PH@("`@("`@(&EF("@A)'1H
M:7,M/E]C86-H:6YG*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)W!R969S7V-A
M8VAE)UU;)VAO<F1E)UTI("8F"B`@("`@("`@("`@(&ES<V5T*"1?4T534TE/
M3ELG<')E9G-?8V%C:&4G75LD=&AI<RT^7W-C;W!E72DI('L*"B`@("`@("`@
M("`@("\J(%)E<W1O<F4@9VQO8F%L('!R969E<F5N8V5S+B`J+PH@("`@("`@
M("`@("`D=&AI<RT^7W!R969S(#T@87)R87E?;65R9V4H)'1H:7,M/E]P<F5F
M<RP@)%]315-324].6R=P<F5F<U]C86-H92==6R=H;W)D92==+"`D7U-%4U-)
M3TY;)W!R969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P95TI.PH*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;F5W('!R969E<F5N
M8V4@96YT<GD@=&\@=&AE("1P<F5F<R!H87-H+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!R968@("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC
M92!T;R!A9&0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86P@("`@5&AE(&EN
M:71I86P@=F%L=64@;V8@=&AE('!R969E<F5N8V4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D;6%S:R`@5&AE(&EN:71I86P@8FET;6%S:R!O9B!T:&4@<')E
M9F5R96YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1P<F5F+"`D=F%L
M(#T@)R<L("1M87-K(#T@,"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)'1H:7,M/E]P<F5F<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5F<ULD
M<')E9ET@/2!A<G)A>2@G=B<@/3X@)'9A;"P@)VTG(#T^("1M87-K+"`G9"<@
M/3X@)'9A;"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M
M;W9E<R!A('!R969E<F5N8V4@96YT<GD@9G)O;2!T:&4@)'!R969S(&AA<V@N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@
M;V8@=&AE('!R969E<F5N8V4@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96UO=F4H)'!R968I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1T:&ES+3Y?<')E9G,I*2!["B`@("`@("`@("`@("1S8V]P92`]("1T:&ES
M+3YG97138V]P92@D<')E9BD["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<')E9G-;)'!R969=*3L*("`@("`@("`@("`@=6YS970H)%]315-324].6R=P
M<F5F<U]C86-H92==6R1S8V]P95U;)'!R969=*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!G:79E;B!P<F5F97)E;F-E<R`H
M)'!R968I('1O('1H92!S<&5C:69I960@=F%L=64*("`@("`J("@D=F%L*2P@
M:68@=&AE('!R969E<F5N8V4@:7,@;6]D:69I86)L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P<F5F("`@("`@5&AE(&YA;64@;V8@=&AE('!R
M969E<F5N8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L
M("`@("`@(%1H92!N97<@=F%L=64@9F]R('1H:7,@<')E9F5R96YC92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E('1H92!P<F5F
M97)E;F-E('9A;'5E(&=E=',@8V]N=F5R=&5D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@9G)O;2!T:&4@8W5R<F5N="!C:&%R<V5T('1O('1H
M92!B86-K96YD)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!C
M:&%R<V5T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@=F%L=64@=V%S('-U8V-E<W-F=6QL>2!S970L(&9A;'-E(&]N(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T5F%L=64H)'!R968L("1V86PL("1C;VYV97)T(#T@=')U
M92D*("`@('L*("`@("`@("`O*B!%>&ET(&5A<FQY(&EF('1H:7,@<')E9F5R
M96YC92!I<R!L;V-K960@;W(@9&]E<VXG="!E>&ES="X@*B\*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?<')E9G-;)'!R969=*2!\?"`D=&AI<RT^:7-,
M;V-K960H)'!R968I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E=%9A;'5E*"1P<F5F
M+"`D=F%L+"!T<G5E+"`D8V]N=F5R="D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7U]S970H)&YA;64L("1V86QU92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G-E=%9A;'5E*"1N86UE+"`D=F%L=64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T<R!T:&4@9VEV96X@<')E9F5R96YC97,@*"1P<F5F*2!T;R!T
M:&4@<W!E8VEF:65D('9A;'5E"B`@("`@*B`H)'9A;"DL('=H971H97(@;W(@
M;F]T('1H92!P<F5F97)E;F-E(&ES('5S97(M;6]D:69I86)L92P@=6YS970*
M("`@("`J('1H92!D969A=6QT(&)I="P@86YD('-E="!T:&4@9&ER='D@8FET
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'!R968@("`@(%1H92!N86UE(&]F('1H92!P
M<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!S=')I;F<@("1V
M86P@("`@("!4:&4@;F5W('9A;'5E(&9O<B!T:&ES('!R969E<F5N8V4N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER='D@("`@5')U92!I9B!W92!S:&]U
M;&0@;6%R:R!T:&4@;F5W('9A;'5E(&%S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@9&ER='D@*&-H86YG960I+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&-O;G9E<G0@($EF('1R=64@=&AE('!R969E<F5N8V4@=F%L=64@
M9V5T<R!C;VYV97)T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!F<F]M('1H92!C=7)R96YT(&-H87)S970@=&\@=&AE(&)A8VME;F0G<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-H87)S970N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!V86QU92!W
M87,@<W5C8V5S<V9U;&QY('-E="P@9F%L<V4@;VX@80H@("`@("H@("`@("`@
M("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T
M5F%L=64H)'!R968L("1V86PL("1D:7)T>2`]('1R=64L("1C;VYV97)T(#T@
M=')U92D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF
M("@D8V]N=F5R="D@>PH@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/F-O;G9E
M<G14;T1R:79E<B@D=F%L+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!T:&4@<')E9F5R96YC92=S('9A;'5E(&ES(&%L
M<F5A9'D@97%U86P@=&\@)'9A;"P@9&]N)W0*("`@("`@("`@*B!B;W1H97(@
M8VAA;F=I;F<@:70N($-H86YG:6YG(&ET('=O=6QD('-E="!T:&4@(F1I<G1Y
M(B!B:70L"B`@("`@("`@("H@8V%U<VEN9R!A;B!U;FYE8V5S<V%R>2!U<&1A
M=&4@;&%T97(@;VX@:6X@=&AE('-T;W)A9V4*("`@("`@("`@*B!R;W5T:6YE
M+B`J+PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R969S6R1P<F5F72D@
M)B8*("`@("`@("`@("`@*"@D=&AI<RT^7W!R969S6R1P<F5F75LG=B==(#T]
M("1V86PI("8F"B`@("`@("`@("`@("`A)'1H:7,M/FES1&5F875L="@D<')E
M9BDI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF('1H92!V86QU92!E>&-E961S('1H
M92!A;&QO=V%B;&4@<W1O<F%G90H@("`@("`@("`J(&QI;6ET+B`J+PH@("`@
M("`@(&EF("AI<W-E="@D8V]N9ELG<')E9G,G75LG;6%X<VEZ92==*2D@>PH@
M("`@("`@("`@("!I9B`H<W1R;&5N*"1V86PI(#X@)&-O;F9;)W!R969S)UU;
M)VUA>'-I>F4G72D@>PH@("`@("`@("`@("`@("`@9VQO8F%L("1N;W1I9FEC
M871I;VX["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&YO=&EF:6-A=&EO
M;BDI('L*("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M
M(&%L;&]W86)L92!S:7IE(BDL("1P<F5F*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!!<W-I
M9VX@=&AE(&YE=R!V86QU92P@=6YS970@=&AE(")D969A=6QT(B!B:70L(&%N
M9"!S970@=&AE"B`@("`@("`@("`@(F1I<G1Y(B!B:70N("HO"B`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3Y?<')E9G-;)'!R969=6R=M)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<')E9G-;)'!R969=6R=M)UT@/2`P.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7W!R969S6R1P<F5F75LG=B==(#T@)'9A;#L*
M("`@("`@("`D=&AI<RT^<V5T1&5F875L="@D<')E9BP@9F%L<V4I.PH@("`@
M("`@(&EF("@D9&ER='DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y
M*"1P<F5F+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YC86-H
M955P9&%T92@D<')E9BD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L=64@;V8@=&AE(')E<75E
M<W1E9"!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!R968@("`@("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!R971R
M:65V92X*("`@("`J($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E
M('1H92!P<F5F97)E;F-E('9A;'5E(&=E=',@8V]N=F5R=&5D"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@8F%C:V5N9"=S(&-H
M87)S970@=&\@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!C:&%R<V5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=F%L=64@;V8@=&AE('!R969E<F5N8V4L(&YU;&P@:68@:70@9&]E
M<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F%L=64H)'!R
M968L("1C;VYV97)T(#T@=')U92D*("`@('L*("`@("`@("!S=&%T:6,@)&-H
M87)S970["B`@("`@("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]P<F5F<ULD<')E9EU;
M)W8G72DI(#\*("`@("`@("`@("`@*"1C;VYV97)T(#\*("`@("`@("`@("`@
M("1T:&ES+3YC;VYV97)T1G)O;41R:79E<B@D=&AI<RT^7W!R969S6R1P<F5F
M75LG=B==+"`D8VAA<G-E="D@.@H@("`@("`@("`@("`@)'1H:7,M/E]P<F5F
M<ULD<')E9EU;)W8G72D@.@H@("`@("`@("`@("!N=6QL.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]?9V5T*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9V5T5F%L=64H)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M36]D:69I97,@=&AE(")L;V-K960B(&)I="!F;W(@=&AE(&=I=F5N('!R969E
M<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@(%1H
M92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P
M87)A;2!B;V]L96%N("1B;V]L("!4:&4@;F5W(&)O;VQE86X@=F%L=64@9F]R
M('1H92`B;&]C:V5D(B!B:70N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$QO
M8VME9"@D<')E9BP@)&)O;VPI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971-
M87-K*"1P<F5F+"`D8F]O;"P@7U!2149?3$]#2T5$*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('-T871E(&]F('1H92`B;&]C:V5D(B!B
M:70@9F]R('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E
M('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5&AE
M(&)O;VQE86X@<W1A=&4@;V8@)'!R968G<R`B;&]C:V5D(B!B:70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES3&]C:V5D*"1P<F5F*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V=E=$UA<VLH)'!R968L(%]04D5&7TQ/0TM%1"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I9FEE<R!T:&4@(G-H87)E9"(@
M8FET(&9O<B!T:&4@9VEV96X@<')E9F5R96YC92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N
M8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@(%1H
M92!N97<@8F]O;&5A;B!V86QU92!F;W(@=&AE(")S:&%R960B(&)I="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T4VAA<F5D*"1P<F5F+"`D8F]O;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7W-E=$UA<VLH)'!R968L("1B;V]L+"!?4%)%
M1E]32$%2140I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<W1A=&4@;V8@=&AE(")S:&%R960B(&)I="!F;W(@=&AE(&=I=F5N('!R969E
M<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE
M(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@8VAE8VLN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4:&4@8F]O;&5A;B!S=&%T92!O9B`D<')E
M9B=S(")S:&%R960B(&)I="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-3:&%R
M960H)'!R968I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T36%S
M:R@D<')E9BP@7U!2149?4TA!4D5$*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($UO9&EF:65S('1H92`B9&ER='DB(&)I="!F;W(@=&AE(&=I=F5N('!R969E
M<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@("`@
M(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J
M($!P87)A;2!B;V]L96%N("1B;V]L("`@("!4:&4@;F5W(&)O;VQE86X@=F%L
M=64@9F]R('1H92`B9&ER='DB(&)I="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1&ER='DH)'!R968L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<V5T36%S:R@D<')E9BP@)&)O;VPL(%]04D5&7T1)4E19*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T871E(&]F('1H92`B9&ER='DB
M(&)I="!F;W(@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N
M8V4@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M:&4@8F]O;&5A;B!S=&%T92!O9B`D<')E9B=S(")D:7)T>2(@8FET+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<T1I<G1Y*"1P<F5F*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V=E=$UA<VLH)'!R968L(%]04D5&7T1)4E19*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($UO9&EF:65S('1H92`B9&5F875L="(@
M8FET(&9O<B!T:&4@9VEV96X@<')E9F5R96YC92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N
M8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@(%1H
M92!N97<@8F]O;&5A;B!V86QU92!F;W(@=&AE(")D969A=6QT(B!B:70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'0H)'!R968L("1B;V]L*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<V5T36%S:R@D<')E9BP@)&)O;VPL(%]0
M4D5&7T1%1D%53%0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@9&5F875L="!V86QU92!O9B!T:&4@9VEV96X@<')E9F5R96YC92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("!4:&4@;F%M92!O9B!T
M:&4@<')E9F5R96YC92!T;R!G970@=&AE(&1E9F%U;'0@9F]R+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("`@("`@(%1H92!P<F5F97)E;F-E)W,@
M9&5F875L="!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L
M="@D<')E9BD*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3Y?
M<')E9G-;)'!R969=6R=D)UTI(#\*("`@("`@("`@("`@)'1H:7,M/E]P<F5F
M<ULD<')E9EU;)V0G72`Z"B`@("`@("`@("`@("<G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!I9B!T:&4@8W5R<F5N="!P<F5F97)E;F-E
M('9A;'5E(&ES('1H92!D969A=6QT"B`@("`@*B!V86QU92!F<F]M('!R969S
M+G!H<"!O<B!A('5S97(@9&5F:6YE9"!V86QU90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E
M('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I9B!T:&4@<')E9F5R96YC92!I<R!T:&4@87!P;&EC871I;VX@9&5F875L
M=`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-$969A=6QT*"1P<F5F*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V=E=$UA<VLH)'!R968L(%]04D5&7T1%1D%53%0I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@=F%L=64@9F]R(&$@9VEV96X@
M;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R
M969E<F5N8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O
M;VP@(%1H92!N97<@8F]O;&5A;B!V86QU92!F;W(@=&AE(")D969A=6QT(B!B
M:70N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%S:R`@5&AE(&UA<VL@=&\@
M861D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T36%S:R@D<')E9BP@)&)O
M;VPL("1M87-K*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R
M969S6R1P<F5F72DI('L*("`@("`@("`@("`@:68@*"1B;V]L("$]("1T:&ES
M+3Y?9V5T36%S:R@D<')E9BP@)&UA<VLI*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&)O;VPI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!R969S
M6R1P<F5F75LG;2==('P]("1M87-K.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!R969S6R1P<F5F75LG
M;2==("8]('XD;6%S:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&)O
M;VQE86X@<W1A=&4@9F]R(&$@9VEV96X@;6%S:RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M<F5F("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@;6]D:69Y+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&UA<VL@(%1H92!M87-K('1O(&=E="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1H92!B;V]L96%N('-T
M871E(&9O<B!T:&4@9VEV96X@;6%S:RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$UA<VLH)'!R968L("1M87-K*0H@("`@>PH@("`@("`@(')E='5R;B!I
M<W-E="@D=&AI<RT^7W!R969S6R1P<F5F75LG;2==*2`_("@D=&AI<RT^7W!R
M969S6R1P<F5F75LG;2==("8@)&UA<VLI(#H@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AE(&-U<G)E;G0@<')E
M9F5R96YC92!I<R!E;7!T>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P<F5F("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!C:&5C:RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('!R
M969E<F5N8V4@:7,@96UP='DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES16UP
M='DH)'!R968I"B`@("!["B`@("`@("`@<F5T=7)N(&5M<'1Y*"1T:&ES+3Y?
M<')E9G-;)'!R969=6R=V)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@<V-O<&4@;V8@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@;V8@=&AE
M('!R969E<F5N8V4@=&\@97AA;6EN92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('-C;W!E(&]F('1H92`D<')E9BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4V-O<&4H)'!R968I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YI<U-H87)E9"@D<')E9BDI('L*("`@("`@("`@("`@<F5T=7)N("=H
M;W)D92<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<V-O<&4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&$@;&ES="!O9B`B9&ER='DB('!R969E<F5N8V5S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!L:7-T(&]F(")D:7)T>2(@<')E9F5R96YC97,@:6X@)'1H
M:7,M/E]P<F5F<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<G1Y4')E9G,H
M*0H@("`@>PH@("`@("`@("1D:7)T>5]P<F5F<R`](&%R<F%Y*"D["@H@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]P<F5F<RD@87,@)'!R
M968I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YI<T1I<G1Y*"1P<F5F*2D@
M>PH@("`@("`@("`@("`@("`@)&1I<G1Y7W!R969S6UT@/2`D<')E9CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D:7)T>5]P
M<F5F<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@9&5F
M875L="!P<F5F97)E;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5T<FEE
M=F4H*0H@("`@>PH@("`@("`@("\J($QO860@9&5F875L=',@=&\@;6%K92!S
M=7)E('=E(&AA=F4@86QL('!R969E<F5N8V5S+B`J+PH@("`@("`@("1T:&ES
M+3Y?<V5T1&5F875L=',H)VAO<F1E)RD["B`@("`@("`@)'1H:7,M/E]S971$
M969A=6QT<R@D=&AI<RT^7W-C;W!E*3L*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N('=I;&P@8F4@
M<G5N(&%T('1H92!E;F0@;V8@979E<GD@<F5Q=65S="!A<R!A('-H=71D;W=N
M"B`@("`@*B!F=6YC=&EO;B`H<F5G:7-T97)E9"!B>2!T:&4@4')E9G,Z.B!C
M;VYS=')U8W1O<BDN("!!;&P@<')E9G,@=VET:"!T:&4*("`@("`J(&1I<G1Y
M(&)I="!S970@=VEL;"!B92!S879E9"!T;R!T:&4@<W1O<F%G92!B86-K96YD
M(&%T('1H:7,@=&EM93L@=&AU<RP*("`@("`J('1H97)E(&ES(&YO(&YE960@
M=&\@;6%N=6%L;'D@8V%L;"`D<')E9G,M/G-T;W)E*"D@979E<GD@=&EM92!A
M"B`@("`@*B!P<F5F97)E;F-E(&ES(&-H86YG960N"B`@("`@*@H@("`@("H@
M0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E*"D*("`@('L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H
M:7,@9G5N8W1I;VX@<')O=FED97,@8V]M;6]N(&-L96%N=7`@9G5N8W1I;VYS
M(&9O<B!A;&P@;V8@=&AE(&1R:79E<@H@("`@("H@:6UP;&5M96YT871I;VYS
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1A;&P@($-L96%N('5P
M(&%L;"!(;W)D92!P<F5F97)E;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VQE86YU<"@D86QL(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@4F5M;W9E
M('1H:7,@<V-O<&4@9G)O;2!T:&4@<')E9F5R96YC97,@8V%C:&4L(&EF(&ET
M"B`@("`@("`@("`@97AI<W1S+B`J+PH@("`@("`@(&EF("AI<W-E="@D7U-%
M4U-)3TY;)W!R969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P95TI*2!["B`@("`@
M("`@("`@('5N<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G75LD=&AI<RT^
M7W-C;W!E72D["B`@("`@("`@?0H*("`@("`@("`O*B!097)F;W)M(&$@2&]R
M9&4M=VED92!C;&5A;G5P/R`J+PH@("`@("`@(&EF("@D86QL*2!["B`@("`@
M("`@("`@("\J($1E<W1R;WD@=&AE(&-O;G1E;G1S(&]F('1H92!P<F5F97)E
M;F-E<R!H87-H+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W!R969S(#T@87)R
M87DH*3L*"B`@("`@("`@("`@("\J($1E<W1R;WD@=&AE(&-O;G1E;G1S(&]F
M('1H92!P<F5F97)E;F-E<R!C86-H92X@*B\*("`@("`@("`@("`@:68@*&ES
M<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G72DI('L*("`@("`@("`@("`@
M("`@('5N<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@
M86QL('!R969E<F5N8V5S(&9R;VT@=&AE(&)A8VME;F0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L96%R*"D*("`@('L*("`@("`@("`D=&AI<RT^8VQE86YU
M<"AT<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@=F%L
M=64@9G)O;2!T:&4@9')I=F5R)W,@8VAA<G-E="!T;R!T:&4@<W!E8VEF:65D
M(&-H87)S970N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1V86QU92`@
M("`@02!V86QU92!T;R!C;VYV97)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VAA<G-E="`@5&AE(&-H87)S970@=&\@8V]N=F5R="!T;RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]N=F5R=&5D('9A;'5E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;VYV97)T1G)O;41R:79E<B@D=F%L=64L("1C
M:&%R<V5T*0H@("`@>PH@("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A('9A;'5E(&9R;VT@=&AE('-P96-I
M9FEE9"!C:&%R<V5T('1O('1H92!D<FEV97(G<R!C:&%R<V5T+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@($$@=F%L=64@=&\@8V]N=F5R
M="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T
M('1O(&-O;G9E<G0@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@8V]N=F5R=&5D('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;VYV97)T5&]$<FEV97(H)'9A;'5E+"`D8VAA<G-E="D*("`@('L*("`@("`@
M("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4&]P=6QA
M=&5S('1H92`D<')E9G,@:&%S:"!W:71H(&YE=R!E;G1R:65S(&%N9"!E>'1E
M<FYA;&QY(&1E9FEN960*("`@("`J(&1E9F%U;'0@=F%L=65S+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T:6]N('1O
M(&QO860@9&5F875L=',@9F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T
M1&5F875L=',H)&%P<"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH@("`@("`@("1F:6QE;F%M92`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O
M="<L("1A<'`I("X@)R]C;VYF:6<O<')E9G,N<&AP)SL*"B`@("`@("`@+RH@
M16YS=7)E('1H870@=&AE(&1E9F%U;'1S(&9R;VT@=&AI<R!F:6QE(&%R92!O
M;FQY(')E860@;VYC92X*("`@("`@("`@("!!;'-O+"!M86ME('-U<F4@=V4@
M8V%N(')E860@=&AI<R!F:6QE+B`J+PH@("`@("`@(&EF("@A0&ES7W)E861A
M8FQE*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4F5A9"!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!4
M:&4@)%]P<F5F<R!A<G)A>2P@=VAI8V@@=VEL;"!B90H@("`@("`@("`@(&EN
M(&QO8V%L('-C;W!E+"!I<R!A<W-U;65D('1O(&AO;&0@=&AE(&1E9F%U;'0@
M=F%L=65S+B`J+PH@("`@("`@(&EN8VQU9&4@)&9I;&5N86UE.PH@("`@("`@
M(&9O<F5A8V@@*"1?<')E9G,@87,@)'!R968@/3X@)'!V86QS*2!["B`@("`@
M("`@("`@(&EF("AI<W-E="@D<'9A;'-;)W9A;'5E)UTI("8F"B`@("`@("`@
M("`@("`@("!I<W-E="@D<'9A;'-;)VQO8VME9"==*2`F)@H@("`@("`@("`@
M("`@("`@:7-S970H)'!V86QS6R=S:&%R960G72D@)B8*("`@("`@("`@("`@
M("`@("@D<'9A;'-;)W1Y<&4G72`A/2`G;&EN:R<I("8F"B`@("`@("`@("`@
M("`@("`H)'!V86QS6R=T>7!E)UT@(3T@)W-P96-I86PG*2D@>PH@("`@("`@
M("`@("`@("`@)'!R968@/2!S=')?<F5P;&%C92@G+B<L("=?)RP@)'!R968I
M.PH@("`@("`@("`@("`@("`@)&UA<VL@/2`P.PH@("`@("`@("`@("`@("`@
M:68@*"1P=F%L<ULG;&]C:V5D)UTI('L*("`@("`@("`@("`@("`@("`@("`D
M;6%S:R!\/2!?4%)%1E],3T-+140["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H)'!V86QS6R=S:&%R960G72!\?"`D87!P(#T]("=H
M;W)D92<I('L*("`@("`@("`@("`@("`@("`@("`D;6%S:R!\/2!?4%)%1E]3
M2$%2140["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;6%S
M:R`F/2!^7U!2149?1$E25%D["B`@("`@("`@("`@("`@("`D;6%S:R!\/2!?
M4%)%1E]$149!54Q4.PH*("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H)'!R
M968L("1P=F%L<ULG=F%L=64G72P@)&UA<VLI.PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D<'9A;'-;)VAO;VLG72DI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$AO;VLH)'!R968I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!5<&1A=&4@
M=&AE('!R969E<F5N8V5S(&-A8VAE('=I=&@@=&AE(&1E9F%U;'1S+B`J+PH@
M("`@("`@("1T:&ES+3YC86-H955P9&%T92@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&5R9F]R;7,@<VAU=&1O=VX@86-T:79I=&EE<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W-H
M=71D;W=N*"D*("`@('L*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC
M=&EO;BAA<G)A>2@F)'1H:7,L("=S=&]R92<I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9"`D<')E9B!T;R!T:&4@;&ES="!O9B!P<F5F97)E;F-E<R!W
M:71H(&AO;VL@9G5N8W1I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!R968@(%1H92!P<F5F97)E;F-E('=I=&@@82!H;V]K+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5T2&]O:R@D<')E9BD*("`@('L*("`@("`@("`D
M=&AI<RT^7VAO;VMS6UT@/2`D<')E9CL*("`@('T*"B`@("`O*BH*("`@("`J
M($%F=&5R('!R969E<F5N8V5S(&AA=F4@8F5E;B!L;V%D960L('-E="!A;GD@
M;&]C:V5D(&]R(&5M<'1Y"B`@("`@*B!P<F5F97)E;F-E<R!T:&%T(&AA=F4@
M:&]O:W,@=&\@=&AE(')E<W5L="!O9B!T:&4@:&]O:RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-A;&Q(;V]K<R@I"B`@("!["B`@("`@("`@:68@*"%I<U]N
M=6QL*"1T:&ES+3Y?:&]O:W-#86QL960I*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:&]O:W-#86QL960@/2!T
M<G5E.PH*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?:&]O:W,I*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&=L;V)A;"`D
M<F5G:7-T<GD["B`@("`@("`@:6YC;'5D95]O;F-E("1R96=I<W1R>2T^9V5T
M*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAO;VMS(&%S("1P<F5F*2!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^:7-,;V-K960H)'!R968I('Q\"B`@("`@
M("`@("`@("`@("`A)'1H:7,M/F=E=%9A;'5E*"1P<F5F*2!\?`H@("`@("`@
M("`@("`@("`@)'1H:7,M/FES1&5F875L="@D<')E9BDI('L*("`@("`@("`@
M("`@("`@("1F=6YC(#T@)U]P<F5F<U]H;V]K7R<@+B`D<')E9CL*("`@("`@
M("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)&9U;F,I*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S971686QU92@D<')E9BP@)&9U;F,H
M)'1H:7,M/E]U<V5R*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!C;VYC<F5T92!0<F5F<R!I;G-T86YC92!B87-E9"!O;B`D
M9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("`@
M("!4:&4@='EP92!O9B!C;VYC<F5T92!0<F5F<R!S=6)C;&%S<R!T;R!R971U
M<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@268@)&1R:79E
M<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=+VQI8B]0<F5F<R\@
M9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@(%1H92!S8V]P92!F;W(@=&AI
M<R!S970@;V8@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(@=VAO(&]W;G,@=&AI<R!S
M970@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!P<F5F97)E
M;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!4:&4@<&%S
M<W=O<F0@87-S;V-I871E9"!W:71H("1U<V5R+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!O<B!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H
M="!N965D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@(%-H;W5L
M9"!C86-H:6YG(&)E('5S960_"B`@("`@*@H@("`@("H@0')E='5R;B!0<F5F
M<R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@4')E9G,@:6YS=&%N8V4L
M(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'-C;W!E(#T@
M)VAO<F1E)RP@)'5S97(@/2`G)RP@)'!A<W-W;W)D(#T@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`D<&%R86US(#T@;G5L;"P@)&-A8VAI;F<@/2!T<G5E
M*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@
M("`@("`@("`D87!P(#T@)&1R:79E<ELP73L*("`@("`@("`@("`@)&1R:79E
M<B`]("1D<FEV97);,5T["B`@("`@("`@?0H*("`@("`@("`O*B!!='1E;7!T
M('1O(')E9VES=&5R("AC86-H92D@=&AE("1P<F5F<R!H87-H(&EN('-E<W-I
M;VX@<W1O<F%G92X@*B\*("`@("`@("!I9B`H)&-A8VAI;F<I('L*("`@("`@
M("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UTI*2![
M"B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)W!R969S7V-A8VAE)UT@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D9')I
M=F5R(#T@8F%S96YA;64H)&1R:79E<BD["B`@("`@("`@:68@*&5M<'1Y*"1D
M<FEV97(I('Q\("1D<FEV97(@/3T@)VYO;F4G*2!["B`@("`@("`@("`@("1D
M<FEV97(@/2`G<V5S<VEO;B<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z
M.F=E=$1R:79E<D-O;F9I9R@G<')E9G,G+"`D9')I=F5R*3L*("`@("`@("!]
M"@H@("`@("`@("\J($EF("1P87)A;7-;)W5S97)?:&]O:R==(&ES(&1E9FEN
M960L('5S92!I="!T;R!R971R:65V92!T:&4@=F%L=64@=&\*("`@("`@("`@
M*B!U<V4@9F]R('1H92!U<V5R;F%M92`H)'1H:7,M/E]U<V5R*2X@3W1H97)W
M:7-E+"!J=7-T('5S92!T:&4@=F%L=64*("`@("`@("`@*B!P87-S960@:6X@
M=&AE("1U<V5R('!A<F%M971E<BX@*B\*("`@("`@("!I9B`H(65M<'1Y*"1P
M87)A;7-;)W5S97)?:&]O:R==*2`F)@H@("`@("`@("`@("!F=6YC=&EO;E]E
M>&ES=',H)'!A<F%M<ULG=7-E<E]H;V]K)UTI*2!["B`@("`@("`@("`@("1U
M<V5R(#T@8V%L;%]U<V5R7V9U;F,H)'!A<F%M<ULG=7-E<E]H;V]K)UTL("1U
M<V5R*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]0<F5F<R\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H9FEL95]E>&ES=',H
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+U!R969S+R<@+B`D9')I=F5R("X@)RYP
M:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+U!R969S+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O4')E
M9G,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D
M8VQA<W,@/2`G4')E9G-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1P<F5F<R`]("9N97<@
M)&-L87-S*"1U<V5R+"`D<&%S<W=O<F0L("1S8V]P92P@)'!A<F%M<RP@)&-A
M8VAI;F<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P<F5F<R`]
M(%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C
M;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1P<F5F<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E(%!R969S(&EN<W1A
M;F-E(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R+B!)="!W:6QL(&]N;'D@8W)E
M871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO(%!R969S(&EN<W1A;F-E"B`@("`@
M*B!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*
M("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE
M('!R969E<F5N8V4@<V]U<F-E<R`H86YD+"!T:'5S+`H@("`@("H@;75L=&EP
M;&4@4')E9G,@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)E!R
M969S.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M9')I=F5R("`@("!4:&4@='EP92!O9B!C;VYC<F5T92!0<F5F<R!S=6)C;&%S
M<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL@:6X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=+VQI
M8B]0<F5F<R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN
M<&AP+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@(%1H92!S8V]P
M92!F;W(@=&AI<R!S970@;V8@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(@=VAO(&]W
M;G,@=&AI<R!S970@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!P<F5F97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D
M("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U<V5R+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N
M>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!O<B!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C
M;&%S<R!M:6=H="!N965D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI
M;F<@(%-H;W5L9"!C86-H:6YG(&)E('5S960_"B`@("`@*@H@("`@("H@0')E
M='5R;B!0<F5F<R`@5&AE(&-O;F-R971E(%!R969S(')E9F5R96YC92P@;W(@
M9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG
M;&5T;VXH)&1R:79E<BP@)'-C;W!E(#T@)VAO<F1E)RP@)'5S97(@/2`G)RP@
M)'!A<W-W;W)D(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A
M;7,@/2!N=6QL+"`D8V%C:&EN9R`]('1R=64I"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-?;G5L
M;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E
M=$1R:79E<D-O;F9I9R@G<')E9G,G+"`D9')I=F5R*3L*("`@("`@("!]"@H@
M("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@
M)'5S97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC
M97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I
M9VYA='5R95T@/2`F4')E9G,Z.F9A8W1O<GDH)&1R:79E<BP@)'-C;W!E+"`D
M=7-E<BP@)'!A<W-W;W)D+"`D<&%R86US+"`D8V%C:&EN9RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@
M('T*"GT*````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@N<&AP````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#$R-#$R,``Q,#4Q-30S,3`V,0`P,3<V,C8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!P87)A;65T97(@;F%M92!F;W(@=&AE(&QO9V]U="!R96%S;VXN
M"B`J+PID969I;F4H)T%55$A?4D5!4T].7U!!4D%-)RP@)VQO9V]U=%]R96%S
M;VXG*3L*"B\J*@H@*B!4:&4@<&%R86UE=&5R(&YA;64@9F]R('1H92!L;V=O
M=70@;65S<V%G92!U<V5D('=I=&@@='EP90H@*B!!551(7U)%05-/3E]-15-3
M04=%+@H@*B\*9&5F:6YE*"=!551(7U)%05-/3E]-4T=?4$%204TG+"`G;&]G
M;W5T7VUS9R<I.PH*+RHJ"B`J(%1H92`G8F%D;&]G:6XG(')E87-O;BX*("H*
M("H@5&AE(&9O;&QO=VEN9R`G<F5A<V]N<R<@9F]R('1H92!L;V=O=70@<V-R
M965N(&%R92!R96-O9VYI>F5D.@H@*B`\<')E/@H@*B`@("=B861L;V=I;B<@
M("`M+2`@0F%D('5S97)N86UE(&%N9"]O<B!P87-S=V]R9`H@*B`@("=B<F]W
M<V5R)R`@("`M+2`@02!B<F]W<V5R(&-H86YG92!W87,@9&5T96-T960*("H@
M("`G9F%I;&5D)R`@("`@+2T@($QO9VEN(&9A:6QE9`H@*B`@("=L;V=O=70G
M("`@("`M+2`@3&]G;W5T(&1U92!T;R!U<V5R(')E<75E<W0*("H@("`G;65S
M<V%G92<@("`@+2T@($QO9V]U="!W:71H(&-U<W1O;2!M97-S86=E(&EN($%5
M5$A?4D5!4T].7TU31U]005)!30H@*B`@("=S97-S:6]N)R`@("`M+2`@3&]G
M;W5T(&1U92!T;R!S97-S:6]N(&5X<&ER871I;VX*("H@("`G<V5S<VEO;FEP
M)R`@+2T@($QO9V]U="!D=64@=&\@8VAA;F=E(&]F($E0(&%D9')E<W,@9'5R
M:6YG('-E<W-I;VX*("H@/"]P<F4^"B`J+PID969I;F4H)T%55$A?4D5!4T].
M7T)!1$Q/1TE.)RP@)V)A9&QO9VEN)RD["@HO*BH*("H@5&AE("=B<F]W<V5R
M)R!R96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7T)23U=315(G+"`G
M8G)O=W-E<B<I.PH*+RHJ"B`J(%1H92`G9F%I;&5D)R!R96%S;VXN"B`J+PID
M969I;F4H)T%55$A?4D5!4T].7T9!24Q%1"<L("=F86EL960G*3L*"B\J*@H@
M*B!4:&4@)V5X<&ER960G(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%3
M3TY?15A025)%1"<L("=E>'!I<F5D)RD["@HO*BH*("H@5&AE("=L;V=O=70G
M(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?3$]'3U54)RP@)VQO
M9V]U="<I.PH*+RHJ"B`J(%1H92`G;65S<V%G92<@<F5A<V]N+@H@*B\*9&5F
M:6YE*"=!551(7U)%05-/3E]-15-304=%)RP@)VUE<W-A9V4G*3L*"B\J*@H@
M*B!4:&4@)W-E<W-I;VXG(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%3
M3TY?4T534TE/3B<L("=S97-S:6]N)RD["@HO*BH*("H@5&AE("=S97-S:6]N
M:7`G(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?4T534TE/3DE0
M)RP@)W-E<W-I;VYI<"<I.PH*+RHJ"B`J(%1H92!!=71H.CH@8VQA<W,@<')O
M=FED97,@82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@:6YT;R!T:&4@
M=F%R:6]U<PH@*B!B86-K96YD<R!F;W(@=&AE($AO<F1E(&%U=&AE;G1I8V%T
M:6]N('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<"QV(#$N,30R+C$P+C(S(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA
M<W,@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL
M:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@
M("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S
M;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=R;W5P<R<@("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@2&%S
M:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@5&AE(&-R961E;G1I86QS(&-U<G)E;G1L>2!B96EN9R!A
M=71H96YT:6-A=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A
M=71H0W)E9&5N=&EA;',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;F%M92!O9B!T:&4@8V]N8W)E=&4@075T:"!I;7!L96UE;G1A
M=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($%U=&@@
M:6UP;&5M96YT871I;VX@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1')I=F5R*"D*("`@('L*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)V%U
M=&A?)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1FEN9',@;W5T(&EF(&$@<V5T(&]F(&QO9VEN
M(&-R961E;G1I86QS(&%R92!V86QI9"P@86YD(&EF(')E<75E<W1E9"P*("`@
M("`J(&UA<FL@=&AE('5S97(@87,@;&]G9V5D(&EN(&EN('1H92!C=7)R96YT
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A
M>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!C:&5C:RX*("`@
M("`J($!P87)A;2!B;V]L96%N("1L;V=I;B`@("`@(%=H971H97(@=&\@;&]G
M('1H92!U<V5R(&EN+B!)9B!F86QS92P@=V4G;&P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]N;'D@=&5S="!T:&4@8W)E9&5N=&EA;',@
M86YD('=O;B=T(&UO9&EF>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE(&-U<G)E;G0@<V5S<VEO;BX@1&5F875L=',@=&\@=')U92X*
M("`@("`J($!P87)A;2!S=')I;F<@)')E86QM("`@("`@(%1H92!A=71H96YT
M:6-A=&EO;B!R96%L;2!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@
M=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AE;G1I8V%T92@D=7-E
M<DED+"`D8W)E9&5N=&EA;',L("1L;V=I;B`]('1R=64L("1R96%L;2`](&YU
M;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D875T
M:"`](&9A;'-E.PH@("`@("`@("1U<V5R260@/2!T<FEM*"1U<V5R260I.PH*
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P<F5A=71H96YT
M:6-A=&4G72DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!
M4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@("`@("!I9B`H9G5N
M8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P<F5A=71H96YT:6-A=&4G*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"%C86QL7W5S97)?9G5N8R@G7VAO<F1E
M7VAO;VM?<')E875T:&5N=&EC871E)RP@)'5S97))9"P@)&-R961E;G1I86QS
M+"`D<F5A;&TI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M9V5T075T:$5R<F]R*"D@(3T@05542%]214%33TY?34534T%'12D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(
M7U)%05-/3E]&04E,140I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-T;W)E('1H
M92!C<F5D96YT:6%L<R!B96EN9R!C:&5C:V5D('-O('1H870@<W5B8VQA<W-E
M<R!C86X@;6]D:69Y"B`@("`@("`@("H@=&AE;2!I9B!N96-E<W-A<GD@*&QI
M:V4@=')A;G-P87)E;G0@875T:"!D;V5S*2X@*B\*("`@("`@("`D=&AI<RT^
M7V%U=&A#<F5D96YT:6%L<R`](&%R<F%Y*`H@("`@("`@("`@("`G=7-E<DED
M)R`]/B`D=7-E<DED+`H@("`@("`@("`@("`G8W)E9&5N=&EA;',G(#T^("1C
M<F5D96YT:6%L<RP*("`@("`@("`@("`@)W)E86QM)R`]/B`D<F5A;&TL"B`@
M("`@("`@("`@("=C:&%N9V5297%U97-T960G(#T^(&9A;'-E"B`@("`@("`@
M*3L*"B`@("`@("`@:68@*"1A=71H96YT:6-A=&5D(#T@)'1H:7,M/E]A=71H
M96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*2D@>PH@("`@("`@("`@
M("!I9B`H:7-?82@D875T:&5N=&EC871E9"P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!O<W1A=71H
M96YT:6-A=&4G72DI('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92!(
M3U)$15]"05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W!O<W1A=71H
M96YT:6-A=&4G*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A8V%L;%]U
M<V5R7V9U;F,H)U]H;W)D95]H;V]K7W!O<W1A=71H96YT:6-A=&4G+"`D=7-E
M<DED+"`D8W)E9&5N=&EA;',L("1R96%L;2DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?9V5T075T:$5R<F]R*"D@(3T@05542%]2
M14%33TY?34534T%'12D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?1D%)3$5$*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&QO
M9VEN*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T075T:"@D=&AI<RT^
M7V%U=&A#<F5D96YT:6%L<ULG=7-E<DED)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%U=&A#<F5D96YT:6%L<ULG8W)E9&5N
M=&EA;',G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?875T:$-R961E;G1I86QS6R=R96%L;2==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A=71H0W)E9&5N=&EA;'-;)V-H86YG
M95)E<75E<W1E9"==*3L*("`@("`@("`@("`@("`@("1A=71H(#T@=')U93L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@A)'1H
M:7,M/E]C:&5C:U-E<W-I;VY)4"@I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?4T534TE/3DE0*3L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H(21T:&ES+3Y?8VAE8VM"<F]W<V5R4W1R:6YG*"DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!
M551(7U)%05-/3E]"4D]74T52*3L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M875T:"`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D875T:#L*("`@('T*"B`@("`O*BH*("`@("`J($9O<FUA=',@
M82!P87-S=V]R9"!U<VEN9R!T:&4@8W5R<F5N="!E;F-R>7!T:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@(%1H92!P
M;&%I;G1E>'0@<&%S<W=O<F0@=&\@96YC<GEP="X*("`@("`J($!P87)A;2!S
M=')I;F<@)'-A;'0@("`@("`@("`@(%1H92!S86QT('1O('5S92!T;R!E;F-R
M>7!T('1H92!P87-S=V]R9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($EF(&YO="!P<F5S96YT+"!A(&YE=R!S86QT('=I;&P@8F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&=E;F5R871E
M9"X*("`@("`J($!P87)A;2!S=')I;F<@)&5N8W)Y<'1I;VX@("`@(%1H92!K
M:6YD(&]F('!A<W=O<F0@96YC<GEP=&EO;B!T;R!U<V4N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!M9#4M:&5X
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-H;W=?96YC<GEP="`@4V]M92!P
M87-S=V]R9"!S>7-T96US('!R97!E;F0@=&AE(&MI;F0@;V8*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5N8W)Y<'1I;VX@=&\@=&AE
M(&-R>7!T960@<&%S<W=O<F0@*'M32$%]+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@971C*2X@1&5F875L=',@=&\@9F%L<V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R>7!T960@<&%S
M<W=O<F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-R>7!T961087-S=V]R
M9"@D<&QA:6YT97AT+"`D<V%L="`]("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E;F-R>7!T:6]N(#T@)VUD-2UH97@G+"`D<VAO=U]E
M;F-R>7!T(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@1V5T('1H92!S86QT
M('1O('5S92X@*B\*("`@("`@("`D<V%L="`]($%U=&@Z.F=E=%-A;'0H)&5N
M8W)Y<'1I;VXL("1S86QT+"`D<&QA:6YT97AT*3L*"B`@("`@("`@+RH@16YC
M<GEP="!T:&4@<&%S<W=O<F0N("HO"B`@("`@("`@<W=I=&-H("@D96YC<GEP
M=&EO;BD@>PH@("`@("`@(&-A<V4@)W!L86EN)SH*("`@("`@("`@("`@<F5T
M=7)N("1P;&%I;G1E>'0["@H@("`@("`@(&-A<V4@)VUS860G.@H@("`@("`@
M("`@("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@G(B<@+B`D<&QA
M:6YT97AT("X@)R(G+"`G25-/+3@X-3DM,2<L("=55$8M,39,12<I.PH*("`@
M("`@("!C87-E("=S:&$G.@H@("`@("`@("`@("`D96YC<GEP=&5D(#T@8F%S
M938T7V5N8V]D92AM:&%S:"A-2$%32%]32$$Q+"`D<&QA:6YT97AT*2D["B`@
M("`@("`@("`@(')E='5R;B`H)'-H;W=?96YC<GEP="D@/R`G>U-(07TG("X@
M)&5N8W)Y<'1E9"`Z("1E;F-R>7!T960["@H@("`@("`@(&-A<V4@)V-R>7!T
M)SH*("`@("`@("!C87-E("=C<GEP="UD97,G.@H@("`@("`@(&-A<V4@)V-R
M>7!T+6UD-2<Z"B`@("`@("`@8V%S92`G8W)Y<'0M8FQO=V9I<V@G.@H@("`@
M("`@("`@("!R971U<FX@*"1S:&]W7V5N8W)Y<'0@/R`G>V-R>7!T?2<@.B`G
M)RD@+B!C<GEP="@D<&QA:6YT97AT+"`D<V%L="D["@H@("`@("`@(&-A<V4@
M)VUD-2UB87-E-C0G.@H@("`@("`@("`@("`D96YC<GEP=&5D(#T@8F%S938T
M7V5N8V]D92AM:&%S:"A-2$%32%]-1#4L("1P;&%I;G1E>'0I*3L*("`@("`@
M("`@("`@<F5T=7)N("@D<VAO=U]E;F-R>7!T*2`_("=[340U?2<@+B`D96YC
M<GEP=&5D(#H@)&5N8W)Y<'1E9#L*"B`@("`@("`@8V%S92`G<W-H82<Z"B`@
M("`@("`@("`@("1E;F-R>7!T960@/2!B87-E-C1?96YC;V1E*&UH87-H*$U(
M05-(7U-(03$L("1P;&%I;G1E>'0@+B`D<V%L="D@+B`D<V%L="D["B`@("`@
M("`@("`@(')E='5R;B`H)'-H;W=?96YC<GEP="D@/R`G>U-32$%])R`N("1E
M;F-R>7!T960@.B`D96YC<GEP=&5D.PH*("`@("`@("!C87-E("=S;60U)SH*
M("`@("`@("`@("`@)&5N8W)Y<'1E9"`](&)A<V4V-%]E;F-O9&4H;6AA<V@H
M34A!4TA?340U+"`D<&QA:6YT97AT("X@)'-A;'0I("X@)'-A;'0I.PH@("`@
M("`@("`@("!R971U<FX@*"1S:&]W7V5N8W)Y<'0I(#\@)WM3340U?2<@+B`D
M96YC<GEP=&5D(#H@)&5N8W)Y<'1E9#L*"B`@("`@("`@8V%S92`G87!R;60U
M)SH*("`@("`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D<&QA:6YT97AT*3L*
M("`@("`@("`@("`@)&-O;G1E>'0@/2`D<&QA:6YT97AT("X@)R1A<'(Q)"<@
M+B`D<V%L=#L*("`@("`@("`@("`@)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U
M*"1P;&%I;G1E>'0@+B`D<V%L="`N("1P;&%I;G1E>'0I*3L*"B`@("`@("`@
M("`@(&9O<B`H)&D@/2`D;&5N9W1H.R`D:2`^(#`[("1I("T](#$V*2!["B`@
M("`@("`@("`@("`@("`D8V]N=&5X="`N/2!S=6)S='(H)&)I;F%R>2P@,"P@
M*"1I(#X@,38@/R`Q-B`Z("1I*2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9F]R("@D:2`]("1L96YG=&@[("1I(#X@,#L@)&D@/CX](#$I('L*("`@
M("`@("`@("`@("`@("1C;VYT97AT("X]("@D:2`F(#$I(#\@8VAR*#`I(#H@
M)'!L86EN=&5X='LP?3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&)I
M;F%R>2`]($%U=&@Z.E]B:6XH;60U*"1C;VYT97AT*2D["@H@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#`P.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`D;F5W(#T@*"1I("8@,2D@/R`D<&QA:6YT97AT(#H@<W5B<W1R*"1B
M:6YA<GDL(#`L,38I.PH@("`@("`@("`@("`@("`@:68@*"1I("4@,RD@>PH@
M("`@("`@("`@("`@("`@("`@("1N97<@+CT@)'-A;'0["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&D@)2`W*2!["B`@("`@("`@
M("`@("`@("`@("`@)&YE=R`N/2`D<&QA:6YT97AT.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&YE=R`N/2`H)&D@)B`Q*2`_('-U8G-T
M<B@D8FEN87)Y+"`P+"`Q-BD@.B`D<&QA:6YT97AT.PH@("`@("`@("`@("`@
M("`@)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U*"1N97<I*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'`@/2!A<G)A>2@I.PH@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`U.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D
M:R`]("1I("L@-CL*("`@("`@("`@("`@("`@("1J(#T@)&D@*R`Q,CL*("`@
M("`@("`@("`@("`@(&EF("@D:B`]/2`Q-BD@>PH@("`@("`@("`@("`@("`@
M("`@("1J(#T@-3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1P6UT@/2!!=71H.CI?=&]!4%)-1#4H*&]R9"@D8FEN87)Y6R1I72D@/#P@
M,38I('P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*&]R9"@D8FEN87)Y6R1K72D@/#P@."D@?`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H;W)D*"1B:6YA<GE;)&I=*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#4I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!R971U<FX@)R1A<'(Q)"<@+B`D<V%L="`N
M("<D)R`N(&EM<&QO9&4H)R<L("1P*2`N($%U=&@Z.E]T;T%04DU$-2AO<F0H
M)&)I;F%R>5LQ,5TI+"`S*3L*"B`@("`@("`@8V%S92`G;60U+6AE>"<Z"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("@D<VAO=U]E;F-R
M>7!T*2`_("=[340U?2<@+B!M9#4H)'!L86EN=&5X="D@.B!M9#4H)'!L86EN
M=&5X="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A('-A;'0@9F]R('1H92!A<'!R;W!R:6%T92!K:6YD(&]F('!A<W-W;W)D
M(&5N8W)Y<'1I;VXN"B`@("`@*B!/<'1I;VYA;&QY('1A:V5S(&$@<V5E9"!A
M;F0@82!P;&%I;G1E>'0@<&%S<W=O<F0L('1O(&5X=')A8W0@=&AE('-E960*
M("`@("`J(&]F(&%N(&5X:7-T:6YG('!A<W-W;W)D+"!O<B!F;W(@96YC<GEP
M=&EO;B!T>7!E<R!T:&%T('5S92!T:&4@<&QA:6YT97AT"B`@("`@*B!I;B!T
M:&4@9V5N97)A=&EO;B!O9B!T:&4@<V%L="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1E;F-R>7!T:6]N("!4:&4@:VEN9"!O9B!P87-W;W)D(&5N
M8W)Y<'1I;VX@=&\@=7-E+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1&5F875L=',@=&\@;60U+6AE>"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'-E960@("`@("`@(%1H92!S965D('1O(&=E="!T:&4@<V%L="!F<F]M
M("AP<F]B86)L>2!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!P<F5V:6]U<VQY(&=E;F5R871E9"!P87-S=V]R9"DN($1E9F%U;'1S('1O
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G96YE<F%T:6YG
M(&$@;F5W('-E960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@
M("!4:&4@<&QA:6YT97AT('!A<W-W;W)D('1H870@=V4G<F4@9V5N97)A=&EN
M9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@82!S86QT(&9O
M<BX@1&5F875L=',@=&\@;F]N92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&=E;F5R871E9"!O<B!E>'1R86-T960@<V%L="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4V%L="@D96YC<GEP=&EO;B`]("=M9#4M:&5X
M)RP@)'-E960@/2`G)RP@)'!L86EN=&5X="`]("<G*0H@("`@>PH@("`@("`@
M("\O($5N8W)Y<'0@=&AE('!A<W-W;W)D+@H@("`@("`@('-W:71C:"`H)&5N
M8W)Y<'1I;VXI('L*("`@("`@("!C87-E("=C<GEP="<Z"B`@("`@("`@8V%S
M92`G8W)Y<'0M9&5S)SH*("`@("`@("`@("`@:68@*"1S965D*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@<W5B<W1R*'!R96=?<F5P;&%C92@G?%Y[8W)Y
M<'1]?&DG+"`G)RP@)'-E960I+"`P+"`R*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E='5R;B!S=6)S='(H;60U*&UT7W)A;F0H
M*2DL(#`L(#(I.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@)V-R>7!T
M+6UD-2<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>V-R>7!T?7QI)RP@
M)R<L("1S965D*2P@,"P@,3(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("<D,20G("X@<W5B<W1R*&UD-2AM=%]R86YD
M*"DI+"`P+"`X*2`N("<D)SL*("`@("`@("`@("`@?0H*("`@("`@("!C87-E
M("=C<GEP="UB;&]W9FES:"<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>
M>V-R>7!T?7QI)RP@)R<L("1S965D*2P@,"P@,38I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<D,B0G("X@<W5B<W1R
M*&UD-2AM=%]R86YD*"DI+"`P+"`Q,BD@+B`G)"<["B`@("`@("`@("`@('T*
M"B`@("`@("`@8V%S92`G<W-H82<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H
M)WQ>>U-32$%]?"<L("<G+"`D<V5E9"DL("TR,"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@;6AA<VA?:V5Y9V5N7W,R
M:RA-2$%32%]32$$Q+"`D<&QA:6YT97AT+"!S=6)S='(H<&%C:R@G:"HG+"!M
M9#4H;71?<F%N9"@I*2DL(#`L(#@I+"`T*3L*("`@("`@("`@("`@?0H*("`@
M("`@("!C87-E("=S;60U)SH*("`@("`@("`@("`@:68@*"1S965D*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@<W5B<W1R*'!R96=?<F5P;&%C92@G?%Y[
M4TU$-7U\)RP@)R<L("1S965D*2P@+3$V*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E='5R;B!M:&%S:%]K97EG96Y?<S)K*$U(
M05-(7TU$-2P@)'!L86EN=&5X="P@<W5B<W1R*'!A8VLH)V@J)RP@;60U*&UT
M7W)A;F0H*2DI+"`P+"`X*2P@-"D["B`@("`@("`@("`@('T*"B`@("`@("`@
M8V%S92`G87!R;60U)SH*("`@("`@("`@("`@+RH@-C0@8VAA<F%C=&5R<R!T
M:&%T(&%R92!V86QI9"!F;W(@05!2340U('!A<W-W;W)D<RX@*B\*("`@("`@
M("`@("`@)$%04DU$-2`]("<N+S`Q,C,T-38W.#E!0D-$149'2$E*2TQ-3D]0
M45)35%565UA96F%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ)SL*"B`@("`@
M("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U
M8G-T<BAP<F5G7W)E<&QA8V4H)R]>7"1A<'(Q7"0H+GLX?2DN*B\G+"`G7%PQ
M)RP@)'-E960I+"`P+"`X*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1S86QT(#T@)R<["B`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)'-A
M;'0@+CT@)$%04DU$-7MR86YD*#`L(#8S*7T["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!R971U<FX@)'-A;'0["B`@("`@("`@("`@('T*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A(')A;F1O
M;2P@:&]P969U;&QY('!R;VYO=6YC96%B;&4L('!A<W-W;W)D+B!4:&ES(&-A
M;B!B92!U<V5D"B`@("`@*B!W:&5N(')E<V5T=&EN9R!A=71O;6%T:6-A;&QY
M(&$@=7-E<B=S('!A<W-W;W)D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG($$@<F%N9&]M('!A<W-W;W)D"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M;E)A;F1O;5!A<W-W;W)D*"D*("`@('L*("`@("`@("`D=F]W96QS("`@(#T@
M)V%E:6]U>2<["B`@("`@("`@)&-O;G-T86YT<R`]("=B8V1F9VAJ:VQM;G!Q
M<G-T=G=X>B<["B`@("`@("`@)&YU;6)E<G,@("`]("<P,3(S-#4V-S@Y)SL*
M"B`@("`@("`@+RH@06QT97)N871E(&-O;G-T86YT(&%N9"!V;W=E;"!R86YD
M;VT@8VAA<G,@=VET:"!T=V\@<F%N9&]M(&YU;6)E<G,*("`@("`@("`@*B!A
M="!T:&4@96YD+B!4:&ES('-H;W5L9"!P<F]D=6-E(&$@9F%I<FQY('!R;VYO
M=6YC96%B;&4@<&%S<W=O<F0N("HO"B`@("`@("`@)&-H87)S6S!=(#T@<W5B
M<W1R*"1C;VYS=&%N=',L(&UT7W)A;F0H,"P@<W1R;&5N*"1C;VYS=&%N=',I
M("T@,2DL(#$I.PH@("`@("`@("1C:&%R<ULQ72`]('-U8G-T<B@D=F]W96QS
M+"!M=%]R86YD*#`L('-T<FQE;B@D=F]W96QS*2`M(#$I+"`Q*3L*("`@("`@
M("`D8VAA<G-;,ET@/2!S=6)S='(H)&-O;G-T86YT<RP@;71?<F%N9"@P+"!S
M=')L96XH)&-O;G-T86YT<RD@+2`Q*2P@,2D["B`@("`@("`@)&-H87)S6S-=
M(#T@<W5B<W1R*"1V;W=E;',L(&UT7W)A;F0H,"P@<W1R;&5N*"1V;W=E;',I
M("T@,2DL(#$I.PH@("`@("`@("1C:&%R<ULT72`]('-U8G-T<B@D8V]N<W1A
M;G1S+"!M=%]R86YD*#`L('-T<FQE;B@D8V]N<W1A;G1S*2`M(#$I+"`Q*3L*
M("`@("`@("`D8VAA<G-;-5T@/2!S=6)S='(H)&YU;6)E<G,L(&UT7W)A;F0H
M,"P@<W1R;&5N*"1N=6UB97)S*2`M(#$I+"`Q*3L*("`@("`@("`D8VAA<G-;
M-ET@/2!S=6)S='(H)&YU;6)E<G,L(&UT7W)A;F0H,"P@<W1R;&5N*"1N=6UB
M97)S*2`M(#$I+"`Q*3L*"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H)R<L("1C
M:&%R<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<V5T(&]F(&%U
M=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@
M(%1H92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D
M96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%5P9&%T97,@82!S970@;V8@875T:&5N=&EC871I
M;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@(%1H92!O;&0@
M=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@("`@(%1H
M92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L
M<R`@(%1H92!N97<@8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R
M*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W5N<W5P<&]R=&5D)RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5T(&]F(&%U=&AE;G1I8V%T
M:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T
M;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=U;G-U<'!O<G1E
M9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L;',@86QL(&%P<&QI8V%T
M:6]N<R<@<F5M;W9E57-E<B!!4$D@;65T:&]D<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;6]V955S97)$871A*"1U<V5R260I"B`@("!["B`@("`@
M("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@9F]R96%C:"`H)')E9VES
M=')Y+3YL:7-T07!P<RAA<G)A>2@G;F]T;V]L8F%R)RP@)VAI9&1E;B<L("=A
M8W1I=F4G+"`G861M:6XG*2D@87,@)&%P<"D@>PH@("`@("`@("`@("!I9B`H
M)')E9VES=')Y+3YH87--971H;V0H)W)E;6]V955S97)$871A)RP@)&%P<"DI
M('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D<F5G:7-T
M<GDM/F-A;&Q">5!A8VMA9V4H)&%P<"P@)W)E;6]V955S97)$871A)RP@87)R
M87DH)'5S97))9"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J($QI<W1S(&%L;"!U<V5R<R!I;B!T:&4@<WES
M=&5M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)W5N<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&5C:W,@:68@)'5S97))9"!E>&ES=',@:6X@=&AE('-Y<W1E;2X*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R260@57-E<B!)1"!F;W(@=VAI8V@@=&\@8VAE8VL*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T("1U<V5R260@
M86QR96%D>2!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D
M=7-E<DED*0H@("`@>PH@("`@("`@(')E='5R;B!I;E]A<G)A>2@D=7-E<DED
M+"`D=&AI<RT^;&ES=%5S97)S*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!&:6YD<R!O=70@:68@=&AE(&-L
M:65N="!M871C:&5S(&%N(&%L;&]W960@25`*("`@("`J(&)L;V-K+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS
M(&EF('1H97)E(&ES(&$@<V5S<VEO;B!W:71H('9A;&ED(&%U=&@@:6YF;W)M
M871I;VXN(&9O<B!T:&4*("`@("`J('-P96-I9FEE9"!U<V5R+B!)9B!T:&5R
M92!I<VXG="P@8G5T('1H92!C;VYF:6=U<F5D($%U=&@@9')I=F5R('-U<'!O
M<G1S"B`@("`@*B!T<F%N<W!A<F5N="!A=71H96YT:6-A=&EO;BP@=&AE;B!W
M92!T<GD@=&AA="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96%L
M;2`@5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM('1O(&-H96-K+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE('5S
M97(@:7,@875T:&5N=&EC871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!
M=71H96YT:6-A=&5D*"1R96%L;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES<V5T*"1?4T534TE/3ELG7U]A=71H)UTI*2!["B`@("`@("`@("`@(&EF
M("@A96UP='DH)%]315-324].6R=?7V%U=&@G75LG875T:&5N=&EC871E9"==
M*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG7U]A=71H
M)UU;)W5S97))9"==*2`F)@H@("`@("`@("`@("`@("`@*"1?4T534TE/3ELG
M7U]A=71H)UU;)W)E86QM)UT@/3T@)')E86QM*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"%!=71H.CI?8VAE8VM397-S:6]N25`H*2D@>PH@("`@("`@("`@
M("`@("`@("`@($%U=&@Z.E]S971!=71H17)R;W(H05542%]214%33TY?4T53
M4TE/3DE0*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H(4%U=&@Z.E]C:&5C:T)R;W=S97)3
M=')I;F<H*2D@>PH@("`@("`@("`@("`@("`@("`@($%U=&@Z.E]S971!=71H
M17)R;W(H05542%]214%33TY?0E)/5U-%4BD["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@5')Y('1R
M86YS<&%R96YT(&%U=&AE;G1I8V%T:6]N(&YO=RX*("`@("`@("`D875T:"`]
M("9!=71H.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D
M<FEV97(G72D["B`@("`@("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=T
M<F%N<W!A<F5N="<I("8F"B`@("`@("`@("`@("1A=71H+3YT<F%N<W!A<F5N
M="@I*2!["B`@("`@("`@("`@(')E='5R;B!!=71H.CII<T%U=&AE;G1I8V%T
M960H)')E86QM*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G1L>2!L
M;V=G960@:6X@=7-E<BP@:68@=&AE<F4@:7,@;VYE+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1H92!U<V5R260@;V8@=&AE(&-U<G)E;G0@=7-E
M<BP@;W(@9F%L<V4@:68@;F\@=7-E<B!I<PH@("`@("H@("`@("`@("`@("`@
M("`@;&]G9V5D(&EN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!=71H*"D*
M("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=?7V%U=&@G72DI
M('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)U]?875T:"==
M6R=A=71H96YT:6-A=&5D)UTI("8F"B`@("`@("`@("`@("`@("`A96UP='DH
M)%]315-324].6R=?7V%U=&@G75LG=7-E<DED)UTI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)%]315-324].6R=?7V%U=&@G75LG=7-E<DED)UT["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!W:&5T:&5R('1H92!A=71H
M96YT:6-A=&EO;B!B86-K96YD(')E<75E<W1E9"!A('!A<W-W;W)D(&-H86YG
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5VAE=&AE<B!T:&4@
M8F%C:V5N9"!R97%U97-T960@82!P87-S=V]R9"!C:&%N9V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES4&%S<W=O<F1#:&%N9V5297%U97-T960H*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)U]?875T:"==*2`F)@H@
M("`@("`@("`@("`A96UP='DH)%]315-324].6R=?7V%U=&@G75LG875T:&5N
M=&EC871E9"==*2`F)@H@("`@("`@("`@("`A96UP='DH)%]315-324].6R=?
M7V%U=&@G75LG8VAA;F=E4F5Q=65S=&5D)UTI*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R96YT;'D@;&]G
M9V5D+6EN('5S97(@=VET:&]U="!A;GD@9&]M86EN(&EN9F]R;6%T:6]N"B`@
M("`@*B`H92YG+BP@8F]B0&5X86UP;&4N8V]M('=O=6QD(&)E(')E='5R;F5D
M(&%S("=B;V(G*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M=7-E<B!)1"!O9B!T:&4@8W5R<F5N="!U<V5R+"!O<B!F86QS92!I9B!N;R!U
M<V5R"B`@("`@*B`@("`@("`@("`@("`@("!I<R!L;V=G960@:6XN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$)A<F5!=71H*"D*("`@('L*("`@("`@("`D
M=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!I9B`H)'5S97(I('L*
M("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D=7-E<BP@)T`G*3L*("`@("`@
M("`@("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M=7-E<B`]('-U8G-T<B@D=7-E<BP@,"P@)'!O<RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7-E<CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&1O;6%I;B!O9B!C=7)R96YT;'D@;&]G
M9V5D+6EN('5S97(@*&4N9RXL(&)O8D!E>&%M<&QE+F-O;0H@("`@("H@=V]U
M;&0@8F4@<F5T=7)N960@87,@)V5X86UP;&4N8V]M)RDN"B`@("`@*@H@("`@
M("H@0'-I;F-E($AO<F1E(#,N,"XV"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5&AE(&1O;6%I;B!S=69F:7@@;V8@=&AE(&-U<G)E;G0@=7-E<BP@
M;W(@9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%U=&A$;VUA:6XH
M*0H@("`@>PH@("`@("`@(&EF("@D=7-E<B`]($%U=&@Z.F=E=$%U=&@H*2D@
M>PH@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1U<V5R+"`G0"<I.PH@("`@
M("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!S=6)S='(H)'5S97(L("1P;W,@*R`Q*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F5Q=65S=&5D(&-R961E;G1I86P@
M9F]R('1H92!C=7)R96YT;'D@;&]G9V5D(&EN('5S97(L(&EF"B`@("`@*B!P
M<F5S96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-R961E;G1I
M86P@(%1H92!C<F5D96YT:6%L('1O(')E=')I979E+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1H92!R97%U97-T960@8W)E9&5N=&EA;"P@;W(@
M9F%L<V4@:68@;F\@=7-E<B!I<PH@("`@("H@("`@("`@("`@("`@("`@;&]G
M9V5D(&EN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#<F5D96YT:6%L*"1C
M<F5D96YT:6%L*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)%]315-324].
M6R=?7V%U=&@G72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG
M7U]A=71H)UU;)V%U=&AE;G1I8V%T960G72DI('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]396-R970N<&AP)SL*("`@("`@("`@("`@)&-R
M961E;G1I86QS(#T@0'5N<V5R:6%L:7IE*%-E8W)E=#HZ<F5A9"A396-R970Z
M.F=E=$ME>2@G875T:"<I+"`D7U-%4U-)3TY;)U]?875T:"==6R=C<F5D96YT
M:6%L<R==*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1C<F5D
M96YT:6%L<RD@)B8*("`@("`@("`@("`@:7-S970H)&-R961E;G1I86QS6R1C
M<F5D96YT:6%L72DI('L*("`@("`@("`@("`@<F5T=7)N("1C<F5D96YT:6%L
M<ULD8W)E9&5N=&EA;%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AE(')E<75E<W1E9"!C<F5D96YT:6%L(&9O<B!T:&4@8W5R<F5N
M=&QY(&QO9V=E9"!I;B!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-R961E;G1I86P@(%1H92!C<F5D96YT:6%L('1O('-E="X*("`@("`J
M($!P87)A;2!S=')I;F<@)'9A;'5E("`@("`@(%1H92!V86QU92!T;R!S970@
M=&AE(&-R961E;G1I86P@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-R
M961E;G1I86PH)&-R961E;G1I86PL("1V86QU92D*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1?4T534TE/3ELG7U]A=71H)UTI("8F"B`@("`@("`@("`@
M("%E;7!T>2@D7U-%4U-)3TY;)U]?875T:"==6R=A=71H96YT:6-A=&5D)UTI
M*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5C<F5T+G!H
M<"<["B`@("`@("`@("`@("1C<F5D96YT:6%L<R`]($!U;G-E<FEA;&EZ92A3
M96-R970Z.G)E860H4V5C<F5T.CIG971+97DH)V%U=&@G*2P@)%]315-324].
M6R=?7V%U=&@G75LG8W)E9&5N=&EA;',G72DI.PH@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)&-R961E;G1I86QS*2D@>PH@("`@("`@("`@("`@("`@)&-R
M961E;G1I86QS6R1C<F5D96YT:6%L72`]("1V86QU93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1C<F5D96YT:6%L<R`](&%R<F%Y
M*"1C<F5D96YT:6%L(#T^("1V86QU92D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)%]315-324].6R=?7V%U=&@G75LG8W)E9&5N=&EA;',G72`](%-E
M8W)E=#HZ=W)I=&4H4V5C<F5T.CIG971+97DH)V%U=&@G*2P@<V5R:6%L:7IE
M*"1C<F5D96YT:6%L<RDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@82!V87)I86)L92!I;B!T:&4@<V5S<VEO;B!S87EI;F<@=&AA
M="!A=71H;W)I>F%T:6]N(&AA<R!S=6-C965D960L"B`@("`@*B!N;W1E('=H
M:6-H('5S97))9"!W87,@875T:&]R:7IE9"P@86YD(&YO=&4@=VAE;B!T:&4@
M;&]G:6X@=&]O:R!P;&%C92X*("`@("`J"B`@("`@*B!)9B!A('5S97(@;F%M
M92!H;V]K('=A<R!D969I;F5D(&EN('1H92!C;VYF:6=U<F%T:6]N+"!I="!G
M971S(&%P<&QI960*("`@("`J('1O('1H92!U<V5R260@870@=&AI<R!P;VEN
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("`@
M("`@("!4:&4@=7-E<DED('=H;R!H87,@8F5E;B!A=71H;W)I>F5D+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@("`@("`@5&AE(&-R961E
M;G1I86QS(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5A
M;&T@("`@("`@("`@("`@5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM('1O('5S
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1C:&%N9V5297%U97-T960@(%=H
M971H97(@=&\@<F5Q=65S="!T:&%T('1H92!U<V5R(&-H86YG90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE:7(@<&%S<W=O
M<F0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%U=&@H)'5S97))9"P@)&-R
M961E;G1I86QS+"`D<F5A;&T@/2!N=6QL+"`D8VAA;F=E4F5Q=65S=&5D(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)'5S97))9"`]('1R:6TH)'5S97))9"D[
M"B`@("`@("`@)'5S97))9"`]($%U=&@Z.F%D9$AO;VLH)'5S97))9"D["@H@
M("`@("`@("\J($EF('=E)W)E(&%L<F5A9'D@<V5T('=I=&@@=&AI<R!U<V5R
M260L(&1O;B=T(&-O;G1I;G5E+B`J+PH@("`@("`@(&EF("AI<W-E="@D7U-%
M4U-)3TY;)U]?875T:"==6R=U<V5R260G72D@)B8*("`@("`@("`@("`@)%]3
M15-324].6R=?7V%U=&@G75LG=7-E<DED)UT@/3T@)'5S97))9"D@>PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!#;&5A<B!A
M;GD@97AI<W1I;F<@:6YF;RX@*B\*("`@("`@("`D=&AI<RT^8VQE87)!=71H
M*"1R96%L;2D["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5C<F5T
M+G!H<"<["B`@("`@("`@)&-R961E;G1I86QS(#T@4V5C<F5T.CIW<FET92A3
M96-R970Z.F=E=$ME>2@G875T:"<I+"!S97)I86QI>F4H)&-R961E;G1I86QS
M*2D["@H@("`@("`@(&EF("@A96UP='DH)')E86QM*2D@>PH@("`@("`@("`@
M("`D=7-E<DED("X]("=`)R`N("1R96%L;3L*("`@("`@("!]"@H@("`@("`@
M("1?4T534TE/3ELG7U]A=71H)UT@/2!A<G)A>2@*("`@("`@("`@("`@)V%U
M=&AE;G1I8V%T960G(#T^('1R=64L"B`@("`@("`@("`@("=U<V5R260G(#T^
M("1U<V5R260L"B`@("`@("`@("`@("=C<F5D96YT:6%L<R<@/3X@)&-R961E
M;G1I86QS+`H@("`@("`@("`@("`G<F5A;&TG(#T^("1R96%L;2P*("`@("`@
M("`@("`@)W1I;65S=&%M<"<@/3X@=&EM92@I+`H@("`@("`@("`@("`G<F5M
M;W1E7V%D9'(G(#T^(&ES<V5T*"1?4T525D526R=214U/5$5?041$4B==*2`_
M("1?4T525D526R=214U/5$5?041$4B==(#H@;G5L;"P*("`@("`@("`@("`@
M)V)R;W=S97(G(#T^("1'3$]"04Q36R=B<F]W<V5R)UTM/F=E=$%G96YT4W1R
M:6YG*"DL"B`@("`@("`@("`@("=C:&%N9V5297%U97-T960G(#T^("1C:&%N
M9V5297%U97-T960*("`@("`@("`I.PH*("`@("`@("`O*B!296QO860@<')E
M9F5R96YC97,@9F]R('1H92!N97<@=7-E<BX@*B\*("`@("`@("`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^;&]A9%!R969S*"D["B`@("`@("`@3DQ3.CIS971,
M86YG*"1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G;&%N9W5A9V4G*2D[
M"@H@("`@("`@("\J($9E=&-H('1H92!U<V5R)W,@;&%S="!L;V=I;B!T:6UE
M+B`J+PH@("`@("`@("1O;&1?;&]G:6X@/2!`=6YS97)I86QI>F4H)$=,3T)!
M3%-;)W!R969S)UTM/F=E=%9A;'5E*"=L87-T7VQO9VEN)RDI.PH*("`@("`@
M("`O*B!$:7-P;&%Y(&ET+"!I9B!W92!H879E(&$@;F]T:69I8V%T:6]N(&]B
M:F5C="!A;F0@=&AE"B`@("`@("`@("H@<VAO=U]L87-T7VQO9VEN('!R969E
M<F5N8V4@:7,@86-T:79E+B`J+PH@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,
M4ULG;F]T:69I8V%T:6]N)UTI("8F("1'3$]"04Q36R=P<F5F<R==+3YG9716
M86QU92@G<VAO=U]L87-T7VQO9VEN)RDI('L*("`@("`@("`@("`@:68@*&5M
M<'1Y*"1O;&1?;&]G:6Y;)W1I;64G72DI('L*("`@("`@("`@("`@("`@("1'
M3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"A?*"),87-T(&QO9VEN.B!.
M979E<B(I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1O;&1?;&]G:6Y;)VAO<W0G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T
M:6]N)UTM/G!U<V@H<W!R:6YT9BA?*"),87-T(&QO9VEN.B`E<R(I+"!S=')F
M=&EM92@G)6,G+"`D;VQD7VQO9VEN6R=T:6UE)UTI*2P@)VAO<F1E+FUE<W-A
M9V4G*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*'-P<FEN=&8H
M7R@B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(I+"!S=')F=&EM92@G)6,G+"`D
M;VQD7VQO9VEN6R=T:6UE)UTI+"`D;VQD7VQO9VEN6R=H;W-T)UTI+"`G:&]R
M9&4N;65S<V%G92<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!3970@=&AE('5S97(G<R!L87-T7VQO
M9VEN(&EN9F]R;6%T:6]N+@H@("`@("`@("1H;W-T(#T@96UP='DH)%]315)6
M15);)TA45%!?6%]&3U)705)$141?1D]2)UTI"B`@("`@("`@("`@(#\@)%]3
M15)615);)U)%34]415]!1$12)UT*("`@("`@("`@("`@.B`D7U-%4E9%4ELG
M2%144%]87T9/4E=!4D1%1%]&3U(G73L*("`@("`@("`D;&%S=%]L;V=I;B`]
M(&%R<F%Y*"=T:6UE)R`]/B!T:6UE*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]S="<@/3X@0&=E=&AO<W1B>6%D9'(H)&AO<W0I*3L*("`@
M("`@("`D1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)VQA<W1?;&]G:6XG
M+"!S97)I86QI>F4H)&QA<W1?;&]G:6XI*3L*"B`@("`@("`@:68@*"1C:&%N
M9V5297%U97-T960I('L*("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A
M=&EO;B==+3YP=7-H*%\H(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/FAA<T-A
M<&%B:6QI='DH)W5P9&%T92<I*2!["B`@("`@("`@("`@("`@("`O*B!!(&)I
M="!O9B!A(&ML=61G92X@(%523"!I<R!S970@9G)O;2!T:&4@;&]G:6X@<V-R
M965N+"!B=70*("`@("`@("`@("`@("`@("`J('=E(&%R96XG="!C;VUP;&5T
M96QY(&-E<G1A:6X@=V4@9V]T(&AE<F4@9G)O;2!T:&4@;&]G:6X*("`@("`@
M("`@("`@("`@("`J('-C<F5E;BX@(%-O(&%N>2!S8W)E96X@=VAI8V@@8V%L
M;',@<V5T075T:"@I('=H:6-H(&AA<R!A"B`@("`@("`@("`@("`@("`@*B!U
M<FP@=VEL;"!E;F0@=7`@9V]I;F<@=&AE<F4N("!3:&]U;&0@8F4@3TLN("HO
M"B`@("`@("`@("`@("`@("`D=7)L7W!A<F%M(#T@571I;#HZ9V5T1F]R;41A
M=&$H)W5R;"<I.PH*("`@("`@("`@("`@("`@(&EF("@D=7)L7W!A<F%M*2![
M"B`@("`@("`@("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH571I;#HZ
M<F5M;W9E4&%R86UE=&5R*"1U<FQ?<&%R86TL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-E
M<W-I;VY?;F%M92@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T<G5E*3L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7W1O
M(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D
M92<I("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R]I;F1E
M>"YP:'`G.PH@("`@("`@("`@("`@("`@("`@("1R971U<FY?=&\@/2!5=&EL
M.CIA9&1087)A;65T97(H)')E='5R;E]T;RP@)W5R;"<L("1U<FPI.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5T
M=7)N7W1O(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=W96)R;V]T)RP@)VAO<F1E)RD*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G+VEN9&5X+G!H<"<I.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)W-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<"<I.PH@("`@("`@("`@("`@
M("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F5T=7)N
M7W1O)R`]/B`D<F5T=7)N7W1O*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@9F%L<V4I.PH*("`@("`@("`@("`@
M("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@("`@("`@("`@
M("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;&5A<G,@86YY(&%U=&AE;G1I8V%T:6]N('1O:V5N<R!I
M;B!T:&4@8W5R<F5N="!S97-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)')E86QM("!4:&4@875T:&5N=&EC871I;VX@<F5A;&T@=&\@8VQE
M87(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R075T:"@D<F5A;&T@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)')E86QM*2`F)B!I<W-E
M="@D7U-%4U-)3TY;)U]?875T:"==6R1R96%L;5TI*2!["B`@("`@("`@("`@
M("1?4T534TE/3ELG7U]A=71H)UU;)')E86QM72`](&%R<F%Y*"D["B`@("`@
M("`@("`@("1?4T534TE/3ELG7U]A=71H)UU;)')E86QM75LG875T:&5N=&EC
M871E9"==(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1?4T53
M4TE/3ELG7U]A=71H)UTI*2!["B`@("`@("`@("`@("1?4T534TE/3ELG7U]A
M=71H)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`D7U-%4U-)3TY;)U]?875T
M:"==6R=A=71H96YT:6-A=&5D)UT@/2!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J(%)E;6]V92!T:&4@=7-E<B=S(&-A8VAE9"!P<F5F97)E;F-E<R!I
M9B!T:&5Y(&%R92!P<F5S96YT+B`J+PH@("`@("`@(&EF("AI<W-E="@D1TQ/
M0D%,4ULG<F5G:7-T<GDG72DI('L*("`@("`@("`@("`@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/G5N;&]A9%!R969S*"D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@27,@=&AE(&-U<G)E;G0@=7-E<B!A;B!A9&UI;FES=')A
M=&]R/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@
M($%L;&]W('5S97)S('=I=&@@=&AI<R!P97)M:7-S:6]N(&%D;6EN(&%C8V5S
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&-U
M<G)E;G0@8V]N=&5X="X*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M;&5V
M96P@(%1H92!L979E;"!O9B!P97)M:7-S:6]N<R!T;R!C:&5C:R!F;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("A015)-4U]%1$E4+"!0
M15)-4U]$14Q%5$4L(&5T8RDN($1E9F%U;'1S"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T;R!015)-4U]%1$E4+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<B`@("`@("`@5&AE('5S97(@=&\@8VAE8VLN($1E9F%U
M;'1S('1O($%U=&@Z.F=E=$%U=&@H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H:7,@:7,@86X@861M:6X@=7-E
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!9&UI;B@D<&5R;6ES<VEO;B`]
M(&YU;&PL("1P97)M;&5V96P@/2!N=6QL+"`D=7-E<B`](&YU;&PI"B`@("![
M"B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H)'5S97(@/3T]
M(&YU;&PI('L*("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG971!=71H*"D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H0&ES7V%R<F%Y*"1C;VYF6R=A=71H
M)UU;)V%D;6EN<R==*2D@>PH@("`@("`@("`@("!I9B`H)'5S97(@)B8@:6Y?
M87)R87DH)'5S97(L("1C;VYF6R=A=71H)UU;)V%D;6EN<R==*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D<&5R;6ES<VEO;BDI('L*("`@
M("`@("`@("`@:68@*&ES7VYU;&PH)'!E<FUL979E;"DI('L*("`@("`@("`@
M("`@("`@("1P97)M;&5V96P@/2!015)-4U]%1$E4.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<&5R;7,G72T^:&%S4&5R
M;6ES<VEO;B@D<&5R;6ES<VEO;BP@)'5S97(L("1P97)M;&5V96PI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@07!P;&EE<R!A(&AO;VL@9&5F:6YE9"!B>2!T:&4@9G5N8W1I;VX@
M7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0H*2!T;PH@("`@("H@=&AE(&=I
M=F5N('5S97(@;F%M92!I9B!T:&ES(&9U;F-T:6]N(&5X:7-T<R!A;F0@=7-E
M<B!H;V]K<R!A<F4@96YA8FQE9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!S:&]U;&0@8F4@8V%L;&5D(&EF(&$@8F%C:V5N9"=S('5S97(@;F%M92!N
M965D<R!T;R!B90H@("`@("H@8V]N=F5R=&5D('1O(&$@*'5N:7%U92D@2&]R
M9&4@=7-E<B!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S
M97))9"`@5&AE(&]R:6=I;F%L('5S97(@;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('5S97(@;F%M92!W:71H('1H92!H;V]K(&%P
M<&QI960@=&\@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$AO;VLH)'5S
M97))9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF
M("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W5S97)N86UE)UTI*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O:&]O
M:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G7W5S
M97)N86UE7VAO;VM?9G)O;6)A8VME;F0G*2D@>PH@("`@("`@("`@("`@("`@
M)'5S97))9"`](&-A;&Q?=7-E<E]F=6YC*"=?=7-E<FYA;65?:&]O:U]F<F]M
M8F%C:V5N9"<L("1U<V5R260I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'5S97))9#L*("`@('T*"B`@("`O*BH*("`@("`J
M($%P<&QI97,@82!H;V]K(&1E9FEN960@8GD@=&AE(&9U;F-T:6]N(%]U<V5R
M;F%M95]H;V]K7W1O8F%C:V5N9"@I('1O"B`@("`@*B!T:&4@9VEV96X@=7-E
M<B!N86UE(&EF('1H:7,@9G5N8W1I;VX@97AI<W1S(&%N9"!U<V5R(&AO;VMS
M(&%R92!E;F%B;&5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D('-H;W5L
M9"!B92!C86QL960@:68@82!(;W)D92!U<V5R(&YA;64@;F5E9',@=&\@8F4@
M8V]N=F5R=&5D"B`@("`@*B!T;R!A(&)A8VME;F0G<R!U<V5R(&YA;64@;W(@
M9&ES<&QA>65D('1O('1H92!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97))9"`@5&AE($AO<F1E('5S97(@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5S97(@;F%M92!W:71H('1H92!H
M;V]K(&%P<&QI960@=&\@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M94AO;VLH)'5S97))9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@
M("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W5S97)N86UE)UTI
M*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]C
M;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G7W5S97)N86UE7VAO;VM?=&]B86-K96YD)RDI('L*("`@("`@("`@
M("`@("`@("1U<V5R260@/2!C86QL7W5S97)?9G5N8R@G7W5S97)N86UE7VAO
M;VM?=&]B86-K96YD)RP@)'5S97))9"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=7-E<DED.PH@("`@?0H*("`@("\J*@H@
M("`@("H@475E<FEE<R!T:&4@8W5R<F5N="!!=71H(&]B:F5C="!T;R!F:6YD
M(&]U="!I9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A<&%B:6QI
M='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET>2`@
M5&AE(&-A<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P86)I;&ET>2!I
M<R!S=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI
M='DH)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D
M=&AI<RT^8V%P86)I;&ET:65S6R1C87!A8FEL:71Y72D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!54DD@;V8@=&AE(&QO9VEN('-C<F5E
M;B!F;W(@=&AE(&-U<G)E;G0@875T:&5N=&EC871I;VX*("`@("`J(&UE=&AO
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L
M:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H
M92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@55))+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971,;V=I;E-C<F5E;B@D87!P(#T@)VAO<F1E
M)RP@)'5R;"`]("<G*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@
M("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG
M9')I=F5R)UTI.PH@("`@("`@(')E='5R;B`D875T:"T^7V=E=$QO9VEN4V-R
M965N*"1A<'`L("1U<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@;F%M960@<&%R86UE=&5R(&9O<B!T:&4@8W5R<F5N="!A=71H(&1R
M:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A;2`@5&AE
M('!A<F%M971E<B!T;R!F971C:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('!A<F%M971E<B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1T:&ES+3Y?<&%R86US6R1P87)A;5TI(#\@)'1H:7,M/E]P87)A;7-;
M)'!A<F%M72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!N86UE(&]F('1H92!A=71H96YT:6-A=&EO;B!P<F]V:61E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%5S960@8GD@<F5C
M=7)S:79E(&-A;&QS('=H96X@=6YT86YG;&EN9R!C;VUP;W-I=&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@875T:"X*("`@("`J($!P87)A;2!A
M<G)A>2`@)'!A<F%M<R`@57-E9"!B>2!R96-U<G-I=F4@8V%L;',@=VAE;B!U
M;G1A;F=L:6YG(&-O;7!O<VET90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!A=71H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M;F%M92!O9B!T:&4@9')I=F5R(&-U<G)E;G1L>2!P<F]V:61I;F<*("`@("`J
M("`@("`@("`@("`@("`@("!A=71H96YT:6-A=&EO;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4')O=FED97(H)&1R:79E<B`](&YU;&PL("1P87)A;7,@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@
M:68@*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@("`@("`@)&1R:79E<B`]
M("1C;VYF6R=A=71H)UU;)V1R:79E<B==.PH@("`@("`@('T*("`@("`@("!I
M9B`H:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@
M2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G875T:"<L"B`@("`@("`@("`@("`@
M("!I<U]A<G)A>2@D9')I=F5R*2`_("1D<FEV97);,5T@.B`D9')I=F5R*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D9')I=F5R(#T]("=A<'!L:6-A=&EO
M;B<I('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1P87)A;7-;)V%P<"==
M*2`_("1P87)A;7-;)V%P<"==(#H@)V%P<&QI8V%T:6]N)SL*("`@("`@("!]
M(&5L<V5I9B`H)&1R:79E<B`]/2`G8V]M<&]S:71E)RD@>PH@("`@("`@("`@
M("!I9B`H*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A
M;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'!A<F%M<RDI("8F"B`@("`@("`@
M("`@("`@("`A96UP='DH)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I;E]D<FEV
M97)=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N($%U=&@Z.F=E=%!R;W9I
M9&5R*"1P87)A;7-;)V1R:79E<G,G75LD;&]G:6Y?9')I=F5R75LG9')I=F5R
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:7-S970H)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I;E]D<FEV97)=6R=P87)A
M;7,G72D@/R`D<&%R86US6R=D<FEV97)S)UU;)&QO9VEN7V1R:79E<EU;)W!A
M<F%M<R==(#H@;G5L;"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("=C;VUP;W-I=&4G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B`D9')I=F5R.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&QO9V]U="!R96%S;VXN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@3VYE(&]F('1H92!L;V=O=70@<F5A<V]N<R`H<V5E
M('1H92!!551(7TQ/1T]55%\J"B`@("`@*B`@("`@("`@("`@("`@("!C;VYS
M=&%N=',@9F]R('1H92!V86QI9"!R96%S;VYS*2X@(%)E='5R;G,@;G5L;"!I
M9B!T:&5R90H@("`@("H@("`@("`@("`@("`@("`@:7,@;F\@;&]G;W5T(')E
M87-O;B!P<F5S96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,;V=O=712
M96%S;VXH*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG7U]A
M=71H97)R;W(G75LG='EP92==*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)U]?875T:&5R<F]R)UU;)W1Y<&4G73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@571I;#HZ9V5T1F]R;41A=&$H05542%]2
M14%33TY?4$%204TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('-T871U<R!S=')I;F<@=&\@=7-E(&9O<B!L;V=O=70@
M;65S<V%G97,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L
M;V=O=70@<F5A<V]N('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3&]G;W5T4F5A<V]N4W1R:6YG*"D*("`@('L*("`@("`@("!S=VET8V@@*$%U
M=&@Z.F=E=$QO9V]U=%)E87-O;B@I*2!["B`@("`@("`@8V%S92!!551(7U)%
M05-/3E]315-324]..@H@("`@("`@("`@("`D=&5X="`]('-P<FEN=&8H7R@B
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G*2D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($%55$A?4D5!4T].7U-%
M4U-)3TY)4#H*("`@("`@("`@("`@)'1E>'0@/2!S<')I;G1F*%\H(EEO=7(@
M26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB*2P@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G;F%M92<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@05542%]214%33TY?0E)/5U-%4CH*("`@("`@("`@("`@)'1E
M>'0@/2!S<')I;G1F*%\H(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB*2P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<I*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@05542%]214%33TY?
M3$]'3U54.@H@("`@("`@("`@("`D=&5X="`](%\H(EEO=2!H879E(&)E96X@
M;&]G9V5D(&]U="XB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@05542%]214%33TY?1D%)3$5$.@H@("`@("`@("`@("`D=&5X="`](%\H
M(DQO9VEN(&9A:6QE9"XB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@05542%]214%33TY?0D%$3$]'24XZ"B`@("`@("`@("`@("1T97AT
M(#T@7R@B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@05542%]214%33TY?15A025)%1#H*
M("`@("`@("`@("`@)'1E>'0@/2!?*")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+B(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!!551(7U)%
M05-/3E]-15-304=%.@H@("`@("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;
M)U]?875T:&5R<F]R)UU;)VUS9R==*2D@>PH@("`@("`@("`@("`@("`@)'1E
M>'0@/2`D1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG;7-G)UT["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&5X="`](%5T:6PZ.F=E
M=$9O<FU$871A*$%55$A?4D5!4T].7TU31U]005)!32D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("1T97AT(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5N97)A=&5S('1H92!C;W)R96-T('!A<F%M971E<G,@=&\@<&%S<R!T
M;R!T:&4@9VEV96X@;&]G;W5T(%523"X*("`@("`J"B`@("`@*B!)9B!N;R!R
M96%S;VXO;7-G(&ES('!A<W-E9"!I;BP@=7-E('1H92!C=7)R96YT(&=L;V)A
M;"!A=71H96YT:6-A=&EO;@H@("`@("H@97)R;W(@;65S<V%G92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@(%1H92!54DP@=&\@<F5D
M:7)E8W0@=&\N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96%S;VX@(%1H92!R
M96%S;VX@9F]R(&QO9V]U="X*("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@
M("`@268@<F5A<V]N(&ES($%55$A?4D5!4T].7TU%4U-!1T4L('1H92!M97-S
M86=E('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1I<W!L87D@
M=&\@=&AE('5S97(N"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@9F]R;6%T
M=&5D(%523`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1,;V=O=71087)A;65T
M97)S*"1U<FPL("1R96%S;VX@/2!N=6QL+"`D;7-G(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H:7-?;G5L;"@D<F5A<V]N*2D@>PH@("`@("`@("`@("`D
M<F5A<V]N(#T@075T:#HZ9V5T3&]G;W5T4F5A<V]N*"D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)')E87-O;BD@>PH@("`@("`@("`@("`D=7)L(#T@571I
M;#HZ861D4&%R86UE=&5R*"1U<FPL($%55$A?4D5!4T].7U!!4D%-+"`D<F5A
M<V]N+"!F86QS92D["B`@("`@("`@("`@(&EF("@D<F5A<V]N(#T]($%55$A?
M4D5!4T].7TU%4U-!1T4I('L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL
M*"1M<V<I*2!["B`@("`@("`@("`@("`@("`@("`@)&US9R`]($%U=&@Z.F=E
M=$QO9V]U=%)E87-O;E-T<FEN9R@I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!!
M551(7U)%05-/3E]-4T=?4$%204TL("1M<V<L(&9A;'-E*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!54DD@;V8@=&AE(&QO9VEN('-C
M<F5E;B!F;W(@=&AI<R!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@=&\@=7-E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7)L("!4:&4@55),('1O(')E9&ER96-T('1O(&%F=&5R
M(&QO9VEN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]G
M:6X@<V-R965N(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$QO9VEN
M4V-R965N*"1A<'`@/2`G:&]R9&4G+"`D=7)L(#T@)R<I"B`@("!["B`@("`@
M("`@)&QO9VEN(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=W96)R;V]T)RP@)&%P<"D@+B`G+VQO9VEN+G!H<"<L('1R=64I.PH@
M("`@("`@(&EF("@A96UP='DH)'5R;"DI('L*("`@("`@("`@("`@)&QO9VEN
M(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V=I;BP@)W5R;"<L("1U<FPI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&QO9VEN.PH@("`@?0H*("`@("\J
M*@H@("`@("H@075T:&5N=&EC871I;VX@<W1U8BX*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@1F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]A=71H96YT:6-A=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&5R<F]R(&UE<W-A9V4@
M9F]R(&%N(&EN=F%L:60@875T:&5N=&EC871I;VXN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M='EP92`@5&AE('1Y<&4@;V8@97)R;W(@*$%55$A?4D5!4T].(&-O;G-T86YT
M*2X*("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@(%1H92!E<G)O<B!M97-S
M86=E+W)E87-O;B!F;W(@:6YV86QI9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@875T:&5N=&EC871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M971!=71H17)R;W(H)'1Y<&4L("1M<V<@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1'3$]"04Q36R=?7V%U=&AE<G)O<B==(#T@87)R87DH*3L*("`@("`@("`D
M1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG='EP92==(#T@)'1Y<&4["B`@("`@
M("`@)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)VUS9R==(#T@)&US9SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&5R<F]R('1Y<&4@9F]R
M(&%N(&EN=F%L:60@875T:&5N=&EC871I;VX@;W(@9F%L<V4@;VX@97)R;W(N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!%<G)O<B!T>7!E(&]R(&9A;'-E(&]N(&5R<F]R"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G971!=71H17)R;W(H*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG='EP92==
M*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]?875T:&5R<F]R
M)UU;)W1Y<&4G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%P<')O<')I871E
M(&%U=&AE;G1I8V%T:6]N(&1R:79E<BP@:68@86YY+"!S96QE8W1I;F<@8GD@
M=&AE"B`@("`@*B!S<&5C:69I960@<&%R86UE=&5R+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@("`@("`@5&AE('!A<F%M971E<B!N86UE+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("!4:&4@<&%R86UE=&5R(&QI<W0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97)P87)A;7,@($$@;&ES="!O
M9B!P87)A;65T97)S('1O('!A<W,@=&\@=&AE(&1R:79E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;B!V86QU92!O<B!C86QL960@=7-E
M<B!F=6YC(&]R(&YU;&P@:68@=6YA=F%I;&%B;&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V=E=$1R:79E<D)Y4&%R86TH)&YA;64L("1P87)A;7,L("1D<FEV
M97)P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R1N86UE72D@)B8*("`@("`@("`@("`@9G5N8W1I;VY?97AI<W1S
M*"1P87)A;7-;)&YA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@8V%L;%]U
M<V5R7V9U;F-?87)R87DH)'!A<F%M<ULD;F%M95TL("1D<FEV97)P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!097)F;W)M<R!C:&5C:R!O;B!S97-S:6]N('1O('-E92!I
M9B!)4"!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H90H@("`@("H@;&%S
M="!A8V-E<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF($E0($%D9')E<W,@
M:7,@=&AE('-A;64@*&]R('1H92!C:&5C:R!I<PH@("`@("H@("`@("`@("`@
M("`@("`@("!D:7-A8FQE9"DL(&9A;'-E(&EF('1H92!A9&1R97-S(&AA<R!C
M:&%N9V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM397-S:6]N25`H
M*0H@("`@>PH@("`@("`@(')E='5R;B`H96UP='DH)$=,3T)!3%-;)V-O;F8G
M75LG875T:"==6R=C:&5C:VEP)UTI('Q\"B`@("`@("`@("`@("`@("`H:7-S
M970H)%]315-324].6R=?7V%U=&@G75LG<F5M;W1E7V%D9'(G72D@)B8@)%]3
M15-324].6R=?7V%U=&@G75LG<F5M;W1E7V%D9'(G72`]/2`D7U-%4E9%4ELG
M4D5-3U1%7T%$1%(G72DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4&5R9F]R
M;7,@8VAE8VL@;VX@<V5S<VEO;B!T;R!S964@:68@8G)O=W-E<B!S=')I;F<@
M:&%S(&-H86YG960@<VEN8V4*("`@("`J('1H92!L87-T(&%C8V5S<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@8G)O=W-E<B!S=')I;F<@:7,@=&AE('-A
M;64L(&9A;'-E(&EF('1H90H@("`@("H@("`@("`@("`@("`@("`@("!S=')I
M;F<@:&%S(&-H86YG960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:T)R
M;W=S97)3=')I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B`H96UP='DH)$=,
M3T)!3%-;)V-O;F8G75LG875T:"==6R=C:&5C:V)R;W=S97(G72D@?'P*("`@
M("`@("`@("`@("`@("1?4T534TE/3ELG7U]A=71H)UU;)V)R;W=S97(G72`]
M/2`D1TQ/0D%,4ULG8G)O=W-E<B==+3YG971!9V5N=%-T<FEN9R@I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1O(&%L;&]W960@-C0@8VAA
M<F%C=&5R<R!F;W(@05!2340U('!A<W-W;W)D<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M=F%L=64*("`@("`J($!P87)A;2!I;G1E9V5R("1C;W5N=`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("`D=F%L=64@8V]N=F5R=&5D('1O('1H92`V
M-"!-1#4@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W1O05!2
M340U*"1V86QU92P@)&-O=6YT*0H@("`@>PH@("`@("`@("\J(#8T(&-H87)A
M8W1E<G,@=&AA="!A<F4@=F%L:60@9F]R($%04DU$-2!P87-S=V]R9',N("HO
M"B`@("`@("`@)$%04DU$-2`]("<N+S`Q,C,T-38W.#E!0D-$149'2$E*2TQ-
M3D]045)35%565UA96F%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ)SL*"B`@
M("`@("`@)&%P<FUD-2`]("<G.PH@("`@("`@("1C;W5N="`](&%B<R@D8V]U
M;G0I.PH@("`@("`@('=H:6QE("@M+21C;W5N="D@>PH@("`@("`@("`@("`D
M87!R;60U("X]("1!4%)-1#5;)'9A;'5E("8@,'@S9ET["B`@("`@("`@("`@
M("1V86QU92`^/CT@-CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1A<')M
M9#4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!H97AA9&5C:6UA
M;"!S=')I;F<@=&\@8FEN87)Y(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5X("!(
M97@@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@0FEN87)Y
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B:6XH)&AE>"D*("`@('L*
M("`@("`@("`D8FEN(#T@)R<["B`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D
M:&5X*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;&5N9W1H.R`D:2`K
M/2`R*2!["B`@("`@("`@("`@("1T;7`@/2!S<V-A;F8H<W5B<W1R*"1H97@L
M("1I+"`R*2P@)R5X)RD["B`@("`@("`@("`@("1B:6X@+CT@8VAR*&%R<F%Y
M7W-H:69T*"1T;7`I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1B:6X[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C
M;VYC<F5T92!!=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O
M;F-R971E($%U=&@@<W5B8VQA<W,@=&\@<F5T=7)N+B!4:&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@:7,@8F%S960@;VX@=&AE('-T;W)A9V4@
M9')I=F5R("@D9')I=F5R*2X@5&AE(&-O9&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@)&1R:79E
M<B!I<R!A;B!A<G)A>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T
M:&5N('=E('=I;&P@;&]O:R!I;B`D9')I=F5R6S!=+VQI8B]!=71H+R!F;W(@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@:6UP
M;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET
M:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT
M(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!!=71H("!4:&4@;F5W;'D@
M8W)E871E9"!C;VYC<F5T92!!=71H(&EN<W1A;F-E+"!O<B!F86QS92!O;B!A
M;@H@("`@("H@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@
M("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D9')I=F5R(#T@)&1R
M:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M
M92@D9')I=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I('Q\("@D
M9')I=F5R(#T]("=N;VYE)RDI('L*("`@("`@("`@("`@)&%U=&@@/2`F;F5W
M($%U=&@H*3L*("`@("`@("`@("`@<F5T=7)N("1A=71H.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@
M)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V%U=&@G+"`D9')I
M=F5R*3L*("`@("`@("!]"@H@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R
M<R<L(#$I.PH@("`@("`@("1I;F-L=61E7V5R<F]R(#T@)R<["B`@("`@("`@
M:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@
M+B`G+VQI8B]!=71H+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T%U=&@O
M)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<W-E="@D<&AP7V5R<F]R;7-G*2D@>PH@("`@("`@("`@("`D:6YC;'5D95]E
M<G)O<B`]("1P:'!?97)R;W)M<V<["B`@("`@("`@?0H@("`@("`@(&EN:5]R
M97-T;W)E*"=T<F%C:U]E<G)O<G,G*3L*"B`@("`@("`@)&-L87-S(#T@)T%U
M=&A?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA
M<W,I*2!["B`@("`@("`@("`@("1A=71H(#T@)FYE=R`D8VQA<W,H)'!A<F%M
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%U=&@@/2!014%2
M.CIR86ES945R<F]R*"=!=71H($1R:79E<B`H)R`N("1C;&%S<R`N("<I(&YO
M="!F;W5N9"<@+B`H)&EN8VQU9&5?97)R;W(@/R`G.B`G("X@)&EN8VQU9&5?
M97)R;W(@.B`G)RD@+B`G+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1A=71H.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@075T:"!I;G-T86YC92!B
M87-E9"!O;@H@("`@("H@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A
M(&YE=R!I;G-T86YC92!I9B!N;R!!=71H(&EN<W1A;F-E('=I=&@*("`@("`J
M('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J
M"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(&%U=&AE
M;G1I8V%T:6]N('-O=7)C97,@*&%N9"P@=&AU<RP*("`@("`J(&UU;'1I<&QE
M($%U=&@@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)D%U=&@Z
M.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!!=71H('-U8F-L87-S('1O(')E
M='5R;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@5&AI<R!I<R!B
M87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1D<FEV97(I+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!4:&4@8V]D92!I<R!D>6YA;6EC86QL
M>2!I;F-L=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@075T:"`@5&AE(&-O;F-R971E($%U=&@@<F5F97)E;F-E+"!O
M<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI
M<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(;W)D
M93HZ9V5T1')I=F5R0V]N9FEG*"=A=71H)RP*("`@("`@("`@("`@("`@(&ES
M7V%R<F%Y*"1D<FEV97(I(#\@)&1R:79E<ELQ72`Z("1D<FEV97(I.PH@("`@
M("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D
M9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*&5M<'1Y*"1I;G-T86YC
M97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I
M9VYA='5R95T@/2`F075T:#HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92](:7-T;W)Y+G!H<```
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8T,C4`,3`U
M,34T,S$P-C$`,#(P,S<W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@2&ES=&]R>3HZ(&-L87-S
M('!R;W9I9&5S(&$@;65T:&]D(&]F('1R86-K:6YG(&-H86YG97,@:6X@2&]R
M9&4*("H@;V)J96-T<RP@<W1O<F5D(&EN(&$@4U%,('1A8FQE+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP+'8@,2XR."XR
M+C$T(#(P,#8O,#4O,#,@,C$Z-#8Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J
M($!P86-K86=E($AO<F1E7TAI<W1O<GD*("HO"F-L87-S($AO<F1E7TAI<W1O
M<GD@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A($1"(&EN<W1A;F-E
M('1O(&UA;F%G92!T:&4@:&ES=&]R>2X*("`@("`J"B`@("`@*B!`=F%R($1"
M"B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@2&ES=&]R
M>2!I;G-T86YC92X*("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@
M:6YS=&%N8V4@:68@;F\@2&ES=&]R>2!I;G-T86YC90H@("`@("H@8W5R<F5N
M=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E
M(&EN=F]K960@87,Z("1V87(@/2`F2&ES=&]R>3HZ<VEN9VQE=&]N*"D*("`@
M("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7TAI<W1O<GD@(%1H92!C;VYC<F5T
M92!(:7-T;W)Y(')E9F5R96YC92P@;W(@9F%L<V4@;VX@86X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D:&ES=&]R
M>3L*"B`@("`@("`@:68@*"%I<W-E="@D:&ES=&]R>2DI('L*("`@("`@("`@
M("`@)&AI<W1O<GD@/2`F;F5W($AO<F1E7TAI<W1O<GDH*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:&ES=&]R>3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95](
M:7-T;W)Y*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M(&EF("AE;7!T>2@D8V]N9ELG<W%L)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?9&(@/2!014%2.CIR86ES945R<F]R*%\H(E1H92!(:7-T;W)Y('-Y<W1E
M;2!I<R!D:7-A8FQE9"XB*2D["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E
M7V]N8V4@)T1"+G!H<"<["B`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ8V]N
M;F5C="@D8V]N9ELG<W%L)UTI.PH*("`@("`@("`O*B!3970@1$(@<&]R=&%B
M:6QI='D@;W!T:6]N<RX@*B\*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B
M+"`G1$)?8V]M;6]N)RDI('L*("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^
M7V1B+3YP:'!T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI
M='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E4
M65]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]0
M3U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@3&]G<R!A;B!E=F5N="!T;R!A;B!I=&5M)W,@:&ES=&]R>2!L;V<N(%1H
M92!I=&5M(&UU<W0@8F4@=6YI<75E;'D*("`@("`J(&ED96YT:69I960@8GD@
M)&=U:60N($%N>2!O=&AE<B!D971A:6QS(&%B;W5T('1H92!E=F5N="!A<F4@
M<&%S<V5D(&EN"B`@("`@*B`D871T<FEB=71E<RX@4W1A;F1A<F0@<W5G9V5S
M=&5D(&%T=')I8G5T97,@87)E.@H@("`@("H*("`@("`J("`@)W=H;R<@/3X@
M5&AE(&ED(&]F('1H92!U<V5R('1H870@<&5R9F]R;65D('1H92!A8W1I;VX@
M*'=I;&P@8F4@861D960*("`@("`J("`@("`@("`@("`@875T;VUA=&EC86QL
M>2!I9B!N;W0@<')E<V5N="DN"B`@("`@*@H@("`@("H@("`G=',G(#T^(%1I
M;65S=&%M<"!O9B!T:&4@86-T:6]N("AT:&ES('=I;&P@8F4@861D960@875T
M;VUA=&EC86QL>2!I9@H@("`@("H@("`@("`@("`@(&ET(&ES(&YO="!P<F5S
M96YT*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G=6ED("`@("`@
M("`@("`@5&AE('5N:7%U92!I9&5N=&EF:65R(&]F('1H92!E;G1R>2!T;PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D9"!T;RX*
M("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R`@("`@("!4:&4@:&%S
M:"!O9B!N86UE(#T^('9A;'5E(&5N=')I97,@=&AA=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&1E<V-R:6)E('1H:7,@979E;G0N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5P;&%C94%C=&EO;B`@268@)&%T
M=')I8G5T97-;)V%C=&EO;B==(&ES(&%L<F5A9'D*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!P<F5S96YT(&EN('1H92!I=&5M)W,@
M:&ES=&]R>2!L;V<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7!D871E('1H870@96YT<GD@:6YS=&5A9"!O9B!C<F5A=&EN9R!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;F5W(&]N
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@
M5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QO9R@D9W5I9"P@)&%T=')I8G5T97,@/2!A<G)A
M>2@I+"`D<F5P;&%C94%C=&EO;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&(["B`@("`@("`@?0H*("`@("`@("`D:&ES
M=&]R>2`]("8D=&AI<RT^9V5T2&ES=&]R>2@D9W5I9"D["B`@("`@("`@:68@
M*"$D:&ES=&]R>2!\?"!I<U]A*"1H:7-T;W)Y+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:&ES=&]R>3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AE;7!T>2@D871T<FEB=71E<ULG=VAO)UTI*2!["B`@("`@("`@
M("`@("1A='1R:6)U=&5S6R=W:&\G72`]($%U=&@Z.F=E=$%U=&@H*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1A='1R:6)U=&5S6R=T<R==*2D@
M>PH@("`@("`@("`@("`D871T<FEB=71E<ULG=',G72`]('1I;64H*3L*("`@
M("`@("!]"@H@("`@("`@("\J($EF('=E('=A;G0@=&\@<F5P;&%C92!A;B!E
M;G1R>2!W:71H('1H92!S86UE(&%C=&EO;BP@=')Y(&%N9"!F:6YD"B`@("`@
M("`@("H@;VYE+B!4<F%C:R!W:&5T:&5R(&]R(&YO="!W92!S=6-C965D(&EN
M("1D;VYE+"!S;R!W92!K;F]W('=H971H97(*("`@("`@("`@*B!O<B!N;W0@
M=&\@861D('1H92!E;G1R>2!L871E<BX@*B\*("`@("`@("`D9&]N92`](&9A
M;'-E.PH@("`@("`@(&EF("@D<F5P;&%C94%C=&EO;B`F)B`A96UP='DH)&%T
M=')I8G5T97-;)V%C=&EO;B==*2D@>PH@("`@("`@("`@("`D8V]U;G0@/2!C
M;W5N="@D:&ES=&]R>2T^9&%T82D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D:&ES=&]R>2T^9&%T85LD:5U;)V%C=&EO;B==*2`F)@H@("`@("`@
M("`@("`@("`@("`@("1H:7-T;W)Y+3YD871A6R1I75LG86-T:6]N)UT@/3T@
M)&%T=')I8G5T97-;)V%C=&EO;B==*2!["@H@("`@("`@("`@("`@("`@("`@
M("1V86QU97,@/2!A<G)A>2@D871T<FEB=71E<ULG=',G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)W=H;R==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D
M871T<FEB=71E<ULG9&5S8R==*2`_("1A='1R:6)U=&5S6R=D97-C)UT@.B!N
M=6QL*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB=71E<ULG
M=',G72D["B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%T=')I8G5T97-;
M)W=H;R==*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB=71E
M<ULG9&5S8R==*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB
M=71E<ULG86-T:6]N)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("@D871T
M<FEB=71E<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S6UT@
M/2!S97)I86QI>F4H)&%T=')I8G5T97,I.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97-;72`]
M(&YU;&P["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1V86QU97-;72`]("1H:7-T;W)Y+3YD871A6R1I75LG:60G73L*"B`@
M("`@("`@("`@("`@("`@("`@)'(@/2`D=&AI<RT^7V1B+3YQ=65R>2@G55!$
M051%(&AO<F1E7VAI<W1O<FEE<R!3150@:&ES=&]R>5]T<R`](#\L)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!H:7-T;W)Y
M7W=H;R`](#\L)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R!H:7-T;W)Y7V1E<V,@/2`_+"<@+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<@:&ES=&]R>5]E>'1R82`](#\@5TA%
M4D4@:&ES=&]R>5]I9"`](#\G+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'(["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@=V4G<F4@;F]T(')E<&QA
M8VEN9R!B>2!A8W1I;VXL(&]R(&EF('=E(&1I9&XG="!F:6YD(&%N(&5N=')Y
M('1O"B`@("`@("`@("H@<F5P;&%C92P@:6YS97)T(&$@;F5W(')O=RX@*B\*
M("`@("`@("!I9B`H(21D;VYE*2!["B`@("`@("`@("`@("1V86QU97,@/2!A
M<G)A>2@D=&AI<RT^7V1B+3YN97AT260H)VAO<F1E7VAI<W1O<FEE<R<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=U:60L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D871T<FEB=71E<ULG=',G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R=W:&\G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1A='1R:6)U=&5S6R=D97-C
M)UTI(#\@)&%T=')I8G5T97-;)V1E<V,G72`Z(&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I<W-E="@D871T<FEB=71E<ULG86-T:6]N)UTI
M(#\@)&%T=')I8G5T97-;)V%C=&EO;B==(#H@;G5L;"D["B`@("`@("`@("`@
M('5N<V5T*"1A='1R:6)U=&5S6R=T<R==*3L*("`@("`@("`@("`@=6YS970H
M)&%T=')I8G5T97-;)W=H;R==*3L*("`@("`@("`@("`@=6YS970H)&%T=')I
M8G5T97-;)V1E<V,G72D["B`@("`@("`@("`@('5N<V5T*"1A='1R:6)U=&5S
M6R=A8W1I;VXG72D["B`@("`@("`@("`@(&EF("@D871T<FEB=71E<RD@>PH@
M("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@<V5R:6%L:7IE*"1A='1R:6)U
M=&5S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1V
M86QU97-;72`](&YU;&P["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R
M(#T@)'1H:7,M/E]D8BT^<75E<GDH)TE.4T525"!)3E1/(&AO<F1E7VAI<W1O
M<FEE<R`H:&ES=&]R>5]I9"P@;V)J96-T7W5I9"P@:&ES=&]R>5]T<RP@:&ES
M=&]R>5]W:&\L(&AI<W1O<GE?9&5S8RP@:&ES=&]R>5]A8W1I;VXL(&AI<W1O
M<GE?97AT<F$I)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@
M5D%,5453("@_+"`_+"`_+"`_+"`_+"`_+"`_*2<L("1V86QU97,I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!(:7-T;W)Y3V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&YA
M;65D(&AI<W1O<GD*("`@("`J(&5N=')Y+"!W:71H('1H92!D871A(')E=')I
M979E9"!A<'!R;W!R:6%T96QY+B`D875T;V-R96%T92!H87,*("`@("`J(&YO
M(&%F9F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G=6ED("`@
M("`@("`@5&AE(&YA;64@;V8@=&AE(&AI<W1O<GD@96YT<GD@=&\@<F5T<FEE
M=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@1&5P<F5C
M871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$AI<W1O<GDH)&=U:60L
M("1A=71O8W)E871E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?82@D
M=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1F86QS
M92`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@)')O=W,@/2`D=&AI<RT^7V1B+3YG971!;&PH)U-%3$5#
M5"`J($923TT@:&]R9&5?:&ES=&]R:65S(%=(15)%(&]B:F5C=%]U:60@/2`_
M)RP@87)R87DH)&=U:60I+"!$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@
M("1H:7-T;W)Y(#T@)FYE=R!(:7-T;W)Y3V)J96-T*"1G=6ED+"`D<F]W<RD[
M"B`@("`@("`@<F5T=7)N("1H:7-T;W)Y.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1FEN9',@:&ES=&]R>2!O8FIE8W1S(&)Y('1I;65S=&%M<"P@86YD(&]P
M=&EO;F%L;'D@9FEL=&5R(&]N(&]T:&5R"B`@("`@*B!F:65L9',@87,@=V5L
M;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;7`@("`@(%1H92!C
M;VUP87)I<V]N(&]P97)A=&]R("@\+"`^+"`\/2P@/CTL(&]R(#TI('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-H96-K('1H92!T:6UE<W1A
M;7!S('=I=&@N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=',@("`@(%1H92!T
M:6UE<W1A;7`@=&\@8V]M<&%R92!A9V%I;G-T+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1F:6QT97)S("!!;B!A<G)A>2!O9B!A9&1I=&EO;F%L("A!3D1E9"D@
M8W)I=&5R:6$N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($5A8V@@
M87)R87D@=F%L=64@<VAO=6QD(&)E(&%N(&%R<F%Y('=I=&@@,PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!E;G1R:65S.@H@("`@("H@/'!R93X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("=O<"<@("`@+2!T:&4@
M;W!E<F%T;W(@=&\@8V]M<&%R92!T:&ES(&9I96QD"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=VET:"X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("=F:65L9"<@+2!T:&4@:&ES=&]R>2!F:65L
M9"!B96EN9R!C;VUP87)E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("AI+F4N("=A8W1I;VXG*2X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("=V86QU92<@+2!T:&4@=F%L=64@=&\@8VAE8VL@
M9F]R("AI+F4N("=A9&0G*2X*("`@("`J(#PO<')E/@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%R96YT("!4:&4@<&%R96YT(&AI<W1O<GD@=&\@<W1A<G0@
M<V5A<F-H:6YG(&%T+B!)9B!N;VXM96UP='DL"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@('=I;&P@8F4@<V5A<F-H960@9F]R('=I=&@@82!,24M%
M("<D<&%R96YT.B4G(&-L875S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<G)A>2!O9B!H:7-T;W)Y(&]B:F5C="!I9',L(&]R(&%N(&5M
M<'1Y(&%R<F%Y(&EF"B`@("`@*B`@("`@("`@("`@("`@("!N;VYE(&UA=&-H
M960@=&AE(&-R:71E<FEA+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971">51I
M;65S=&%M<"@D8VUP+"`D=',L("1F:6QT97)S(#T@87)R87DH*2P@)'!A<F5N
M="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!T:&4@=&EM97-T86UP('1E<W0N
M("HO"B`@("`@("`@)'=H97)E(#T@87)R87DH(FAI<W1O<GE?=',@)&-M<"`D
M=',B*3L*"B`@("`@("`@+RH@061D(&%D9&ET:6]N86P@9FEL=&5R<RP@:68@
M=&AE<F4@87)E(&%N>2X@*B\*("`@("`@("!I9B`H)&9I;'1E<G,I('L*("`@
M("`@("`@("`@9F]R96%C:"`H)&9I;'1E<G,@87,@)&9I;'1E<BD@>PH@("`@
M("`@("`@("`@("`@)'=H97)E6UT@/2`G:&ES=&]R>5\G("X@)&9I;'1E<ELG
M9FEE;&0G72`N("<@)R`N("1F:6QT97);)V]P)UT@+B`G("<@+B`D=&AI<RT^
M7V1B+3YQ=6]T92@D9FEL=&5R6R=V86QU92==*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"1P87)E;G0I('L*("`@("`@("`@("`@
M)'=H97)E6UT@/2`G;V)J96-T7W5I9"!,24M%("<@+B`D=&AI<RT^7V1B+3YQ
M=6]T92@D<&%R96YT("X@)SHE)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D8BT^9V5T07-S;V,H)U-%3$5#5"!$25-424Y#5"!O8FIE
M8W1?=6ED+"!H:7-T;W)Y7VED($923TT@:&]R9&5?:&ES=&]R:65S(%=(15)%
M("<@+B!I;7!L;V1E*"<@04Y$("<L("1W:&5R92DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T<R!T:&4@=&EM97-T86UP(&]F('1H92!M;W-T(')E8V5N
M="!C:&%N9V4@=&\@)&=U:60N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9W5I9"`@("!4:&4@;F%M92!O9B!T:&4@:&ES=&]R>2!E;G1R>2!T;R!R
M971R:65V92X*("`@("`J($!P87)A;2!S=')I;F<@)&%C=&EO;B`@06X@86-T
M:6]N.B`G861D)RP@)VUO9&EF>2<L("=D96QE=&4G+"!E=&,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=&EM97-T86UP+"!O<B`P(&EF
M(&YO(&UA=&-H:6YG(&5N=')Y(&ES(&9O=6YD+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971!8W1I;VY4:6UE<W1A;7`H)&=U:60L("1A8W1I;VXI"B`@("![
M"B`@("`@("`@+RH@5&AI<R!I;7!L96UE;G1A=&EO;B!S=&EL;"!W;W)K<RP@
M8G5T('=E('-H;W5L9"!B92!A8FQE('1O"B`@("`@("`@("H@9V5T(&UU8V@@
M9F%S=&5R(&YO=R!W:71H(&$@4T5,14-4($U!6"AH:7-T;W)Y7W1S*0H@("`@
M("`@("`J("XN+B!Q=65R>2X@*B\*("`@("`@("`D:&ES=&]R>2`]("8D=&AI
M<RT^9V5T2&ES=&]R>2@D9W5I9"D["B`@("`@("`@:68@*"$D:&ES=&]R>2!\
M?"!I<U]A*"1H:7-T;W)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@)&QA<W0@/2`P.PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D:&ES=&]R>2T^9&%T82DI('L*("`@("`@("`@
M("`@9F]R96%C:"`H)&AI<W1O<GDM/F1A=&$@87,@)&5N=')Y*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&5N=')Y6R=A8W1I;VXG72`]/2`D86-T:6]N("8F
M("1E;G1R>5LG=',G72`^("1L87-T*2!["B`@("`@("`@("`@("`@("`@("`@
M)&QA<W0@/2`D96YT<GE;)W1S)UT["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&%S=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!O;F4@;W(@;6]R92!H:7-T;W)Y
M(&5N=')I97,@8GD@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&YA;65S("!4:&4@:&ES=&]R>2!E;G1R:65S('1O(')E;6]V92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5M;W9E0GE.86UE<R@D;F%M97,I"B`@("!["B`@
M("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D
M:61S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D;F%M97,@87,@)&YA
M;64I('L*("`@("`@("`@("`@)&ED<UM=(#T@)'1H:7,M/E]D8BT^<75O=&4H
M)&YA;64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M
M/G%U97)Y*"=$14Q%5$4@1E)/32!H;W)D95]H:7-T;W)I97,@5TA%4D4@;V)J
M96-T7W5I9"!)3B`H)R`N(&EM<&QO9&4H)RPG+"`D:61S*2`N("<I)RD["B`@
M("!]"@I]"@HO*BH*("H@0VQA<W,@9F]R('!R97-E;G1I;F<@2&ES=&]R>2!I
M;F9O<FUA=&EO;BX*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C
M:V%G92!(;W)D95](:7-T;W)Y"B`J+PIC;&%S<R!(:7-T;W)Y3V)J96-T('L*
M"B`@("!V87(@)'5I9#L*("`@('9A<B`D9&%T82`](&%R<F%Y*"D["@H@("`@
M9G5N8W1I;VX@2&ES=&]R>4]B:F5C="@D=6ED+"`D9&%T82`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@)'1H:7,M/G5I9"`]("1U:60["@H@("`@("`@(&EF
M("@A)&1A=&$@?'P@:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M9&%T82!A<R`D<F]W*2!["B`@("`@("`@("`@("1H:7-T;W)Y(#T@87)R87DH
M)V%C=&EO;B<@/3X@)')O=ULG:&ES=&]R>5]A8W1I;VXG72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)')O=ULG:&ES=&]R>5]D
M97-C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=H;R<@/3X@
M)')O=ULG:&ES=&]R>5]W:&\G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:60G(#T^("1R;W=;)VAI<W1O<GE?:60G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=',G(#T^("1R;W=;)VAI<W1O<GE?=',G72D[
M"B`@("`@("`@("`@(&EF("@D<F]W6R=H:7-T;W)Y7V5X=')A)UTI('L*("`@
M("`@("`@("`@("`@("1E>'1R82`]($!U;G-E<FEA;&EZ92@D<F]W6R=H:7-T
M;W)Y7V5X=')A)UTI.PH@("`@("`@("`@("`@("`@:68@*"1E>'1R82D@>PH@
M("`@("`@("`@("`@("`@("`@("1H:7-T;W)Y(#T@87)R87E?;65R9V4H)&AI
M<W1O<GDL("1E>'1R82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/F1A=&%;72`]("1H:7-T;W)Y.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971$871A*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/F1A=&$["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-86EN=&5N86YC
M92YP:'``````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C,P,C8`
M,3`U,34T,S$P-C$`,#(Q,34V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*BH*("H@1&\@=&%S:R!Y96%R;'D@
M*$9I<G-T(&QO9VEN(&%F=&5R+V]N($IA;G5A<GD@,2DN"B`J+PID969I;F4H
M)TU!24Y414Y!3D-%7UE%05),62<L(#$I.PH*+RHJ"B`J($1O('1A<VL@;6]N
M=&AL>2`H1FER<W0@;&]G:6X@869T97(O;VX@9FER<W0@;V8@;6]N=&@I+@H@
M*B\*9&5F:6YE*"=-04E.5$5.04Y#15]-3TY42$Q9)RP@,BD["@HO*BH*("H@
M1&\@=&%S:R!W965K;'D@*$9I<G-T(&QO9VEN(&%F=&5R+V]N(&$@4W5N9&%Y
M*2X*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?5T5%2TQ9)RP@,RD["@HO*BH*
M("H@1&\@=&%S:R!D86EL>2`H1FER<W0@;&]G:6X@;V8@=&AE(&1A>2DN"B`J
M+PID969I;F4H)TU!24Y414Y!3D-%7T1!24Q9)RP@-"D["@HO*BH*("H@1&\@
M=&%S:R!E=F5R>2!L;V=I;BX*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?159%
M4EDG+"`U*3L*"B\J*@H@*B!$;R!T87-K(&]N(&9I<G-T(&QO9VEN(&]N;'DN
M"B`J+PID969I;F4H)TU!24Y414Y!3D-%7T9)4E-47TQ/1TE.)RP@-BD["@HO
M*BH*("H@0V]N9FER;6%T:6]N+7-T>6QE(&]U='!U="!F;W(@;6%I;G1E;F%N
M8V4@<&%G92X*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?3U544%547T-/3D9)
M4DTG+"`W*3L*"B\J*@H@*B!!9W)E96UE;G0M<W1Y;&4@;W5T<'5T(&9O<B!M
M86EN=&5N86YC92!P86=E+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#15]/5510
M551?04=2144G+"`X*3L*"B\J*@H@*B!.;W1I8V4M<W1Y;&4@;W5T<'5T(&9O
M<B!M86EN=&5N86YC92!P86=E+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#15]/
M5510551?3D]424-%)RP@.2D["@HO*BH*("H@5&AE(&YA;64@;V8@=&AE(%52
M3"!P87)A;65T97(@=&AA="!I;F1I8V%T97,@=&AA="!T:&4@;6%I;G1E;F%N
M8V4@=&%S:W,@87)E"B`J(&-O;7!L971E9"X*("HO"F1E9FEN92@G34%)3E1%
M3D%.0T5?1$].15]005)!32<L("=M86EN=&5N86YC95]D;VYE)RD["@HO*B!)
M;G1E<G9A;',@:&%S:"`M('5S960@=&\@8G5I;&0@<V5L96-T('1A8FQE<R!I
M;B!P<F5F97)E;F-E<R!M96YU+B`J+PHD:6YT97)V86QS(#T@87)R87DH*3L*
M)&EN=&5R=F%L<UM-04E.5$5.04Y#15]914%23%E=("`](%\H(EEE87)L>2(I
M.PHD:6YT97)V86QS6TU!24Y414Y!3D-%7TU/3E1(3%E=(#T@7R@B36]N=&AL
M>2(I.PHD:6YT97)V86QS6TU!24Y414Y!3D-%7U=%14M,65T@(#T@7R@B5V5E
M:VQY(BD["B1I;G1E<G9A;'-;34%)3E1%3D%.0T5?1$%)3%E=("`@/2!?*")$
M86EL>2(I.PHD:6YT97)V86QS6TU!24Y414Y!3D-%7T5615)972`@(#T@7R@B
M179E<GD@3&]G:6XB*3L*)$=,3T)!3%-;)VEN=&5R=F%L<R==(#T@)B1I;G1E
M<G9A;',["@HO*BH*("H@5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@<')O=FED
M97,@82!S970@;V8@;65T:&]D<R!F;W(@9&5A;&EN9R!W:71H"B`J(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@<G5N('5P;VX@;&]G:6X@=&\@2&]R9&4@87!P
M;&EC871I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`L=B`Q+C4R+C$P+C$S(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R
M9&4@,2XS+C4*("H@0'!A8VMA9V4@2&]R9&5?36%I;G1E;F%N8V4*("HO"F-L
M87-S($UA:6YT96YA;F-E('L*"B`@("`O*BH*("`@("`J($AA<V@@:&]L9&EN
M9R!M86EN=&5N86YC92!P<F5F97)E;F-E(&YA;65S+@H@("`@("H@4WEN=&%X
M.B`@4%)%1DY!344@/3X@:6YT97)V86P*("`@("`J(%9A;&ED(&EN=&5R=F%L
M<R!A<F4Z($U!24Y414Y!3D-%7UE%05),62P@34%)3E1%3D%.0T5?34].5$A,
M62P*("`@("`J("`@("`@("`@("`@("`@("`@("`@($U!24Y414Y!3D-%7U=%
M14M,62P@34%)3E1%3D%.0T5?1$%)3%DL"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!-04E.5$5.04Y#15]%5D5262P@($U!24Y414Y!3D-%7T9)4E-4
M7TQ/1TE."B`@("`@*B!/<&5R871I;VYS('=I;&P@8F4@<G5N(&EN('1H92!O
M<F1E<B!T:&5Y(&%P<&5A<B!I;B!T:&4@87)R87D@+0H@("`@("H@("!-04M%
M(%-54D4@1E5.0U1)3TY3($%212!)3B!42$4@0T]24D5#5"!/4D1%4B$*("`@
M("`J($]P97)A=&EO;G,@8V%N(&%P<&5A<B!M;W)E('1H86X@;VYC92`M('1H
M97D@=VEL;"!O;FQY(&)E(')U;B!O;F-E('!E<@H@("`@("H@("!L;V=I;B!T
M:&]U9V@@*'1H92!O<&5R871I;VX@=VEL;"!R=6X@=&AE(&9I<G-T('1I;64@
M:70@:7,@<V5E;B!I;@H@("`@("H@("!T:&4@87)R87DI+@H@("`@("H*("`@
M("`J(%1H:7,@87)R87D@<VAO=6QD(&)E(&9I;&QE9"!I;B!F;W(@96%C:"!(
M;W)D92!M;V1U;&4@=&AA="!E>'1E;F1S"B`@("`@*B`@('1H92!-86EN=&5N
M86YC92!C;&%S<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D;6%I;G1?=&%S:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@54Y)6"!T:6UE<W1A;7`@;V8@=&AE(&QA<W0@;6%I;G1E;F%N8V4@<G5N
M(&9O<B!U<V5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)%]L87-T4G5N(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!-
M86EN=&5N86YC95]487-K;&ES="!O8FIE8W0@9F]R('1H:7,@;&]G:6XN"B`@
M("`@*@H@("`@("H@0'9A<B!-86EN=&5N86YC95]487-K;&ES=`H@("`@("HO
M"B`@("!V87(@)%]T87-K;&ES=#L*"B`@("`O*BH*("`@("`J($%R<F%Y('1O
M('-T;W)E($UA:6YT96YA;F-E7U1A<VL@;V)J96-T<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1A<VM#86-H92`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C
M;VYC<F5T92!-86EN=&5N86YC95\J(&]B:F5C="!B87-E9"!O;B!T:&4@;6]D
M=6QE"B`@("`@*B!N86UE('!A<W-E9"!I;G1O(&ET+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&UO9'5L92`@5&AE(&YA;64@;V8@=&AE($AO<F1E
M(&UO9'5L92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H
M(&-O;G1A:6YI;F<@861D:71I;VYA;"!D871A(&YE961E9"!B>2!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!-86EN=&5N86YC92`@5&AE($UA:6YT96YA;F-E
M(&]B:F5C="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9F86-T;W)Y*"1M;V1U;&4L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\J(%-P87=N
M('1H92!R96QE=F%N="!D<FEV97(L(&%N9"!R971U<FX@:70@*&]R(&9A;'-E
M(&]N(&9A:6QU<F4I+B`J+PH@("`@("`@(&EN8VQU9&5?;VYC92`D<F5G:7-T
M<GDM/F=E="@G9FEL97)O;W0G+"`D;6]D=6QE*2`N("<O;&EB+TUA:6YT96YA
M;F-E+R<@+B`D;6]D=6QE("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=-
M86EN=&5N86YC95\G("X@)&UO9'5L93L*("`@("`@("!I9B`H8VQA<W-?97AI
M<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&UA:6YT96YA;F-E(#T@)FYE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&UA:6YT96YA;F-E(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&UA:6YT96YA;F-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($$@:&%S:"!C;VYT86EN:6YG('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`G;&%S=%]M86EN=&5N86YC92<@
M/3X@5&AE(&QA<W0@=&EM92!M86EN=&5N86YC92!W87,@<G5N("AU;FEX('1I
M;65S=&%M<"DN"B`@("`@*B\*("`@(&9U;F-T:6]N($UA:6YT96YA;F-E*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J(%-E="!T:&4@8VQA
M<W,@=F%R:6%B;&4@)%]L87-T4G5N+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=L87-T7VUA:6YT96YA;F-E)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&%S=%)U;B`]("1P87)A;7-;)VQA<W1?;6%I;G1E;F%N8V4G73L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<F5T<FEE=F5487-K;&ES="@I
M.PH@("`@("`@("1T:&ES+3Y?<VAU=&1O=VXH*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1O(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;F5E9&5D(&9O<B!T
M:&ES(&QO9VEN+B`@5&AI<R!F=6YC=&EO;@H@("`@("H@=VEL;"!G96YE<F%T
M92!T:&4@;&ES="!O9B!T87-K<R!T;R!P97)F;W)M(&1U<FEN9R!T:&ES(&QO
M9VEN"B`@("`@*B!A;F0@=VEL;"!R961I<F5C="!T;R!T:&4@;6%I;G1E;F%N
M8V4@<&%G92!I9B!N96-E<W-A<GDN("!4:&ES"B`@("`@*B!I<R!T:&4@9G5N
M8W1I;VX@=&AA="!S:&]U;&0@8F4@8V%L;&5D(&9R;VT@=&AE(&%P<&QI8V%T
M:6]N('5P;VX*("`@("`J(&QO9VEN+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M=6Y-86EN=&5N86YC92@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@=&\@<V5E
M(&EF('=E(&%R92!F:6YI<VAE9"!W:71H(&UA:6YT96YA;F-E"B`@("`@("`@
M("H@;W!E<F%T:6]N<RX@*B\*("`@("`@("!I9B`H(55T:6PZ.F=E=$9O<FU$
M871A*$U!24Y414Y!3D-%7T1/3D5?4$%204TI*2!["B`@("`@("`@("`@("\J
M($1E=&5R;6EN92!I9B!W92!S:&]U;&0@<F5D:7)E8W0@=&\@=&AE(&UA:6YT
M96YA;F-E('!A9V4N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VYE961-
M86EN=&5N86YC95!A9V4H*2`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1T:&ES+3Y?9V5T36%I;G1E;F%N8V55
M4DPH*2P@=')U92D["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!&:6YA;&QY+"!R=6X@86YY('1A
M<VMS('1H870@;F5E9"!T;R!B92!E>&5C=71E9"X@*B\*("`@("`@("`D=&AI
M<RT^7V1O36%I;G1E;F%N8V5487-K<R@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&\@=&AE(&YE8V5S<V%R>2!M86EN=&5N86YC92!T87-K<R!F;W(@=&AI
M<R!L;V%D:6YG(&]F('1H92!M86EN=&5N86YC90H@("`@("H@<&%G92X@(%1H
M:7,@:7,@=&AE(&9U;F-T:6]N('1H870@:7,@8V%L;&5D(&9R;VT@=&AE(&UA
M:6YT96YA;F-E('!A9V4*("`@("`J(&5V97)Y('1I;64@:70@:7,@;&]A9&5D
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&1I<W!L87D@
M<F5Q=6ER960@9F]R('1H92!M86EN=&5N86YC92!P86=E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R=6Y-86EN=&5N86YC95!A9V4H*0H@("`@>PH@("`@("`@
M("\J(%-H;W5L9"!W92!R=6X@86YY('1A<VMS/R`J+PH@("`@("`@("1T:&ES
M+3Y?9&]-86EN=&5N86YC951A<VMS*"D["@H@("`@("`@("\J($=E="!T:&4@
M;&ES="!O9B!T87-K<R!W92!N965D('1O(&1I<W!L87D@=&\@=&AE('5S97(N
M("HO"B`@("`@("`@)'1A<VM?;F\@/2`D=&AI<RT^7VYE961-86EN=&5N86YC
M95!A9V4H*3L*("`@("`@("`D=&%S:W,@/2`D=&AI<RT^7W1A<VML:7-T+3YG
M971,:7-T*"D["@H@("`@("`@("\J(%)E;6]V92`G;F5W9FQA9R<@9G)O;2!F
M:7)S="!T87-K+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]T87-K;&ES="T^
M<')O8V5S<V5D*'1R=64I*2!["B`@("`@("`@("`@(&EF("AC;W5N="@D=&%S
M:W,I*2!["B`@("`@("`@("`@("`@("!R97-E="@D=&%S:W,I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]T87-K;&ES="T^<V5T3F5W4&%G92AK97DH)'1A
M<VMS*2P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H(6ES7VYU;&PH)'1A<VM?;F\I*2!["B`@("`@("`@("`@("1T87-K
M<R`](&%R<F%Y7W-L:6-E*"1T87-K<RP@,"P@)'1A<VM?;F\@*R`Q*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D=&%S:W,I*2!["B`@("`@("`@
M("`@(')E<V5T*"1T87-K<RD["B`@("`@("`@("`@("1A8W1I;VX@/2`D=&%S
M:W-;:V5Y*"1T87-K<RE=6R=D:7-P;&%Y)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&%C=&EO;B`](&YU;&P["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@87)R87DH)&%C=&EO;BP@87)R87E?:V5Y<R@D=&%S:W,I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN9F]R;6%T:6]N
M86P@=&5X="!M97-S86=E(&]N('=H870@=&AE(&]P97)A=&EO;B!I<PH@("`@
M("H@86)O=70@=&\@9&\N($%L<V\@:6YD:6-A=&5S('=H971H97(@=&AE(&)O
M>"!S:&]U;&0@8F4@8VAE8VME9`H@("`@("H@8GD@9&5F875L="!O<B!N;W0N
M($]P97)A=&EO;G,@=&AA="!H879E(&)E96X@;&]C:V5D(&)Y('1H90H@("`@
M("H@861M:6X@=VEL;"!R971U<FX@;G5L;"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P<F5F("!.86UE(&]F('1H92!O<&5R871I;VX@=&\@9V5T
M(&EN9F]R;6%T:6]N(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("`Q<W0@96QE;65N="`M($1E<V-R:7!T:6]N(&]F('=H870@=&AE(&]P97)A
M=&EO;B!I<R!A8F]U=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T;R!D;R!D=7)I;F<@=&AI<R!L;V=I;BX*("`@("`J("`@("`@("`@
M("`@("`@(#)N9"!E;&5M96YT("T@5VAE=&AE<B!T:&4@<')E9F5R96YC92!I
M<R!S970@=&\@;VX@;W(@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;F9O
M36%I;G1E;F%N8V4H)'!R968I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F
M<SL*"B`@("`@("`@+RH@268@=&AE('!R969E<F5N8V4@:&%S(&)E96X@;&]C
M:V5D(&)Y('1H92!A9&UI;BP@9&\@;F]T('-H;W<*("`@("`@("`@("!T:&4@
M=7-E<BX@*B\*("`@("`@("!I9B`H)'!R969S+3YI<TQO8VME9"@D<')E9BDI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&UO
M9"`]("8D=&AI<RT^7VQO861-;V1U;&4H)'!R968I.PH@("`@("`@(')E='5R
M;B!A<G)A>2@D;6]D+3YD97-C<FEB94UA:6YT96YA;F-E*"DL("1P<F5F<RT^
M9V5T5F%L=64H)'!R968I*3L*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R
M="!V87)I86)L92!N86UE<R!T;R!U<V4@9F]R(&-R96%T:6YG('-E;&5C="!T
M86)L97,@:6X@=&AE"B`@("`@*B!P<F5F97)E;F-E<R!M96YU+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F('9A<FEA8FQE(&YA
M;65S('1O(&)E(&EM<&]R=&5D(&EN=&\@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("!P<F5F<RYP:'`@;F%M97-P86-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E>'!O<G1);G1E<G9A;%!R969S*"D*("`@('L*("`@("`@("!G;&]B86P@
M)'!R969S.PH*("`@("`@("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH*3L*"B`@
M("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^;6%I;G1?=&%S:W,I
M(&%S("1V86PI('L*("`@("`@("`@("`@:68@*"$D<')E9G,M/FES3&]C:V5D
M*"1V86P@+B`G7VEN=&5R=F%L)RDI('L*("`@("`@("`@("`@("`@("1R971U
M<FY?87)R87E;72`]("1V86P@+B`G7VEN=&5R=F%L7V]P=&EO;G,G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R;E]A
M<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U="!H:61D96X@9F]R
M(&5L96UE;G1S(&9O<B!T:&4@4$]35"!F;W)M('1O(&5N<W5R92!T:&4@8V%L
M;&EN9PH@("`@("H@<V-R:7!T(&AA<R!T:&4@<V%M92!03U-4(&5L96UE;G1S
M(&%S('=H96X@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,*("`@("`J(&9I
M<G-T(')U;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9O
M<FT@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&]S=$1A=&$H*0H@
M("`@>PH@("`@("`@("1T97AT(#T@)R<["@H@("`@("`@(&EF("@H)&1A=&$@
M/2`D=&AI<RT^7W1A<VML:7-T+3YG9710;W-T1&%T82@I*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D9&%T82!A<R`D;F%M92`]/B`D=F%L*2!["B`@("`@
M("`@("`@("`@("`D=&5X="`N/2`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I("X@)R(@=F%L=64](B<@
M+B!H=&UL<W!E8VEA;&-H87)S*"1V86PI("X@)R(@+SXG("X@(EQN(CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!54DP@;F5E9&5D(&9O
M<B!T:&4@;6%I;G1E;F%N8V4@9F]R;2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(%523"!T;R!R961I<F5C="!T;RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T36%I;G1E;F%N8V5&;W)M55),*"D*("`@('L*("`@("`@
M(&EF("@D=&AI<RT^7VYE961-86EN=&5N86YC95!A9V4H*2`A/3T@;G5L;"D@
M>PH@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$UA:6YT96YA;F-E55),
M*"D["B`@("`@("!](&5L<V4@>PH@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V=E=$EN:71I86Q086=E55),*"D["B`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S('1H92!L:7-T(&]F(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@=&AA="!A<F4@879A:6QA8FQE"B`@("`@*B!F;W(@=&AI<R!S97-S
M:6]N("AS=&]R960@:6X@82!-86EN=&5N86YC95]487-K;&ES="!O8FIE8W0I
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF(&QI<W0@=V%S(&-R
M96%T960N"B`@("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF(&YO="`H
M92YG+B!L:7-T(&%L<F5A9'D@97AI<W1S*2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-R96%T951A<VM,:7-T*"D*("`@('L*("`@("`@("!G;&]B86P@)'!R
M969S.PH*("`@("`@("`O*B!#<F5A=&4@82!N97<@36%I;G1E;F%N8V5?5&%S
M:VQI<W0@;V)J96-T+B`J+PH@("`@("`@("1T:&ES+3Y?=&%S:VQI<W0@/2`F
M;F5W($UA:6YT96YA;F-E7U1A<VML:7-T*"D["@H@("`@("`@("\J($-R96%T
M92!T:6UE(&]B:F5C=',@9F]R('1O9&%Y)W,@9&%T92!A;F0@;&%S="!L;V=I
M;B!D871E+B`J+PH@("`@("`@("1L87-T7V1A=&4@/2!G971D871E*"1T:&ES
M+3Y?;&%S=%)U;BD["B`@("`@("`@)&-U<E]D871E("`](&=E=&1A=&4H*3L*
M"B`@("`@("`@+RH@1V\@=&AR;W5G:"!E86-H(&ET96T@:6X@)&UA:6YT7W1A
M<VMS(&%N9"!D971E<FUI;F4@:68@=V4@;F5E9"!T;PH@("`@("`@("`@(')U
M;B!I="!D=7)I;F<@=&AI<R!M86EN=&5N86YC92!R=6XN("HO"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/FUA:6YT7W1A<VMS(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`O*B!3:VEP(&ET96T@:68@:70@86QR96%D>2!A<'!E
M87)S(&EN('1H92!T87-K<R!L:7-T+B`J+PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]T87-K;&ES="T^:6Y,:7-T*"1K97DI*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@1&5T
M97)M:6YE('1H92!C;W)R96-T(&EN=&5R=F%L(&9O<B!T:&4@:71E;2X@*B\*
M("`@("`@("`@("`@:68@*"@D:6YT97)V86P@/2`D<')E9G,M/F=E=%9A;'5E
M*"1K97D@+B`G7VEN=&5R=F%L)RDI*2!["B`@("`@("`@("`@("`@("`D=F%L
M(#T@)&EN=&5R=F%L.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D861D
M5&%S:R`](&9A;'-E.PH*("`@("`@("`@("`@+RH@1DE24U0@3$]'24X@3U!%
M4D%424].4R`J+PH@("`@("`@("`@("`O*B!)9B`D7VQA<W12=6X@:7,@96UP
M='D@*#T@,"DL('1H:7,@:7,@=&AE(&9I<G-T('1I;64@=&AE('5S97(*("`@
M("`@("`@("`@("`@:&%S(&QO9V=E9"!I;BX@1&]N)W0@<G5N(&%N>2!O=&AE
M<B!M86EN=&5N86YC92!O<&5R871I;VYS(&]N"B`@("`@("`@("`@("`@('1H
M92!F:7)S="!L;V=I;BX@*B\*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?;&%S=%)U;BDI('L*("`@("`@("`@("`@("`@(&EF("@D=F%L(#T]($U!
M24Y414Y!3D-%7T9)4E-47TQ/1TE.*2!["B`@("`@("`@("`@("`@("`@("`@
M)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!914%23%E?3U!%4D%424].4R`J+PH@("`@
M("`@("`@("!E;'-E:68@*"@D=F%L(#T]($U!24Y414Y!3D-%7UE%05),62D@
M)B8*("`@("`@("`@("`@("`@("`@("`H)&-U<E]D871E6R=Y96%R)UT@/B`D
M;&%S=%]D871E6R=Y96%R)UTI*2!["B`@("`@("`@("`@("`@("`D861D5&%S
M:R`]('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($U/3E1(
M3%D@3U!%4D%424].4R`J+PH@("`@("`@("`@("!E;'-E:68@*"@D=F%L(#T]
M($U!24Y414Y!3D-%7TU/3E1(3%DI("8F"B`@("`@("`@("`@("`@("`@("`@
M*"@D8W5R7V1A=&5;)WEE87(G72`^("1L87-T7V1A=&5;)WEE87(G72D@?'P@
M*"1C=7)?9&%T95LG;6]N)UT@/B`D;&%S=%]D871E6R=M;VXG72DI*2!["B`@
M("`@("`@("`@("`@("`D861D5&%S:R`]('1R=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J(%=%14M,62!/4$52051)3TY3("HO"B`@("`@("`@
M("`@(&5L<V5I9B`H*"1V86P@/3T@34%)3E1%3D%.0T5?5T5%2TQ9*2`F)@H@
M("`@("`@("`@("`@("`@("`@("@H)&-U<E]D871E6R=W9&%Y)UT@/"`D;&%S
M=%]D871E6R=W9&%Y)UTI('Q\("@H=&EM92@I("T@-C`T.#`P*2`^("1T:&ES
M+3Y?;&%S=%)U;BDI*2!["B`@("`@("`@("`@("`@("`D861D5&%S:R`]('1R
M=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($1!24Q9($]015)!
M5$E/3E,@*B\*("`@("`@("`@("`@96QS96EF("@H)'9A;"`]/2!-04E.5$5.
M04Y#15]$04E,62D@)B8*("`@("`@("`@("`@("`@("`@("`H*"1C=7)?9&%T
M95LG>65A<B==(#X@)&QA<W1?9&%T95LG>65A<B==*2!\?"`H)&-U<E]D871E
M6R=Y9&%Y)UT@/B`D;&%S=%]D871E6R=Y9&%Y)UTI*2D@>PH@("`@("`@("`@
M("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!%5D5262!,3T=)3B!/4$52051)3TY3("HO"B`@("`@("`@("`@
M(&5L<V5I9B`H)'9A;"`]/2!-04E.5$5.04Y#15]%5D5262D@>PH@("`@("`@
M("`@("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("\J(%-K:7`@=&AE('1A<VL@:68@86YY(&]F('1H92!F;VQL;W=I
M;F<Z"B`@("`@("`@("`@("`@("L@5&AI<R!T87-K(&1O97,@;F]T(&YE960@
M=&\@8F4@<G5N(&EN('1H:7,@;&]G:6X*("`@("`@("`@("`@("`@*R!4:&ES
M('1A<VL@:7,@;F]T('-E="!I;B!T:&4@<')E9F5R96YC97,@*B\*("`@("`@
M("`@("`@:68@*"$D861D5&%S:R!\?"`A)'!R969S+3YG971686QU92@D:V5Y
M*2D@8V]N=&EN=64["@H@("`@("`@("`@("`O*B!,;V%D('1H92!T87-K(&UO
M9'5L92!N;W<N("HO"B`@("`@("`@("`@("1M;V0@/2`F)'1H:7,M/E]L;V%D
M36]D=6QE*"1K97DI.PH*("`@("`@("`@("`@+RH@1&5T97)M:6YE(&EF('1H
M:7,@=&%S:R!H87,@86QR96%D>2!B965N(&-O;F9I<FUE9"]S970@=FEA('-O
M;64*("`@("`@("`@("`@("`@<V]R="!O9B!A9&UI;B!S971T:6YG+B!!;'-O
M+"!I9B!T:&4@=7-E<B]A9&UI;B!H87,@<V5T('1H90H@("`@("`@("`@("`@
M("`G8V]N9FER;5]M86EN=&5N86YC92<@9FQA9RP@<VMI<"!C;VYF:7)M871I
M;VXN("HO"B`@("`@("`@("`@("1C;VYF:7)M960@/2!F86QS93L*("`@("`@
M("`@("`@:68@*"1P<F5F<RT^:7-,;V-K960H)&ME>2D@?'P*("`@("`@("`@
M("`@("`@("$D<')E9G,M/F=E=%9A;'5E*"=C;VYF:7)M7VUA:6YT96YA;F-E
M)RDI('L*("`@("`@("`@("`@("`@("1C;VYF:7)M960@/2!T<G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O*B!!9&0@=&AE('1A<VL@=&\@=&AE
M('1A<VML:7-T+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W1A<VML:7-T+3YA
M9&1487-K*"1K97DL("1C;VYF:7)M960L("1M;V0M/F=E=$1I<W!L87E4>7!E
M*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QO860@;6]D
M=6QE("AI9B!N;W0@86QR96%D>2!L;V%D960I+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UO
M9&YA;64@($YA;64@;V8@=&AE(&UO9'5L92!T;R!L;V%D+@H@("`@("H*("`@
M("`J($!R971U<FX@36%I;G1E;F%N8V5?5&%S:R`@02!R969E<F5N8V4@=&\@
M=&AE(')E<75E<W1E9"!M;V1U;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?
M;&]A9$UO9'5L92@D;6]D;F%M92D*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=&%S:T-A8VAE
M6R1M;V1N86UE72DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E("1R96=I
M<W1R>2T^9V5T*"=F:6QE<F]O="<L("1T:&ES+3Y?=&%S:VQI<W0M/F=E=$UO
M9'5L92@I*2`N("<O;&EB+TUA:6YT96YA;F-E+U1A<VLO)R`N("1M;V1N86UE
M("X@)RYP:'`G.PH@("`@("`@("`@("`D8VQA<W,@/2`G36%I;G1E;F%N8V5?
M5&%S:U\G("X@)&UO9&YA;64["B`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES
M=',H)&-L87-S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]T87-K0V%C
M:&5;)&UO9&YA;65=(#T@)FYE=R`D8VQA<W,["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S(BDL("1C;&%S<RDI+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H
M:7,M/E]T87-K0V%C:&5;)&UO9&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!54DP@9F]R('1H92!I;FET:6%L('!A9V4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!54DP@9F]R('1H92!I;FET:6%L('!A9V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971);FET:6%L4&%G95523"@I"B`@("!["B`@("`@
M("`@<F5T=7)N(%5T:6PZ.F%D9%!A<F%M971E<B@D=&AI<RT^7W1A<VML:7-T
M+3YG971487)G970H*2P@87)R87DH34%)3E1%3D%.0T5?1$].15]005)!32`]
M/B`Q+"`G9&]M86EN=&5N86YC92<@/3X@,2DL(&YU;&PL(&9A;'-E*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@55),(&9O<B!T:&4@;6%I;G1E
M;F%N8V4@<&%G92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%523"!F;W(@=&AE(&UA
M:6YT96YA;F-E('!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971-86EN
M=&5N86YC95523"@I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*
M"B`@("`@("`@+RH@5V4@;F5E9"!T;R!P87-S('1H92!C86-H92!)1"!A;F0@
M)VUO9'5L92<@<&%R86UE=&5R<RX@*B\*("`@("`@("`D=7)L(#T@2&]R9&4Z
M.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`G+"!T<G5E*3L*("`@("`@("`D=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL(&%R<F%Y*"=M;V1U;&4G(#T^
M("1T:&ES+3Y?=&%S:VQI<W0M/F=E=$UO9'5L92@I+"`G9&]M86EN=&5N86YC
M92<@/3X@,2DL(&YU;&PL(&9A;'-E*3L*"B`@("`@("`@<F5T=7)N("1U<FP[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296=I<W1E<B!T:&4@<VAU=&1O=VX@
M9G5N8W1I;VX@9F]R('-T;W)I;F<@=&AE(&UA:6YT96YA;F-E"B`@("`@*B!T
M87-K;&ES="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W-H=71D;W=N*"D*("`@('L*("`@("`@("!R96=I
M<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?8V%C:&54
M87-K;&ES="<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A8VAE('1H92!M
M86EN=&5N86YC92!T87-K;&ES="!B971W965N('!A9V4@<F5Q=65S=',N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C86-H951A<VML:7-T*"D*("`@('L*("`@("`@("`D7U-%4U-)3TY;
M)VAO<F1E7VUA:6YT96YA;F-E7W1A<VML:7-T)UT@/2!S97)I86QI>F4H)'1H
M:7,M/E]T87-K;&ES="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M97,@82!C86-H960@;6%I;G1E;F%N8V4@=&%S:VQI<W0@;W(@;6%K97,@<W5R
M92!O;F4@:7,*("`@("`J(&-R96%T960N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R971R:65V951A<VML
M:7-T*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=H;W)D
M95]M86EN=&5N86YC95]T87-K;&ES="==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W1A<VML:7-T(#T@=6YS97)I86QI>F4H)%]315-324].6R=H;W)D95]M
M86EN=&5N86YC95]T87-K;&ES="==*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V-R96%T951A<VML:7-T*"D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T92!A;&P@8V]N9FER;65D('1A
M<VMS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9&]-86EN=&5N86YC951A<VMS*"D*("`@('L*("`@("`@
M("`D=&%S:W,@/2`D=&AI<RT^7W1A<VML:7-T+3YG971,:7-T*"D["@H@("`@
M("`@(&9O<F5A8V@@*"1T87-K<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@:68@*"1V86Q;)VYE=W!A9V4G72D@>PH@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?=&%S:VQI<W0M/G!R;V-E<W-E9"@I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]T87-K;&ES="T^<V5T3F5W4&%G92@D:V5Y
M+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?2!E;'-E:68@*"1V86Q;)V-O;F9I<FUE9"==
M('Q\"B`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M1&%T82@D
M:V5Y("X@)U]C;VYF:7)M)RDI('L*("`@("`@("`@("`@("`@("\J(%!E<F9O
M<FT@;6%I;G1E;F%N8V4@:68@8V]N9FER;65D+B`J+PH@("`@("`@("`@("`@
M("`@)&UO9"`]("8D=&AI<RT^7VQO861-;V1U;&4H)&ME>2D["B`@("`@("`@
M("`@("`@("`D;6]D+3YD;TUA:6YT96YA;F-E*"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]T87-K;&ES="T^<F5M;W9E5&%S:R@D:V5Y
M*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E)W9E('-U8V-E<W-F=6QL
M>2!C;VUP;&5T960@979E<GD@=&%S:R!I;B!T:&4@;&ES="`H;W(*("`@("`@
M("`@*B!S:VEP<&5D(&ET*2P@<F5C;W)D(&YO=R!A<R!T:&4@;&%S="!T:6UE
M(&UA:6YT96YA;F-E('=A<PH@("`@("`@("`J(')U;BX@*B\*("`@("`@("!I
M9B`H(6-O=6YT*"1T:&ES+3Y?=&%S:VQI<W0M/F=E=$QI<W0H*2DI('L*("`@
M("`@("`@("`@)$=,3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=L87-T7VUA
M:6YT96YA;F-E)RP@=&EM92@I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$;R!A;GD@;V8@=&AE('1A<VMS(')E<75I<F4@=&AE(&UA:6YT
M96YA;F-E('!A9V4_"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@:V5Y(&]F('1H92!T
M87-K('1H870@<F5Q=6ER97,@=&AE(&UA:6YT96YA;F-E"B`@("`@*B`@("`@
M("`@("`@("`@("`@('!A9V4N(%)E='5R;G,@;G5L;"!I9B!T:&4@;6%I;G1E
M;F%N8V4@<&%G92!I<R!N;PH@("`@("H@("`@("`@("`@("`@("`@("!L;VYG
M97(@;F5E9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;F5E9$UA:6YT96YA
M;F-E4&%G92@I"B`@("!["B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?=&%S:VQI<W0M/F=E=$QI<W0H*2!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@:68@*"1V86Q;)VYE=W!A9V4G72D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A96UP='DH)'9A;%LG<')O8V5S<R==*2`F)@H@("`@("`@("`@
M("`@("`@(55T:6PZ.F=E=$9O<FU$871A*"=D;VUA:6YT96YA;F-E)RDI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%S:VQI<W0M/G-E=$YE=U!A9V4H
M)&ME>2P@=')U92D["B`@("`@("`@("`@("`@("!R971U<FX@)&D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!-86EN=&5N86YC
M95]487-K;&ES=#HZ(&-L87-S(&ES('5S960@=&\@<W1O<F4@=&AE(&QI<W0@
M;V8@;6%I;G1E;F%N8V4*("H@=&%S:W,@=&AA="!N965D('1O(&)E(')U;B!D
M=7)I;F<@=&AI<R!L;V=I;BX*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?36%I;G1E;F%N8V4*("HO"F-L
M87-S($UA:6YT96YA;F-E7U1A<VML:7-T('L*"B`@("`O*BH*("`@("`J(%1H
M92!(;W)D92!M;V1U;&4@<G5N;FEN9R!T:&4@;6%I;G1E;F%N8V4@=&%S:W,N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M;6]D=6QE.PH*("`@("\J*@H@("`@("H@5&AE(%523"!O9B!T:&4@=V5B('!A
M9V4@=&\@;&]A9"!A9G1E<B!M86EN=&5N86YC92!I<R!C;VUP;&5T92X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T87)G
M970["@H@("`@+RHJ"B`@("`@*B!03U-4(&1A=&$@9F]R('1H92!C86QL:6YG
M('-C<FEP="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7W!O<W1D871A.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@
M=&%S:W,@=&\@<G5N(&1U<FEN9R!T:&ES(&QO9VEN+@H@("`@("H*("`@("`J
M($M%63H@("`@5&%S:R!N86UE"B`@("`@*B!604Q513H@($%R<F%Y(#T^("@*
M("`@("`J("`@("`@("`@("`G8V]N9FER;65D)R`@/3X@(&)O;VQE86XL"B`@
M("`@*B`@("`@("`@("`@)V1I<W!L87DG("`@(#T^("!I;G1E9V5R+`H@("`@
M("H@("`@("`@("`@("=N97=P86=E)R`@("`]/B`@8F]O;&5A;BP*("`@("`J
M("`@("`@("`@("`G<')O8V5S<R<@("`@/3X@(&)O;VQE86X*("`@("`J("`@
M("`@("`@*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?=&%S:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@26YT97)N
M86P@9FQA9R!F;W(@861D5&%S:R@I+@H@("`@("H*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)%]A9&1&;&%G(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!(87,@=&AE('1A<VML:7-T(&)E96X@<')O8V5S<V5D('EE
M=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?<')O8V5S<V5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@36%I;G1E;F%N8V5?5&%S:VQI
M<W0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@
M("1T:&ES+3Y?;6]D=6QE(#T@)')E9VES=')Y+3YG971!<'`H*3L*("`@("`@
M("`D=&AI<RT^7W1A<F=E="`]($AO<F1E.CIS96QF57)L*'1R=64I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!A('1A<VL@=&\@=&AE('1A<VML:7-T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@(%1H
M92!N86UE(&]F('1H92!T87-K('1O('!E<F9O<FTN"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D8V]N9FER;65D("!(87,@=&AE('1A<VL@8F5E;B!C;VYF:7)M
M960_"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ES<&QA>2`@("!4:&4@9&ES
M<&QA>2!T>7!E(&]F('1H92!T87-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M9&1487-K*"1K97DL("1C;VYF:7)M960L("1D:7-P;&%Y*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?=&%S:W-;)&ME>5T@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3Y?=&%S:W-;)&ME>5U;)V-O;F9I<FUE9"==(#T@)&-O;F9I<FUE9#L*
M("`@("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=D:7-P;&%Y)UT@/2`D9&ES
M<&QA>3L*"B`@("`@("`@:68@*"@D9&ES<&QA>2`]/2!-04E.5$5.04Y#15]/
M5510551?04=2144I('Q\"B`@("`@("`@("`@("@D9&ES<&QA>2`]/2!-04E.
M5$5.04Y#15]/5510551?3D]424-%*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W1A<VMS6R1K97E=6R=N97=P86=E)UT@/2!T<G5E.PH@("`@("`@("`@("`D
M=&AI<RT^7V%D9$9L86<@/2!F86QS93L*("`@("`@("!](&5L<V5I9B`H*"1C
M;VYF:7)M960@/3T@9F%L<V4I("8F("@A)'1H:7,M/E]A9&1&;&%G*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=N97=P86=E)UT@/2!T
M<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V%D9$9L86<@/2!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?=&%S:W-;)&ME>5U;
M)VYE=W!A9V4G72`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E=',@=&AE(&YE=W!A9V4@9FQA9R!F;W(@82!T87-K+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A<VL@(%1H92!N86UE(&]F('1H
M92!T87-K('1O(&%L=&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FQA9R`@
M2&]W('1O('-E="!T:&4@9FQA9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M3F5W4&%G92@D=&%S:RP@)&9L86<I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YI;DQI<W0H)'1A<VLI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&%S:W-;
M)'1A<VM=6R=N97=P86=E)UT@/2`D9FQA9SL*("`@("`@("`@("`@)'1H:7,M
M/E]T87-K<ULD=&%S:UU;)W!R;V-E<W,G72`]("$D9FQA9SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S('1H92!T87-K(&9R;VT@
M=&AE('1A<VML:7-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A
M<VL@(%1H92!N86UE(&]F('1H92!T87-K('1O(&%L=&5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F5487-K*"1T87-K*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^:6Y,:7-T*"1T87-K*2D@>PH@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7W1A<VMS6R1T87-K72D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@27,@=&AI<R!T87-K(&%L<F5A9'D@:6X@=&AE('1A<VML:7-T
M/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A<VL@(%1H92!N86UE
M(&]F('1H92!T87-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5VAE=&AE<B!T:&4@=&%S:R!I<R!A;')E861Y(&EN('1H92!T87-K;&ES="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:6Y,:7-T*"1T87-K*0H@("`@>PH@("`@
M("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W1A<VMS6R1T87-K72D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@=&%S:W,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@=&%S:W,@
M=&AA="!S=&EL;"!N965D('1O(&)E(&1O;F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$QI<W0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1A
M<VMS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!(;W)D92!M
M;V1U;&4@=&AE('1A<VMS(&%R92!R=6YN:6YG('5N9&5R+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@2&]R9&4@;6]D=6QE(&YA;64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UO9'5L92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?;6]D=6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!03U-4(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(%!/4U0@9&%T82!F<F]M('1H92!I;FET:6%L(%523"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4&]S=$1A=&$H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!O<W1D871A.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!54DP@;V8@=&AE('=E8B!P86=E('1O(&QO860@869T
M97(@;6%I;G1E;F%N8V4@:7,@8V]M<&QE=&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!T87)G970@55),+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971487)G970H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W1A<F=E=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',O9&ES<&QA>7,@
M=&AE(&9L86<@=&\@<VAO=R!T:&%T('1A<VML:7-T(&AA<R!B965N('!R;V-E
M<W-E9"!A=`H@("`@("H@;&5A<W0@;VYC92X*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D<V5T("!3970@=&AE(&9L86<_"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!(87,@=&AE('1A<VML:7-T(&)E96X@<')O8V5S
M<V5D(&)E9F]R93\*("`@("`J+PH@("`@9G5N8W1I;VX@<')O8V5S<V5D*"1S
M970@/2!F86QS92D*("`@('L*("`@("`@("`D<F5T=F%L=64@/2`D=&AI<RT^
M7W!R;V-E<W-E9#L*("`@("`@("!I9B`H)'-E="D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W!R;V-E<W-E9"`]('1R=64["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5T=F%L=64["B`@("!]"@I]"@HO*BH*("H@06)S=')A8W0@8VQA
M<W,@=&\@86QL;W<@9F]R(&UO9'5L87)I>F%T:6]N(&]F('-P96-I9FEC(&UA
M:6YT96YA8V4@=&%S:W,N"B`J"B`J($9O<B!T:&ES(&5X<&QA;F%T:6]N+"!T
M:&4@<W!E8VEF:6,@2&]R9&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@8W)E
M871E"B`J(&UA:6YT96YA;F-E(&%C=&EO;G,@9F]R('=I;&P@8F4@;&%B96QE
M9"!(3U)$14%04"X*("H*("H@5&\@861D(&$@;F5W(&UA:6YT96YA;F-E('1A
M<VLL('EO=2!N965D('1O(&1O('1H92!F;VQL;W=I;F<Z"B`J(%LQ72!!9&0@
M<')E9F5R96YC92!T;R`B2$]21$5!4%`O8V]N9FEG+W!R969S+G!H<"(@9FEL
M92X*("H@("`@("A4:&4@;F%M92!O9B!T:&ES('!R969E<F5N8V4@=VEL;"!B
M92!R969E<G)E9"!T;R!A<R!04D5&3D%-12D*("H@("`@(%1H:7,@<')E9F5R
M96YC92!S:&]U;&0@8F4@;V8@='EP92`G8VAE8VMB;W@G("AI+F4N(#$@/2!O
M;CL@,"`](&]F9BDN"B`J("`@("!;3W!T:6]N86PZ72`@061D(&$@<')E9F5R
M96YC92!I;B!P<F5F<RYP:'`@;V8@=&AE(&YA;64*("H@("`@("`@("`@("`@
M("`@("`G4%)%1DY!345?:6YT97)V86PG('1O(&%L;&]W('1H92!U<V5R('1O
M('-E="!T:&4@:6YT97)V86PN"B`J("`@("`@("`@("`@("`@("`@)V1E9F%U
M;'0G('9A;'5E('-H;W5L9"!B92!S970@=&\@=&AE('9A;'5E<R!O9B!T:&4@
M:6YT97)V86P*("H@("`@("`@("`@("`@("`@("!C;VYS=&%N=',@86)O=F4N
M"B`J("`@("`@("`@("`@("`@("`@268@=&AI<R!P<F5F97)E;F-E(&1O97-N
M)W0@97AI<W0L('1H92!D969A=6QT(&EN=&5R=F%L"B`J("`@("`@("`@("`@
M("`@("`@=7-E9"!W:6QL(&)E('1H92!O;F4@=&AA="!A<'!E87)S(&EN("1M
M86EN=%]T87-K<RX*("H@6S)=($-R96%T92!A(&1I<F5C=&]R>2!N86UE9"`B
M2$]21$5!4%`O;&EB+TUA:6YT96YA;F-E(BX*("H@6S-=($-R96%T92!A(&-L
M87-S(&5N=&ET;&5D($UA:6YT96YA;F-E7TA/4D1%05!0('1H870@97AT96YD
M<R!T:&4*("H@("`@($UA:6YT96YA;F-E(&-L87-S+@H@*B`@("`@5&AI<R!C
M;&%S<R!S:&]U;&0@8V]N=&%I;B!O;FQY('1H92!A<'!L:6-A=&EO;B!S<&5C
M:69I8R!D969I;FET:6]N<R!O9@H@*B`@("`@)&UA:6YT7W1A<VMS("AS964@
M86)O=F4@9F]R(&1E<V-R:7!T:6]N*2X*("H@("`@(%-A=F4@=&AI<R!F:6QE
M(&%S(")(3U)$14%04"]L:6(O36%I;G1E;F%N8V4O2$]21$5!4%`N<&AP(BX*
M("H@6S1=($-R96%T92!A(&1I<F5C=&]R>2!T:71L960@(DA/4D1%05!0+VQI
M8B]-86EN=&5N86YC92]487-K(BX*("H@6S5=($-R96%T92!M;V1U;&5S(&EN
M($A/4D1%05!0+VQI8B]-86EN=&5N86YC92]487-K(&YA;65D("=04D5&3D%-
M12YP:'`G"B`J("`@("!T:&%T(&5X=&5N9"!T:&4@36%I;G1E;F%N8V5?5&%S
M:R!C;&%S<RX*("H@("`@(%1H92!C;&%S<R!S:&]U;&0@8F4@;F%M960@36%I
M;G1E;F%N8V5?5&%S:U]04D5&3D%-12X*("H@("`@(%1H92!C;&%S<R!S:&]U
M;&0@9&5C;&%R92!T:&4@9F]L;&]W:6YG('1W;R!M971H;V1S.@H@*B`@("`@
M("`G9&]-86EN=&5N86YC92<@+2!4:&ES(&ES('1H92!F=6YC=&EO;B!T:&%T
M(&ES(')U;B!T;R!D;R!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<W!E8VEF:65D(&UA:6YT96YA;F-E(&]P97)A=&EO;BX*("H@("`@("`@)V1E
M<V-R:6)E36%I;G1E;F%N8V4G("T@5&AI<R!F=6YC=&EO;B!S971S('1H92!P
M<F5F97)E;F-E('1E>'0*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@86YD('1E>'0@=&\@8F4@=7-E9"!O;B!T:&4@8V]N9FER;6%T:6]N"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!A9V4N("!3:&]U;&0@
M<F5T=7)N(&$@9&5S8W)I<'1I;VX@;V8@=VAA=`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!Y;W5R("=D;TUA:6YT96YA;F-E)R!F=6YC=&EO
M;B!I<R!A8F]U="!T;R!D;RX*("H@("`@($YE:71H97(@9G5N8W1I;VX@<F5Q
M=6ER97,@86YY('!A<F%M971E<G,@<&%S<V5D(&EN+@H@*@H@*B!4:&5R92!A
M<F4@,R!D:69F97)E;G0@='EP97,@;V8@;6%I;G1E;F%N8V4@*'-E="!V:6$@
M)%]D:7-P;&%Y7W1Y<&4I.@H@*B!;,5T@34%)3E1%3D%.0T5?3U544%547T-/
M3D9)4DT*("H@("`@($5A8V@@;W5T<'5T(&9R;VT@9&5S8W)I8F5-86EN=&5N
M86YC92@I('=I;&P@:&%V92!A(&-H96-K8F]X(&%S<V]C:6%T960*("H@("`@
M('=I=&@@:70N($9O<B!E86-H(&-H96-K8F]X('-E;&5C=&5D+"!D;TUA:6YT
M96YA;F-E*"D@9F]R('1H870@=&%S:R!W:6QL"B`J("`@("!B92!R=6XN($UO
M<F4@=&AA;B`Q(&-O;F9I<FUA=&EO;B!M97-S86=E(&-A;B!B92!D:7-P;&%Y
M960@;VX@=&AE"B`J("`@("!M86EN=&5N86YC92!P86=E(&%T(&]N8V4N"B`J
M"B`J(%LR72!-04E.5$5.04Y#15]/5510551?04=2144*("H@("`@(%1H92!O
M=71P=70@9G)O;2!D97-C<FEB94UA:6YT96YA;F-E*"D@<VAO=6QD(&)E('1E
M>'0@87-K:6YG('1H92!U<V5R('1O"B`J("`@("!A9W)E92]D:7-A9W)E92!T
M;R!S<&5C:69I960@=&5R;7,N($EF("=Y97,G(&ES('-E;&5C=&5D+"!T:&4@
M4$]35`H@*B`@("`@=F%R:6%B;&4@)V%G<F5E)R!W:6QL(&)E('-E="X@268@
M)VYO)R!I<R!S96QE8W1E9"P@=&AE(%!/4U0@=F%R:6%B;&4*("H@("`@("=N
M;W1?86=R964G('=I;&P@8F4@<V5T+B!);B!E:71H97(@8V%S92P@9&]-86EN
M=&5N86YC92@I('=I;&P@04Q705E3(&)E"B`J("`@("!R=6XN"B`J("`@("`J
M(%1H:7,@<W1Y;&4@=VEL;"!B92!D:7-P;&%Y960@;VX@:71S(&]W;BP@<V5P
M87)A=&4@;6%I;G1E;F%N8V4@<&%G92X@*@H@*@H@*B!;,UT@34%)3E1%3D%.
M0T5?3U544%547TY/5$E#10H@*B`@("`@5&AE(&]U='!U="!F<F]M(&1E<V-R
M:6)E36%I;G1E;F%N8V4H*2!S:&]U;&0@8F4@86YY(&YO;BUI;G1E<F%C=&EV
M92!T97AT"B`J("`@("!D97-I<F5D+B!4:&5R92!W:6QL(&)E(&$@<VEN9VQE
M("=#;&EC:R!T;R!#;VYT:6YU92<@8G5T=&]N(&)E;&]W('1H:7,*("H@("`@
M('1E>'0N(&1O36%I;G1E;F%N8V4H*2!W:6QL($%,5T%94R!B92!R=6XN"B`J
M("`@("`J(%1H:7,@<W1Y;&4@=VEL;"!B92!D:7-P;&%Y960@;VX@:71S(&]W
M;BP@<V5P87)A=&4@;6%I;G1E;F%N8V4@<&%G92X@*@H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,2TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J($!S:6YC92`@($AO<F1E(#$N,RXU"B`J($!P86-K86=E($AO<F1E7TUA
M:6YT96YA;F-E"B`J+PIC;&%S<R!-86EN=&5N86YC95]487-K('L*"B`@("`O
M*BH*("`@("`J(%1H92!S='EL92!O9B!T:&4@;6%I;G1E;F%N8V4@<&%G92!O
M=71P=70N"B`@("`@*B!0;W-S:6)L92!V86QU97,Z($U!24Y414Y!3D-%7T]5
M5%!55%]#3TY&25)-+`H@("`@("H@("`@("`@("`@("`@("`@("!-04E.5$5.
M04Y#15]/5510551?04=2144L"B`@("`@*B`@("`@("`@("`@("`@("`@($U!
M24Y414Y!3D-%7T]55%!55%].3U1)0T4*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1?9&ES<&QA>5]T>7!E(#T@34%)3E1%
M3D%.0T5?3U544%547T-/3D9)4DT["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!-86EN=&5N86YC95]487-K*"D*
M("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($1O(&UA:6YT96YA;F-E(&]P
M97)A=&EO;B`H:68@:70@:&%S(&)E96X@8V]N9FER;65D*2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE(&UA:6YT96YA;F-E
M(&]P97)A=&EO;B!W87,@<W5C8V5S<V9U;"!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O36%I;G1E;F%N
M8V4H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!D97-C<FEP=&EO;B!I;F9O<FUA=&EO;B!F;W(@
M=&AE(&UA:6YT96YA;F-E('!A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@($1E<V-R:7!T:6]N('1H870@=VEL;"!B92!D:7-P;&%Y960@;VX@
M=&AE(&UA:6YT96YA;F-E"B`@("`@*B`@("`@("`@("`@("`@("`@8V]N9FER
M;6%T:6]N('!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<V-R:6)E36%I
M;G1E;F%N8V4H*0H@("`@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1E<VER960@;W5T<'5T('1Y<&4@
M9F]R('1H92!M86EN=&5N86YC92!P86=E+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@1&5S:7)E9"!O=71P=70@='EP92!F;W(@=&AE(&UA:6YT
M96YA;F-E(&-O;F9I<FUA=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("!P
M86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$:7-P;&%Y5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&ES<&QA>5]T>7!E.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W-S$R
M`#$P-3$U-#,Q,#8Q`#`R,38U-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@4V5S<VEO;DAA;F1L97(Z
M.B!D969I;F5S(&%N($%022!F;W(@:6UP;&5M96YT:6YG(&-U<W1O;2!S97-S
M:6]N"B`J(&AA;F1L97)S(&9O<B!02%`N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<"QV(#$N,3,N
M,3`N,3$@,C`P-B\P-R\Q-"`P.#HU-#HU.2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J
M+PIC;&%S<R!397-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@*B!(87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@4V5S<VEO
M;DAA;F1L97(@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E<W-I;VY(86YD;&5R*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M='5R;B!A(&-O;F-R971E(%-E<W-I;VY(86YD;&5R(&EN<W1A;F-E(&)A<V5D
M(&]N"B`@("`@*B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4V5S<VEO;DAA;F1L
M97(@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@
M8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@4V5S<VEO
M;DAA;F1L97(@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("!F
M86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@("1A<'`@/2`D9')I
M=F5R6S!=.PH@("`@("`@("`@("`D9')I=F5R(#T@)&1R:79E<ELQ73L*("`@
M("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*
M("`@("`@("!I9B`H)&1R:79E<B`]/2`G;65M8V%C:&5D)RD@>PH@("`@("`@
M("`@("`O+R!4<F%P(&9O<B!O;&0@9')I=F5R(&YA;64N"B`@("`@("`@("`@
M("1D<FEV97(@/2`G;65M8V%C:&4G.PH@("`@("`@('T*"B`@("`@("`@)&-L
M87-S(#T@)U-E<W-I;VY(86YD;&5R7R<@+B`D9')I=F5R.PH@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D87!P*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+VQI8B]397-S:6]N2&%N9&QE<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`G2&]R9&4O4V5S<VEO;DAA;F1L97(O)R`N("1D<FEV97(@+B`G+G!H<"<[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D<&%R
M86US*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D92YP
M:'`G.PH@("`@("`@("`@("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)W-E<W-I;VYH86YD;&5R)RP@)&1R:79E<BD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&AA;F1L97(@/2!N97<@)&-L87-S*"1P87)A
M;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H86YD;&5R(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L
M87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&AA;F1L97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!397-S:6]N2&%N
M9&QE<@H@("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@270@=VEL
M;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@;F\@4V5S
M<VEO;DAA;F1L97(@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S
M"B`@("`@*B!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9397-S:6]N2&%N
M9&QE<CHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D<FEV97(@(%-E92!397-S:6]N2&%N9&QE<CHZ9F%C=&]R>2@I+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!3964@4V5S<VEO;DAA;F1L97(Z
M.F9A8W1O<GDH*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M8W)E871E9"!C;VYC<F5T92!397-S:6]N2&%N9&QE<B!I;G-T86YC92P@;W(@
M9F%L<V4*("`@("`J("`@("`@("`@("`@("`@(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!N
M=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S(#T@87)R87DH
M*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I
M=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*&5M<'1Y*"1I;G-T86YC97-;
M)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA
M='5R95T@/2`F4V5S<VEO;DAA;F1L97(Z.F9A8W1O<GDH)&1R:79E<BP@)'!A
M<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD
M<VEG;F%T=7)E73L*("`@('T*"B`@("`O*BH*("`@("`J($]P96X@=&AE(%-E
M<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V%V95]P871H("`@("!4
M:&4@<&%T:"!T;R!T:&4@<V5S<VEO;B!O8FIE8W0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S97-S:6]N7VYA;64@(%1H92!N86UE(&]F('1H92!S97-S:6]N
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]P
M96XH)'-A=F5?<&%T:"P@)'-E<W-I;VY?;F%M92D*("`@('L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E('1H92!3
M97-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L
M;W-E*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E860@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S
M:6]N(&ED96YT:69I97(@9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97-S:6]N(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N
M(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A
M('1O('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@
M("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J($!P87)A
M;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D
M:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@
M<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@4V5S<VEO;DAA;F1L
M97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE
M<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M97-T<F]Y*"1I9"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F<F]M('1H92!3
M97-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AL:69E=&EM92`@
M5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W
M:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X;&EF971I;64@/2`S
M,#`I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E
M<FUI;F5S(&EF(&$@<V5S<VEO;B!B96QO;F=S('1O(&%N(&%U=&AE;G1I8V%T
M960@=7-E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S
M:6]N(&1A=&$@:71S96QF+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E='5R
M;E]U<V5R("!)9B!T<G5E+"!R971U<FX@=&AE('5S97(@<V5S<VEO;B!D871A
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQS=')I;F<@(%1R=64@
M;W(@=&AE('5S97(G<R!S97-S:6]N(&1A=&$@:68@=&AE('-E<W-I;VX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&)E;&]N9W,@=&\@86X@875T
M:&5N=&EC871E9"!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:7-!=71H
M96YT:6-A=&5D*"1S97-S:6]N7V1A=&$L("1R971U<FY?9&%T82`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<V5S<VEO;E]D871A*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!W
M:&EL92`H)'-E<W-I;VY?9&%T82D@>PH@("`@("`@("`@("`D=F%R<R`](&5X
M<&QO9&4H)WPG+"`D<V5S<VEO;E]D871A+"`R*3L*("`@("`@("`@("`@)&1A
M=&$@/2!U;G-E<FEA;&EZ92@D=F%R<ULQ72D["B`@("`@("`@("`@(&EF("@D
M=F%R<ULP72`]/2`G7U]A=71H)RD@>PH@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1D871A*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&1A=&%;)V%U=&AE;G1I8V%T960G72DI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)')E='5R;E]D871A(#\@)&1A=&$@.B!T<G5E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1S97-S:6]N7V1A=&$@/2!S=6)S
M='(H)'-E<W-I;VY?9&%T82P@<W1R;&5N*"1V87)S6S!=*2`K('-T<FQE;BAS
M97)I86QI>F4H)&1A=&$I*2`K(#$I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!A(&QI<W0@;V8@=&AE('9A;&ED('-E<W-I;VX@:61E
M;G1I9FEE<G,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F('9A;&ED('-E<W-I;VX@:61E
M;G1I9FEE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<W-I;VY)1',H
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO
M="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE('1H92!N=6UB97(@;V8@8W5R<F5N=&QY(&QO9V=E9"!I;B!U<V5R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($$@8V]U;G0@;V8@;&]G
M9V5D(&EN('5S97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=$%U=&AE
M;G1I8V%T9615<V5R<R@I"B`@("!["B`@("`@("`@)&-O=6YT(#T@,#L*"B`@
M("`@("`@)'-E<W-I;VYS(#T@)'1H:7,M/F=E=%-E<W-I;VY)1',H*3L*("`@
M("`@("!I9B`H:7-?82@D<V5S<VEO;G,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1S97-S:6]N<R!A<R`D:60I('L*("`@("`@("`@("`@)&1A
M=&$@/2`D=&AI<RT^<F5A9"@D:60I.PH@("`@("`@("`@("!I9B`H(6ES7V$H
M)&1A=&$L("=014%27T5R<F]R)RD@)B8*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:7-!=71H96YT:6-A=&5D*"1D871A*2D@>PH@("`@("`@("`@("`@("`@
M)&-O=6YT*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8V]U;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M;&ES="!O9B!C=7)R96YT;'D@;&]G9V5D(&EN('5S97)S+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!L;V=G960@:6X@=7-E<G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!=71H96YT:6-A=&5D57-E<G,H
M)&1A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D=7-E<G,@/2!A<G)A>2@I
M.PH*("`@("`@("`D<V5S<VEO;G,@/2`D=&AI<RT^9V5T4V5S<VEO;DE$<R@I
M.PH@("`@("`@(&EF("AI<U]A*"1S97-S:6]N<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'-E<W-I;VYS.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)'-E<W-I;VYS(&%S("1I9"D@>PH@("`@("`@("`@
M("`D9&%T82`]("1T:&ES+3YR96%D*"1I9"D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&1A=&$@/2`D
M=&AI<RT^7VES075T:&5N=&EC871E9"@D9&%T82P@=')U92D["B`@("`@("`@
M("`@(&EF("@D9&%T82`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1U
M<V5R(#T@)&1A=&%;)W5S97))9"==.PH@("`@("`@("`@("`@("`@:68@*"1D
M871E*2!["B`@("`@("`@("`@("`@("`@("`@)'5S97(@/2!D871E*"=R)RP@
M)&1A=&%;)W1I;65S=&%M<"==*2`N("<@("<@+B`D=7-E<CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1U<V5R<UM=(#T@)'5S97(["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7-E<G,[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T9O<FTN<&AP````````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#,R-#8U,@`Q,#4Q-30S,3`V,0`P,3<V-#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J($AO<F1E7T9O<FT@36%S=&5R($-L87-S+@H@*@H@*B!4:&4@2&]R9&5?
M1F]R;3HZ('!A8VMA9V4@<')O=FED97,@9F]R;2!R96YD97)I;F<L('9A;&ED
M871I;VXL(&%N9`H@*B!O=&AE<B!F=6YC=&EO;F%L:71Y(&9O<B!T:&4@2&]R
M9&4@07!P;&EC871I;VX@1G)A;65W;W)K+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP+'8@,2XS,#8N,BXT."`R,#`V+S`T+S(V(#$U
M.C4R.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V(%)O
M8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!#
M;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]B97)T($4N
M($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(
M;W)D95]&;W)M('L*"B`@("!V87(@)%]N86UE(#T@)R<["B`@("!V87(@)%]T
M:71L92`]("<G.PH@("`@=F%R("1?97AT<F$@/2`G)SL*("`@('9A<B`D7W9A
M<G,["B`@("!V87(@)%]S=6)M:70@/2!A<G)A>2@I.PH@("`@=F%R("1?<F5S
M970@/2!F86QS93L*("`@('9A<B`D7V5R<F]R<R`](&%R<F%Y*"D["B`@("!V
M87(@)%]S=6)M:71T960@/2!N=6QL.PH@("`@=F%R("1?<V5C=&EO;G,@/2!A
M<G)A>2@I.PH@("`@=F%R("1?;W!E;E]S96-T:6]N(#T@;G5L;#L*("`@('9A
M<B`D7V-U<G)E;G1396-T:6]N(#T@87)R87DH*3L*("`@('9A<B`D7W9A<FEA
M8FQE<R`](&%R<F%Y*"D["B`@("!V87(@)%]H:61D96Y687)I86)L97,@/2!A
M<G)A>2@I.PH@("`@=F%R("1?=7-E1F]R;51O:V5N(#T@=')U93L*("`@('9A
M<B`D7V%U=&]F:6QL960@/2!F86QS93L*("`@('9A<B`D7V5N8W1Y<&4@/2!N
M=6QL.PH@("`@=F%R("1?:&5L<"`](&9A;'-E.PH*("`@(&9U;F-T:6]N($AO
M<F1E7T9O<FTH)B1V87)S+"`D=&ET;&4@/2`G)RP@)&YA;64@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@("`@("`@
M("`D;F%M92`](%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1T:&ES*2D["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7W9A<G,@/2`F)'9A<G,["B`@("`@
M("`@)'1H:7,M/E]T:71L92`]("1T:71L93L*("`@("`@("`D=&AI<RT^7VYA
M;64@/2`D;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1F
M;W)M+"`F)'9A<G,L("1T:71L92`]("<G+"`D;F%M92`](&YU;&PI"B`@("![
M"B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@("1S:6=N871U
M<F4@/2!S97)I86QI>F4H87)R87DH)&9O<FTL("1V87)S+"`D=&ET;&4L("1N
M86UE*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U
M<F5=*2D@>PH@("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1F;W)M*2D@
M>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9N
M97<@)&9O<FTH)'9A<G,L("1T:71L92P@)&YA;64I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72`]("9N97<@2&]R9&5?1F]R;2@D=F%R<RP@)'1I=&QE+"`D;F%M92D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N
M8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%9A<G,H
M)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<R`]("8D=F%R<SL*
M("`@('T*"B`@("!F=6YC=&EO;B!G9714:71L92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T
M5&ET;&4H)'1I=&QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D
M=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T17AT<F$H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V5X=')A.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-E=$5X=')A*"1E>'1R82D*("`@('L*("`@("`@("`D=&AI<RT^7V5X
M=')A(#T@)&5X=')A.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$YA;64H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VYA;64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971S(&]R(&=E=',@=VAE=&AE<B!T:&4@9F]R;2!S:&]U
M;&0@8F4@=F5R:69I960@8GD@=&]K96YS+@H@("`@("H@5&]K96YS(&%R92!U
M<V5D('1O('9E<FEF>2!T:&%T(&$@9F]R;2!I<R!O;FQY('-U8FUI='1E9"!O
M;F-E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1T;VME;B`@268@
M<W!E8VEF:65D+"!S971S('=H971H97(@=&\@=7-E(&9O<FT@=&]K96YS+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!F;W)M('1O
M:V5N<R!A<F4@8F5I;F<@=7-E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=7-E
M5&]K96XH)'1O:V5N(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU
M;&PH)'1O:V5N*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S949O<FU4;VME
M;B`]("1T;VME;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=7-E1F]R;51O:V5N.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!R
M96YD97)E<B!F;W(@=&AI<R!F;W)M+"!E:71H97(@82!C=7-T;VT@<F5N9&5R
M97(@;W(@=&AE"B`@("`@*B!S=&%N9&%R9"!O;F4N"B`@("`@*@H@("`@("H@
M5&\@=7-E(&$@8W5S=&]M(&9O<FT@<F5N9&5R97(L('EO=7(@9F]R;2!C;&%S
M<R!N965D<R!T;PH@("`@("H@;W9E<G)I9&4@=&AI<R!F=6YC=&EO;CH*("`@
M("`J(#QC;V1E/@H@("`@("H@9G5N8W1I;VX@)F=E=%)E;F1E<F5R*"D*("`@
M("`J('L*("`@("`J("`@("`D<B`]("9N97<@0W5S=&]M1F]R;5)E;F1E<F5R
M*"D["B`@("`@*B`@("`@<F5T=7)N("1R.PH@("`@("H@?0H@("`@("H@/"]C
M;V1E/@H@("`@("H*("`@("`J("XN+B!W:&5R92!#=7-T;VU&;W)M4F5N9&5R
M97(@:7,@=&AE(&-L87-S;F%M92!O9B!T:&4@8W5S=&]M"B`@("`@*B!R96YD
M97)E<B!C;&%S<RP@=VAI8V@@<VAO=6QD(&5X=&5N9"!(;W)D95]&;W)M7U)E
M;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M(&AA<V@@;V8@<F5N9&5R97(M<W!E8VEF:6,@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&]B:F5C="!(;W)D95]&;W)M7U)E;F1E<F5R("!4
M:&4@9F]R;2!R96YD97)E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%)E
M;F1E<F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PH@("`@("`@("1R
M96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@D<&%R86US*3L*
M("`@("`@("!R971U<FX@)')E;F1E<F5R.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9G9714>7!E*"1T>7!E+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D='EP95]C;&%S<R`]("=(;W)D95]&;W)M7U1Y<&5?)R`N("1T>7!E
M.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1T>7!E7V-L87-S*2D@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G3F]N
M97AI<W1A;G0@8VQA<W,@(B5S(B!F;W(@9FEE;&0@='EP92`B)7,B)RP@)'1Y
M<&5?8VQA<W,L("1T>7!E*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H@("`@("`@("1T>7!E7V]B(#T@)FYE=R`D='EP95]C;&%S<R@I.PH@
M("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D='EP95]O8BP@
M)VEN:70G*2P@)'!A<F%M<RD["B`@("`@("`@<F5T=7)N("1T>7!E7V]B.PH@
M("`@?0H*("`@(&9U;F-T:6]N('-E=%-E8W1I;VXH)'-E8W1I;VX@/2`G)RP@
M)&1E<V,@/2`G)RP@)&EM86=E(#T@)R<L("1E>'!A;F1E9"`]('1R=64I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]C=7)R96YT4V5C=&EO;B`]("1S96-T:6]N
M.PH@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]S96-T:6]N<RD@)B8@(21T
M:&ES+3YG971/<&5N4V5C=&EO;B@I*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971/<&5N4V5C=&EO;B@D<V5C=&EO;BD["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=D97-C)UT@/2`D9&5S8SL*("`@
M("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG97AP86YD960G72`]
M("1E>'!A;F1E9#L*("`@("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N
M75LG:6UA9V4G72`]("1I;6%G93L*("`@('T*"B`@("!F=6YC=&EO;B!G9713
M96-T:6]N1&5S8R@D<V5C=&EO;BD*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]S96-T:6]N<ULD<V5C=&EO;EU;)V1E<V,G73L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971396-T:6]N26UA9V4H)'-E8W1I;VXI"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=I;6%G92==
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$]P96Y396-T:6]N*"1S96-T:6]N
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<RT^<V5T*"=?7V9O<FU/<&5N
M4V5C=&EO;B<L("1S96-T:6]N*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971/
M<&5N4V5C=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%R
M<RT^9V5T*"=?7V9O<FU/<&5N4V5C=&EO;B<I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=%-E8W1I;VY%>'!A;F1E9%-T871E*"1S96-T:6]N+"`D8F]O;&5A
M;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D8F]O;&5A;BD@>PH@("`@
M("`@("`@("`O*B!/;FQY('1H92!B;V]L96%N('9A;'5E(&ES(')E<75I<F5D
M+B`J+PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S96-T:6]N<ULD<V5C
M=&EO;EU;)V5X<&%N9&5D)UT["B`@("`@("`@?0H*("`@("`@("`O*B!.965D
M('1O(')E='5R;B!T:&4@=F%L=65S(&9O<B!U<V4@:6X@<W1Y;&5S+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG97AP86YD
M960G72D@>PH@("`@("`@("`@("!R971U<FX@)V)L;V-K)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)VYO;F4G.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F%D9%9A<FEA8FQE*"1H=6UA;DYA;64L("1V87).86UE+"`D='EP92P@
M)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1R96%D;VYL
M>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^:6YS97)T5F%R:6%B;&5"969O<F4H;G5L;"P@)&AU
M;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D+"`D<F5A9&]N;'DL
M("1D97-C<FEP=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B`F:6YS97)T5F%R:6%B;&5"969O
M<F4H)&)E9F]R92P@)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E9"P@)')E
M861O;FQY(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<V-R:7!T:6]N(#T@;G5L;"P@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@)'1Y<&4@/2`F)'1H:7,M/F=E=%1Y<&4H)'1Y<&4L
M("1P87)A;7,I.PH@("`@("`@("1V87(@/2`F;F5W($AO<F1E7T9O<FU?5F%R
M:6%B;&4H)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D+"`D<F5A
M9&]N;'DL("1D97-C<FEP=&EO;BD["@H@("`@("`@("\J(%-E="!T:&4@9F]R
M;2!O8FIE8W0@<F5F97)E;F-E(&EN('1H92!V87(N("HO"B`@("`@("`@)'9A
M<BT^<V5T1F]R;4]B*"1T:&ES*3L*"B`@("`@("`@:68@*"1V87(M/F=E=%1Y
M<&5.86UE*"D@/3T@)V5N=6TG("8F"B`@("`@("`@("`@(&-O=6YT*"1V87(M
M/F=E=%9A;'5E<R@I*2`]/2`Q*2!["B`@("`@("`@("`@("1V86QS(#T@87)R
M87E?:V5Y<R@D=F%R+3YG971686QU97,H*2D["B`@("`@("`@("`@("1T:&ES
M+3Y?=F%R<RT^861D*"1V87(M/G9A<DYA;64L("1V86QS6S!=*3L*("`@("`@
M("`@("`@)'9A<BT^7V%U=&]F:6QL960@/2!T<G5E.PH@("`@("`@('T@96QS
M96EF("@D=F%R+3YG9714>7!E3F%M92@I(#T]("=F:6QE)R!\?`H@("`@("`@
M("`@("`@("`@("`D=F%R+3YG9714>7!E3F%M92@I(#T]("=I;6%G92<I('L*
M("`@("`@("`@("`@)'1H:7,M/E]E;F-T>7!E(#T@)VUU;'1I<&%R="]F;W)M
M+61A=&$G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]C
M=7)R96YT4V5C=&EO;BDI('L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT
M4V5C=&EO;B`]("=?7V)A<V4G.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M7VYU;&PH)&)E9F]R92DI('L*("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L
M97-;)'1H:7,M/E]C=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1N=6T@/2`P.PH@("`@("`@("`@("!W
M:&EL92`H:7-S970H)'1H:7,M/E]V87)I86)L97-;)'1H:7,M/E]C=7)R96YT
M4V5C=&EO;EU;)&YU;5TI("8F"B`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W9A<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N75LD;G5M72T^9V5T
M5F%R3F%M92@I("$]("1B969O<F4I('L*("`@("`@("`@("`@("`@("1N=6TK
M*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I;VY=6R1N=6U=*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H:7,M/E]C
M=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H:7,M/E]C
M=7)R96YT4V5C=&EO;ET@/2!A<G)A>5]M97)G92@*("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA8FQE<ULD=&AI<RT^7V-U
M<G)E;G1396-T:6]N72P@,"P@)&YU;2DL"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH)B1V87(I+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-L:6-E
M*"1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I;VY=+"`D
M;G5M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=F%R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A('9A<FEA
M8FQE(&9R;VT@=&AE(&9O<FTN"B`@("`@*@H@("`@("H@07,@;VYL>2!V87)I
M86)L97,@8V%N(&)E('!A<W-E9"!B>2!R969E<F5N8V4L('EO=2!N965D('1O
M(&-A;&P@=&AI<PH@("`@("H@;65T:&]D('1H:7,@=V%Y(&EF('=A;G0@=&\@
M<&%S<R!A('9A<FEA8FQE(&YA;64Z"B`@("`@*B`\8V]D93X*("`@("`J("1F
M;W)M+3YR96UO=F5687)I86)L92@D=F%R(#T@)W9A<FYA;64G*3L*("`@("`J
M(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R;5]687)I
M86)L97QS=')I;F<@)'9A<B`@16ET:&5R('1H92!V87)I86)L92=S(&YA;64@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@=F%R:6%B;&4@=&\@<F5M;W9E(&9R;VT@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('9A
M<FEA8FQE('=A<R!F;W5N9"`H86YD(&1E;&5T960I+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96UO=F5687)I86)L92@F)'9A<BD*("`@('L*("`@("`@("!F
M;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?=F%R:6%B;&5S*2!A<R`D<V5C
M=&EO;BD@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES
M+3Y?=F%R:6%B;&5S6R1S96-T:6]N72D@87,@)&DI('L*("`@("`@("`@("`@
M("`@(&EF("@H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L92<I("8F
M("1T:&ES+3Y?=F%R:6%B;&5S6R1S96-T:6]N75LD:5T@/3T]("1V87(I('Q\
M"B`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3Y?=F%R:6%B;&5S6R1S96-T
M:6]N75LD:5TM/F=E=%9A<DYA;64H*2`]/2`D=F%R*2D@>PH@("`@("`@("`@
M("`@("`@("`@("\O(%-L:6-E(&]U="!T:&4@=F%R:6%B;&4@=&\@8F4@<F5M
M;W9E9"X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A<FEA8FQE<ULD
M=&AI<RT^7V-U<G)E;G1396-T:6]N72`](&%R<F%Y7VUE<F=E*`H@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA8FQE
M<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@,"P@)&DI+`H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA8FQE<ULD
M=&AI<RT^7V-U<G)E;G1396-T:6]N72P@)&D@*R`Q*2D["@H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9A9&1(:61D96XH)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+"`D<F5Q
M=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("1R96%D;VYL>2`](&9A
M;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D='EP92`]
M("8D=&AI<RT^9V5T5'EP92@D='EP92P@)'!A<F%M<RD["B`@("`@("`@)'9A
M<B`]("9N97<@2&]R9&5?1F]R;5]687)I86)L92@D:'5M86Y.86UE+"`D=F%R
M3F%M92P@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5Q=6ER960L("1R96%D;VYL>2P@)&1E<V-R:7!T:6]N*3L*
M("`@("`@("`D=F%R+3YH:61E*"D["B`@("`@("`@)'1H:7,M/E]H:61D96Y6
M87)I86)L97-;72`]("8D=F%R.PH@("`@("`@(')E='5R;B`D=F%R.PH@("`@
M?0H*("`@(&9U;F-T:6]N("9G971687)I86)L97,H)&9L870@/2!T<G5E+"`D
M=VET:$AI9&1E;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D9FQA="D@
M>PH@("`@("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?=F%R:6%B;&5S(&%S("1S96-T:6]N*2!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<V5C=&EO;B!A<R`D=F%R*2!["B`@("`@
M("`@("`@("`@("`@("`@)'9A<G-;72`]("1V87(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1W:71H2&ED9&5N
M*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E;E9A
M<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("`@("`@("`@)'9A<G-;
M72`]("1V87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("1V87)S.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W9A<FEA8FQE<SL*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5T0G5T=&]N<R@D<W5B;6ET+"`D<F5S970@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)'-U8FUI="`]/3T@=')U92!\
M?"!I<U]N=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S=6)M:70I*2!["B`@("`@
M("`@("`@("\J($1E9F%U;'0@=&\@)U-U8FUI="<N("HO"B`@("`@("`@("`@
M("1S=6)M:70@/2!A<G)A>2A?*")3=6)M:70B*2D["B`@("`@("`@?2!E;'-E
M:68@*"%I<U]A<G)A>2@D<W5B;6ET*2D@>PH@("`@("`@("`@("`O*B!$969A
M=6QT('1O(&%R<F%Y(&EF(&YO="!P87-S960N("HO"B`@("`@("`@("`@("1S
M=6)M:70@/2!A<G)A>2@D<W5B;6ET*3L*("`@("`@("!]"B`@("`@("`@+RH@
M3VYL>2!I9B`D<F5S970@:7,@<W1R:6-T;'D@=')U92!I;G-E<G0@9&5F875L
M="`G4F5S970G+B`J+PH@("`@("`@(&EF("@D<F5S970@/3T]('1R=64I('L*
M("`@("`@("`@("`@)')E<V5T(#T@7R@B4F5S970B*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?<W5B;6ET(#T@)'-U8FUI=#L*("`@("`@("`D=&AI
M<RT^7W)E<V5T(#T@)')E<V5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&%P<&5N
M9$)U='1O;G,H)'-U8FUI="D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1S=6)M:70I*2!["B`@("`@("`@("`@("1S=6)M:70@/2!A<G)A>2@D<W5B
M;6ET*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<W5B;6ET(#T@87)R
M87E?;65R9V4H)'1H:7,M/E]S=6)M:70L("1S=6)M:70I.PH@("`@?0H*("`@
M(&9U;F-T:6]N('!R97-E<G9E5F%R0GE0;W-T*"8D=F%R<RP@)'9A<FYA;64L
M("1A;'1?=F%R;F%M92`]("<G*0H@("`@>PH@("`@("`@("1V86QU92`]("1V
M87)S+3YG971%>&ES=',H)'9A<FYA;64L("1W87-S970I.PH*("`@("`@("`O
M*B!)9B!A;B!A;'1E<FYA=&4@;F%M92!I<R!G:79E;B!U;F1E<B!W:&EC:"!T
M;R!P<F5S97)V92!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H)&%L=%]V87)N
M86UE*2!["B`@("`@("`@("`@("1V87)N86UE(#T@)&%L=%]V87)N86UE.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1W87-S970I('L*("`@("`@("`@("`@
M)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@D=F%R;F%M92P@)'9A;'5E*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!R97-E<G9E5F%R0GE0;W-T*"1V
M87)N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1V
M86QU92DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1I9"`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R97-E<G9E5F%R
M0GE0;W-T*"1V87)N86UE("X@)ULG("X@)&ED("X@)UTG+"`D=F%L*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V87)N
M86UE(#T@:'1M;'-P96-I86QC:&%R<R@D=F%R;F%M92D["B`@("`@("`@("`@
M("1V86QU92`](&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*3L*("`@("`@("`@
M("`@<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E<R(@=F%L
M=64](B5S(B`O/B<@+B`B7&XB+`H@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`D=F%L=64I.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!O<&5N*"8D<F5N9&5R97(L("8D=F%R<RP@)&%C
M=&EO;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y<&4I("8F("%I<U]N=6QL*"1T
M:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@("`@)&5N8W1Y<&4@/2`D=&AI
M<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@("`@("1R96YD97)E<BT^;W!E
M;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^7VYA;64L("1E;F-T>7!E*3L*
M("`@("`@("`D<F5N9&5R97(M/FQI<W1&;W)M5F%R<R@D=&AI<RD["@H@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]N86UE*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W!R97-E<G9E5F%R0GE0;W-T*"=F;W)M;F%M92<L("1T:&ES+3Y?
M;F%M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]U<V5&;W)M
M5&]K96XI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]4;VME
M;BYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W!R97-E<G9E5F%R0GE0;W-T
M*"=?7V9O<FU4;VME;E\G("X@)'1H:7,M/E]N86UE+"!(;W)D95]4;VME;CHZ
M9V5N97)A=&5)9"@D=&AI<RT^7VYA;64I*3L*("`@("`@("!]"@H@("`@("`@
M("\J($QO;W`@=&AR;W5G:"!V87)S(&%N9"!C:&5C:R!F;W(@86YY('-P96-I
M86P@8V%S97,@=&\@<')E<V5R=F4N("HO"B`@("`@("`@)'9A<FEA8FQE<R`]
M("1T:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R
M:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@+RH@4')E<V5R=F4@=F%L
M=64@:68@8VAA;F=E(&AA<R!T;R!B92!T<F%C:V5D+B`J+PH@("`@("`@("`@
M("!I9B`H)'9A<BT^9V5T3W!T:6]N*"=T<F%C:V-H86YG92<I*2!["B`@("`@
M("`@("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@
M)'9A<FYA;64L("=?7V]L9%\G("X@)'9A<FYA;64I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E;E9A
M<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("1T:&ES+3YP<F5S97)V
M959A<D)Y4&]S="@D=F%R<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@8VQO<V4H)B1R96YD97)E<BD*("`@
M('L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"D["B`@("!]"@H@("`@9G5N
M8W1I;VX@<F5N9&5R06-T:79E*"8D<F5N9&5R97(L("8D=F%R<RP@)&%C=&EO
M;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PL("1F;V-U<R`]
M('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y<&4I("8F
M("%I<U]N=6QL*"1T:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@("`@)&5N
M8W1Y<&4@/2`D=&AI<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@("`@("1R
M96YD97)E<BT^;W!E;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^9V5T3F%M
M92@I+"`D96YC='EP92D["B`@("`@("`@)')E;F1E<F5R+3YL:7-T1F]R;59A
M<G,H)'1H:7,I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;F%M92DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@G9F]R
M;6YA;64G+"`D=&AI<RT^7VYA;64I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1T:&ES+3Y?=7-E1F]R;51O:V5N*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O5&]K96XN<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]P
M<F5S97)V959A<D)Y4&]S="@G7U]F;W)M5&]K96Y?)R`N("1T:&ES+3Y?;F%M
M92P@2&]R9&5?5&]K96XZ.F=E;F5R871E260H)'1H:7,M/E]N86UE*2D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]S96-T:6]N<RDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@G7U]F
M;W)M3W!E;E-E8W1I;VXG+"`D=&AI<RT^9V5T3W!E;E-E8W1I;VXH*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=F%R<R!A;F0@8VAE
M8VL@9F]R(&%N>2!S<&5C:6%L(&-A<V5S('1O"B`@("`@("`@("H@<')E<V5R
M=F4N("HO"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG971687)I86)L
M97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V87(I('L*
M("`@("`@("`@("`@+RH@4')E<V5R=F4@=F%L=64@:68@8VAA;F=E(&AA<R!T
M;R!B92!T<F%C:V5D+B`J+PH@("`@("`@("`@("!I9B`H)'9A<BT^9V5T3W!T
M:6]N*"=T<F%C:V-H86YG92<I*2!["B`@("`@("`@("`@("`@("`D=F%R;F%M
M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64L("=?7V]L9%\G
M("X@)'9A<FYA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7VAI9&1E;E9A<FEA8FQE<R!A<R`D=F%R*2![
M"B`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@
M)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"@H@("`@("`@("1R96YD
M97)E<BT^8F5G:6Y!8W1I=F4H)'1H:7,M/F=E=%1I=&QE*"DL("1T:&ES+3YG
M971%>'1R82@I*3L*("`@("`@("`D<F5N9&5R97(M/G)E;F1E<D9O<FU!8W1I
M=F4H)'1H:7,L("1V87)S*3L*("`@("`@("`D<F5N9&5R97(M/G-U8FUI="@D
M=&AI<RT^7W-U8FUI="P@)'1H:7,M/E]R97-E="D["B`@("`@("`@)')E;F1E
M<F5R+3YE;F0H*3L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"1F;V-U<RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R26YA8W1I=F4H)B1R96YD97)E
M<BP@)'9A<G,I"B`@("!["B`@("`@("`@)')E;F1E<F5R+3YB96=I;DEN86-T
M:79E*"1T:&ES+3YG9714:71L92@I+"`D=&AI<RT^9V5T17AT<F$H*2D["B`@
M("`@("`@)')E;F1E<F5R+3YR96YD97)&;W)M26YA8W1I=F4H)'1H:7,L("1V
M87)S*3L*("`@("`@("`D<F5N9&5R97(M/F5N9"@I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('!R97-E<G9E*"1V87)S*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7W5S949O<FU4;VME;BD@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?<')E<V5R
M=F5687)">5!O<W0H)U]?9F]R;51O:V5N7R<@+B`D=&AI<RT^7VYA;64L($AO
M<F1E7U1O:V5N.CIG96YE<F%T94ED*"1T:&ES+3Y?;F%M92DI.PH@("`@("`@
M('T*"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG971687)I86)L97,H
M*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V87(I('L*("`@
M("`@("`@("`@)'9A<FYA;64@/2`D=F%R+3YG971687).86UE*"D["@H@("`@
M("`@("`@("`O*B!3879E('9A;'5E(&]F(&EN9&EV:61U86P@8V]M<&]N96YT
M<RX@*B\*("`@("`@("`@("`@<W=I=&-H("@D=F%R+3YG9714>7!E3F%M92@I
M*2!["B`@("`@("`@("`@(&-A<V4@)W!A<W-W;W)D8V]N9FER;2<Z"B`@("`@
M("`@("`@(&-A<V4@)V5M86EL8V]N9FER;2<Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMO
M<FEG:6YA;%TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A
M<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G6V-O;F9I<FU=)RD["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUO;G1H>65A
M<B<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O<W0H
M)'9A<G,L("1V87)N86UE("X@)UMM;VYT:%TG*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G
M6WEE87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)VUO;G1H9&%Y>65A<B<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^
M<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMM;VYT:%TG
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D
M=F%R<RP@)'9A<FYA;64@+B`G6V1A>5TG*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G6WEE
M87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'1H:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S+"`D
M=F%R;F%M92D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M:&ED9&5N5F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@)'1H:7,M
M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S+"`D=F%R+3YG971687).86UE*"DI
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!U;G-E=%9A<G,H)B1V
M87)S*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG971687)I86)L
M97,H*2!A<R`D=F%R*2!["B`@("`@("`@("`@("1V87)S+3YR96UO=F4H)'9A
M<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$;V5S('1H92!A8W1I;VX@;V8@=F%L:61A=&EN9R!T:&4@9F]R;2P@
M8VAE8VMI;F<@:68@:70@<F5A;&QY(&AA<R!B965N"B`@("`@*B!S=6)M:71T
M960@8GD@8V%L;&EN9R!I<U-U8FUI='1E9"@I(&%N9"!I9B!T<G5E(&1O97,@
M86YY(&]N4W5B;6ET*"D*("`@("`J(&-A;&QS(&9O<B!V87(@='EP97,@:6X@
M=&AE(&9O<FTN(%1H92!?<W5B;6ET=&5D('9A<B!I<R!T:&5N(')E8VAE8VME
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?5F%R:6%B;&5S("1V87)S
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("`@("`@("1C86Y!=71O9FEL;"`@
M0V%N('1H92!F;W)M(&)E('9A;&ED('=I=&AO=70*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B96EN9R!S=6)M:71T960_
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!F
M;W)M(&ES('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!V86QI9&%T92@F
M)'9A<G,L("1C86Y!=71O1FEL;"`](&9A;'-E*0H@("`@>PH@("`@("`@("\J
M($=E="!S=6)M:71T960@<W1A='5S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M:7-3=6)M:71T960H*2!\?"`D8V%N075T;T9I;&PI('L*("`@("`@("`@("`@
M+RH@1F]R;2!W87,@<W5B;6ET=&5D(&]R(&-A;B!A=71O9FEL;#L@8VAE8VL@
M9F]R(&%N>2!V87)I86)L90H@("`@("`@("`@("`@*B!T>7!E<R<@;VY3=6)M
M:70H*2X@*B\*("`@("`@("`@("`@)'1H:7,M/F]N4W5B;6ET*"1V87)S*3L*
M"B`@("`@("`@("`@("\J(%)E8VAE8VL@<W5B;6ET=&5D('-T871U<RX@*B\*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-3=6)M:71T960H*2`F)B`A)&-A
M;D%U=&]&:6QL*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!&
M;W)M(&AA<R!N;W0@8F5E;B!S=6)M:71T960[(')E='5R;B!F86QS92X@*B\*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)&UE<W-A9V4@/2`G)SL*("`@("`@("`D=&AI<RT^7V%U=&]F:6QL960@/2!T
M<G5E.PH*("`@("`@("!I9B`H)'1H:7,M/E]U<V5&;W)M5&]K96XI('L*("`@
M("`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@(&EF("AI<W-E="@D
M8V]N9ELG=&]K96XG72DI('L*("`@("`@("`@("`@("`@("\J($EF('1H97)E
M(&ES(&$@8V]N9FEG=7)E9"!T;VME;B!S>7-T96TL('-E="!I="!U<"X@*B\*
M("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4;VME;CHZ
M<VEN9VQE=&]N*"1C;VYF6R=T;VME;B==6R=D<FEV97(G72P@2&]R9&4Z.F=E
M=$1R:79E<D-O;F9I9R@G=&]K96XG+"`D8V]N9ELG=&]K96XG75LG9')I=F5R
M)UTI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J
M($1E9F%U;'0@=&\@=&AE(&9I;&4@<WES=&5M(&EF(&YO(&-O;F9I9RX@*B\*
M("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4;VME;CHZ
M<VEN9VQE=&]N*"=F:6QE)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"$D=&]K96Y3;W5R8V4M/G9E<FEF>2@D=F%R<RT^9V5T*"=?7V9O<FU4
M;VME;E\G("X@)'1H:7,M/E]N86UE*2DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==(#T@7R@B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T5F%R:6%B;&5S
M*"D@87,@)'9A<BD@>PH@("`@("`@("`@("`D=&AI<RT^7V%U=&]F:6QL960@
M/2`D=F%R+3Y?875T;V9I;&QE9"`F)B`D=&AI<RT^7V%U=&]F:6QL960["B`@
M("`@("`@("`@(&EF("@A)'9A<BT^=F%L:61A=&4H)'9A<G,L("1M97-S86=E
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<G-;)'9A<BT^9V5T
M5F%R3F%M92@I72`]("1M97-S86=E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/E]A=71O9FEL;&5D*2!["B`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==*3L*("`@
M("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&ED9&5N5F%R:6%B
M;&5S(&%S("1V87(I('L*("`@("`@("`@("`@:68@*"$D=F%R+3YV86QI9&%T
M92@D=F%R<RP@)&UE<W-A9V4I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V5R<F]R<ULD=F%R+3YG971687).86UE*"E=(#T@)&UE<W-A9V4["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^:7-6
M86QI9"@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-L96%R5F%L:61A=&EO;B@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]E<G)O<G,@/2!A<G)A>2@I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$5R<F]R*"1V87(I"B`@("!["B`@("`@("`@
M:68@*&ES7V$H)'9A<BP@)TAO<F1E7T9O<FU?5F%R:6%B;&4G*2D@>PH@("`@
M("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]("1V87(["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V5R<F]R<ULD;F%M95TI(#\@
M)'1H:7,M/E]E<G)O<G-;)&YA;65=(#H@;G5L;#L*("`@('T*"B`@("!F=6YC
M=&EO;B!S971%<G)O<B@D=F%R+"`D;65S<V%G92D*("`@('L*("`@("`@("!I
M9B`H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L92<I*2!["B`@("`@
M("`@("`@("1N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1N86UE(#T@)'9A<CL*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]E<G)O<G-;)&YA;65=(#T@)&UE<W-A9V4["B`@("!]
M"@H@("`@9G5N8W1I;VX@8VQE87)%<G)O<B@D=F%R*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A*"1V87(L("=(;W)D95]&;W)M7U9A<FEA8FQE)RDI('L*("`@
M("`@("`@("`@)&YA;64@/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&YA;64@/2`D=F%R.PH@("`@("`@('T*
M("`@("`@("!U;G-E="@D=&AI<RT^7V5R<F]R<ULD;F%M95TI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&ES5F%L:60H*0H@("`@>PH@("`@("`@(')E='5R;B`H
M)'1H:7,M/E]A=71O9FEL;&5D('Q\(&-O=6YT*"1T:&ES+3Y?97)R;W)S*2`]
M/2`P*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>&5C=71E*"8D=F%R<RD*("`@
M('L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G5V%R;FEN9SH@2&]R9&5?
M1F]R;3HZ97AE8W5T92@I(&-A;&QE9"P@<VAO=6QD(&)E(&]V97)R:61D96XG
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($9E=&-H('1H92!F:65L9"!V86QU97,@;V8@=&AE
M('-U8FUI='1E9"!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!687)I86)L
M97,@)'9A<G,@(%1H92!687)I86)L97,@;V)J96-T+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1I;F9O("`@("`@07)R87D@=&\@8F4@9FEL;&5D('=I=&@@=&AE
M('-U8FUI='1E9"!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R
M<RP@)B1I;F9O*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5T26YF;T9R;VU6
M87)I86)L97,H)'1H:7,M/F=E=%9A<FEA8FQE<R@I+"`D=F%R<RP@)&EN9F\I
M.PH@("`@("`@("1T:&ES+3Y?9V5T26YF;T9R;VU687)I86)L97,H)'1H:7,M
M/E]H:61D96Y687)I86)L97,L("1V87)S+"`D:6YF;RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&971C:"!T:&4@9FEE;&0@=F%L=65S(&9R;VT@82!G:79E
M;B!A<G)A>2!O9B!V87)I86)L97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D=F%R:6%B;&5S
M("!!;B!A<G)A>2!O9B!(;W)D95]&;W)M7U9A<FEA8FQE(&]B:F5C=',@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9F5T8V@@9G)O;2X*
M("`@("`J($!P87)A;2!O8FIE8W0@)'9A<G,@("`@("`@5&AE(%9A<FEA8FQE
M<R!O8FIE8W0N"B`@("`@*B!`<&%R86T@87)R87D@("1I;F9O("`@("`@(%1H
M92!A<G)A>2!T;R!B92!F:6QL960@=VET:"!T:&4@<W5B;6ET=&5D"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I96QD('9A;'5E<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V=E=$EN9F]&<F]M5F%R:6%B;&5S*"1V87)I
M86)L97,L("8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@(&9O<F5A8V@@
M*"1V87)I86)L97,@87,@)'9A<BD@>PH@("`@("`@("`@("!I9B`H)'9A<BT^
M:7-!<G)A>59A;"@I*2!["B`@("`@("`@("`@("`@("`D=F%R+3YG971);F9O
M*"1V87)S+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=F%L=65S*2D@>PH@("`@("`@("`@("`@("`@("`@("1V87).86UE(#T@
M<W1R7W)E<&QA8V4H)UM=)RP@)R<L("1V87(M/F=E=%9A<DYA;64H*2D["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D:2`]/B`D
M=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I75LD=F%R
M3F%M95T@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@("`@("`@
M("`@(&EF("A(;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D=F%R+3YG9716
M87).86UE*"DL("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1I;F9O6R1B87-E72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)&)A<V5=(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'!O:6YT97(@/2`F)&EN
M9F];)&)A<V5=.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AC;W5N="@D
M:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`](&%R<F%Y
M7W-H:69T*"1K97ES*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D<&]I;G1E<ELD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R1K97E=(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E
M<B`]("8D<&]I;G1E<ELD:V5Y73L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T26YF;R@D=F%R<RP@)'!O:6YT
M97(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=F%R+3YG971);F9O*"1V87)S+"`D:6YF;ULD=F%R+3YG971687).
M86UE*"E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!H87-(96QP*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]H96QP.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5T97)M:6YE<R!I9B!T:&ES(&9O<FT@:&%S(&)E96X@<W5B;6ET=&5D
M(&]R(&YO="X@268@=&AE(&-L87-S"B`@("`@*B!V87(@7W-U8FUI='1E9"!I
M<R!N=6QL('1H96X@:70@=VEL;"!C:&5C:R!F;W(@=&AE('!R97-E;F-E(&]F
M"B`@("`@*B!T:&4@9F]R;6YA;64@:6X@=&AE(&9O<FT@=F%R:6%B;&5S+@H@
M("`@("H*("`@("`J($]T:&5R(&5V96YT<R!C86X@97AP;&EC:71L>2!S970@
M=&AE(%]S=6)M:71T960@=F%R:6%B;&4@=&\*("`@("`J(&9A;'-E('1O(&EN
M9&EC871E(&$@9F]R;2!S=6)M:70@8G5T(&YO="!F;W(@86-T=6%L('!O<W1I
M;F<@;V8*("`@("`J(&1A=&$@*&5G+B!O;D-H86YG92!E=F5N=',@=&\@=7!D
M871E('1H92!D:7-P;&%Y(&]F(&9I96QD<RDN"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]R(&9A;'-E(&EN9&EC871I;F<@:68@=&AE
M(&9O<FT@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@<W5B;6ET
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-U8FUI='1E9"@I"B`@("![
M"B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]S=6)M:71T960I*2!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W9A<G,M/F=E="@G9F]R;6YA;64G*2`]
M/2`D=&AI<RT^9V5T3F%M92@I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-U8FUI='1E9"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-U8FUI='1E9"`](&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]S=6)M
M:71T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@=&AE<F4@
M:7,@86YY=&AI;F<@=&\@9&\@;VX@=&AE('-U8FUI<W-I;VX@;V8@=&AE(&9O
M<FT@8GD*("`@("`J(&QO;W!I;F<@=&AR;W5G:"!E86-H('9A<FEA8FQE)W,@
M;VY3=6)M:70H*2!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R
M9&5?5F%R:6%B;&5S("1V87)S"B`@("`@*B\*("`@(&9U;F-T:6]N(&]N4W5B
M;6ET*"8D=F%R<RD*("`@('L*("`@("`@("`O*B!,;V]P('1H<F]U9V@@86QL
M('9A<G,@86YD(&-H96-K(&EF('1H97)E)W,@86YY=&AI;F<@=&\@9&\@;VX*
M("`@("`@("`@*B!S=6)M:70N("HO"B`@("`@("`@)'9A<FEA8FQE<R`]("1T
M:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B
M;&5S(&%S("1V87(I('L*("`@("`@("`@("`@)'9A<BT^='EP92T^;VY3=6)M
M:70H)'9A<BP@)'9A<G,I.PH@("`@("`@("`@("`O*B!)9B!C:&%N9V5S('1O
M('9A<B!B96EN9R!T<F%C:V5D(&1O;B=T(')E9VES=&5R('1H92!F;W)M(&%S
M"B`@("`@("`@("`@("`J('-U8FUI='1E9"!I9B!O;&0@=F%L=64@86YD(&YE
M=R!V86QU92!D:69F97(N("HO"B`@("`@("`@("`@(&EF("@D=F%R+3YG971/
M<'1I;VXH)W1R86-K8VAA;F=E)RDI('L*("`@("`@("`@("`@("`@("1V87)N
M86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("`@("`@("`@:68@
M*"%I<U]N=6QL*"1V87)S+3YG970H)V9O<FUN86UE)RDI("8F"B`@("`@("`@
M("`@("`@("`@("`@)'9A<G,M/F=E="@D=F%R;F%M92D@(3T@)'9A<G,M/F=E
M="@G7U]O;&1?)R`N("1V87)N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W5B;6ET=&5D(#T@9F%L<V4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%>'!L:6-I=&QY('-E=',@=&AE('-T871E(&]F('1H92!F;W)M('-U8FUI
M="X*("`@("`J"B`@("`@*B!!;B!E=F5N="!C86X@;W9E<G)I9&4@=&AE(&%U
M=&]M871I8R!D971E<FUI;F%T:6]N(&]F('1H92!S=6)M:70@<W1A=&4*("`@
M("`J(&EN('1H92!I<U-U8FUI='1E9"@I(&9U;F-T:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1S=&%T92`@5VAE=&AE<B!T;R!S970@=&AE
M('-T871E(&]F('1H92!F;W)M(&%S(&)E:6YG"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@('-U8FUI='1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T4W5B;6ET=&5D*"1S=&%T92`]('1R=64I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]S=6)M:71T960@/2`D<W1A=&4["B`@("!]"@I]"@HO*BH*("H@2&]R
M9&5?1F]R;5]4>7!E($-L87-S"B`J"B`J($!A=71H;W(@(%)O8F5R="!%+B!#
M;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`<&%C:V%G92!(
M;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U
M;F-T:6]N($AO<F1E7T9O<FU?5'EP92@I"B`@("!["B`@("!]"@H@("`@9G5N
M8W1I;VX@:6YI="@I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@;VY3=6)M
M:70H*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)&UE
M<W-A9V4@/2`G/'-T<F]N9SY%<G)O<CH\+W-T<F]N9SX@2&]R9&5?1F]R;5]4
M>7!E.CII<U9A;&ED*"D@8V%L;&5D("T@<VAO=6QD(&)E(&]V97)R:61D96X\
M8G(@+SXG.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC
M=&EO;B!G9714>7!E3F%M92@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]3=')I;F<N<&AP)SL*("`@("`@("!R971U<FX@<W1R7W)E<&QA
M8V4H)VAO<F1E7V9O<FU?='EP95\G+"`G)RP@4W1R:6YG.CIL;W=E<BAG971?
M8VQA<W,H)'1H:7,I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%L=65S
M*"D*("`@('L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@
M("`@("`D:6YF;R`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@('T*"GT*
M"F-L87-S($AO<F1E7T9O<FU?5'EP95]S<&%C97(@97AT96YD<R!(;W)D95]&
M;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R
M<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F
M:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("![
M"B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA
M;64G72`](%\H(E-P86-E<B(I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@
M("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?=V5A=&AE<F1O=&-O;2!E
M>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?<F5G97@["B`@
M("!V87(@)%]S:7IE.PH@("`@=F%R("1?;6%X;&5N9W1H.PH*("`@("\J*@H@
M("`@("H@5&AE(&EN:71I86QI<V%T:6]N(&9U;F-T:6]N(&9O<B!T:&4@=&5X
M="!V87)I86)L92!T>7!E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E9V5X("`@("`@($%N
M>2!V86QI9"!02%`@4$-212!P871T97)N('-Y;G1A>"!T:&%T"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!N965D<R!T;R!B92!M871C:&5D
M(&9O<B!T:&4@9FEE;&0@=&\@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G-I9&5R960@=F%L:60N($EF(&QE9G0@96UP='D@=F%L
M:61I='D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I;&P@
M8F4@8VAE8VME9"!O;FQY(&9O<B!R97%U:7)E9"!F:65L9',*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('=H971H97(@=&AE>2!A<F4@96UP
M='D@;W(@;F]T+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M268@=7-I;F<@=&AI<R!R96=E>"!T97-T(&ET(&ES(&%D=FES86)L90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@96YT97(@82!D97-C
M<FEP=&EO;B!F;W(@=&AI<R!F:65L9"!T;PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=V%R;B!T:&4@=7-E<B!W:&%T(&ES(&5X<&5C=&5D
M+"!A<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&=E
M;F5R871E9"!E<G)O<B!M97-S86=E(&ES('%U:71E(&=E;F5R:6,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%N9"!W:6QL(&YO="!G:79E
M(&%N>2!I;F1I8V%T:6]N('=H97)E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@<F5G97@@9F%I;&5D+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'-I>F4@("`@("`@5&AE('-I>F4@;V8@=&AE(&EN<'5T(&9I96QD
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QE;F=T:"`@5&AE(&UA>"!N
M=6UB97(@;V8@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI
M="@D<F5G97@@/2`G)RP@)'-I>F4@/2`T,"P@)&UA>&QE;F=T:"`](&YU;&PI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]R96=E>"`@("`@/2`D<F5G97@["B`@
M("`@("`@)'1H:7,M/E]S:7IE("`@("`@/2`D<VEZ93L*("`@("`@("`D=&AI
M<RT^7VUA>&QE;F=T:"`]("1M87AL96YG=&@["B`@("!]"@H@("`@9G5N8W1I
M;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*
M("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;6%X;&5N9W1H*2`F
M)B!3=')I;F<Z.FQE;F=T:"@D=F%L=64I(#X@)'1H:7,M/E]M87AL96YG=&@I
M('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI<RT^7VUA
M>&QE;F=T:"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(')E<75I<F5?;VYC92`G4V5R=FEC97,O5V5A=&AE<BYP:'`G
M.PH@("`@("`@("1W96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E871H97(Z
M.G-E<G9I8V4H)U=E871H97)$;W1#;VTG*3L*("`@("`@("`D=V5A=&AE<D1O
M=$-O;2T^<V5T06-C;W5N=$1A=&$H)SQ087)T;F5R240^)RP@)SQ,:6-E;G-E
M2V5Y/B<I.PH@("`@("`@("1S96%R8V@@/2`D=V5A=&AE<D1O=$-O;2T^<V5A
M<F-H3&]C871I;VXH)'9A;'5E*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1S
M96%R8V@I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z("(I("X@:6UP;&]D92@G+"`G+"`D<V5A
M<F-H*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS
M96EF("AI<U]A*"1S96%R8V@L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)&UE<W-A9V4@/2`D<V5A<F-H+3YG971-97-S86=E*"D["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<VEZ93L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971-87A,96YG=&@H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7VUA>&QE;F=T:#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A
M<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B5V5A=&AE<BYC
M;VTB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@
M("`@("`@("=R96=E>"<@("`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B4F5G
M97@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`]/B`G=&5X="<I+`H@("`@("`@("`@("`G<VEZ92<@("`@("`]/B!A<G)A
M>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@("`@("=M
M87AL96YG=&@G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B36%X:6UU;2!L96YG
M=&@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`]/B`G:6YT)RDL"B`@("`@("`@*3L*("`@("`@("!R971U<FX@)&%B;W5T
M.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VAE861E<B!E>'1E
M;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F
M)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I
M;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B
M;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@
M("1A8F]U=%LG;F%M92==(#T@7R@B2&5A9&5R(BD["B`@("`@("`@<F5T=7)N
M("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]D97-C
M<FEP=&EO;B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I
M;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*
M("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A
M>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B1&5S8W)I<'1I;VXB
M*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*+RHJ"B`J(%-I
M;7!L>2!R96YD97)S(&ET<R!R87<@=F%L=64@:6X@8F]T:"!A8W1I=F4@86YD
M(&EN86-T:79E(')E;F1E<FEN9RX*("HO"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]H=&UL(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO
M;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@
M("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y
M*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")(5$U,(BD["B`@("`@
M("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?
M5'EP95]N=6UB97(@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A
M<B`D7V9R86-T:6]N.PH*("`@(&9U;F-T:6]N(&EN:70H)&9R86-T:6]N(#T@
M;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7V9R86-T:6]N(#T@)&9R86-T
M:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R
M<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M
M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I("8F("@H<W1R:6YG*2AD
M;W5B;&4I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@("`@("`@("`@("1M97-S
M86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D=F%L
M=64I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@268@;6%T8VAE9"P@=&AE;B!T:&ES(&ES(&$@8V]R<F5C="!N
M=6UE<FEC('9A;'5E+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"1T:&ES
M+3Y?9V5T5F%L:61A=&EO;E!A='1E<FXH*2P@)'9A;'5E*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E
M(#T@7R@B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(I.PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T
M5F%L:61A=&EO;E!A='1E<FXH*0H@("`@>PH@("`@("`@('-T871I8R`D<&%T
M=&5R;B`]("<G.PH@("`@("`@(&EF("@A96UP='DH)'!A='1E<FXI*2!["B`@
M("`@("`@("`@(')E='5R;B`D<&%T=&5R;CL*("`@("`@("!]"@H@("`@("`@
M("\J($=E="!C=7)R96YT(&QO8V%L92!I;F9O<FUA=&EO;BX@*B\*("`@("`@
M("`D;&EN9F\@/2!.3%,Z.F=E=$QO8V%L94EN9F\H*3L*"B`@("`@("`@+RH@
M0G5I;&0@=&AE('!A='1E<FXN("HO"B`@("`@("`@)'!A='1E<FX@/2`G*"TI
M/R<["@H@("`@("`@("\J($]N;'D@8VAE8VL@=&AO=7-A;F1S('-E<&%R871O
M<G,@:68@;&]C86QE(&AA<R!A;GDN("HO"B`@("`@("`@:68@*"%E;7!T>2@D
M;&EN9F];)VUO;E]T:&]U<V%N9'-?<V5P)UTI*2!["B`@("`@("`@("`@("\J
M(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R96-T('1H;W5S86YD<R!S97!A<F%T
M;W)S("AI9B!A;GDI+B`J+PH@("`@("`@("`@("`D<&%T=&5R;B`N/2`G*"A<
M9"LI?"@H7&1[,"PS?3\I*%LG("X@)&QI;F9O6R=M;VY?=&AO=7-A;F1S7W-E
M<"==("X@)UU<9'LS?2DJ/RDI)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O*B!.;R!L;V-A;&4@=&AO=7-A;F1S('-E<&%R871O<BP@8VAE8VL@
M9F]R(&]N;'D@9&EG:71S+B`J+PH@("`@("`@("`@("`D<&%T=&5R;B`N/2`G
M*%QD*RDG.PH@("`@("`@('T*("`@("`@("`O*B!)9B!N;R!D96-I;6%L('!O
M:6YT('-P96-I9FEE9"!D969A=6QT('1O(&1O="X@*B\*("`@("`@("!I9B`H
M96UP='DH)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==*2D@>PH@("`@("`@
M("`@("`D;&EN9F];)VUO;E]D96-I;6%L7W!O:6YT)UT@/2`G+B<["B`@("`@
M("`@?0H@("`@("`@("\J(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R96-T(&1E
M8VEM86QS("AI9B!A;GDI+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M7V9R86-T:6]N*2D@>PH@("`@("`@("`@("`D9G)A8W1I;VX@/2`G*B<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9R86-T:6]N(#T@)WLP+"<@
M+B`D=&AI<RT^7V9R86-T:6]N("X@)WTG.PH@("`@("`@('T*("`@("`@("`D
M<&%T=&5R;B`N/2`G*%LG("X@)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==
M("X@)UTH7&0G("X@)&9R86-T:6]N("X@)RDI/R<["@H@("`@("`@("\J(%!U
M="!T;V=E=&AE<B!T:&4@=VAO;&4@<F5G97@@<&%T=&5R;BX@*B\*("`@("`@
M("`D<&%T=&5R;B`]("<O7B<@+B`D<&%T=&5R;B`N("<D+R<["@H@("`@("`@
M(')E='5R;B`D<&%T=&5R;CL*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O
M*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D=F%L=64@
M/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@)&QI
M;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O*"D["B`@("`@("`@)'9A;'5E(#T@
M<W1R7W)E<&QA8V4H)&QI;F9O6R=M;VY?=&AO=7-A;F1S7W-E<"==+"`G)RP@
M)'9A;'5E*3L*("`@("`@("`D:6YF;R`]('-T<E]R97!L86-E*"1L:6YF;ULG
M;6]N7V1E8VEM86Q?<&]I;G0G72P@)RXG+"`D=F%L=64I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U
M="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*").=6UB
M97(B*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@
M2&]R9&5?1F]R;5]4>7!E7VEN="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92![
M"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L
M("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E
M9"@I("8F(&5M<'1Y*"1V86QU92D@)B8@*"AS=')I;F<I*&EN="DD=F%L=64@
M(3T]("1V86QU92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P
M<F5G7VUA=&-H*"<O7ELP+3E=*R0O)RP@)'9A;'5E*2D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@
M7R@B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(I.PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@
M("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B26YT96=E<B(I.PH@("`@("`@
M(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y
M<&5?;V-T86P@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T
M:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I
M"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T
M>2@D=F%L=64I("8F("@H<W1R:6YG*2AI;G0I)'9A;'5E("$]/2`D=F%L=64I
M*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R
M97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M871C:"@G
M+UY;,"TW72LD+R<L("1V86QU92DI('L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(BD["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN
M9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O
M=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@
M)&%B;W5T6R=N86UE)UT@/2!?*")/8W1A;"(I.PH@("`@("`@(')E='5R;B`D
M86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?:6YT3&ES
M="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-6
M86QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E<75I<F5D
M*"DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES
M(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P<F5G7VUA=&-H
M*"<O7ELP+3D@+%TK)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<R(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D
M86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B
M26YT96=E<B!L:7-T(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*
M"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]T97AT(&5X=&5N9',@2&]R9&5?
M1F]R;5]4>7!E('L*"B`@("!V87(@)%]R96=E>#L*("`@('9A<B`D7W-I>F4[
M"B`@("!V87(@)%]M87AL96YG=&@["@H@("`@+RHJ"B`@("`@*B!4:&4@:6YI
M=&EA;&ES871I;VX@9G5N8W1I;VX@9F]R('1H92!T97AT('9A<FEA8FQE('1Y
M<&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<F5G97@@("`@("`@06YY('9A;&ED(%!(4"!0
M0U)%('!A='1E<FX@<WEN=&%X('1H870*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YE961S('1O(&)E(&UA=&-H960@9F]R('1H92!F:65L
M9"!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N
M<VED97)E9"!V86QI9"X@268@;&5F="!E;7!T>2!V86QI9&ET>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!C:&5C:V5D(&]N
M;'D@9F]R(')E<75I<F5D(&9I96QD<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=VAE=&AE<B!T:&5Y(&%R92!E;7!T>2!O<B!N;W0N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!U<VEN9R!T:&ES
M(')E9V5X('1E<W0@:70@:7,@861V:7-A8FQE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T;R!E;G1E<B!A(&1E<V-R:7!T:6]N(&9O<B!T
M:&ES(&9I96QD('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!W87)N('1H92!U<V5R('=H870@:7,@97AP96-T960L(&%S('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N97)A=&5D(&5R<F]R
M(&UE<W-A9V4@:7,@<75I=&4@9V5N97)I8PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@86YD('=I;&P@;F]T(&=I=F4@86YY(&EN9&EC871I
M;VX@=VAE<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!R96=E>"!F86EL960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VEZ92`@
M("`@("!4:&4@<VEZ92!O9B!T:&4@:6YP=70@9FEE;&0N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6%X;&5N9W1H("!4:&4@;6%X(&YU;6)E<B!O9B!C:&%R
M86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET*"1R96=E>"`]("<G
M+"`D<VEZ92`](#0P+"`D;6%X;&5N9W1H(#T@;G5L;"D*("`@('L*("`@("`@
M("`D=&AI<RT^7W)E9V5X("`@("`]("1R96=E>#L*("`@("`@("`D=&AI<RT^
M7W-I>F4@("`@("`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?;6%X;&5N9W1H
M(#T@)&UA>&QE;F=T:#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D
M=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@
M("1V86QI9"`]('1R=64["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]M
M87AL96YG=&@I("8F(%-T<FEN9SHZ;&5N9W1H*"1V86QU92D@/B`D=&AI<RT^
M7VUA>&QE;F=T:"D@>PH@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@
M("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A;'5E(&ES(&]V97(@
M=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI<RT^7VUA>&QE;F=T
M:"D["B`@("`@("`@?2!E;'-E:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E
M;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@("`@("`D=F%L:60@/2!S
M=')L96XH=')I;2@D=F%L=64I*2`^(#`["@H@("`@("`@("`@("!I9B`H(21V
M86QI9"D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I
M96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E:68@*"%E;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@("`@("`D
M=F%L:60@/2!P<F5G7VUA=&-H*"1T:&ES+3Y?<F5G97@L("1V86QU92D["@H@
M("`@("`@("`@("!I9B`H(21V86QI9"D@>PH@("`@("`@("`@("`@("`@)&UE
M<W-A9V4@/2!?*")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'9A
M;&ED.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T36%X3&5N9W1H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M
M87AL96YG=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A
M8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I
M"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O
M=71;)VYA;64G72`](%\H(E1E>'0B*3L*("`@("`@("`D86)O=71;)W!A<F%M
M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R96=E>"<@("`@(#T^(&%R<F%Y
M*"=L86)E;"<@/3X@7R@B4F5G97@B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`G
M<VEZ92<@("`@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT
M)RDL"B`@("`@("`@("`@("=M87AL96YG=&@G(#T^(&%R<F%Y*"=L86)E;"<@
M/3X@7R@B36%X:6UU;2!L96YG=&@B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@*3L*("`@
M("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R
M;5]4>7!E7W-T<FEN9VQI<W0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?=&5X
M="!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`]
M(%\H(E-T<FEN9R!L:7-T(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`]
M(&%R<F%Y*`H@("`@("`@("`@("`G<F5G97@G("`@("`]/B!A<G)A>2@G;&%B
M96PG(#T^(%\H(E)E9V5X(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@("`@("`@("`@)W-I>F4G
M("`@("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@
M("`@("`@("`@("`G;6%X;&5N9W1H)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H
M(DUA>&EM=6T@;&5N9W1H(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("D["B`@("`@("`@
M<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]C96QL<&AO;F4@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U
M;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A
M9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*"B`@("`@("`@:68@
M*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=F%L:60@/2!S
M=')L96XH=')I;2@D=F%L=64I*2`^(#`["B`@("`@("`@("`@(&EF("@A)'9A
M;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE
M;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=F%L:60@/2!P<F5G7VUA=&-H*"<O7EPK/UM<
M9"@I7"U<+R!=*B0O)RP@)'9A;'5E*3L*("`@("`@("`@("`@:68@*"$D=F%L
M:60I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N(BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*
M("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D-E;&QP:&]N92(I.PH@("`@
M("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M
M7U1Y<&5?:7!A9&1R97-S(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E7W1E>'0@
M>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E
M+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*"B`@
M("`@("`@:68@*'-T<FQE;BAT<FEM*"1V86QU92DI(#X@,"D@>PH@("`@("`@
M("`@("`D:7`@/2!E>'!L;V1E*"<N)RP@)'9A;'5E*3L*("`@("`@("`@("`@
M)'9A;&ED(#T@*&-O=6YT*"1I<"D@/3T@-"D["B`@("`@("`@("`@(&EF("@D
M=F%L:60I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I<"!A<R`D<&%R
M="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5M97)I8R@D<&%R
M="D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/B`R-34@?'P*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/"`P*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A
M)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(BD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@
M("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@("`@("`D;65S<V%G92`]
M(%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G;F%M92<@
M/3X@7R@B25`@061D<F5S<R(I*3L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]L;VYG5&5X="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP95]T97AT
M('L*"B`@("!V87(@)%]R;W=S.PH@("`@=F%R("1?8V]L<SL*("`@('9A<B`D
M7VAE;'!E<B`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@:6YI="@D<F]W<R`]
M(#@L("1C;VQS(#T@.#`L("1H96QP97(@/2`G)RD*("`@('L*("`@("`@("`D
M=&AI<RT^7W)O=W,@/2`D<F]W<SL*("`@("`@("`D=&AI<RT^7V-O;',@/2`D
M8V]L<SL*("`@("`@("`D=&AI<RT^7VAE;'!E<B`]("1H96QP97(["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T4F]W<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F]W<SL*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VQS*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VQS.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&AA<TAE;'!E<B@D;W!T:6]N(#T@)R<I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1O<'1I;VXI*2!["B`@("`@("`@("`@("\J($YO(&]P
M=&EO;B!S<&5C:69I960L(&-H96-K(&EF(&%N>2!H96QP97)S(&AA=F4@8F5E
M;@H@("`@("`@("`@("`@*B!A8W1I=F%T960N("HO"B`@("`@("`@("`@(')E
M='5R;B`A96UP='DH)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T@96QS96EF
M("AE;7!T>2@D=&AI<RT^7VAE;'!E<BDI('L*("`@("`@("`@("`@+RH@3F\@
M:&5L<&5R<R!A8W1I=F%T960@870@86QL+"!R971U<FX@9F%L<V4N("HO"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O*B!#:&5C:R!I9B!G:79E;B!H96QP97(@:&%S(&)E96X@86-T
M:79A=&5D+B`J+PH@("`@("`@("`@("!R971U<FX@:6Y?87)R87DH)&]P=&EO
M;BP@)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A
M<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B3&]N9R!T97AT
M(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@
M("`@("`G<F]W<R<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O
M9B!R;W=S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E
M)R`@/3X@)VEN="<I+`H@("`@("`@("`@("`G8V]L<R<@("`]/B!A<G)A>2@G
M;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C;VQU;6YS(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@
M("`@("`G:&5L<&5R)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DAE;'!E<B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=B
M;V]L96%N)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@
M("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8V]U;G1E9%1E>'0@97AT
M96YD<R!(;W)D95]&;W)M7U1Y<&5?;&]N9U1E>'0@>PH*("`@('9A<B`D7V-H
M87)S.PH*("`@(&9U;F-T:6]N(&EN:70H)')O=W,@/2!N=6QL+"`D8V]L<R`]
M(&YU;&PL("1C:&%R<R`](#$P,#`I"B`@("!["B`@("`@("`@<&%R96YT.CII
M;FET*"1R;W=S+"`D8V]L<RD["B`@("`@("`@)'1H:7,M/E]C:&%R<R`]("1C
M:&%R<SL*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A
M<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@("1V86QI9"`]
M('1R=64["@H@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"DI('L*("`@
M("`@("`@("`@)&QE;F=T:"`](%-T<FEN9SHZ;&5N9W1H*'1R:6TH)'9A;'5E
M*2D["@H@("`@("`@("`@("!I9B`H)&QE;F=T:"`\/2`P*2!["B`@("`@("`@
M("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@("`@("1M97-S
M86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@
M("`@?2!E;'-E:68@*"1L96YG=&@@/B`D=&AI<RT^7V-H87)S*2!["B`@("`@
M("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@("`@("1M
M97-S86=E(#T@<W!R:6YT9BA?*")4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB*2P@4W1R:6YG
M.CIL96YG=&@H=')I;2@D=F%L=64I*2P@)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L:60["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T0VAA<G,H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-H87)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@
M("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")#;W5N=&5D('1E>'0B*3L*("`@
M("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R
M;W=S)R`@/3X@87)R87DH)VQA8F5L)R`]/B!?*").=6UB97(@;V8@<F]W<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN
M="<I+`H@("`@("`@("`@("`G8V]L<R<@(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B3G5M8F5R(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@)V-H87)S
M)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C:&%R86-T97)S
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G
M:6YT)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]
M"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?861D<F5S<R!E>'1E;F1S($AO
M<F1E7T9O<FU?5'EP95]L;VYG5&5X="!["@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@
M("`@("`D86)O=71;)VYA;64G72`](%\H(D%D9')E<W,B*3L*("`@("`@("`D
M86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R;W=S)R`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!R;W=S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@
M("`@("`@("`@)V-O;',G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B3G5M8F5R
M(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E)R`@/3X@)VEN="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@
M?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V9I;&4@97AT96YD<R!(;W)D
M95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D
M=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V
M87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=7!L;V%D960@/2!"
M<F]W<V5R.CIW87-&:6QE57!L;V%D960H)'9A<BT^9V5T5F%R3F%M92@I*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)'5P;&]A9&5D+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1U<&QO861E9"T^9V5T
M365S<V%G92@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF
M;RD*("`@('L*("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*
M("`@("`@("`D=7!L;V%D960@/2!"<F]W<V5R.CIW87-&:6QE57!L;V%D960H
M)&YA;64I.PH@("`@("`@(&EF("@D=7!L;V%D960@/3T]('1R=64I('L*("`@
M("`@("`@("`@)&EN9F];)VYA;64G72`]("1?1DE,15-;)&YA;65=6R=N86UE
M)UT["B`@("`@("`@("`@("1I;F9O6R=T>7!E)UT@/2`D7T9)3$536R1N86UE
M75LG='EP92==.PH@("`@("`@("`@("`D:6YF;ULG=&UP7VYA;64G72`]("1?
M1DE,15-;)&YA;65=6R=T;7!?;F%M92==.PH@("`@("`@("`@("`D:6YF;ULG
M9FEL92==(#T@)%]&24Q%4ULD;F%M95U;)W1M<%]N86UE)UT["B`@("`@("`@
M("`@("1I;F9O6R=E<G)O<B==(#T@)%]&24Q%4ULD;F%M95U;)V5R<F]R)UT[
M"B`@("`@("`@("`@("1I;F9O6R=S:7IE)UT@/2`D7T9)3$536R1N86UE75LG
M<VEZ92==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VYA;64G(#T^
M(%\H(D9I;&4@=7!L;V%D(BDI.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R
M;5]4>7!E7VEM86=E(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("`O
M*BH*("`@("`J($AA<R!A(&9I;&4@8F5E;B!U<&QO861E9"!O;B!T:&ES(&9O
M<FT@<W5B;6ET/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]U<&QO861E9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!3
M:&]W('1H92!U<&QO860@8G5T=&]N/PH@("`@("H*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7W5P;&]A9"`]('1R=64["@H@
M("`@+RHJ"B`@("`@*B!3:&]W('1H92!O<'1I;VX@=&\@=7!L;V%D(&%L<V\@
M;W)I9VEN86P@;F]N+6UO9&EF:65D(&EM86=E/PH@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7VME97!O<FEG/2!F
M86QS93L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!T:&4@<')E
M=FEO=7-L>2!U<&QO861E9"!I;6%G92!I;F9O+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UG(#T@87)R87DH*3L*"B`@
M("!F=6YC=&EO;B!I;FET*"1S:&]W7W5P;&]A9"`]('1R=64L("1S:&]W7VME
M97!O<FEG(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]S:&]W7W5P
M;&]A9"`@(#T@)'-H;W=?=7!L;V%D.PH@("`@("`@("1T:&ES+3Y?<VAO=U]K
M965P;W)I9R`]("1S:&]W7VME97!O<FEG.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&]N4W5B;6ET*"8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@+RH@1V5T
M('1H92!U<&QO860N("HO"B`@("`@("`@)'1H:7,M/E]G9715<&QO860H)'9A
M<G,L("1V87(I.PH*("`@("`@("`O*B!)9B!T:&ES('=A<R!D;VYE('1H<F]U
M9V@@=&AE('5P;&]A9"!B=71T;VX@;W9E<G)I9&4@=&AE('-U8FUI='1E9`H@
M("`@("`@("`J('9A;'5E(&]F('1H92!F;W)M+B`J+PH@("`@("`@(&EF("@D
M=F%R<RT^9V5T*"=?9&]?)R`N("1V87(M/F=E=%9A<DYA;64H*2DI('L*("`@
M("`@("`@("`@)'9A<BT^9F]R;2T^<V5T4W5B;6ET=&5D*&9A;'-E*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D9FEE;&0@
M/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["@H@("`@("`@("\J
M($=E="!T:&4@=7!L;V%D+B`J+PH@("`@("`@("1T:&ES+3Y?9V5T57!L;V%D
M*"1V87)S+"`D=F%R*3L*"B`@("`@("`@+RH@5&AE('5P;&]A9"!G96YE<F%T
M960@82!014%2($5R<F]R+B`J+PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M=7!L;V%D960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@+RH@3F]T
M(')E<75I<F5D(&%N9"!N;R!I;6%G92!U<&QO860@871T96UP=&5D+B`J+PH@
M("`@("`@("`@("!I9B`H(21V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D
M9FEE;&1;)VEM9R==*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M/E]U<&QO
M861E9"T^9V5T0V]D92@I(#T](#0I('L*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H*"1T:&ES
M+3Y?=7!L;V%D960M/F=E=$-O9&4H*2`]/2!54$Q/041?15)27TY/7T9)3$4I
M("8F"B`@("`@("`@("`@("`@("!E;7!T>2@D9FEE;&1;)VEM9R==*2D@>PH@
M("`@("`@("`@("`@("`@+RH@3F]T:&EN9R!U<&QO861E9"!A;F0@;F\@;VQD
M97(@=7!L;V%D+B`J+PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1F:65L
M9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@("`O*B!.;W1H:6YG('5P;&]A
M9&5D(&)U="!O;&1E<B!U<&QO860@<')E<V5N="X@*B\*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@+RH@4V]M92!O=&AE<B!E<G)O<B!M97-S86=E+B`J+PH@("`@
M("`@("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7W5P;&]A9&5D+3YG971-
M97-S86=E*"D["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O
M*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@=7!L;V%D+B`J+PH@("`@("`@
M("1T:&ES+3Y?9V5T57!L;V%D*"1V87)S+"`D=F%R*3L*"B`@("`@("`@+RH@
M1V5T(&EM86=E('!A<F%M<R!S=&]R960@:6X@=&AE(&AI9&1E;B!F:65L9"X@
M*B\*("`@("`@("`D=F%L=64@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@
M("`@("`@)&EN9F\@/2`D=&AI<RT^7VEM9SL*("`@("`@("!I9B`H96UP='DH
M)&EN9F];)V9I;&4G72DI('L*("`@("`@("`@("`@=6YS970H)&EN9F];)V9I
M;&4G72D["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@
M:68@*"1T:&ES+3Y?<VAO=U]K965P;W)I9RD@>PH@("`@("`@("`@("`D:6YF
M;ULG:V5E<%]O<FEG)UT@/2`A96UP='DH)'9A;'5E6R=K965P7V]R:6<G72D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE('5P;&]A9&5D('9A;'5E
M("AE:71H97(@=')U92!O<B!014%27T5R<F]R*2X@*B\*("`@("`@("`D:6YF
M;ULG=7!L;V%D960G72`]("8D=&AI<RT^7W5P;&]A9&5D.PH*("`@("`@("`O
M*B!)9B!A(&UO9&EF:65D(&9I;&4@97AI<W1S(&UO=F4@:70@;W9E<B!T:&4@
M;W)I9VEN86PN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=U]K965P;W)I
M9R`F)B`D:6YF;ULG:V5E<%]O<FEG)UTI('L*("`@("`@("`@("`@+RH@4F5Q
M=65S=&5D('1H92!S879I;F<@;V8@;W)I9VEN86P@9FEL92!A;'-O+B`J+PH@
M("`@("`@("`@("`D:6YF;ULG;W)I9U]F:6QE)UT@/2!(;W)D93HZ9V5T5&5M
M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*("`@("`@("`@("`@)&EN
M9F];)V9I;&4G72`]($AO<F1E.CIG971496UP1&ER*"D@+B`G+VUO9%\G("X@
M)&EN9F];)V9I;&4G73L*("`@("`@("`@("`@+RH@0VAE8VL@:68@82!M;V1I
M9FEE9"!F:6QE(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("`@("`@:68@
M*"%F:6QE7V5X:7-T<R@D:6YF;ULG9FEL92==*2D@>PH@("`@("`@("`@("`@
M("`@)&EN9F];)V9I;&4G72`]("1I;F9O6R=O<FEG7V9I;&4G73L*("`@("`@
M("`@("`@("`@('5N<V5T*"1I;F9O6R=O<FEG7V9I;&4G72D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!3879I;F<@
M;V8@;W)I9VEN86P@;F]T(')E<75I<F5D+B`J+PH@("`@("`@("`@("`D;6]D
M7V9I;&4@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R]M;V1?)R`N("1I;F9O
M6R=F:6QE)UT["B`@("`@("`@("`@("1I;F9O6R=F:6QE)UT@/2!(;W)D93HZ
M9V5T5&5M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*"B`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D;6]D7V9I;&4I*2!["B`@("`@("`@("`@
M("`@("`O*B!5;FQI;FL@9FER<W0@*&AA<R!T;R!B92!D;VYE(&]N(%=I;F1O
M=W,@;6%C:&EN97,_*2`J+PH@("`@("`@("`@("`@("`@=6YL:6YK*"1I;F9O
M6R=F:6QE)UTI.PH@("`@("`@("`@("`@("`@<F5N86UE*"1M;V1?9FEL92P@
M)&EN9F];)V9I;&4G72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!U<&QO860@86YD('-E=',@=7`@
M=&AE('5P;&]A9"!D871A(&%R<F%Y+B!%:71H97(*("`@("`J(&9E=&-H97,@
M86X@=7!L;V%D(&1O;F4@=VET:"!T:&ES('-U8FUI="!O<B!R971R:65S('-T
M;W)E9`H@("`@("H@=7!L;V%D(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G9715<&QO860H)B1V87)S+"`F)'9A<BD*("`@('L*("`@("`@("`O*B!$
M;VXG="!B;W1H97(@=VET:"!T:&ES(&9U;F-T:6]N(&EF(&%L<F5A9'D@8V%L
M;&5D(&%N9"!S970*("`@("`@("`@*B!U<"!V87)S+B`J+PH@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]I;6<I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@9FEL92!H87,@
M8F5E;B!U<&QO861E9"X@*B\*("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E
M=%9A<DYA;64H*3L*("`@("`@("`D=&AI<RT^7W5P;&]A9&5D(#T@0G)O=W-E
M<CHZ=V%S1FEL955P;&]A9&5D*"1V87)N86UE("X@)UMN97==)RD["@H@("`@
M("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D(#T]/2!T<G5E*2!["B`@("`@("`@
M("`@("\J($$@9FEL92!H87,@8F5E;B!U<&QO861E9"!O;B!T:&ES('-U8FUI
M="X@4V%V92!T;R!T96UP(&1I<B!F;W(*("`@("`@("`@("`@("H@<')E=FEE
M=R!W;W)K+B`J+PH@("`@("`@("`@("`D=&AI<RT^7VEM9ULG='EP92==(#T@
M)'1H:7,M/F=E=%5P;&]A9&5D1FEL951Y<&4H)'9A<FYA;64@+B`G6VYE=UTG
M*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@;W1H97(@<&%R=',@;V8@=&AE
M('5P;&]A9"X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!
M<G)A>2YP:'`G.PH@("`@("`@("`@("!(;W)D95]!<G)A>3HZ9V5T07)R87E0
M87)T<R@D=F%R;F%M92`N("=;;F5W72<L("1B87-E+"`D:V5Y<RD["@H@("`@
M("`@("`@("`O*B!'970@=&AE('1E;7!O<F%R>2!F:6QE(&YA;64N("HO"B`@
M("`@("`@("`@("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A>2@D8F%S
M92P@)W1M<%]N86UE)RDL("1K97ES*3L*("`@("`@("`@("`@)'1H:7,M/E]I
M;6=;)V9I;&4G72`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?1DE,15,L
M("1K97ES7W!A=&@I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!A8W1U86P@
M9FEL92!N86UE+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H/2!A<G)A>5]M
M97)G92AA<G)A>2@D8F%S92P@)VYA;64G*2P@)&ME>7,I.PH@("`@("`@("`@
M("`D=&AI<RT^7VEM9ULG;F%M92==(#T@2&]R9&5?07)R87DZ.F=E=$5L96UE
M;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["@H@("`@("`@("`@("`O*B!'970@
M=&AE(&9I;&4@<VEZ92X@*B\*("`@("`@("`@("`@)&ME>7-?<&%T:#T@87)R
M87E?;65R9V4H87)R87DH)&)A<V4L("=S:7IE)RDL("1K97ES*3L*("`@("`@
M("`@("`@)'1H:7,M/E]I;6=;)W-I>F4G72`]($AO<F1E7T%R<F%Y.CIG971%
M;&5M96YT*"1?1DE,15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@("`@+RH@
M1V5T(&%N>2!E>&ES=&EN9R!V86QU97,@9F]R('1H92!I;6%G92!U<&QO860@
M9FEE;&0N("HO"B`@("`@("`@("`@("1U<&QO860@/2`D=F%R<RT^9V5T*"1V
M87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@("`@("1U<&QO861;)VEM9R==
M(#T@0'5N<V5R:6%L:7IE*"1U<&QO861;)VEM9R==*3L*"B`@("`@("`@("`@
M("\J($=E="!T:&4@=&5M<"!F:6QE(&EF(&%L<F5A9'D@;VYE('5P;&]A9&5D
M+"!O=&AE<G=I<V4@8W)E871E(&$*("`@("`@("`@("`@("H@;F5W('1E;7!O
M<F%R>2!F:6QE+B`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1U<&QO861;
M)VEM9R==6R=F:6QE)UTI*2!["B`@("`@("`@("`@("`@("`D=&UP7V9I;&4@
M/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R\G("X@)'5P;&]A9%LG:6UG)UU;
M)V9I;&4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1T;7!?9FEL92`]($AO<F1E.CIG971496UP1FEL92@G2&]R9&4G+"!F86QS
M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($UO=F4@=&AE(&)R
M;W=S97(@8W)E871E9"!T96UP(&9I;&4@=&\@=&AE(&YE=R!T96UP(&9I;&4N
M("HO"B`@("`@("`@("`@(&UO=F5?=7!L;V%D961?9FEL92@D=&AI<RT^7VEM
M9ULG9FEL92==+"`D=&UP7V9I;&4I.PH@("`@("`@("`@("`D=&AI<RT^7VEM
M9ULG9FEL92==(#T@8F%S96YA;64H)'1M<%]F:6QE*3L*"B`@("`@("`@("`@
M("\J(%-T;W)E('1H92!U<&QO861E9"!I;6%G92!F:6QE(&1A=&$@=&\@=&AE
M(&AI9&1E;B!F:65L9"X@*B\*("`@("`@("`@("`@)'5P;&]A9%LG:6UG)UT@
M/2!S97)I86QI>F4H)'1H:7,M/E]I;6<I.PH@("`@("`@("`@("`D=F%R<RT^
M<V5T*"1V87(M/F=E=%9A<DYA;64H*2P@)'5P;&]A9"D["B`@("`@("`@?2!E
M;'-E:68@*"1T:&ES+3Y?=7!L;V%D960I('L*("`@("`@("`@("`@+RH@1FEL
M92!H87,@;F]T(&)E96X@=7!L;V%D960N("HO"B`@("`@("`@("`@("1U<&QO
M860@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D+3YG971#;V1E*"D@/3T@-"`F)B`A
M96UP='DH)'5P;&]A9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEM9R`]($!U;G-E<FEA;&EZ92@D=7!L;V%D6R=I;6<G72D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T57!L
M;V%D961&:6QE5'EP92@D9FEE;&0I"B`@("!["B`@("`@("`@+RH@1V5T(&%N
M>2!I;F1E>"!O;B!T:&4@9FEE;&0@;F%M92X@*B\*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@)&EN9&5X(#T@2&]R
M9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)&9I96QD+"`D8F%S92P@)&ME>7,I
M.PH*("`@("`@("!I9B`H)&EN9&5X*2!["B`@("`@("`@("`@("\J($EN9&5X
M('!R97-E;G0L(&9E=&-H('1H92!M:6UE('1Y<&4@=F%R('1O(&-H96-K+B`J
M+PH@("`@("`@("`@("`D:V5Y<U]P871H(#T@87)R87E?;65R9V4H87)R87DH
M)&)A<V4L("=T>7!E)RDL("1K97ES*3L*("`@("`@("`@("`@)'1Y<&4@/2!(
M;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P871H*3L*
M("`@("`@("`@("`@)&ME>7-?<&%T:#T@87)R87E?;65R9V4H87)R87DH)&)A
M<V4L("=T;7!?;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("1T;7!?;F%M
M92`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?1DE,15,L("1K97ES7W!A
M=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO(&EN9&5X
M+"!S:6UP;&4@<V5T('5P(&]F('9A<G,@=&\@8VAE8VLN("HO"B`@("`@("`@
M("`@("1T>7!E(#T@)%]&24Q%4ULD9FEE;&1=6R=T>7!E)UT["B`@("`@("`@
M("`@("1T;7!?;F%M92`]("1?1DE,15-;)&9I96QD75LG=&UP7VYA;64G73L*
M("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D='EP92D@?'P@*"1T>7!E
M(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2D@>PH@("`@("`@("`@
M("`O*B!4>7!E('=A<VXG="!S970@;VX@=7!L;V%D+"!T<GD@86YA;&ES:6YG
M('1H92!U<&QO860N("HO"B`@("`@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUA9VEC+G!H<"<[
M"B`@("`@("`@("`@(&EF("@A*"1T>7!E(#T@34E-15]-86=I8SHZ86YA;'EZ
M949I;&4H)'1M<%]N86UE+"!I<W-E="@D8V]N9ELG;6EM92==6R=M86=I8U]D
M8B==*2`_("1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UT@.B!N=6QL*2DI('L*
M("`@("`@("`@("`@("`@(&EF("@D:6YD97@I('L*("`@("`@("`@("`@("`@
M("`@("`O*B!'970@=&AE(&YA;64@=F%L=64N("HO"B`@("`@("`@("`@("`@
M("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B87-E+"`G
M;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!(
M;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P871H*3L*
M"B`@("`@("`@("`@("`@("`@("`@+RH@5V]R:R!O=70@=&AE('1Y<&4@9G)O
M;2!T:&4@9FEL92!N86UE+B`J+PH@("`@("`@("`@("`@("`@("`@("1T>7!E
M(#T@34E-15]-86=I8SHZ9FEL96YA;654;TU)344H)&YA;64I.PH*("`@("`@
M("`@("`@("`@("`@("`O*B!3970@=&AE('1Y<&4N("HO"B`@("`@("`@("`@
M("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B87-E
M+"`G='EP92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@2&]R9&5?
M07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"P@)'1Y<&4I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`O*B!7;W)K(&]U="!T:&4@='EP92!F<F]M('1H92!F:6QE(&YA;64N("HO
M"B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC.CIF:6QE
M;F%M951O34E-12@D7T9)3$536R1F:65L9%U;)VYA;64G72D["@H@("`@("`@
M("`@("`@("`@("`@("\J(%-E="!T:&4@='EP92X@*B\*("`@("`@("`@("`@
M("`@("`@("`D7T9)3$536R1F:65L9%U;)W1Y<&4G72`]($U)345?36%G:6,Z
M.F9I;&5N86UE5&]-24U%*"1?1DE,15-;)&9I96QD75LG;F%M92==*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A9',@
M86YY(&5X:7-T:6YG(&EM86=E(&1A=&$@:6YT;R!T:&4@:6UA9V4@9FEE;&0N
M(%)E<75I<F5S('1H870@=&AE"B`@("`@*B!A<G)A>2`D:6UA9V4@<&%S<V5D
M('1O(&ET(&-O;G1A:6YS('1H92!S=')U8W1U<F4Z"B`@("`@*B`@("1I;6%G
M95LG;&]A9"==6R=F:6QE)UT@+2!T:&4@9FEL96YA;64@;V8@=&AE(&EM86=E
M.PH@("`@("H@("`D:6UA9V5;)VQO860G75LG9&%T82==("T@=&AE(')A=R!I
M;6%G92!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D:6UA9V4@(%1H92!I;6%G92!A<G)A
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861);6%G941A=&$H)B1I;6%G
M92D*("`@('L*("`@("`@("`O*B!.;R!E>&ES=&EN9R!I;6%G92!D871A('1O
M(&QO860N("HO"B`@("`@("`@:68@*"%I<W-E="@D:6UA9V5;)VQO860G72DI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@
M4V%V92!T:&4@9&%T82!T;R!T:&4@=&5M<"!D:7(N("HO"B`@("`@("`@)'1M
M<%]F:6QE(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*2`N("<O)R`N("1I;6%G95LG
M;&]A9"==6R=F:6QE)UT["B`@("`@("`@:68@*"1F9"`](&9O<&5N*"1T;7!?
M9FEL92P@)W<G*2D@>PH@("`@("`@("`@("!F=W)I=&4H)&9D+"`D:6UA9V5;
M)VQO860G75LG9&%T82==*3L*("`@("`@("`@("`@9F-L;W-E*"1F9"D["B`@
M("`@("`@?0H*("`@("`@("`D:6UA9V5;)VEM9R==(#T@<V5R:6%L:7IE*&%R
M<F%Y*"=F:6QE)R`]/B`D:6UA9V5;)VQO860G75LG9FEL92==*2D["B`@("`@
M("`@=6YS970H)&EM86=E6R=L;V%D)UTI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y
M*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*"));6%G92!U<&QO860B
M*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@
M("`@("=S:&]W7W5P;&]A9"<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-H
M;W<@=7!L;V%D(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G='EP92<@(#T^("=B;V]L96%N)RDL"B`@("`@("`@("`@("=S:&]W
M7VME97!O<FEG)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86PB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2D["B`@("`@("`@
M<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]B;V]L96%N(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC
M=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E
M*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@
M("`@("1I;F9O(#T@4W1R:6YG.CIL;W=E<B@D=F%R<RT^9V5T*"1V87(M/F=E
M=%9A<DYA;64H*2DI(#T]("=O;B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*
M("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E1R=64@;W(@9F%L<V4B*3L*
M("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?
M1F]R;5]4>7!E7VQI;FL@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M(&9U;F-T:6]N(&EN:70H)'9A;'5E<RD*("`@('L*("`@("`@("`D=&AI<RT^
M=F%L=65S(#T@)'9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED
M*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@
M("`@)VYA;64G(#T^(%\H(DQI;FLB*2P*("`@("`@("`@("`@)W!A<F%M<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`G=7)L)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(DQI;FL@55),(BDL"B`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RDL"B`@("`@("`@
M("`@("`@("`G=&5X="<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M)VQA8F5L)R`]/B!?*"),:6YK('1E>'0B*2P*("`@("`@("`@("`@("`@("`@
M("`G='EP92<@/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("=T87)G970G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=L86)E;"<@/3X@7R@B
M3&EN:R!T87)G970B*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@
M)W1E>'0G*2P*("`@("`@("`@("`@("`@("=O;F-L:6-K)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(D]N8VQI8VL@979E
M;G0B*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*2P*
M("`@("`@("`@("`@("`@("=T:71L92<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)VQA8F5L)R`]/B!?*"),:6YK('1I=&QE(&%T=')I8G5T92(I
M+`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I+`H@("`@
M("`@("`@("`@("`@)V%C8V5S<VME>2<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)VQA8F5L)R`]/B!?*"),:6YK(&%C8V5S<R!K97DB*2P*("`@
M("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*2DI.PH@("`@?0H*
M?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V5M86EL(&5X=&5N9',@2&]R9&5?
M1F]R;5]4>7!E('L*"B`@("!V87(@)%]A;&QO=U]M=6QT:2`](&9A;'-E.PH@
M("`@=F%R("1?<W1R:7!?9&]M86EN(#T@9F%L<V4["B`@("!V87(@)%]L:6YK
M7V-O;7!O<V4@/2!F86QS93L*("`@('9A<B`D7VQI;FM?;F%M92`](&YU;&P[
M"@H@("`@9G5N8W1I;VX@:6YI="@D86QL;W=?;75L=&D@/2!F86QS92P@)'-T
M<FEP7V1O;6%I;B`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`D;&EN:U]C
M;VUP;W-E(#T@9F%L<V4L("1L:6YK7VYA;64@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?86QL;W=?;75L=&D@/2`D86QL;W=?;75L=&D["B`@("`@
M("`@)'1H:7,M/E]S=')I<%]D;VUA:6X@/2`D<W1R:7!?9&]M86EN.PH@("`@
M("`@("1T:&ES+3Y?;&EN:U]C;VUP;W-E(#T@)&QI;FM?8V]M<&]S93L*("`@
M("`@("`D=&AI<RT^7VQI;FM?;F%M92`]("1L:6YK7VYA;64["B`@("!]"@H@
M("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D
M;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I
M("8F(&5M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?
M*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=F%L=64I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]21D,X,C(N<&AP)SL*
M("`@("`@("`@("`@)'!A<G-E<B`]("9N97<@36%I;%]21D,X,C(H*3L*("`@
M("`@("`@("`@)'!A<G-E9%]E;6%I;"`]("1P87)S97(M/G!A<G-E061D<F5S
M<TQI<W0H)'9A;'5E+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I9B`H
M:7-?82@D<&%R<V5D7V5M86EL+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`D;65S<V%G92`]("1P87)S961?96UA:6PM/F=E=$UE<W-A9V4H
M*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H*"$D=&AI<RT^7V%L;&]W7VUU;'1I*2`F)B!C
M;W5N="@D<&%R<V5D7V5M86EL*2`^(#$I('L*("`@("`@("`@("`@("`@("1M
M97-S86=E(#T@7R@B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D<&%R<V5D7V5M86EL6S!=+3YM86EL
M8F]X*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(BD["B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D[
M"B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")%;6%I;"(I.PH@("`@("`@
M("1A8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)V%L;&]W
M7VUU;'1I)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@)W-T<FEP
M7V1O;6%I;B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@
M)VQI;FM?8V]M<&]S92<@/3X@87)R87DH)VQA8F5L)R`]/B!?*"),:6YK('1H
M92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P
M;&%Y:6YG(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`]/B`G8F]O;&5A;B<I+`H@("`@("`@("`@("`G;&EN:U]N86UE
M)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*2D["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]M871R:7@@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M('9A<B`D7V-O;',["B`@("!V87(@)%]R;W=S.PH@("`@=F%R("1?;6%T<FEX
M.PH@("`@=F%R("1?;F5W7VEN<'5T.PH*("`@("\J*@H@("`@("H@26YI=&EA
M;&EZ97,@=&AE('9A<FEA8FQE+@H@("`@("H*("`@("`J($!E>&%M<&QE"B`@
M("`@*B!I;FET*&%R<F%Y*"=#;VQU;6X@02<L("=#;VQU;6X@0B<I+`H@("`@
M("H@("`@("!A<G)A>2@Q(#T^("=2;W<@3VYE)RP@,B`]/B`G4F]W(#(G+"`S
M(#T^("=2;W<@,R<I+`H@("`@("H@("`@("!A<G)A>2AA<G)A>2AT<G5E+"!T
M<G5E+"!F86QS92DL"B`@("`@*B`@("`@("`@("`@(&%R<F%Y*'1R=64L(&9A
M;'-E+"!T<G5E*2P*("`@("`J("`@("`@("`@("`@87)R87DH9F%S;&4L('1R
M=64L(&9A;'-E*2DL"B`@("`@*B`@("`@(&%R<F%Y*"=2;W<@-"<L("=2;W<@
M-2<I*3L*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-O;',@("`@("`@
M("`@("`@("!!(&QI<W0@;V8@8V]L=6UN(&AE861E<G,N"B`@("`@*B!`<&%R
M86T@87)R87D@)')O=W,@("`@("`@("`@("`@("!!(&AA<V@@=VET:"!R;W<@
M241S(&%S('1H92!K97ES(&%N9"!R;W<*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&QA8F5L<R!A<R!T:&4@=F%L=65S+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1M871R:7@@("`@("`@("`@("`@02!T=V\@9&EM
M96YS:6]N86P@:&%S:"!W:71H('1H92!F:65L9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=F%L=65S+@H@("`@("H@0'!A<F%M
M(&)O;VQE86Y\87)R87D@)&YE=U]I;G!U="`@268@=')U92P@82!F<F5E('1E
M>'0@9FEE;&0@=&\@861D(&$@;F5W"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R;W<@:7,@9&ES<&QA>65D(&]N('1H92!T;W`L
M(&$@<V5L96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B;W@@:68@=&AI<R!P87)A;65T97(@:7,@82!V86QU92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:6YI="@D8V]L<RP@)')O=W,@/2!A<G)A>2@I+"`D
M;6%T<FEX(#T@87)R87DH*2P@)&YE=U]I;G!U="`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?8V]L<R`@("`@("`]("1C;VQS.PH@("`@("`@("1T
M:&ES+3Y?<F]W<R`@("`@("`]("1R;W=S.PH@("`@("`@("1T:&ES+3Y?;6%T
M<FEX("`@("`]("1M871R:7@["B`@("`@("`@)'1H:7,M/E]N97=?:6YP=70@
M(#T@)&YE=U]I;G!U=#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D
M=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;',H*2`@
M("`@>R!R971U<FX@)'1H:7,M/E]C;VQS.R!]"B`@("!F=6YC=&EO;B!G9712
M;W=S*"D@("`@('L@<F5T=7)N("1T:&ES+3Y?<F]W<SL@?0H@("`@9G5N8W1I
M;VX@9V5T36%T<FEX*"D@("![(')E='5R;B`D=&AI<RT^7VUA=')I>#L@?0H@
M("`@9G5N8W1I;VX@9V5T3F5W26YP=70H*2![(')E='5R;B`D=&AI<RT^7VYE
M=U]I;G!U=#L@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A
M<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R<RT^9V5T
M*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@:68@*"%E;7!T>2@D=F%L
M=65S6R=N)UU;)W(G72D@)B8@:7-S970H)'9A;'5E<ULG;B==6R=V)UTI*2![
M"B`@("`@("`@("`@("1N97=?<F]W(#T@)'9A;'5E<ULG;B==6R=R)UT["B`@
M("`@("`@("`@("1V86QU97-;)W(G75LD;F5W7W)O=UT@/2`D=F%L=65S6R=N
M)UU;)W8G73L*("`@("`@("`@("`@=6YS970H)'9A;'5E<ULG;B==*3L*("`@
M("`@("!]"@H@("`@("`@("1I;F9O(#T@*&ES<V5T*"1V86QU97-;)W(G72D@
M/R`D=F%L=65S6R=R)UT@.B!A<G)A>2@I*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@
M("`@("`D86)O=71;)VYA;64G72`](%\H(D9I96QD(&UA=')I>"(I.PH@("`@
M("`@("1A8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)V-O
M;',G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B0V]L=6UN('1I=&QE<R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG
M;&ES="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA
M<W,@2&]R9&5?1F]R;5]4>7!E7V5M86EL0V]N9FER;2!E>'1E;F1S($AO<F1E
M7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A
M<BT^:7-297%U:7)E9"@I("8F(&5M<'1Y*"1V86QU95LG;W)I9VEN86PG72DI
M('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E
M<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'9A;'5E6R=O<FEG:6YA;"==("$]("1V86QU95LG
M8V]N9FER;2==*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B16UA:6P@
M861D<F5S<V5S(&UU<W0@;6%T8V@N(BD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S97(@/2`F
M;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@("`@("1P87)S961?96UA:6P@
M/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1V86QU95LG;W)I9VEN86PG
M72P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*&-O=6YT*"1P87)S
M961?96UA:6PI(#X@,2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?
M*")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(BD["B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1P87)S961?96UA:6Q;,%TM/FUA:6QB;W@I*2!["B`@
M("`@("`@("`@("`@("`D;65S<V%G92`](%\H(EEO=2!D:60@;F]T(&5N=&5R
M(&$@=F%L:60@96UA:6P@861D<F5S<RXB*3L*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF
M;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U
M="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D
M86)O=71;)VYA;64G72`](%\H(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(BD[
M"B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E
M7T9O<FU?5'EP95]P87-S=V]R9"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92![
M"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L
M("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L:60@/2!T<G5E.PH*("`@
M("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@("`@("1V
M86QI9"`]('-T<FQE;BAT<FEM*"1V86QU92DI(#X@,#L*"B`@("`@("`@("`@
M(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@
M87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E!A<W-W;W)D
M(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]P87-S=V]R9$-O;F9I<FT@97AT96YD<R!(;W)D95]&
M;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R
M<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M
M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=65;)V]R:6=I;F%L)UTI*2![
M"B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1V86QU95LG;W)I9VEN86PG72`A/2`D=F%L=65;)V-O
M;F9I<FTG72D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E!A<W-W;W)D
M<R!M=7-T(&UA=&-H+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@
M("`@("`D=F%L=64@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D[
M"B`@("`@("`@)&EN9F\@/2`D=F%L=65;)V]R:6=I;F%L)UT["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B
M;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(BD["B`@("`@("`@<F5T=7)N("1A
M8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]E;G5M(&5X
M=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]V86QU97,["B`@
M("!V87(@)%]P<F]M<'0["@H@("`@9G5N8W1I;VX@:6YI="@D=F%L=65S+"`D
M<')O;7!T(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W9A;'5E<R`]
M("1V86QU97,["@H@("`@("`@(&EF("@D<')O;7!T(#T]/2!T<G5E*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<')O;7!T(#T@7R@B+2T@<V5L96-T("TM(BD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P<F]M<'0@
M/2`D<')O;7!T.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A
M;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@
M("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@)'9A;'5E(#T]("<G
M("8F("%I<W-E="@D=&AI<RT^7W9A;'5E<ULD=F%L=65=*2D@>PH@("`@("`@
M("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!I<W-E="@D=&AI
M<RT^7W9A;'5E<ULD=F%L=65=*2!\?`H@("`@("`@("`@("`H)'1H:7,M/E]P
M<F]M<'0@)B8@96UP='DH)'9A;'5E*2DI('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(DEN=F%L
M:60@9&%T82!S=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%!R;VUP="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')O;7!T
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE
M;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@
M("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE
M)UT@/2!?*")$<F]P(&1O=VX@;&ES="(I.PH@("`@("`@("1A8F]U=%LG<&%R
M86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")686QU97,@=&\@<V5L96-T(&9R;VTB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES
M="<I+`H@("`@("`@("`@("`G<')O;7!T)R`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(E!R;VUP="!T97AT(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)W1E>'0G*2D["B`@("`@("`@<F5T=7)N("1A8F]U
M=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]M;&5N=6T@97AT
M96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W9A;'5E<SL*("`@
M('9A<B`D7W!R;VUP=',["@H@("`@9G5N8W1I;VX@:6YI="@F)'9A;'5E<RP@
M)'!R;VUP=',@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%L=65S
M(#T@)B1V86QU97,["@H@("`@("`@(&EF("@D<')O;7!T<R`]/3T@=')U92D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!R;VUP=',@/2!A<G)A>2A?*"(M+2!S
M96QE8W0@+2TB*2P@7R@B+2T@<V5L96-T("TM(BDI.PH@("`@("`@('T@96QS
M96EF("@A:7-?87)R87DH)'!R;VUP=',I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<')O;7!T<R`](&%R<F%Y*"1P<F]M<'1S+"`D<')O;7!T<RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P<F]M<'1S(#T@)'!R
M;VUP=',["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&]N4W5B;6ET
M*"8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2`D=F%R
M+3YG971687).86UE*"D["B`@("`@("`@)'9A;'5E(#T@)'9A<G,M/F=E="@D
M=F%R;F%M92D["@H@("`@("`@(&EF("@D=F%L=65;)S$G72`A/2`D=F%L=65;
M)V]L9"==*2!["B`@("`@("`@("`@("1V87(M/F9O<FTM/G-E=%-U8FUI='1E
M9"AF86QS92D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L
M:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B`H96UP='DH)'9A;'5E
M6R<Q)UTI('Q\(&5M<'1Y*"1V86QU95LG,B==*2DI('L*("`@("`@("`@("`@
M)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6-O=6YT*"1T:&ES+3Y?=F%L=65S*2!\?"!I<W-E="@D=&AI<RT^7W9A;'5E
M<ULD=F%L=65;)S$G75TI('Q\"B`@("`@("`@("`@("@A96UP='DH)'1H:7,M
M/E]P<F]M<'1S*2`F)B!E;7!T>2@D=F%L=65;)S$G72DI*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@
M/2!?*"));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(I.PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971686QU97,H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;'5E<SL*("`@('T*"B`@("!F
M=6YC=&EO;B!G9710<F]M<'1S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]P<F]M<'1S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V
M87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1I;F9O(#T@)'9A
M<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@(')E='5R;B`D
M:6YF;ULG,B==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@
M86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H
M*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B
M;W5T6R=N86UE)UT@/2!?*")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B
M*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@
M("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S('1O
M('-E;&5C="!F<F]M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W!R;VUP
M="<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")0<F]M<'0@=&5X="(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI
M.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D
M95]&;W)M7U1Y<&5?;75L=&EE;G5M(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E
M7V5N=6T@>PH*("`@('9A<B`D<VEZ92`](#4["@H@("`@9G5N8W1I;VX@:6YI
M="@D=F%L=65S+"`D<VEZ92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I
M<U]N=6QL*"1S:7IE*2D@>PH@("`@("`@("`@("`D=&AI<RT^<VEZ92`]("AI
M;G0I)'-I>F4["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.FEN:70H)'9A
M;'5E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H:7-?
M87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@
M87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-686QI
M9"@D=F%R+"`D=F%R<RP@)'9A;"P@)&UE<W-A9V4I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@)B8@*"AS=')I;F<I*&EN="DD
M=F%L=64@(3T]("1V86QU92DI('L*("`@("`@("`@("`@:68@*"1V87(M/FES
M4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!I<W-E="@D
M=&AI<RT^7W9A;'5E<ULD=F%L=65=*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B26YV86QI
M9"!D871A('-U8FUI='1E9"XB*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`]
M(%\H(DUU;'1I<&QE('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U=%LG<&%R
M86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@("`@
M("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDI
M.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D
M95]&;W)M7U1Y<&5?<F%D:6\@97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?96YU
M;2!["@H@("`@+RH@16YT:7)E;'D@:6UP;&5M96YT960@8GD@2&]R9&5?1F]R
M;5]4>7!E7V5N=6T[(&IU<W0@82!D:69F97)E;G0*("`@("`J('9I97<N("HO
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@
M)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H
M(E)A9&EO('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U=%LG<&%R86US)UT@
M/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH)VQA8F5L
M)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I*3L*("`@("`@("!R971U<FX@
M)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W-E="!E
M>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?=F%L=65S.PH@
M("`@=F%R("1?8VAE8VM!;&P@/2!F86QS93L*"B`@("!F=6YC=&EO;B!I;FET
M*"8D=F%L=65S+"`D8VAE8VM!;&P@/2!F86QS92D*("`@('L*("`@("`@("`D
M=&AI<RT^7W9A;'5E<R`]("1V86QU97,["B`@("`@("`@)'1H:7,M/E]C:&5C
M:T%L;"`]("1C:&5C:T%L;#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED
M*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@
M("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!C;W5N="@D
M=F%L=64I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:71E;2D@>PH@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=F%L=65S6R1I=&5M72DI('L*
M("`@("`@("`@("`@("`@("1E<G)O<B`]('1R=64["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(6ES<V5T*"1E<G)O<BDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(DEN=F%L:60@9&%T82!S
M=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN
M9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O
M=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@
M)&%B;W5T6R=N86UE)UT@/2!?*")3970B*3L*("`@("`@("`D86)O=71;)W!A
M<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y
M*"=L86)E;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2D["B`@("`@("`@
M<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]D871E(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]F
M;W)M870["@H@("`@9G5N8W1I;VX@:6YI="@D9F]R;6%T(#T@)R5A("5D("5"
M)RD*("`@('L*("`@("`@("`D=&AI<RT^7V9O<FUA="`]("1F;W)M870["B`@
M("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L
M=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L:60@/2!T<G5E.PH*
M("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@("`@
M("1V86QI9"`]('-T<FQE;BAT<FEM*"1V86QU92DI(#X@,#L*"B`@("`@("`@
M("`@(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]
M('-P<FEN=&8H7R@B)7,@:7,@<F5Q=6ER960B*2P@)'9A<BT^9V5T2'5M86Y.
M86UE*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G971!9V\H)'1I;65S=&%M<"D*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4@)T1A=&4O0V%L8RYP:'`G.PH@("`@("`@("1D
M:69F9&%Y<R`]($1A=&5?0V%L8SHZ9&%T941I9F8H9&%T92@G:B<L("1T:6UE
M<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9&%T92@G;B<L("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9&%T92@G62<L("1T:6UE<W1A;7`I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T92@G
M:B<I+"!D871E*"=N)RDL(&1A=&4H)UDG*2D["@H@("`@("`@("\J($%N(&5R
M<F]R(&]C8W5R960N("HO"B`@("`@("`@:68@*"1D:69F9&%Y<R`]/2`M,2D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D86=O
M(#T@)&1I9F9D87ES("H@1&%T95]#86QC.CIC;VUP87)E1&%T97,H9&%T92@G
M:B<L("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!D871E*"=N)RP@)'1I;65S=&%M<"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&1A=&4H)UDG+"`D=&EM97-T86UP*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T92@G:B<I
M+"!D871E*"=N)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&1A=&4H)UDG*2D["B`@("`@("`@:68@*"1A
M9V\@/"`M,2D@>PH@("`@("`@("`@("!R971U<FX@<W!R:6YT9BA?*"(@*"5S
M(&1A>7,@86=O*2(I+"`D9&EF9F1A>7,I.PH@("`@("`@('T@96QS96EF("@D
M86=O(#T]("TQ*2!["B`@("`@("`@("`@(')E='5R;B!?*"(@*'EE<W1E<F1A
M>2DB*3L*("`@("`@("!](&5L<V5I9B`H)&%G;R`]/2`P*2!["B`@("`@("`@
M("`@(')E='5R;B!?*"(@*'1O9&%Y*2(I.PH@("`@("`@('T@96QS96EF("@D
M86=O(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N(%\H(B`H=&]M;W)R;W<I
M(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('-P<FEN
M=&8H7R@B("AI;B`E<R!D87ES*2(I+"`D9&EF9F1A>7,I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!G971&;W)M871T9614:6UE*"1T:6UE<W1A
M;7`L("1F;W)M870@/2!N=6QL+"`D<VAO=V%G;R`]('1R=64I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1F;W)M870I*2!["B`@("`@("`@("`@("1F;W)M
M870@/2`D=&AI<RT^7V9O<FUA=#L*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D=&EM97-T86UP*2D@>PH@("`@("`@("`@("!R971U<FX@<W1R9G1I
M;64H)&9O<FUA="P@)'1I;65S=&%M<"D@+B`H)'-H;W=A9V\@/R!(;W)D95]&
M;W)M7U1Y<&5?9&%T93HZ9V5T06=O*"1T:6UE<W1A;7`I(#H@)R<I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L
M9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")$871E(BDI.PH@("`@
M?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W1I;64@97AT96YD<R!(;W)D
M95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D
M=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V
M87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I("8F("@H<W1R:6YG
M*2AD;W5B;&4I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M
M<'1Y*"1V86QU92D@?'P@<')E9U]M871C:"@G+UY;,"TR73];,"TY73I;,"TU
M75LP+3E=)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(I.PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VYA;64G
M(#T^(%\H(E1I;64B*2D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y
M<&5?:&]U<DUI;G5T95-E8V]N9"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92![
M"@H@("`@=F%R("1?<VAO=U]S96-O;F1S.PH*("`@(&9U;F-T:6]N(&EN:70H
M)'-H;W=?<V5C;VYD<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<VAO=U]S96-O;F1S(#T@)'-H;W=?<V5C;VYD<SL*("`@('T*"B`@("!F=6YC
M=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E
M*0H@("`@>PH@("`@("`@("1T:6UE(#T@)'9A<G,M/F=E="@D=F%R+3YG9716
M87).86UE*"DI.PH@("`@("`@(&EF("@A)'1H:7,M/E]S:&]W7W-E8V]N9',@
M)B8@(6ES<V5T*"1T:6UE6R=S96-O;F0G72DI('L*("`@("`@("`@("`@)'1I
M;65;)W-E8V]N9"==(#T@,#L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H
M:7,M/F5M<'1Y5&EM94%R<F%Y*"1T:6UE*2`F)B`A)'1H:7,M/F-H96-K=&EM
M92@D=&EM95LG:&]U<B==+"`D=&EM95LG;6EN=71E)UTL("1T:6UE6R=S96-O
M;F0G72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")0;&5A<V4@96YT
M97(@82!V86QI9"!T:6UE+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YE;7!T>51I;65!<G)A>2@D=&EM
M92D@)B8@)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@("`@("1M97-S
M86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VMT:6UE*"1H;W5R+"`D;6EN
M=71E+"`D<V5C;VYD*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&AO=7(I
M('Q\("1H;W5R(#T]("<G('Q\("@D:&]U<B`\(#`@?'P@)&AO=7(@/B`R,RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES<V5T*"1M:6YU=&4I('Q\("1M:6YU=&4@/3T@)R<@?'P@*"1M
M:6YU=&4@/"`P('Q\("1M:6YU=&4@/B`V,"DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1S96-O
M;F0I('Q\("1S96-O;F0@/3T]("<G('Q\("@D<V5C;VYD(#P@,"!\?"`D<V5C
M;VYD(#X@-C`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!T:6UE('-U<'!L:65D(&%S(&$@2&]R9&5?1&%T92!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&EM95]I;B`@
M1&%T92!I;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R=&5D(&)Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&;W)M(&%N
M9"!(;W)D95]$871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A;7`@65E9
M64U-1$1(2$U-4U,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!53DE8(&5P;V-H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&4@(%1H
M92!T:6UE(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&EM94]B
M*"1T:6UE7VEN*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M1&%T92YP:'`G.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1I;65?:6XI*2![
M"B`@("`@("`@("`@(&EF("@A)'1H:7,M/F5M<'1Y5&EM94%R<F%Y*"1T:6UE
M7VEN*2D@>PH@("`@("`@("`@("`@("`@)'1I;65?:6X@/2!S<')I;G1F*"<Q
M.3<P+3`Q+3`Q("4P,F0Z)3`R9#HE,#)D)RP@)'1I;65?:6Y;)VAO=7(G72P@
M)'1I;65?:6Y;)VUI;G5T92==+"`D=&EM95]I;ELG<V5C;VYD)UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@;F5W($AO<F1E
M7T1A=&4H)'1I;65?:6XI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!T:6UE('-U<'!L:65D('-P;&ET('5P(&EN=&\@86X@87)R87DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&EM95]I;B`@5&EM92!I;B!O
M;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R=&5D(&)Y"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&;W)M(&%N9"!(;W)D95]$
M871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A;7`@65E964U-1$1(2$U-
M4U,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!53DE8(&5P
M;V-H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!W:71H
M('1H<F5E(&5L96UE;G1S("T@:&]U<BP@;6EN=71E(&%N9"!S96-O;F1S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714:6UE4&%R=',H)'1I;65?:6XI"B`@
M("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:6UE7VEN*2D@>PH@("`@("`@
M("`@("`O*B!4:&ES(&ES('!R;V)A8FQY(&$@9F%I;&5D(&ES5F%L:60@:6YP
M=70@<V\@:G5S="!R971U<FX@=&AE"B`@("`@("`@("`@("`J('!A<G1S(&%S
M('1H97D@87)E+B`J+PH@("`@("`@("`@("!R971U<FX@)'1I;65?:6X["B`@
M("`@("`@?2!E;'-E:68@*&5M<'1Y*"1T:6UE7VEN*2D@>PH@("`@("`@("`@
M("`O*B!4:&ES(&ES(&IU<W0@86X@96UP='D@9FEE;&0@<V\@<F5T=7)N(&5M
M<'1Y('!A<G1S+B`J+PH@("`@("`@("`@("!R971U<FX@87)R87DH)VAO=7(G
M(#T^("<G+"`G;6EN=71E)R`]/B`G)RP@)W-E8V]N9"<@/3X@)R<I.PH@("`@
M("`@('T*("`@("`@("`D=&EM92`]("1T:&ES+3YG9714:6UE3V(H)'1I;65?
M:6XI.PH@("`@("`@(')E='5R;B!A<G)A>2@G:&]U<B<@/3X@)'1I;64M/FAO
M=7(L"B`@("`@("`@("`@("`@("`@("`@("=M:6YU=&4G(#T^("1T:6UE+3YM
M:6XL"B`@("`@("`@("`@("`@("`@("`@("=S96-O;F0G(#T^("1T:6UE+3YS
M96,I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5M<'1Y5&EM94%R<F%Y*"1T:6UE
M*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-?87)R87DH)'1I;64I("8F(&5M
M<'1Y*"1T:6UE6R=H;W5R)UTI("8F(&5M<'1Y*"1T:6UE6R=M:6YU=&4G72D@
M)B8@96UP='DH)'1I;65;)W-E8V]N9"==*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=N86UE)R`]/B!?*")4:6UE('-E;&5C=&EO;B(I*3L*("`@('T*"GT*"F-L
M87-S($AO<F1E7T9O<FU?5'EP95]M;VYT:%EE87(@97AT96YD<R!(;W)D95]&
M;W)M7U1Y<&4@>PH*("`@('9A<B`D7W-T87)T7WEE87(["B`@("!V87(@)%]E
M;F1?>65A<CL*"B`@("!F=6YC=&EO;B!I;FET*"1S=&%R=%]Y96%R(#T@;G5L
M;"P@)&5N9%]Y96%R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H96UP='DH
M)'-T87)T7WEE87(I*2!["B`@("`@("`@("`@("1S=&%R=%]Y96%R(#T@,3DR
M,#L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1E;F1?>65A<BDI('L*
M("`@("`@("`@("`@)&5N9%]Y96%R(#T@9&%T92@G62<I.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]S=&%R=%]Y96%R(#T@)'-T87)T7WEE87(["B`@
M("`@("`@)'1H:7,M/E]E;F1?>65A<B`]("1E;F1?>65A<CL*("`@('T*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@A)'9A<BT^:7-297%U:7)E9"@I
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"$D=F%R<RT^9V5T*"1T:&ES+3YG971-;VYT:%9A<B@D=F%R*2D@
M?'P*("`@("`@("`@("`@(21V87)S+3YG970H)'1H:7,M/F=E=%EE87)687(H
M)'9A<BDI*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB*3L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T36]N=&A687(H)'9A<BD*("`@('L*("`@("`@
M("!R971U<FX@)'9A<BT^9V5T5F%R3F%M92@I("X@)UMM;VYT:%TG.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=%EE87)687(H)'9A<BD*("`@('L*("`@("`@
M("!R971U<FX@)'9A<BT^9V5T5F%R3F%M92@I("X@)UMY96%R72<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")-;VYT:"!A;F0@>65A<B(I+`H@
M("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@("=S=&%R=%]Y96%R)R`]/B!A<G)A>2@G;&%B
M96PG(#T^(%\H(E-T87)T('EE87(B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=S=')I;F=L
M:7-T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`G96YD7WEE87(G("`@
M/3X@87)R87DH)VQA8F5L)R`]/B!?*")%;F0@>65A<B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@
M/3X@)W-T<FEN9VQI<W0G*2DI.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R
M;5]4>7!E7VUO;G1H1&%Y665A<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92![
M"@H@("`@=F%R("1?<W1A<G1?>65A<CL*("`@('9A<B`D7V5N9%]Y96%R.PH@
M("`@=F%R("1?<&EC:V5R.PH@("`@=F%R("1?9F]R;6%T7VEN(#T@;G5L;#L*
M("`@('9A<B`D7V9O<FUA=%]O=70@/2`G)7@G.PH*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!D871E('-U<'!L:65D(&%S(&$@2&]R9&5?1&%T92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T7WEE87(@
M(%1H92!F:7)S="!A=F%I;&%B;&4@>65A<B!F;W(@:6YP=70N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D96YD7WEE87(@("`@5&AE(&QA<W0@879A:6QA8FQE
M('EE87(@9F]R(&EN<'5T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!I8VME
M<B`@("`@($1O('=E('-H;W<@=&AE($1(5$U,(&-A;&5N9&%R/PH@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&9O<FUA=%]I;B`@(%1H92!F;W)M870@=&\@=7-E
M('=H96X@<V5N9&EN9R!T:&4@9&%T90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<B!S=&]R86=E+B!$969A=6QT<R!T;R!5;FEX(&5P
M;V-H+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%-I;6EL
M87(@=&\@=&AE('-T<F9T:6UE*"D@9G5N8W1I;VXN"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9F]R;6%T7V]U="`@5&AE(&9O<FUA="!T;R!U<V4@=VAE;B!D
M:7-P;&%Y:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&1A=&4N(%-I;6EL87(@=&\@=&AE('-T<F9T:6UE*"D@9G5N8W1I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H)'-T87)T7WEE87(@/2`G)RP@
M)&5N9%]Y96%R(#T@)R<L("1P:6-K97(@/2!T<G5E+`H@("`@("`@("`@("`@
M("`@("`D9F]R;6%T7VEN(#T@;G5L;"P@)&9O<FUA=%]O=70@/2`G)7@G*0H@
M("`@>PH@("`@("`@(&EF("AE;7!T>2@D<W1A<G1?>65A<BDI('L*("`@("`@
M("`@("`@)'-T87)T7WEE87(@/2!D871E*"=9)RD["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D96YD7WEE87(I*2!["B`@("`@("`@("`@("1E;F1?
M>65A<B`](&1A=&4H)UDG*2`K(#$P.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]S=&%R=%]Y96%R(#T@)'-T87)T7WEE87(["B`@("`@("`@)'1H:7,M
M/E]E;F1?>65A<B`]("1E;F1?>65A<CL*("`@("`@("`D=&AI<RT^7W!I8VME
M<B`]("1P:6-K97(["B`@("`@("`@)'1H:7,M/E]F;W)M871?:6X@/2`D9F]R
M;6%T7VEN.PH@("`@("`@("1T:&ES+3Y?9F]R;6%T7V]U="`]("1F;W)M871?
M;W5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R
M<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)&1A=&4@/2`D
M=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@)&5M<'1Y
M(#T@)'1H:7,M/F5M<'1Y1&%T94%R<F%Y*"1D871E*3L*"B`@("`@("`@:68@
M*"1E;7!T>2`]/2`Q("8F("1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@
M("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V5I9B`H
M)&5M<'1Y(#T](#`@)B8@(6-H96-K9&%T92@D9&%T95LG;6]N=&@G72P@)&1A
M=&5;)V1A>2==+"`D9&%T95LG>65A<B==*2D@>PH@("`@("`@("`@("`D;65S
M<V%G92`](%\H(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(BD["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V5I9B`H)&5M<'1Y(#T]("TQ
M*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&5M<'1Y1&%T94%R<F%Y*"1D871E*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?87)R87DH)&1A=&4I*2!["B`@("`@("`@("`@(')E='5R;B!E;7!T>2@D
M9&%T92D["B`@("`@("`@?0H*("`@("`@("`D96UP='D@/2`P.PH@("`@("`@
M("\J($-H96-K(&5A8V@@9&%T92!A<G)A>2!C;VUP;VYE;G0N("HO"B`@("`@
M("`@9F]R96%C:"`H)&1A=&4@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@)&5M<'1Y
M*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-H96-K
M('-T871E(&]F(&5M<'1Y+B`J+PH@("`@("`@(&EF("@D96UP='D@/3T@,"D@
M>PH@("`@("`@("`@("`O*B!)9B!N;R!E;7!T>2!P87)T<R!R971U<FX@,"X@
M*B\*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?2!E;'-E:68@*"1E
M;7!T>2`]/2`S*2!["B`@("`@("`@("`@("\J($EF(&%L;"!E;7!T>2!P87)T
M<R!R971U<FX@,2X@*B\*("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@268@<V]M92!E;7!T>2!P87)T<R!R
M971U<FX@+3$N("HO"B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1A=&4@<W5P<&QI
M960@<W!L:70@=7`@:6YT;R!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871E7VEN("!$871E(&EN(&]N92!O9B!T:&4@=&AR964@
M9F]R;6%T<R!S=7!P;W)T960@8GD*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@($AO<F1E7T9O<FT@86YD($AO<F1E7T1A=&4@*$E33R!F;W)M870*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%E965DM34TM1$0@2$@Z
M34TZ4U,L('1I;65S=&%M<"!965E934U$1$A(34U34PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@86YD(%5.25@@97!O8V@I('!L=7,@=&AE(&9O
M=7)T:"!965E9+4U-+41$+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%R<F%Y('=I=&@@=&AR964@96QE;65N=',@+2!Y96%R+"!M;VYT:"!A;F0@
M9&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$871E4&%R=',H)&1A=&5?
M:6XI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D871E7VEN*2D@>PH@
M("`@("`@("`@("`O*B!4:&ES(&ES('!R;V)A8FQY(&$@9F%I;&5D(&ES5F%L
M:60@:6YP=70@<V\@:G5S="!R971U<FX*("`@("`@("`@("`@("H@=&AE('!A
M<G1S(&%S('1H97D@87)E+B`J+PH@("`@("`@("`@("!R971U<FX@)&1A=&5?
M:6X["B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1D871E7VEN*2D@>PH@("`@
M("`@("`@("`O*B!4:&ES(&ES(&IU<W0@86X@96UP='D@9FEE;&0@<V\@<F5T
M=7)N(&5M<'1Y('!A<G1S+B`J+PH@("`@("`@("`@("!R971U<FX@87)R87DH
M)WEE87(G(#T^("<G+"`G;6]N=&@G(#T^("<G+"`G9&%Y)R`]/B`G)RD["B`@
M("`@("`@?0H*("`@("`@("`D9&%T92`]("1T:&ES+3YG971$871E3V(H)&1A
M=&5?:6XI.PH@("`@("`@(')E='5R;B!A<G)A>2@G>65A<B<@/3X@)&1A=&4M
M/GEE87(L"B`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3X@)&1A=&4M
M/FUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`G9&%Y)R`]/B`D9&%T92T^
M;61A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1A=&4@
M<W5P<&QI960@87,@82!(;W)D95]$871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D871E7VEN("!$871E(&EN(&]N92!O9B!T:&4@
M=&AR964@9F]R;6%T<R!S=7!P;W)T960@8GD*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@($AO<F1E7T9O<FT@86YD($AO<F1E7T1A=&4@*$E33R!F
M;W)M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%E965DM34TM
M1$0@2$@Z34TZ4U,L('1I;65S=&%M<"!965E934U$1$A(34U34PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@86YD(%5.25@@97!O8V@I('!L=7,@
M=&AE(&9O=7)T:"!965E9+4U-+41$+@H@("`@("H*("`@("`J($!R971U<FX@
M1&%T92`@5&AE(&1A=&4@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971$871E3V(H)&1A=&5?:6XI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]$871E+G!H<"<["@H@("`@("`@(&EF("AI<U]A<G)A>2@D9&%T
M95]I;BDI('L*("`@("`@("`@("`@+RH@268@<&%S<V5D(&%N(&%R<F%Y(&-H
M86YG92!I="!T;R!T:&4@25-/(&9O<FUA="X@*B\*("`@("`@("`@("`@:68@
M*"1T:&ES+3YE;7!T>41A=&5!<G)A>2@D9&%T95]I;BD@/3T@,"D@>PH@("`@
M("`@("`@("`@("`@)&1A=&5?:6X@/2!S<')I;G1F*"<E,#1D+24P,F0M)3`R
M9"`P,#HP,#HP,"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&5?:6Y;)WEE87(G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&%T95]I;ELG;6]N=&@G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&%T95]I;ELG9&%Y)UTI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>7&1[-'TM
M7&1[,GTM7&1[,GTD+R<L("1D871E7VEN*2D@>PH@("`@("`@("`@("`O*B!&
M:7@@=&AE(&1A=&4@:68@:70@:7,@=&AE('-H;W)T96YE9"!)4T\N("HO"B`@
M("`@("`@("`@("1D871E7VEN(#T@)&1A=&5?:6X@+B`G(#`P.C`P.C`P)SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!N97<@2&]R9&5?1&%T92@D9&%T
M95]I;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1A=&4@
M<W5P<&QI960@87,@82!(;W)D95]$871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D871E("!%:71H97(@86X@86QR96%D>2!S970@
M=7`@2&]R9&5?1&%T92!O8FIE8W0@;W(@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@<W1R:6YG(&1A=&4@:6X@;VYE(&]F('1H92!T:')E92!F;W)M
M871S('-U<'!O<G1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@8GD@
M2&]R9&5?1F]R;2!A;F0@2&]R9&5?1&%T92`H25-/(&9O<FUA=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@65E962U-32U$1"!(2#I-33I34RP@=&EM
M97-T86UP(%E965E-341$2$A-35-3(&%N9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@54Y)6"!E<&]C:"D@<&QU<R!T:&4@9F]U<G1H(%E965DM34TM
M1$0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D871E(&9O
M<FUA='1E9"!A8V-O<F1I;F<@=&\@=&AE("1F;W)M871?;W5T"B`@("`@*B`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R('=H96X@<V5T=&EN9R!U<"!T:&4@
M;6]N=&AD87EY96%R(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!F;W)M
M871$871E*"1D871E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9&%T92P@
M)T1A=&4G*2D@>PH@("`@("`@("`@("`D9&%T92`]("1T:&ES+3YG971$871E
M3V(H)&1A=&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871E+3YS
M=')F=&EM92@D=&AI<RT^7V9O<FUA=%]O=70I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@26YS97)T('1H92!D871E(&EN<'5T('1H<F]U9V@@=&AE(&9O<FT@
M:6YT;R`D:6YF;R!A<G)A>2P@:6X@=&AE(&9O<FUA=`H@("`@("H@<W!E8VEF
M:65D(&)Y('1H92`D9F]R;6%T7VEN('!A<F%M971E<B!W:&5N('-E='1I;F<@
M=7`@;6]N=&AD87EY96%R"B`@("`@*B!F:65L9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@
M("`@("`@)&EN9F\@/2`D=&AI<RT^7W9A;&ED871E06YD1F]R;6%T*"1V87(M
M/F=E=%9A;'5E*"1V87)S*2P@)'9A<BD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!686QI9&%T92]F;W)M870@82!D871E('-U8FUI<W-I;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]V86QI9&%T94%N9$9O<FUA="@D=F%L=64L("8D=F%R
M*0H@("`@>PH@("`@("`@("\J($EF(&%N>2!C;VUP;VYE;G0@:7,@96UP='D@
M8V]N<VED97(@:70@82!B860@9&%T92!A;F0@<F5T=7)N('1H90H@("`@("`@
M("`J(&1E9F%U;'0N("HO"B`@("`@("`@:68@*"1T:&ES+3YE;7!T>41A=&5!
M<G)A>2@D=F%L=64I(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N("1V87(M
M/F=E=$1E9F%U;'0H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9&%T92`]("1T:&ES+3YG971$871E3V(H)'9A;'5E*3L*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?9F]R;6%T7VEN(#T]/2!N=6QL*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)&1A=&4M/G1I;65S=&%M<"@I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871E+3YS=')F=&EM
M92@D=&AI<RT^7V9O<FUA=%]I;BD["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L
M9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")$871E('-E;&5C=&EO
M;B(I+`H@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%R=%]Y96%R)R`]/B!A<G)A
M>2@G;&%B96PG(#T^(%\H(E-T87)T('EE87(B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=I
M;G0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("=E;F1?>65A<B<@("`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(D5N9"!Y96%R(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`G:6YT)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`G<&EC:V5R)R`@
M("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:&]W('!I8VME<B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E)R`@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("=F;W)M871?:6XG("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-T;W)A9V4@
M9F]R;6%T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9O<FUA=%]O=70G(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B1&ES<&QA>2!F;W)M870B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI*3L*
M("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]C;VQO<E!I8VME<B!E
M>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI
M9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@
M("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I("8F(&5M<'1Y*"1V86QU92DI
M('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E
M<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P<F5G7VUA=&-H*"<O
M7B,H6S`M.6$M>ETI>S9])"]I)RP@)'9A;'5E*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B
M5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!2
M1T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+B(I.PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@
M("`@("1A8F]U=%LG;F%M92==(#T@7R@B0V]L;W5R('-E;&5C=&EO;B(I.PH@
M("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?<V]R=&5R(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@
M("!V87(@)%]I;G-T86YC93L*("`@('9A<B`D7W9A;'5E<SL*("`@('9A<B`D
M7W-I>F4["B`@("!V87(@)%]H96%D97(["@H@("`@9G5N8W1I;VX@:6YI="@D
M=F%L=65S+"`D<VEZ92`](#@L("1H96%D97(@/2`G)RD*("`@('L*("`@("`@
M("!S=&%T:6,@)&AO<F1E7W-O<G1E<E]I;G-T86YC92`](#`["@H@("`@("`@
M("\J($=E="!T:&4@;F5X="!P<F]G<F5S<VEV92!I;G-T86YC92!C;W5N="!F
M;W(@=&AE(&AO<F1E"B`@("`@("`@("H@<V]R=&5R('-O('1H870@;75L=&EP
M;&4@<V]R=&5R<R!C86X@8F4@=7-E9"!O;B!O;F4@<&%G92X@*B\*("`@("`@
M("`D:&]R9&5?<V]R=&5R7VEN<W1A;F-E*RL["B`@("`@("`@)'1H:7,M/E]I
M;G-T86YC92`]("=H;W)D95]S;W)T97)?)R`N("1H;W)D95]S;W)T97)?:6YS
M=&%N8V4["B`@("`@("`@)'1H:7,M/E]V86QU97,@/2`D=F%L=65S.PH@("`@
M("`@("1T:&ES+3Y?<VEZ92`@(#T@)'-I>F4["B`@("`@("`@)'1H:7,M/E]H
M96%D97(@/2`D:&5A9&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H
M)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%L=65S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V86QU97,["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<VEZ93L*("`@('T*"B`@("!F=6YC=&EO;B!G971(96%D97(H
M*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]H96%D97(I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VAE861E<CL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]P
M=&EO;G,H)&ME>7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1H=&UL(#T@)R<[
M"B`@("`@("`@:68@*"1T:&ES+3Y?:&5A9&5R*2!["B`@("`@("`@("`@("1H
M=&UL("X]("<\;W!T:6]N('9A;'5E/2(B/B<@+B!H=&UL<W!E8VEA;&-H87)S
M*"1T:&ES+3Y?:&5A9&5R*2`N("<\+V]P=&EO;CXG.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&5M<'1Y*"1K97ES*2D@>PH@("`@("`@("`@("`D:V5Y<R`]
M(&%R<F%Y7VME>7,H)'1H:7,M/E]V86QU97,I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1K97ES(#T@97AP;&]D92@B7'0B+"`D:V5Y<ULG87)R
M87DG72D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1S
M;%]K97DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64]
M(B<@+B`D<VQ?:V5Y("X@)R(^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M
M/E]V86QU97-;)'-L7VME>5TI("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@("`@("`@)'9A
M;'5E(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@
M("1I;F9O(#T@97AP;&]D92@B7'0B+"`D=F%L=65;)V%R<F%Y)UTI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@
M("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?
M*")3;W)T(&]R9&5R('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U=%LG<&%R
M86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@("`@
M("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL
M"B`@("`@("`@("`@("=H96%D97(G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B
M2&5A9&5R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E
M)R`@/3X@)W1E>'0G*2D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*
M"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]S96QE8W1&:6QE<R!E>'1E;F1S
M($AO<F1E7T9O<FU?5'EP92!["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5X="!T
M;R!U<V4@:6X@=&AE(&QI;FLN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?;&EN:U]T97AT.PH*("`@("\J*@H@("`@("H@
M5&AE('-T>6QE('1O('5S92!F;W(@=&AE(&QI;FLN"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;&EN:U]S='EL93L*"B`@
M("`O*BH*("`@("`J("!#<F5A=&4@=&AE(&QI;FL@=VET:"!A;B!I8V]N(&EN
M<W1E860@;V8@=&5X=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?:6-O;CL*"B`@("`O*BH*("`@("`J($-O;G1A:6YS
M(&=O;&QE;2!S96QE8W1F:6QE('-E;&5C=&EO;DE$"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V5L96-T:60["@H@("`@
M9G5N8W1I;VX@:6YI="@D;&EN:U]T97AT(#T@;G5L;"P@)&QI;FM?<W1Y;&4@
M/2`G)RP@)&EC;VX@/2!F86QS92P*("`@("`@("`@("`@("`@("`@)'-E;&5C
M=&ED(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&QI;FM?=&5X
M="DI('L*("`@("`@("`@("`@)&QI;FM?=&5X="`](%\H(E-E;&5C="!&:6QE
M<R(I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VQI;FM?=&5X="`]("1L
M:6YK7W1E>'0["B`@("`@("`@)'1H:7,M/E]L:6YK7W-T>6QE(#T@)&QI;FM?
M<W1Y;&4["B`@("`@("`@)'1H:7,M/E]I8V]N(#T@)&EC;VX["B`@("`@("`@
M)'1H:7,M/E]S96QE8W1I9"`]("1S96QE8W1I9#L*("`@('T*"B`@("!F=6YC
M=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E
M*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@
M("`@("1V86QU92`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D
M:6YF;R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=F:6QE<R]S96QE
M8W1L:7-T4F5S=6QT<R<L(&%R<F%Y*"1V86QU92D@*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D9I;&4@<V5L96-T:6]N
M(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]A<W-I9VX@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@
M>PH*("`@('9A<B`D7VQE9G1686QU97,["B`@("!V87(@)%]R:6=H=%9A;'5E
M<SL*("`@('9A<B`D7VQE9G1(96%D97(["B`@("!V87(@)%]R:6=H=$AE861E
M<CL*("`@('9A<B`D7W-I>F4["B`@("!V87(@)%]W:61T:#L*"B`@("!F=6YC
M=&EO;B!I;FET*"1L969T5F%L=65S+"`D<FEG:'1686QU97,L("1L969T2&5A
M9&5R(#T@)R<L"B`@("`@("`@("`@("`@("`@("1R:6=H=$AE861E<B`]("<G
M+"`D<VEZ92`](#@L("1W:61T:"`]("<R,#!P>"<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]L969T5F%L=65S(#T@)&QE9G1686QU97,["B`@("`@("`@)'1H
M:7,M/E]R:6=H=%9A;'5E<R`]("1R:6=H=%9A;'5E<SL*("`@("`@("`D=&AI
M<RT^7VQE9G1(96%D97(@/2`D;&5F=$AE861E<CL*("`@("`@("`D=&AI<RT^
M7W)I9VAT2&5A9&5R(#T@)')I9VAT2&5A9&5R.PH@("`@("`@("1T:&ES+3Y?
M<VEZ92`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D=VED=&@[
M"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D
M=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971686QU97,H)'-I9&4I"B`@("!["B`@
M("`@("`@<F5T=7)N("1S:61E(#\@)'1H:7,M/E]R:6=H=%9A;'5E<R`Z("1T
M:&ES+3Y?;&5F=%9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!S971686QU
M97,H)'-I9&4L("1V86QU97,I"B`@("!["B`@("`@("`@:68@*"1S:61E*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<FEG:'1686QU97,@/2`D=F%L=65S.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;&5F=%9A;'5E
M<R`]("1V86QU97,["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=$AE861E<B@D<VED92D*("`@('L*("`@("`@("!R971U<FX@)'-I9&4@/R`D
M=&AI<RT^7W)I9VAT2&5A9&5R(#H@)'1H:7,M/E]L969T2&5A9&5R.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5VED=&@H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W=I9'1H.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$]P=&EO;G,H)'-I9&4L("1F;W)M;F%M92D*("`@
M('L*("`@("`@("`D:'1M;"`]("<G.PH@("`@("`@("1H96%D97(@/2!F86QS
M93L*("`@("`@("!I9B`H)'-I9&4I('L*("`@("`@("`@("`@)'9A;'5E<R`]
M("1T:&ES+3Y?<FEG:'1686QU97,["B`@("`@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]R:6=H=$AE861E<BDI('L*("`@("`@("`@("`@("`@("1V86QU
M97,@/2!A<G)A>2@G)R`]/B`D=&AI<RT^7W)I9VAT2&5A9&5R*2`K("1V86QU
M97,["B`@("`@("`@("`@("`@("`D:&5A9&5R<R`]('1R=64["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L=65S(#T@
M)'1H:7,M/E]L969T5F%L=65S.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?;&5F=$AE861E<BDI('L*("`@("`@("`@("`@("`@("1V86QU97,@
M/2!A<G)A>2@G)R`]/B`D=&AI<RT^7VQE9G1(96%D97(I("L@)'9A;'5E<SL*
M("`@("`@("`@("`@("`@("1H96%D97)S(#T@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU
M93TB)R`N("1K97D@+B`G(B<["B`@("`@("`@("`@(&EF("@D:&5A9&5R<RD@
M>PH@("`@("`@("`@("`@("`@)&AE861E<G,@/2!F86QS93L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<@;VYD8FQC
M;&EC:STB2&]R9&5?1F]R;5]!<W-I9VXN;6]V92A<)R<@+B`D9F]R;6YA;64@
M+@H@("`@("`@("`@("`@)UPG+"`G("X@*&EN="DD<VED92`N("<I.R(G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<^)R`N("1V86P@
M+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M
M;#L*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L
M("8D:6YF;RD*("`@('L*("`@("`@("`D=F%L=64@/2`D=F%R<RT^9V5T*"1V
M87(M/F=E=%9A<DYA;64H*2`N("=?7W9A;'5E<R<I.PH@("`@("`@(&EF("AS
M=')P;W,H)'9A;'5E+"`B7'1<="(I(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`D;&5F="`]("1V86QU93L*("`@("`@("`@("`@)')I9VAT(#T@)R<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D;&5F="P@)')I9VAT
M*2`](&5X<&QO9&4H(EQT7'0B+"`D=F%L=64I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&QE9G0I*2!["B`@("`@("`@("`@("1I;F9O6R=L969T
M)UT@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I
M;F9O6R=L969T)UT@/2!E>'!L;V1E*")<="(L("1L969T*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&5M<'1Y*"1R:6=H="DI('L*("`@("`@("`@("`@)&EN
M9F];)W)I9VAT)UT@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1I;F9O6R=R:6=H="==(#T@97AP;&]D92@B7'0B+"`D<FEG:'0I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O
M(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T
M*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A
M8F]U=%LG;F%M92==(#T@7R@B07-S:6=N;65N="!C;VQU;6YS(BD["B`@("`@
M("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G;&5F
M=%9A;'5E<R<@/3X@87)R87DH)VQA8F5L)R`]/B!?*"),969T('9A;'5E<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`G<W1R:6YG;&ES="<I+`H@("`@("`@("`@("`G<FEG:'1686QU97,G(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B4FEG:'0@=F%L=65S(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG
M;&ES="<I+`H@("`@("`@("`@("`G;&5F=$AE861E<B<@/3X@87)R87DH)VQA
M8F5L)R`]/B!?*"),969T(&AE861E<B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("=R
M:6=H=$AE861E<B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")2:6=H="!H96%D
M97(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP
M92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("=S:7IE)R`@(#T^(&%R<F%Y
M*"=L86)E;"<@/3X@7R@B4VEZ92(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@)W=I9'1H
M)R`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5VED=&@@:6X@0U-3('5N:71S
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^
M("=T97AT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC
M;&%S<R!(;W)D95]&;W)M7U1Y<&5?8W)E9&ET8V%R9"!E>'1E;F1S($AO<F1E
M7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E<75I<F5D*"DI('L*("`@("`@("`@
M("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@+RH@9V5T0V%R9%1Y
M<&4H*2!W:6QL(&%L<V\@=F5R:69Y('1H92!C:&5C:W-U;2X@*B\*("`@("`@
M("`@("`@)'1Y<&4@/2`D=&AI<RT^9V5T0V%R9%1Y<&4H)'9A;'5E*3L*("`@
M("`@("`@("`@:68@*"1T>7!E(#T]/2!F86QS92!\?"`D='EP92`]/2`G=6YK
M;F]W;B<I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(BD["B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$-H96-K<W5M*"1C8VYU;2D*("`@('L*("`@("`@("`D;&5N(#T@
M<W1R;&5N*"1C8VYU;2D["B`@("`@("`@:68@*"%I<U]L;VYG*"1L96X@+R`R
M*2D@>PH@("`@("`@("`@("`D=V5I9VAT(#T@,CL*("`@("`@("`@("`@)&1I
M9VET(#T@)&-C;G5M6S!=.PH@("`@("`@('T@96QS96EF("AI<U]L;VYG*"1L
M96X@+R`R*2D@>PH@("`@("`@("`@("`D=V5I9VAT(#T@,3L*("`@("`@("`@
M("`@)&1I9VET(#T@)&-C;G5M6S!=("H@,CL*("`@("`@("!]"B`@("`@("`@
M:68@*"1D:6=I="`^(#DI('L*("`@("`@("`@("`@)&1I9VET(#T@)&1I9VET
M("T@.3L*("`@("`@("!]"B`@("`@("`@)&D@/2`Q.PH@("`@("`@("1C:&5C
M:W-U;2`]("1D:6=I=#L*("`@("`@("!W:&EL92`H)&D@/"`D;&5N*2!["B`@
M("`@("`@("`@(&EF("@D8V-N=6U;)&E=("$]("<@)RD@>PH@("`@("`@("`@
M("`@("`@)&1I9VET(#T@)&-C;G5M6R1I72`J("1W96EG:'0["B`@("`@("`@
M("`@("`@("`D=V5I9VAT(#T@*"1W96EG:'0@/3T@,2D@/R`R(#H@,3L*("`@
M("`@("`@("`@("`@(&EF("@D9&EG:70@/B`Y*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1I9VET(#T@)&1I9VET("T@.3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1C:&5C:W-U;2`K/2`D9&EG:70["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8VAE8VMS=6T["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V%R9%1Y
M<&4H)&-C;G5M*0H@("`@>PH@("`@("`@("1S=6T@/2`D=&AI<RT^9V5T0VAE
M8VMS=6TH)&-C;G5M*3L*("`@("`@("`D;"`]('-T<FQE;B@D8V-N=6TI.PH*
M("`@("`@("`O+R!38W)E96X@8VAE8VMS=6TN"B`@("`@("`@:68@*"@D<W5M
M("4@,3`I("$](#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(%9I<V$N"B`@("`@("`@:68@
M*"@H)&P@/3T@,38I('Q\("@D;"`]/2`Q,RDI("8F"B`@("`@("`@("`@("@D
M8V-N=6U;,%T@/3T@-"DI('L*("`@("`@("`@("`@<F5T=7)N("=V:7-A)SL*
M("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!-87-T97)#87)D+@H@
M("`@("`@(&EF("@H)&P@/3T@,38I("8F"B`@("`@("`@("`@("@D8V-N=6U;
M,%T@/3T@-2D@)B8*("`@("`@("`@("`@*"1C8VYU;5LQ72`^/2`Q*2`F)@H@
M("`@("`@("`@("`H)&-C;G5M6S%=(#P](#4I*2!["B`@("`@("`@("`@(')E
M='5R;B`G;6%S=&5R8V%R9"<["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C
M:R!F;W(@06UE>"X*("`@("`@("!I9B`H*"1L(#T](#$U*2`F)@H@("`@("`@
M("`@("`H)&-C;G5M6S!=(#T](#,I("8F"B`@("`@("`@("`@("@H)&-C;G5M
M6S%=(#T](#0I('Q\("@D8V-N=6U;,5T@/3T@-RDI*2!["B`@("`@("`@("`@
M(')E='5R;B`G86UE>"<["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F
M;W(@1&ES8V]V97(@*$YO=G5S*2X*("`@("`@("!I9B`H<W1R;&5N*"1C8VYU
M;2D@/3T@,38@)B8*("`@("`@("`@("`@<W5B<W1R*"1C8VYU;2P@,"P@-"D@
M/3T@)S8P,3$G*2!["B`@("`@("`@("`@(')E='5R;B`G9&ES8V]V97(G.PH@
M("`@("`@('T*"B`@("`@("`@+R\@268@=V4@9V]T('1H:7,@9F%R+"!T:&5N
M(&YO(&-A<F0@;6%T8VAE9"X*("`@("`@("!R971U<FX@)W5N:VYO=VXG.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@
M='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@
M("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@
M/2!?*")#<F5D:70@8V%R9"!N=6UB97(B*3L*("`@("`@("!R971U<FX@)&%B
M;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V]B<F]W<V5R
M(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO;B!I<U9A
M;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@
M("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")296QA=&EO;G-H:7`@0G)O=W-E
M<B(I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(
M;W)D95]&;W)M7U1Y<&5?9&)L;V]K=7`@97AT96YD<R!(;W)D95]&;W)M7U1Y
M<&5?96YU;2!["@H@("`@9G5N8W1I;VX@:6YI="@D9'-N+"`D<W%L+"`D<')O
M;7!T(#T@;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)T1"+G!H
M<"<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@)&1B(#T@
M)D1".CIC;VYN96-T*"1D<VXI.PH@("`@("`@(&EF("@A:7-?82@D9&(L("=0
M14%27T5R<F]R)RDI('L*"B`@("`@("`@("`@("\O(%-E="!$0B!P;W)T86)I
M;&ET>2!O<'1I;VYS+@H@("`@("`@("`@("!S=VET8V@@*"1D8BT^<&AP='EP
M92D@>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("`@
M("`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E4
M65],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$0E]03U)4
M04))3$E465]25%))32D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1D8BT^<V5T3W!T:6]N
M*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"
M7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1C;VP@/2`F)&1B+3YG971#;VPH)'-Q;"D["B`@("`@("`@("`@(&EF
M("@A:7-?82@D8V]L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@
M("`@("`D=F%L=65S(#T@2&]R9&5?07)R87DZ.F-O;6)I;F4H)&-O;"P@)&-O
M;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<&%R96YT.CII
M;FET*"1V86QU97,L("1P<F]M<'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@
M("`@("`@("`@)VYA;64G(#T^(%\H(D1A=&%B87-E($QO;VMU<"(I+`H@("`@
M("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=D
M<VXG(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B1%-.("AS964@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R
M;RUD<VXN<&AP*2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`@("`@)W-Q;"<@/3X@
M87)R87DH)VQA8F5L)R`]/B!?*")344P@<W1A=&5M96YT(&9O<B!V86QU92!L
M;V]K=7!S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP
M92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("`@("`G<')O;7!T)R`]/B!A
M<G)A>2@G;&%B96PG(#T^(%\H(E!R;VUP="!T97AT(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI"B`@
M("`@("`@("`@("D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?
M9FEG;&5T(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]T
M97AT.PH@("`@=F%R("1?9F]N=#L*"B`@("!F=6YC=&EO;B!I;FET*"1T97AT
M+"`D9F]N="D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*
M("`@("`@("`D=&AI<RT^7V9O;G0@/2`D9F]N=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=F%L=64I("8F("1V87(M/FES
M4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("A3=')I;F<Z.FQO=V5R*"1V86QU
M92D@(3T@4W1R:6YG.CIL;W=E<B@D=&AI<RT^7W1E>'0I*2!["B`@("`@("`@
M("`@("1M97-S86=E(#T@7R@B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO
M="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(I.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971&;VYT*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]F;VYT.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%1E>'0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1E>'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G;F%M92<@/3X@7R@B1FEG
M;&5T($-!4%1#2$$B*2P*("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`G=&5X="<@/3X@87)R87DH)VQA8F5L)R`]/B!?
M*")497AT(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`@("`@)V9O;G0G(#T^(&%R
M<F%Y*"=L86)E;"<@/3X@7R@B1FEG;&5T(&9O;G0B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI"B`@("`@
M("`@("`@("D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?:6YV
M86QI9"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1M97-S
M86=E.PH*("`@(&9U;F-T:6]N(&EN:70H)&UE<W-A9V4I"B`@("!["B`@("`@
M("`@)'1H:7,M/FUE<W-A9V4@/2`D;65S<V%G93L*("`@('T*"B`@("!F=6YC
M=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E
M*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*"B\J*@H@
M*B!4:&ES(&-L87-S(')E<')E<V5N=',@82!S:6YG;&4@9F]R;2!V87)I86)L
M92!T:&%T(&UA>2!B92!R96YD97)E9"!A<R!O;F4@;W(*("H@;6]R92!F;W)M
M(&9I96QD<RX*("H*("H@0&%U=&AO<B`@4F]B97)T($4N($-O>6QE(#QR;V)E
M<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!P86-K86=E($AO<F1E7T9O<FT*
M("HO"F-L87-S($AO<F1E7T9O<FU?5F%R:6%B;&4@>PH*("`@("\J*@H@("`@
M("H@5&AE(&9O<FT@:6YS=&%N8V4@=&AI<R!V87)I86)L92!I<R!A<W-I9VYE
M9"!T;RX*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7T9O<FT*("`@("`J+PH@
M("`@=F%R("1F;W)M.PH*("`@("\J*@H@("`@("H@02!S:&]R="!D97-C<FEP
M=&EO;B!O9B!T:&ES('9A<FEA8FQE)W,@<'5R<&]S92X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&AU;6%N3F%M93L*"B`@
M("`O*BH*("`@("`J(%1H92!I;G1E<FYA;&QY('5S960@;F%M92X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'9A<DYA;64[
M"@H@("`@+RHJ"B`@("`@*B!!('M`;&EN:R!(;W)D95]&;W)M7U1Y<&5](&EN
M<W1A;F-E+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?1F]R;5]4>7!E"B`@
M("`@*B\*("`@('9A<B`D='EP93L*"B`@("`O*BH*("`@("`J(%=H971H97(@
M=&AI<R!I<R!A(')E<75I<F5D('9A<FEA8FQE+@H@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)')E<75I<F5D.PH*("`@("\J
M*@H@("`@("H@5VAE=&AE<B!T:&ES(&ES(&$@<F5A9&]N;'D@=F%R:6%B;&4N
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M<F5A9&]N;'D["@H@("`@+RHJ"B`@("`@*B!!(&QO;F<@9&5S8W)I<'1I;VX@
M;V8@=&AE('9A<FEA8FQE)W,@<'5R<&]S92P@<W!E8VEA;"!I;G-T<G5C=&EO
M;G,L(&5T8RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)&1E<V-R:7!T:6]N.PH*("`@("\J*@H@("`@("H@5&AE('9A<FEA
M8FQE(&AE;'`@=&5X="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)&AE;'`["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H
M:7,@:7,@86X@87)R87D@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V%R<F%Y5F%L.PH*("`@("\J*@H@
M("`@("H@5&AE(&1E9F%U;'0@=F%L=64N"B`@("`@*@H@("`@("H@0'9A<B!M
M:7AE9`H@("`@("HO"B`@("!V87(@)%]D969686QU92`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!!('M`;&EN:R!(;W)D95]&;W)M7T%C=&EO;GT@:6YS=&%N
M8V4N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]&;W)M7T%C=&EO;@H@("`@
M("HO"B`@("!V87(@)%]A8W1I;VX["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R
M('1H:7,@=F%R:6%B;&4@:7,@9&ES86)L960N"B`@("`@*@H@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V1I<V%B;&5D(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D7V%U=&]F:6QL960@/2!F86QS93L*"B`@
M("`O*BH*("`@("`J(%=H971H97(@=&AI<R!I<R!A(&AI9&1E;B!V87)I86)L
M92X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?:&ED9&5N(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O<'1I;VYS
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AU;6%N3F%M92`@
M("`@($$@<VAO<G0@9&5S8W)I<'1I;VX@;V8@=&AE('9A<FEA8FQE)W,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!U<G!O<V4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1V87).86UE("`@("`@("!4:&4@:6YT97)N
M86QL>2!U<V5D(&YA;64N"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R;5]4>7!E
M("1T>7!E("!!('M`;&EN:R!(;W)D95]&;W)M7U1Y<&5](&EN<W1A;F-E+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)')E<75I<F5D("`@("`@5VAE=&AE<B!T
M:&ES(&ES(&$@<F5Q=6ER960@=F%R:6%B;&4N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<F5A9&]N;'D@("`@("!7:&5T:&5R('1H:7,@:7,@82!R96%D;VYL
M>2!V87)I86)L92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<V-R:7!T:6]N
M("`@($$@;&]N9R!D97-C<FEP=&EO;B!O9B!T:&4@=F%R:6%B;&4G<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<'5R<&]S92P@<W!E
M8VEA;"!I;G-T<G5C=&EO;G,L(&5T8RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?1F]R;5]687)I86)L92@D:'5M86Y.86UE+"`D=F%R3F%M92P@)B1T
M>7!E+"`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R96%D;VYL>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL*0H@
M("`@>PH@("`@("`@("1T:&ES+3YH=6UA;DYA;64@("`]("1H=6UA;DYA;64[
M"B`@("`@("`@)'1H:7,M/G9A<DYA;64@("`@(#T@)'9A<DYA;64["B`@("`@
M("`@)'1H:7,M/G1Y<&4@("`@("`@(#T@)B1T>7!E.PH@("`@("`@("1T:&ES
M+3YR97%U:7)E9"`@("`]("1R97%U:7)E9#L*("`@("`@("`D=&AI<RT^<F5A
M9&]N;'D@("`@/2`D<F5A9&]N;'D["B`@("`@("`@)'1H:7,M/F1E<V-R:7!T
M:6]N(#T@)&1E<V-R:7!T:6]N.PH@("`@("`@("1T:&ES+3Y?87)R87E686P@
M("`]("AS=')P;W,H)'9A<DYA;64L("=;72<I("$]/2!F86QS92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!<W-I9VX@=&AI<R!V87)I86)L92!T;R!T:&4@
M<W!E8VEF:65D(&9O<FTN"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T9O
M<FT@)&9O<FT@(%1H92!F;W)M(&EN<W1A;F-E('1O(&%S<VEG;B!T:&ES('9A
M<FEA8FQE('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971&;W)M3V(H)B1F
M;W)M*0H@("`@>PH@("`@("`@("1T:&ES+3YF;W)M(#T@)B1F;W)M.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&1E9F%U;'0@=F%L=64@9F]R('1H
M:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1V86QU
M92`@02!V87)I86)L92!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M1&5F875L="@D=F%L=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]D969686QU
M92`]("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AI
M<R!V87)I86)L92=S(&1E9F%U;'0@=F%L=64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AI<R!V87)I86)L92=S(&1E9F%U;'0@=F%L=64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1E9E9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@07-S:6=N<R!A;B!A8W1I;VX@=&\@=&AI<R!V87)I86)L92X*("`@("`J
M"B`@("`@*B!%>&%M<&QE.@H@("`@("H@/&-O9&4^"B`@("`@*B`D=B`]("8D
M9F]R;2T^861D5F%R:6%B;&4H)TUY(%9A<FEA8FQE)RP@)W9A<C$G+"`G=&5X
M="<L(&9A;'-E*3L*("`@("`J("1A8W1I;VX@/2`F2&]R9&5?1F]R;5]!8W1I
M;VXZ.F9A8W1O<GDH)W-U8FUI="<I.PH@("`@("H@)'8M/G-E=$%C=&EO;B@D
M86-T:6]N*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@
M2&]R9&5?1F]R;5]!8W1I;VX@)&%C=&EO;B`@02![0&QI;FL@2&]R9&5?1F]R
M;5]!8W1I;VY](&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971!
M8W1I;VXH)&%C=&EO;BD*("`@('L*("`@("`@("`D=&AI<RT^7V%C=&EO;B`]
M("1A8W1I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H
M97(@=&AI<R!V87)I86)L92!H87,@86X@871T86-H960@86-T:6]N+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES('9A<FEA
M8FQE(&AA<R!A;B!A='1A8VAE9"!A8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AA<T%C=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("%I<U]N=6QL
M*"1T:&ES+3Y?86-T:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S
M('1H:7,@82!H:61D96X@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&AI9&4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&ED9&5N(#T@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES(&ES
M(&$@:&ED9&5N('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&ES(&$@:&ED9&5N('9A<FEA8FQE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<TAI9&1E;B@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:&ED9&5N.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES86)L
M97,@=&AI<R!V87)I86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES86)L
M92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]D:7-A8FQE9"`]('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AI<R!V87)I
M86)L92!I<R!D:7-A8FQE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@=&AI<R!V87)I86)L92!I<R!D:7-A8FQE9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-$:7-A8FQE9"@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&ES86)L960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE('-H;W)T(&1E<V-R:7!T:6]N(&]F('1H:7,@=F%R:6%B;&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@<VAO<G0@9&5S8W)I
M<'1I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T2'5M86Y.86UE*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FAU;6%N3F%M93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN=&5R;F%L;'D@=7-E9"!V87)I
M86)L92!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&ES
M('9A<FEA8FQE)W,@:6YT97)N86P@;F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5F%R3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YV
M87).86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&ES('9A
M<FEA8FQE)W,@='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T9O
M<FU?5'EP92`@5&AI<R!V87)I86)L92=S('M`;&EN:R!(;W)D95]&;W)M7U1Y
M<&5]"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N8V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9G9714>7!E*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N86UE(&]F('1H:7,@=F%R:6%B;&4G<R!T>7!E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&ES('9A<FEA8FQE)W,@('M`
M;&EN:R!(;W)D95]&;W)M7U1Y<&5](&YA;64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%1Y<&5.86UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G1Y<&4M/F=E=%1Y<&5.86UE*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('=H971H97(@=&AI<R!I<R!A(')E<75I<F5D('9A<FEA8FQE+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&ES
M(&$@<F5Q=6ER960@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M4F5Q=6ER960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5Q=6ER
M960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AI
M<R!I<R!A(')E861O;FQY('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&$@<F5A9&]N;'D@=F%R:6%B;&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4F5A9&]N;'DH*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^<F5A9&]N;'D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!P;W-S:6)L92!V86QU97,@;V8@=&AI<R!V87)I
M86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<&]S<VEB
M;&4@=F%L=65S(&]F('1H:7,@=F%R:6%B;&4@;W(@;G5L;"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5F%L=65S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G1Y<&4M/F=E=%9A;'5E<R@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@=F%R:6%B;&4@:&%S(&$@;&]N9R!D
M97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AI<R!V87)I86)L92!H87,@82!L;VYG(&1E<V-R:7!T:6]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!H87-$97-C<FEP=&EO;B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^9&5S8W)I<'1I;VXI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&ES('9A<FEA8FQE)W,@;&]N
M9R!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AI<R!V87)I86)L92=S(&QO;F<@9&5S8W)I<'1I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$1E<V-R:7!T:6]N*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/F1E<V-R:7!T:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!W:&5T:&5R('1H:7,@:7,@86X@87)R87D@=F%R:6%B;&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H:7,@86X@
M87)R87D@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES07)R87E6
M86PH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%R<F%Y5F%L.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@=F%R
M:6%B;&4@:7,@=&\@=7!L;V%D(&$@9FEL92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=F%R:6%B;&4@:7,@=&\@=7!L;V%D(&$@
M9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-5<&QO860H*0H@("`@>PH@
M("`@("`@(')E='5R;B`H)'1H:7,M/G1Y<&4M/F=E=%1Y<&5.86UE*"D@/3T@
M)V9I;&4G*3L*("`@('T*"B`@("`O*BH*("`@("`J($%S<VEG;G,@82!H96QP
M('1E>'0@=&\@=&AI<R!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1H96QP("!4:&4@=F%R:6%B;&4@:&5L<"!T97AT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971(96QP*"1H96QP*0H@("`@>PH@("`@("`@("1T
M:&ES+3YF;W)M+3Y?:&5L<"`]('1R=64["B`@("`@("`@)'1H:7,M/FAE;'`@
M/2`D:&5L<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE
M<B!T:&ES('9A<FEA8FQE(&AA<R!S;VUE(&AE;'`@=&5X="!A<W-I9VYE9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AI<R!V
M87)I86)L92!H87,@82!H96QP('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&AA<TAE;'`H*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M
M/FAE;'`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:&5L
M<"!T97AT(&]F('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H:7,@=F%R:6%B;&4G<R!H96QP('1E>'0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$AE;'`H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^:&5L<#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@82!V87)I
M86)L92!O<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T
M:6]N("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@;6EX960@)'9A
M;"`@("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T3W!T:6]N*"1O<'1I;VXL("1V86PI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]O<'1I;VYS6R1O<'1I;VY=(#T@)'9A;#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!V87)I86)L92!O<'1I;VXG<R!V86QU92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@(%1H92!O<'1I;VX@
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@(%1H
M92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T
M:6]N*"1O<'1I;VXI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULD;W!T:6]N72D@/R`D=&AI<RT^7V]P=&EO;G-;)&]P=&EO
M;ET@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<V5S('1H
M92!S=6)M:71T960@=F%L=64@;V8@=&AI<R!V87)I86)L92!A8V-O<F1I;F<@
M=&\@=&AE(')U;&5S(&]F"B`@("`@*B!T:&4@=F%R:6%B;&4@='EP92X*("`@
M("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("1V87)S("!4:&4@>T!L:6YK
M(%9A<FEA8FQE<WT@:6YS=&%N8V4@;V8@=&AE('-U8FUI='1E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*("`@("`J($!P87)A;2!M
M:7AE9"`D:6YF;R`@("`@($$@=F%R:6%B;&4@<&%S<V5D(&)Y(')E9F5R96YC
M92!T:&%T('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&%S<VEG;F5D('1H92!P<F]C97-S960@=F%L=64@;V8@=&AE('-U8FUI='1E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=F%R:6%B;&4@=F%L
M=64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1&5P96YD:6YG(&]N
M('1H92!V87)I86)L92!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971)
M;F9O*"8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^='EP92T^9V5T26YF;R@D=F%R<RP@)'1H:7,L("1I;F9O*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES('9A<FEA8FQE
M(&EF(&ET(&AA9"!T:&4@(G1R86-K8VAA;F=E(B!O<'1I;VX@<V5T"B`@("`@
M*B!H87,@86-T=6%L;'D@8F5E;B!C:&%N9V5D+@H@("`@("H*("`@("`J($!P
M87)A;2!687)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B;&5S?2!I
M;G-T86YC92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@3G5L;"!I9B!T:&ES('9A<FEA8FQE(&1O97-N)W0@:&%V92!T:&4@(G1R
M86-K8VAA;F=E(@H@("`@("H@("`@("`@("`@("`@("`@("!O<'1I;VX@<V5T
M(&]R('1H92!F;W)M('=A<VXG="!S=6)M:71T960@>65T+B!!(&)O;VQE86X*
M("`@("`J("`@("`@("`@("`@("`@("`@:6YD:6-A=&EN9R!W:&5T:&5R('1H
M92!V87)I86)L92!W87,@8VAA;F=E9"!O=&AE<G=I<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('=A<T-H86YG960H)B1V87)S*0H@("`@>PH@("`@("`@(&EF
M("@A)'1H:7,M/F=E=$]P=&EO;B@G=')A8VMC:&%N9V4G*2D@>PH@("`@("`@
M("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@)&]L9"`]("1V
M87)S+3YG970H)U]?;VQD7R<@+B`D=&AI<RT^9V5T5F%R3F%M92@I*3L*("`@
M("`@("!I9B`H:7-?;G5L;"@D;VQD*2D@>PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O;&0@(3T@)'9A<G,M
M/F=E="@D=&AI<RT^9V5T5F%R3F%M92@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%9A;&ED871E<R!T:&ES('9A<FEA8FQE+@H@("`@("H*("`@("`J($!P
M87)A;2!687)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B;&5S?2!I
M;G-T86YC92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G
M92`@02!V87)I86)L92!P87-S960@8GD@<F5F97)E;F-E('1H870@=VEL;"!B
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@87-S:6=N960@82!D
M97-C<FEP=&EV92!E<G)O<B!M97-S86=E(&EF"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!V86QI9&%T:6]N(&9A:6QE9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('9A<FEA8FQE('9A;&ED
M871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&4H)B1V87)S+"`F
M)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?87)R87E686PI
M('L*("`@("`@("`@("`@)'9A;',@/2`D=&AI<RT^9V5T5F%L=64H)'9A<G,I
M.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V86QS*2D@>PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YR97%U:7)E9"D@>PH@("`@("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB
M*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1V86QS(&%S("1I(#T^("1V86QU92D@>PH@("`@("`@
M("`@("`@("`@:68@*"1V86QU92`]/3T@;G5L;"`F)B`D=&AI<RT^<F5Q=6ER
M960I('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(21T:&ES+3YT>7!E+3YI<U9A;&ED*"1T:&ES+"`D
M=F%R<RP@)'9A;'5E+"`D;65S<V%G92DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1V86QU92`]("1T:&ES+3YG971686QU92@D=F%R<RD[
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^='EP92T^:7-686QI9"@D=&AI
M<RP@)'9A<G,L("1V86QU92P@)&UE<W-A9V4I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!S=6)M:71T960@;W(@9&5F875L="!V86QU92!O9B!T:&ES('9A<FEA
M8FQE+@H@("`@("H@268@86X@86-T:6]N(&ES(&%T=&%C:&5D('1O('1H:7,@
M=F%R:6%B;&4L('1H92!V86QU92!W:6QL(&=E="!P87-S960@=&\*("`@("`J
M('1H92!A8W1I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!687)I
M86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B;&5S?2!I;G-T86YC92!O
M9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("`@268@=&AE
M('9A<FEA8FQE(&ES(&%N(&%R<F%Y('9A<FEA8FQE+"!T:&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I97,@=&AE(&%R<F%Y(&5L
M96UE;G0@=&\@<F5T=7)N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!V87)I86)L92!O<B!E;&5M96YT('9A;'5E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971686QU92@F)'9A<G,L("1I;F1E>"`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3Y?87)R87E686PI('L*("`@("`@("`@("`@
M)&YA;64@/2!S=')?<F5P;&%C92@G6UTG+"`G)RP@)'1H:7,M/G9A<DYA;64I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@)'1H:7,M
M/G9A<DYA;64["B`@("`@("`@?0H@("`@("`@("1V86QU92`]("1V87)S+3YG
M971%>&ES=',H)&YA;64L("1W87-S970I.PH*("`@("`@("!I9B`H(21W87-S
M970I('L*("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/F=E=$1E9F%U;'0H
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7V%R<F%Y5F%L("8F
M("%I<U]N=6QL*"1I;F1E>"DI('L*("`@("`@("`@("`@:68@*"$D=V%S<V5T
M("8F("%I<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D<F5T
M=7)N(#T@)'9A;'5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)')E='5R;B`](&ES<V5T*"1V86QU95LD:6YD97A=*2`_("1V86QU
M95LD:6YD97A=(#H@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1R971U<FX@/2`D=F%L=64["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/FAA<T%C=&EO;B@I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?86-T:6]N+3YS971686QU97,H)'9A<G,L("1R971U<FXL("1T
M:&ES+3Y?87)R87E686PI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M971U<FX["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O2V]L86(N<&AP````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,38U-#`U`#$P-3$U-#,Q,#8Q`#`Q-S<W,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RHJ(%=E(')E
M<75I<F4@=&AE(&)A<V4@2&]R9&4@;&EB<F%R>2X@*B\*<F5Q=6ER95]O;F-E
M("=(;W)D92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<[
M"@HO*BH@5V4@;F5E9"!T:&4@4W1R:6YG("8@3DQ3(&QI8G)A<FEE<R!F;W(@
M8VAA<F%C=&5R('-E="!C;VYV97)S:6]N<RP@971C+B`J+PIR97%U:7)E7V]N
M8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TY,
M4RYP:'`G.PH*+RHJ(%=E(&YE960@=&AE($AO<F1E($U)344@;&EB<F%R>2!T
M;R!D96%L('=I=&@@34E-12!M97-S86=E<RP@;V)V:6]U<VQY(#HM*2X@*B\*
M<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O34E-12]087)T+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O34E-
M12]-97-S86=E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O34E-12](96%D
M97)S+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O34E-12]3=')U8W1U<F4N
M<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?2V]L86(@;&EB<F%R>2!R97%U:7)E
M<R!V97)S:6]N(#X](#$N,"XS(&]F($YE=%])34%0("AI+F4N(&$@=F5R<VEO
M;@H@*B!T:&%T(&EN8VQU9&5S('-U<'!O<G0@9F]R('1H92!!3DY/5$%414U/
M4D4@24U!4"!E>'1E;G-I;VXI+B!4:&4@;&%T97-T"B`J('9E<G-I;VX@;V8@
M3F5T7TE-05`@8V%N(&)E(&]B=&%I;F5D(&9R;VT@:'1T<#HO+W!E87(N<&AP
M+FYE="]G970O3F5T7TE-05`*("HO"G)E<75I<F5?;VYC92`G3F5T+TE-05`N
M<&AP)SL*"B\J*@H@*B!4:&4@8VAA<F%C=&5R('-E<75E;F-E('5S960@8GD@
M82`H2V]L86(I($-Y<G5S($E-05`@<V5R=F5R('1O('-E<&%R871E(&QI;F5S
M"B`J('=I=&AI;B!A(&UE<W-A9V4N"B`J+PID969I;F4H)TM/3$%"7TY%5TQ)
M3D4G+"`B7')<;B(I.PH*+RHJ"B`J(%1H92!C:&%R86-T97(@=7-E9"!T;R!D
M96QI;6ET('-U8F9O;&1E<G,@=VET:&EN(&$@*$MO;&%B*2!#>7)U<R!F;VQD
M97(*("H@:&EE<F%R8VAY+@H@*B\*9&5F:6YE*"=+3TQ!0E]&3TQ$15)?1$5,
M24TG+"`G+R<I.PH*+RHJ"B`J(%1H92!R;V]T(&]F('1H92!+;VQA8B!A;FYO
M=&%T:6]N(&AI97)A<F-H>2P@=7-E9"!O;B!T:&4@=F%R:6]U<R!)34%0(&9O
M;&1E<@H@*B!T:&%T(&%R92!U<V5D(&)Y($MO;&%B(&-L:65N=',N"B`J+PID
M969I;F4H)TM/3$%"7T%.3D]47U)/3U0G+"`G+W9E;F1O<B]K;VQA8B\G*3L*
M"B\J*@H@*B!4:&4@86YN;W1A=&EO;BP@87,@9&5F:6YE9"!B>2!T:&4@2V]L
M86(@9F]R;6%T('-P96,L('1H870@:7,@=7-E9"!T;R!S=&]R90H@*B!I;F9O
M<FUA=&EO;B!A8F]U="!W:&%T(&=R;W5P=V%R92!F;W)M870@=&AE(&9O;&1E
M<B!C;VYT86EN<RX*("HO"F1E9FEN92@G2T],04)?04Y.3U1?1D],1$527U19
M4$4G+"!+3TQ!0E]!3DY/5%]23T]4("X@)V9O;&1E<BUT>7!E)RD["@HO*BH*
M("H@02!(;W)D92US<&5C:69I8R!A;FYO=&%T:6]N('1H870@<W1O<F5S('1H
M92!5240@;V8@=&AE($AO<F1E('-H87)E('1H870*("H@8V]R<F5S<&]N9',@
M=&\@=&AE($E-05`@9F]L9&5R+B!4:&ES(&ES('5S960@:6X@=&AE('-Y;F-H
M<F]N:7-A=&EO;B!P<F]C97-S"B`J(&]F('1H92!)34%0(&9O;&1E<B!L:7-T
M(&%N9"!T:&4@2&]R9&4@<VAA<F4@;&ES="X*("HO"F1E9FEN92@G2T],04)?
M04Y.3U1?4TA!4D5?54E$)RP@2T],04)?04Y.3U1?4D]/5"`N("=H+7-H87)E
M+75I9"<I.PH*+RHJ"B`J(%1H92!8+2!H96%D97(@=7-E9"!T;R!S=&]R92!A
M(&-O<'D@;V8@=&AE($MO;&%B(&]B:F5C="!T>7!E('-T<FEN9R!F;W(@=&AE
M"B`J(&]B:F5C="!T>7!E('1H870@:7,@8V]N=&%I;F5D('=I=&AI;B!T:&4@
M96UA:6P@;65S<V%G92X*("HO"F1E9FEN92@G2T],04)?2$5!1$527U194$4G
M+"`G6"U+;VQA8BU4>7!E)RD["@HO*BH*("H@06X@:6YD97@@:6YT;R!T:&4@
M)%]315-324].(&%R<F%Y('=H:6-H(&ES('5S960@=&\@8V%C:&4@=VAA="!A
M<'!L:6-A=&EO;@H@*B!W87,@;&%S="!S>6YC:')O;FES960[('1H:7,@<')E
M=F5N=',@=7,@9G)O;2!C;VYT:6YU;W5S;'D@<F4M<WEN8VAR;VYI<VEN9PH@
M*B!O;B!E=F5R>2!P86=E(&QO860@=VET:&EN(&$@<VEN9VQE(&%P<&QI8V%T
M:6]N+@H@*B\*9&5F:6YE*"=+3TQ!0E],05-47U-93D-(141?05!0)RP@)VMO
M;&%B7VQA<W1?<WEN8VAE9%]A<'`G*3L*"B\J*@H@*B!!;B!I;F1E>"!I;G1O
M('1H92`D7U-%4U-)3TX@87)R87D@=VAI8V@@:7,@=7-E9"!T;R!C86-H92!A
M(&UA<'!I;F<@;V8@<VAA<F4*("H@54E$<R!T;R!)34%0(&9O;&1E<G,[('1H
M:7,@:7,@=7-E9"!B>2!T:&4@=F%R:6]U<R!A<'!L:6-A=&EO;B!D<FEV97)S
M('=H96X*("H@;W!E;FEN9R!A('-P96-I9FEC('-H87)E+"!I;B!O<F1E<B!T
M;R!K;F]W('=H870@=&AE(&-O<G)E<W!O;F1I;F<@24U!4`H@*B!F;VQD97(@
M=&AA="!M=7-T(&)E(&]P96YE9"!I<RX*("HO"F1E9FEN92@G2T],04)?4TA!
M4D5?34%0)RP@)VMO;&%B7W-H87)E7VUA<"<I.PH*+RHJ"B`J(%1H92!P<F5F
M:7@@9F]R(&%L;"!+;VQA8B!G<F]U<'=A<F4@;V)J96-T(&UI;64@='EP92!S
M=')I;F=S+B!%86-H(&]B:F5C=`H@*B!T>7!E(&AA<R!T:&ES('-T<FEN9R!I
M;B!C;VUM;VXL('=I=&@@82!S=69F:7@@;V8@92YG+B`G;F]T92<L("=E=F5N
M="<L(&5T8RX*("H@=&\@:6YD:6-A=&4@=VAA="!T:&4@<W!E8VEF:6,@2V]L
M86(@9W)O=7!W87)E(&9O<FUA="!I<RX*("HO"F1E9FEN92@G2T],04)?34E-
M15]465!%7U!2149)6"<L("=A<'!L:6-A=&EO;B]X+79N9"YK;VQA8BXG*3L*
M"B\J*@H@*B!4:&4@<W1R:6YG('5S960@=&\@:61E;G1I9GD@=&AE($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!I;B!V87)I;W5S"B`J('!L86-E
M<R`H92YG+B!I;B!+;VQA8B!O8FIE8W1S(&=E;F5R871E9"!B>2!T:&4@;&EB
M<F%R>2DN"B`J+PID969I;F4H)TM/3$%"7U!23T150U1?240G+"`G:&]R9&4O
M:V]L86(O,2XP)RD["@HO*BH*("H@5&AE($AO<F1E7TMO;&%B(&QI8G)A<GD@
M:7,@8F]T:"!A;B!O8FIE8W0@=7-E9"!B>2!A<'!L:6-A=&EO;B!D<FEV97)S
M('1O"B`J(&-O;6UU;FEC871E('=I=&@@82!+;VQA8B!S97)V97(L(&%S('=E
M;&P@87,@82!U=&EL:71Y(&QI8G)A<GD@<')O=FED:6YG"B`J('-E=F5R86P@
M9G5N8W1I;VYS('1O(&AE;'`@:6X@=&AE($E-05`@9F]L9&5R(#PM/B!(;W)D
M92!3:&%R92!S>6YC:')O;FES871I;VX*("H@<')O8V5S<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP+'8@,2XR-BXQ,"XQ-B`R
M,#`V+S`W+S$W(#`Y.C,P.C4P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P-"TR,#`V($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]H;W)D92YO<F<O*0H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4W1U87)T($)I;F=E(#QO;6EC
M<F]N0&UI9VAT>2YC;RYZ83X*("H@0'!A8VMA9V4@2&]R9&5?2V]L86(*("HO
M"F-L87-S($MO;&%B('L*"B\O($-L87-S(&EN=&5R9F%C90H*("`@("\J*@H@
M("`@("H@5&AE(&-U<G)E;G0@87!P;&EC871I;VX@=&AA="!T:&ES($MO;&%B
M(&]B:F5C="!I;G-T86YC92!I<R!C871E<FEN9R!T;RX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A<'`["@H@("`@+RHJ
M"B`@("`@*B!/=7(@3F5T7TE-05`@;V)J96-T+"!U<V5D('1O(&-O;6UU;FEC
M871E('=I=&@@=&AE($-Y<G5S('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R
M($YE=%])34%0"B`@("`@*B\*("`@('9A<B`D7VEM87`@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@02!C86-H960@=F5R<VEO;B!O9B!+;VQA8CHZ9V5T07!P
M0V]N<W1S*"1T:&ES+3Y?87!P*2!T:&%T(&ES('5S960@:6X*("`@("`J('-E
M=F5R86P@;V8@=&AE($MO;&%B.CH@9G5N8W1I;VYS+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87!P7V-O;G-T<SL*"B`@
M("`O*BH*("`@("`J($$@<VAO<G1C=70@=&\@)'1H:7,M/E]A<'!?8V]N<W1S
M6R=M:6UE7W1Y<&5?<W5F9FEX)UT*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]O8FIE8W1?='EP93L*"B`@("`O*BH*("`@
M("`J(%1H92!F=6QL(&UI;64@='EP92!S=')I;F<@;V8@=&AE(&-U<G)E;G0@
M2V]L86(@;V)J96-T(&9O<FUA="!W92=R90H@("`@("H@9&5A;&EN9R!W:71H
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7VUI;65?='EP93L*"B`@("`O*BH*("`@("`J(%1H92`H96YC;V1E9"D@;F%M
M92!O9B!T:&4@24U!4"!F;VQD97(@=&AA="!C;W)R97-P;VYD<R!T;R!T:&4@
M8W5R<F5N=`H@("`@("H@<VAA<F4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?9F]L9&5R.PH*("`@("\J*@H@("`@("H@
M5&AE($U)345?365S<V%G92!O8FIE8W0@=&AA="!C;VYT86EN<R!T:&4@8W5R
M<F5N=&QY(&QO861E9"!M97-S86=E+B!4:&ES"B`@("`@*B!I<R!U<V5D('=H
M96X@=7!D871I;F<@86X@;V)J96-T+"!I;B!O<F1E<B!T;R!P<F5S97)V92!E
M=F5R>71H:6YG(&5L<V4*("`@("`J('=I=&AI;B!T:&4@;65S<V%G92!T:&%T
M('=E(&1O;B=T(&MN;W<@:&]W('1O(&AA;F1L92X*("`@("`J"B`@("`@*B!`
M=F%R($U)345?365S<V%G90H@("`@("HO"B`@("!V87(@)%]M97-S86=E.PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@8V]N=&%I;FEN9R`D7VUE<W-A9V4G
M<R!H96%D97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?:&5A9&5R<SL*"B`@("`O*BH*("`@("`J(%1H92!-24U%(&ED
M96YT:69I97(@;V8@=&AE($MO;&%B(&=R;W5P=V%R92!O8FIE8W0@=VET:&EN
M("1T:&ES+3Y?;65S<V%G92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]M:6UE7VED.PH*("`@("\J*@H@("`@("H@5&AE
M("A+;VQA8BD@54E$(&]F("1T:&ES+3Y?;65S<V%G92X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]U:60["@H@("`@+RHJ
M"B`@("`@*B!4:&4@1&]M1&]C=6UE;G0@;V)J96-T('1H870@8V]N=&%I;G,@
M=&AE(%A-3"!$3TT@=')E92!O9B!T:&4@8W5R<F5N=&QY"B`@("`@*B!L;V%D
M960@9W)O=7!W87)E(&]B:F5C="X@5V4@8V%C:&4@=&AI<R!H97)E('1O(&5N
M<W5R92!P<F5S97)V871I;VX@;V8*("`@("`J('5N:VYO=VX@9FEE;&1S('=H
M96X@<F4M<V%V:6YG('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!$
M;VU$;V-U;65N=`H@("`@("HO"B`@("!V87(@)%]X;6P["@H@("`@+RHJ"B`@
M("`@*B!4:&4@24U!4"!M97-S86=E(&YU;6)E<B!O9B`D=&AI<RT^7VUE<W-A
M9V4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D7VUS9U]N;SL*"B`@("!F=6YC=&EO;B!G9715240H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W5I9#L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971-:6UE5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6EM
M95]T>7!E.PH@("`@?0H*("`@(&9U;F-T:6]N($MO;&%B*"D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D=&AI<RT^7V%P<"`]
M("1R96=I<W1R>2T^9V5T07!P*"D["B`@("!]"@H@("`@9G5N8W1I;VX@;W!E
M;B@D<VAA<F5?=6ED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@
M("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)V1O;7AM;"<I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DAO<F1E
M+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G
M9&]M>&UL)R!02%`@97AT96YS:6]N(BDI.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]A<'!?8V]N<W1S(#T@2V]L86(Z.F=E=$%P<$-O;G-T<R@D=&AI
M<RT^7V%P<"D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]A<'!?8V]N<W1S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V%P<%]C;VYS=',["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V]B:F5C
M=%]T>7!E(#T@)'1H:7,M/E]A<'!?8V]N<W1S6R=M:6UE7W1Y<&5?<W5F9FEX
M)UT["B`@("`@("`@)'1H:7,M/E]M:6UE7W1Y<&4@/2!+3TQ!0E]-24U%7U19
M4$5?4%)%1DE8("X@)'1H:7,M/E]O8FIE8W1?='EP93L*"B`@("`@("`@)&-U
M<G)E;G1?=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("`D;F1X(#T@
M<W1R<&]S*"1C=7)R96YT7W5S97(L("=`)RD["B`@("`@("`@)'5S97(@/2`D
M;F1X(#T]/2!F86QS92`_("1C=7)R96YT7W5S97(@.B!S=6)S='(H)&-U<G)E
M;G1?=7-E<BP@,"P@)&YD>"D["B`@("`@("`@)&1O;6%I;B`]('-T<G-T<B@D
M8W5R<F5N=%]U<V5R+"`G0"<I.PH*("`@("`@("`D<VAA<F5?;6%P(#T@2V]L
M86(Z.F=E=%-H87)E36%P*"D["B`@("`@("`@:68@*&5M<'1Y*"1S:&%R95]M
M87!;)'-H87)E7W5I9%TI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@)&9O;&1E<B`]("1S:&%R95]M87!;)'-H87)E
M7W5I9%T["@H@("`@("`@("\O(%1R86YS;&%T92!R96UO=&4M<WEN=&%X(&9O
M;&1E<G,@=&AA="!W92!O=VX@=&\@;&]C86PM<WEN=&%X('-O('1H870*("`@
M("`@("`O+R!W92!C86X@;W!E;B!T:&5M('!R;W!E<FQY"B`@("`@("`@<')E
M9U]M871C:"@B.W5S97(O*%M>+UTK*2\H6UY`72LI*$`N*BD_.R(L("1F;VQD
M97(L("1M871C:&5S*3L*"B`@("`@("`@)'5S97)?9&]M86EN(#T@:7-S970H
M)&UA=&-H97-;,UTI(#\@)&UA=&-H97-;,UT@.B`D9&]M86EN.PH@("`@("`@
M(&EF("@D;6%T8VAE<ULQ72`]/2`D=7-E<B`F)B`D=7-E<E]D;VUA:6X@/3T@
M)&1O;6%I;BD@>PH@("`@("`@("`@("`D9F]L9&5R(#T@(DE.0D]8+R1M871C
M:&5S6S)=(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9F]L9&5R
M(#T@(G5S97(O)&UA=&-H97-;,5TO)&UA=&-H97-;,ETB.PH@("`@("`@("`@
M("!I9B`H)'5S97)?9&]M86EN("$]("1D;VUA:6XI('L*("`@("`@("`@("`@
M("`@("1F;VQD97(@+CT@)'5S97)?9&]M86EN.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9O;&1E<B`]("1F;VQD97(["@H@
M("`@("`@("1T:&ES+3Y?:6UA<"`](&YE=R!.971?24U!4"@D8V]N9ELG:V]L
M86(G75LG:6UA<"==6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G
M75LG<&]R="==*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^
M;&]G:6XH)&-U<G)E;G1?=7-E<BP@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S
M<W=O<F0G*2P@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA
M<"T^<V5L96-T36%I;&)O>"@D=&AI<RT^7V9O;&1E<BD["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]I;6%P+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@("1T:&ES+3Y?:6UA
M<"`](&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&9I;F1/
M8FIE8W0H)'5I9"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I
M;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YS96%R8V@H(E-50DI%
M0U0@7"(D=6ED7"(B*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1R97-U;'0I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(BDL
M("1U:60I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT6S!=
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&QI<W1/8FIE8W1S*"D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;6%P+3YS96%R8V@H)TA%041%4B`B)R`N($M/3$%"7TA%041%4E]465!%
M("X@)R(@(B<@+B`D=&AI<RT^7VUI;65?='EP92`N("<B)RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@9FEN9$]B:F5C=',H)&-R:71E<FEA*0H@("`@>PH@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM87`M/G-E87)C:"@D8W)I=&5R:6$I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&QI<W1/8FIE8W1S26Y&;VQD97(H)&9O;&1E<BD*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["@H@("`@("`@("\O($-O;FYE8W0@=&\@=&AE($E-05`@
M<V5R=F5R"B`@("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO
M;&%B)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P
M)UU;)W!O<G0G72D["@H@("`@("`@("\O($QO9VEN('5S:6YG('1H92!C=7)R
M96YT($AO<F1E(&-R961E;G1I86QS"B`@("`@("`@)')E<W5L="`]("1I;6%P
M+3YL;V=I;BA!=71H.CIG971!=71H*"DL($%U=&@Z.F=E=$-R961E;G1I86PH
M)W!A<W-W;W)D)RDL(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G56YA8FQE('1O(&%U=&AE;G1I8V%T92!W:71H('1H92!+
M;VQA8B!)34%0('-E<G9E<B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4V5L96-T(&UA:6QB;W@@=&\@<V5A<F-H(&EN"B`@("`@("`@)')E<W5L="`]
M("1I;6%P+3YS96QE8W1-86EL8F]X*"1F;VQD97(I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&EM
M87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^<V5A
M<F-H*"=(14%$15(@(B<@+B!+3TQ!0E](14%$15)?5%E012`N("<B("(G("X@
M)'1H:7,M/E]M:6UE7W1Y<&4@+B`G(B<I.PH@("`@("`@("1I;6%P+3YD:7-C
M;VYN96-T*"D["@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@
M("\O(%1/1$\Z('=R:71E(&$@9G5N8W1I;VX@=&AA="!I<R!A8FQE('1O(&QO
M;VL@=&AR;W5G:"!A;&P@9F]L9&5R<PH@("`@+R\@;V8@=&AE('1Y<&4@=V4G
M<F4@:6YT97)E<W1E9"!I;BP@;&]O:VEN9R!F;W(@86X@;V)J96-T('=I=&@@
M80H@("`@+R\@<W!E8VEF:6,@54E$+B!4:&ES(&ES(&YE961E9"!F;W(@=&AE
M(&=E=$)Y1U5)1"@I(&9U;F-T:6]N<R!I;@H@("`@+R\@=&AE('9A<FEO=7,@
M87!P;&EC871I;VX@9')I=F5R<RX*"B`@("!F=6YC=&EO;B!M;W9E3V)J96-T
M*"1U:60L("1N97=?<VAA<F4I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T
M:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@)&US9U]N;R`]("1T:&ES+3YF:6YD3V)J96-T*"1U
M:60I.PH@("`@("`@(&EF("AI<U]A*"1M<V=?;F\L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1M<V=?;F\["B`@("`@("`@?0H*("`@
M("`@("`D<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P*"D["B`@("`@
M("`@:68@*&5M<'1Y*"1S:&%R95]M87!;)&YE=U]S:&%R95TI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(BDL("1N97=?<VAA<F4I
M*3L*("`@("`@("!]"@H@("`@("`@("1N97=?9F]L9&5R(#T@)'-H87)E7VUA
M<%LD;F5W7W-H87)E73L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA
M<"T^8V]P>4UE<W-A9V5S*"1N97=?9F]L9&5R+"`D;7-G7VYO*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6UA<"T^9&5L971E365S<V%G97,H)&US9U]N;RD["B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM87`M/F5X<'5N9V4H*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!R96UO=F5/8FIE8W1S*"1O8FIE8W1S+"`D:7-?;7-G;F\@/2!F86QS
M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1O8FIE8W1S*2D@>PH@("`@("`@("`@("`D;V)J96-T
M<R`](&%R<F%Y*"1O8FIE8W1S*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M:7-?;7-G;F\@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1N97=?;V)J96-T
M<R`](&%R<F%Y*"D["@H@("`@("`@("`@("!F;W)E86-H("@D;V)J96-T<R!A
M<R`D;V)J96-T*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/F9I;F1/8FIE8W0H)&]B:F5C="D["B`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@)&YE=U]O8FIE8W1S6UT@/2`D<F5S=6QT.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D;V)J96-T<R`]("1N97=?;V)J96-T<SL*("`@
M("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/F1E;&5T
M94UE<W-A9V5S*"1O8FIE8W1S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^
M97AP=6YG92@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!R
M96UO=F5!;&Q/8FIE8W1S*"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YD96QE=&5-
M97-S86=E<R@D=&AI<RT^;&ES=$]B:F5C=',H*2D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9L;V%D3V)J96-T*"1U:60L("1I<U]M<V=N
M;R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM
M87`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D:7-?;7-G;F\@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M("1U:60@/2`D=&AI<RT^9FEN9$]B:F5C="@D=6ED*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)'5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1U:60["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?:&5A9&5R<R`]("1T:&ES+3Y?:6UA<"T^9V5T4&%R<V5D
M2&5A9&5R<R@D=6ED*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VAE861E
M<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G95]T97AT(#T@)'1H:7,M
M/E]I;6%P+3YG971-97-S86=E<R@D=6ED*3L*("`@("`@("!I9B`H:7-?82@D
M;65S<V%G95]T97AT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D;65S<V%G95]T97AT.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1M97-S86=E7W1E>'0I*2!["B`@("`@("`@("`@("1M97-S86=E
M7W1E>'0@/2!A<G)A>5]S:&EF="@D;65S<V%G95]T97AT*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?;7-G7VYO(#T@)'5I9#L*("`@("`@("`D=&AI
M<RT^7VUE<W-A9V4@/2`F34E-15]3=')U8W1U<F4Z.G!A<G-E5&5X=$U)345-
M97-S86=E*"1M97-S86=E7W1E>'0I.PH*("`@("`@("`D<&%R=',@/2`D=&AI
M<RT^7VUE<W-A9V4M/F-O;G1E;G14>7!E36%P*"D["B`@("`@("`@:68@*"@D
M=&AI<RT^7VUI;65?:60@/2!A<G)A>5]S96%R8V@H)'1H:7,M/E]M:6UE7W1Y
M<&4L("1P87)T<RDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R="`]
M("1T:&ES+3Y?;65S<V%G92T^9V5T4&%R="@D=&AI<RT^7VUI;65?:60I.PH@
M("`@("`@("`@("`D=&5X="`]("1P87)T+3YT<F%N<V9E<D1E8V]D92@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B*2P@)'1H:7,M/E]M:6UE7W1Y
M<&4L("1U:60I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?>&UL(#T@
M0&1O;7AM;%]O<&5N7VUE;2@D=&5X="P@1$]-6$U,7TQ/041?4$%24TE.1R!\
M"B`@("`@("`@("`@($1/35A-3%],3T%$7T-/35!,151%7T%45%)3('P@1$]-
M6$U,7TQ/041?4U5"4U1)5%5415]%3E1)5$E%4R!\"B`@("`@("`@("`@($1/
M35A-3%],3T%$7T1/3E1?2T5%4%]"3$%.2U,L("1E<G)O<BD["B`@("`@("`@
M:68@*"%E;7!T>2@D97)R;W(I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(I+"`D=&AI
M<RT^7V]B:F5C=%]T>7!E+"`D=6ED*2D["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W5I9"`]("1T:&ES+3YG971686PH)W5I9"<I.PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7WAM;"T^9&]C=6UE;G1?96QE;65N="@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9N97=/8FIE8W0H)'5I9"D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VUS9U]N;R`]("TQ
M.PH*("`@("`@("`D=&AI<RT^7VUE<W-A9V4@/2!N97<@34E-15]-97-S86=E
M*"D["@H@("`@("`@("1K;VQA8E]T97AT(#T@<W!R:6YT9BA?*")4:&ES(&ES
M(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C
M="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VAT='`Z+R]W=W<N:V]L86(N;W)G
M+VMO;&%B,BUC;&EE;G1S+FAT;6PG*3L*"B`@("`@("`@)'!A<G0@/2!N97<@
M34E-15]087)T*"=T97AT+W!L86EN)RP@4W1R:6YG.CIW<F%P*"1K;VQA8E]T
M97AT+"`W-BP@2T],04)?3D573$E.12P@3DQ3.CIG971#:&%R<V5T*"DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H
M*2D["B`@("`@("`@)'!A<G0M/G-E=%1R86YS9F5R16YC;V1I;F<H)W%U;W1E
M9"UP<FEN=&%B;&4G*3L*("`@("`@("`D=&AI<RT^7VUE<W-A9V4M/F%D9%!A
M<G0H)'!A<G0I.PH*("`@("`@("`D<&%R="`](&YE=R!-24U%7U!A<G0H)'1H
M:7,M/E]M:6UE7W1Y<&4L("<G+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@
M("`@)'!A<G0M/G-E=%1R86YS9F5R16YC;V1I;F<H)W%U;W1E9"UP<FEN=&%B
M;&4G*3L*("`@("`@("`D=&AI<RT^7VUE<W-A9V4M/F%D9%!A<G0H)'!A<G0I
M.PH*("`@("`@("`D<&%R=',@/2`D=&AI<RT^7VUE<W-A9V4M/F-O;G1E;G14
M>7!E36%P*"D["B`@("`@("`@:68@*"@D=&AI<RT^7VUI;65?:60@/2!A<G)A
M>5]S96%R8V@H)'1H:7,M/E]M:6UE7W1Y<&4L("1P87)T<RDI(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(I+"`D=&AI<RT^7VUI;65?='EP
M92DI.PH@("`@("`@('T*"B`@("`@("`@)&AE861E<G,@/2!N97<@34E-15](
M96%D97)S*"D["B`@("`@("`@)&AE861E<G,M/F%D9$AE861E<B@G1G)O;2<L
M($%U=&@Z.F=E=$%U=&@H*2D["B`@("`@("`@)&AE861E<G,M/F%D9$AE861E
M<B@G5&\G+"!!=71H.CIG971!=71H*"DI.PH@("`@("`@("1H96%D97)S+3YA
M9&1(96%D97(H)U-U8FIE8W0G+"`D=6ED*3L*("`@("`@("`D:&5A9&5R<RT^
M861D2&5A9&5R*"=5<V5R+4%G96YT)RP@2T],04)?4%)/1%5#5%])1"D["B`@
M("`@("`@)&AE861E<G,M/F%D9$AE861E<B@G4F5P;'DM5&\G+"`G)RD["B`@
M("`@("`@)&AE861E<G,M/F%D9$AE861E<B@G1&%T92<L(&1A=&4H)W(G*2D[
M"B`@("`@("`@)&AE861E<G,M/F%D9$AE861E<BA+3TQ!0E](14%$15)?5%E0
M12P@)'1H:7,M/E]M:6UE7W1Y<&4I.PH@("`@("`@("1H96%D97)S+3YA9&1-
M24U%2&5A9&5R<R@D=&AI<RT^7VUE<W-A9V4I.PH*("`@("`@("`D=&AI<RT^
M7VAE861E<G,@/2`D:&5A9&5R<RT^=&]!<G)A>2@I.PH*("`@("`@("`D=&AI
M<RT^7WAM;"`](&1O;7AM;%]O<&5N7VUE;2@*("`@("`@("`@("`@)SP_>&UL
M('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^)R`N"B`@("`@("`@
M("`@("<\)R`N("1T:&ES+3Y?;V)J96-T7W1Y<&4@+B`G('9E<G-I;VX](C$N
M,"(^)R`N"B`@("`@("`@("`@("<\=6ED/B<@+B`D=6ED("X@)SPO=6ED/B<@
M+@H@("`@("`@("`@("`G/&)O9'D^/"]B;V1Y/B<@+@H@("`@("`@("`@("`G
M/&-A=&5G;W)I97,^/"]C871E9V]R:65S/B<@+@H@("`@("`@("`@("`G/&-R
M96%T:6]N+61A=&4^)R`N($MO;&%B.CIE;F-O9&5$871E5&EM92@I("X@)SPO
M8W)E871I;VXM9&%T93XG("X*("`@("`@("`@("`@)SQS96YS:71I=FET>3YP
M=6)L:6,\+W-E;G-I=&EV:71Y/B<@+@H@("`@("`@("`@("`G/"\G("X@)'1H
M:7,M/E]O8FIE8W1?='EP92`N("<^)RP*("`@("`@("`@("`@1$]-6$U,7TQ/
M041?4$%24TE.1R!\($1/35A-3%],3T%$7T-/35!,151%7T%45%)3('P*("`@
M("`@("`@("`@1$]-6$U,7TQ/041?4U5"4U1)5%5415]%3E1)5$E%4R!\($1/
M35A-3%],3T%$7T1/3E1?2T5%4%]"3$%.2U,L"B`@("`@("`@("`@("1E<G)O
M<@H@("`@("`@("D["B`@("`@("`@:68@*"%E;7!T>2@D97)R;W(I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,B*2P@)'5I9"DI.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]U:60@/2`D=6ED.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]X;6PM
M/F1O8W5M96YT7V5L96UE;G0H*3L*("`@('T*"B`@("!F=6YC=&EO;B!S879E
M3V)J96-T*"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^<V5T5F%L*"=L87-T+6UO9&EF:6-A=&EO;BUD871E)RP@
M2V]L86(Z.F5N8V]D941A=&54:6UE*"DI.PH@("`@("`@("1T:&ES+3YS9716
M86PH)W!R;V1U8W0M:60G+"!+3TQ!0E]04D]$54-47TE$*3L*"B`@("`@("`@
M)'!A<G0@/2!N97<@34E-15]087)T*"1T:&ES+3Y?;6EM95]T>7!E+"`D=&AI
M<RT^7WAM;"T^9'5M<%]M96TH=')U92DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`D<&%R="T^
M<V5T5')A;G-F97)%;F-O9&EN9R@G<75O=&5D+7!R:6YT86)L92<I.PH@("`@
M("`@("1T:&ES+3Y?;65S<V%G92T^86QT97)087)T*"1T:&ES+3Y?;6EM95]I
M9"P@)'!A<G0I.PH*("`@("`@("!I9B`H)'1H:7,M/E]M<V=?;F\@(3T@+3$I
M('L*("`@("`@("`@("`@)'1H:7,M/G)E;6]V94]B:F5C=',H)'1H:7,M/E]M
M<V=?;F\L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@)&AE861E<G,@/2!N
M97<@34E-15](96%D97)S*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]H
M96%D97)S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D:&5A9&5R
M<RT^861D2&5A9&5R*"1K97DL("1V86PI.PH@("`@("`@('T*"B`@("`@("`@
M)&UE<W-A9V4@/2!+;VQA8CHZ:V]L86).97=L:6YE<R@D:&5A9&5R<RT^=&]3
M=')I;F<H*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VUE<W-A9V4M/G1O4W1R:6YG*&9A;'-E*2D["@H@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/F%P<&5N9$UE<W-A9V4H)&UE
M<W-A9V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7VUS9U]N;R`]("1T:&ES+3YF:6YD3V)J96-T*"1T
M:&ES+3Y?=6ED*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VUS9U]N;RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]M
M<V=?;F\["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("!F=6YC=&EO;B`F9V5T0W5R<F5N=$]B:F5C="@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?>&UL+3YD;V-U;65N=%]E;&5M96YT*"D["B`@
M("!]"@H@("`@9G5N8W1I;VX@)F=E=$5L96TH)&YA;64L("8D<&%R96YT*0H@
M("`@>PH@("`@("`@("1E;&5M96YT<R`]("8D=&AI<RT^9V5T06QL16QE;7,H
M)&YA;64L("1P87)E;G0I.PH*("`@("`@("!I9B`H96UP='DH)&5L96UE;G1S
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&5L96UE;G1S6S!=.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9G971!;&Q%;&5M<R@D;F%M92P@)B1P87)E;G0I"B`@("!["B`@("`@("`@
M<F5T=7)N("1P87)E;G0M/F=E=%]E;&5M96YT<U]B>5]T86=N86UE*"1N86UE
M*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4F]O=$5L96TH)&YA;64I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971%;&5M*"1N86UE+"`D=&AI
M<RT^9V5T0W5R<F5N=$]B:F5C="@I*3L*("`@('T*"B`@("!F=6YC=&EO;B`F
M9V5T06QL4F]O=$5L96US*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9V5T06QL16QE;7,H)&YA;64L("1T:&ES+3YG971#=7)R96YT3V)J
M96-T*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;$5L96TH)&YA;64L("8D
M<&%R96YT*0H@("`@>PH@("`@("`@("1E;&5M96YT(#T@)B1T:&ES+3YG971%
M;&5M*"1N86UE+"`D<&%R96YT*3L*("`@("`@("!I9B`H)&5L96UE;G0@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<&%R96YT+3YR96UO=F5?8VAI;&0H)&5L96UE;G0I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&1E;$%L;$5L96US*"1N86UE+"`F)'!A<F5N
M="D*("`@('L*("`@("`@("`D96QE;65N=',@/2`F)'1H:7,M/F=E=$%L;$5L
M96US*"1N86UE+"`D<&%R96YT*3L*("`@("`@("!F;W(@*"1I(#T@,"P@)&H@
M/2!C;W5N="@D96QE;65N=',I.R`D:2`\("1J.R`D:2LK*2!["B`@("`@("`@
M("`@("1P87)E;G0M/G)E;6]V95]C:&EL9"@D96QE;65N='-;)&E=*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I
M;VX@9&5L06QL4F]O=$5L96US*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^9&5L06QL16QE;7,H)&YA;64L("1T:&ES+3YG971#=7)R96YT
M3V)J96-T*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;%)O;W1%;&5M*"8D
M96QE;65N="D*("`@('L*("`@("`@("!I9B`H)&5L96UE;G0@/3T](&9A;'-E
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1R
M;V]T(#T@)B1T:&ES+3YG971#=7)R96YT3V)J96-T*"D["B`@("`@("`@<F5T
M=7)N("1R;V]T+3YR96UO=F5?8VAI;&0H)&5L96UE;G0I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$5L96U686PH)B1P87)E;G0L("1N86UE+"`D9&5F875L
M="`](#`I"B`@("!["B`@("`@("`@:68@*"1P87)E;G0@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@(')E='5R;B`D9&5F875L=#L*("`@("`@("!]"@H@("`@
M("`@("1E;&5M96YT(#T@)B1T:&ES+3YG971%;&5M*"1N86UE+"`D<&%R96YT
M*3L*("`@("`@("!I9B`H)&5L96UE;G0@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B`D9&5F875L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D96QE;65N="T^9V5T7V-O;G1E;G0H*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971%;&5M4W1R*"8D<&%R96YT+"`D;F%M92P@)&1E9F%U;'0@/2`G)RD*
M("`@('L*("`@("`@("!I9B`H)'!A<F5N="`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N("1D969A=6QT.PH@("`@("`@('T*"B`@("`@("`@)&5L
M96UE;G0@/2`F)'1H:7,M/F=E=$5L96TH)&YA;64L("1P87)E;G0I.PH@("`@
M("`@(&EF("@D96QE;65N="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T
M=7)N("1D969A=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&5L96UE;G0M/F=E=%]C;VYT96YT*"DL("=U
M=&8M."<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A;"@D;F%M92P@)&1E
M9F%U;'0@/2`P*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9V5T16QE
M;59A;"@D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I+"`D;F%M92P@)&1E9F%U
M;'0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-T<B@D;F%M92P@)&1E9F%U
M;'0@/2`G)RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5L96U3
M='(H)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2P@)&YA;64L("1D969A=6QT
M*3L*("`@('T*"B`@("!F=6YC=&EO;B`F:6YI=$5L96TH)&YA;64L("8D<&%R
M96YT*0H@("`@>PH@("`@("`@(&EF("@D<&%R96YT(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`D<&%R96YT(#T@)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H
M*3L*("`@("`@("!]"@H@("`@("`@("1E;&5M96YT(#T@)'1H:7,M/F=E=$5L
M96TH)&YA;64L("1P87)E;G0I.PH*("`@("`@("!I9B`H)&5L96UE;G0@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("1E;&5M96YT(#T@)'!A<F5N="T^87!P
M96YD7V-H:6QD*"1T:&ES+3Y?>&UL+3YC<F5A=&5?96QE;65N="@D;F%M92DI
M.PH@("`@("`@('T*"B`@("`@("`@)&-H:6QD<F5N(#T@)&5L96UE;G0M/F-H
M:6QD7VYO9&5S*"D["B`@("`@("`@9F]R96%C:"`H)&-H:6QD<F5N(&%S("1C
M:&EL9"D@>PH@("`@("`@("`@("!I9B`H)&-H:6QD+3YN;V1E7W1Y<&4H*2`]
M/2!834Q?5$585%].3T1%*2!["B`@("`@("`@("`@("`@("`D96QE;65N="T^
M<F5M;W9E7V-H:6QD*"1C:&EL9"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D96QE;65N=#L*("`@('T*"B`@("!F=6YC=&EO
M;B`F:6YI=%)O;W1%;&5M*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^:6YI=$5L96TH)&YA;64L("1T:&ES+3YG971#=7)R96YT3V)J96-T
M*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N("9A<'!E;F1%;&5M*"1N86UE+"`F
M)'!A<F5N="D*("`@('L*("`@("`@("!R971U<FX@)'!A<F5N="T^87!P96YD
M7V-H:6QD*"1T:&ES+3Y?>&UL+3YC<F5A=&5?96QE;65N="@D;F%M92DI.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9A<'!E;F12;V]T16QE;2@D;F%M92D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/F%P<&5N9$5L96TH)&YA;64L("1T
M:&ES+3YG971#=7)R96YT3V)J96-T*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9S971%;&5M5F%L*"8D<&%R96YT+"`D;F%M92P@)'9A;'5E(#T@)R<I"B`@
M("!["B`@("`@("`@)&5L96UE;G0@/2`F)'1H:7,M/FEN:71%;&5M*"1N86UE
M+"`D<&%R96YT*3L*("`@("`@("`D96QE;65N="T^<V5T7V-O;G1E;G0H)'9A
M;'5E*3L*"B`@("`@("`@<F5T=7)N("1E;&5M96YT.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9S971%;&5M4W1R*"8D<&%R96YT+"`D;F%M92P@)'9A;'5E(#T@
M)R<I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS971%;&5M5F%L*"1P
M87)E;G0L("1N86UE+"!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@
M3DQ3.CIG971#:&%R<V5T*"DL("=U=&8M."<I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B`F<V5T5F%L*"1N86UE+"`D=F%L=64@/2`G)RD*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G-E=$5L96U686PH)'1H:7,M/F=E=$-U<G)E;G1/
M8FIE8W0H*2P@)&YA;64L("1V86QU92D["B`@("!]"@H@("`@9G5N8W1I;VX@
M)G-E=%-T<B@D;F%M92P@)'9A;'5E(#T@)R<I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YS971%;&5M4W1R*"1T:&ES+3YG971#=7)R96YT3V)J96-T
M*"DL("1N86UE+"`D=F%L=64I.PH@("`@?0H*+R\@571I;&ET>2!L:6)R87)Y
M(&EN=&5R9F%C90H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!C
M;VYT86EN:6YG('1H92!C=7)R96YT(%540R!D871E(&EN('1H92!F;W)M870*
M("`@("`J('!R97-C<FEB960@8GD@=&AE($MO;&%B($9O<FUA="!3<&5C:69I
M8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R
M<F5N="!55$,@9&%T92!I;B!T:&4@9F]R;6%T("=965E9+4U-+41$)RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@96YC;V1E1&%T92@D9&%T92`](&9A;'-E*0H@
M("`@>PH@("`@("`@(&EF("@D9&%T92`]/3T@,"D@>PH@("`@("`@("`@("!R
M971U<FX@,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('-T<F9T:6UE*"<E
M62TE;2TE9"<L("1D871E(#T]/2!F86QS92`_('1I;64H*2`Z("1D871E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!53DE8('1I;65S=&%M
M<"!C;W)R97-P;VYD:6YG('1H92!G:79E;B!D871E('-T<FEN9R!W:&EC:"!I
M<R!I;@H@("`@("H@=&AE(&9O<FUA="!P<F5S8W)I8F5D(&)Y('1H92!+;VQA
M8B!&;W)M870@4W!E8VEF:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871E("!4:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H
M92!D871E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('5N
M:7@@=&EM97-T86UP(&-O<G)E<W!O;F1I;F<@=&\@)&1A=&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1E8V]D941A=&4H)&1A=&4I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!]"@H@("`@("`@(&QI<W0H)'EE87(L("1M;VYT:"P@)&1A>2D@/2!E
M>'!L;V1E*"<M)RP@)&1A=&4I.PH@("`@("`@(')E='5R;B!M:W1I;64H,"P@
M,"P@,"P@)&UO;G1H+"`D9&%Y+"`D>65A<BD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&-U<G)E;G0@
M551#(&1A=&4@86YD('1I;64@:6X@=&AE(&9O<FUA=`H@("`@("H@<')E<V-R
M:6)E9"!B>2!T:&4@2V]L86(@1F]R;6%T(%-P96-I9FEC871I;VXN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@("`@5&AE(&-U<G)E;G0@551#(&1A
M=&4@86YD('1I;64@:6X@=&AE(&9O<FUA=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@)UE965DM34TM1$14:&@Z;6TZ<W-:)RP@=VAE<F4@=&AE(%0@86YD
M(%H@87)E(&QI=&5R86P*("`@("`J("`@("`@("`@("`@("`@("`@(&-H87)A
M8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D941A=&54:6UE*"1D
M871E=&EM92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D9&%T971I;64@
M/3T](#`I('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!G;7-T<F9T:6UE*"<E62TE;2TE9%0E2#HE33HE4UHG+"`D
M9&%T971I;64@/3T](&9A;'-E(#\@=&EM92@I(#H@)&1A=&5T:6UE*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!53DE8('1I;65S=&%M<"!C
M;W)R97-P;VYD:6YG('1H92!G:79E;B!D871E+71I;64@<W1R:6YG('=H:6-H
M"B`@("`@*B!I<R!I;B!T:&4@9F]R;6%T('!R97-C<FEB960@8GD@=&AE($MO
M;&%B($9O<FUA="!3<&5C:69I8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&1A=&5T:6UE("!4:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N
M(&]F('1H92!D871E("8@=&EM92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1H92!U;FEX('1I;65S=&%M<"!C;W)R97-P;VYD:6YG('1O("1D
M871E=&EM92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E1&%T951I;64H
M)&1A=&5T:6UE*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D9&%T971I;64I
M*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@
M;&ES="@D>65A<BP@)&UO;G1H+"`D9&%Y+"`D:&]U<BP@)&UI;G5T92P@)'-E
M8V]N9"D*("`@("`@("`@("`@/2!S<V-A;F8H)&1A=&5T:6UE+"`G)60M)60M
M)614)60Z)60Z)61:)RD["B`@("`@("`@<F5T=7)N(&=M;6MT:6UE*"1H;W5R
M+"`D;6EN=71E+"`D<V5C;VYD+"`D;6]N=&@L("1D87DL("1Y96%R*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!53DE8('1I;65S=&%M<"!C
M;W)R97-P;VYD:6YG('1H92!G:79E;B!D871E(&]R(&1A=&4M=&EM90H@("`@
M("H@<W1R:6YG('=H:6-H(&ES(&EN(&5I=&AE<B!F;W)M870@<')E<V-R:6)E
M9"!B>2!T:&4@2V]L86(@1F]R;6%T"B`@("`@*B!3<&5C:69I8V%T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&4@(%1H92!S=')I;F<@
M<F5P<F5S96YT871I;VX@;V8@=&AE(&1A=&4@*"8@=&EM92DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=6YI>"!T:6UE<W1A;7`@8V]R
M<F5S<&]N9&EN9R!T;R`D9&%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C
M;V1E1&%T94]R1&%T951I;64H)&1A=&4I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`H<W1R;&5N*"1D871E*2`]/2`Q,"`_($MO;&%B
M.CID96-O9&5$871E*"1D871E*2`Z($MO;&%B.CID96-O9&5$871E5&EM92@D
M9&%T92DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E8V]D949U;&Q$87E$871E
M*"1D871E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D9&%T92DI('L*("`@
M("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M*'-T<FQE;B@D9&%T92D@/3T@,3`@/R!+;VQA8CHZ9&5C;V1E1&%T92@D9&%T
M92DK,C0J-C`J-C`@.B!+;VQA8CHZ9&5C;V1E1&%T951I;64H)&1A=&4I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!P97)C96YT86=E5&]";V]L96%N*"1P97)C
M96YT86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D<&5R8V5N=&%G92`]/2`Q
M,#`@/R`G,2<@.B`G,"<["B`@("!]"@H@("`@9G5N8W1I;VX@8F]O;&5A;E1O
M4&5R8V5N=&%G92@D8F]O;&5A;BD*("`@('L*("`@("`@("!R971U<FX@)&)O
M;VQE86X@/R`G,3`P)R`Z("<P)SL*("`@('T*"B`@("`O*BH*("`@("`J($-O
M;G9E<G1S(&$@<W1R:6YG(&EN('1H92!C=7)R96YT(&-H87)A8W1E<B!S970@
M=&\@86X@24U!4"!55$8M-R!S=')I;F<L"B`@("`@*B!S=6ET86)L92!F;W(@
M=7-E(&%S('1H92!N86UE(&]F(&%N($E-05`@9F]L9&5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!T97AT(&EN('1H92!C=7)R
M96YT(&-H87)A8W1E<B!S970@=&\@8V]N=F5R="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@("`D;F%M92!E;F-O9&5D(&EN('1H92!)34%0('9A
M<FEA=&EO;B!O9B!55$8M-RX*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E
M26UA<$9O;&1E<DYA;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(%-T
M<FEN9SHZ8V]N=F5R=$-H87)S970H)&YA;64L($Y,4SHZ9V5T0VAA<G-E="@I
M+"`G551&-RU)34%0)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T
M<R!A('-T<FEN9R!I;B!T:&4@24U!4"!V87)I871I;VX@;V8@551&+3<@:6YT
M;R!A('-T<FEN9R!I;B!T:&4*("`@("`J(&-U<G)E;G0@8VAA<F%C=&5R('-E
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@=&5X
M="!I;B!)34%0(%541BTW('1O(&-O;G9E<G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@("`@)&YA;64@96YC;V1E9"!I;B!T:&4@8W5R<F5N="!C
M:&%R86-T97(@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&5);6%P
M1F]L9&5R3F%M92@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@D;F%M92P@)U541C<M24U!4"<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]N=F5R=',@86QL(&YE=VQI;F5S("AI;B!$3U,L
M($U!0R`F(%5.25@@9F]R;6%T*2!I;B!T:&4@<W!E8VEF:65D('1E>'0*("`@
M("`J('1O('5N:7@M<W1Y;&4@*$Q&*2!F;W)M870N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@8V]N=F5R="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@)'1E>'0@=VET:"!A;&P@;F5W
M;&EN97,@<F5P;&%C960@8GD@3$8N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N
M:7A.97=L:6YE<R@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@<')E9U]R
M97!L86-E*"(O7')<;GQ<;GQ<<B]S(BP@(EQN(BP@)'1E>'0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]N=F5R=',@86QL(&YE=VQI;F5S("AI;B!$3U,L
M($U!0R`F(%5.25@@9F]R;6%T*2!I;B!T:&4@<W!E8VEF:65D('1E>'0*("`@
M("`J('1O($MO;&%B("A#>7)U<RD@9F]R;6%T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O(&-O;G9E<G0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@("1T97AT('=I=&@@86QL(&YE=VQI
M;F5S(')E<&QA8V5D(&)Y($M/3$%"7TY%5TQ)3D4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&MO;&%B3F5W;&EN97,H)'1E>'0I"B`@("!["B`@("`@("`@<F5T
M=7)N('!R96=?<F5P;&%C92@B+UQR7&Y\7&Y\7'(O<R(L($M/3$%"7TY%5TQ)
M3D4L("1T97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('5N9F]L9&5D(')E<')E<V5N=&%T:6]N(&]F('1H92!G:79E;B!T97AT+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O
M('5N9F]L9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N
M9F]L9&5D(')E<')E<V5N=&%T:6]N(&]F("1T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!U;F9O;&1497AT*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R
M;B!P<F5G7W)E<&QA8V4H(B]<<EQN6R!<=%TK+R(L("(B+"`D=&5X="D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%P<&QI
M8V%T:6]N+7-P96-I9FEC(&-O;G-T86YT<RP@=&AA="!A<F4@=7-E9"!I;@H@
M("`@("H@82!G96YE<FEC(&UA;FYE<B!T:')O=6=H;W5T('1H92!L:6)R87)Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI
M8V%T:6]N('=H;W-E(&-O;G-T86YT<R!T;R!Q=65R>2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!!;B!A<G)A>2!O9B!A<'!L:6-A=&EO;BUS<&5C
M:69I8R!C;VYS=&%N=',@:68@)&%P<"!I<R!A"B`@("`@*B`@("`@("`@("`@
M("`@("!S=7!P;W)T960@87!P;&EC871I;VXL(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@:68@)&%P<"!I<PH@("`@("H@("`@("`@("`@("`@("`@;F]T('-U
M<'!O<G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T07!P0V]N<W1S*"1A
M<'`I"B`@("!["B`@("`@("`@<W=I=&-H("@D87!P*2!["B`@("`@("`@8V%S
M92`G;6YE;6\G.@H@("`@("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@
M("`@("`@("`G;6EM95]T>7!E7W-U9F9I>"<@("`@("`]/B`G;F]T92<L"B`@
M("`@("`@("`@("`@("`G9&5F875L=%]F;VQD97)?;F%M92<@("`]/B!?*").
M;W1E<R(I+`H@("`@("`@("`@("`@("`@)W-H87)E7VYA;64G("`@("`@("`@
M("`@/3X@7R@B;F]T97!A9"(I+`H@("`@("`@("`@("`@("`@)V1E9F%U;'1?
M<VAA<F5?;F%M92<@("`@/3X@7R@B)7,G<R!.;W1E<&%D(BDL"B`@("`@("`@
M("`@("D["@H@("`@("`@(&-A<V4@)VMR;VYO;&ET:"<Z"B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=M:6UE7W1Y<&5?<W5F
M9FEX)R`@("`@(#T^("=E=F5N="<L"B`@("`@("`@("`@("`@("`G9&5F875L
M=%]F;VQD97)?;F%M92<@("`]/B!?*")#86QE;F1A<B(I+`H@("`@("`@("`@
M("`@("`@)W-H87)E7VYA;64G("`@("`@("`@("`@/3X@7R@B8V%L96YD87(B
M*2P*("`@("`@("`@("`@("`@("=D969A=6QT7W-H87)E7VYA;64G("`@(#T^
M(%\H(B5S)W,@0V%L96YD87(B*2P*("`@("`@("`@("`@*3L*"B`@("`@("`@
M8V%S92`G='5R8F$G.@H@("`@("`@("`@("!R971U<FX@87)R87DH"B`@("`@
M("`@("`@("`@("`G;6EM95]T>7!E7W-U9F9I>"<@("`@("`]/B`G8V]N=&%C
M="<L"B`@("`@("`@("`@("`@("`G9&5F875L=%]F;VQD97)?;F%M92<@("`]
M/B!?*")#;VYT86-T<R(I+`H@("`@("`@("`@("`@("`@)W-H87)E7VYA;64G
M("`@("`@("`@("`@/3X@7R@B861D<F5S<R!B;V]K(BDL"B`@("`@("`@("`@
M("`@("`G9&5F875L=%]S:&%R95]N86UE)R`@("`]/B!?*"(E<R=S($%D9')E
M<W,@0F]O:R(I+`H@("`@("`@("`@("`I.PH*("`@("`@("!C87-E("=N86<G
M.@H@("`@("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("`@("`G
M;6EM95]T>7!E7W-U9F9I>"<@("`@("`]/B`G=&%S:R<L"B`@("`@("`@("`@
M("`@("`G9&5F875L=%]F;VQD97)?;F%M92<@("`]/B!?*")487-K<R(I+`H@
M("`@("`@("`@("`@("`@)W-H87)E7VYA;64G("`@("`@("`@("`@/3X@7R@B
M=&%S:R!L:7-T(BDL"B`@("`@("`@("`@("`@("`G9&5F875L=%]S:&%R95]N
M86UE)R`@("`]/B!?*"(E<R=S(%1A<VML:7-T(BDL"B`@("`@("`@("`@("D[
M"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(I+"`D87!P*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!)
M34%0($%#3"!S=')I;F<@8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV96X@2&]R
M9&4@<&5R;6ES<VEO;G,*("`@("`J('9A;'5E+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1P97)M<R`@5&AE($AO<F1E('!E<FUI<W-I;VYS('9A
M;'5E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]W;F5R("!7:6QL('1H92!!
M0TP@<W1R:6YG(&)E('5S960@9F]R('1H92!F;VQD97(@;W=N97(_"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@:6YC;'5D97,@=&AE("=A
M)R!R:6=H=',@:6X@=&AE($%#3"!S=')I;F<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!)34%0($%#3"!S=')I;F<@8V]R<F5S<&]N9&EN
M9R!T;R`D<&5R;7,@86YD("1O=VYE<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<&5R;7-4;T%#3"@D<&5R;7,L("1O=VYE<B`]('1R=64I"B`@("!["B`@("`@
M("`@)')E<W5L="`]("1O=VYE<B`_("=A)R`Z("<G.PH@("`@("`@(&EF("@D
M<&5R;7,@)B!015)-4U]32$]7*2!["B`@("`@("`@("`@("1R97-U;'0@+CT@
M)VPG.PH@("`@("`@('T*("`@("`@("!I9B`H)'!E<FUS("8@4$5235-?4D5!
M1"D@>PH@("`@("`@("`@("`D<F5S=6QT("X]("=R)SL*("`@("`@("!]"B`@
M("`@("`@:68@*"1P97)M<R`F(%!%4DU37T5$250I('L*("`@("`@("`@("`@
M)')E<W5L="`N/2`G:7-W8R<["B`@("`@("`@?0H@("`@("`@(&EF("@D<&5R
M;7,@)B!015)-4U]$14Q%5$4I('L*("`@("`@("`@("`@)')E<W5L="`N/2`G
M9"<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!(;W)D92!P97)M:7-S:6]N<R!V
M86QU92!C;W)R97-P;VYD:6YG('1O('1H92!G:79E;B!)34%0($%#3`H@("`@
M("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%C;%]S
M=')I;F<@(%1H92!)34%0($%#3"!S=')I;F<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@2&]R9&4@<&5R;6ES<VEO;G,@=F%L=64@8V]R
M<F5S<&]N9&EN9R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`D86-L7W-T
M<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@86-L5&]097)M<R@D86-L7W-T
M<FEN9RD*("`@('L*("`@("`@("`D<F5S=6QT(#T@,#L*"B`@("`@("`@9F]R
M("@D:2`](#`L("1J(#T@<W1R;&5N*"1A8VQ?<W1R:6YG*3L@)&D@/"`D:CL@
M)&DK*RD@>PH@("`@("`@("`@("!S=VET8V@@*"1A8VQ?<W1R:6YG6R1I72D@
M>PH@("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@("`@("`@("1R97-U
M;'0@?#T@4$5235-?4TA/5SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G<B<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT('P]
M(%!%4DU37U)%040["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VDG.@H@("`@("`@("`@("`@("`@)')E<W5L="!\/2!015)-
M4U]%1$E4.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=D)SH*("`@("`@("`@("`@("`@("1R97-U;'0@?#T@4$5235-?1$5,
M151%.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A;B!A<W-O8VEA=&EV92!A<G)A>2!O=70@;V8@
M86X@24U!4"!!0TP@;&ES="!A<R!R971U<FYE9"!B>2!T:&4*("`@("`J($YE
M=%])34%0(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%C
M;"`@5&AE($E-05`@04-,(&%R<F%Y+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T:&4@:V5Y<R!A
M<F4@:6YD:79I9'5A;"!U<V5R<PH@("`@("H@("`@("`@("`@("`@("`@86YD
M('1H92!V86QU97,@=&AE($%#3"!S=')I;F<@9F]R('1H92!S<&5C:69I8R!U
M<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8VQ4;T%R<F%Y*"1A8VPI"B`@
M("!["B`@("`@("`@:68@*&ES7V$H)&%C;"P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&%C;#L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1A8VP@87,@)'5S
M97(I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]G<F]U<#HH+BLI
M+R<L("1U<V5R6R=54T52)UTL("1M871C:&5S*2D@>PH@("`@("`@("`@("`@
M("`@+RH@3&]O:R!U<"!A;F0@97AP86YD(&=R;W5P<RX@*B\*("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*("`@("`@
M("`@("`@("`@("1G<F]U<"`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["B`@("`@
M("`@("`@("`@("`D9VED(#T@)&=R;W5P+3YG971'<F]U<$ED*"1M871C:&5S
M6S%=*3L*("`@("`@("`@("`@("`@("1U<V5R<R`]("1G<F]U<"T^;&ES=%5S
M97)S*"1G:60I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'5S97)S(&%S
M("1U*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L=%LD=5T@/2`D=7-E
M<ELG4DE'2%13)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT6R1U<V5R6R=54T52)UU=
M(#T@)'5S97);)U))1TA44R==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("!F=6YC=&EO;B!G
M9713:&%R94UA<"@I"B`@("!["B`@("`@("`@<F5T=7)N(&5M<'1Y*"1?4T53
M4TE/3EM+3TQ!0E]32$%215]-05!=*0H@("`@("`@("`@/R!A<G)A>2@I"B`@
M("`@("`@("`Z('5N<V5R:6%L:7IE*"1?4T534TE/3EM+3TQ!0E]32$%215]-
M05!=*3L*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%R94UA<"@D<VAA<F5?
M;6%P*0H@("`@>PH@("`@("`@("1?4T534TE/3EM+3TQ!0E]32$%215]-05!=
M(#T@<V5R:6%L:7IE*"1S:&%R95]M87`I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('5P9&%T94UA<'!E9%-H87)E*"8D<VAA<F5?;6%P+"`D<VAA<F5?=6ED+"`D
M:6UA<%]F;VQD97(I"B`@("!["B`@("`@("`@)'-H87)E7VUA<%LD<VAA<F5?
M=6ED72`]("1I;6%P7V9O;&1E<CL*("`@('T*"B`@("!F=6YC=&EO;B!G9713
M:&%R94UA<'!I;F<H)B1S:&%R95]M87`L("1S:&%R95]U:60L("1D;F5?<F5S
M=6QT(#T@)R<I"B`@("!["B`@("`@("`@<F5T=7)N(&5M<'1Y*"1S:&%R95]M
M87!;)'-H87)E7W5I9%TI(#\@)&1N95]R97-U;'0@.B`D<VAA<F5?;6%P6R1S
M:&%R95]U:61=.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V94UA<'!E9%-H
M87)E*"8D<VAA<F5?;6%P+"`D<VAA<F5?=6ED*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D<VAA<F5?;6%P6R1S:&%R95]U:61=*2D@>PH@("`@("`@("`@
M("!U;G-E="@D<VAA<F5?;6%P6R1S:&%R95]U:61=*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3>6YC:')O;FES97,@=&AE(%!E<FUS(&]F
M(&$@2&]R9&4@<VAA<F4@=&\@=&AE($%#3"!O9B!A;B!)34%0(&9O;&1E<BP*
M("`@("`J(&-R96%T:6YG('1H92!F;VQD97(@:68@;F5C97-S87)Y+B!)="!A
M;'-O('-E=',@=&AE(&YE8V5S<V%R>2!A;FYO=&%T:6]N<PH@("`@("H@:6YD
M:6-A=&EN9R!W:&%T(&=R;W5P=V%R92!F;W)M870@='EP92!I<R!C;VYT86EN
M960@=VET:&EN('1H92!F;VQD97(L"B`@("`@*B!A;F0@=VAA="!(;W)D92!S
M:&%R92!I="!C;W)R97-P;VYD<R!T;RX*("`@("`J"B`@("`@*B!`<&%R86T@
M;V)J96-T("1I;6%P("`@02!R969E<F5N8V4@=&\@82!.971?24U!4"!O8FIE
M8W0@=&AA="!I<R!A;')E861Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@8V]N;F5C=&5D(&%N9"!A=71H96YT:6-A=&5D('1O('1H92!C;W)R96-T
M('-E<G9E<BX*("`@("`J($!P87)A;2!O8FIE8W0@)'-H87)E("!!(')E9F5R
M96YC92!T;R!T:&4@2&]R9&4@<VAA<F4@;V)J96-T('1H870@=V4@87)E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6YT97)E<W1E9"!I;BX*("`@
M("`J($!P87)A;2!S=')I;F<@)&%P<%]C;VYS=',@($$@<F5F97)E;F-E('1O
M('1H92!R97-U;'0@;V8@82!G971!<'!#;VYS=',H*0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V%L;"!F;W(@=&AE(&-U<G)E;G0@2&]R
M9&4@87!P;&EC871I;VXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M2&]R9&4O2V]L86(@:6YT96=R871I;VXM<W5P<&]R=&5D(&%P<"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<WEN8VAR;VYI<V53:&%R92@F)&EM87`L("8D<VAA<F4L("8D87!P7V-O
M;G-T<RD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF
M("AE;7!T>2@D<VAA<F4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DEN=F%L:60@<VAA<F4@;V)J96-T(BDI.PH@("`@("`@
M('T*"B`@("`@("`@)'-H87)E7W5I9"`]("1S:&%R92T^9V5T3F%M92@I.PH@
M("`@("`@("1O=VYE<B`]("1S:&%R92T^9V5T*"=O=VYE<B<I.PH@("`@("`@
M("1D969A=6QT(#T@)'-H87)E7W5I9"`]/2`D;W=N97(["@H@("`@("`@("1N
M9'@@/2!S=')P;W,H)&]W;F5R+"`G0"<I.PH@("`@("`@("1U<V5R(#T@)&YD
M>"`]/3T@9F%L<V4@/R`D;W=N97(@.B!S=6)S='(H)&]W;F5R+"`P+"`D;F1X
M*3L*("`@("`@("`D9&]M86EN(#T@<W1R<W1R*"1O=VYE<BP@)T`G*3L*"B`@
M("`@("`@)&9O;&1E<E]T>7!E(#T@)&%P<%]C;VYS='-;)VUI;65?='EP95]S
M=69F:7@G72`N("@D9&5F875L="`_("<N9&5F875L="<@.B`G)RD["B`@("`@
M("`@)&9O;&1E<E]N86UE(#T@(G5S97(O)'5S97(O(B`N("@D9&5F875L="`_
M("1A<'!?8V]N<W1S6R=D969A=6QT7V9O;&1E<E]N86UE)UT@.B`D<VAA<F4M
M/F=E="@G;F%M92<I*2`N("1D;VUA:6X["B`@("`@("`@+R]+;VQA8CHZ96YC
M;V1E26UA<$9O;&1E<DYA;64H)&1E9F%U;'0@/R`D87!P7V-O;G-T<ULG9&5F
M875L=%]F;VQD97)?;F%M92==(#H@)'-H87)E+3YG970H)VYA;64G*2D["B`@
M("`@("`@:68@*&ES7V$H)&9O;&1E<E]N86UE+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D9F]L9&5R7VYA;64["B`@("`@("`@?0H*
M("`@("`@("`D<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P*"D["@H@
M("`@("`@("1O;&1?9F]L9&5R(#T@2V]L86(Z.F=E=%-H87)E36%P<&EN9R@D
M<VAA<F5?;6%P+"`D<VAA<F5?=6ED*3L*"B`@("`@("`@)')E<W5L="`]("1I
M;6%P+3YM86EL8F]X17AI<W0H)&9O;&1E<E]N86UE*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F;VQD97)?
M;F%M92`A/2`D;VQD7V9O;&1E<BD@>PH@("`@("`@("`@("!I9B`H)')E<W5L
M="`F)B`D;VQD7V9O;&1E<BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B*2P@
M)&9O;&1E<E]N86UE+"`D;VQD7V9O;&1E<BDI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H)&]L9%]F;VQD97(I('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D:6UA<"T^<F5N86UE36%I;&)O>"@D;VQD7V9O;&1E<BP@
M)&9O;&1E<E]N86UE*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E:68@*"1R97-U;'0@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@)&EM87`M/F-R96%T94UA:6QB;W@H)&9O;&1E<E]N86UE*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+R\@1W)A;G0@=&AE($-Y<G5S($%D;6EN:7-T<F%T;W(@8W)E871E("8@
M9&5L971E(&%C8V5S<R`H;F5E9&5D"B`@("`@("`@+R\@9F]R('1H92!A9&UI
M;G5S97(@=&\@9&5L971E('1H92!M86EL8F]X('=H96X@<F5M;W9I;F<@<VAA
M<F5S*0H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^<V5T04-,*"1F;VQD97)?
M;F%M92P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UTL("=C
M9"<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("`D86-L(#T@2V]L86(Z.F%C;%1O07)R87DH)&EM87`M/F=E=$%#3"@D
M9F]L9&5R7VYA;64I*3L*("`@("`@("!I9B`H:7-?82@D86-L+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D86-L.PH@("`@("`@('T*
M"B`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@
M("`@("`@)'!E<FU?;&ES="`]("1P97)M+3YG9715<V5R4&5R;6ES<VEO;G,H
M*3L*"B`@("`@("`@9F]R96%C:"`H)'!E<FU?;&ES="!A<R`D=7-E<B`]/B`D
M=7-E<E]P97)M<RD@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)&EM87`M/G-E
M=$%#3"@D9F]L9&5R7VYA;64L("1U<V5R+"!+;VQA8CHZ<&5R;7-4;T%C;"@D
M=7-E<E]P97)M<RP@)'5S97(@/3T@)&]W;F5R*2D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!U;G-E="@D86-L6R1U<V5R72D["B`@("`@("`@?0H*("`@("`@("`O+R!-
M86ME('-U<F4@=V4@9&]N)W0@9&5L971E('1H92!C=7)R96YT('5S97(@;W(@
M=&AE($-Y<G5S"B`@("`@("`@+R\@061M:6YI<W1R871O<B!F<F]M('1H92!F
M;VQD97(G<R!!0TPL(&]R(&5L<V4@=V4G;&P@8F4@;&]C:V5D(&]U=`H@("`@
M("`@('5N<V5T*"1A8VQ;)&]W;F5R72D["B`@("`@("`@=6YS970H)&%C;%LD
M8V]N9ELG:V]L86(G75LG:6UA<"==6R=A9&UI;G5S97(G75TI.PH*("`@("`@
M("!F;W)E86-H("@D86-L(&%S("1U<V5R(#T^("1U<V5R7V%C;"D@>PH@("`@
M("`@("`@("`D<F5S=6QT(#T@)&EM87`M/F1E;&5T94%#3"@D9F]L9&5R7VYA
M;64L("1U<V5R*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D
M:6UA<"T^<V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/5%]&3TQ$15)?5%E012P@
M87)R87DH)W9A;'5E+G-H87)E9"<@/3X@)&9O;&1E<E]T>7!E*2P@)&9O;&1E
M<E]N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YS971!;FYO=&%T:6]N*$M/3$%"
M7T%.3D]47U-(05)%7U5)1"P@87)R87DH)W9A;'5E+G-H87)E9"<@/3X@)'-H
M87)E7W5I9"DL("1F;VQD97)?;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@($MO;&%B.CIU<&1A=&5-87!P9613
M:&%R92@D<VAA<F5?;6%P+"`D<VAA<F5?=6ED+"`D9F]L9&5R7VYA;64I.PH@
M("`@("`@($MO;&%B.CIS9713:&%R94UA<"@D<VAA<F5?;6%P*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@=7!D871E4VAA
M<F4H)B1S:&%R92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D
M;F]T:69I8V%T:6]N.PH*("`@("`@("`D87!P(#T@)')E9VES=')Y+3YG971!
M<'`H*3L*("`@("`@("!I9B`H87)R87E?<V5A<F-H*"1A<'`L(&%R<F%Y*"=M
M;F5M;R<L("=N86<G+"`G='5R8F$G+"`G:W)O;F]L:71H)RDI(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("!I9B`H96UP='DH)%]315-324].6TM/3$%"7TQ!
M4U1?4UE.0TA%1%]!4%!=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A<'`@/2`D7U-%4U-)
M3TY;2T],04)?3$%35%]364Y#2$5$7T%04%T["B`@("`@("`@?0H*("`@("`@
M("`D87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#;VYS=',H)&%P<"D["B`@
M("`@("`@:68@*&ES7V$H)&%P<%]C;VYS=',L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]($MO;&%B.CI?=7!D871E4VAA<F4H)'-H87)E+"`D87!P7V-O
M;G-T<RD["B`@("`@("`@)&ED(#T@)'-H87)E+3YG970H)VYA;64G*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<'!?
M8V]N<W1S6R=S:&%R95]N86UE)UTL("1I9"P@)')E<W5L="T^9V5T365S<V%G
M92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!?=7!D871E4VAA<F4H)B1S
M:&%R92P@)B1A<'!?8V]N<W1S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO;&%B
M)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;
M)W!O<G0G72D["@H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G:6XH)&-O
M;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UTL("1C;VYF6R=K;VQA
M8B==6R=I;6%P)UU;)V%D;6EN<'<G72P@9F%L<V4L(&9A;'-E*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L
M="`]($MO;&%B.CIS>6YC:')O;FES95-H87)E*"1I;6%P+"`D<VAA<F4L("1A
M<'!?8V]N<W1S*3L*"B`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@<F5M
M;W9E4VAA<F4H)B1S:&%R92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y+"`D;F]T:69I8V%T:6]N.PH*("`@("`@("`D87!P(#T@)')E9VES=')Y
M+3YG971!<'`H*3L*"B`@("`@("`@+R\@5V4@;VYL>2!R96UO=F4@<VAA<F5S
M(&EF($MO;&%B(&EN=&5G<F%T:6]N(&ES(&5N86)L960L(&%N9"!I9B!W92=V
M90H@("`@("`@("\O('!R979I;W5S;'D@<WEN8VAR;VYI<V5D('1H92!S:&%R
M97,@;&ES="`H:2YE+B!W92!K;F]W('=H870@24U!4`H@("`@("`@("\O(&9O
M;&1E<B!C;W)R97-P;VYD<R!T;R!T:&4@9VEV96X@<VAA<F4I+@H@("`@("`@
M(&EF("AE;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=E;F%B;&5D
M)UTI('Q\"B`@("`@("`@("`@("@A96UP='DH)%]315-324].6TM/3$%"7TQ!
M4U1?4UE.0TA%1%]!4%!=*2`F)@H@("`@("`@("`@("`@)%]315-324].6TM/
M3$%"7TQ!4U1?4UE.0TA%1%]!4%!=("$]("1A<'`I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1A<'!?8V]N<W1S
M(#T@2V]L86(Z.F=E=$%P<$-O;G-T<R@D87!P*3L*("`@("`@("!I9B`H:7-?
M82@D87!P7V-O;G-T<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@2V]L
M86(Z.E]R96UO=F53:&%R92@D<VAA<F4I.PH@("`@("`@("1I9"`]("1S:&%R
M92T^9V5T*"=N86UE)RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M7"(E<UPB.B`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%P<%]C;VYS='-;)W-H87)E7VYA;64G72P@)&ED+"`D<F5S
M=6QT+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]
M(&5L<V5I9B`H)')E<W5L="`]/3T@=')U92D@>PH@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z(%-U8V-E
M<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%P<%]C;VYS='-;)W-H87)E7VYA
M;64G72P@)&ED*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96UO=F53
M:&%R92@F)'-H87)E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@
M("`@("`@:68@*&5M<'1Y*"1S:&%R92DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!S:&%R92!O8FIE8W0B*2D[
M"B`@("`@("`@?0H*("`@("`@("`D<VAA<F5?=6ED(#T@)'-H87)E+3YG971.
M86UE*"D["@H@("`@("`@("1S:&%R95]M87`@/2!+;VQA8CHZ9V5T4VAA<F5-
M87`H*3L*"B`@("`@("`@)&9O;&1E<B`]($MO;&%B.CIG9713:&%R94UA<'!I
M;F<H)'-H87)E7VUA<"P@)'-H87)E7W5I9"D["B`@("`@("`@:68@*&5M<'1Y
M*"1F;VQD97(I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO;&%B
M)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;
M)W!O<G0G72D["@H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G:6XH)&-O
M;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UTL("1C;VYF6R=K;VQA
M8B==6R=I;6%P)UU;)V%D;6EN<'<G72P@9F%L<V4L(&9A;'-E*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L
M="`]("1I;6%P+3YD96QE=&5-86EL8F]X*"1F;VQD97(I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D:6UA<"T^9&ES
M8V]N;F5C="@I.PH*("`@("`@("!+;VQA8CHZ<F5M;W9E36%P<&5D4VAA<F4H
M)'-H87)E7VUA<"P@)'-H87)E7W5I9"D["@H@("`@("`@($MO;&%B.CIS9713
M:&%R94UA<"@D<VAA<F5?;6%P*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@9G5N8W1I;VX@<WEN8VAR;VYI<V53:&%R97,H)B1S:&%R97,L
M("1A<'`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=C;VYF
M)UU;)VMO;&%B)UU;)V5N86)L960G72D@?'P*("`@("`@("`@("`@87)R87E?
M<V5A<F-H*"1A<'`L(&%R<F%Y*"=M;F5M;R<L("=N86<G+"`G='5R8F$G+"`G
M:W)O;F]L:71H)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("`O+R!4=7)B82!D;V5S;B=T('5S92!S:&%R
M97,L('-O('=E(&IU<W0@8W)E871E(&$@9'5M;7D@<VAA<F4@;&ES="`F"B`@
M("`@("`@+R\@9&5F875L="!S:&%R92!H97)E('1O(&UA:V4@<W5R92!T:&4@
M9F]L;&]W:6YG(&-O9&4@=V]R:W,N"B`@("`@("`@:68@*&5M<'1Y*"1S:&%R
M97,I("8F("1A<'`@/3T@)W1U<F)A)RD@>PH@("`@("`@("`@("`D<VAA<F5S
M(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)&%P<"D["@H@("`@("`@("`@
M("`D87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#;VYS=',H)&%P<"D["@H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<[
M"B`@("`@("`@("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N
M*"D["B`@("`@("`@("`@("1N86UE(#T@)&ED96YT:71Y+3YG971686QU92@G
M9G5L;&YA;64G*3L*("`@("`@("`@("`@:68@*'1R:6TH)&YA;64I(#T]("<G
M*2!["B`@("`@("`@("`@("`@("`D;F%M92`]($%U=&@Z.G)E;6]V94AO;VLH
M075T:#HZ9V5T075T:"@I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<VAA<F4@/2`F)'-H87)E<RT^;F5W4VAA<F4H075T:#HZ9V5T075T:"@I*3L*
M("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"!S<')I;G1F*"1A<'!?
M8V]N<W1S6R=D969A=6QT7W-H87)E7VYA;64G72P@)&YA;64I*3L*("`@("`@
M("`@("`@)'-H87)E<RT^861D4VAA<F4H)'-H87)E*3L*("`@("`@("!]"@H@
M("`@("`@("\O($-H96-K(&EF('=E)W9E(&%L<F5A9'D@<WEN8VAR;VYI<V5D
M('1H92!)34%0(&9O;&1E<B!L:7-T.R!I9B!W92!H879E"B`@("`@("`@+R\@
M=&AE;B!E>&ET(&5A<FQY+B!&;VQD97(@<WEN8VAR;VYI<V%T:6]N(&ES(&1O
M;F4@;VX@87!P;&EC871I;VX*("`@("`@("`O+R!S=&%R='5P("T@=&AI<R!I
M;F-L=61E<R!S=VET8VAI;F<@8F5T=V5E;B!A<'!L:6-A=&EO;G,@87,@=V5L
M;"!A<PH@("`@("`@("\O('5P;VX@:6YI=&EA;"!L;V=I;BX*("`@("`@("!I
M9B`H(65M<'1Y*"1?4T534TE/3EM+3TQ!0E],05-47U-93D-(141?05!072D@
M)B8*("`@("`@("`@("`@)%]315-324].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!
M4%!=(#T]("1A<'`I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@9VQO8F%L("1N;W1I9FEC871I;VX["@H@("`@("`@("1R97-U
M;'0@/2!+;VQA8CHZ7W-Y;F-H4VAA<F5S*"1S:&%R97,I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(I+"`D<F5S=6QT+3YG
M971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3>6YC:')O;FES97,@=&AE($E-05`@9F]L9&5R
M(&QI<W0@86YD('1H92!(;W)D92!S:&%R92!L:7-T+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@82!S=6-C97-S9G5L('-Y;F-H<F]N
M:7-A=&EO;BP@9F%L<V4@=VAE;B!A"B`@("`@*B`@("`@("`@("`@("`@("!S
M>6YC:')O;FES871I;VX@:7,@;F]T(')E<75I<F5D("AI+F4N(&UU;'1I<&QE
M('!A9V4@;&]A9',*("`@("`J("`@("`@("`@("`@("`@(&EN(&$@<VEN9VQE
M(&%P<&QI8V%T:6]N*2P@;W(@82!014%27T5R<F]R(&]B:F5C="!O;@H@("`@
M("H@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-Y;F-H4VAA<F5S*"8D<VAA<F5S*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<F5G:7-T<GDL("1C;VYF.PH*("`@("`@("`D87!P(#T@)')E9VES=')Y
M+3YG971!<'`H*3L*"B`@("`@("`@+R\@3W1H97)W:7-E('=E(&YE960@=&\@
M;6%P('1H92!C=7)R96YT($E-05`@9F]L9&5R(&QI<W0@=&\@=&AE"B`@("`@
M("`@+R\@87!P;&EC871I;VYS('-H87)E(&QI<W0N"@H@("`@("`@("\O($UA
M:V4@<W5R92!T:&ES(&ES(&)E:6YG(&-A;&QE9"!F<F]M(&$@:VYO=VX@87!P
M;&EC871I;VX*("`@("`@("`D87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#
M;VYS=',H)&%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]C;VYS=',L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?8V]N<W1S
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0V]N;F5C="!T;R!T:&4@24U!4"!S
M97)V97(*("`@("`@("`D:6UA<"`](&YE=R!.971?24U!4"@D8V]N9ELG:V]L
M86(G75LG:6UA<"==6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G
M75LG<&]R="==*3L*"B`@("`@("`@+R\@3&]G:6X@=7-I;F<@=&AE(&-U<G)E
M;G0@2&]R9&4@8W)E9&5N=&EA;',*("`@("`@("`D8W5R<F5N=%]U<V5R(#T@
M075T:#HZ9V5T075T:"@I.PH@("`@("`@("1N9'@@/2!S=')P;W,H)&-U<G)E
M;G1?=7-E<BP@)T`G*3L*("`@("`@("`D=7-E<B`]("1N9'@@/3T](&9A;'-E
M(#\@)&-U<G)E;G1?=7-E<B`Z('-U8G-T<B@D8W5R<F5N=%]U<V5R+"`P+"`D
M;F1X*3L*("`@("`@("`D9&]M86EN(#T@<W1R<W1R*"1C=7)R96YT7W5S97(L
M("=`)RD["B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;B@D8W5R<F5N
M=%]U<V5R+"!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I+"!F86QS
M92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`O+R!/8G1A:6X@82!L:7-T(&]F(&%L;"!F;VQD97)S('1H
M92!C=7)R96YT('5S97(@:&%S(&%C8V5S<R!T;PH@("`@("`@("1F;VQD97)?
M;&ES="`]("1I;6%P+3YG971-86EL8F]X97,H*3L*("`@("`@("!I9B`H:7-?
M82@D9F]L9&5R7VQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1F;VQD97)?;&ES=#L*("`@("`@("!]"@H@("`@("`@("\O(%=E
M)W)E(&]N;'D@:6YT97)E<W1E9"!I;B!T:&4@9F]L9&5R<R!O9B!T:&4@<W!E
M8VEF:6,@<F5S;W5R8V4@='EP90H@("`@("`@("\O(&9O<B!T:&4@8W5R<F5N
M="!A<'!L:6-A=&EO;BP@<V\@9FEL=&5R(&]U="!T:&4@<F5S=`H@("`@("`@
M("1L;V-A;%]F;VQD97)S(#T@87)R87DH*3L*("`@("`@("`D<F5M;W1E7V9O
M;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F;VQD97)?;&ES
M="!A<R`D9F]L9&5R*2!["B`@("`@("`@("`@("1A;FYO=&%T:6]N(#T@)&EM
M87`M/F=E=$%N;F]T871I;VXH2T],04)?04Y.3U1?1D],1$527U194$4L("=V
M86QU92YS:&%R960G+"`D9F]L9&5R*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&%N;F]T871I;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D86YN;W1A=&EO;CL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@268@=&AE<F4@:7,@;F\@86YN;W1A=&EO;B!T:&5N('=E('1R96%T
M(&ET(&%S(&$@<W1A;F1A<F0@;6%I;`H@("`@("`@("`@("`O+R!F;VQD97(@
M*&DN92X@=V4@:6=N;W)E(&ET*2X*("`@("`@("`@("`@:68@*&5M<'1Y*"1A
M;FYO=&%T:6]N*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\O($EF('1H92!F;VQD97(@:7,@;V8@
M=&AE(&-O<G)E8W0@='EP92!T:&5N('=E(&%D9"!I="!T;R!O=7(@;&ES=`H@
M("`@("`@("`@("`O+R!O9B!F;VQD97)S('1H870@<VAO=6QD(&-O<G)E<W!O
M;F0@=&\@82!S:&%R92X@2&5R92!W92!G970@86YY"B`@("`@("`@("`@("\O
M(&]T:&5R(&%D9&ET:6]N86P@:6YF;W)M871I;VX@=V4@;6%Y(&YE960L('-U
M8V@@87,@=VAE=&AE<B!T:&4*("`@("`@("`@("`@+R\@9F]L9&5R('=A<R!P
M<F5V:6]U<VQY(&UA<'!E9"!T;R!A('-H87)E+"!I=',@04-,+"!I=',@;W=N
M97(@*&EF"B`@("`@("`@("`@("\O(&ET(&ES(&$@<VAA<F5D(&9O;&1E<BD@
M86YD(&ET<R!D:7-P;&%Y(&YA;64N"B`@("`@("`@("`@("1T>7!E(#T@97AP
M;&]D92@G+B<L("1A;FYO=&%T:6]N*3L*("`@("`@("`@("`@:68@*"1T>7!E
M6S!=(#T]("1A<'!?8V]N<W1S6R=M:6UE7W1Y<&5?<W5F9FEX)UTI('L*("`@
M("`@("`@("`@("`@("1A8VP@/2!+;VQA8CHZ86-L5&]!<G)A>2@D:6UA<"T^
M9V5T04-,*"1F;VQD97(I*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1A
M8VPL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&%C;#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M+R!3:VEP('1H92!#>7)U<R!!9&UI;FES=')A=&]R"B`@("`@("`@("`@("`@
M("!U;G-E="@D86-L6R1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN=7-E
M<B==72D["@H@("`@("`@("`@("`@("`@)'-H87)E7W5I9"`]("1I;6%P+3YG
M971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47U-(05)%7U5)1"P@)W9A;'5E+G-H
M87)E9"<L("1F;VQD97(I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)'-H
M87)E7W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<VAA<F5?=6ED.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@('!R96=?;6%T8V@H(CLH24Y"3UA\=7-E<B\H6UXO72LI*2\H
M6UY`72LI*$`N*BD_.R(L("1F;VQD97(L("1M871C:&5S*3L*"B`@("`@("`@
M("`@("`@("`D9&5F875L="`]("@A96UP='DH)'1Y<&5;,5TI("8F("1T>7!E
M6S%=(#T]("=D969A=6QT)RD["@H@("`@("`@("`@("`@("`@:68@*"1M871C
M:&5S6S%=(#T]("=)3D)/6"<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&1E9F%U;'0I('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L
M=64H)V9U;&QN86UE)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AT
M<FEM*"1N86UE*2`]/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2!!=71H.CIR96UO=F5(;V]K*"1C=7)R96YT7W5S97(I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1N86UE(#T@<W!R:6YT9B@D87!P7V-O;G-T<ULG9&5F875L=%]S:&%R
M95]N86UE)UTL("1N86UE*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M;&1E<B`]("1A<'!?8V]N<W1S6R=D969A=6QT7V9O;&1E<E]N86UE)UT["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64@/2`D9F]L9&5R(#T@2V]L86(Z.F1E8V]D94EM87!&;VQD
M97).86UE*"1M871C:&5S6S-=*3L*("`@("`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@("`@("1F;VQD97(@/2`B=7-E<B\D=7-E<B\D9F]L
M9&5R)&1O;6%I;B(["@H@("`@("`@("`@("`@("`@("`@("1L;V-A;%]F;VQD
M97)S6R1F;VQD97)=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("=S:&%R95]U:60G("`@("`]/B`D<VAA<F5?=6ED+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G86-L)R`@("`@("`@("`@/3X@)&%C;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@)VYA;64G("`@("`@("`@(#T^("1N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@("`@("`@/3X@)&1E9F%U
M;'0L"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5S97)?9&]M86EN(#T@:7-S
M970H)&UA=&-H97-;-%TI(#\@)&UA=&-H97-;-%T@.B`D9&]M86EN.PH@("`@
M("`@("`@("`@("`@("`@("1F;VQD97(@/2!I<W-E="@D;6%T8VAE<ULT72D@
M/R`D9F]L9&5R(#H@)&9O;&1E<B`N("1U<V5R7V1O;6%I;CL*("`@("`@("`@
M("`@("`@("`@("`D;W=N97(@/2`D;6%T8VAE<ULR72`N("1U<V5R7V1O;6%I
M;CL*("`@("`@("`@("`@("`@("`@("!I9B`H)&1E9F%U;'0I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET
M>2YP:'`G.PH@("`@("`@("`@("`@("`@("`@("`@("`D:61E;G1I='D@/2`F
M261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L("1O=VYE<BD["B`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@)&ED96YT:71Y+3YG971686QU92@G
M9G5L;&YA;64G*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'1R:6TH
M)&YA;64I(#T]("<G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92`]($%U=&@Z.G)E;6]V94AO;VLH)&]W;F5R*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]
M('-P<FEN=&8H)&%P<%]C;VYS='-;)V1E9F%U;'1?<VAA<F5?;F%M92==+"`D
M;F%M92D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;64@/2!+;VQA8CHZ9&5C;V1E26UA<$9O;&1E
M<DYA;64H)&UA=&-H97-;,UTI.PH@("`@("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`@("`@)')E;6]T95]F;VQD97)S6R1F;VQD97)=(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=S:&%R95]U:60G("`@
M("`]/B`D<VAA<F5?=6ED+`H@("`@("`@("`@("`@("`@("`@("`@("`G86-L
M)R`@("`@("`@("`@/3X@)&%C;"P*("`@("`@("`@("`@("`@("`@("`@("`@
M)VYA;64G("`@("`@("`@(#T^("1N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5F875L="<@("`@("`@/3X@)&1E9F%U;'0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("=O=VYE<B<@("`@("`@("`]/B`D;W=N97(L"B`@("`@
M("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@5V4@;F]W(&UA<"!T:&4@<F5M
M86EN:6YG(&9O;&1E<B!L:7-T('1O('1H92!C=7)R96YT(&%P<&QI8V%T:6]N
M<PH@("`@("`@("\O('-H87)E(&QI<W0L('1O('-Y;F-H($AO<F1E('=I=&@@
M;W1H97(@2V]L86(@8VQI96YT<R!T:&%T(&UA>2!H879E"B`@("`@("`@+R\@
M<')E=FEO=7-L>2!M;V1I9FEE9"!T:&4@9W)O=7!W87)E(&9O;&1E<G,*"B`@
M("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`D:6UA<"`](&YE
M=R!.971?24U!4"@D8V]N9ELG:V]L86(G75LG:6UA<"==6R=S97)V97(G72P@
M)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<&]R="==*3L*"B`@("`@("`@)')E
M<W5L="`]("1I;6%P+3YL;V=I;B@D8V]N9ELG:V]L86(G75LG:6UA<"==6R=A
M9&UI;G5S97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YP=R==
M+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O+R!43T1/.B!S964@:68@=&AE<F4@:7,@82!M
M;W)E(&%C8W5R871E('=A>2!O9B!L:7-T:6YG(&%L;"!S:&%R97,@=&AA=`H@
M("`@("`@("\O(&%R92!A8V-E<W-I8FQE+"!R96=A<F1L97-S(&]F('=H870@
M<&5R;6ES<VEO;G,@=&AE('5S97(@:&%S("AI+F4N(&EF"B`@("`@("`@+R\@
M=&AE('5S97(@:&%S(&%T(&QE87-T(&]N92!P97)M:7-S:6]N(&QE=F5L('1O
M('1H92!S:&%R92P@=&AE('-H87)E"B`@("`@("`@+R\@<VAO=6QD(&)E(&EN
M(&]N92!O9B!T:&5S92!L:7-T<RDN"B`@("`@("`@)&QO8V%L7W-H87)E<R`]
M("1S:&%R97,M/FQI<W13:&%R97,H)&-U<G)E;G1?=7-E<BP@4$5235-?4TA/
M5RP@)&-U<G)E;G1?=7-E<BD["B`@("`@("`@)&%L;%]S:&%R97,@/2`D<VAA
M<F5S+3YL:7-T4VAA<F5S*"1C=7)R96YT7W5S97(L(%!%4DU37U-(3U<I.PH@
M("`@("`@("1R96UO=&5?<VAA<F5S(#T@87)R87E?9&EF9E]A<W-O8R@D86QL
M7W-H87)E<RP@)&QO8V%L7W-H87)E<RD["B`@("`@("`@2V]L86(Z.G-E=%-H
M87)E36%P*&%R<F%Y*"DI.PH@("`@("`@("1S:&%R95]M87`@/2!A<G)A>2@I
M.PH*("`@("`@("`O+R!.;W<@<WEN8VAR;VYI<V4@=&AE(&9O;&1E<B!L:7-T
M('=I=&@@=&AE('-H87)E(&QI<W0*("`@("`@("!F;W)E86-H("@D;&]C86Q?
M9F]L9&5R<R!A<R`D9F]L9&5R(#T^("1A='1R<RD@>PH@("`@("`@("`@("!I
M9B`H96UP='DH)&%T=')S6R=S:&%R95]U:60G72DI('L*("`@("`@("`@("`@
M("`@("\O($YO('-H87)E(&-O<G)E<W!O;F1S('1O('1H:7,@9F]L9&5R+"!S
M;R!C<F5A=&4@;VYE"B`@("`@("`@("`@("`@("`D=6ED(#T@96UP='DH)&%T
M=')S6R=D969A=6QT)UTI(#\@;60U*&UI8W)O=&EM92@I*2`Z("1C=7)R96YT
M7W5S97(["B`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)'-H87)E<RT^;F5W
M4VAA<F4H)'5I9"D["B`@("`@("`@("`@("`@("`D<VAA<F4M/G-E="@G;F%M
M92<L("1A='1R<ULG;F%M92==*3L*("`@("`@("`@("`@("`@("1S:&%R97,M
M/F%D9%-H87)E*"1S:&%R92D["@H@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1I;6%P+3YS971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47U-(05)%7U5)1"P@
M87)R87DH)W9A;'5E+G-H87)E9"<@/3X@)'5I9"DL("1F;VQD97(I.PH@("`@
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@($MO;&%B.CIU<&1A=&5-87!P
M9613:&%R92@D<VAA<F5?;6%P+"`D=6ED+"`D9F]L9&5R*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O($]T:&5R=VES92!T:&5R
M92!I<R!A('-H87)E(&-O<G)E<W!O;F1I;F<@=&\@=&AI<R!F;VQD97(*("`@
M("`@("`@("`@("`@(&EF("@A)'-H87)E<RT^97AI<W1S*"1A='1R<ULG<VAA
M<F5?=6ED)UTI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@268@:70G<R!N
M;W0@<')E<V5N="!F;W(@=VAA=&5V97(@<F5A<V]N+"!C<F5A=&4@:70*("`@
M("`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)'-H87)E<RT^;F5W4VAA<F4H
M)&%T=')S6R=S:&%R95]U:60G72D["B`@("`@("`@("`@("`@("`@("`@)'-H
M87)E+3YS970H)VYA;64G+"`D871T<G-;)VYA;64G72D["B`@("`@("`@("`@
M("`@("`@("`@)'-H87)E<RT^861D4VAA<F4H)'-H87)E*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@3W1H97)W
M:7-E(&-H96-K('1H870@:70@:7,@;F%M960@8V]R<F5C=&QY"B`@("`@("`@
M("`@("`@("`@("`@)'-H87)E(#T@)B1L;V-A;%]S:&%R97-;)&%T=')S6R=S
M:&%R95]U:60G75T["B`@("`@("`@("`@("`@("`@("`@:68@*"1S:&%R92T^
M9V5T*"=N86UE)RD@(3T@)&%T=')S6R=N86UE)UTI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"`D871T<G-;)VYA;64G
M72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@($MO;&%B.CIU<&1A=&5-87!P9613:&%R92@D<VAA
M<F5?;6%P+"`D871T<G-;)W-H87)E7W5I9"==+"`D9F]L9&5R*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&-U<G)E;G1?=7-E<G,@/2`D<VAA<F4M
M/FQI<W15<V5R<R@I.PH*("`@("`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG
M971097)M:7-S:6]N*"D["B`@("`@("`@("`@("1M=7-T7W-A=F4@/2!F86QS
M93L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R<ULG86-L)UT@87,@)'5S
M97(@/3X@)&%C;"D@>PH@("`@("`@("`@("`@("`@)'!E<FUS(#T@2V]L86(Z
M.F%C;%1O4&5R;7,H)&%C;"D["B`@("`@("`@("`@("`@("!I9B`H)'!E<FUS
M("$]("1'3$]"04Q36R=P97)M<R==+3YG971097)M:7-S:6]N<R@D<&5R;2P@
M)'5S97(I*2!["B`@("`@("`@("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)0
M97)M:7-S:6]N*"1U<V5R+"`D<&5R;7,L(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("`@("`D;75S=%]S879E(#T@=')U93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1N9'@@/2!A<G)A>5]S96%R8V@H)'5S97(L("1C
M=7)R96YT7W5S97)S*3L*("`@("`@("`@("`@("`@(&EF("@D;F1X("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1C=7)R96YT7W5S
M97)S6R1N9'A=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@9F]R96%C:"`H)&-U<G)E;G1?=7-E<G,@87,@)'5S97(I
M('L*("`@("`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG<&5R;7,G72T^9V5T
M4&5R;6ES<VEO;G,H)'!E<FTL("1U<V5R*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S
M97(L(%!%4DU37T%,3"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("1M
M=7-T7W-A=F4@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&UU<W1?<V%V92D@>PH@("`@("`@("`@
M("`@("`@)'-H87)E+3YS971097)M:7-S:6]N*"1P97)M+"!F86QS92D["B`@
M("`@("`@("`@("`@("`D<VAA<F4M/G-A=F4H*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D871T<G-;)W-H87)E7W5I9"==*2D@
M>PH@("`@("`@("`@("`@("`@=6YS970H)&QO8V%L7W-H87)E<ULD871T<G-;
M)W-H87)E7W5I9"==72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@=6YS970H)&QO8V%L7W-H87)E<ULD8W5R<F5N=%]U<V5R72D["@H@("`@
M("`@("\O(%5P9&%T92!S:&%R97,@=&AA="!A<F4@;F]T(&]W;F5D(&)Y('1H
M92!C=7)R96YT('5S97(@*&]N;'D@:68@=&AE<F4*("`@("`@("`O+R!A<F4@
M<VAA<F5D(&9O;&1E<G,@86-C97-S:6)L92!T;R!T:&4@8W5R<F5N="!U<V5R
M*0H@("`@("`@(&EF("@A96UP='DH)')E;6]T95]F;VQD97)S*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D<F5M;W1E7V9O;&1E<G,@87,@)&9O;&1E<B`]
M/B`D871T<G,I('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D871T<G-;
M)W-H87)E7W5I9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1U:60@/2!E
M;7!T>2@D871T<G-;)V1E9F%U;'0G72D@/R!M9#4H;6EC<F]T:6UE*"DI(#H@
M)&%T=')S6R=O=VYE<B==.PH@("`@("`@("`@("`@("`@("`@("1S:&%R92`]
M("8D<VAA<F5S+3YN97=3:&%R92@D=6ED*3L*("`@("`@("`@("`@("`@("`@
M("`D<VAA<F4M/G-E="@G;W=N97(G+"`D871T<G-;)V]W;F5R)UTI.PH@("`@
M("`@("`@("`@("`@("`@("1S:&%R92T^<V5T*"=N86UE)RP@)&%T=')S6R=N
M86UE)UTI.PH@("`@("`@("`@("`@("`@("`@("1S:&%R97,M/F%D9%-H87)E
M*"1S:&%R92D["@H@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2`D:6UA
M<"T^<V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/5%]32$%215]5240L(&%R<F%Y
M*"=V86QU92YS:&%R960G(#T^("1U:60I+"`D9F]L9&5R*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@2V]L86(Z
M.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R95]M87`L("1U:60L("1F;VQD97(I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(21S:&%R97,M/F5X:7-T<R@D871T<G-;)W-H87)E7W5I9"==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)'-H87)E<RT^
M;F5W4VAA<F4H)&%T=')S6R=S:&%R95]U:60G72D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1S:&%R92T^<V5T*"=O=VYE<B<L("1A='1R<ULG;W=N97(G
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("1S:&%R92T^<V5T*"=N86UE
M)RP@)&%T=')S6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<VAA<F5S+3YA9&13:&%R92@D<VAA<F4I.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(%1H92!S:&%R
M92!E>&ES=',@9VQO8F%L;'DL(&)U="!M87D@;F]T('EE="!B92!L:7-T960*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1R96UO=&5?<VAA
M<F5S6R1A='1R<ULG<VAA<F5?=6ED)UU=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1A='1R
M<ULG<VAA<F5?=6ED)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1R
M96UO=&5?<VAA<F5S6R1A='1R<ULG<VAA<F5?=6ED)UU=.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M<VAA<F4M/F=E="@G;F%M92<I("$]("1A='1R<ULG;F%M92==*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<VAA<F4M/G-E="@G;F%M92<L("1A
M='1R<ULG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@2V]L86(Z
M.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R95]M87`L("1A='1R<ULG<VAA<F5?
M=6ED)UTL("1F;VQD97(I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1C=7)R96YT7W5S97)S(#T@)'-H87)E+3YL:7-T57-E<G,H*3L*
M"B`@("`@("`@("`@("`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I
M;VXH*3L*("`@("`@("`@("`@("`@("1M=7-T7W-A=F4@/2!F86QS93L*"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D871T<G-;)V%C;"==(&%S("1U<V5R
M(#T^("1A8VPI('L*("`@("`@("`@("`@("`@("`@("`D<&5R;7,@/2!+;VQA
M8CHZ86-L5&]097)M<R@D86-L*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'!E<FUS("$]("1'3$]"04Q36R=P97)M<R==+3YG971097)M:7-S:6]N<R@D
M<&5R;2P@)'5S97(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P97)M
M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@)'!E<FUS+"!F86QS92D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1M=7-T7W-A=F4@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;F1X(#T@
M87)R87E?<V5A<F-H*"1U<V5R+"`D8W5R<F5N=%]U<V5R<RD["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1N9'@@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1C=7)R96YT7W5S97)S6R1N9'A=*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&-U<G)E;G1?=7-E<G,@87,@)'5S97(I('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)$=,3T)!3%-;)W!E<FUS)UTM/F=E
M=%!E<FUI<W-I;VYS*"1P97)M+"`D=7-E<BD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO
M;B@D=7-E<BP@4$5235-?04Q,+"!F86QS92D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1M=7-T7W-A=F4@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)&UU
M<W1?<V%V92D@>PH@("`@("`@("`@("`@("`@("`@("1S:&%R92T^<V5T4&5R
M;6ES<VEO;B@D<&5R;2P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("1S
M:&%R92T^<V%V92@I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)&%T=')S6R=S:&%R95]U:60G72DI('L*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D<F5M;W1E7W-H87)E<ULD871T<G-;)W-H
M87)E7W5I9"==72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\O($9I;F%L;'DL(')E;6]V92!A;GD@97AT
M<F$@<VAA<F5S('=E(&UA>2!H879E("AT:&5S92!W97)E(&]N8V4@9F]L9&5R
M<PH@("`@("`@("\O('1H870@=V5R92!S=6)S97%U96YT;'D@9&5L971E9"!B
M>2!A;F]T:&5R($MO;&%B(&-L:65N="DN(%1H:7,@:7,@;VYL>0H@("`@("`@
M("\O(&1O;F4@9F]R('-H87)E<R!T:&%T('1H92!C=7)R96YT('5S97(@;W=N
M<RP@:2YE+B!S:&%R97,@=&AA="!W97)E"B`@("`@("`@+R\@<W5B9F]L9&5R
M<R!O9B!T:&4@8W5R<F5N="!U<V5R<R<@24Y"3U@N"B`@("`@("`@9F]R96%C
M:"`H)&QO8V%L7W-H87)E<R!A<R`D<VAA<F4I('L*("`@("`@("`@("`@)')E
M<W5L="`]("1S:&%R97,M/G)E;6]V95-H87)E*"1S:&%R92D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!&;W(@<F5M;W1E('-H87)E<RP@=V4@<VEM<&QY
M(')E;6]V92!T:&4@8W5R<F5N="!U<V5R(&9R;VT@=&AE('-H87)E<PH@("`@
M("`@("\O('!E<FUI<W-I;VYS(&QI<W0N"B`@("`@("`@9F]R96%C:"`H)')E
M;6]T95]S:&%R97,@87,@)'5I9"`]/B`D<VAA<F4I('L*("`@("`@("`@("`@
M)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@("`@("`@("`@
M("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D8W5R<F5N=%]U<V5R+"!0
M15)-4U]!3$PL(&9A;'-E*3L*("`@("`@("`@("`@)'-H87)E+3YS971097)M
M:7-S:6]N*"1P97)M+"!F86QS92D["B`@("`@("`@("`@("1S:&%R92T^<V%V
M92@I.PH@("`@("`@('T*"B`@("`@("`@+R\@06YD('=E)W)E(&1O;F4A($1I
M<V-O;FYE8W0@9G)O;2!)34%0+"!S970@=&AE(&QA<W0@<WEN8V@G960@87!P
M"B`@("`@("`@+R\@9FQA9R!T;R!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;BP@
M86YD('5P9&%T92!T:&4@<VAA<F4@;6%P+@H@("`@("`@("1I;6%P+3YD:7-C
M;VYN96-T*"D["@H@("`@("`@("1?4T534TE/3EM+3TQ!0E],05-47U-93D-(
M141?05!072`]("1A<'`["B`@("`@("`@2V]L86(Z.G-E=%-H87)E36%P*"1S
M:&%R95]M87`I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&=R;W5P=V%R92!T>7!E(&]F('1H92!G
M:79E;B!)34%0(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T
M("1M86EL8F]X("!4:&4@;6%I;&)O>"!O9B!I;G1E<F5S="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!!('-T<FEN9R!I;F1I8V%T:6YG('1H92!G
M<F]U<'=A<F4@='EP92!O9B`D;6%I;&)O>"!O<@H@("`@("H@("`@("`@("`@
M("`@("`@8F]O;&5A;B`B9F%L<V4B(&]N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971-86EL8F]X5'EP92@D;6%I;&)O>"D*("`@('L*("`@("`@
M("!G;&]B86P@)&-O;F8["@H@("`@("`@("1T>7!E(#T@9F%L<V4["@H@("`@
M("`@("\O($-O;FYE8W0@=&\@=&AE($E-05`@<V5R=F5R"B`@("`@("`@)&EM
M87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<V5R
M=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W!O<G0G72D["@H@("`@
M("`@("\O($QO9VEN('5S:6YG('1H92!C=7)R96YT($AO<F1E(&-R961E;G1I
M86QS"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;BA!=71H.CIG971!
M=71H*"DL($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RDL(&9A;'-E
M+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G56YA8FQE
M('1O(&%U=&AE;G1I8V%T92!W:71H('1H92!+;VQA8B!)34%0('-E<G9E<B<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@<F5T=7)N("1T
M>7!E.PH@("`@("`@('T*"B`@("`@("`@+R\@3V)T86EN('1H92!G<F]U<'=A
M<F4@86YN;W1A=&EO;B!O9B`D;6%I;&)O>`H@("`@("`@("1A;FYO=&%T:6]N
M(#T@)&EM87`M/F=E=$%N;F]T871I;VXH2T],04)?04Y.3U1?1D],1$527U19
M4$4L("=V86QU92YS:&%R960G+"`D;6%I;&)O>"D["B`@("`@("`@:68@*"%I
M<U]A*"1A;FYO=&%T:6]N+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T>2@D86YN
M;W1A=&EO;BDI('L*("`@("`@("`@("`@)'1Y<&4@/2!E>'!L;V1E*"<N)RP@
M)&%N;F]T871I;VXI.PH@("`@("`@("`@("!I9B`H*"%E;7!T>2@D='EP95LQ
M72D@)B8@)'1Y<&5;,5T@/3T@)V1E9F%U;'0G*2!\?"`H96UP='DH)'1Y<&5;
M,5TI*2D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D='EP95LP73L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&EM87`M/F1I<V-O;FYE
M8W0H*3L*"B`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@;&ES="!O9B!A;&P@24U!4"!F;VQD97)S("AI;F-L
M=61I;F<@=&AE:7(@9W)O=7!W87)E('1Y<&4I('1H870*("`@("`J('1H92!C
M=7)R96YT('5S97(@:&%S(&%C8V-E<W,@=&\N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@06X@87)R87D@;V8@87)R87DH)&9O;&1E<FYA;64L("1F
M;VQD97)T>7!E*2!I=&5M<R`H96UP='D*("`@("`J("`@("`@("`@("`@("`@
M(&]N(&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<G,H
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&9O;&1E
M<G,@/2!A<G)A>2@I.PH*("`@("`@("`O+R!#;VYN96-T('1O('1H92!)34%0
M('-E<G9E<@H@("`@("`@("1I;6%P(#T@;F5W($YE=%])34%0*"1C;VYF6R=K
M;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG:6UA
M<"==6R=P;W)T)UTI.PH*("`@("`@("`O+R!,;V=I;B!U<VEN9R!T:&4@8W5R
M<F5N="!(;W)D92!C<F5D96YT:6%L<PH@("`@("`@("1R97-U;'0@/2`D:6UA
M<"T^;&]G:6XH075T:#HZ9V5T075T:"@I+"!!=71H.CIG971#<F5D96YT:6%L
M*"=P87-S=V]R9"<I+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U5N86)L92!T;R!A=71H96YT:6-A=&4@=VET:"!T:&4@
M2V]L86(@24U!4"!S97)V97(G+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D["B`@
M("`@("`@("`@(')E='5R;B`D9F]L9&5R<SL*("`@("`@("!]"@H@("`@("`@
M("\O($]B=&%I;B!A(&QI<W0@;V8@86QL(&9O;&1E<G,@=&AE(&-U<G)E;G0@
M=7-E<B!H87,@86-C97-S('1O"B`@("`@("`@)&9O;&1E<E]L:7-T(#T@)&EM
M87`M/F=E=$UA:6QB;WAE<R@I.PH@("`@("`@(&EF("AI<U]A*"1F;VQD97)?
M;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G56YA8FQE('1O(&]B=&%I;B!)34%0(&9O;&1E<B!L:7-T)RP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("`D:6UA<"T^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("!R971U<FX@)&9O
M;&1E<G,["B`@("`@("`@?0H*("`@("`@("`O+R!)=&5R871E(&]V97(@86QL
M('1H92!F;VQD97)S(&]B=&%I;FEN9R!T:&5I<B!G<F]U<'=A<F4@='EP97,*
M("`@("`@("!F;W)E86-H("@D9F]L9&5R7VQI<W0@87,@)&9O;&1E<BD@>PH@
M("`@("`@("`@("`D9F]L9&5R='EP92`]("=M86EL)SL*"B`@("`@("`@("`@
M("1A;FYO=&%T:6]N(#T@)&EM87`M/F=E=$%N;F]T871I;VXH2T],04)?04Y.
M3U1?1D],1$527U194$4L("=V86QU92YS:&%R960G+"`D9F]L9&5R*3L*("`@
M("`@("`@("`@:68@*"%I<U]A*"1A;FYO=&%T:6]N+"`G4$5!4E]%<G)O<B<I
M("8F("%E;7!T>2@D86YN;W1A=&EO;BDI('L*("`@("`@("`@("`@("`@("1T
M>7!E(#T@97AP;&]D92@G+B<L("1A;FYO=&%T:6]N*3L*("`@("`@("`@("`@
M("`@(&EF("@H(65M<'1Y*"1T>7!E6S%=*2`F)B`D='EP95LQ72`]/2`G9&5F
M875L="<I('Q\("AE;7!T>2@D='EP95LQ72DI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&9O;&1E<G1Y<&4@/2`D='EP95LP73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9O;&1E<G-;72`](&%R
M<F%Y*"1F;VQD97(L("1F;VQD97)T>7!E*3L*("`@("`@("!]"@H@("`@("`@
M("1I;6%P+3YD:7-C;VYN96-T*"D["@H@("`@("`@(')E='5R;B`D9F]L9&5R
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1R:6=G97)S('1H92!F<F5E8G5S
M>2!U<&1A=&4@9F]R('1H92!G:79E;B!S:&%R92!U:60N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N(%1R=64@:68@=7!D871E('=A<R!S=6-C97-S
M9G5L;"P@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!T
M<FEG9V5R1G)E94)U<WE5<&1A=&4H)'-H87)E7W5I9"D*("`@('L*("`@("`@
M("`D<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P*"D["B`@("`@("`@
M:68@*&5M<'1Y*"1S:&%R95]M87!;)'-H87)E7W5I9%TI*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1F;VQD97)?
M<&%T:"`]("1S:&%R95]M87!;)'-H87)E7W5I9%T["@H@("`@("`@("\O($E-
M05`@<&%T:"!I<R!E:71H97(@+TE.0D]8+SQP871H/D!D;VUA:6X@;W(@+W5S
M97(O<V]M96]N92\\<&%T:#Y`9&]M86EN"B`@("`@("`@+R\@<W1R:7`@9&]M
M86EN"B`@("`@("`@)&5N9"`]('-T<G)P;W,H)&9O;&1E<E]P871H+"`G0"<I
M.PH@("`@("`@("1F;VQD97(@/2!S=6)S='(H)&9O;&1E<E]P871H+"`P+"`D
M96YD*3L*"B`@("`@("`@:68@*"$D9F]L9&5R6S!=(#T]("<O)RD@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1S96-O
M;F1?<VQA<V@@/2!S=')P;W,H)&9O;&1E<BP@)R\G+"`Q*3L*("`@("`@("!I
M9B`H)'-E8V]N9%]S;&%S:"`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T<FYC;7`H)&9O
M;&1E<BP@)R])3D)/6"\G+"`W*2`]/2`P*2!["B`@("`@("`@("`@("1F;VQD
M97(@/2!!=71H.CIG971!=71H*"DN<W5B<W1R*"1F;VQD97(L("1S96-O;F1?
M<VQA<V@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F;VQD97(@
M/2!S=6)S='(H)&9O;&1E<BP@)'-E8V]N9%]S;&%S:"`K(#$I.PH@("`@("`@
M('T*("`@("`@("`D=7)L(#T@)VAT='!S.B\O)R`N("1'3$]"04Q36R=C;VYF
M)UU;)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UT@+B`G+V9R965B=7-Y+W1R
M:6=G97(O)R`N("1F;VQD97(@+B`G+G!F8B<["@H@("`@("`@("\O(&YO=R!S
M=&%R="!T:&4@<F5Q=65S=`H@("`@("`@(')E<75I<F5?;VYC92`G2%144"]2
M97%U97-T+G!H<"<["B`@("`@("`@)&AT='`@/2!N97<@2%144%]297%U97-T
M*"1U<FPL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=M971H;V0G(#T^("='150G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=&EM96]U="<@/3X@-2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V%L;&]W4F5D:7)E8W1S)R`]/B!T
M<G5E*2D["B`@("`@("`@)&AT='`M/G-E=$)A<VEC075T:"A!=71H.CIG971!
M=71H*"DL($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RDI.PH*("`@
M("`@("!`)&AT='`M/G-E;F1297%U97-T*"D["B`@("`@("`@:68@*"1H='1P
M+3YG971297-P;VYS94-O9&4H*2`A/2`R,#`I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@=')I
M9V=E<B!F<F5E+V)U<WD@=7!D871E(&9O<B`E<R(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D96UA:6PI*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T1A=&%4<F5E+G!H<```````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#$T,S4T,``Q,#4Q-30S,3`V,0`P,C`T,C4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"B\J*@H@*B!,:7-T
M(&5V97)Y(&]B:F5C="!I;B!A;B!A<G)A>2P@<VEM:6QA<B!T;R!014%2+VAT
M;6PO;65N=2YP:'`N"B`J+PID969I;F4H)T1!5$%44D5%7T9/4DU!5%]44D5%
M)RP@,2D["@HO*BH*("H@1V5T(&$@9G5L;"!L:7-T("T@86X@87)R87D@;V8@
M:V5Y<RX*("HO"F1E9FEN92@G1$%40512145?1D]234%47T9,050G+"`R*3L*
M"B\J*@H@*B!4:&4@<F]O="!E;&5M96YT("AT;W`M;&5V96P@<&%R96YT*2!O
M9B!E86-H($1A=&%4<F5E(&=R;W5P+@H@*B\*9&5F:6YE*"=$051!5%)%15]2
M3T]4)RP@+3$I.PH*+RHJ"B`J($)U:6QD(&$@;F]R;6%L('-E;&5C="!Q=65R
M>2X*("HO"F1E9FEN92@G1$%40512145?0E5)3$1?4T5,14-4)RP@,"D["@HO
M*BH*("H@0G5I;&0@82!C;W5N="!O;FQY('%U97)Y+@H@*B\*9&5F:6YE*"=$
M051!5%)%15]"54E,1%]#3U5.5"<L(#$I.PH*+RHJ"B`J(%1H92!$871A5')E
M93HZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&%B<W1R86-T960@:6YT97)F
M86-E(&EN=&\@=&AE"B`J('9A<FEO=7,@8F%C:V5N9',@9F]R('1H92!(;W)D
M92!$871A5')E92!S>7-T96TN"B`J"B`J($$@<&EE8V4@;V8@9&%T82!I<R!J
M=7-T(&$@=&ET;&4@=&AA="!I<R!S879E9"!I;B!T:&4@<&%G92!F;W(@=&AE
M(&YU;&P*("H@9')I=F5R(&]R(&-A;B!B92!S879E9"!I;B!A(&1A=&%B87-E
M('1O(&)E(&%C8V5S<V5D(&9R;VT@979E<GEW:&5R92X@179E<GD*("H@<W1O
M<F5D(&]B:F5C="!M=7-T(&AA=F4@82!D:69F97)E;G0@;F%M92`H:6YS:61E
M(&5A8V@@9W)O=7!I9"DN"B`J"B`J(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A
M<F%M<SH\<')E/@H@*B`@("=G<F]U<"<@+2T@1&5F:6YE(&5A8V@@9W)O=7`@
M;V8@;V)J96-T<R!W92!W86YT('1O(&)U:6QD+CPO<')E/@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`L=B`Q+C$U,2XR
M+C$X(#(P,#8O,#<O,3,@,#@Z-3@Z-#0@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#,@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O
M;W0N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M/@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7T1A=&%4<F5E
M"B`J+PIC;&%S<R!$871A5')E92!["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!O
M9B!A;&P@9&%T83H@:6YD97AE9"!B>2!I9"X@5&AE(&9O<FUA="!I<SH@87)R
M87DH:60@/3X*("`@("`J("=N86UE)R`]/B!N86UE+"`G<&%R96YT)R`]/B!P
M87)E;G0I+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?9&%T82`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!(&AA<V@@
M=&AA="!C86X@8F4@=7-E9"!T;R!M87`@82!F=6QL(&]B:F5C="!N86UE"B`@
M("`@*B`H<&%R96YT.F-H:6QD.F]B:F5C="D@=&\@=&AA="!O8FIE8W0G<R!U
M;FEQ=64@240N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]N86UE36%P(#T@87)R87DH*3L*"B`@("`@+RHJ"B`@("`@*B!!
M8W1U86P@871T<FEB=71E('-O<G1I;F<@:&%S:"X*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-O<G1(87-H(#T@;G5L;#L*
M"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I
M;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N
M('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(%=E(&%L=V%Y<R!N965D("=G<F]U<"<L(&$@
M<W1R:6YG('1H870@9&5F:6YE<R!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!P<F5F:7@@9F]R(&5A8V@@<V5T(&]F(&AI97)A<F-H:6-A;"!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!$871A5')E92@D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<&%R86UE=&5R(&]F
M('1H:7,@1&%T851R964@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%R86T@(%1H92!P87)A;65T97(@=&\@<F5T=7)N+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!P87)A;65T97(G<R!V86QU
M92!O<B!N=6QL(&EF(&ET(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!A<F%M*"1P87)A;2D*("`@('L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]P87)A;7-;)'!A<F%M72D@/R`D=&AI<RT^7W!A<F%M
M<ULD<&%R86U=(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V
M97,@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]B
M:F5C="`@5&AE(&]B:F5C="!T;R!R96UO=F4N"B`@("`@*B!`<&%R86T@)&9O
M<F-E("`@("`@("`@($9O<F-E(')E;6]V86P@;V8@979E<GD@8VAI;&0@;V)J
M96-T/PH@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F4H)&]B:F5C="P@)&9O
M<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&]B:F5C="P@
M)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@)&]B:F5C="`]("1O
M8FIE8W0M/F=E=$YA;64H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H
M:7,M/F5X:7-T<R@D;V)J96-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@D;V)J96-T("X@)R!D;V5S(&YO="!E>&ES="<I.PH@
M("`@("`@('T*"B`@("`@("`@)&-H:6QD<F5N(#T@)'1H:7,M/F=E=$YU;6)E
M<D]F0VAI;&1R96XH)&]B:F5C="D["B`@("`@("`@:68@*"1C:&EL9')E;BD@
M>PH@("`@("`@("`@("`O*B!43T1/.B!R96UO=F4@8VAI;&1R96X@:68@)&9O
M<F-E(#T]('1R=64@*B\*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="XB*2P@8V]U;G0H)&-H:6QD<F5N*2DI.PH@("`@("`@('T*"B`@("`@
M("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1O8FIE8W0I.PH@("`@("`@("1P:60@
M/2`D=&AI<RT^9V5T4&%R96YT*"1O8FIE8W0I.PH@("`@("`@("1O<F1E<B`]
M("1T:&ES+3Y?9&%T85LD:61=6R=O<F1E<B==.PH@("`@("`@('5N<V5T*"1T
M:&ES+3Y?9&%T85LD:61=*3L*("`@("`@("!U;G-E="@D=&AI<RT^7VYA;65-
M87!;)&ED72D["@H@("`@("`@("\O(%-H:69T(&1O=VX@=&AE(&]R9&5R('!O
M<VET:6]N<RX*("`@("`@("`D=&AI<RT^7W)E;W)D97(H)'!I9"P@)&]R9&5R
M*3L*"B`@("`@("`@<F5T=7)N("1I9#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V97,@86QL($1A=&%4<F5E(&]B:F5C=',@;W=N960@8GD@82!C97)T
M86EN('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@
M02!U<V5R(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97)$
M871A*"1U<V5R*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=N;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-
M;W9E(&%N(&]B:F5C="!T;R!A(&YE=R!P87)E;G0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1O8FIE8W0@("`@("!4:&4@;V)J96-T('1O(&UO=F4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P87)E;G0@(%1H92!N97<@<&%R
M96YT(&]B:F5C="X@1&5F875L=',@=&\@=&AE(')O;W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&UO=F4H)&]B:F5C="P@)&YE=W!A<F5N="`](&YU;&PI"B`@
M("!["B`@("`@("`@)&-I9"`]("1T:&ES+3YG971)9"@D;V)J96-T*3L*("`@
M("`@("!I9B`H:7-?82@D8VED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H)T]B:F5C="!T
M;R!M;W9E(&1O97,@;F]T(&5X:7-T.B`E<R<L("1C:60M/F=E=$UE<W-A9V4H
M*2DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1N97=P87)E
M;G0I*2!["B`@("`@("`@("`@("1P:60@/2`D=&AI<RT^9V5T260H)&YE=W!A
M<F5N="D["B`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H)TYE=R!P87)E;G0@9&]E<R!N;W0@97AI<W0Z("5S)RP@)'!I
M9"T^9V5T365S<V%G92@I*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<&ED(#T@1$%40512145?4D]/5#L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?9&%T85LD8VED75LG<&%R96YT)UT@/2`D
M<&ED.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H86YG92!A;B!O8FIE8W0G<R!N86UE+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`@)&]L9%]O8FIE8W0@("`@("`@5&AE(&]L9"!O8FIE8W0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=?;V)J96-T7VYA;64@(%1H92!N
M97<@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D
M;VQD7V]B:F5C="P@)&YE=U]O8FIE8W1?;F%M92D*("`@('L*("`@("`@("`O
M*B!#:&5C:R!W:&5T:&5R('1H92!O8FIE8W0@97AI<W1S(&%T(&%L;"`J+PH@
M("`@("`@(&EF("@A)'1H:7,M/F5X:7-T<R@D;VQD7V]B:F5C="DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&]L9%]O8FIE8W0@
M+B`G(&1O97,@;F]T(&5X:7-T)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#
M:&5C:R!F;W(@9'5P;&EC871E<R`M(&=E="!P87)E;G0@86YD(&-R96%T92!N
M97<@;V)J96-T"B`@("`@("`@("H@;F%M92`J+PH@("`@("`@("1P87)E;G0@
M/2`D=&AI<RT^9V5T3F%M92@D=&AI<RT^9V5T4&%R96YT*"1O;&1?;V)J96-T
M*2D["B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)'!A<F5N="`N("<Z)R`N
M("1N97=?;V)J96-T7VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=$=7!L:6-A=&4@;F%M92`G("X@)&YE=U]O8FIE8W1?
M;F%M92D["B`@("`@("`@?0H*("`@("`@("`O*B!297!L86-E('1H92!O;&0@
M;F%M92!W:71H('1H92!N97<@;VYE(&EN('1H92!C86-H92`J+PH@("`@("`@
M("1O;&1?;V)J96-T7VED(#T@)'1H:7,M/F=E=$ED*"1O;&1?;V)J96-T*3L*
M("`@("`@("`D=&AI<RT^7V1A=&%;)&]L9%]O8FIE8W1?:61=6R=N86UE)UT@
M/2`D;F5W7V]B:F5C=%]N86UE.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H86YG97,@=&AE(&]R9&5R(&]F('1H92!C
M:&EL9')E;B!O9B!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%R96YT("!4:&4@9G5L;"!I9"!P871H(&]F('1H92!P87)E;G0@
M;V)J96-T+@H@("`@("H@0'!A<F%M(&UI>&5D("1O<F1E<B`@("!)9B!A;B!A
M<G)A>2!I="!S<&5C:69I97,@=&AE(&YE=R!P;W-I=&EO;G,@9F]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&%L;"!C:&EL9"!O8FIE8W1S+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!)9B!A;B!I;G1E9V5R(&%N
M9"`D8VED(&ES('-P96-I9FEE9"P@=&AE('!O<VET:6]N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('=H97)E('1H92!C:&EL9"!S<&5C:69I960@
M8GD@)&-I9"!I<R!I;G-E<G1E9"X@268*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@)&-I9"!I<R!N;W0@<W!E8VEF:65D+"!T:&4@<&]S:71I;VX@
M9V5T<R!D96QE=&5D+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C
M875S:6YG('1H92!F;VQL;W=I;F<@<&]S:71I;VYS('1O('-H:69T('5P+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@("!3964@)&]R9&5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96]R9&5R*"1P87)E;G1S+"`D;W)D97(@/2!N
M=6QL+"`D8VED(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VAA;F=E(&]R9&5R(&]F(&-H:6QD<F5N(&]F(&%N(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P:60@("`@(%1H92!P87)E
M;G0@;V)J96-T(&ED('-T<FEN9R!P871H+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1O<F1E<B`@("!3<&5C:69I8R!N97<@;W)D97(@<&]S:71I;VX@;W(@86X@
M87)R87D@8V]N=&%I;FEN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@;F5W('!O<VET:6]N<R!F;W(@=&AE(&=I=F5N('!A<F5N="X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C:60@("`@268@<')O=FED960@:6YD:6-A
M=&5S(&EN<V5R=&EO;B!O9B!A(&YE=R!C:&EL9"!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@<&%R96YT('1O(&%V;VED(&EN8W)E;65N
M=&EN9R!I="!W:&5N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('-H
M:69T:6YG('5P(&%L;"!O=&AE<B!C:&EL9')E;B=S(&]R9&5R+B!)9B!N;W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<')O=FED960@:6YD:6-A
M=&5S(&1E;&5T:6]N+"!S;R!S:&EF="!A;&P@;W1H97(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@<&]S:71I;VYS(&1O=VX@;VYE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<F5O<F1E<B@D<&ED+"`D;W)D97(@/2!N=6QL+"`D
M8VED(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O<F1E
M<BD@)B8@(6ES7VYU;&PH)&]R9&5R*2D@>PH@("`@("`@("`@("`O+R!3:6YG
M;&4@=7!D871E("AA9&0O9&5L*2X*("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)&-I9"DI('L*("`@("`@("`@("`@("`@("\O($YO(&ED(&=I=F5N('-O('-H
M=69F;&4@9&]W;BX*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M9&%T82!A<R`D8U]K97D@/3X@)&-?=F%L*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?9&%T85LD8U]K97E=6R=P87)E;G0G72`]/2`D<&ED
M"B`@("`@("`@("`@("`@("`@("`@("`@("8F("1T:&ES+3Y?9&%T85LD8U]K
M97E=6R=O<F1E<B==(#X@)&]R9&5R*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&%T85LD8U]K97E=6R=O<F1E<B==+2T["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@5V4@:&%V92!A;B!I9"!S;R!S
M:'5F9FQE('5P+@H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]D
M871A(&%S("1C7VME>2`]/B`D8U]V86PI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-?:V5Y("$]("1C:60@("8F("1T:&ES+3Y?9&%T85LD8U]K97E=
M6R=P87)E;G0G72`]/2`D<&ED"B`@("`@("`@("`@("`@("`@("`@("`@("8F
M("1T:&ES+3Y?9&%T85LD8U]K97E=6R=O<F1E<B==(#X]("1O<F1E<BD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&-?:V5Y75LG
M;W)D97(G72LK.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("AI<U]A<G)A
M>2@D;W)D97(I("8F(&-O=6YT*"1O<F1E<BDI('L*("`@("`@("`@("`@+R\@
M375L=&D@=7!D871E+@H@("`@("`@("`@("!F;W)E86-H("@D;W)D97(@87,@
M)&]R9&5R7W!O<VET:6]N(#T^("1C:60I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&%T85LD8VED75LG;W)D97(G72`]("1O<F1E<E]P;W-I=&EO;CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($5X<&QI8VET;'D@<V5T('1H92!O<F1E<B!F;W(@82!D871A=')E92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&ED("`@("!4:&4@9&%T871R964@;V)J96-T(&ED('1O
M(&-H86YG92X*("`@("`J($!P87)A;2!I;G1E9V5R("1O<F1E<B`@5&AE(&YE
M=R!O<F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W)D97(H)&ED+"`D
M;W)D97(I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J($1Y;F%M
M:6-A;&QY(&1E=&5R;6EN97,@=&AE(&]B:F5C="!C;&%S<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@(%1H92!S970@;V8@871T
M<FEB=71E<R!T:&%T(&-O;G1A:6X@=&AE(&-L87-S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N+B!$969A=6QT<R!T;R!$
M871A5')E94]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E9FEN94]B
M:F5C=$-L87-S*"1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@("`@("1C;&%S<R`]("=$871A5')E94]B:F5C="<[
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D871T<FEB=71E<RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;&%S<SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@(&EF("@D
M871T<ELG;F%M92==(#T]("=$871A5')E92<I('L*("`@("`@("`@("`@("`@
M(&EF("@D871T<ELG:V5Y)UT@/3T@)V]B:F5C=$-L87-S)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1C;&%S<R`]("1A='1R6R=V86QU92==.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1A='1R6R=K97DG72`]/2`G;V)J96-T5'EP92<I('L*("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@97AP;&]D92@G+R<L("1A='1R6R=V86QU92==
M*3L*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`D<F5G:7-T<GDM/F-A
M;&Q">5!A8VMA9V4H)')E<W5L=%LP72P@)V1E9FEN94-L87-S)RP@87)R87DH
M)W1Y<&4G(#T^("1R97-U;'1;,5TI*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1C;&%S<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!$871A5')E94]B:F5C="`H;W(@<W5B8VQA<W,I(&]B
M:F5C="!O9B!T:&4@9&%T82!I;B!T:&4*("`@("`J(&]B:F5C="!D969I;F5D
M(&)Y("1O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;V)J
M96-T("!4:&4@;V)J96-T('1O(&9E=&-H.B`G<&%R96YT.G-U8BUP87)E;G0Z
M;F%M92<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@(%-U8F-L87-S
M(&]F($1A=&%4<F5E3V)J96-T('1O('5S92X@1&5F875L=',@=&\*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@1&%T851R965/8FIE8W0N($YU;&P@
M9F]R8V5S('1H92!D<FEV97(@=&\@;&]O:PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!I;G1O('1H92!A='1R:6)U=&5S('1A8FQE('1O(&1E=&5R
M;6EN92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA
M<W,@=&\@=7-E+B!)9B!N;VYE(&ES(&9O=6YD(&ET('5S97,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@1&%T851R965/8FIE8W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9G971/8FIE8W0H)&]B:F5C="P@)&-L87-S(#T@)T1A
M=&%4<F5E3V)J96-T)RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&]B:F5C
M="DI('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M3F\@;V)J96-T(')E<75E<W1E9"XG*3L*("`@("`@("`@("`@<F5T=7)N("1E
M<G)O<CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&]A9"@D;V)J96-T
M*3L*("`@("`@("!I9B`H(21T:&ES+3YE>&ES=',H)&]B:F5C="DI('L*("`@
M("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@D;V)J96-T("X@
M)R!N;W0@9F]U;F0N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("`D=7-E7V%T=')I8G5T97,@/2!I<U]N=6QL*"1C
M;&%S<RD@?'P@:7-?8V%L;&%B;&4H87)R87DH)&-L87-S+"`G7V9R;VU!='1R
M:6)U=&5S)RDI.PH@("`@("`@(&EF("@D=7-E7V%T=')I8G5T97,I('L*("`@
M("`@("`@("`@)&%T=')I8G5T97,@/2`D=&AI<RT^9V5T071T<FEB=71E<R@D
M=&AI<RT^9V5T260H)&]B:F5C="DI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M871T<FEB=71E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1A='1R:6)U=&5S.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H:7-?;G5L;"@D8VQA<W,I*2!["B`@("`@("`@("`@("`@("`D8VQA
M<W,@/2`D=&AI<RT^7V1E9FEN94]B:F5C=$-L87-S*"1A='1R:6)U=&5S*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR
M86ES945R<F]R*"1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)&1A=&%/8B`]
M("9N97<@)&-L87-S*"1O8FIE8W0I.PH@("`@("`@("1D871A3V(M/G-E=$1A
M=&%4<F5E*"1T:&ES*3L*("`@("`@("`O*B!)9B!T:&4@8VQA<W,@:&%S(&$@
M7V9R;VU!='1R:6)U=&5S(&UE=&AO9"P@;&]A9"!D871A(&9R;VT*("`@("`@
M("`@*B!T:&4@871T<FEB=71E<R!B86-K96YD+B`J+PH@("`@("`@(&EF("@D
M=7-E7V%T=')I8G5T97,I('L*("`@("`@("`@("`@)&1A=&%/8BT^7V9R;VU!
M='1R:6)U=&5S*"1A='1R:6)U=&5S*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O*B!/=&AE<G=I<V4@;&]A9"!I="!F<F]M('1H92!O;&0@9&%T
M82!S=&]R86=E(&9I96QD+B`J+PH@("`@("`@("`@("`D9&%T84]B+3YS971$
M871A*"1T:&ES+3YG971$871A*"1T:&ES+3YG971)9"@D;V)J96-T*2DI.PH@
M("`@("`@('T*"B`@("`@("`@)&1A=&%/8BT^<V5T3W)D97(H)'1H:7,M/F=E
M=$]R9&5R*"1O8FIE8W0I*3L*("`@("`@("!R971U<FX@)&1A=&%/8CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!$871A5')E94]B:F5C="`H
M;W(@<W5B8VQA<W,I(&]B:F5C="!O9B!T:&4@9&%T82!I;B!T:&4*("`@("`J
M(&]B:F5C="!W:71H('1H92!)1"`D:60N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&ED("`@($%N(&]B:F5C="!I9"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-L87-S("!3=6)C;&%S<R!O9B!$871A5')E94]B:F5C="!T;R!U
M<V4N($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M1&%T851R965/8FIE8W0N($YU;&P@9F]R8V5S('1H92!D<FEV97(@=&\@;&]O
M:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN=&\@=&AE(&%T=')I
M8G5T97,@=&%B;&4@=&\@9&5T97)M:6YE('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('-U8F-L87-S('1O('5S92X@268@;F]N92!I<R!F;W5N
M9"!I="!U<V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1&%T851R
M965/8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971/8FIE8W1">4ED
M*"1I9"P@)&-L87-S(#T@)T1A=&%4<F5E3V)J96-T)RD*("`@('L*("`@("`@
M("!I9B`H96UP='DH)&ED*2D@>PH@("`@("`@("`@("`D;V)J96-T(#T@4$5!
M4CHZ<F%I<V5%<G)O<B@G3F\@:60@<F5Q=65S=&5D+B<I.PH@("`@("`@("`@
M("!R971U<FX@)&]B:F5C=#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7VQO861">4ED*"1I9"D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("1U<V5?871T<FEB=71E<R`](&ES
M7VYU;&PH)&-L87-S*2!\?"!I<U]C86QL86)L92AA<G)A>2@D8VQA<W,L("=?
M9G)O;4%T=')I8G5T97,G*2D["B`@("`@("`@:68@*"1U<V5?871T<FEB=71E
M<RD@>PH@("`@("`@("`@("`D871T<FEB=71E<R`]("1T:&ES+3YG971!='1R
M:6)U=&5S*"1I9"D["B`@("`@("`@("`@(&EF("AI<U]A*"1A='1R:6)U=&5S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&%T
M=')I8G5T97,["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AI<U]N
M=6QL*"1C;&%S<RDI('L*("`@("`@("`@("`@("`@("1C;&%S<R`]("1T:&ES
M+3Y?9&5F:6YE3V)J96-T0VQA<W,H)&%T=')I8G5T97,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA
M<W,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1C
M;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@)&YA
M;64@/2`D=&AI<RT^9V5T3F%M92@D:60I.PH@("`@("`@("1D871A3V(@/2`F
M;F5W("1C;&%S<R@D;F%M92D["B`@("`@("`@)&1A=&%/8BT^<V5T1&%T851R
M964H)'1H:7,I.PH@("`@("`@("\J($EF('1H92!C;&%S<R!H87,@82!?9G)O
M;4%T=')I8G5T97,@;65T:&]D+"!L;V%D(&1A=&$@9G)O;0H@("`@("`@("`J
M('1H92!A='1R:6)U=&5S(&)A8VME;F0N("HO"B`@("`@("`@:68@*"1U<V5?
M871T<FEB=71E<RD@>PH@("`@("`@("`@("`D9&%T84]B+3Y?9G)O;4%T=')I
M8G5T97,H)&%T=')I8G5T97,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\J($]T:&5R=VES92!L;V%D(&ET(&9R;VT@=&AE(&]L9"!D871A('-T
M;W)A9V4@9FEE;&0N("HO"B`@("`@("`@("`@("1D871A3V(M/G-E=$1A=&$H
M)'1H:7,M/F=E=$1A=&$H)&ED*2D["B`@("`@("`@?0H*("`@("`@("`D9&%T
M84]B+3YS971/<F1E<B@D=&AI<RT^9V5T3W)D97(H)&YA;64I*3L*("`@("`@
M("!R971U<FX@)&1A=&%/8CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@86X@87)R87D@;V8@1&%T851R965/8FIE8W0@*&]R('-U8F-L87-S*2!O
M8FIE8W1S"B`@("`@*B!C;W)R97-P;VYD:6YG('1O('1H92!O8FIE8W1S(&EN
M("1I9',L('=I=&@@=&AE(&]B:F5C=`H@("`@("H@;F%M97,@87,@=&AE(&ME
M>7,@;V8@=&AE(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M:61S("`@("!!;B!A<G)A>2!O9B!O8FIE8W0@:61S+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VQA<W,@(%-U8F-L87-S(&]F($1A=&%4<F5E3V)J96-T('1O
M('5S92X@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!$871A5')E94]B:F5C="X@3G5L;"!F;W)C97,@=&AE(&1R:79E<B!T;R!L
M;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6YT;R!T:&4@871T
M<FEB=71E<R!T86)L92!T;R!D971E<FUI;F4@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@<W5B8VQA<W,@=&\@=7-E+B!)9B!N;VYE(&ES(&9O
M=6YD(&ET('5S97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!$871A
M5')E94]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$]B:F5C=',H
M)&ED<RP@)&-L87-S(#T@)T1A=&%4<F5E3V)J96-T)RD*("`@('L*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]L;V%D0GE)9"@D:61S*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&1E9FEN94-L
M87-S(#T@:7-?;G5L;"@D8VQA<W,I.PH@("`@("`@("1A='1R:6)U=&5S(#T@
M:7-?;G5L;"@D8VQA<W,I('Q\(&ES7V-A;&QA8FQE*&%R<F%Y*"1C;&%S<RP@
M)U]F<F]M071T<FEB=71E<R<I*3L*"B`@("`@("`@:68@*"1A='1R:6)U=&5S
M*2!["B`@("`@("`@("`@("1D871A(#T@)'1H:7,M/F=E=$%T=')I8G5T97,H
M)&ED<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@/2`D
M=&AI<RT^9V5T1&%T82@D:61S*3L*("`@("`@("!]"@H@("`@("`@("1O8FIE
M8W1S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D:61S(&%S("1I9"D@
M>PH@("`@("`@("`@("`D;F%M92`]("1T:&ES+3YG971.86UE*"1I9"D["B`@
M("`@("`@("`@(&EF("@A96UP='DH)&YA;64I("8F("%E;7!T>2@D9&%T85LD
M:61=*2D@>PH@("`@("`@("`@("`@("`@:68@*"1D969I;F5#;&%S<RD@>PH@
M("`@("`@("`@("`@("`@("`@("1C;&%S<R`]("1T:&ES+3Y?9&5F:6YE3V)J
M96-T0VQA<W,H)&1A=&%;)&ED72D["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1C;&%S
M<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1O8FIE8W1S6R1N86UE72`]("9N97<@)&-L87-S*"1N86UE
M*3L*("`@("`@("`@("`@("`@("1O8FIE8W1S6R1N86UE72T^<V5T1&%T851R
M964H)'1H:7,I.PH@("`@("`@("`@("`@("`@:68@*"1A='1R:6)U=&5S*2![
M"B`@("`@("`@("`@("`@("`@("`@)&]B:F5C='-;)&YA;65=+3Y?9G)O;4%T
M=')I8G5T97,H)&1A=&%;)&ED72D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1O8FIE8W1S6R1N86UE72T^<V5T1&%T
M82@D9&%T85LD:61=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1O8FIE8W1S6R1N86UE72T^<V5T3W)D97(H)'1H:7,M/F=E=$]R9&5R
M*"1N86UE*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;V)J96-T<SL*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A
M(&QI<W0@;V8@;V)J96-T<RX*("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A
M;G0@)&9O<FUA="`@("`@($9O<FUA="!O9B!T:&4@97AP;W)T"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`@)'-T87)T;&5A9B`@(%1H92!N86UE(&]F('1H92!L
M96%F(&9R;VT@=VAI8V@@=V4@<W1A<G0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&5X<&]R="!T<F5E+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@("1R96QO860@("`@("!292UL;V%D('1H92!R97%U97-T960@
M8VAU;FL_($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9A;'-E("AO;FQY('=H870@:7,@8W5R<F5N=&QY(&QO861E
M9"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)')O;W1N86UE("`@(%1H92!L
M86)E;"!T;R!U<V4@9F]R('1H92!R;V]T(&5L96UE;G0N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O($1!5$%44D5%
M7U)/3U0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@)&UA>&1E<'1H("`@(%1H
M92!M87AI;75M(&YU;6)E<B!O9B!L979E;',@=&\@<F5T=7)N+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!$051!
M5%)%15]23T]4+"!W:&EC:"!I<R!N;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!L:6UI="X*("`@("`J($!P87)A;2!B;V]L96%N("`D
M;&]A9%1R964@("`@3&]A9"!A('1R964@<W1A<G1I;F<@870@)')O;W0L(&]R
M(&IU<W0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E<75E<W1E9"!L979E;"!A;F0@9&ER96-T('!A<F5N=',_"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O('-I;F=L
M92!L979E;"X*("`@("`J($!P87)A;2!S=')I;F<@("`D<V]R=&)Y7VYA;64@
M071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@("1S;W)T8GE?:V5Y("!!='1R:6)U=&4@:V5Y('1O('5S
M92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("`D9&ER96-T
M:6]N("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!T<F5E(')E<')E<V5N=&%T:6]N(&]F
M('1H92!O8FIE8W1S+"!O<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@("`@
M("`@("`@(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D
M9F]R;6%T+"`D<W1A<G1L96%F(#T@1$%40512145?4D]/5"P@)')E;&]A9"`]
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("1R;V]T;F%M92`]($1!5$%44D5%
M7U)/3U0L("1M87AD97!T:"`]("TQ+"`D;&]A9%1R964@/2!F86QS92P*("`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME
M>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("\J(%-E
M="!S;W)T:6YG(&AA<V@@*B\*("`@("`@("!I9B`H(6ES7VYU;&PH)'-O<G1B
M>5]N86UE*2!\?"`A:7-?;G5L;"@D<V]R=&)Y7VYA;64I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V]R=$AA<V@@/2!$871A5')E93HZ<V]R=$AA<V@H)'-T
M87)T;&5A9BP@)'-O<G1B>5]N86UE+"`D<V]R=&)Y7VME>2P@)&1I<F5C=&EO
M;BD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQO860H)'-T87)T;&5A
M9BP@)&QO8614<F5E+"`D<F5L;V%D+"`D<V]R=&)Y7VYA;64L("1S;W)T8GE?
M:V5Y+"`D9&ER96-T:6]N*3L*("`@("`@("`D;W5T(#T@87)R87DH*3L*"B`@
M("`@("`@<W=I=&-H("@D9F]R;6%T*2!["B`@("`@("`@8V%S92!$051!5%)%
M15]&3U)-051?5%)%13H*("`@("`@("`@("`@)'-T87)T:60@/2`D=&AI<RT^
M9V5T260H)'-T87)T;&5A9BP@)&UA>&1E<'1H*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)'-T87)T:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<W1A<G1I9#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;%1R964H)&]U="P@)'-T87)T:60L
M("1M87AD97!T:"D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M($1!5$%44D5%7T9/4DU!5%]&3$%4.@H@("`@("`@("`@("`D<W1A<G1I9"`]
M("1T:&ES+3YG971)9"@D<W1A<G1L96%F*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)'-T87)T:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<W1A<G1I9#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^7V5X=')A8W1!;&Q,979E;$QI<W0H)&]U="P@)'-T87)T:60L("1M
M87AD97!T:"D["B`@("`@("`@("`@(&EF("@A96UP='DH)&]U=%M$051!5%)%
M15]23T]472DI('L*("`@("`@("`@("`@("`@("1O=71;1$%40512145?4D]/
M5%T@/2`D<F]O=&YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;W0@<W5P<&]R=&5D)RD["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]S;W)T2&%S:"DI('L*("`@("`@
M("`@("`@+RH@4F5S970@<V]R=&EN9R!H87-H+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^7W-O<G1(87-H(#T@;G5L;#L*("`@("`@("`@("`@+RH@4F5V97)S
M92!S:6YC92!T:&4@871T<FEB=71E('-O<G1I;F<@8V]M8FEN960@=VET:"!T
M<F5E('5P+7=A<F0*("`@("`@("`@("`@("H@<V]R=&EN9R!P<F]D=6-E<R!A
M(')E=F5R<V5D(&]B:F5C="!O<F1E<BX@*B\*("`@("`@("`@("`@)&]U="`]
M(&%R<F%Y7W)E=F5R<V4H)&]U="P@=')U92D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&]U=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O=6YT<R!O
M8FIE8W1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T87)T;&5A
M9B`@5&AE(&YA;64@;V8@=&AE(&QE868@9G)O;2!W:&EC:"!W92!S=&%R=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!C;W5N=&EN9RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@=&AE
M(&]B:F5C=',@8F5L;W<@)'-T87)T;&5A9BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]U;G0H)'-T87)T;&5A9B`]($1!5$%44D5%7U)/3U0I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8V]U;G0H)'-T87)T;&5A9BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@871T<FEB=71E('-O<G0@:&%S:`H@
M("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<F]O="`@("`@("`@(%1H92!N86UE(&]F('1H92!L
M96%F(&9R;VT@=VAI8V@@=V4@<W1A<G0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&5X<&]R="!T<F5E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M92!T;R!U<V4@
M9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VME
M>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I<F5C=&EO;CH*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N
M9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@
M9&5S8V5N9&EN9PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!S
M;W)T(&AA<V@*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$AA<V@H)')O;W0L
M("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L;"P*("`@
M("`@("`@("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@
M("`@(')E='5R;B!S<')I;G1F*"<E<RTE<RTE<RTE<R<L("1R;V]T+"`D<V]R
M=&)Y7VYA;64L("1S;W)T8GE?:V5Y+"`D9&ER96-T:6]N*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($5X<&]R="!A(&QI<W0@;V8@;V)J96-T<R!J=7-T(&QI
M:V4@9V5T*"D@86)O=F4L(&)U="!U<V5S(&%N"B`@("`@*B!O8FIE8W0@:60@
M=&\@9F5T8V@@=&AE(&QI<W0@;V8@;V)J96-T<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@8V]N<W1A;G0@)&9O<FUA="`@("!&;W)M870@;V8@=&AE(&5X<&]R
M="X*("`@("`J($!P87)A;2!S=')I;F<@("1S=&%R=&QE868@(%1H92!I9"!O
M9B!T:&4@;&5A9B!F<F]M('=H:6-H('=E('-T87)T('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@97AP;W)T('1R964N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<F5L;V%D("`@("!296QO860@=&AE(')E<75E<W1E
M9"!C:'5N:S\@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9A;'-E("AO;FQY('=H870@:7,@8W5R<F5N=&QY(&QO861E
M9"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F]O=&YA;64@("!4:&4@;&%B
M96P@=&\@=7-E(&9O<B!T:&4@<F]O="!E;&5M96YT+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@1$%40512145?4D]/
M5"X*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AD97!T:"`@(%1H92!M87AI
M;75M(&YU;6)E<B!O9B!L979E;',@=&\@<F5T=7)N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R`M,2P@=VAI8V@@:7,@
M;F\@;&EM:70N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('1R
M964@<F5P<F5S96YT871I;VX@;V8@=&AE(&]B:F5C=',L(&]R(&$@4$5!4E]%
M<G)O<@H@("`@("H@("`@("`@("`@("`@("`@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0GE)9"@D9F]R;6%T+"`D<W1A<G1L96%F(#T@
M1$%40512145?4D]/5"P@)')E;&]A9"`](&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`D<F]O=&YA;64@/2!$051!5%)%15]23T]4+"`D;6%X9&5P=&@@
M/2`M,2D*("`@('L*("`@("`@("`D=&AI<RT^7VQO861">4ED*"1S=&%R=&QE
M868I.PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH*("`@("`@("!S=VET8V@@
M*"1F;W)M870I('L*("`@("`@("!C87-E($1!5$%44D5%7T9/4DU!5%]44D5%
M.@H@("`@("`@("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;%1R964H)&]U
M="P@)'-T87)T;&5A9BP@)&UA>&1E<'1H*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@1$%40512145?1D]234%47T9,050Z"B`@("`@("`@
M("`@("1T:&ES+3Y?97AT<F%C=$%L;$QE=F5L3&ES="@D;W5T+"`D<W1A<G1L
M96%F+"`D;6%X9&5P=&@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1O=71;
M1$%40512145?4D]/5%TI*2!["B`@("`@("`@("`@("`@("`D;W5T6T1!5$%4
M4D5%7U)/3U1=(#T@)')O;W1N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F]T('-U<'!O<G1E9"<I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@;&ES="!O9B!A;&P@9W)O=7!S("AR;V]T(&YO9&5S*2!O
M9B!T:&4@9&%T82!T<F5E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!T:&4@9W)O=7`@241S"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R
M;W5P<R@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I
M979E(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M('1H92!D871A=')E95]D871A
M(&9I96QD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@:60@=&\@9F5T8V@L
M(&]R(&%N(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$1A=&$H)&-I9"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@26UP;W)T(&$@;&ES="!O9B!O8FIE8W1S+B!5<V5D(&)Y(&1R:79E
M<G,@=&\@<&]P=6QA=&4@=&AE(&EN=&5R;F%L"B`@("`@*B`D7V1A=&$@87)R
M87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&1A=&$@("`@(%1H
M92!D871A('1O(&EM<&]R="X*("`@("`J($!P87)A;2!S=')I;F<@("1C:&%R
M<V5T("!4:&4@8VAA<G-E="!T;R!C;VYV97)T('1H92!O8FIE8W0@;F%M92!F
M<F]M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&1A=&$L("1C:&%R<V5T
M(#T@;G5L;"D*("`@('L*("`@("`@("`D8VED<R`](&%R<F%Y*"D["B`@("`@
M("`@9F]R96%C:"`H)&1A=&$@87,@)&ED(#T^("1C870I('L*("`@("`@("`@
M("`@:68@*"%I<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@
M)&-A=%LQ72`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&-A=%LQ72P@)&-H
M87)S970I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C:61S6R1C871;
M,%U=(#T@)&-A=%LQ73L*("`@("`@("`@("`@)&-P87)E;G1S6R1C871;,%U=
M(#T@)&-A=%LR73L*("`@("`@("`@("`@)&-O<F1E<G-;)&-A=%LP75T@/2`D
M8V%T6S-=.PH@("`@("`@("`@("`D<V]R9&5R<ULD8V%T6S!=72`]("1I9#L*
M("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C:61S(&%S("1I9"`]/B`D
M;F%M92D@>PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG;F%M92==
M(#T@)&YA;64["B`@("`@("`@("`@("1T:&ES+3Y?9&%T85LD:61=6R=O<F1E
M<B==(#T@)&-O<F1E<G-;)&ED73L*("`@("`@("`@("`@:68@*"%I<U]N=6QL
M*"1T:&ES+3Y?<V]R=$AA<V@I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1A=&%;)&ED75LG<V]R=&5R)UU;)'1H:7,M/E]S;W)T2&%S:%T@/2`D<V]R
M9&5R<ULD:61=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP
M='DH)&-P87)E;G1S6R1I9%TI*2!["B`@("`@("`@("`@("`@("`D<&%R96YT
M<R`](&5X<&QO9&4H)SHG+"!S=6)S='(H)&-P87)E;G1S6R1I9%TL(#$I*3L*
M("`@("`@("`@("`@("`@("1P87(@/2`D<&%R96YT<UMC;W5N="@D<&%R96YT
M<RD@+2`Q73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&%T85LD:61=6R=P
M87)E;G0G72`]("1P87(["@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7VYA;65-87!;)'!A<ETI*2!["B`@("`@("`@("`@("`@("`@("`@
M+R\@268@=V4G=F4@86QR96%D>2!L;V%D960@=&AE(&1I<F5C="!P87)E;G0@
M;V8*("`@("`@("`@("`@("`@("`@("`O+R!T:&ES(&]B:F5C="P@=7-E('1H
M870@=&\@9FEN9"!T:&4@9G5L;"!N86UE+@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;F%M94UA<%LD:61=(#T@)'1H:7,M/E]N86UE36%P6R1P87)=
M("X@)SHG("X@)&YA;64["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("\O($]T:&5R=VES92P@<G5N('1H<F]U9V@@<&%R
M96YT<R!O;F4@8GD@;VYE('1O"B`@("`@("`@("`@("`@("`@("`@+R\@8G5I
M;&0@:70@=7`N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE36%P
M6R1I9%T@/2`G)SL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%R
M96YT<R!A<R`D<&%R240I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D8VED<ULD<&%R241=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I9%T@+CT@)SHG("X@)&-I9'-;
M)'!A<DE$73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VYA;65-
M87!;)&ED72`]('-U8G-T<B@D=&AI<RT^7VYA;65-87!;)&ED72P@,2D@+B`G
M.B<@+B`D;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&%T85LD:61=6R=P87)E
M;G0G72`]($1!5$%44D5%7U)/3U0["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VYA;65-87!;)&ED72`]("1N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X=')A8W0@;VYE(&QE=F5L(&]F(&1A=&$@9F]R(&$@<&%R96YT(&QE868L
M('-O<G1E9"!F:7)S="!B>0H@("`@("H@=&AE:7(@;W)D97(@86YD('1H96X@
M8GD@;F%M92X@5&AI<R!F=6YC=&EO;B!I<R!A('=A>2!T;R!G970@80H@("`@
M("H@8V]L;&5C=&EO;B!O9B`D;&5A9B=S(&-H:6QD<F5N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&QE868@($YA;64@;V8@=&AE('!A<F5N="!F
M<F]M('=H:6-H('1O('-T87)T+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X=')A8W1/;F5,979E;"@D;&5A
M9B`]($1!5$%44D5%7U)/3U0I"B`@("!["B`@("`@("`@)&]U="`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]D871A(&%S("1I9"`]/B`D
M=F%L<RD@>PH@("`@("`@("`@("!I9B`H)'9A;'-;)W!A<F5N="==(#T]("1L
M96%F*2!["B`@("`@("`@("`@("`@("`D;W5T6R1I9%T@/2`D=F%L<SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU;&PH)'1H
M:7,M/E]S;W)T2&%S:"DI('L*("`@("`@("`@("`@=6%S;W)T*"1O=70L(&%R
M<F%Y*"1T:&ES+"`G7V-M<"<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!U87-O<G0H)&]U="P@87)R87DH)'1H:7,L("=?8VUP4V]R=&5D)RDI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%>'1R86-T(&%L;"!L979E;',@;V8@9&%T82P@<W1A<G1I
M;F<@9G)O;2!A(&=I=F5N('!A<F5N=`H@("`@("H@;&5A9B!I;B!T:&4@9&%T
M871R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1O=70@("`@("`@
M("!4:&ES(&ES(&%N(&ET97)A=&EN9R!F=6YC=&EO;BP@<V\@)&]U="!I<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@8GD@<F5F
M97)E;F-E('1O(&-O;G1A:6X@=&AE(')E<W5L="X*("`@("`J($!P87)A;2!S
M=')I;F<@("1P87)E;G0@("`@5&AE(&YA;64@;V8@=&AE('!A<F5N="!F<F]M
M('=H:6-H('1O(&)E9VEN+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&1E
M<'1H("!-87@@;V8@;&5V96QS(&]F(&1E<'1H('1O(&-H96-K+@H@("`@("H*
M("`@("`J($!N;W1E($EF(&YO=&AI;F<@:7,@<F5T=7)N960@=&AA="!M96%N
M<R!T:&5R92!I<R!N;R!C:&EL9"P@8G5T"B`@("`@*B!D;VXG="!F;W)G970@
M=&\@861D('1H92!P87)E;G0@:68@86YY('-U8G-E<75E;G0@;W!E<F%T:6]N
M<R!A<F4*("`@("`J(')E<75I<F5D(0H@("`@("HO"B`@("!F=6YC=&EO;B!?
M97AT<F%C=$%L;$QE=F5L5')E92@F)&]U="P@)'!A<F5N="`]($1!5$%44D5%
M7U)/3U0L("1M87AD97!T:"`]("TQ*0H@("`@>PH@("`@("`@(&EF("@D;6%X
M9&5P=&@@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D;W5T6R1P87)E;G1=(#T@=')U93L*"B`@("`@("`@
M)&L@/2`D=&AI<RT^7V5X=')A8W1/;F5,979E;"@D<&%R96YT*3L*("`@("`@
M("!F;W)E86-H("@D:R!A<R`D;V)J96-T(#T^("1V*2!["B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)&]U=%LD<&%R96YT72DI('L*("`@("`@("`@("`@
M("`@("1O=71;)'!A<F5N=%T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1O=71;)'!A<F5N=%U;)&]B:F5C=%T@/2!T<G5E.PH@("`@
M("`@("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;%1R964H)&]U=%LD<&%R
M96YT72P@)&]B:F5C="P@)&UA>&1E<'1H("T@,2D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@17AT<F%C="!A;&P@;&5V96QS(&]F(&1A=&$L
M('-T87)T:6YG(&9R;VT@86YY('!A<F5N="!I;@H@("`@("H@=&AE('1R964N
M"B`@("`@*@H@("`@("H@4F5T=7)N960@87)R87D@9F]R;6%T.B!A<G)A>2AP
M87)E;G0@/3X@87)R87DH8VAI;&0@/3X@=')U92DI"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1O=70@("`@("`@("!4:&ES(&ES(&%N(&ET97)A=&EN
M9R!F=6YC=&EO;BP@<V\@)&]U="!I<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!P87-S960@8GD@<F5F97)E;F-E('1O(&-O;G1A:6X@=&AE
M(')E<W5L="X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@5&AE
M(&YA;64@;V8@=&AE('!A<F5N="!F<F]M('=H:6-H('1O(&)E9VEN+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&UA>&1E<'1H("!-87@@;G5M8F5R(&]F(&QE
M=F5L<R!O9B!D97!T:"!T;R!C:&5C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V5X=')A8W1!;&Q,979E;$QI<W0H)B1O=70L("1P87)E;G0@/2!$051!5%)%
M15]23T]4+"`D;6%X9&5P=&@@/2`M,2D*("`@('L*("`@("`@("!I9B`H)&UA
M>&1E<'1H(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@+R\@5&AI<R!I<R!R961U;F1A;G0@;6]S="!O9B!T
M:&4@=&EM92P@<V\@;6%K92!S=7)E('=E(&YE960@=&\*("`@("`@("`O+R!D
M;R!I="X*("`@("`@("!I9B`H96UP='DH)&]U=%LD<&%R96YT72DI('L*("`@
M("`@("`@("`@)&]U=%LD<&%R96YT72`]("1T:&ES+3YG971.86UE*"1P87)E
M;G0I.PH@("`@("`@('T*"B`@("`@("`@)&L@/2!A<G)A>5]K97ES*"1T:&ES
M+3Y?97AT<F%C=$]N94QE=F5L*"1P87)E;G0I*3L*("`@("`@("!F;W)E86-H
M("@D:R!A<R`D;V)J96-T*2!["B`@("`@("`@("`@("1O=71;)&]B:F5C=%T@
M/2`D=&AI<RT^9V5T3F%M92@D;V)J96-T*3L*("`@("`@("`@("`@)'1H:7,M
M/E]E>'1R86-T06QL3&5V96Q,:7-T*"1O=70L("1O8FIE8W0L("1M87AD97!T
M:"`M(#$I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!C:&EL9"=S(&1I<F5C="!P87)E;G0@240N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1C:&EL9"`@16ET:&5R('1H92!O8FIE8W0L(&%N(&%R
M<F%Y(&-O;G1A:6YI;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!P871H(&5L96UE;G1S+"!O<B!T:&4@;V)J96-T(&YA;64@9F]R('=H:6-H
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T;R!L;V]K('5P('1H92!P
M87)E;G0G<R!)1"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!U;FEQ=64@240@;V8@=&AE('!A<F5N="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&%R96YT*"1C:&EL9"D*("`@('L*("`@("`@("!I9B`H:7-?82@D
M8VAI;&0L("=$871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1C:&EL
M9"`]("1C:&EL9"T^9V5T3F%M92@I.PH@("`@("`@('T*("`@("`@("`D:60@
M/2`D=&AI<RT^9V5T260H)&-H:6QD*3L*("`@("`@("!I9B`H:7-?82@D:60L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)&ED75LG<&%R
M96YT)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82`D8VAI;&0G<R!D
M:7)E8W0@<&%R96YT($E$+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1C:&EL9$ED("!'970@=&AE('!A<F5N="!O9B!T:&ES(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!U;FEQ=64@240@;V8@
M=&AE('!A<F5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R96YT0GE)
M9"@D8VAI;&1)9"D*("`@('L*("`@("`@("`D=&AI<RT^7VQO861">4ED*"1C
M:&EL9$ED*3L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]D871A6R1C
M:&EL9$ED72D@/PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&-H:6QD261=
M6R=P87)E;G0G72`Z"B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H)&-H
M:6QD260@+B`G(&YO="!F;W5N9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&$@;&ES="!O9B!P87)E;G1S(&%L;"!T:&4@=V%Y('5P('1O('1H92!R
M;V]T(&]B:F5C="!F;W(*("`@("`J("1C:&EL9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@("`D8VAI;&0@("!4:&4@;F%M92!O9B!T:&4@8VAI;&0*
M("`@("`J($!P87)A;2!B;V]L96%N("1G971I9',@($EF('1R=64L(')E='5R
M;B!P87)E;G0@241S.R!O=&AE<G=I<V4L(')E='5R;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@;F%M97,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@6V-H:6QD72!;<&%R96YT72!I;B!A('1R964@9F]R;6%T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971087)E;G1S*"1C:&EL9"P@)&=E=&ED
M<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1P:60@/2`D=&AI<RT^9V5T4&%R
M96YT*"1C:&EL9"D["B`@("`@("`@:68@*&ES7V$H)'!I9"P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M4&%R96YT<R!N;W0@9F]U;F0Z("<@+B`D<&ED+3YG971-97-S86=E*"DI.PH@
M("`@("`@('T*("`@("`@("`D<&YA;64@/2`D=&AI<RT^9V5T3F%M92@D<&ED
M*3L*("`@("`@("!I9B`H)&=E=&ED<RD@>PH@("`@("`@("`@("`D<&%R96YT
M<R`](&%R<F%Y*"1P:60@/3X@=')U92D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'!A<F5N=',@/2!A<G)A>2@D<&YA;64@/3X@=')U92D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'!I9"`A/2!$051!5%)%15]23T]4*2![
M"B`@("`@("`@("`@(&EF("@D9V5T:61S*2!["B`@("`@("`@("`@("`@("`D
M<&%R96YT<ULD<&ED72`]("1T:&ES+3YG971087)E;G1S*"1P;F%M92P@)&=E
M=&ED<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<&%R96YT<ULD<&YA;65=(#T@)'1H:7,M/F=E=%!A<F5N=',H)'!N86UE+"`D
M9V5T:61S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1P87)E;G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES
M="!O9B!P87)E;G1S(&%L;"!T:&4@=V%Y('5P('1O('1H92!R;V]T(&]B:F5C
M="!F;W(*("`@("`J("1C:&EL9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8VAI;&1)9"`@5&AE(&ED(&]F('1H92!C:&EL9"X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R96YT<R`@("!4:&4@87)R87DL(&%S('=E(&)U:6QD
M(&ET('5P+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@9FQA="!L
M:7-T(&]F(&%L;"!O9B!T:&4@<&%R96YT<R!O9B`D8VAI;&0L"B`@("`@*B`@
M("`@("`@("`@("`@("!H87-H960@:6X@)&ED(#T^("1N86UE(&9O<FUA="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R96YT3&ES="@D8VAI;&1)9"P@
M)'!A<F5N=',@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P:60@/2`D=&AI
M<RT^9V5T4&%R96YT0GE)9"@D8VAI;&1)9"D["B`@("`@("`@:68@*&ES7V$H
M)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G4&%R96YT<R!N;W0@9F]U;F0Z("<@+B`D<&ED+3YG
M971-97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1P:60@(3T@
M1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D<&%R96YT<ULD<&ED72`]
M("1T:&ES+3YG971.86UE*"1P:60I.PH@("`@("`@("`@("`D<&%R96YT<R`]
M("1T:&ES+3YG971087)E;G1,:7-T*"1P:60L("1P87)E;G1S*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<&%R96YT<SL*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!A('!A<F5N="!)1"!S=')I;F<@*&ED.F-I9"!F;W)M870I
M(&9O<B!T:&4@<W!E8VEF:65D(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&]B:F5C="`@5&AE(&]B:F5C="!T;R!R971U<FX@82!P87)E
M;G0@<W1R:6YG(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQ0
M14%27T5R<F]R("!4:&4@240@(G!A=&@B('1O('1H92!P87)E;G0@;V)J96-T
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N
M=$ED4W1R:6YG*"1O8FIE8W0I"B`@("!["B`@("`@("`@)'!T<F5E(#T@)'1H
M:7,M/F=E=%!A<F5N=',H)&]B:F5C="P@=')U92D["B`@("`@("`@:68@*&ES
M7V$H)'!T<F5E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<'1R964["B`@("`@("`@?0H*("`@("`@("`D<&ED<R`]("<G.PH@("`@
M("`@('=H:6QE("@H;&ES="@D:60L("1P87)E;G0I(#T@96%C:"@D<'1R964I
M*2`F)B!I<U]A<G)A>2@D<&%R96YT*2D@>PH@("`@("`@("`@("`D<&ED<R`]
M("<Z)R`N("1I9"`N("1P:61S.PH@("`@("`@("`@("`D<'1R964@/2`D<&%R
M96YT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P:61S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!N=6UB97(@;V8@8VAI;&1R96X@86X@
M;V)J96-T(&AA<RP@;VYL>2!C;W5N=&EN9R!I;6UE9&EA=&4*("`@("`J(&-H
M:6QD<F5N+"!N;W0@9W)A;F1C:&EL9')E;BP@971C+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D<&%R96YT("!%:71H97(@=&AE(&]B:F5C="!O<B!T
M:&4@;F%M92!F;W(@=VAI8V@@=&\@8V]U;G0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@8VAI;&1R96XL(&1E9F%U;'1S('1O('1H92!R;V]T
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@*$1!5$%44D5%7U)/3U0I
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971.=6UB97)/9D-H:6QD<F5N*"1P87)E;G0@/2!$051!5%)%
M15]23T]4*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1P87)E;G0L("=$871A
M5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1P87)E;G0@/2`D<&%R96YT
M+3YG971.86UE*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;&]A9"@D
M<&%R96YT*3L*("`@("`@("`D;W5T(#T@)'1H:7,M/E]E>'1R86-T3VYE3&5V
M96PH)'1H:7,M/F=E=$ED*"1P87)E;G0I*3L*("`@("`@("!R971U<FX@:7-?
M87)R87DH)&]U="D@/R!C;W5N="@D;W5T*2`Z(#`["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:R!I9B!A;B!O8FIE8W0@97AI<W1S(&]R(&YO="X@5&AE
M(')O;W0@96QE;65N="!$051!5%)%15]23T]4(&%L=V%Y<R!E>&ES=',N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1O8FIE8W0@(%1H92!N86UE(&]F
M('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!O8FIE8W0@97AI<W1S+"!F86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D;V)J96-T*0H@("`@>PH@("`@
M("`@(&EF("AE;7!T>2@D;V)J96-T*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=$
M871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1O8FIE8W0@/2`D;V)J
M96-T+3YG971.86UE*"D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1O
M8FIE8W0I*2!["B`@("`@("`@("`@("1O8FIE8W0@/2!I;7!L;V1E*"<Z)RP@
M)&]B:F5C="D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&]B:F5C="`]/2!$
M051!5%)%15]23T]4*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@)&ED36%P(#T@87)R87E?9FQI<"@D=&AI<RT^7VYA
M;65-87`I.PH@("`@("`@(&EF("AI<W-E="@D:61-87!;)&]B:F5C=%TI*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]L;V%D*"1O8FIE8W0I.PH@("`@("`@("1I9$UA<"`](&%R<F%Y
M7V9L:7`H)'1H:7,M/E]N86UE36%P*3L*("`@("`@("!R971U<FX@:7-S970H
M)&ED36%P6R1O8FIE8W1=*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@;F%M92!O9B!A;B!O8FIE8W0@9G)O;2!I=',@:60N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&ED("!4:&4@:60@9F]R('=H:6-H('1O(&QO
M;VL@=7`@=&AE(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M92@D:60I"B`@("!["B`@("`@
M("`@+RH@268@;F\@:60@;W(@:68@:60@:7,@82!014%2(&5R<F]R+"!R971U
M<FX@;G5L;"X@*B\*("`@("`@("!I9B`H96UP='DH)&ED*2!\?"!I<U]A*"1I
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"@H@("`@("`@("\J($EF(&-H96-K:6YG(&YA;64@;V8@<F]O
M="P@<F5T=7)N($1!5$%44D5%7U)/3U0N("HO"B`@("`@("`@:68@*"1I9"`]
M/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@(')E='5R;B!$051!5%)%
M15]23T]4.PH@("`@("`@('T*"B`@("`@("`@+RH@268@9F]U;F0@:6X@=&AE
M(&YA;64@;6%P+"!R971U<FX@=&AE(&YA;64N("HO"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;F%M94UA<%LD:61=*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]N86UE36%P6R1I9%T["B`@("`@("`@?0H*("`@("`@("`O
M*B!.;W0@9F]U;F0@:6X@;F%M92!M87`L('1R>2!L;V%D:6YG('1H:7,@:60@
M:6YT;R!T:&4@;F%M90H@("`@("`@("`J(&UA<"X@*B\*("`@("`@("`D=&AI
M<RT^7VQO861">4ED*"1I9"D["@H@("`@("`@("\J($EF(&ED(&QO861E9"!R
M971U<FX@=&AE(&YA;64L(&]T:&5R=VES92!R971U<FX@;G5L;"X@*B\*("`@
M("`@("!R971U<FX@:7-S970H)'1H:7,M/E]N86UE36%P6R1I9%TI(#\*("`@
M("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I9%T@.@H@("`@("`@("`@("!N
M=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!I9"!O9B!A;B!O
M8FIE8W0@9G)O;2!I=',@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&YA;64@($5I=&AE<B!T:&4@;V)J96-T+"!A;B!A<G)A>2!C;VYT86EN
M:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("!P871H(&5L96UE
M;G1S+"!O<B!T:&4@;V)J96-T(&YA;64@9F]R('=H:6-H"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@('1O(&QO;VL@=7`@=&AE(&ED+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$ED
M*"1N86UE*0H@("`@>PH@("`@("`@("\J($-H96-K(&EF("1N86UE(&ES(&YO
M="!A('-T<FEN9RX@*B\*("`@("`@("!I9B`H:7-?82@D;F%M92P@)T1A=&%4
M<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@+RH@1&%T851R965/8FIE8W0L
M(&=E="!T:&4@<W1R:6YG(&YA;64N("HO"B`@("`@("`@("`@("1N86UE(#T@
M)&YA;64M/F=E=$YA;64H*3L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH
M)&YA;64I*2!["B`@("`@("`@("`@("\J(%!A=&@@87)R87DL(&EM<&QO9&4@
M=&\@9V5T('1H92!S=')I;F<@;F%M92X@*B\*("`@("`@("`@("`@)&YA;64@
M/2!I;7!L;V1E*"<Z)RP@)&YA;64I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@8VAE8VMI;F<@:60@;V8@<F]O="P@<F5T=7)N($1!5$%44D5%7U)/3U0N
M("HO"B`@("`@("`@:68@*"1N86UE(#T]($1!5$%44D5%7U)/3U0I('L*("`@
M("`@("`@("`@<F5T=7)N($1!5$%44D5%7U)/3U0["B`@("`@("`@?0H*("`@
M("`@("`O*B!#:&5C:R!I9B!T:&4@;F%M92!A8W1U86QL>2!E>&ES=',L(&EF
M(&YO="!R971U<FX@82!014%2"B`@("`@("`@("H@97)R;W(N("HO"B`@("`@
M("`@:68@*"$D=&AI<RT^97AI<W1S*"1N86UE*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D;F%M92`N("<@9&]E<R!N;W0@97AI
M<W0G*3L*("`@("`@("!]"@H@("`@("`@("\J($9L:7`@=&AE(&YA;64@;6%P
M('1O(&QO;VL@=7`@=&AE(&ED('5S:6YG('1H92!N86UE(&%S(&ME>2X@*B\*
M("`@("`@("`D:61-87`@/2!A<G)A>5]F;&EP*"1T:&ES+3Y?;F%M94UA<"D[
M"B`@("`@("`@<F5T=7)N("1I9$UA<%LD;F%M95T["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@=&AE(&]R9&5R('!O<VET:6]N(&]F(&%N(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&-H:6QD("!%:71H97(@=&AE
M(&]B:F5C="!O<B!T:&4@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@;V)J96-T)W,@;W)D97(@<&]S:71I;VX@;W(@82!014%2(&5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]R9&5R
M*"1C:&EL9"D*("`@('L*("`@("`@("!I9B`H:7-?82@D8VAI;&0L("=$871A
M5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1C:&EL9"`]("1C:&EL9"T^
M9V5T3F%M92@I.PH@("`@("`@('T*("`@("`@("`D:60@/2`D=&AI<RT^9V5T
M260H)&-H:6QD*3L*("`@("`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V1A=&%;)&ED75LG;W)D97(G72D@
M/PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG;W)D97(G72`Z"B`@
M("`@("`@("`@(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297!L86-E
M(&%L;"!O8V-U<F5N8V5S(&]F("<Z)R!I;B!A;B!O8FIE8W0@;F%M92!W:71H
M("<N)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M;F%M92!O9B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@96YC;V1E9"!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!E
M;F-O9&5.86UE*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!S=')?<F5P
M;&%C92@G.B<L("<N)RP@)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!S:&]R="!N86UE(&]F(&%N(&]B:F5C="P@<F5T=7)N<R!O;FQY
M('1H92!L87-T('!O<G1I;VX@;V8@=&AE"B`@("`@*B!F=6QL(&YA;64N($9O
M<B!D:7-P;&%Y('!U<G!O<V5S(&]N;'DN"B`@("`@*@H@("`@("H@0'-T871I
M8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE
M(&]F('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!O8FIE8W0G<R!S:&]R="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9713:&]R=$YA;64H)&YA;64I"B`@("!["B`@("`@("`@+RH@268@=&AE
M<F4@87)E('-E=F5R86P@8V]M<&]N96YT<R!T;R!T:&4@;F%M92P@97AP;&]D
M92!A;F0@9V5T('1H90H@("`@("`@("`J(&QA<W0@;VYE+"!O=&AE<G=I<V4@
M:G5S="!R971U<FX@=&AE(&YA;64N("HO"B`@("`@("`@:68@*'-T<G!O<R@D
M;F%M92P@)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)&YA;64@/2!E
M>'!L;V1E*"<Z)RP@)&YA;64I.PH@("`@("`@("`@("`D;F%M92`](&%R<F%Y
M7W!O<"@D;F%M92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;F%M93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!T<F5E('-O<G1E9"!B
M>2!T:&4@<W!E8VEF:65D(&%T=')I8G5T92!N86UE(&%N9"]O<B!K97DN"B`@
M("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')O;W0@("`@
M("`@("!7:&EC:"!P;W)T:6]N(&]F('1H92!T<F5E('1O('-O<G0N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@86QL
M(&]F(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8614<F5E("`@(%-O
M<G0@=&AE('1R964@<W1A<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=65S=&5D(&QE
M=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@
M=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V]R
M=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@(%-O<G0@9&ER96-T
M:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A
M<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q
M("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713;W)T9614
M<F5E*"1R;V]T+"`D;&]A9%1R964@/2!F86QS92P@)'-O<G1B>5]N86UE(#T@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]K97D@
M/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D<R!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1O8FIE8W0@("`@
M("`@(%1H92!O8FIE8W0@=&\@861D("AS=')I;F<@;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$871A5')E94]B:F5C="DN"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D:61?87-?;F%M92`@5')U92!O<B!F86QS92!T
M;R!I;F1I8V%T92!I9B!O8FIE8W0@240@:7,@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B92!U<V5D(&%S(&]B:F5C="!N86UE+B!5
M<V5D(&EN('-I='5A=&EO;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!W:&5R92!T:&5R92!I<R!N;R!A=F%I;&%B;&4@=6YI<75E(&EN
M<'5T(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B
M:F5C="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)&]B:F5C="P@
M)&ED7V%S7VYA;64@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@061D(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`@)&YA;64@(%1H92!S:&]R="!O8FIE8W0@;F%M92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("`D:60@("`@5&AE(&YE=R!O8FIE8W0G<R!U;FEQ
M=64@240N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@)'!I9"`@(%1H92!U;FEQ
M=64@240@;V8@=&AE(&]B:F5C="=S('!A<F5N="X*("`@("`J($!P87)A;2!I
M;G1E9V5R("`D;W)D97(@5&AE(&]R9&5R:6YG(&1A=&$@9F]R('1H92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V%D9"@D;F%M92P@)&ED+"`D<&ED+"`D;W)D97(@/2`G
M)RD*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&%;)&ED72`](&%R<F%Y*"=N
M86UE)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=P87)E;G0G(#T^("1P:60L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;W)D97(G(#T^("1O<F1E<BD["B`@("`@("`@)'1H:7,M
M/E]N86UE36%P6R1I9%T@/2`D;F%M93L*"B`@("`@("`@+RH@4VAI9G0@86QO
M;F<@=&AE(&]R9&5R('!O<VET:6]N<RX@*B\*("`@("`@("`D=&AI<RT^7W)E
M;W)D97(H)'!I9"P@)&]R9&5R+"`D:60I.PH*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&1A=&$@9F]R(&%N
M(&]B:F5C="!F<F]M('1H92!H;W)D95]D871A=')E95]A='1R:6)U=&5S"B`@
M("`@*B!T86)L92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B!\(&%R<F%Y("1C:60@(%1H92!O8FIE8W0@
M:60@=&\@9F5T8V@L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]R(&%N(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@02!H87-H(&]F(&%T=')I8G5T97,L(&]R(&$@;75L
M=&DM;&5V96P@:&%S:`H@("`@("H@("`@("`@("`@("`@("`@;V8@;V)J96-T
M(&ED<R`]/B!T:&5I<B!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971!='1R:6)U=&5S*"1C:60I"B`@("!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!O8FIE8W1S(&UA=&-H
M:6YG(&$@<V5T(&]F(&%T=')I8G5T92!C<FET97)I82X*("`@("`J"B`@("`@
M*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<V5E(&)U:6QD071T<FEB=71E
M475E<GDH*0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1C<FET97)I
M82`@(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J($!P87)A;2!S=')I
M;F<@("1P87)E;G0@("`@(%1H92!P87)E;G0@;F]D92!T;R!S=&%R="!S96%R
M8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&Q,979E;',@
M(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E
M;G0_($1E9F%U;'1S('1O(&%L;"!L979E;',N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<F5S=')I8W0@("!/;FQY(')E='5R;B!A='1R:6)U=&5S('=I=&@@
M=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%T
M=')I8G5T95]N86UE(&]R(&%T=')I8G5T95]I9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]U;G1">4%T=')I8G5T97,H)&-R:71E<FEA+"`D<&%R96YT(#T@
M1$%40512145?4D]/5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1A;&Q,979E;',@/2!T<G5E+"`D<F5S=')I8W0@/2`G;F%M92<I"B`@("![
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T
M960G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S970@;V8@
M;V)J96-T(&ED<R!B87-E9"!O;B!A('-E="!O9B!A='1R:6)U=&4@8W)I=&5R
M:6$N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'-E
M92!B=6EL9$%T=')I8G5T95%U97)Y*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@("`D8W)I=&5R:6$@("`@(%1H92!A<G)A>2!O9B!C<FET97)I82X*
M("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("`@5&AE('!A<F5N
M="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%L;$QE=F5L<R`@("!2971U<FX@86QL(&QE=F5L<RP@;W(@
M:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;"!L
M979E;',N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S=')I8W0@("`@($]N
M;'D@<F5T=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&5?;F%M92!O<B!A
M='1R:6)U=&5?:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;2`@("`@
M("`@(%1H92!O8FIE8W0@=&\@<W1A<G0@=&\@9F5T8VAI;F<*("`@("`J($!P
M87)A;2!I;G1E9V5R("1C;W5N="`@("`@("`@5&AE(&YU;6)E<B!O9B!O8FIE
M8W1S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA
M;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J
M($!P87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T
M;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER
M96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G971">4%T=')I8G5T97,H)&-R:71E<FEA+"`D
M<&%R96YT(#T@1$%40512145?4D]/5"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D86QL3&5V96QS(#T@=')U92P@)')E<W1R:6-T(#T@)VYA;64G
M+"`D9G)O;2`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M=6YT(#T@,"P@)'-O<G1B>5]N86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@
M/2`P*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N
M;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T<R!)
M1',@8GD@871T<FEB=71E('9A;'5E<RX@241S('=I=&AO=70@871T<FEB=71E
M<R!W:6QL(&)E(&%D9&5D('1O"B`@("`@*B!T:&4@96YD(&]F('1H92!S;W)T
M960@;&ES="X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'5N;W)D97)E9%]I9',@($%R<F%Y(&]F(&ED<R!T
M;R!S;W)T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?;F%M92`@("!!
M='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R
M86T@87)R87D@)'-O<G1B>5]K97D@("`@($%T=')I8G5T92!K97D@=&\@=7-E
M(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1D:7)E8W1I;VX@
M("`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!3;W)T960@:61S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S;W)T0GE!='1R:6)U=&5S*"1U;F]R9&5R961?:61S+"`D<V]R
M=&)Y7VYA;64@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P<&]R=&5D
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE(&1A=&$@:6X@
M86X@;V)J96-T+B!$;V5S(&YO="!C:&%N9V4@=&AE(&]B:F5C="=S"B`@("`@
M*B!P87)E;G0@;W(@;F%M92P@:G5S="!S97)I86QI>F5D(&1A=&$@;W(@871T
M<FEB=71E<RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@
M*B!`<&%R86T@1&%T851R964@)&]B:F5C="`@02!$871A5')E92!O8FIE8W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T941A=&$H)&]B:F5C="D*("`@
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O
M<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!T=V\@;V)J96-T
M<R!B>2!T:&5I<B!O<F1E<B!F:65L9"P@86YD(&EF('1H870@:7,@=&AE('-A
M;64L"B`@("`@*B!A;'!H86)E=&EC86QL>2`H8V%S92!I;G-E;G-I=&EV92D@
M8GD@;F%M92X*("`@("`J"B`@("`@*B!9;W4@;F5V97(@8V%L;"!T:&ES(&9U
M;F-T:6]N.R!I="=S('5S960@:6X@=6%S;W)T*"D@8V%L;',N($1O"B`@("`@
M*B!.3U0@=7-E('5S;W)T*"D[('EO=2=L;"!L;W-E(&ME>2`]/B!V86QU92!A
M<W-O8VEA=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A("!4
M:&4@9FER<W0@;V)J96-T"B`@("`@*B!`<&%R86T@87)R87D@)&(@(%1H92!S
M96-O;F0@;V)J96-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`Q
M(&EF("1A('-H;W5L9"!B92!F:7)S="P*("`@("`J("`@("`@("`@("`@("`@
M("`M,2!I9B`D8B!S:&]U;&0@8F4@9FER<W0L"B`@("`@*B`@("`@("`@("`@
M("`@("`@(#`@:68@=&AE>2!A<F4@96YT:7)E;'D@97%U86PN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;7`H)&$L("1B*0H@("`@>PH@("`@("`@(&EF("@D
M85LG;W)D97(G72`^("1B6R=O<F1E<B==*2!["B`@("`@("`@("`@(')E='5R
M;B`Q.PH@("`@("`@('T@96QS96EF("@D85LG;W)D97(G72`\("1B6R=O<F1E
M<B==*2!["B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@<W1R8V%S96-M<"@D85LG;F%M92==+"`D
M8ELG;F%M92==*3L*("`@("`@("!]"B`@("!]"@H@("`@("\J*@H@("`@("H@
M4V]R=',@='=O(&]B:F5C=',@8GD@=&AE:7(@<V]R=&5R(&AA<V@@9FEE;&0N
M"B`@("`@*@H@("`@("H@66]U(&YE=F5R(&-A;&P@=&AI<R!F=6YC=&EO;CL@
M:70G<R!U<V5D(&EN('5A<V]R="@I(&-A;&QS+B!$;R!.3U0@=7-E"B`@("`@
M*B!U<V]R="@I.R!Y;W4G;&P@;&]S92!K97D@/3X@=F%L=64@87-S;V-I871I
M;VYS+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&$@(%1H92!F:7)S="!O8FIE8W0*("`@("`J
M($!P87)A;2!A<G)A>2`D8B`@5&AE('-E8V]N9"!O8FIE8W0*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(#$@:68@)&$@<VAO=6QD(&)E(&9I<G-T
M+`H@("`@("H@("`@("`@("`@("`@("`@("TQ(&EF("1B('-H;W5L9"!B92!F
M:7)S="P*("`@("`J("`@("`@("`@("`@("`@("`@,"!I9B!T:&5Y(&%R92!E
M;G1I<F5L>2!E<75A;"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-M<%-O<G1E
M9"@D82P@)&(I"B`@("!["B`@("`@("`@:68@*"1A6R=S;W)T97(G75LD=&AI
M<RT^7W-O<G1(87-H72`\("1B6R=S;W)T97(G75LD=&AI<RT^7W-O<G1(87-H
M72D@>PH@("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!$871A5')E
M92!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!$871A
M5')E92!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@5&AI<R!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@
M*"1D<FEV97(I+B!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C
M;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+B!)9B`D9')I=F5R(&ES(&%N
M(&%R<F%Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H96X@=V4@
M=VEL;"!L;V]K(&EN("1D<FEV97);,%TO;&EB+T1A=&%4<F5E+R!F;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@<W5B8VQA<W,@:6UP;&5M
M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@2&5R92P@=V4@;F5E
M9"`G9W)O=7`G(#T@82!S=')I;F<@=&AA="!D969I;F5S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@=&]P+6QE=F5L(&=R;W5P<R!O9B!O8FIE8W1S
M+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R964@(%1H92!N97=L>2!C
M<F5A=&5D(&-O;F-R971E($1A=&%4<F5E(&EN<W1A;F-E+"!O<B!F86QS90H@
M("`@("H@("`@("`@("`@("`@("`@("`@;VX@86X@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*
M"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@
M)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V1A=&%T<F5E)RP@
M)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)&1R:79E
M<BDI('L*("`@("`@("`@("`@)&1R:79E<B`]("=N=6QL)SL*("`@("`@("!]
M"@H@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O1&%T851R964O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)T1A=&%4<F5E7R<@
M+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`D9'0@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9'0@/2!014%2.CIR86ES945R
M<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F
M;W5N9"XG*3L*("`@("`@("!]"B`*("`@("`@("!R971U<FX@)&1T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E
M;F-E('1O(&$@8V]N8W)E=&4@1&%T851R964@:6YS=&%N8V4@8F%S960@;VX*
M("`@("`J("1D<FEV97(N"B`@("`@*@H@("`@("H@270@=VEL;"!O;FQY(&-R
M96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!$871A5')E92!I;G-T86YC92!W
M:71H('1H92!S86UE"B`@("`@*B!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES
M=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT
M:7!L92!$871A5')E92!S;W5R8V5S("AA;F0L('1H=7,L(&UU;'1I<&QE"B`@
M("`@*B!$871A5')E92!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J
M"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@
M/2`F1&%T851R964Z.G-I;F=L971O;B@I.PH@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!4>7!E(&]F(&-O;F-R971E($1A=&%4<F5E('-U
M8F-L87-S('1O(')E='5R;BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!B87-E9"!O;B!S=&]R86=E(&1R:79E<B`H)&1R:79E<BDN(%1H92!C;V1E
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9'EN86UI8V%L;'D@
M:6YC;'5D960N($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!L;V]K(&EN("1D<FEV97);,%TO;&EB
M+T1A=&%4<F5E+R!F;W(@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B
M8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&%4
M<F5E("!4:&4@8V]N8W)E=&4@1&%T851R964@<F5F97)E;F-E+"!O<B!F86QS
M92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O
M;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T
M:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I
M*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@
M("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V1A=&%T<F5E
M)RP@)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@
M<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I
M9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@
M("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F1&%T851R964Z.F9A8W1O
M<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*"B\J*@H@*B!#
M;&%S<R!T:&%T(&-A;B!B92!E>'1E;F1E9"!T;R!S879E(&%R8FET<F%R>2!I
M;F9O<FUA=&EO;B!A<R!P87)T(&]F(&$@<W1O<F5D"B`J(&]B:F5C="X*("H*
M("H@0&%U=&AO<B`@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N
M8V]M/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E
M7T1A=&%4<F5E"B`J+PIC;&%S<R!$871A5')E94]B:F5C="!["@H@("`@+RHJ
M"B`@("`@*B!4:&ES(&]B:F5C="=S($1A=&%4<F5E(&EN<W1A;F-E+@H@("`@
M("H*("`@("`J($!V87(@1&%T851R964*("`@("`J+PH@("`@=F%R("1D871A
M=')E93L*"B`@("`O*BH*("`@("`J($ME>2UV86QU92!H87-H('1H870@=VEL
M;"!B92!S97)I86QI>F5D+@H@("`@("H*("`@("`J($!S964@9V5T1&%T82@I
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9&%T82`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@=6YI<75E(&YA;64@;V8@=&AI
M<R!O8FIE8W0N"B`@("`@*B!4:&5S92!N86UE<R!H879E('1H92!S86UE(')E
M<75I<F5M96YT<R!A<R!O=&AE<B!O8FIE8W0@;F%M97,@+2!T:&5Y(&UU<W0*
M("`@("`J(&)E('5N:7%U92P@971C+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D;F%M93L*"B`@("`O*BH*("`@("`J($EF
M('1H:7,@;V)J96-T(&AA<R!O<F1E<FEN9R!D871A+"!S=&]R92!I="!H97)E
M+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@
M)&]R9&5R(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($1A=&%4<F5E3V)J96-T
M(&-O;G-T<G5C=&]R+@H@("`@("H@2G5S="!S971S('1H92`D;F%M92!P87)A
M;65T97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&]B:F5C="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!$871A5')E94]B
M:F5C="@D;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^<V5T3F%M92@D;F%M
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92![0&QI;FL@1&%T
M851R965](&EN<W1A;F-E('5S960@=&\@<F5T<FEE=F4@=&AI<R!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E("1D871A=')E92`@02![
M0&QI;FL@1&%T851R965](&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971$871A5')E92@F)&1A=&%T<F5E*0H@("`@>PH@("`@("`@("1T:&ES
M+3YD871A=')E92`]("8D9&%T871R964["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'971S('1H92!N86UE(&]F('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG(%1H92!O8FIE8W0@;F%M92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YN86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;F%M92!O
M9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!.3U1%.B!5<V4@=VET:"!C
M875T:6]N+B!4:&ES(&UA>2!T:')O=R!O=70@;V8@<WEN8R!T:&4@8V%C:&5D
M(&1A=&%T<F5E"B`@("`@*B!T86)L97,@:68@;F]T('5S960@<')O<&5R;'DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@
M=&\@<V5T('1H:7,@;V)J96-T)W,@;F%M92!T;RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T3F%M92@D;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^;F%M
M92`]("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@<VAO
M<G0@;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J($9O<B!D:7-P;&%Y('!U
M<G!O<V5S(&]N;'DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!O8FIE8W0G<R!S:&]R="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713:&]R=$YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B!$871A5')E93HZ
M9V5T4VAO<G1.86UE*"1T:&ES+3YN86UE*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE($E$(&]F('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@;V)J96-T)W,@240N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F1A=&%T<F5E+3YG971)9"@D=&AI<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'971S('1H92!D871A(&%R<F%Y+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!I;G1E<FYA;"!D871A(&%R<F%Y+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971$871A*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!D871A(&%R
M<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@5&AE(&1A=&$@87)R
M87D@=&\@<W1O<F4@:6YT97)N86QL>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1&%T82@D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^9&%T82`]("1D
M871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;W)D97(@;V8@
M=&AI<R!O8FIE8W0@:6X@:71S(&]B:F5C="!C;VQL96-T:6]N+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1O<F1E<@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971/<F1E<B@D;W)D97(I"B`@("!["B`@("`@("`@)'1H:7,M/F]R
M9&5R(#T@)&]R9&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&ES(&]B:F5C="=S('!A<F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;&%S<R`@(%-U8F-L87-S(&]F($1A=&%4<F5E3V)J96-T('1O('5S
M92X@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M1&%T851R965/8FIE8W0N($YU;&P@9F]R8V5S('1H92!D<FEV97(@=&\@;&]O
M:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;G1O('1H92!A='1R
M:6)U=&5S('1A8FQE('1O(&1E=&5R;6EN92!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@<W5B8VQA<W,@=&\@=7-E+B!)9B!N;VYE(&ES(&9O
M=6YD(&ET('5S97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@1&%T
M851R965/8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B
M:F5C="`@5&AI<R!O8FIE8W0G<R!P87)E;G0*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=%!A<F5N="@D8VQA<W,@/2`G1&%T851R965/8FIE8W0G*0H@("`@
M>PH@("`@("`@("1I9"`]("1T:&ES+3YD871A=')E92T^9V5T4&%R96YT*"1T
M:&ES*3L*("`@("`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YD871A=')E92T^9V5T3V)J96-T0GE)9"@D:60L("1C;&%S
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8VAI;&0@;V8@
M=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@("`@("`@(%1H92!C:&EL9"=S(&YA;64N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D875T;V-R96%T92`@268@=')U92!A;F0@;F\@8VAI;&0@=VET:"!T
M:&4@9VEV96X@;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5X:7-T<RP@;VYE(&=E=',@8W)E871E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F=E=$-H:6QD*"1N86UE+"`D875T;V-R96%T92`]('1R=64I"B`@
M("!["B`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+B`G
M.B<@+B`D;F%M93L*"B`@("`@("`@+RH@268@=&AE(&-H:6QD('-H;W5L9&XG
M="!G970@8W)E871E9"P@=V4@9&]N)W0@8VAE8VL@9F]R(&ET<PH@("`@("`@
M("`J(&5X:7-T86YC92!T;R!R971U<FX@=&AE(")N;W0@9F]U;F0B(&5R<F]R
M(&]F"B`@("`@("`@("H@9V5T3V)J96-T*"DN("HO"B`@("`@("`@:68@*"$D
M875T;V-R96%T92!\?"`D=&AI<RT^9&%T871R964M/F5X:7-T<R@D;F%M92DI
M('L*("`@("`@("`@("`@)&-H:6QD(#T@)B1T:&ES+3YD871A=')E92T^9V5T
M3V)J96-T*"1N86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8VAI;&0@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1N86UE*3L*("`@("`@("`@
M("`@)&-H:6QD+3YS971$871A5')E92@D=&AI<RT^9&%T871R964I.PH@("`@
M("`@("`@("`D=&AI<RT^9&%T871R964M/F%D9"@D8VAI;&0I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1C:&EL9#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-A=F5S(&%N>2!C:&%N9V5S('1O('1H:7,@;V)J96-T('1O('1H92!B
M86-K96YD('!E<FUA;F5N=&QY+B!.97<@;V)J96-T<PH@("`@("H@87)E(&%D
M9&5D(&EN<W1E860N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%
M05)?17)R;W(@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V%V92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YD871A
M=')E92T^97AI<W1S*"1T:&ES*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F1A=&%T<F5E+3YU<&1A=&5$871A*"1T:&ES*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1A=&%T<F5E+3YA9&0H
M)'1H:7,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T
M92!T:&ES(&]B:F5C="!F<F]M('1H92!B86-K96YD('!E<FUA;F5N=&QY+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A=')E92T^<F5M
M;W9E*"1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@;VYE(&]F
M('1H92!A='1R:6)U=&5S(&]F('1H92!O8FIE8W0L(&]R(&YU;&P@:68@:70@
M:7-N)W0@9&5F:6YE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M='1R:6)U=&4@(%1H92!A='1R:6)U=&4@=&\@9V5T+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1H92!V86QU92!O9B!T:&4@871T<FEB=71E+"!O
M<B!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&%T=')I8G5T92D*
M("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/F1A=&%;)&%T=')I
M8G5T95TI"B`@("`@("`@("`@(#\@)'1H:7,M/F1A=&%;)&%T=')I8G5T95T*
M("`@("`@("`@("`@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M<R!O;F4@;V8@=&AE(&%T=')I8G5T97,@;V8@=&AE(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U=&4@(%1H92!A='1R:6)U
M=&4@=&\@<V5T+@H@("`@("H@0'!A<F%M(&UI>&5D("1V86QU92`@("`@("!4
M:&4@=F%L=64@9F]R("1A='1R:6)U=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E="@D871T<FEB=71E+"`D=F%L=64I"B`@("!["B`@("`@("`@)'1H:7,M
M/F1A=&%;)&%T=')I8G5T95T@/2`D=F%L=64["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]097)M<RYP:'``````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,S$R,C4`,3`U,34T,S$P-C$`,#(P,#$V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@HO*BH@
M17AI<W1E;F-E(&]F(&]B:F5C="!I<R!K;F]W;B`M(&]B:F5C="!I<R!S:&]W
M;B!T;R!U<V5R+B`J+PID969I;F4H)U!%4DU37U-(3U<G+"`R*3L*"B\J*B!#
M;VYT96YT<R!O9B!T:&4@;V)J96-T(&-A;B!B92!R96%D+B`J+PID969I;F4H
M)U!%4DU37U)%040G+"`T*3L*"B\J*B!#;VYT96YT<R!O9B!T:&4@;V)J96-T
M(&-A;B!B92!E9&ET960N("HO"F1E9FEN92@G4$5235-?141)5"<L(#@I.PH*
M+RHJ(%1H92!O8FIE8W0@8V%N(&)E(&1E;&5T960N("HO"F1E9FEN92@G4$52
M35-?1$5,151%)RP@,38I.PH*+RHJ"B`J($$@8FET;6%S:R!O9B!A;&P@<&]S
M<VEB;&4@<&5R;6ES<VEO;B!V86QU97,N(%5S969U;"!F;W(*("H@<F5M;W9E
M6'AX4&5R;6ES<VEO;B@I+"!U;G-E=%!E<FTH*2P@971C+@H@*B\*9&5F:6YE
M*"=015)-4U]!3$PG+"!015)-4U]32$]7('P@4$5235-?4D5!1"!\(%!%4DU3
M7T5$250@?"!015)-4U]$14Q%5$4I.PH*+RHJ"B`J(%1H92!097)M<SHZ(&-L
M87-S('!R;W9I9&5S('1H92!(;W)D92!P97)M:7-S:6]N<R!S>7-T96TN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<"QV(#$N.#`N
M,3`N.2`R,#`V+S`U+S`U(#`T.C`X.C4Y('-E;'-K>2!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7U!E<FUS"B`J+PIC;&%S<R!097)M
M<R!["@H@("`@+RHJ"B`@("`@*B!#86-H97,@:6YF;W)M871I;VX@86)O=70@
M87!P;&EC871I;VX@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!L:6-A=&EO;E!E<FUI<W-I;VYS
M.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@879A:6QA8FQE('!E<FUI
M<W-I;VYS(&9O<B!A(&=I=F5N(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I;&%B;&4@
M<&5R;6ES<VEO;G,@86YD('1H96ER('1I=&QE<R!O<@H@("`@("H@("`@("`@
M("`@("`@("`@9F%L<V4@:68@;F]T('-U8B!P97)M:7-S:6]N<R!E>&ES="!F
M;W(@=&AI<R!L979E;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T079A:6QA
M8FQE*"1N86UE*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@
M("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@+RH@3F\@
M;F%M92!P87-S960L('-O('1O<"!L979E;"!P97)M:7-S:6]N<R!A<F4@<F5Q
M=65S=&5D+B!4:&5S90H@("`@("`@("`@("`@*B!C86X@;VYL>2!B92!A<'!L
M:6-A=&EO;G,N("HO"B`@("`@("`@("`@("1A<'!S(#T@)')E9VES=')Y+3YL
M:7-T07!P<RAA<G)A>2@G;F]T;V]L8F%R)RP@)V%C=&EV92<L("=H:61D96XG
M*2P@=')U92D["B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)&%P
M<',I(&%S("1A<'`I('L*("`@("`@("`@("`@("`@("1A<'!S6R1A<'!=(#T@
M)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2`N("<@*"<@+B`D87!P("X@
M)RDG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&%S;W)T*"1A<'!S*3L*
M("`@("`@("`@("`@<F5T=7)N("1A<'!S.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\J($YA;64@:&%S(&)E96X@<&%S<V5D+"!E>'!L;V1E('1H
M92!N86UE('1O(&=E="!A;&P@=&AE(&QE=F5L<R!I;@H@("`@("`@("`@("`@
M*B!P97)M:7-S:6]N(&)E:6YG(')E<75I<W1E9"P@=VET:"!T:&4@87!P(&%S
M('1H92!F:7)S="!L979E;"X@*B\*("`@("`@("`@("`@)&QE=F5L<R`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1L979E;',@/2!E>'!L;V1E*"<Z)RP@)&YA
M;64I.PH*("`@("`@("`@("`@+RH@1FER<W0@;&5V96P@:7,@86QW87ES(&%P
M<"X@*B\*("`@("`@("`@("`@)&%P<"`]("1L979E;'-;,%T["@H@("`@("`@
M("`@("`O*B!2971U<FX@96UP='D@:68@;F\@87!P(&1E9FEN960@05!)(&UE
M=&AO9"!F;W(@<')O=FED:6YG"B`@("`@("`@("`@("`J('!E<FUI<W-I;VX@
M:6YF;W)M871I;VXN("HO"B`@("`@("`@("`@(&EF("@A)')E9VES=')Y+3YH
M87--971H;V0H)W!E<FUS)RP@)&%P<"DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V%L
M;"!T:&4@87!P)W,@<&5R;6ES<VEO;B!F=6YC=&EO;B!T;R!R971U<FX@=&AE
M('!E<FUI<W-I;VYS"B`@("`@("`@("`@("`J('-P96-I9FEC('1O('1H:7,@
M87!P+B`J+PH@("`@("`@("`@("`D<&5R;7,@/2`D=&AI<RT^9V5T07!P;&EC
M871I;VY097)M:7-S:6]N<R@D87!P*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)'!E<FUS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'!E<FUS.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("\J($=E="!T
M:&4@<&%R="!O9B!T:&4@87!P)W,@<&5R;6ES<VEO;G,@8F%S960@;VX@=&AE
M('!E<FUI<W-I;VX*("`@("`@("`@("`@("H@;F%M92!R97%U97-T960N("HO
M"B`@("`@("`@("`@("1C:&EL9')E;B`]($AO<F1E7T%R<F%Y.CIG971%;&5M
M96YT*"1P97)M<ULG=')E92==+"`D;&5V96QS*3L*("`@("`@("`@("`@:68@
M*"1C:&EL9')E;B`]/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("%I<U]A
M<G)A>2@D8VAI;&1R96XI('Q\"B`@("`@("`@("`@("`@("`A8V]U;G0H)&-H
M:6QD<F5N*2D@>PH@("`@("`@("`@("`@("`@+RH@3F\@87)R87D@;V8@8VAI
M;&1R96X@879A:6QA8FQE(&9O<B!T:&ES('!E<FUI<W-I;VX@;F%M92X@*B\*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'!E<FUS7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!F;W)E86-H("@D8VAI;&1R96X@87,@)'!E<FU?:V5Y(#T^("1P97)M7W9A
M;"D@>PH@("`@("`@("`@("`@("`@)'!E<FUS7VQI<W1;)'!E<FU?:V5Y72`]
M("1P97)M<ULG=&ET;&4G75LD;F%M92`N("<Z)R`N("1P97)M7VME>5T["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1P97)M<U]L:7-T.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-H
M;W)T(&YA;64@;V8@86X@;V)J96-T+"!T:&4@;&%S="!P;W)T:6]N(&]F('1H
M92!F=6QL(&YA;64N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!O8FIE8W0G
M<R!S:&]R="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&]R=$YA
M;64H)&YA;64I"B`@("!["B`@("`@("`@+RH@268@=&AE<F4@87)E('-E=F5R
M86P@8V]M<&]N96YT<R!T;R!T:&4@;F%M92P@97AP;&]D92!A;F0*("`@("`@
M("`@*B!G970@=&AE(&QA<W0@;VYE+"!O=&AE<G=I<V4@:G5S="!R971U<FX@
M=&AE(&YA;64N("HO"B`@("`@("`@:68@*'-T<G!O<R@D;F%M92P@)SHG*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1M<"`](&5X<&QO9&4H)SHG+"`D
M;F%M92D["B`@("`@("`@("`@(')E='5R;B!A<G)A>5]P;W`H)'1M<"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1N86UE.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@<&5R;6ES<VEO
M;B!N86UE+"!R971U<FYS('1H92!T:71L92!F;W(@=&AA="!P97)M:7-S:6]N
M(&)Y"B`@("`@*B!L;V]K:6YG(&ET('5P(&EN('1H92!A<'!L:6-A=&EO;G,G
M<R!P97)M:7-S:6]N(&%P:2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@<&5R;6ES<VEO;G,G<R!N86UE+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@=&ET;&4@9F]R('1H92!P97)M:7-S:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:71L92@D;F%M92D*("`@('L*
M("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;&5V96QS(#T@
M97AP;&]D92@G.B<L("1N86UE*3L*("`@("`@("!I9B`H8V]U;G0H)&QE=F5L
M<RD@/3T@,2D@>PH@("`@("`@("`@("!R971U<FX@)')E9VES=')Y+3YG970H
M)VYA;64G+"`D;F%M92D@+B`G("@G("X@)&YA;64@+B`G*2<["B`@("`@("`@
M?0H@("`@("`@("1P97)M(#T@87)R87E?<&]P*"1L979E;',I.PH*("`@("`@
M("`O*B!&:7)S="!L979E;"!I<R!A;'=A>7,@87!P+B`J+PH@("`@("`@("1A
M<'`@/2`D;&5V96QS6S!=.PH*("`@("`@("`O*B!2971U<FX@96UP='D@:68@
M;F\@87!P(&1E9FEN960@05!)(&UE=&AO9"!F;W(@<')O=FED:6YG('!E<FUI
M<W-I;VX*("`@("`@("`@*B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H
M(21R96=I<W1R>2T^:&%S365T:&]D*"=P97)M<R<L("1A<'`I*2!["B`@("`@
M("`@("`@(')E='5R;B!097)M<SHZ9V5T4VAO<G1.86UE*"1N86UE*3L*("`@
M("`@("!]"@H@("`@("`@("1A<'!?<&5R;7,@/2`D=&AI<RT^9V5T07!P;&EC
M871I;VY097)M:7-S:6]N<R@D87!P*3L*"B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1A<'!?<&5R;7-;)W1I=&QE)UU;)&YA;65=*0H@("`@("`@("`@("`_("1A
M<'!?<&5R;7-;)W1I=&QE)UU;)&YA;65=("X@)R`H)R`N($1A=&%4<F5E.CIG
M9713:&]R=$YA;64H)&YA;64I("X@)RDG"B`@("`@("`@("`@(#H@1&%T851R
M964Z.F=E=%-H;W)T3F%M92@D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T('!E<FUI<W-I;VYS(&EM<&QE
M;65N=&5D(&)Y(&%N(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!S:6YC
M92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@
M($%N(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@2&%S:"!W:71H('!E<FUI<W-I;VYS(&EN9F]R;6%T:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971!<'!L:6-A=&EO;E!E<FUI<W-I;VYS*"1A
M<'`I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V%P<&QI8V%T
M:6]N4&5R;6ES<VEO;G-;)&%P<%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M87!P;&EC871I;VY097)M:7-S:6]N<ULD87!P72`]("1'3$]"04Q36R=R96=I
M<W1R>2==+3YC86QL0GE086-K86=E*"1A<'`L("=P97)M<R<I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?87!P;&EC871I;VY097)M:7-S
M:6]N<ULD87!P73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!N
M97<@<&5R;6ES<VEO;G,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%!E<FUI<W-I;VYS("!!(&YE=R!P97)M:7-S:6]N<R!O
M8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=097)M:7-S:6]N*"1N
M86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!0
M97)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@4&5R;6ES<VEO;B!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@;F%M
M960@<&5R;6ES<VEO;BP*("`@("`J('=I=&@@=&AE('5S97)S(&%N9"!O=&AE
M<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!P97)M:7-S
M:6]N('1O(')E=')I979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4&5R
M;6ES<VEO;B@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N(BDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(%!E<FUI<W-I;VX@;V)J96-T(&-O<G)E<W!O;F1I;F<@
M=&\@=&AE(&=I=F5N('5N:7%U92!)1"P@=VET:`H@("`@("H@=&AE('5S97)S
M(&%N9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!U;FEQ=64@240@
M;V8@=&AE('!E<FUI<W-I;VX@=&\@<F5T<FEE=F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9G971097)M:7-S:6]N0GE)9"@D8VED*0H@("`@>PH@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<&5R;6ES<VEO;B!T;R!T:&4@
M<&5R;6ES<VEO;G,@<WES=&5M+B!4:&4@<&5R;6ES<VEO;B!M=7-T(&9I<G-T
M"B`@("`@*B!B92!C<F5A=&5D('=I=&@@4&5R;3HZ;F5W4&5R;6ES<VEO;B@I
M+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@861D960@=&\@
M:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@4&5R;6ES<VEO;B`D<&5R;2`@5&AE(&YE=R!P97)M(&]B
M:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&5R;6ES<VEO;B@F)'!E
M<FTI"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@
M82!P97)M:7-S:6]N(&9R;VT@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2!P97)M
M86YE;G1L>2X*("`@("`J"B`@("`@*B!`<&%R86T@4&5R;6ES<VEO;B`D<&5R
M;2`@5&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&9O<F-E("`@($9O<F-E('1O(')E;6]V92!E=F5R>2!C:&EL9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E4&5R;6ES<VEO;B@F)'!E<FTL
M("1F;W)C92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W
M86YT('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&:6YD<R!O=70@=VAA="!R:6=H=',@=&AE(&=I=F5N('5S97(@:&%S
M('1O('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M<&5R;6ES<VEO;B`@5&AE(&9U;&P@<&5R;6ES<VEO;B!N86UE(&]F('1H92!O
M8FIE8W0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8VAE
M8VL@=&AE('!E<FUI<W-I;VYS(&]F+"!O<B!T:&4@4&5R;6ES<VEO;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R("`@("`@(%1H92!U<V5R('1O(&-H96-K(&9O
M<BX@1&5F875L=',@=&\@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&-R
M96%T;W(@("`@5&AE('5S97(@=VAO(&-R96%T960@=&AE(&5V96YT+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($$@8FET;6%S:R!O9B!P97)M:7-S
M:6]N<R!T:&4@=7-E<B!H87,L(&9A;'-E(&EF('1H97)E"B`@("`@*B`@("`@
M("`@("`@("`@("!A<F4@;F]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VXL("1U<V5R(#T@;G5L;"P@)&-R96%T
M;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!U;FEQ=64@:61E;G1I9FEE<B!O9B!T:&ES('!E<FUI<W-I
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(%!E<FUI<W-I;VX@)'!E<FUI<W-I
M;VX@(%1H92!P97)M:7-S:6]N(&]B:F5C="!T;R!G970@=&AE($E$(&]F+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('5N:7%U92!I9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S
M:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!0
M97)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD<R!O
M=70@:68@=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<FEG:'1S('1O('1H
M92!G:79E;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)'5S97(@("`@("`@(%1H92!U<V5R('1O(&-H96-K
M(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@("!4:&4@
M<&5R;6ES<VEO;B!L979E;"!N965D960@9F]R(&%C8V5S<RX*("`@("`J($!P
M87)A;2!S=')I;F<@("1C<F5A=&]R("`@("!4:&4@8W)E871O<B!O9B!T:&4@
M979E;G0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U
M<V5R+"`D<&5R;2P@)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A
M('!E<FUI<W-I;VX@97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@
M=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H92!P97)M:7-S:6]N(&5X:7-T<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@97AI<W1S*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F
M('!A<F5N="!P97)M:7-S:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C:&EL9"`@5&AE(&YA;64@;V8@=&AE(&-H:6QD('1O(')E=')I979E
M('!A<F5N=',@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@
M:&%S:"!W:71H(&%L;"!P87)E;G1S(&EN(&$@=')E92!F;W)M870N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=',H)&-H:6QD*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!P97)M:7-S:6]N
M<R!O9B!T:&4@<WES=&5M(&EN(&$@=')E92!F;W)M870N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@86QL('!E<FUI<W-I;VYS
M(&EN(&$@=')E92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1R
M964H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A;B!H87-H(&]F('1H92!A=F%I;&%B;&4@
M<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&%V86EL86)L92!P97)M:7-S:6]N<R!A<R!A(&AA<V@N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!E<FUS07)R87DH*0H@("`@>PH@("`@("`@(')E='5R
M;B!A<G)A>2A015)-4U]32$]7(#T^(%\H(E-H;W<B*2P*("`@("`@("`@("`@
M("`@("`@("`@4$5235-?4D5!1"`]/B!?*")296%D(BDL"B`@("`@("`@("`@
M("`@("`@("`@(%!%4DU37T5$250@/3X@7R@B161I="(I+`H@("`@("`@("`@
M("`@("`@("`@("!015)-4U]$14Q%5$4@/3X@7R@B1&5L971E(BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:6YT96=E<B!V86QU92!O9B!P
M97)M:7-S:6]N<R!R971U<FYS(&%N(&%R<F%Y"B`@("`@*B!R97!R97-E;G1A
M=&EO;B!O9B!T:&4@:6YT96=E<BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D:6YT("!4:&4@:6YT96=E<B!R97!R97-E;G1A=&EO;B!O9B!P97)M
M:7-S:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YT96=E<E1O07)R87DH
M)&EN="D*("`@('L*("`@("`@("!S=&%T:6,@)&%R<F%Y(#T@87)R87DH*3L*
M("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1I;G1=*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&%R<F%Y6R1I;G1=.PH@("`@("`@('T*"B`@("`@("`@)&%R
M<F%Y6R1I;G1=(#T@87)R87DH*3L*"B`@("`@("`@+RH@1V5T('1H92!A=F%I
M;&%B;&4@<&5R;7,@87)R87DN("HO"B`@("`@("`@)'!E<FUS(#T@4&5R;7,Z
M.F=E=%!E<FUS07)R87DH*3L*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&5A
M8V@@<&5R;2!A;F0@8VAE8VL@:68@:71S('9A;'5E(&ES(&EN8VQU9&5D(&EN
M('1H90H@("`@("`@("`J(&EN=&5G97(@<F5P<F5S96YT871I;VXN("HO"B`@
M("`@("`@9F]R96%C:"`H)'!E<FUS(&%S("1V86P@/3X@)&QA8F5L*2!["B`@
M("`@("`@("`@(&EF("@D:6YT("8@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M)&%R<F%Y6R1I;G1=6R1V86Q=(#T@=')U93L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1A<G)A>5LD:6YT73L*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E(%!E
M<FUS(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!T:&4@8V]N8W)E
M=&4@4&5R;7,@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@=&\@<F5T=7)N+B`@5&AE(&-L87-S(&YA;64@:7,@8F%S960@;VX@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('!E<FUS(&1R:79E<B`H
M)&1R:79E<BDN("!4:&4@8V]D92!I<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(%!E<FUS?&)O;VQE86X@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R
M971E(%!E<FUS(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A8W1O<GDH)&1R:79E<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@("`@("`@)'!E<FUS(#T@)FYE
M=R!097)M<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EN8VQU
M9&5?;VYC92`G2&]R9&4O4&5R;7,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@("`@("1C;&%S<R`]("=097)M<U\G("X@)&1R:79E<CL*("`@("`@
M("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@
M("`@("`D<&5R;7,@/2`F;F5W("1C;&%S<R@I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'!E<FUS(#T@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&5R;7,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N
M8V4@=&\@82!C;VYC<F5T92!097)M<R!I;G-T86YC92X*("`@("`J($ET('=I
M;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@4&5R;7,@:6YS
M=&%N8V4*("`@("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)E!E<FUS
M.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!R971U<FX@4&5R;7-\8F]O
M;&5A;B`@5&AE(&-O;F-R971E(%!E<FT@<F5F97)E;F-E+"!O<B!F86QS92!O
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@
M("!["B`@("`@("`@<W1A=&EC("1P97)M.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1P97)M*2D@>PH@("`@("`@("`@("`D<&5R;2`]("9097)M<SHZ9F%C=&]R
M>2@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG9&%T871R964G75LG9')I=F5R
M)UTI(#\@)V1A=&%T<F5E)R`Z(&YU;&PI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1P97)M.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-;V)I;&4N<&AP````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#<P-S,`,3`U,34T,S$P-C$`,#(P,30T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO
M<F1E7TUO8FEL95]C87)D(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@
M>PH*("`@('9A<B`D7VYA;64["B`@("!V87(@)%]T:71L93L*("`@('9A<B`D
M7V9O<FT["B`@("!V87(@)%]E;&5M96YT<R`](&%R<F%Y*"D["B`@("!V87(@
M)%]S;V9T:V5Y<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("!4:&4@
M;F%M92!O9B!T:&ES(&-A<F0N($-A;B!B92!U<V5D(&EN(&%N8VAO<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&QI;FMS+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&ET;&4@($EF(&$@<W1R:6YG(&ES('!R;W9I9&5D(&AE<F4L
M(&ET('=I;&P@8F4@9&ES<&QA>65D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:6X@=&AE($A434P@=&ET;&4@8F%R+"!R97-P96-T:79E;'D@<V]M
M97=H97)E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE(%=!
M4"!D:7-P;&%Y+B!5<VEN9R!A('1I=&QE('EO=2!W:6QL(&YO<FUA;&QY"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:&%V92!T;R!S<&5N9"!O;F4@
M;V8@>6]U<B!F97<@;&EN97,@;VX@>6]U<B!705`*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!D:7-P;&%Y+B!#;VYS:61E<B!T:&%T('-O;64@5T%0
M('!H;VYE<R]31$LG<R!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!H86YD:&5L9"!D979I8V5S(&1O;B=T(&1I<W!L87D@=&AE('1I=&QE(&%T
M(&%L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7V-A<F0H
M)&YA;64@/2!N=6QL+"`D=&ET;&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D
M=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@)F%D9"@F)&5L96UE;G0I"B`@
M("!["B`@("`@("`@<W1A=&EC("1L:6YK<V5T061D960["@H@("`@("`@(&EF
M("@A:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]E;&5M96YT)RDI('L*
M("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI
M9"!E;&5M96YT+B<I.PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@
M("`@('T@96QS96EF("AI<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7W1E
M>'0G*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G2&]R
M9&5?36]B:6QE7W1A8FQE)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D
M96QE;65N="P@)TAO<F1E7TUO8FEL95]I;6%G92<I('Q\"B`@("`@("`@("`@
M("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?;&EN:R<I('Q\
M"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I
M;&5?<&AO;F4G*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT
M+"`G2&]R9&5?36]B:6QE7W)U;&4G*2D@>PH@("`@("`@("`@("`D8FQO8VL@
M/2`F;F5W($AO<F1E7TUO8FEL95]B;&]C:R@D96QE;65N="D["B`@("`@("`@
M("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D8FQO8VL["B`@("`@("`@?2!E
M;'-E:68@*&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?8FQO8VLG*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&5L96UE;G0[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I
M;&5?9F]R;2<I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]F
M;W)M*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G0V%R9',@;6%Y(&]N;'D@8V]N=&%I;B!O;F4@1F]R;2!E;&5M96YT
M+B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&5L96UE
M;G0["B`@("`@("`@("`@("1T:&ES+3Y?9F]R;2`]("8D96QE;65N=#L*("`@
M("`@("!](&5L<V5I9B`H:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]L
M:6YK<V5T)RDI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;&EN:W-E=$%D
M9&5D*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G0V%R9',@;6%Y(&]N;'D@8V]N=&%I;B!O;F4@3&EN:W-E="!E;&5M
M96YT+B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D8FQO8VL@/2`F;F5W($AO<F1E7TUO8FEL
M95]B;&]C:R@D96QE;65N="D["B`@("`@("`@("`@("1T:&ES+3Y?96QE;65N
M='-;72`]("8D8FQO8VL["B`@("`@("`@("`@("1L:6YK<V5T061D960@/2!T
M<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E<G)O<B`](%!%
M05(Z.G)A:7-E17)R;W(H)U1H:7,@96QE;65N="!M=7-T(&)E(&EN<VED92!A
M;B!A<'!R;W!R:6%T92!C;VYT86EN97(@96QE;65N="XG*3L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M96QE;65N=#L*("`@('T*"B`@("!F=6YC=&EO;B!S;V9T:V5Y*"1U<FPL("1L
M86)E;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-O9G1K97ES6UT@/2!A<G)A
M>2@G=7)L)R`]/B`D=7)L+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=L86)E;"<@/3X@)&QA8F5L*3L*("`@('T*"GT*"B\J*@H@*B!(
M;W)D95]-;V)I;&4Z.@H@*@H@*B!(;W)D92!!4$D@9F]R(&=E;F5R871I;F<@
M36]B:6QE(&-O;G1E;G0N($EN8VQU9&5S(&YU;65R;W5S('5T:6QI='D*("H@
M9G5N8W1I;VYS+"!G96YE<F%L:7IE9"!E;&5M96YT(&-L87-S97,L(&%N9"!R
M96YD97)E<G,@9F]R(&UA<FMU<`H@*B!L86YG=6%G97,@:6YC;'5D:6YG(%=-
M3"P@2$1-3"P@86YD($-(5$U,+@H@*@H@*B!4:&ES(&-L87-S(&ES('1H92!T
M;W`@;&5V96P@8VQA<W,@;V8@86QL($AO<F1E7TUO8FEL92!C;&%S<V5S+B!9
M;W5R"B`J('!A9V4@<VAO=6QD(&-O;G-I<W0@;V8@97AA8W1L>2!O;F4@2&]R
M9&5?36]B:6QE(&]B:F5C="X@07!P<F]P<FEA=&4*("H@;6%R:W5P("T@26UO
M9&4L(%=-3"P@2$1-3"P@971C+B`M(&ES(&=E;F5R871E9"!B>2!T:&4@87!P
M<F]P<FEA=&4*("H@<F5N9&5R97(@;V)J96-T"B`J"B`J($1O(&YO="!O=F5R
M<W1U9F8@2&]R9&5?36]B:6QE(&]B:F5C=',N(%)E;65M8F5R('1H870@82!L
M;W0@;V8@5T%0"B`J(&-L:65N=',@8V%N;F]T(&AA;F1L92!M;W)E('1H86X@
M86)O=70@,30P,"!B>71E<R!O9B!C;VUP:6QE9"!D871A+@H@*@H@*B!%>&%M
M<&QE<SH*("H*("H@)&UY4&%G92`](&YE=R!(;W)D95]-;V)I;&4H*3L*("H@
M)&UY4&%G92`](&YE=R!(;W)D95]-;V)I;&4H)TUY(%=!4"!P86=E)RD["B`J
M("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE*"<G+"`G8V5N=&5R)RD["B`J
M"B`J("\O($UO<F4@<W1U9F8*("H*("H@)&UY4&%G92T^861D*"1M>51E>'0I
M.PH@*@H@*B`O+R!-;W)E(&ET96US"B`J"B`J("1M>5!A9V4M/G)E;F1E<B@I
M.PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-;V)I;&4O36]B:6QE+G!H<"QV
M(#$N,S(N,3`N.2`R,#`V+S`V+S(V(#`V.C(W.C(S('-E;'-K>2!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO
M<F1E7TUO8FEL92!E>'1E;F1S($AO<F1E7TUO8FEL95]C87)D('L*"B`@("!V
M87(@)%]T:71L93L*("`@('9A<B`D7V5L96UE;G1S(#T@87)R87DH*3L*("`@
M('9A<B`D7V-A<F1S(#T@87)R87DH*3L*("`@('9A<B`D7V1E8G5G(#T@9F%L
M<V4["@H@("`@+R\@1&5C:61E('=H971H97(@=&AE('-I;75L871O<B!D979I
M8V4@:7,@=&\@8F4@=7-E9"X@3VYL>2!A9F9E8W1S"B`@("`O+R!(5$U,(&)R
M;W=S97(@;W5T<'5T+@H@("`@=F%R("1?<VEM=6QA=&]R(#T@9F%L<V4["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1I=&QE("!)9B!A('-T<FEN9R!I<R!P<F]V:61E9"!H97)E
M+"!I="!W:6QL(&)E(&1I<W!L87EE9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&EN('1H92!(5$U,('1I=&QE(&)A<BP@<F5S<&5C=&EV96QY('-O
M;65W:&5R92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!7
M05`@9&ES<&QA>2X@57-I;F<@82!T:71L92!Y;W4@=VEL;"!N;W)M86QL>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&AA=F4@=&\@<W!E;F0@;VYE
M(&]F('EO=7(@9F5W(&QI;F5S(&]N('EO=7(@5T%0"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@9&ES<&QA>2X@0V]N<VED97(@=&AA="!S;VUE(%=!
M4"!P:&]N97,O4T1+)W,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@:&%N9&AE;&0@9&5V:6-E<R!D;VXG="!D:7-P;&%Y('1H92!T:71L92!A
M="!A;&PN"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9V5N="`@268@<W!E8VEF
M:65D+"!U<V4@:6YS=&5A9"!O9B!(5%107U5315)?04=%3E0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL92@D=&ET;&4@/2!N=6QL+"`D86=E
M;G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&ET;&4I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4["B`@("`@
M("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S97(N<&AP
M)SL*("`@("`@("`D8G)O=W-E<B`]("9"<F]W<V5R.CIS:6YG;&5T;VXH)&%G
M96YT*3L*"B`@("`@("`@:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=H=&UL
M)RDI('L*("`@("`@("`@("`@)&UL(#T@)VAT;6PG.PH@("`@("`@('T@96QS
M96EF("@D8G)O=W-E<BT^:&%S1F5A='5R92@G=VUL)RDI('L*("`@("`@("`@
M("`@)&UL(#T@)W=M;"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&UL(#T@)VAT;6PG.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R]-;V)I;&4O4F5N9&5R97(N<&AP)SL*
M("`@("`@("`D=&AI<RT^7W)E;F1E<F5R(#T@)DAO<F1E7TUO8FEL95]296YD
M97)E<CHZ<VEN9VQE=&]N*"1M;"P@)&)R;W=S97(I.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9A9&0H)B1E;&5M96YT*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7V-A<F0G*2D@>PH@("`@("`@("`@
M("!I9B`H8V]U;G0H)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@
M("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)UEO=2!C86YN;W0@;6EX
M($AO<F1E7TUO8FEL95]C87)D<R!A;F0@;W1H97(@96QE;65N=',@870@=&AE
M(&1E8VL@;&5V96PN)RD["B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7W5S:6YG0V%R
M9',@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V-A<F1S6UT@/2`F)&5L
M96UE;G0["@H@("`@("`@("`@("!R971U<FX@)&5L96UE;G0["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?8V%R9',I
M*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R
M*"=9;W4@8V%N;F]T(&UI>"!(;W)D95]-;V)I;&5?8V%R9',@86YD(&]T:&5R
M(&5L96UE;G1S(&%T('1H92!D96-K(&QE=F5L+B<I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M<F5T=7)N('!A<F5N=#HZ861D*"1E;&5M96YT*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!8W1I=F%T97,@=&AE(&)U:6QT+6EN(&1E=FEC
M92!S:6UU;&%T;W(@;VX@8FEG<V-R965N(&)R;W=S97)S+@H@("`@("H@5&AE
M(&1E=FEC92!S:6UU;&%T;W(@:7,@;VYL>2!F=6QL>2UF=6YC=&EO;F%L(&EN
M($EN=&5R;F5T"B`@("`@*B!%>'!L;W)E<BP@8F5C875S92!T:&4@;&%Y;W5T
M(')E<75I<F5S(&$@<V-R;VQL86)L92!T86)L90H@("`@("H@96QE;65N="X@
M3W1H97(@8G)O=W-E<G,@=VEL;"!F86EL('1O('-H;W<@8V]N=&5N="!O;B!P
M86=E<PH@("`@("H@;&]N9V5R('1H86X@82!S:6YG;&4@<V-R965N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!U<V53:6UU;&%T;W(H*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<VEM=6QA=&]R(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@=&AE('!A9V4@:6X@=&AE(&%P<')O<')I871E(&UA<FMU
M<"!L86YG=6%G92X@1&5P96YD:6YG"B`@("`@*B!O;B!T:&4@<F5N9&5R97(@
M='EP92P@2%1-3"`H<'5R92!(5$U,+"!H86YD:&5L9&9R:65N9&QY($%V86YT
M1V\*("`@("`J($A434PL(&DM;6]D92!C2%1-3"P@34U,*2P@5TU,(&]R($A$
M34P@8V]D92!I<R!C<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-P
M;&%Y*"D*("`@('L*("`@("`@("`D=&AI<RT^7W)E;F1E<F5R+3YR96YD97(H
M)'1H:7,I.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E($AO<F1E7TUO8FEL
M90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@(&9U;F-T
M:6]N($AO<F1E7TUO8FEL95]E;&5M96YT*"D*("`@('L*("`@('T*"B`@("!F
M=6YC=&EO;B!G970H)&%T=')I8G5T92D*("`@('L*("`@("`@("`D871T<B`]
M("=?)R`N("1A='1R:6)U=&4["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3XD
M871T<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3XD871T<CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T*"1A='1R:6)U=&4L("1V86QU
M92D*("`@('L*("`@("`@("`D871T<B`]("=?)R`N("1A='1R:6)U=&4["B`@
M("`@("`@)'1H:7,M/B1A='1R(#T@)'9A;'5E.PH@("`@?0H*?0H*+RHJ"B`J
M($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE
M7V9O<FU%;&5M96YT(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*
M("`@('9A<B`D7VYA;64["B`@("!V87(@)%]V86QU93L*("`@('9A<B`D7VQA
M8F5L.PH@("`@=F%R("1?<VEZ93L*("`@('9A<B`D7VUA>&QE;F=T:#L*("`@
M('9A<B`D7W1Y<&4["B`@("!V87(@)%]F;W)M870["B`@("!V87(@)%]M;V1E
M.PH*("`@("\J*@H@("`@("H@4V5T(&EN<'5T(&UO9&4O:7-T>6QE(&9O<B!J
M87!A;F5S92!-34PO:2UM;V1E(&1E=FEC97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;6]D92`@26YP=70@;6]D92P@;VYE(&]F.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@)V%L<&AA)R`H9&5F875L="D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("=K871A:V%N82<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("=H:7)A9V%N82<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("=N=6UE<FEC)PH@("`@("HO"B`@("!F=6YC=&EO;B!S971-
M;V1E*"1M;V1E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;6]D92`]("1M;V1E
M.PH*("`@("`@("`O+R!-87`@=&AE(&UO9&4@:6YT;R!A;B!A<'!R;W!R:6%T
M92!F;W)M870@<W1R:6YG+"!U<V5D(&9O<@H@("`@("`@("\O(%=-3"!A;F0@
M2$1-3"X@268@82!F;W)M870@<W1R:6YG('=A<R!P<F]V:61E9"!E87)L:65R
M+"!I=`H@("`@("`@("\O('=I;&P@8F4@;W9E<G=R:71T96XN"B`@("`@("`@
M<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@)VAI<F%G86YA)SH*("`@
M("`@("!C87-E("=K871A:V%N82<Z"B`@("`@("`@("`@("1T:&ES+3Y?9F]R
M;6%T(#T@)RI-)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)V%L<&AA)SH*("`@("`@("`@("`@)'1H:7,M/E]F;W)M870@/2`G*FTG.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G;G5M97)I8R<Z"B`@
M("`@("`@("`@("1T:&ES+3Y?9F]R;6%T(#T@)RI.)SL*("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@
M9&5F:6YE<R!A(&9O<FT@=VET:"!V87)I;W5S('!O<W-I8FQE(&EN<'5T(&5L
M96UE;G1S+B!4:&4*("H@:6YP=70@96QE;65N=',@:&%V92!T;R!B92!D969I
M;F5D(&%S('-E<&%R871E(&]B:F5C=',@86YD(&%R90H@*B!L:6YK960@=&\@
M=&AE(&9O<FT@=VET:"!A('-P96-I86P@(F%D9"(@9G5N8W1I;VXN($]N92!(
M;W)D95]-;V)I;&4*("H@;V)J96-T(&-A;B!C;VYT86EN(&]N;'D@;VYE($AO
M<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J
M("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE*"XN+BD["B`J"B`J("1M>49O
M<FT@/2!N97<@2&]R9&5?36]B:6QE7V9O<FTH(B]M>6YE>'1P86=E+G=M;"(I
M.PH@*B`D;7E497AT(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*"XN+BD["B`J
M("1M>49O<FTM/F%D9"@D;7E497AT*3L*("H@)&UY26YP=70@/2!N97<@2&]R
M9&5?36]B:6QE7VEN<'5T*"XN+BD["B`J("1M>49O<FTM/F%D9"@D;7E);G!U
M="D["B`J("1M>5-U8FUI="`](&YE=R!(;W)D95]-;V)I;&5?<W5B;6ET*"XN
M+BD["B`J("1M>49O<FTM/F%D9"@D;7E3=6)M:70I.PH@*@H@*B`D;7E086=E
M+3YA9&0H)&UY1F]R;2D["B`J"B`J("1M>5!A9V4M/G)E;F1E<B@I.PH@*@H@
M*B!`<V5E($AO<F1E7TUO8FEL95]T97AT"B`J($!S964@2&]R9&5?36]B:6QE
M7VEM86=E"B`J($!S964@2&]R9&5?36]B:6QE7W1A8FQE"B`J($!S964@2&]R
M9&5?36]B:6QE7VEN<'5T"B`J($!S964@2&]R9&5?36]B:6QE7W1E>'1A<F5A
M"B`J($!S964@2&]R9&5?36]B:6QE7W-E;&5C=`H@*B!`<V5E($AO<F1E7TUO
M8FEL95]R861I;PH@*B!`<V5E($AO<F1E7TUO8FEL95]C:&5C:V)O>`H@*B!`
M<V5E($AO<F1E7TUO8FEL95]S=6)M:70*("H@0'-E92!(;W)D95]-;V)I;&5?
M<G5L90H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO
M<F1E7TUO8FEL95]F;W)M(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@
M>PH*("`@('9A<B`D7W5R;#L*("`@('9A<B`D7VUE=&AO9#L*("`@('9A<B`D
M7V5L96UE;G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("`@($%D
M9')E<W,@=VAE<F4@=&AE('5S97(@:6YP=70@:7,@<V5N="!T;RX*("`@("`J
M($!P87)A;2!S=')I;F<@)&UE=&AO9"`@("`G<&]S="<@*&1E9F%U;'0I(&]R
M("=G970G+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-E<W-I;VX@(%!R97-E
M<G9E('1H92!S97-I;VX@:60@:6X@=&AE(&9O<FT_($1E9F%U;'1S('1O('1R
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]F;W)M*"1U
M<FPL("1M971H;V0@/2`G<&]S="<L("1S97-S:6]N(#T@=')U92D*("`@('L*
M("`@("`@("`D=&AI<RT^7W5R;"`]("1U<FP["B`@("`@("`@)'1H:7,M/E]M
M971H;V0@/2`D;65T:&]D.PH*("`@("`@("!I9B`H)'-E<W-I;VX@)B8@(6%R
M<F%Y7VME>5]E>&ES=',H<V5S<VEO;E]N86UE*"DL("1?0T]/2TE%*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^861D*&YE=R!(;W)D95]-;V)I;&5?:&ED9&5N
M*'-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED*"DI*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@)F%D9"@F)&9O<FU%;&5M96YT*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A*"1F;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]S
M=6)M:70G*2D@>PH@("`@("`@("`@("`D9F]R;45L96UE;G0M/E]F;W)M(#T@
M)B1T:&ES.PH@("`@("`@("`@("`D8FQO8VL@/2`F;F5W($AO<F1E7TUO8FEL
M95]B;&]C:R@D9F]R;45L96UE;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V5L
M96UE;G1S6UT@/2`F)&)L;V-K.PH@("`@("`@('T@96QS96EF("AI<U]A*"1F
M;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]H:61D96XG*2!\?`H@("`@("`@
M("`@("`@("`@("!I<U]A*"1F;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]B
M;&]C:R<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D
M9F]R;45L96UE;G0["B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&9O<FU%;&5M
M96YT+"`G2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT)RD@?'P*("`@("`@("`@
M("`@("`@("`@:7-?82@D9F]R;45L96UE;G0L("=(;W)D95]-;V)I;&5?=&5X
M="<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&9O<FU%;&5M96YT+"`G
M2&]R9&5?36]B:6QE7W1A8FQE)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?
M82@D9F]R;45L96UE;G0L("=(;W)D95]-;V)I;&5?<G5L92<I('Q\"B`@("`@
M("`@("`@("`@("`@(&ES7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE
M7VEM86=E)RDI('L*("`@("`@("`@("`@)&)L;V-K(#T@)FYE=R!(;W)D95]-
M;V)I;&5?8FQO8VLH)&9O<FU%;&5M96YT*3L*("`@("`@("`@("`@)'1H:7,M
M/E]E;&5M96YT<UM=(#T@)B1B;&]C:SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=3<&5C:69I960@
M96QE;65N="!C86YN;W0@8F4@:6YS:61E(&$@9F]R;2XG*3L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9F]R;45L96UE;G0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&5F875L=',H
M*0H@("`@>PH@("`@("`@("1D969A=6QT<R`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]E;&5M96YT<R!A<R`D=F%L*2!["B`@("`@("`@
M("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)'9A;"DI*2!["B`@
M("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]H:61D96XG.@H@("`@("`@
M("`@("`@("`@)&1E9F%U;'1S6UT@/2!A<G)A>2@G;F%M92<@/3X@)'9A;"T^
M9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QU92<@/3X@)'9A;"T^9V5T*"=V86QU92<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:&ED9&5N)R`]/B!T<G5E*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:&]R
M9&5?;6]B:6QE7V)L;V-K)SH*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86PM/E]E;&5M96YT<R!A<R`D8G9A;"D@>PH@("`@("`@("`@("`@("`@("`@
M('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&)V86PI*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]C:&5C:V)O>"<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D8G9A;"T^:7-#:&5C:V5D
M*"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D969A=6QT<UM=
M(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG970H)VYA;64G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A
M;'5E)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VEN<'5T)SH*
M("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?=&5X=&%R
M96$G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]S
M96QE8W0G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL
M95]R861I;R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1D969A=6QT<UM=
M(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG970H)VYA;64G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G
M(#T^("1B=F%L+3YG970H)W9A;'5E)RDI.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?
M;6]B:6QE7VAI9&1E;B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1D969A
M=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG970H)VYA;64G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=64G(#T^("1B=F%L+3YG970H)W9A;'5E)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAI9&1E;B<@/3X@=')U
M92D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?=&%B;&4G.@H@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D8G9A;"T^7W)O=W,@87,@)')O
M=RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O
M=RT^7V-O;'5M;G,@87,@)&-O;"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&-O;"DI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R
M9&5?;6]B:6QE7V-H96-K8F]X)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1C;VPM/FES0VAE8VME9"@I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L='-;72`]
M(&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=V86QU92<@/3X@)&)V86PM/F=E="@G=F%L=64G*2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]I;G!U="<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?
M;6]B:6QE7W1E>'1A<F5A)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=H;W)D95]M;V)I;&5?<V5L96-T)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?<F%D:6\G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L
M='-;72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W9A;'5E)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL
M95]H:61D96XG.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5F875L='-;72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N
M86UE)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D8G9A;"T^9V5T*"=V86QU
M92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=H:61D96XG(#T^('1R=64I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&5F875L=',["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T1V5T5F%R<R@I"B`@("!["B`@("`@("`@
M+R\@1&5T97)M:6YE(&%L;"!E;&5M96YT<R!T:&%T(&AA=F4@=&\@8F4@<W5B
M;6ET=&5D+@H@("`@("`@("1G971V87)S(#T@87)R87DH*3L*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V5L96UE;G1S(&%S("1V86PI('L*("`@("`@("`@
M("`@<W=I=&-H("AS=')T;VQO=V5R*&=E=%]C;&%S<R@D=F%L*2DI('L*("`@
M("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7V)L;V-K)SH*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86PM/E]E;&5M96YT<R!A<R`D8G9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA
M<W,H)&)V86PI*2D@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E
M7VUO8FEL95]I;G!U="<Z"B`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R
M9&5?;6]B:6QE7VAI9&1E;B<Z"B`@("`@("`@("`@("`@("`@("`@8V%S92`G
M:&]R9&5?;6]B:6QE7W1E>'1A<F5A)SH*("`@("`@("`@("`@("`@("`@("!C
M87-E("=H;W)D95]M;V)I;&5?<V5L96-T)SH*("`@("`@("`@("`@("`@("`@
M("!C87-E("=H;W)D95]M;V)I;&5?8VAE8VMB;W@G.@H@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]R861I;R<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("1G971V87)S6UT@/2`D8G9A;"T^9V5T*"=N86UE)RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?=&%B;&4G.@H@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D8G9A;"T^7W)O=W,@87,@)')O=RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O=RT^
M7V-O;'5M;G,@87,@)&-O;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&-O;"DI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?
M;6]B:6QE7VEN<'5T)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=H;W)D95]M;V)I;&5?:&ED9&5N)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?=&5X=&%R96$G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E
M7VUO8FEL95]S96QE8W0G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)VAO<F1E7VUO8FEL95]C:&5C:V)O>"<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W)A9&EO
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=E='9A
M<G-;72`]("1C;VPM/F=E="@G;F%M92<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D9V5T=F%R<SL*("`@('T*"GT*"B\J
M*@H@*B!4:&ES(&-L87-S(&AO;&1S('1E>'0M;&5V96P@96QE;65N=',@9F]R
M('5S92!I;B!(;W)D95]-;V)I;&4@;W(*("H@2&]R9&5?36]B:6QE7V9O<FT@
M;V)J96-T<RX*("H*("H@17AA;7!L97,Z"B`J"B`J("1B;&]C:R`](&YE=R!(
M;W)D95]-;V)I;&5?8FQO8VLH(DAE;&QO(%=!4"$B*3L*("H@)'1E>'0@/2!N
M97<@2&]R9&5?36]B:6QE7W1E>'0H(E=E;&-O;64@=&\@2&]R9&5?36]B:6QE
M(BP@)V(G*3L*("H@)&)L;V-K+3YA9&0H)'1E>'0I.PH@*@H@*B!`<V5E($AO
M<F1E7TUO8FEL90H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P
M86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7V)L
M;V-K(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D
M7V5L96UE;G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D96QE;65N=',@($%N
M>2!E;&5M96YT<R`H82!S:6YG;&4@;VYE(&]R(&%N(&%R<F%Y*2!T;R!F:6QL
M('1H:7,@8FQO8VL@=VET:"X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?
M36]B:6QE7V)L;V-K*"8D96QE;65N=',I"B`@("!["B`@("`@("`@:68@*"%I
M<U]N=6QL*"1E;&5M96YT<RDI('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D96QE;65N=',I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1E
M;&5M96YT<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D96QE;65N=',@87,@)&5L96UE;G0I('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^861D*"1E;&5M96YT*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B`F861D*"8D96QE;65N="D*("`@('L*("`@("`@("!I9B`H(6ES7V$H
M)&5L96UE;G0L("=(;W)D95]-;V)I;&5?96QE;65N="<I*2!["B`@("`@("`@
M("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@96QE;65N
M="XG*3L*("`@("`@("!](&5L<V5I9B`H:7-?82@D96QE;65N="P@)TAO<F1E
M7TUO8FEL95]T97AT)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE
M;65N="P@)TAO<F1E7TUO8FEL95]T86)L92<I('Q\"B`@("`@("`@("`@("`@
M("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?:6UA9V4G*2!\?`H@
M("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE
M7V9O<FU%;&5M96YT)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE
M;65N="P@)TAO<F1E7TUO8FEL95]L:6YK)RD@?'P*("`@("`@("`@("`@("`@
M("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]L:6YK<V5T)RD@?'P*
M("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL
M95]P:&]N92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L
M("=(;W)D95]-;V)I;&5?<G5L92<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M96QE;65N='-;72`]("8D96QE;65N=#L*("`@("`@("`@("`@<F5T=7)N("1E
M;&5M96YT.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E<G)O<B`]
M(%!%05(Z.G)A:7-E17)R;W(H)U1H92!E;&5M96YT(&ES(&YO="!A;&QO=V5D
M(&EN<VED92!A(&)L;V-K+B<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@:6YS97)T<R!P
M;&%I;B!T97AT(&EN=&\@82!(;W)D95]-;V)I;&5?8FQO8VL@;W(@80H@*B!(
M;W)D95]-;V)I;&5?<F]W(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J
M("1M>51E>'0Q(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*")(96QL;R!705`A
M(BD["B`J("1M>51E>'0R(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*")796QC
M;VUE('1O($AO<F1E7TUO8FEL92(L("=B)RD["B`J("1M>51E>'0S(#T@;F5W
M($AO<F1E7TUO8FEL95]T97AT*")';V]D($UO<FYI;F<B+"!A<G)A>2@G8B<L
M("=B:6<G*2D["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V)L;V-K"B`J($!S
M964@2&]R9&5?36]B:6QE7W)O=PH@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I
M;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]T97AT(&5X=&5N9',@2&]R9&5?
M36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W1E>'0@/2`G)SL*("`@('9A
M<B`D7V%T=')I8G5T97,@/2!A<G)A>2@I.PH@("`@=F%R("1?;&EN96)R96%K
M<R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@5&AE('1E>'0@8V]N=&5N="!O
M9B!T:&4@96QE;65N="X*("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E
M<R`@5&5X="!A='1R:6)U=&5S+B!!;GD@;V8Z"B`@("`@*B`@("=B)PH@("`@
M("H@("`G=2<*("`@("`J("`@)VDG"B`@("`@*B`@("=B:6<G"B`@("`@*B`@
M("=S;6%L;"<*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7W1E
M>'0H)'1E>'0L("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1A='1R:6)U=&5S*2D@>PH@("`@("`@("`@("`D871T<FEB=71E<R`](&%R
M<F%Y*"1A='1R:6)U=&5S*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]A
M='1R:6)U=&5S(#T@)&%T=')I8G5T97,["B`@("!]"@I]"@HO*BH*("H@5&AI
M<R!C;&%S<R!A;&QO=W,@=&\@:6YS97)T(&)I=&UA<"!I;6%G97,@:6YT;R!A
M($AO<F1E7TUO8FEL95]B;&]C:RP*("H@2&]R9&5?36]B:6QE7V9O<FT@;W(@
M2&]R9&5?36]B:6QE7W)O=R!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@
M*B`D:6UA9V4@/2!N97<@2&]R9&5?36]B:6QE7VEM86=E*"<O<&%T:"]T;R]I
M;6%G92YW8FUP)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G:&5I9VAT)R`]/B`Q,#`L("=W:61T:"<@/3X@,3`P*2D["B`J
M"B`J($!S964@2&]R9&5?36]B:6QE7V)L;V-K"B`J($!S964@2&]R9&5?36]B
M:6QE7V9O<FT*("H@0'-E92!(;W)D95]-;V)I;&5?<F]W"B`J"B`J($!P86-K
M86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7VEM86=E
M(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W-R
M8R`]("<G.PH@("`@=F%R("1?871T<FEB=71E<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<W)C("`@("`@("!4:&4@<V]U<F-E(&QO8V%T:6]N(&]F('1H92!I;6%G92X*
M("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R`@26UA9V4@871T<FEB
M=71E<RX@06YY(&]F.@H@("`@("H@("`G86QI9VXG"B`@("`@*B`@("=A;'0G
M"B`@("`@*B`@("=H96EG:'0G"B`@("`@*B`@("=H<W!A8V4G"B`@("`@*B`@
M("=V<W!A8V4G"B`@("`@*B`@("=W:61T:"<*("`@("`J("`@)V-L87-S)PH@
M("`@("H@("`G:60G"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL
M95]I;6%G92@D<W)C+"`D871T<FEB=71E<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S<F,@/2`D<W)C.PH@("`@("`@("1T:&ES+3Y?871T
M<FEB=71E<R`]("1A='1R:6)U=&5S.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@
M8VQA<W,@86QL;W=S('1O(&EN<V5R="!T86)L97,@:6YT;R!A($AO<F1E7TUO
M8FEL92!O<@H@*B!(;W)D95]-;V)I;&5?9F]R;2!O8FIE8W0N"B`J"B`J($5X
M86UP;&5S.@H@*@H@*B`D;7E486)L92`](&YE=R!(;W)D95]-;V)I;&5?=&%B
M;&4H*3L*("H*("H@)')O=S$@/2!N97<@2&]R9&5?36]B:6QE7W)O=R@I.PH@
M*B`D<F]W,2T^861D*"1I;6%G93$I.PH@*B`D<F]W,2T^861D*"1T97AT,2D[
M"B`J("1M>51A8FQE+3YA9&0H)')O=S$I.PH@*@H@*B`D<F]W,B`](&YE=R!(
M;W)D95]-;V)I;&5?<F]W*"D["B`J("1R;W<R+3YA9&0H)&EM86=E,BD["B`J
M("1R;W<R+3YA9&0H)'1E>'0R*3L*("H@)&UY5&%B;&4M/F%D9"@D<F]W,BD[
M"B`J"B`J("1M>41E8VLM/F%D9"@D;7E486)L92D["B`J"B`J($!S964@2&]R
M9&5?36]B:6QE"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H@0'-E92!(
M;W)D95]-;V)I;&5?<F]W"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@
M*B\*8VQA<W,@2&]R9&5?36]B:6QE7W1A8FQE(&5X=&5N9',@2&]R9&5?36]B
M:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W)O=W,@/2!A<G)A>2@I.PH@("`@
M=F%R("1?8F]R9&5R(#T@;G5L;#L*("`@('9A<B`D7W!A9&1I;F<@/2!N=6QL
M.PH@("`@=F%R("1?<W!A8VEN9R`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!!
M9&1S(&$@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W0@=&\@2&]R9&5?36]B:6QE
M7W1A8FQE+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I;&5?<F]W
M("1R;W<@(%1H92!R;W<@;V)J96-T('1O(&%D9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F%D9"@F)')O=RD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)')O
M=RP@)TAO<F1E7TUO8FEL95]R;W<G*2D@>PH@("`@("`@("`@("`D97)R;W(@
M/2!014%2.CIR86ES945R<F]R*"=2;W=S(&UU<W0@8F4@2&]R9&5?36]B:6QE
M7W)O=R!O8FIE8W1S+B<I.PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]R;W=S6UT@/2`F)')O=SL*("`@
M("`@("!R971U<FX@)')O=SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S
M(&1E9FEN97,@=&AE(')O=W,@=&AA="!A($AO<F1E7TUO8FEL95]T86)L92!O
M8FIE8W0*("H@8V]N<VES=',@;V8N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D
M:6UA9V4Q(#T@;F5W($AO<F1E7TUO8FEL95]I;6%G92@B;7E?:6UA9V4N=V)M
M<"(L(")M>5]I;6%G92YP;F<B+"`B.BTI(BD["B`J("1T97AT,2`](&YE=R!(
M;W)D95]-;V)I;&5?=&5X="@B;7D@=&5X="(I.PH@*B`D<F]W,2`](&YE=R!(
M;W)D95]-;V)I;&5?<F]W*"D["B`J("1R;W<Q+3YA9&0H)&EM86=E,2D["B`J
M("1R;W<Q+3YA9&0H*3L*("H@)')O=S$M/F%D9"@D=&5X=#$I.PH@*@H@*B!`
M<V5E($AO<F1E7TUO8FEL95]T86)L90H@*B!`<V5E($AO<F1E7TUO8FEL95]T
M97AT"B`J($!S964@2&]R9&5?36]B:6QE7VEM86=E"B`J($!S964@2&]R9&5?
M36]B:6QE7VQI;FL*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC
M;&%S<R!(;W)D95]-;V)I;&5?<F]W(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L
M96UE;G0@>PH*("`@('9A<B`D7V-O;'5M;G,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@061D<R!A(&-O;'5M;B!E;&5M96YT('1O(&$@2&]R9&5?36]B
M:6QE7W)O=R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7TUO
M8FEL95]E;&5M96YT("1C96QL16QE;65N="`@0V%N(&)E(&$@2&]R9&5?36]B
M:6QE7W1E>'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]B:F5C="P@82!(;W)D95]-;V)I;&5?:6UA9V4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&]B:F5C="P@82!(;W)D95]-;V)I;&5?;&EN:PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T(&]R(&YU
M;&PN(%1H92!L871T97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E<W5L=',@:6X@86X@96UP='D@8V5L;"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@D8V5L;$5L96UE;G0@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&-E;&Q%;&5M96YT*2D@
M>PH@("`@("`@("`@("!I9B`H(6ES7V$H)&-E;&Q%;&5M96YT+"`G2&]R9&5?
M36]B:6QE7W1E>'0G*2`F)@H@("`@("`@("`@("`@("`@(6ES7V$H)&-E;&Q%
M;&5M96YT+"`G2&]R9&5?36]B:6QE7VQI;FLG*2`F)@H@("`@("`@("`@("`@
M("`@(6ES7V$H)&-E;&Q%;&5M96YT+"`G2&]R9&5?36]B:6QE7VEM86=E)RDI
M('L*("`@("`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H
M)U1A8FQE(&-E;&QS(&-A;B!O;FQY(&-O;G1A:6X@=&5X="P@;&EN:W,L(&]R
M(&EM86=E<RXG*3L*("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]C;VQU;6YS6UT@/2`F
M)&-E;&Q%;&5M96YT.PH@("`@("`@("`@("!R971U<FX@)&-E;&Q%;&5M96YT
M.PH@("`@("`@('T@96QS96EF("@A:7-?;G5L;"@D8V5L;$5L96UE;G0I*2![
M"B`@("`@("`@("`@("1T(#T@)FYE=R!(;W)D95]-;V)I;&5?=&5X="@D8V5L
M;$5L96UE;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V-O;'5M;G-;72`]("8D
M=#L*("`@("`@("`@("`@<F5T=7)N("1T.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?8V]L=6UN<UM=(#T@)B1C96QL16QE;65N=#L*
M("`@("`@("`@("`@<F5T=7)N("1C96QL16QE;65N=#L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T0V]L=6UN0V]U;G0H*0H@("`@>PH@("`@
M("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V-O;'5M;G,I.PH@("`@?0H*?0H*
M+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@82!T97AT(&EN<'5T(&9I96QD
M(&EN(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T+@H@*@H@*B!%>&%M<&QE
M<SH*("H*("H@)&UY26YP=70Q(#T@;F5W($AO<F1E7TUO8FEL95]I;G!U="@G
M8VED)RP@)R<L("=#=7-T;VUE<B!)1"<I.PH@*@H@*B`D;7E);G!U=#(@/2!N
M97<@2&]R9&5?36]B:6QE7VEN<'5T*"=C:60G+"`G)RP@)T-U<W1O;65R($E$
M)RP@)RI.)RD["B`J("1M>4EN<'5T,BT^<V5T7W-I>F4H-BD["B`J("1M>4EN
M<'5T,BT^<V5T7VUA>&QE;F=T:"@V*3L*("H*("H@)&UY26YP=70S(#T@;F5W
M($AO<F1E7TUO8FEL95]I;G!U="@G<'<G+"`G)RP@)U!A<W-W;W)D)RP@)RI.
M)RD["B`J("1M>4EN<'5T,RT^<V5T7W-I>F4H."D["B`J("1M>4EN<'5T,RT^
M<V5T7VUA>&QE;F=T:"@X*3L*("H@)&UY26YP=70S+3YS971?='EP92@G<&%S
M<W=O<F0G*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`
M<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]I
M;G!U="!E>'1E;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N="!["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@5F%R:6%B;&4@:6X@=VAI8V@@=&AE(&EN<'5T(&ES
M('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1E
M<W1I;F%T:6]N(%523"X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("`@
M26YI=&EA;"!V86QU92!T:&%T('=I;&P@8F4@<')E<V5N=&5D(&EN('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;G!U="!F:65L9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&QA8F5L("`@1&5S8W)I8F5S('EO=7(@:6YP
M=70@9FEE;&0@;VX@=&AE('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F]R;6%T("!);G!U="!F;W)M870@8V]D92!A8V-O<F1I;F<@=&\@=&AE
M(%=!4"!S=&%N9&%R9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M06QL;W=S('1H92!705`@=7-E<B!C;&EE;G0@92YG+B!T;R!I;G!U="!O;FQY
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1I9VET<R!A;F0@;F\@
M8VAA<F%C=&5R<RX@3VX@86X@2%1-3"!G96YE<F%T960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@<&%G92!T:&ES(&9O<FUA="!H87,@;F\@<VEG
M;FEF:6-A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?
M:6YP=70H)&YA;64L("1V86QU92P@)&QA8F5L(#T@)R<L("1F;W)M870@/2`G
M*DTG*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@
M("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@("`@("`@)'1H:7,M/E]L
M86)E;"`]("1L86)E;#L*("`@("`@("`D=&AI<RT^7V9O<FUA="`]("1F;W)M
M870["B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)W1E>'0G.PH@("`@("`@("1T
M:&ES+3Y?;6]D92`]("=A;'!H82<["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C
M;&%S<R!P<F]V:61E<R!A;B!I;G!U="!T97AT87)E82!I;B!A($AO<F1E7TUO
M8FEL95]F;W)M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>4%R
M96$Q(#T@;F5W($AO<F1E7TUO8FEL95]T97AT87)E82@G9F(G+"`G)RP@)T9E
M961B86-K)RD["B`J("1M>4%R96$R(#T@;F5W($AO<F1E7TUO8FEL95]T97AT
M87)E82@G;7-G)RP@)T5N=&5R(&UE<W-A9V4@:&5R92`N+BXG+"`G365S<V%G
M92<L(#0P+"`U*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@
M*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL
M95]T97AT87)E82!E>'1E;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N="![
M"@H@("`@=F%R("1?<F]W<SL*("`@('9A<B`D7V-O;',["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@5F%R:6%B;&4@:6X@=VAI8V@@=&AE(&EN<'5T(&ES('-E;G0@
M=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&5S=&EN871I
M;VX@55),+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@($EN:71I86P@
M=F%L=64@=&AA="!W:6QL(&)E('!R97-E;G1E9"!I;B!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!T97AT87)E82X*("`@("`J($!P87)A;2!S
M=')I;F<@)&QA8F5L("!$97-C<FEB97,@>6]U<B!T97AT87)E82!O;B!T:&4@
M<W5R9F5R)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S8W)E96XO
M9&ES<&QA>2X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W=S("!2;W=S+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;',@($-O;'5M;G,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]T97AT87)E82@D;F%M92P@)'9A
M;'5E+"`D;&%B96PL("1R;W=S(#T@,RP@)&-O;',@/2`Q-BD*("`@('L*("`@
M("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7W9A
M;'5E(#T@)'9A;'5E.PH@("`@("`@("1T:&ES+3Y?;&%B96P@/2`D;&%B96P[
M"B`@("`@("`@)'1H:7,M/E]R;W=S(#T@)')O=W,["B`@("`@("`@)'1H:7,M
M/E]C;VQS(#T@)&-O;',["B`@("`@("`@)'1H:7,M/E]M;V1E(#T@)V%L<&AA
M)SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&$@<V5L
M96-T(&5L96UE;G0@:6X@82!(;W)D95]-;V)I;&5?9F]R;2!O8FIE8W0N"B`J
M($ET(&%L;&]W<R!T;R!C<F5A=&4@;W!T:6UI>F5D(%=-3"!F;W(@5T%0(&1E
M=FEC97,@=VAI8V@@87)E(&-A<&%B;&4*("H@=&\@:6YT97)P<F5T92!T:&4@
M3W!E;G=A=F4@1U5)(&5X=&5N<VEO;G,@9F]R(%=-3"`Q+C,N($%L;"!O=&AE
M<@H@*B!734P@9&5V:6-E<R!R96-E:79E(%=-3"`Q+C$@8V]M<&%T:6)L92!M
M87)K=7`@8V]D92P@=VAI8V@@:7,@<75I=&4*("H@<VEM:6QA<B!T;R!T:&4@
M;6%R:W5P(&-O9&4@8W)E871E9"!B>2!T:&4@2&]R9&5?36]B:6QE7W)A9&EO
M(&-L87-S+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY4V5L96-T(#T@;F5W
M($AO<F1E7TUO8FEL95]S96QE8W0H)V-O;&]R)RD["B`J("1M>5-E;&5C="T^
M861D*"=";'5E)RP@)V(G*3L*("H@)&UY4V5L96-T+3YA9&0H)U)E9"<L("=R
M)RP@=')U92D["B`J("1M>5-E;&5C="T^861D*"=996QL;W<G+"`G>2<I.PH@
M*@H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E($AO
M<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W-E;&5C="!E>'1E
M;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N="!["@H@("`@=F%R("1?='EP
M93L*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!687)I86)L92!I;B!W:&EC:"!T:&4@:6YF;W)M871I;VX@86)O=70@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!S96QE8W1E9"!O<'1I
M;VX@:7,@<V5N="!T;R!T:&4@9&5S=&EN871I;VX@55),+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D='EP92`@5'EP92!O9B!S96QE8W0@87)E83H*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("=P;W!U<"<Z('!O<'5P('1H92!W:&]L
M92!S96QE8W1I;VX@;&ES=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M)W-P:6XG.B`@<F]T871E(&]P=&EO;G,@;VX@82!705`@9&5V:6-E('-C<F5E
M;B`H3U<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$N
M,R!'54D@;VYL>2DN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL
M95]S96QE8W0H)&YA;64L("1T>7!E(#T@)W!O<'5P)RD*("`@('L*("`@("`@
M("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7W1Y<&4@
M/2`D='EP93L*("`@("`@("`D=&AI<RT^7W9A;'5E(#T@;G5L;#L*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9',@;VYE(&]P=&EO;B!T;R!A($AO<F1E7TUO
M8FEL95]S96QE8W0@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&QA8F5L("`@("`@("`@1&5S8W)I8F5S('1H92!O<'1I;VX@;VX@=&AE
M('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@
M("`@("`@("!686QU92!S96YT(&EN('1H92`B;F%M92(@=F%R:6%B;&4L(&EF
M('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@
M=&AE(&]P=&EO;B!S96QE8W1E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1I
M<U]S96QE8W1E9"`@06QL;W=E9"!V86QU97,@87)E('1R=64@;W(@9F%L<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D;&%B96PL("1V86QU92P@)&ES
M7W-E;&5C=&5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]O<'1I
M;VYS6UT@/2!A<G)A>2@G;&%B96PG(#T^("1L86)E;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*"B`@
M("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]V86QU92D@?'P@)&ES7W-E;&5C
M=&5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@
M("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@
M82!R861I;R!B=71T;VX@96QE;65N="!I;B!A($AO<F1E7TUO8FEL95]F;W)M
M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5)A9&EO(#T@;F5W
M($AO<F1E7TUO8FEL95]R861I;R@G8V]U;G1R>2<I.PH@*B`D;7E2861I;RT^
M861D*"=&:6YL86YD)RP@)T8G*3L*("H@)&UY4F%D:6\M/F%D9"@G1V5R;6%N
M>2<L("=')RP@=')U92D["B`J("1M>5)A9&EO+3YA9&0H)U-W961E;B<L("=3
M)RD["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A8VMA
M9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?<F%D:6\@
M97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@('9A<B`D
M7V)U='1O;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!687)I86)L
M92!I;B!W:&EC:"!T:&4@:6YF;W)M871I;VX@86)O=70@=&AE('!R97-S960@
M8G5T=&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I<R!S96YT('1O
M('1H92!D97-T:6YA=&EO;B!54DPN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7TUO8FEL95]R861I;R@D;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^
M7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7W9A;'5E(#T@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@;VYE(')A9&EO(&)U='1O;B!T
M;R!A($AO<F1E7TUO8FEL95]R861I;R!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;&%B96P@("`@("`@($1E<V-R:6)E<R!T:&4@<F%D
M:6]B=71T;VX@;VX@=&AE('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<V-R965N+V1I<W!L87DN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1V86QU92`@("`@("`@5F%L=64@<V5N="!I;B!T:&4@(FYA;64B
M('9A<FEA8FQE+"!I9B!T:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G5T=&]N(&ES('-E;&5C=&5D+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&ES7V-H96-K960@($%L;&]W960@=F%L=65S(&%R92!T<G5E(&]R
M(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)&QA8F5L+"`D=F%L
M=64L("1I<U]C:&5C:V5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]B=71T;VYS6UT@/2!A<G)A>2@G;&%B96PG(#T^("1L86)E;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E
M*3L*"B`@("`@("`@:68@*"$D=&AI<RT^7W9A;'5E('Q\("@D:7-?8VAE8VME
M9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]V86QU92`]("1V86QU93L*("`@
M("`@("!]"B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A
M('-I;F=L92!C:&5C:V)O>"!E;&5M96YT(&EN(&$@2&]R9&5?36]B:6QE7V9O
M<FT@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY0VAE8VMB;W@@
M/2!N97<@2&]R9&5?36]B:6QE7V-H96-K8F]X*"=A9VUT)RP@)WEE<R<L("=)
M(&%G<F5E)RD["B`J("1M>4-H96-K8F]X(#T@;F5W($AO<F1E7TUO8FEL95]C
M:&5C:V)O>"@G86=M="<L("=Y97,G+"`G22!A9W)E92<L(&9A;'-E*3L*("H@
M)&UY0VAE8VMB;W@@/2!N97<@2&]R9&5?36]B:6QE7V-H96-K8F]X*"=A9VUT
M)RP@)WEE<R<L("=)(&%G<F5E)RP@=')U92D["B`J"B`J($!N;W1E(%1H92!F
M:7)S="!A;F0@<V5C;VYD(&5X86UP;&5S(&%R92!I9&5N=&EC86PN"B`J"B`J
M($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A8VMA9V4@2&]R9&5?
M36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?8VAE8VMB;W@@97AT96YD
M<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@('9A<B`D7V-H96-K
M960["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@("`@("!687)I86)L92!I;B!W:&EC:"`B
M=F%L=64B(&ES('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@9&5S=&EN871I;VX@55),+"!I9B!T:&4@8F]X(&ES(&-H96-K
M960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@("`@4V5E(&YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("`@1&5S8W)I8F5S('1H
M92!C:&5C:V)O>"!O;B!T:&4@<W5R9F5R)W,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!S8W)E96XO9&ES<&QA>2X*("`@("`J($!P87)A;2!B
M;V]L96%N("1C:&5C:V5D("!!;&QO=V5D('9A;'5E<R!A<F4@=')U92!O<B!F
M86QS92X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7V-H96-K
M8F]X*"1N86UE+"`D=F%L=64L("1L86)E;"P@)&-H96-K960@/2!F86QS92D*
M("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@(#T@)&YA;64["B`@("`@("`@
M)'1H:7,M/E]V86QU92`]("1V86QU93L*("`@("`@("`D=&AI<RT^7VQA8F5L
M(#T@)&QA8F5L.PH@("`@("`@("1T:&ES+3Y?8VAE8VME9"`]("1C:&5C:V5D
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0VAE8VME9"@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?8VAE8VME9#L*("`@('T*"GT*"B\J*@H@*B!4
M:&ES(&-L87-S('!R;W9I9&5S(&AI9&1E;B!E;&5M96YT<R!I;B!(;W)D95]-
M;V)I;&5?9F]R;2!O8FIE8W1S+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&AI
M9&1E;B`](&YE=R!(;W)D95]-;V)I;&5?:&ED9&5N*"=I;G1E<FYA;%]R969E
M<F5N8V4G+"`G,#@Q-30W,3$G*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&5?
M9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO
M<F1E7TUO8FEL95]H:61D96X@97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L
M96UE;G0@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5F%R:6%B;&4@:6X@=VAI8V@@
M)'9A;'5E(&ES('-E;G0@=&\@=&AE(&1E<W1I;F%T:6]N(%523"X*("`@("`J
M($!P87)A;2!S=')I;F<@)'9A;'5E("!3964@;F%M92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?36]B:6QE7VAI9&1E;B@D;F%M92P@)'9A;'5E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T
M:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C
M;&%S<R!P<F]V:61E<R!A('-U8FUI="!B=71T;VX@9F]R(&$@2&]R9&5?36]B
M:6QE7V9O<FT@;V)J96-T+B!/;F4*("H@2&]R9&5?36]B:6QE7V9O<FT@;V)J
M96-T(&-A;B!C;VYT86EN(&]N;'D@;VYE($AO<F1E7TUO8FEL95]S=6)M:70@
M;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H@)&UY4W5B;6ET(#T@)FYE=R!(
M;W)D95]-;V)I;&5?<W5B;6ET*"=3=6)M:70G*3L*("H@)&UY4W5B;6ET(#T@
M)FYE=R!(;W)D95]-;V)I;&5?<W5B;6ET*"=3=6)M:70G+"`G=7-E<E]P<F5S
M<V5D)RD["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A
M8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?<W5B
M;6ET(&5X=&5N9',@2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT('L*"B`@("!V
M87(@)%]F;W)M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@5VAA="=S('=R:71T96X@
M;VX@=&AE(&)U='1O;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("!6
M87)I86)L92!I;B!W:&EC:"`B;&%B96PB(&ES('-E;G0@=&\@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9&5S=&EN871I;VX@55),+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?<W5B;6ET*"1L86)E;"P@
M)&YA;64@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7VQA8F5L(#T@)&QA
M8F5L.PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@?0H*?0H*
M+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@82!L:6YK(&EN(&$@2&]R9&5?
M36]B:6QE+"!(;W)D95]-;V)I;&5?;&EN:W-E="!O<@H@*B!(;W)D95]-;V)I
M;&5?=&%B;&4@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY4&%G
M92`](&YE=R!(;W)D95]-;V)I;&4H+BXN*3L*("H*("H@)&UY3&EN:R`](&YE
M=R!(;W)D95]-;V)I;&5?;&EN:R@G0V]N=&EN=64G+"`G+VUY;F5X='!A9V4N
M=VUL)RD["B`J("1M>5!A9V4M/F%D9"@D;7E,:6YK*3L*("H*("H@0'-E92!(
M;W)D95]-;V)I;&4*("H@0'-E92!(;W)D95]-;V)I;&5?;&EN:W-E=`H@*B!`
M<V5E($AO<F1E7TUO8FEL95]T86)L90H@*@H@*B!`<&%C:V%G92!(;W)D95]-
M;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]L:6YK(&5X=&5N9',@2&]R
M9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7VQA8F5L.PH@("`@=F%R
M("1?=7)L.PH@("`@=F%R("1?=&ET;&4["B`@("!V87(@)%]A8V-E<W-K97D[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&QA8F5L("!$97-C<FEB97,@=&AE(&QI;FL@;VX@=&AE
M('-U<F9E<B=S('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7)L("`@($YE>'0@9&5S=&EN871I;VX@861D<F5S<RX@35535"!B92!V
M86QI9"!834P@*"9A;7`[(&EN<W1E860@;V8@)BP@971C+BDN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T:71L92`@268@82!S=')I;F<@:7,@<')O=FED960@
M:&5R92P@:70@=VEL;"!B92!D:7-P;&%Y960*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!I;B!T:&4@2%1-3"!B<F]W<V5R('-T871U<R!B87(@9'5R
M:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(DUO=7-E3W9E<B(L
M(')E<W!E8W1I=F5L>2!S;VUE=VAE<F4@;VX@=&AE(%=!4`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&1I<W!L87DN($EN(&]R9&5R('1O('=O<FL@
M=V5L;"!W:71H(&$@8G)O860@<F%N9V4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!O9B!U<V5R(&%G96YT<RP@:V5E<"!Y;W5R('1I=&QE('5N9&5R
M(#8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C:&%R86-T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?;&EN:R@D;&%B96PL
M("1U<FPL("1T:71L92`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&%B
M96P@/2`D;&%B96P["B`@("`@("`@)'1H:7,M/E]U<FP@/2`D=7)L.PH@("`@
M("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4["@H@("`@("`@("\O($YO(&%C
M8V5S<VME>2!A<W-I9VYE9"!B>2!D969A=6QT.R!C86X@8F4@87-S:6=N960@
M;&%T97(*("`@("`@("`O+R!F<F]M(&$@2&]R9&5?36]B:6QE7VQI;FMS970@
M;V)J96-T(&EF(')E<75I<F5D+@H@("`@("`@("1T:&ES+3Y?86-C97-S:V5Y
M(#T@;G5L;#L*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S
M(&$@<&AO;F4@;G5M8F5R(&EN(&$@2&]R9&5?36]B:6QE(&]B:F5C="X@268@
M<W5P<&]R=&5D(&)Y"B`J('1H96ER(&UO8FEL92!D979I8V4L('5S97)S(&-A
M;B!E<W1A8FQI<V@@82!V;VEC92!C;VYN96-T:6]N('1O('1H90H@*B!S<&5C
M:69I960@;G5M8F5R+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY4&AO;F4@
M/2`F;F5W($AO<F1E7TUO8FEL95]P:&]N92@G,3(S+30U-C<X)RP@)T-!3$PG
M*3L*("H@)&UY4&%G92T^861D*"1M>5!H;VYE*3L*("H*("H@0'-E92!(;W)D
M95]-;V)I;&4*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S
M<R!(;W)D95]-;V)I;&5?<&AO;F4@97AT96YD<R!(;W)D95]-;V)I;&5?96QE
M;65N="!["@H@("`@=F%R("1?;&%B96P["B`@("!V87(@)%]N=6UB97(["B`@
M("!V87(@)%]T:71L93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&AO;F5?;G5M8F5R("!0:&]N
M92!N=6UB97(@=&\@9&EA;"X*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE
M("`@("`@("`@268@82!S=')I;F<@:7,@<')O=FED960@:&5R92P@=&AE(&-A
M;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G5T=&]N
M(&]N(&$@5T%0+TA$34P@9&5V:6-E('=I;&P@8F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@96YA8FQE9"X@26X@;W)D97(@=&\@=V]R
M:R!W96QL('=I=&@*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@82!B<F]A9"!R86YG92!O9B!U<V5R(&%G96YT<RP@:V5E<"!Y;W5R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I=&QE('5N9&5R
M(#8@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B
M:6QE7W!H;VYE*"1P:&]N95]N=6UB97(L("1T:71L92`]("<G*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;&%B96P@/2`D<&AO;F5?;G5M8F5R.PH@("`@("`@
M("1T:&ES+3Y?;G5M8F5R(#T@<')E9U]R97!L86-E*"=\7$1\)RP@)R<L("1P
M:&]N95]N=6UB97(I.PH@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4[
M"B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!D969I;F5S(&$@<V5T(&]F
M(&QI;FMS+B!4:&4@;&EN:W,@:&%V92!T;R!B92!D969I;F5D(&%S"B`J('-E
M<&%R871E($AO<F1E7TUO8FEL95]L:6YK(&]B:F5C=',@86YD(&%R92!A='1A
M8VAE9"!T;R!T:&4@;&EN:W-E=`H@*B!W:71H(&$@<W!E8VEA;"`B861D(B!F
M=6YC=&EO;BX@($9O<B!705`@9&5V:6-E<R!B<F]W<V5R+61E<&5N9&5N=`H@
M*B!734P@8V]D92!W:6QL(&)E(&-R96%T960N($]N(&%L;"!54"UB<F]W<V5R
M+6)A<V5D(%=!4"!D979I8V5S"B`J(&QI;FMS971S(&%L;&]W(&5A<VEE<B!N
M879I9V%T:6]N('1H<F]U9V@@5TU,(&1E8VMS(&)Y('5S:6YG('1H90H@*B`B
M;VYP:6-K(B!734P@;W!T:6]N(&%N9"!T:&5R969O<F4@87)E(&EM<')O=FEN
M9R!T:&4@(G5S86)I;&ET>2(@;V8*("H@86X@87!P;&EC871I;VXN($EN<W1E
M860@;V8@<&%I;F9U;&QY(&YA=FEG871I;F<@=&AR;W5G:"!T:&4@;&EN:W,*
M("H@(G-P;W)T<RT^9F]O=&)A;&PM/G)E<W5L=',M/G1O9&%Y(B!T:&4@;6]B
M:6QE('5S97(@92YG+B!C86X@<')E<W,*("H@(C(T,S$B(&]N('1H92!K97EP
M860@=&\@96YT97(@:&ES(&9A=F]R:71E(&1E8VLN($9O<B!A;&P@;W1H97(@
M5T%0"B`J(&1E=FEC97,@;F]R;6%L(#QA/B!T86=S(&%R92!C<F5A=&5D+B!/
M;F4@2&]R9&5?36]B:6QE(&]B:F5C="!C86X*("H@8V]N=&%I;B!O;FQY(&]N
M92!L:6YK<V5T(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5!A
M9V4@/2!N97<@2&]R9&5?36]B:6QE*"XN+BD["B`J"B`J("1M>4QI;FMS970@
M/2!N97<@2&]R9&5?36]B:6QE7VQI;FMS970H*3L*("H@)&UY3&EN:S$@/2!N
M97<@2&]R9&5?36]B:6QE7VQI;FLH(E!H;VYE8F]O:R(L("(O=V%P+W!H;VYE
M8F]O:RYW;6PB*3L*("H@)&UY3&EN:W-E="T^861D*"1M>4QI;FLQ*3L*("H@
M)&UY3&EN:S(@/2!N97<@2&]R9&5?36]B:6QE7VQI;FLH(D1A=&5";V]K(BP@
M(B]W87`O9&%T96)O;VLN=VUL(BD["B`J("1M>4QI;FMS970M/F%D9"@D;7E,
M:6YK,BD["B`J"B`J("1M>5!A9V4M/F%D9"@D;7E,:6YK<V5T*3L*("H*("H@
M)&UY4&%G92T^<F5N9&5R*"D["B`J"B`J($!S964@2&]R9&5?36]B:6QE7VQI
M;FL*("H@0'-E92!(;W)D95]-;V)I;&4*("H*("H@0'!A8VMA9V4@2&]R9&5?
M36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?;&EN:W-E="!E>'1E;F1S
M($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@("!V87(@)%]E;&5M96YT<SL*
M"B`@("`O*BH*("`@("`J($%D9',@82!(;W)D95]-;V)I;&5?;&EN:R!O8FIE
M8W0@=&\@2&]R9&5?36]B:6QE7VQI;FMS970N"B`@("`@*@H@("`@("H@0'!A
M<F%M($AO<F1E7TUO8FEL95]L:6YK("1L:6YK("!4:&4@;&EN:R!O8FIE8W0@
M=&\@861D+@H@("`@("H*("`@("`J($!S964@2&]R9&5?36]B:6QE7VQI;FL*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@F)&QI;FLI"B`@("!["B`@("`@
M("`@:68@*"%I<U]A*"1L:6YK+"`G2&]R9&5?36]B:6QE7VQI;FLG*2D@>PH@
M("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=,:6YK<R!M
M=7-T(&)E($AO<F1E7TUO8FEL95]L:6YK(&]B:F5C=',N)RD["B`@("`@("`@
M("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7V5L96UE;G1S6UT@/2`F)&QI;FL["B`@("`@("`@)&QI;FLM/G-E="@G86-C
M97-S:V5Y)RP@8V]U;G0H)'1H:7,M/E]E;&5M96YT<RDI.PH*("`@("`@("!R
M971U<FX@)&QI;FL["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!W:6QL
M(&-A=7-E(&$@:&]R:7IO;G1A;"!R=6QE('1O(&)E(&1R87=N(&%C<F]S<R!T
M:&4@<V-R965N+B`@66]U"B`J(&-A;B!U<V4@:70@=&\@<V5P87)A=&4@=&5X
M="!P87)A9W)A<&AS(&EN($AO<F1E7TUO8FEL92!O<B!(;W)D95]-;V)I;&5?
M9F]R;0H@*B!O8FIE8W1S+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY1&5F
M875L=%)U;&4@/2!N97<@2&]R9&5?36]B:6QE7W)U;&4H*3L*("H@)&UY4W!E
M8VEA;%)U;&4@/2!N97<@2&]R9&5?36]B:6QE7W)U;&4H)S8P)2<L(#0I.PH@
M*@H@*B`D;7E086=E+3YA9&0H)&UY1&5F875L=%)U;&4I.PH@*@H@*B`D;7E0
M86=E+3YA9&0H)&UY4W!E8VEA;%)U;&4I.PH@*@H@*B!`<V5E($AO<F1E7TUO
M8FEL90H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E
M($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W)U;&4@97AT
M96YD<R!(;W)D95]-;V)I;&5?96QE;65N="!["@H@("`@=F%R("1?=VED=&@[
M"B`@("!V87(@)%]S:7IE.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@(%!E<F-E;G1A
M9V4@;V8@<V-R965N('=I9'1H(&]R(&%B<V]L=71E('9A;'5E(&EN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&YU;6)E<B!O9B!P:7AE;',@*&4N
M9RX@(C4P)2(L(#$P,"DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VEZ92`@
M($AE:6=H="!O9B!T:&4@;&EN92!T;R!B92!D<F%W;B!I;B!P:7AE;',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]R=6QE*"1W:61T:"`]
M("<G+"`D<VEZ92`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=VED=&@@
M/2`D=VED=&@["B`@("`@("`@)'1H:7,M/E]S:7IE(#T@)'-I>F4["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)0
M0RYP:'``````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R,#$P,P`Q,#4Q-30S,3`V,0`P,3<S-#4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D
M95]24$,Z.B!C;&%S<R!P<F]V:61E<R!A('-E="!O9B!S97)V97(@86YD(&-L
M:65N="!M971H;V1S(&9O<@H@*B!24$,@8V]M;75N:6-A=&EO;BX*("H*("H@
M5$]$3SH*("H@+2!);G1R;W-P96-T:6]N(&1O8W5M96YT871I;VX@86YD(&UE
M=&AO9"!S:6=N871U<F5S+@H@*@H@*B!%6$%-4$Q%.@H@*B`\8V]D93X*("H@
M)')E<W!O;G-E(#T@2&]R9&5?4E!#.CIR97%U97-T*"=X;6QR<&,G+`H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAT='`Z+R]L;V-A;&AO
M<W0Z.#`O:&]R9&4O<G!C+G!H<"<*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=C;VYT86-T<RYS96%R8V@G+`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH87)R87DH)VIA;B<I+"!A<G)A>2@G
M;&]C86QS<6PG*2P*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=N86UE)RP@)V5M86EL)RDI+`H@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W5S97(G(#T^($%U=&@Z.F=E
M=$%U=&@H*2P*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=P87-S)R`]/B!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I
M*2D["B`J(#PO8V]D93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4E!#+U)0
M0RYP:'`L=B`Q+C<N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C,S(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J+PIC;&%S<R!(;W)D95]24$,@
M>PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!W92!N965D(&%N(&%U=&AO<FEZ
M960@=7-E<B!O<B!N;W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]A=71H
M;W)I>F4@/2!T<G5E.PH*("`@("\J*@H@("`@("H@4E!#('-E<G9E<B!C;VYS
M=')U8W1O<@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@
M0')E='5R;B!O8FIE8W0@("!!;B!24$,@<V5R=F5R(&EN<W1A;F-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!(;W)D95]24$,H*0H@("`@>PH@("`@("`@(')E
M9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"1T:&ES+"`G<VAU=&1O
M=VXG*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=7`@=&AE(%)0
M0R!S97)V97(N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-H=71D;W=N*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H96-K(&%U=&AE;G1I8V%T:6]N+B!$:69F97)E;G0@8F%C:V5N9',@
M;6%Y(&AA;F1L90H@("`@("H@875T:&5N=&EC871I;VX@:6X@9&EF9F5R96YT
M('=A>7,N(%1H92!B87-E(&-L87-S(&EM<&QE;65N=&%T:6]N"B`@("`@*B!C
M:&5C:W,@9F]R($A45%`@075T:&5N=&EC871I;VX@86=A:6YS="!T:&4@2&]R
M9&4@875T:"!S971U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%)E='5R;G,@=')U92!I9B!A=71H96YT:6-A=&EO;B!I<R!S=6-C97-S9G5L
M+@H@("`@("H@("`@("`@("`@("`@("`@("!3:&]U;&0@<V5N9"!A<'!R;W!R
M:6%T92`B;F]T(&%U=&AO<FEZ960B(&AE861E<G,*("`@("`J("`@("`@("`@
M("`@("`@("`@;W(@;W1H97(@<F5S<&]N<V4@8V]D97,O8F]D>2!I9B!A=71H
M(&9A:6QS+`H@("`@("H@("`@("`@("`@("`@("`@("!A;F0@=&%K92!C87)E
M(&]F(&5X:71I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AO<FEZ92@I
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V%U=&AO<FEZ92D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1A=71H
M(#T@)D%U=&@Z.G-I;F=L971O;B@D1TQ/0D%,4ULG8V]N9B==6R=A=71H)UU;
M)V1R:79E<B==*3L*"B`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=02%!?
M05542%]54T52)UTI*2!["B`@("`@("`@("`@("1U<V5R(#T@)%]315)615);
M)U!(4%]!551(7U5315(G73L*("`@("`@("`@("`@)'!A<W,@/2`D7U-%4E9%
M4ELG4$A07T%55$A?4%<G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S
M970H)'5S97(I"B`@("`@("`@("`@('Q\("$D875T:"T^875T:&5N=&EC871E
M*"1U<V5R+"!A<G)A>2@G<&%S<W=O<F0G(#T^("1P87-S*2DI('L*("`@("`@
M("`@("`@:&5A9&5R*"=75U<M075T:&5N=&EC871E.B!"87-I8R!R96%L;3TB
M2&]R9&4@4E!#(B<I.PH@("`@("`@("`@("!H96%D97(H)TA45%`O,2XP(#0P
M,2!5;F%U=&AO<FEZ960G*3L*("`@("`@("`@("`@96-H;R`G-#`Q(%5N875T
M:&]R:7IE9"<["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M<F5Q=65S="!B;V1Y(&EN<'5T+B!$:69F97)E;G0@4E!#(&)A8VME;F1S(&-A
M;B!O=F5R<FED90H@("`@("H@=&AI<R!T;R!R971U<FX@86X@;W!E;B!S=')E
M86T@=&\@<&AP.B\O<W1D:6XL(&9O<B!I;G-T86YC92`M"B`@("`@*B!W:&%T
M979E<B!I<R!E87-I97-T('1O(&AA;F1L92!I;B!T:&4@9V5T4F5S<&]N<V4H
M*2!M971H;V0N"B`@("`@*@H@("`@("H@5&AE(&)A<V4@8VQA<W,@:6UP;&5M
M96YT871I;VX@;&]O:W,@9F]R("1(5%107U)!5U]03U-47T1!5$$@86YD"B`@
M("`@*B!R971U<FYS('1H870@:68@:70G<R!A=F%I;&%B;&4[(&]T:&5R=VES
M92P@:70@<F5T=7)N<R!T:&4*("`@("`J(&-O;G1E;G1S(&]F('!H<#HO+W-T
M9&EN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!I;G!U="`M
M(&$@<W1R:6YG("AD969A=6QT*2P@82!F:6QE:&%N9&QE+"!E=&,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$EN<'5T*"D*("`@('L*("`@("`@("!I9B`H
M:7-S970H)$=,3T)!3%-;)TA45%!?4D%77U!/4U1?1$%402==*2D@>PH@("`@
M("`@("`@("!R971U<FX@)$=,3T)!3%-;)TA45%!?4D%77U!/4U1?1$%402==
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!I;7!L;V1E
M*")<<EQN(BP@9FEL92@G<&AP.B\O:6YP=70G*2D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4V5N9',@86X@4E!#(')E<75E<W0@=&\@=&AE
M('-E<G9E<B!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@(%1H92!R87<@<F5Q=65S="!S=')I;F<N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!834P@96YC;V1E9"!R97-P
M;VYS92!F<F]M('1H92!S97)V97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%)E<W!O;G-E*"1R97%U97-T*0H@("`@>PH@("`@("`@(')E='5R;B!?*")N
M;W0@:6UP;&5M96YT960B*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@0V]N=&5N="U4>7!E(&]F('1H92!R97-P;VYS92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@0V]N=&5N="U4>7!E(&]F('1H
M92!24$,@<F5S<&]N<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O
M;G-E0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]X
M;6PG.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&%N(%)00R!R97%U
M97-T(&%N9"!S96YD<R!I="!T;R!T:&4@4E!#('-E<G9E<BX*("`@("`J"B`@
M("`@*B!4:&ES('-T871I8V%L;'D@8V%L;&5D(&UE=&AO9"!I<R!A8W1U86QL
M>2!T:&4@4E!#(&-L:65N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D<FEV97(@("`@5&AE('!R;W1O8V]L(&1R:79E<B!T;R!U<V4N($-U<G)E
M;G1L>2`G<V]A<"<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A
M;F0@)WAM;')P8R<@87)E(&%V86EL86)L92X*("`@("`J($!P87)A;2!S=')I
M;F<@)'5R;"`@("`@("!4:&4@<&%T:"!T;R!T:&4@4E!#('-E<G9E<B!O;B!T
M:&4@8V%L;&5D(&AO<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@
M("`@5&AE(&UE=&AO9"!T;R!C86QL+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!N96-E<W-A<GD@<&%R
M86UE=&5R<R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@;65T:&]D(&-A;&PN"B`@("`@*B!`<&%R86T@)&]P=&EO;G,@("`@("`@
M("`@07-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R<R!D97!E;F1I;F<@
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@<V5L96-T
M960@<')O=&]C;VP@9')I=F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@("`@("`@("`@("!4:&4@<F5T=7)N960@<F5S=6QT(&9R;VT@=&AE(&UE
M=&AO9"!O<B!A(%!%05(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!E<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5Q=65S="@D9')I=F5R+"`D=7)L+"`D;65T:&]D+"`D<&%R86US(#T@
M;G5L;"P@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1A<'`L("1D
M<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@
M/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*"%E;7!T>2@D87!P
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)&%P<"`N("<O;&EB+U)0
M0R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I
M;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]24$,O)R`N("1D<FEV
M97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O4E!#+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO
M<F1E+U)00R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]"B`@("`@
M("`@)&-L87-S(#T@)TAO<F1E7U)00U\G("X@)&1R:79E<CL*("`@("`@("!I
M9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1C;&%S<RP@)W)E<75E<W0G*2P@)'5R
M;"P@)&UE=&AO9"P@)'!A<F%M<RP@)&]P=&EO;G,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI
M=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M8V]N8W)E=&4@4E!#('-E<G9E<B!I;G-T86YC92!B87-E9"!O;@H@("`@("H@
M)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@4E!#('-U8F-L87-S('1O(')E='5R;BX@
M268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R(&ES(&%N
M(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:R!I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("1D<FEV97);,%TO;&EB+U)00R\@9F]R('1H92!S=6)C
M;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T
M:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O
M;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C
M;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@
M("`@("H*("`@("`J($!R971U<FX@2&]R9&5?4E!#("!4:&4@;F5W;'D@8W)E
M871E9"!C;VYC<F5T92!(;W)D95]24$,@<V5R=F5R(&EN<W1A;F-E+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@(&]R(&$@4$5!4E]%<G)O<B!O;B!A;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D
M<FEV97(I*2!["B`@("`@("`@("`@(&QI<W0H)&%P<"P@)&1R:79E<BD@/2`D
M9')I=F5R.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE
M*"1D<FEV97(I.PH*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`D87!P("X@)R]L:6(O4E!#+R<@+B`D9')I
M=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)00R\G("X@)&1R:79E<B`N("<N<&AP
M)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]24$,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O4E!#+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@
M/2`G2&]R9&5?4E!#7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D<G!C(#T@)FYE=R`D8VQA
M<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@("1R<&,@/2!014%2
M.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@
M+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<G!C.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@4E!#('-E<G9E<@H@("`@("H@
M:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T
M92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@;F\@4E!#('-E<G9E<B!I;G-T
M86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY"B`@("`@
M*B!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I
M9B!M=6QT:7!L92!24$,@<V5R=F5R<R`H86YD('1H=7,L(&UU;'1I<&QE(%)0
M0PH@("`@("H@<V5R=F5R(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A
M<B`]("9(;W)D95]24$,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!24$,@
M<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U
M<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!(;W)D95]24$,@(%1H92!C;VYC<F5T92!(;W)D
M95]24$,@<V5R=F5R(')E9F5R96YC92P@;W(@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@(%!%05)?17)R;W(@;VX@86X@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@(&EF
M("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@
M<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I
M9B`H(6%R<F%Y7VME>5]E>&ES=',H)'-I9VYA='5R92P@)&EN<W1A;F-E<RDI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D
M95]24$,Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+G!H<```````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#4P-P`Q
M,#4Q-30S,3`V,0`P,3<R-#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%-O<G1I;F<@;W!T:6]N<PH@
M*B\*9&5F:6YE*"=60U]33U)47TY/3D4G+"`P*3L@("`@("`@("\O(&1O;B=T
M('-O<G0*9&5F:6YE*"=60U]33U)47T%'12<L(#$I.R`@("`@("`@("\O('-O
M<G0@8GD@86=E"F1E9FEN92@G5D-?4T]25%].04U%)RP@,BD[("`@("`@("`O
M+R!S;W)T(&)Y(&9I;&5N86UE"F1E9FEN92@G5D-?4T]25%]2158G+"`S*3L@
M("`@("`@("`O+R!S;W)T(&)Y(')E=FES:6]N(&YU;6)E<@ID969I;F4H)U9#
M7U-/4E1?05542$]2)RP@-"D[("`@("`@+R\@<V]R="!B>2!A=71H;W(@;F%M
M90H*9&5F:6YE*"=60U]33U)47T%30T5.1$E.1R<L(#`I.R`@("\O(&%S8V5N
M9&EN9R!O<F1E<@ID969I;F4H)U9#7U-/4E1?1$530T5.1$E.1R<L(#$I.R`@
M+R\@9&5S8V5N9&EN9R!O<F1E<@H*9&5F:6YE*"=60U]724Y$3U=3)RP@<W5B
M<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<I.PH*+RHJ"B`J(%9E<G-I;VX@
M0V]N=')O;"!G96YE<F%L:7IE9"!L:6)R87)Y+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]60R]60RYP:'`L=B`Q+C$R+C@N,3(@,C`P-B\P-2\S,2`Q-SHP
M-CHS-R!S96QS:WD@17AP("0*("H*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S
M(%9#('L*"B`@("`O*BH*("`@("`J(%1H92!S;W5R8V4@<F]O="!O9B!T:&4@
M<F5P;W-I=&]R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V]U<F-E<F]O
M=#L*"B`@("`O*BH*("`@("`J($AA<V@@=VET:"!T:&4@;&]C871I;VYS(&]F
M(&%L;"!N96-E<W-A<GD@8FEN87)I97,N"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W!A=&AS(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($AA<V@@8V%C:&EN9R!T:&4@<&%R<V5D('5S97)S(&9I;&4N"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W5S97)S.PH*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!S;W5R8V4@<F]O="!F;W(@=&AI<R!R97!O
M<VET;W)Y+"!W:71H(&YO('1R86EL:6YG("\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@4V]U<F-E(')O;W0@9F]R('1H:7,@<F5P;W-I=&]R>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V]U<F-E<F]O="@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<V]U<F-E<F]O=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&QO8V%T:6]N(&]F('1H92!S<&5C:69I960@
M8FEN87)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)I;F%R>2`@
M06X@97AT97)N86P@<')O9W)A;2!N86UE+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;GQS=')I;F<@(%1H92!L;V-A=&EO;B!O9B!T:&4@97AT97)N
M86P@<')O9W)A;2!O<B!F86QS92!I9@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@:70@=V%S;B=T('-P96-I9FEE9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&%T:"@D8FEN87)Y*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A=&AS6R1B:6YA<GE=*2D@>PH@("`@("`@("`@("!I9B`H
M5D-?5TE.1$]74RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&%T:'-;)&)I;F%R>5T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R971U<FX@:7-?97AE8W5T86)L92@D=&AI<RT^7W!A=&AS6R1B
M:6YA<GE=*2`_("1T:&ES+3Y?<&%T:'-;)&)I;F%R>5T@.B!F86QS93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@=&AE('5S97)S(&9I;&4L(&EF
M('!R97-E;G0@:6X@=&AE('-O=7)C92!R;V]T+"!A;F0@<F5T=7)N"B`@("`@
M*B!A(&AA<V@@8V]N=&%I;FEN9R!T:&4@<F5Q=6ES:71E(&EN9F]R;6%T:6]N
M+"!K97EE9"!O;B!T:&4*("`@("`J('5S97)N86UE+"!A;F0@=VET:"!T:&4@
M)V1E<V,G+"=N86UE)RP@86YD("=M86EL)R!V86QU97,@:6YS:61E+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;GQA<G)A>2`@1F%L<V4@:68@=&AE
M(&9I;&4@:7,@;F]T('!R97-E;G0L(&]T:&5R=VES90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97)S('!O<'5L871E9"!W:71H
M('1H92!D871A"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5S97)S*"1U<V5R
M<V9I;&4I"B`@("!["B`@("`@("`@+RH@0VAE8VL@=&AA="!W92!H879E;B=T
M(&%L<F5A9'D@<&%R<V5D('5S97)S+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W5S97)S*2`F)B!I<U]A<G)A>2@D=&AI<RT^7W5S97)S*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]U<V5R<SL*("`@("`@("!]"@H@
M("`@("`@(&EF("@A0&ES7V9I;&4H)'5S97)S9FEL92D@?'P@(2@D9FP@/2!`
M9F]P96XH)'5S97)S9FEL92P@5D-?5TE.1$]74R`_("=R8B<@.B`G<B<I*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7W5S97)S(#T@87)R87DH*3L*"B`@("`@("`@+RH@1&ES8V%R
M9"!T:&4@9FER<W0@;&EN92P@<VEN8V4@:70G;&P@8F4@=&AE(&AE861E<B!I
M;F9O+B`J+PH@("`@("`@(&9G971S*"1F;"P@-#`Y-BD["@H@("`@("`@("\J
M(%!A<G-E('1H92!R97-T(&]F('1H92!L:6YE<R!I;G1O(&$@:&%S:"P@:V5Y
M960@;VX*("`@("`@("`@*B!U<V5R;F%M92X@*B\*("`@("`@("!W:&EL92`H
M)&QI;F4@/2!F9V5T<R@D9FPL(#0P.38I*2!["B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7EQS*B0O)RP@)&QI;F4I*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(7!R
M96=?;6%T8V@H)R]>*%QW*RE<<RLH+BLI7',K*%M<=UPN7"U<7UTK0%M<=UPN
M7"U<7UTK*5QS*R@N*BDD+R<L("1L:6YE+"`D<F5G<RDI('L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7W5S97)S6R1R96=S6S%=75LG;F%M92==(#T@=')I;2@D<F5G<ULR
M72D["B`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)')E9W-;,5U=6R=M86EL
M)UT@/2!T<FEM*"1R96=S6S-=*3L*("`@("`@("`@("`@)'1H:7,M/E]U<V5R
M<ULD<F5G<ULQ75U;)V1E<V,G72`]('1R:6TH)')E9W-;-%TI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=7-E<G,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!60R!I
M;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!60R!S=6)C
M;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET
M:6]N86P@8V]N9FEG=7)A=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&]R("!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%9#("!4:&4@;F5W;'D@8W)E871E9"!C;VYC
M<F5T92!60R!I;G-T86YC92P@;W(@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@
M("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:6YC;'5D95]O;F-E("=60R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("`D8VQA<W,@/2`G5D-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1V8R`](&YE=R`D8VQA
M<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9C
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C
M;VYC<F5T92!60R!I;G-T86YC92!B87-E9`H@("`@("H@;VX@)&1R:79E<BX@
M270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!60PH@
M("`@("H@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E
M;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E
M9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F:6QE(&)A8VME;F1S("AA;F0L"B`@
M("`@*B!T:'5S+"!M=6QT:7!L92!60R!I;G-T86YC97,I(&%R92!R97%U:7)E
M9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@
M87,Z("1V87(@/2`F5D,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9#('-U
M8F-L87-S('1O(')E='5R;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D
M:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@;W(@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!60R`@5&AE(&-O;F-R971E(%9#(')E9F5R
M96YC92P@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF
M("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@
M<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I
M9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@
M("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2!60SHZ9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E
M(%9#"B`J+PIC;&%S<R!60U]$:69F('L*"B`@("`O*BH*("`@("`J($]B=&%I
M;B!A('1R964@8V]N=&%I;FEN9R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8VAA
M;F=E<R!B971W965N"B`@("`@*B!T=V\@<F5V:7-I;VYS+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<F%W("!!;B!A<G)A>2!O9B!L:6YE<R!O9B!T
M:&4@<F%W('5N:69I960@9&EF9BP*("`@("`J("`@("`@("`@("`@("`@("`@
M("!N;W)M86QL>2!O8G1A:6YE9"!T:')O=6=H(%9#7T1I9F8Z.F=E="@I+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J"B`@("`@*B!`=&]D
M;R!D;V-U;65N="!T:&ES('1H;W)O=6=H;'DL(&%S('1H92!F;W)M870@:7,@
M82!B:70@8V]M<&QE>"X*("`@("`J+PH@("`@9G5N8W1I;VX@:'5M86Y296%D
M86)L92@D<F%W*0H@("`@>PH@("`@("`@("1R970@/2!A<G)A>2@I.PH*("`@
M("`@("`O*B!(;VQD('1H92!L969T(&%N9"!R:6=H="!C;VQU;6YS(&]F(&QI
M;F5S(&9O<B!C:&%N9V4*("`@("`@("`@*B!B;&]C:W,N("HO"B`@("`@("`@
M)&-O;',@/2!A<G)A>2AA<G)A>2@I+"!A<G)A>2@I*3L*("`@("`@("`D<W1A
M=&4@/2`G96UP='DG.PH*("`@("`@("`O*B!)=&5R871E('1H<F]U9V@@979E
M<GD@;&EN92!O9B!T:&4@9&EF9BX@*B\*("`@("`@("!F;W)E86-H("@D<F%W
M(&%S("1L:6YE*2!["B`@("`@("`@("`@("\J($QO;VL@9F]R(&$@:&5A9&5R
M('=H:6-H(&EN9&EC871E<R!T:&4@<W1A<G0@;V8@82!D:69F"B`@("`@("`@
M("`@("`J(&-H=6YK+B`J+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UY`0"!<+2A;,"TY72LI+BI<*RA;,"TY72LI+BI`0"@N*BDO)RP@)&QI;F4L
M("1R96=S*2D@>PH@("`@("`@("`@("`@("`@+RH@4'5S:"!A;GD@<')E=FEO
M=7,@:&5A9&5R(&EN9F]R;6%T:6]N('1O('1H92!R971U<FX*("`@("`@("`@
M("`@("`@("`J('-T86-K+B`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D871A*2D@>PH@("`@("`@("`@("`@("`@("`@("1R971;72`]("1D871A
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&$@/2!A
M<G)A>2@G='EP92<@/3X@)VAE861E<B<L("=O;&1L:6YE)R`]/B`D<F5G<ULQ
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYE=VQI;F4G(#T^
M("1R96=S6S)=+"`G8V]N=&5N=',G/B!A<G)A>2@I*3L*("`@("`@("`@("`@
M("`@("1D871A6R=F=6YC=&EO;B==(#T@:7-S970H)')E9W-;,UTI(#\@)')E
M9W-;,UT@.B`G)SL*("`@("`@("`@("`@("`@("1S=&%T92`]("=D=6UP)SL*
M("`@("`@("`@("`@?2!E;'-E:68@*"1S=&%T92`A/2`G96UP='DG*2!["B`@
M("`@("`@("`@("`@("`O*B!792!A<F4@:6X@82!C:'5N:RP@<V\@<W!L:70@
M;W5T('1H92!A8W1I;VX@*"LO+2D*("`@("`@("`@("`@("`@("`J(&%N9"!T
M:&4@;&EN92X@*B\*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)R]>*%M<
M*UPM(%TI*"XJ*2\G+"`D;&EN92P@)')E9W,I.PH@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1R96=S*2`^(#(I('L*("`@("`@("`@("`@("`@("`@("`D
M86-T:6]N(#T@)')E9W-;,5T["B`@("`@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2`D<F5G<ULR73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&%C=&EO;B`]("<@)SL*("`@("`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]("<G.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(&EF("@D86-T:6]N(#T]("<K)RD@>PH@("`@("`@("`@("`@
M("`@("`@("\J(%1H:7,@:7,@:G5S="!A;B!A9&1I=&EO;B!L:6YE+B`J+PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D<W1A=&4@/3T@)V1U;7`G('Q\("1S
M=&%T92`]/2`G861D)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!3
M=&%R="!A9&1I;F<@=&\@=&AE(&%D9&ET:6]N('-T86-K+B`J+PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8V]L<ULP75M=(#T@)&-O;G1E;G0["B`@("`@
M("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=A9&0G.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("\J
M(%1H:7,@:7,@:6YS:61E(&$@8VAA;F=E(&)L;V-K+"!S;R!S=&%R=`H@("`@
M("`@("`@("`@("`@("`@("`@("`@*B!A8V-U;75L871I;F<@;&EN97,N("HO
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=C:&%N9V4G.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]L<ULQ75M=(#T@)&-O;G1E;G0[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1A8W1I;VX@/3T@)RTG*2!["B`@("`@("`@("`@("`@("`@("`@+RH@
M5&AI<R!I<R!A(')E;6]V86P@;&EN92X@*B\*("`@("`@("`@("`@("`@("`@
M("`D<W1A=&4@/2`G<F5M;W9E)SL*("`@("`@("`@("`@("`@("`@("`D8V]L
M<ULP75M=(#T@)&-O;G1E;G0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("\J($%N(&5M<'1Y(&)L;V-K('=I=&@@;F\@
M86-T:6]N+B`J+PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)'-T871E
M*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G861D)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T
M>7!E)R`]/B`G861D)RP@)VQI;F5S)R`]/B`D8V]L<ULP72D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C
M87-E("=R96UO=F4G.@H@("`@("`@("`@("`@("`@("`@("`@("`O*B!792!H
M879E('-O;64@<F5M;W9A;"!L:6YE<R!P96YD:6YG(&EN(&]U<@H@("`@("`@
M("`@("`@("`@("`@("`@("`@*B!S=&%C:RP@<V\@9FQU<V@@=&AE;2X@*B\*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;72`]
M(&%R<F%Y*"=T>7!E)R`]/B`G<F5M;W9E)RP@)VQI;F5S)R`]/B`D8V]L<ULP
M72D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@("`@("!C87-E("=C:&%N9V4G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`O*B!792!H879E(&)O=&@@<F5M;W9E(&%N9"!A9&1I=&EO;B!L:6YE
M<RP@<V\*("`@("`@("`@("`@("`@("`@("`@("`@("H@=&AI<R!I<R!A(&-H
M86YG92!B;&]C:RX@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;
M)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G8VAA;F=E)RP@)V]L
M9"<@/3X@)&-O;'-;,%TL("=N97<G(#T^("1C;VQS6S%=*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1C;VQS(#T@87)R87DH87)R87DH*2P@87)R
M87DH*2D["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;
M72`](&%R<F%Y*"=T>7!E)R`]/B`G96UP='DG+"`G;&EN92<@/3X@)&-O;G1E
M;G0I.PH@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=D=6UP)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@2G5S="!F;'5S:"!A;GD@<F5M86EN:6YG(&5N=')I97,@:6X@=&AE
M(&-O;'5M;G,@<W1A8VLN("HO"B`@("`@("`@<W=I=&-H("@D<W1A=&4I('L*
M("`@("`@("!C87-E("=A9&0G.@H@("`@("`@("`@("`D9&%T85LG8V]N=&5N
M=',G75M=(#T@87)R87DH)W1Y<&4G(#T^("=A9&0G+"`G;&EN97,G(#T^("1C
M;VQS6S!=*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W)E
M;6]V92<Z"B`@("`@("`@("`@("\J(%=E(&AA=F4@<V]M92!R96UO=F%L(&QI
M;F5S('!E;F1I;F<@:6X@;W5R('-T86-K+"!S;PH@("`@("`@("`@("`@*B!F
M;'5S:"!T:&5M+B`J+PH@("`@("`@("`@("`D9&%T85LG8V]N=&5N=',G75M=
M(#T@87)R87DH)W1Y<&4G(#T^("=R96UO=F4G+"`G;&EN97,G(#T^("1C;VQS
M6S!=*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V-H86YG
M92<Z"B`@("`@("`@("`@("\J(%=E(&AA=F4@8F]T:"!R96UO=F4@86YD(&%D
M9&ET:6]N(&QI;F5S+"!S;R!T:&ES(&ES(&$*("`@("`@("`@("`@("H@8VAA
M;F=E(&)L;V-K+B`J+PH@("`@("`@("`@("`D9&%T85LG8V]N=&5N=',G75M=
M(#T@87)R87DH)W1Y<&4G(#T^("=C:&%N9V4G+"`G;VQD)R`]/B`D8V]L<ULP
M72P@)VYE=R<@/3X@)&-O;'-;,5TI.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D9&%T82DI('L*("`@("`@("`@
M("`@)')E=%M=(#T@)&1A=&$["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E=#L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@
M5D-?1FEL92!["@H@("`@=F%R("1R97`["B`@("!V87(@)&1I<CL*("`@('9A
M<B`D;F%M93L*("`@('9A<B`D;&]G<SL*("`@('9A<B`D<F5V<SL*("`@('9A
M<B`D:&5A9#L*("`@('9A<B`D<75I8VML;V<["B`@("!V87(@)'-Y;7)E=CL*
M("`@('9A<B`D<F5V<WEM.PH@("`@=F%R("1B<F%N8VAE<SL*"B`@("!F=6YC
M=&EO;B!S971297!O<VET;W)Y*"1R97`I"B`@("!["B`@("`@("`@)'1H:7,M
M/G)E<"`]("1R97`["B`@("!]"@I]"@HO*BH*("H@5D,@<&%T8VAS970@8VQA
M<W,N"B`J"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]0871C:'-E="![
M"@H@("`@=F%R("1?<F5P.PH@("`@=F%R("1?<&%T8VAS971S(#T@87)R87DH
M*3L*"B`@("!F=6YC=&EO;B!S971297!O<VET;W)Y*"1R97`I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]R97`@/2`D<F5P.PH@("`@?0H*?0H*+RHJ"B`J(%9#
M(')E=FES:6]N<R!C;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V
M87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL
M($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!6
M0PH@*B\*8VQA<W,@5D-?4F5V:7-I;VX@>PH*("`@("\J*@H@("`@("H@5F%L
M:61A=&EO;B!F=6YC=&EO;B!T;R!E;G-U<F4@=&AA="!A(')E=FES:6]N(&YU
M;6)E<B!I<R!O9B!T:&4*("`@("`J(')I9VAT(&9O<FTN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%L("!686QU92!T;R!C:&5C:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@:70@:7,@82!R979I
M<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:60H)'9A;"D*
M("`@('L*("`@("`@("!R971U<FX@)'9A;"`F)B!P<F5G7VUA=&-H*"<O7EM<
M9%PN72LD+R<L("1V86PI.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@
M82!R979I<VEO;B!N=6UB97(L(')E;6]V92!A(&=I=F5N(&YU;6)E<B!O9B!P
M;W)T:6]N<R!F<F]M"B`@("`@*B!I="X@1F]R(&5X86UP;&4L(&EF('=E(')E
M;6]V92`R('!O<G1I;VYS(&]F(#$N,BXS+C0L('=E(&%R90H@("`@("H@;&5F
M="!W:71H(#$N,BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86P@
M("`@("!);G!U="!R979I<VEO;@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%M
M;W5N="`@3G5M8F5R(&]F('!O<G1I;VYS('1O('-T<FEP"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%-T<FEP<&5D(')E=FES:6]N(&YU;6)E<@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S=')I<"@D=F%L+"`D86UO=6YT*0H@("`@
M>PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1V86PI*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)'!O
M<R`](#`["B`@("`@("`@=VAI;&4@*"1A;6]U;G0M+2`^(#`@)B8@*"1P;W,@
M/2!S=')R<&]S*"1V86PL("<N)RDI("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`D=F%L(#T@<W5B<W1R*"1V86PL(#`L("1P;W,I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'!O<R`A/3T@9F%L<V4@/R`D=F%L(#H@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@<VEZ92!O9B!A(')E=FES:6]N(&YU
M;6)E<B!I<R!T:&4@;G5M8F5R(&]F('!O<G1I;VYS(&ET(&AA<RX*("`@("`J
M($9O<B!E>&%M<&QE+"`Q+#(N,RXT(&ES(&]F('-I>F4@-"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1V86P@(%)E=FES:6]N(&YU;6)E<B!T;R!D
M971E<FUI;F4@<VEZ92!O9@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@4VEZ92!O9B!R979I<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VEZ96]F*"1V86PI"B`@("!["B`@("`@("`@:68@*"%60U]2979I<VEO
M;CHZ=F%L:60H)'9A;"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("AS=6)S=')?8V]U;G0H)'9A;"P@
M)RXG*2`K(#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!V86QI
M9"!R979I<VEO;B!N=6UB97(L('1H:7,@=VEL;"!R971U<FX@=&AE(')E=FES
M:6]N"B`@("`@*B!N=6UB97(@9G)O;2!W:&EC:"!I="!B<F%N8VAE9"X@268@
M:70@8V%N;F]T(&)E(&1E=&5R;6EN960L('1H96X*("`@("`J(&9A;'-E(&ES
M(')E='5R;F5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'9A;"`@
M4F5V:7-I;VX@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M?&)O;VQE86X@($)R86YC:"!P;VEN="!R979I<VEO;BP@;W(@9F%L<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&)R86YC:%!O:6YT*"1V86PI"B`@("!["B`@
M("`@("`@+RH@0VAE8VL@:68@=V4@:&%V92!A('9A;&ED(')E=FES:6]N(&YU
M;6)E<B`J+PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1V86PI
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J($EF(&ET<R!O;B!T:&4@=')U;FLL(&]R(&ES(&%N(&]D9"!S:7IE
M+"!R970@9F%L<V4@*B\*("`@("`@("!I9B`H5D-?4F5V:7-I;VXZ.G-I>F5O
M9B@D=F%L*2`\(#,@?'P@*%9#7U)E=FES:6]N.CIS:7IE;V8H)'9A;"D@)2`R
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!3=')I<"!O9F8@='=O(')E=FES:6]N('!O<G1I;VYS+"!A;F0@
M<F5T=7)N(&ET("HO"B`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIS=')I
M<"@D=F%L+"`R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N('1W;R!3
M5DX@<F5V:7-I;VX@;G5M8F5R<RP@=&AI<R!F:6=U<F5S(&]U="!W:&EC:"!O
M;F4@:7,*("`@("`J(&=R96%T97(@=&AA;B!T:&4@;W1H97(@8GD@<W1E<'!I
M;F<@86QO;F<@=&AE(&1E8VEM86P@<&]I;G1S"B`@("`@*B!U;G1I;"!A(&1I
M9F9E<F5N8V4@:7,@9F]U;F0L(&%T('=H:6-H('!O:6YT(&$@<VEG;B!C;VUP
M87)I<V]N"B`@("`@*B!O9B!T:&4@='=O(&ES(')E='5R;F5D+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)')E=C$@(%!E<FEO9"!D96QI;6ET960@
M<F5V:7-I;VX@;G5M8F5R"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978R("!3
M96-O;F0@<&5R:6]D(&1E;&EM:71E9"!R979I<VEO;B!N=6UB97(*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#$@:68@=&AE(&9I<G-T(&ES(&=R
M96%T97(L("TQ(&EF('1H92!S96-O;F0@:68@9W)E871E<BP*("`@("`J("`@
M("`@("`@("`@("`@("`@86YD(#`@:68@=&AE>2!A<F4@97%U86P*("`@("`J
M+PH@("`@9G5N8W1I;VX@8VUP*"1R978Q+"`D<F5V,BD*("`@('L*("`@("`@
M("!R971U<FX@=F5R<VEO;E]C;VUP87)E*"1R978Q+"`D<F5V,BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QO9VEC86P@<F5V:7-I;VX@
M8F5F;W)E('1H:7,@;VYE+B!.;W)M86QL>2P@=&AI<PH@("`@("H@=VEL;"!B
M92!T:&4@<F5V:7-I;VX@;6EN=7,@;VYE+"!B=70@:6X@=&AE(&-A<V4@;V8@
M82!N97<*("`@("`J(&)R86YC:"P@=V4@<W1R:7`@;V9F('1H92!L87-T('1W
M;R!D96-I;6%L('!L86-E<R!T;R!R971U<FX@=&AE"B`@("`@*B!O<FEG:6YA
M;"!B<F%N8V@@<&]I;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<F5V("!2979I<VEO;B!N=6UB97(@=&\@9&5C<F5M96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG?&)O;VQE86X@(%)E=FES:6]N(&YU;6)E<BP@
M;W(@9F%L<V4@:68@;F]N92!C;W5L9"!B90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@9&5T97)M:6YE9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<')E=B@D<F5V*0H@("`@>PH@("`@("`@("1L87-T7V1O="`]('-T<G)P;W,H
M)')E=BP@)RXG*3L*("`@("`@("`D=F%L(#T@<W5B<W1R*"1R978L("LK)&QA
M<W1?9&]T*3L*"B`@("`@("`@:68@*"TM)'9A;"`^(#`I('L*("`@("`@("`@
M("`@<F5T=7)N('-U8G-T<B@D<F5V+"`P+"`D;&%S=%]D;W0I("X@)'9A;#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&%S=%]D;W0M+3L*("`@
M("`@("`@("`@=VAI;&4@*"TM)&QA<W1?9&]T*2!["B`@("`@("`@("`@("`@
M("!I9B`H)')E=ELD;&%S=%]D;W1=(#T]("<N)RD@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`@<W5B<W1R*"1R978L(#`L("1L87-T7V1O="D["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)')E=ELD;&%S=%]D;W1=(#T](&YU
M;&PI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!':79E;B!A(')E=FES:6]N(&YU;6)E<B!O9B!T:&4@
M9F]R;2!X+GDN,"YZ+"!T:&ES(')E;6%P<R!I=`H@("`@("H@:6YT;R!T:&4@
M87!P<F]P<FEA=&4@8G)A;F-H(&YU;6)E<BP@=VAI8V@@:7,@>"YY+GH*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978@($5V96XM9&EG:70@<F5V
M:7-I;VX@;G5M8F5R(&]F(&$@8G)A;F-H"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@($]D9"UD:6=I="!"<F%N8V@@;G5M8F5R"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1O0G)A;F-H*"1R978I"B`@("!["B`@("`@("`@+RH@0VAE
M8VL@:68@=V4@:&%V92!A('9A;&ED(')E=FES:6]N(&YU;6)E<B`J+PH@("`@
M("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@H)&5N
M9"`]('-T<G)P;W,H)')E=BP@)RXG*2D@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R979;)&5N
M9%T@/2`P.PH@("`@("`@(&EF("@H)&5N9#(@/2!S=')R<&]S*"1R978L("<N
M)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@<W5B<W1R*"1R
M978L("LK)&5N9"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<W5B<W1R
M7W)E<&QA8V4H)')E=BP@)RXG+"`D96YD,BP@*"1E;F0M)&5N9#(K,2DI.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U1E>'0N<&AP````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C<T-P`Q,#4Q-30S,3`V,0`P,3<V-C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!497AT.CH@8VQA<W,@<')O=FED97,@8V]M;6]N(&UE=&AO9',@9F]R(&UA
M;FEP=6QA=&EN9R!T97AT+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]497AT+G!H<"QV(#$N,BXQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z
M,C`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A
M<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT
M('L*"B`@("`O*BH*("`@("`J($-O;G9E<G0@82!L:6YE(&]F('1E>'0@=&\@
M9&ES<&QA>2!P<F]P97)L>2!I;B!(5$U,+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@(%1H92!S=')I;F<@;V8@=&5X="!T;R!C;VYV97)T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"UC;VUP
M;&EA;G0@8V]N=F5R=&5D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AT
M;6Q3<&%C97,H)'1E>'0@/2`G)RD*("`@('L*("`@("`@("!S=&%T:6,@)&-H
M87)S970["B`@("`@("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@("`@("!]
M"@H@("`@("`@("1T97AT(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'1E>'0L($5.
M5%]#3TU0050L("1C:&%R<V5T*3L*("`@("`@("`D=&5X="`]('-T<E]R97!L
M86-E*")<="(L("<F;F)S<#L@)FYB<W`[("9N8G-P.R`F;F)S<#L@)RP@)'1E
M>'0I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R`@)RP@)R9N8G-P
M.R`G+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("`G
M+"`G("9N8G-P.R<L("1T97AT*3L*"B`@("`@("`@<F5T=7)N("1T97AT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V%M92!A<R!H=&UL4W!A8V5S*"D@8G5T
M(&-O;G9E<G1S(&%L;"!S<&%C97,@=&\@)FYB<W`["B`@("`@*@H@("`@("H@
M0'-E92!H=&UL4W!A8V5S*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!4:&4@<W1R:6YG(&]F('1E>'0@=&\@8V]N=F5R="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434PM8V]M<&QI86YT(&-O
M;G9E<G1E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!H=&UL06QL4W!A
M8V5S*"1T97AT(#T@)R<I"B`@("!["B`@("`@("`@)'1E>'0@/2!497AT.CIH
M=&UL4W!A8V5S*"1T97AT*3L*("`@("`@("`D=&5X="`]('-T<E]R97!L86-E
M*"<@)RP@)R9N8G-P.R<L("1T97AT*3L*"B`@("`@("`@<F5T=7)N("1T97AT
M.PH@("`@?0H*?0H`````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4VAA<F4N<&AP````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<U,3`S`#$P-3$U-#,Q
M,#8Q`#`Q-S<W-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]$871A5')E92YP
M:'`G.PH*+RHJ"B`J($AO<F1E7U-H87)E.CH@<')O=FED97,@86X@:6YT97)F
M86-E('1O(&%L;"!S:&%R97,@82!U<V5R(&UI9VAT(&AA=F4N("!)=',*("H@
M;65T:&]D<R!T86ME(&-A<F4@;V8@86YY('-I=&4M<W!E8VEF:6,@<F5S=')I
M8W1I;VYS(&-O;F9I9W5R960@:6X@:6X@=&AE"B`J(&%P<&QI8V%T:6]N)W,@
M<')E9G,N<&AP(&%N9"!C;VYF+G!H<"!F:6QE<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO4VAA<F4O4VAA<F4N<&AP+'8@,2XQ,3$N,BXR,"`R,#`V+S`U
M+S`T(#$S.C(U.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($IO96P@5F%N9&%L(#QJ=F%N9&%L0&EN9F]T96-K+G%C+F-A/@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($EN9F]T96-K($EN=&5R;F5T(#QW96)M87-T
M97)`:6YF;W1E8VLN<6,N8V$^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C:RYQ
M8RYC83X*("H@0&%U=&AO<B`@36EK92!#;V-H<F%M92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]3:&%R90H@*B\*8VQA<W,@2&]R9&5?4VAA<F4@>PH*("`@("\J
M*@H@("`@("H@4&]I;G1E<B!T;R!A($1A=&%4<F5E(&EN<W1A;F-E('1O(&UA
M;F%G92]S=&]R92!S:&%R97,*("`@("`J"B`@("`@*B!`=F%R($1A=&%4<F5E
M"B`@("`@*B\*("`@('9A<B`D7V1A=&%T<F5E.PH*("`@("\J*@H@("`@("H@
M5&AE(&%P<&QI8V%T:6]N('=E)W)E(&UA;F%G:6YG('-H87)E<R!F;W(N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?87!P
M.PH*("`@("\J*@H@("`@("H@5&AE('-U8F-L87-S(&]F($1A=&%4<F5E3V)J
M96-T('1O(&EN<W1A;G1I871E('-H87)E<R!A<RX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S:&%R94]B:F5C="`]("=$
M871A5')E94]B:F5C=%]3:&%R92<["@H@("`@+RHJ"B`@("`@*B!!(&-A8VAE
M(&]F(&%L;"!S:&%R97,@=&AA="!H879E(&)E96X@<F5T<FEE=F5D+"!S;R!W
M92!D;VXG="!H:70@=&AE"B`@("`@*B!B86-K96YD(&%G86EN(&%N9"!A9V%I
M;B!F;W(@=&AE;2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7V-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-A
M8VAE('5S960@9F]R(&QI<W13:&%R97,H*2X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VQI<W1C86-H92`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!!(&QI<W0@;V8@;V)J96-T<R!T:&%T('=E)W)E
M(&-U<G)E;G1L>2!S;W)T:6YG+"!F;W(@<F5F97)E;F-E(&1U<FEN9R!T:&4*
M("`@("`J('-O<G1I;F<@86QG;W)I=&AM+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<V]R=$QI<W0["@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC
M<F5T92!(;W)D95]3:&%R92!I;G-T86YC92X@270*("`@("`J('=I;&P@;VYL
M>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?4VAA<F4@:6YS
M=&%N8V4@8W5R<F5N=&QY"B`@("`@*B!E>&ES=',N"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@("`\8V]D
M93XD=F%R(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)&%P<"D[/"]C;V1E
M/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI
M8V%T:6]N<R!T:&%T('1H92!S:&%R97,@<F5L871E<R!T;RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N($AO<F1E7U-H87)E("!4:&4@8V]N8W)E=&4@4VAA<F4@
M<F5F97)E;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)G-I;F=L971O;B@D87!P*0H@("`@>PH@("`@("`@('-T871I
M8R`D<VAA<F5S.PH*("`@("`@("!I9B`H(6ES<V5T*"1S:&%R97-;)&%P<%TI
M*2!["B`@("`@("`@("`@("1S:&%R97-;)&%P<%T@/2!N97<@2&]R9&5?4VAA
M<F4H)&%P<"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-H87)E<ULD
M87!P73L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T:6]N
M('1H870@=&AE('-H87)E<R!B96QO;F<@=&\N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($AO<F1E7U-H87)E*"1A<'`I"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF+"`D<F5G:7-T<GD["@H@("`@("`@(&EF("AE;7!T>2@D8V]N9ELG9&%T
M871R964G75LG9')I=F5R)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"@G66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U
M<V4@4VAA<F5S+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*
M("`@("`@("`D9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==
M.PH@("`@("`@("1T:&ES+3Y?87!P(#T@)&%P<#L*("`@("`@("`D=&AI<RT^
M7V1A=&%T<F5E(#T@)D1A=&%4<F5E.CIS:6YG;&5T;VXH"B`@("`@("`@("`@
M("1D<FEV97(L"B`@("`@("`@("`@(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$
M<FEV97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BDL(&%R<F%Y*"=G<F]U
M<"<@/3X@)VAO<F1E+G-H87)E<RXG("X@)&%P<"DI"B`@("`@("`@*3L*"B`@
M("`@("`@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:&%R95]I;FET
M)RP@87)R87DH)'1H:7,L("1A<'`I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE($1A=&%4<F5E(&EN<W1A;F-E('5S960@=&\@;6%N86=E
M('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E92`@
M5&AI<R!S:&%R92=S($1A=&%4<F5E(&EN<W1A;F-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9V5T1&%T851R964H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1A=&%T<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C="!C;W)R97-P;VYD:6YG
M('1O('1H92!G:79E;B!S:&%R90H@("`@("H@;F%M92P@=VET:"!T:&4@9&5T
M86EL<R!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@<VAA<F4@=&\@
M<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B:F5C
M=%]3:&%R92`@5&AE(')E<75E<W1E9"!S:&%R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F=E=%-H87)E*"1N86UE*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7V-A8VAE6R1N86UE72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8V%C:&5;)&YA;65=.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]C86-H95LD;F%M95T@/2`F)'1H:7,M/E]D871A=')E92T^9V5T3V)J
M96-T*"1N86UE+"`D=&AI<RT^7W-H87)E3V)J96-T*3L*("`@("`@("!I9B`H
M(6ES7V$H)'1H:7,M/E]C86-H95LD;F%M95TL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]C86-H95LD;F%M95TM/G-E=%-H87)E3V(H
M)'1H:7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%C
M:&5;)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A($1A
M=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C="!C;W)R97-P;VYD:6YG('1O('1H
M92!G:79E;B!U;FEQ=64*("`@("`J($E$+"!W:71H('1H92!D971A:6QS(')E
M=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-I9"`@5&AE(&ED(&]F('1H92!S:&%R92!T;R!R971R:65V92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-H87)E("!4
M:&4@<F5Q=65S=&5D('-H87)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T
M4VAA<F5">4ED*"1C:60I"B`@("!["B`@("`@("`@)'-H87)E(#T@)'1H:7,M
M/E]D871A=')E92T^9V5T3V)J96-T0GE)9"@D8VED+"`D=&AI<RT^7W-H87)E
M3V)J96-T*3L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("1S:&%R92T^<V5T4VAA<F5/8B@D=&AI<RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F($1A=&%4<F5E3V)J96-T
M7U-H87)E(&]B:F5C=',@8V]R<F5S<&]N9&EN9R!T;R!T:&4*("`@("`J(&=I
M=F5N('-E="!O9B!U;FEQ=64@241S+"!W:71H('1H92!D971A:6QS(')E=')I
M979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D8VED<R`@5&AE(&%R<F%Y(&]F(&ED<R!T;R!R971R:65V92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5Q=65S=&5D('-H87)E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%-H87)E<R@D8VED<RD*("`@('L*
M("`@("`@("`D<VAA<F5S(#T@)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T
M<R@D8VED<RP@)'1H:7,M/E]S:&%R94]B:F5C="D["B`@("`@("`@:68@*&ES
M7V$H)'-H87)E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'-H87)E<SL*("`@("`@("!]"@H@("`@("`@("1K97ES(#T@87)R87E?
M:V5Y<R@D<VAA<F5S*3L*("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y
M*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R97-;)&ME>5TL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<VAA<F5S6R1K
M97E=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-A8VAE
M6R1K97E=(#T@)B1S:&%R97-;)&ME>5T["B`@("`@("`@("`@("1S:&%R97-;
M)&ME>5TM/G-E=%-H87)E3V(H)'1H:7,I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1S:&%R97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@;F5W('-H87)E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@<VAA<F4G<R!N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@1&%T851R965/8FIE8W1?4VAA<F4@($$@;F5W('-H87)E(&]B:F5C
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=U-H87)E*"1N86UE*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U-H87)E(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y)RD["B`@("`@("`@?0H@("`@("`@("1S:&%R92`]("9N97<@)'1H
M:7,M/E]S:&%R94]B:F5C="@D;F%M92D["B`@("`@("`@)'-H87)E+3YS971$
M871A5')E92@D=&AI<RT^7V1A=&%T<F5E*3L*("`@("`@("`D<VAA<F4M/G-E
M=%-H87)E3V(H)'1H:7,I.PH@("`@("`@("1S:&%R92T^<V5T*"=O=VYE<B<L
M($%U=&@Z.F=E=$%U=&@H*2D["@H@("`@("`@(')E='5R;B`D<VAA<F4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<VAA<F4@=&\@=&AE('-H87)E
M<R!S>7-T96TN(%1H92!S:&%R92!M=7-T(&9I<G-T(&)E(&-R96%T960@=VET
M:`H@("`@("H@2&]R9&5?4VAA<F4Z.FYE=U-H87)E*"DL(&%N9"!H879E(&%N
M>2!I;FET:6%L(&1E=&%I;',@861D960@=&\@:70L"B`@("`@*B!B969O<F4@
M=&AI<R!F=6YC=&EO;B!I<R!C86QL960N"B`@("`@*@H@("`@("H@0'!A<F%M
M($1A=&%4<F5E3V)J96-T7U-H87)E("1S:&%R92`@5&AE(&YE=R!S:&%R92!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R
M;W(@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D4VAA<F4H)'-H87)E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M<VAA<F4L("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=3:&%R97,@;75S="!B92!$871A
M5')E94]B:F5C=%]3:&%R92!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S
M+B<I.PH@("`@("`@('T*"B`@("`@("`@)'!E<FT@/2`F)$=,3T)!3%-;)W!E
M<FUS)UTM/FYE=U!E<FUI<W-I;VXH)'-H87)E+3YG971.86UE*"DI.PH@("`@
M("`@(&EF("AI<U]A*"1P97)M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<&5R;3L*("`@("`@("!]"@H@("`@("`@("\J($=I=F4@
M=&AE(&]W;F5R(&9U;&P@86-C97-S("HO"B`@("`@("`@)'!E<FTM/F%D9%5S
M97)097)M:7-S:6]N*"1S:&%R92T^9V5T*"=O=VYE<B<I+"!015)-4U]32$]7
M+"!F86QS92D["B`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1S
M:&%R92T^9V5T*"=O=VYE<B<I+"!015)-4U]214%$+"!F86QS92D["B`@("`@
M("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1S:&%R92T^9V5T*"=O=VYE
M<B<I+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@)'!E<FTM/F%D9%5S
M97)097)M:7-S:6]N*"1S:&%R92T^9V5T*"=O=VYE<B<I+"!015)-4U]$14Q%
M5$4L(&9A;'-E*3L*"B`@("`@("`@)'-H87)E+3YS971097)M:7-S:6]N*"1P
M97)M+"!F86QS92D["@H@("`@("`@("1R97-U;'0@/2!(;W)D93HZ8V%L;$AO
M;VLH)U]H;W)D95]H;V]K7W-H87)E7V%D9"<L(&%R<F%Y*"1S:&%R92DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4G+"!F86QS
M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)'-H87)E*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!S:&%R92!F<F]M('1H92!S
M:&%R97,@<WES=&5M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J($!P87)A
M;2!$871A5')E94]B:F5C=%]3:&%R92`D<VAA<F4@(%1H92!S:&%R92!T;R!R
M96UO=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R
M;W(@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E4VAA<F4H)'-H87)E*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M82@D<VAA<F4L("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=3:&%R97,@;75S="!B92!$
M871A5')E94]B:F5C=%]3:&%R92!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L
M87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]($AO<F1E.CIC
M86QL2&]O:R@G7VAO<F1E7VAO;VM?<VAA<F5?<F5M;W9E)RP@87)R87DH)'-H
M87)E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D
M92<L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/G)E;6]V92@D
M<VAA<F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O('-E92!I
M9B!A('-H87)E(&AA<R!A;GD@8VAI;&0@<VAA<F5S+@H@("`@("H*("`@("`J
M($!P87)A;2!$871A5')E94]B:F5C=%]3:&%R92`D<VAA<F4@(%1H92!S:&%R
M92!T;R!C:&5C:R!F;W(@8VAI;&1R96XN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I960@<VAA<F4@:&%S(&-H
M:6QD('-H87)E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S0VAI;&1R96XH
M)'-H87)E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D<VAA<F4L("=$871A
M5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=3:&%R97,@;75S="!B92!$871A5')E94]B:F5C=%]3
M:&%R92!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("AB;V]L*21T:&ES+3Y?9&%T871R964M/F=E
M=$YU;6)E<D]F0VAI;&1R96XH)'-H87)E*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!S:&%R92=S(&1I<F5C="!P87)E;G0@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-H87)E("!'970@=&AE('!A
M<F5N="!O9B!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!R971U<FX@1&%T
M851R965/8FIE8W1?4VAA<F4@(%1H92!P87)E;G0@<VAA<F4L(&EF(&ET(&5X
M:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!A<F5N="@D8VAI;&0I
M"B`@("!["B`@("`@("`@)&ED(#T@)'1H:7,M/E]D871A=')E92T^9V5T4&%R
M96YT*"1C:&EL9"D["B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(21I9"!\?"`H)&ED(#T]($1!5$%44D5%7U)/3U0I*2!["B`@
M("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U!A<F5N="!D
M;V5S(&YO="!E>&ES="XG*3L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T4VAA<F5">4ED
M*"1I9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!)1"!O
M9B!A('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E94]B:F5C
M=%]3:&%R92`@5&AE('-H87)E('1O(')E='5R;B!T:&4@240@;V8N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<VAA<F4G<R!)1"!O<B!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-H87)E260H)'-H87)E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1A=&%T<F5E+3YG971)9"@D<VAA<F4M/F=E=$YA;64H*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!5=&EL:71Y(&9U;F-T:6]N('1O(&)E('5S960@=VET
M:"!U87-O<G0H*2!F;W(@<V]R=&EN9R!A<G)A>7,@;V8*("`@("`J($AO<F1E
M7U-H87)E(&]B:F5C=',N"B`@("`@*B!%>&%M<&QE.CQC;V1E/@H@("`@("H@
M=6%S;W)T*"1L:7-T+"!A<G)A>2@G2&]R9&5?4VAA<F4G+"`G7W-O<G13:&%R
M97,G*2D["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S;W)T4VAA<F5S*"1A+"`D
M8BD*("`@('L*("`@("`@("`D85!A<G1S(#T@97AP;&]D92@G.B<L("1A+3YG
M971.86UE*"DI.PH@("`@("`@("1B4&%R=',@/2!E>'!L;V1E*"<Z)RP@)&(M
M/F=E=$YA;64H*2D["@H@("`@("`@("1M:6X@/2!M:6XH8V]U;G0H)&%087)T
M<RDL(&-O=6YT*"1B4&%R=',I*3L*("`@("`@("`D:61!(#T@)R<["B`@("`@
M("`@)&ED0B`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1M:6X[
M("1I*RLI('L*("`@("`@("`@("`@:68@*"1I9$$I('L*("`@("`@("`@("`@
M("`@("1I9$$@+CT@)SHG.PH@("`@("`@("`@("`@("`@)&ED0B`N/2`G.B<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&ED02`N/2`D85!A<G1S6R1I
M73L*("`@("`@("`@("`@)&ED0B`N/2`D8E!A<G1S6R1I73L*"B`@("`@("`@
M("`@(&EF("@D:61!("$]("1I9$(I('L*("`@("`@("`@("`@("`@("1C=7)!
M(#T@:7-S970H)'1H:7,M/E]S;W)T3&ES=%LD:61!72D@/R`D=&AI<RT^7W-O
M<G1,:7-T6R1I9$%=+3YG970H)VYA;64G*2`Z("<G.PH@("`@("`@("`@("`@
M("`@)&-U<D(@/2!I<W-E="@D=&AI<RT^7W-O<G1,:7-T6R1I9$)=*2`_("1T
M:&ES+3Y?<V]R=$QI<W1;)&ED0ETM/F=E="@G;F%M92<I(#H@)R<["B`@("`@
M("`@("`@("`@("!R971U<FX@<W1R;F%T8V%S96-M<"@D8W5R02P@)&-U<D(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@8V]U
M;G0H)&%087)T<RD@/B!C;W5N="@D8E!A<G1S*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-H96-K<R!I9B!A('-H87)E(&5X:7-T<R!I;B!T:&4@<WES=&5M
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-H87)E("!4:&4@<VAA
M<F4@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!S:&%R92!E>&ES=',L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1S:&%R92D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D871A=')E92T^97AI<W1S*"1S:&%R92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N="!O9B!A;&P@
M<VAA<F5S('1H870@)'5S97)I9"!H87,@86-C97-S('1O+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1U<V5R:60@("`@("!4:&4@=7-E<FED(&]F
M('1H92!U<V5R('1O(&-H96-K(&%C8V5S<R!F;W(N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<&5R;2`@("`@("`@5&AE(&QE=F5L(&]F('!E<FUI<W-I;VYS
M(')E<75I<F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&%T=')I8G5T97,@
M(%)E<W1R:6-T('1H92!S:&%R97,@8V]U;G1E9"!T;R!T:&]S90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&UA=&-H:6YG("1A='1R:6)U
M=&5S+B!!;B!A<G)A>2!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%T=')I8G5T92]V86QU97,@<&%I<G,@;W(@82!S:&%R92!O=VYE
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5S97)N86UE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@(%1H92!P87)E
M;G0@<VAA<F4@=&\@<W1A<G0@<V5A<F-H:6YG(&%T+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%L;$QE=F5L<R`@(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J
M=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V
M96QS+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@3G5M8F5R(&]F
M('-H87)E<R!T:&4@=7-E<B!H87,@86-C97-S('1O+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;W5N=%-H87)E<R@D=7-E<FED+"`D<&5R;2`](%!%4DU37U-(
M3U<L("1A='1R:6)U=&5S(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)E;G0@/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS(#T@=')U
M92D*("`@('L*("`@("`@("`D:V5Y(#T@<V5R:6%L:7IE*&%R<F%Y*"1T:&ES
M+3Y?87!P+"`D=7-E<FED+"`D<&5R;2P@)&%T=')I8G5T97,L("1P87)E;G0L
M("1A;&Q,979E;',L("=C;W5N="<I*3L*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]L:7-T8V%C:&5;)&ME>5TI*2!["B`@("`@("`@("`@("1C<FET97)I
M82`]("1T:&ES+3YG9713:&%R94-R:71E<FEA*"1U<V5R:60L("1P97)M+"`D
M871T<FEB=71E<RD["B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&-A8VAE6R1K
M97E=(#T@)'1H:7,M/E]D871A=')E92T^8V]U;G1">4%T=')I8G5T97,H)&-R
M:71E<FEA+"`D<&%R96YT+"`D86QL3&5V96QS+"`G:60G*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VQI<W1C86-H95LD:V5Y73L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@86QL('-H
M87)E<R!T:&%T("1U<V5R:60@:&%S(&%C8V5S<R!T;RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D=7-E<FED("`@("`@(%1H92!U<V5R:60@;V8@
M=&AE('5S97(@=&\@8VAE8VL@86-C97-S(&9O<BX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1P97)M("`@("`@("`@5&AE(&QE=F5L(&]F('!E<FUI<W-I;VYS
M(')E<75I<F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&%T=')I8G5T97,@
M("!297-T<FEC="!T:&4@<VAA<F5S(&-O=6YT960@=&\@=&AO<V4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;6%T8VAI;F<@)&%T=')I
M8G5T97,N($%N(&%R<F%Y(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%T=')I8G5T92]V86QU97,@<&%I<G,@;W(@82!S:&%R92!O
M=VYE<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U<V5R
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("`@5&AE
M('!A<F5N="!S:&%R92!T;R!S=&%R="!S96%R8VAI;F<@870N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@(%)E='5R;B!A;&P@;&5V96QS
M+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@
M86QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QE=F5L
M<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1F<F]M("`@("`@("`@5&AE('-H
M87)E('1O('-T87)T(&QI<W1I;F<@870N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8V]U;G0@("`@("`@(%1H92!N=6UB97(@;V8@<VAA<F5S('1O(')E='5R
M;BX*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?;F%M92`@071T<FEB
M=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@
M<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@("`@
M4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE('-H87)E<R!T:&4@=7-E<B!H87,@86-C97-S
M('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B`F;&ES=%-H87)E<R@D=7-E<FED
M+"`D<&5R;2`](%!%4DU37U-(3U<L("1A='1R:6)U=&5S(#T@;G5L;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0@/2!$051!5%)%15]23T]4
M+"`D86QL3&5V96QS(#T@=')U92P@)&9R;VT@/2`P+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O=6YT(#T@,"P@)'-O<G1B>5]N86UE(#T@;G5L;"P@
M)'-O<G1B>5]K97D@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@)&ME>2`]('-E<FEA;&EZ
M92AA<G)A>2@D=&AI<RT^7V%P<"P@)'5S97)I9"P@)'!E<FTL("1A='1R:6)U
M=&5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F5N="P@
M)&%L;$QE=F5L<RP@)&9R;VTL("1C;W5N="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S;W)T8GE?;F%M92P@)'-O<G1B>5]K97DL("1D:7)E
M8W1I;VXI*3L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]L:7-T8V%C:&5;
M)&ME>5TI*2!["B`@("`@("`@("`@("1C<FET97)I82`]("1T:&ES+3YG9713
M:&%R94-R:71E<FEA*"1U<V5R:60L("1P97)M+"`D871T<FEB=71E<RD["B`@
M("`@("`@("`@("1S:&%R96QI<W0@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971"
M>4%T=')I8G5T97,H"B`@("`@("`@("`@("`@("`D8W)I=&5R:6$L("1P87)E
M;G0L("1A;&Q,979E;',L("=I9"<L("1F<F]M+"`D8V]U;G0L"B`@("`@("`@
M("`@("`@("`D<V]R=&)Y7VYA;64L("1S;W)T8GE?:V5Y+"`D9&ER96-T:6]N
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-H87)E;&ES="P@)U!%05)?17)R
M;W(G*2!\?"`A8V]U;G0H)'-H87)E;&ES="DI('L*("`@("`@("`@("`@("`@
M("\J($EF('=E(&=O="!B86-K(&%N(&5R<F]R(&]R(&%N(&5M<'1Y(&%R<F%Y
M+"!P87-S(&ET(&)A8VL@=&\*("`@("`@("`@("`@("`@("`J('1H92!C86QL
M97(N("HO"B`@("`@("`@("`@("`@("!R971U<FX@)'-H87)E;&ES=#L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@36%K92!S=7)E(&=E=%-H87)E
M<R@I(&1I9&XG="!R971U<FX@86X@97)R;W(N("HO"B`@("`@("`@("`@("1S
M:&%R97,@/2`F)'1H:7,M/F=E=%-H87)E<RAA<G)A>5]K97ES*"1S:&%R96QI
M<W0I*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-H87)E<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S:&%R97,["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&-A8VAE6R1K97E=
M(#T@)B1S:&%R97,["B`@("`@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0@/2`D
M=&AI<RT^7VQI<W1C86-H95LD:V5Y73L*("`@("`@("`@("`@=6%S;W)T*"1T
M:&ES+3Y?;&ES=&-A8VAE6R1K97E=+"!A<G)A>2@D=&AI<RP@)U]S;W)T4VAA
M<F5S)RDI.PH@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T(#T@;G5L;#L*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!(;W)D93HZ8V%L;$AO;VLH
M)U]H;W)D95]H;V]K7W-H87)E7VQI<W0G+"!A<G)A>2@D=7-E<FED+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FTL("1A='1R:6)U
M=&5S+"`D=&AI<RT^7VQI<W1C86-H95LD:V5Y72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:&]R9&4G+"!F86QS92D["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7VQI<W1C86-H95LD:V5Y73L*("`@('T*"B`@("`O*BH*("`@("`J
M($QI<W1S("IA;&PJ('-H87)E<R!F;W(@=&AE(&-U<G)E;G0@87!P+W-H87)E
M+"!R96=A<F1L97-S(&]F"B`@("`@*B!P97)M:7-S:6]N<RX@5&AI<R!I<R!F
M;W(@861M:6X@9G5N8W1I;VYA;&ET>2!A;F0@<V-R:7!T:6YG('1O;VQS+"!A
M;F0*("`@("`J('-H;W5L9&XG="!B92!C86QL960@9G)O;2!U<V5R+6QE=F5L
M(&-O9&4A"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!A<F5N="`@
M4W1A<G0@=&AE(&QI<W1I;F<@870@82!C97)T86EN('!O:6YT(&EN('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=')E92X@1&5F875L=',@
M=&\@1$%40512145?4D]/5"P@=&AE(')O;W0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@06QL('-H87)E<R!F;W(@=&AE(&-U<G)E;G0@87!P+W-H
M87)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T06QL4VAA<F5S*"1P87)E
M;G0@/2!$051!5%)%15]23T]4*0H@("`@>PH@("`@("`@("1S:&%R96QI<W0@
M/2`D=&AI<RT^7V1A=&%T<F5E+3YG970H1$%40512145?1D]234%47T9,050L
M("1P87)E;G0L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1S:&%R96QI<W0L
M("=014%27T5R<F]R)RD@?'P@(6-O=6YT*"1S:&%R96QI<W0I*2!["B`@("`@
M("`@("`@("\O($EF('=E(&=O="!B86-K(&%N(&5R<F]R(&]R(&%N(&5M<'1Y
M(&%R<F%Y+"!J=7-T(')E='5R;B!I="X*("`@("`@("`@("`@<F5T=7)N("1S
M:&%R96QI<W0["B`@("`@("`@?0H@("`@("`@('5N<V5T*"1S:&%R96QI<W1;
M)'!A<F5N=%TI.PH*("`@("`@("`D<VAA<F5S(#T@)B1T:&ES+3YG9713:&%R
M97,H87)R87E?:V5Y<R@D<VAA<F5L:7-T*2D["B`@("`@("`@:68@*&ES7V$H
M)'-H87)E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'-H87)E<SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0@
M/2`D<VAA<F5S.PH@("`@("`@('5A<V]R="@D<VAA<F5S+"!A<G)A>2@D=&AI
M<RP@)U]S;W)T4VAA<F5S)RDI.PH@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0@
M/2!N=6QL.PH*("`@("`@("!R971U<FX@)'-H87)E<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@8W)I=&5R:6$@9F]R('%U
M97)Y:6YG('-H87)E<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M=7-E<FED("`@("`@5&AE('5S97)I9"!O9B!T:&4@=7-E<B!T;R!C:&5C:R!A
M8V-E<W,@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FT@("`@("`@
M(%1H92!L979E;"!O9B!P97)M:7-S:6]N<R!R97%U:7)E9"X*("`@("`J($!P
M87)A;2!M:7AE9"`@("1A='1R:6)U=&5S("!297-T<FEC="!T:&4@<VAA<F5S
M(')E='5R;F5D('1O('1H;W-E('=H;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&AA=F4@=&AE<V4@871T<FEB=71E('9A;'5E<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8W)I=&5R:6$@=')E92!F
M;W(@9F5T8VAI;F<@=&AI<R!U<V5R)W,@<VAA<F5S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9713:&%R94-R:71E<FEA*"1U<V5R:60L("1P97)M(#T@4$52
M35-?4TA/5RP@)&%T=')I8G5T97,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@A96UP='DH)'5S97)I9"DI('L*("`@("`@("`@("`@)&-R:71E<FEA(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`G3U(G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("\O("AO=VYE<B`]/2`D=7-E<FED*0H@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G04Y$
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("=O
M=VYE<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I
M96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("1U<V5R
M:60I*2DL"@H@("`@("`@("`@("`@("`@("`@("\O("AN86UE(#T]('!E<FU?
M=7-E<G,@86YD(&ME>2`]/2`D=7-E<FED(&%N9"!V86P@)B`D<&5R;2D*("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T
M)R`]/B`G<&5R;5]U<V5R<R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)V9I96QD)R`]/B`G:V5Y)RP@)V]P)R`]/B`G/2<L("=T97-T
M)R`]/B`D=7-E<FED*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]/B`G)B<L("=T97-T)R`]
M/B`D<&5R;2DI*2P*"B`@("`@("`@("`@("`@("`@("`@+R\@*&YA;64@/3T@
M<&5R;5]C<F5A=&]R(&%N9"!V86P@)B`D<&5R;2D*("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)T%.1"<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE
M;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`G<&5R;5]C
M<F5A=&]R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)R8G+"`G=&5S="<@/3X@)'!E
M<FTI*2DL"@H@("`@("`@("`@("`@("`@("`@("\O("AN86UE(#T]('!E<FU?
M9&5F875L="!A;F0@=F%L("8@)'!E<FTI"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]
M/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?9&5F875L
M="<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD
M)R`]/B`G=F%L=64G+"`G;W`G(#T^("<F)RP@)W1E<W0G(#T^("1P97)M*2DI
M*2D["@H@("`@("`@("`@("`O+R!)9B!T:&4@=7-E<B!H87,@86YY(&=R;W5P
M(&UE;6)E<G-H:7!S+"!C:&5C:R!F;W(@=&AO<V4@86QS;RX*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@("`@("`@
M("`D9W)O=7`@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D
M9W)O=7!S(#T@)&=R;W5P+3YG971'<F]U<$UE;6)E<G-H:7!S*"1U<V5R:60L
M('1R=64I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)&=R;W5P<RP@)U!%05)?
M17)R;W(G*2`F)B!C;W5N="@D9W)O=7!S*2D@>PH@("`@("`@("`@("`@("`@
M+R\@*&YA;64@/3T@<&5R;5]G<F]U<',@86YD(&ME>2!I;B`H)&=R;W5P<RD@
M86YD('9A;"`F("1P97)M*0H@("`@("`@("`@("`@("`@)&-R:71E<FEA6R=/
M4B==6UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G04Y$)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]
M/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?9W)O=7!S
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@
M)VME>2<L("=O<"<@/3X@)TE.)RP@)W1E<W0G(#T^(&%R<F%Y7VME>7,H)&=R
M;W5P<RDI+`H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G
M(#T^("=V86QU92<L("=O<"<@/3X@)R8G+"`G=&5S="<@/3X@)'!E<FTI*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8W)I=&5R:6$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N
M86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`G<&5R;5]G=65S="<I+`H@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=V86QU92<L
M("=O<"<@/3X@)R8G+"`G=&5S="<@/3X@)'!E<FTI*2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T97,I*2!["B`@("`@("`@
M("`@("\O($)U:6QD(&%T=')I8G5T92]K97D@9FEL=&5R+@H@("`@("`@("`@
M("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@)&-R:71E<FEA(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("1C<FET97)I82P*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G2D])3B<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T%.1"<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("1K
M97DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@
M)'9A;'5E*2DI*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@
M*"%E;7!T>2@D871T<FEB=71E<RDI('L*("`@("`@("`@("`@+R\@4F5S=')I
M8W0@=&\@<VAA<F5S(&]W;F5D(&)Y('1H92!U<V5R('-P96-I9FEE9"!I;B!T
M:&4*("`@("`@("`@("`@+R\@)&%T=')I8G5T97,@<W1R:6YG+@H@("`@("`@
M("`@("`D8W)I=&5R:6$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=!3D0G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("1C<FET97)I82P*("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)TI/24XG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S
M="<@/3X@)V]W;F5R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)STG+"`G=&5S="<@
M/3X@)&%T=')I8G5T97,I*2DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D8W)I=&5R:6$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@
M*@H@("`@("H@0'-E92!097)M<SHZ9V5T4&5R;6ES<VEO;G,*("`@("`J"B`@
M("`@*B!`<&%R86T@5$]$3PH@("`@("H@0'!A<F%M(%1/1$\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&5R
M;6ES<VEO;G,H)'-H87)E+"`D=7-E<B`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"%I<U]A*"1S:&%R92P@)T1A=&%4<F5E3V)J96-T7U-H87)E)RDI('L*
M("`@("`@("`@("`@)'-H87)E(#T@)B1T:&ES+3YG9713:&%R92@D<VAA<F4I
M.PH@("`@("`@('T*"B`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M
M:7-S:6]N*"D["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=P97)M<R==+3YG
M971097)M:7-S:6]N<R@D<&5R;2P@)'5S97(I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@261E;G1I='D@9F]R(&$@<&%R=&EC=6QA<B!S
M:&%R92!O=VYE<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'-H87)E
M("!4:&4@<VAA<F4@=&\@9F5T8V@@=&AE($ED96YT:71Y(&9O<B`M(&5I=&AE
M<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!N86UE
M+"!O<B!T:&4@1&%T851R965/8FIE8W1?4VAA<F4@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<')E9F5R96YC92=S('9A;'5E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T261E;G1I='E">5-H87)E*"1S
M:&%R92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E+"`G1&%T851R
M965/8FIE8W1?4VAA<F4G*2D@>PH@("`@("`@("`@("`D<VAA<F4@/2`D=&AI
M<RT^9V5T4VAA<F4H)'-H87)E*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-H
M87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("1O=VYE<B`]
M("1S:&%R92T^9V5T*"=O=VYE<B<I.PH@("`@("`@(')E='5R;B`D<F5T(#T@
M)DED96YT:71Y.CIS:6YG;&5T;VXH)VYO;F4G+"`D;W=N97(I.PH@("`@?0H*
M?0H*+RHJ"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R965/8FIE8W0@8VQA
M<W,@9F]R('-T;W)I;F<@4VAA<F4@:6YF;W)M871I;VX@:6X@=&AE"B`J($1A
M=&%4<F5E(&1R:79E<BX@268@>6]U('=A;G0@=&\@<W1O<F4@<W!E8VEA;&EZ
M960@4VAA<F4@:6YF;W)M871I;VXL('EO=0H@*B!S:&]U;&0@97AT96YD('1H
M:7,@8VQA<W,@:6YS=&5A9"!O9B!E>'1E;F1I;F<@1&%T851R965/8FIE8W0@
M9&ER96-T;'DN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]3:&%R90H@*B\*8VQA<W,@1&%T851R965/8FIE8W1?
M4VAA<F4@97AT96YD<R!$871A5')E94]B:F5C="!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@2&]R9&5?4VAA<F4@;V)J96-T('=H:6-H('1H:7,@<VAA<F4@8V%M
M92!F<F]M("T@;F5E9&5D(&9O<@H@("`@("H@=7!D871I;F<@9&%T82!I;B!T
M:&4@8F%C:V5N9"!T;R!M86ME(&-H86YG97,@<W1I8VLL(&5T8RX*("`@("`J
M"B`@("`@*B!`=F%R($AO<F1E7U-H87)E"B`@("`@*B\*("`@('9A<B`D7W-H
M87)E3V(["@H@("`@+RHJ"B`@("`@*B!4:&4@1&%T851R965/8FIE8W1?4VAA
M<F4@8V]N<W1R=6-T;W(N($IU<W0@;6%K97,@<W5R92!T;R!C86QL('1H92!P
M87)E;G0*("`@("`J(&-O;G-T<G5C=&]R('-O('1H870@=&AE('-H87)E)W,@
M;F%M92!I<R!S970@<')O<&5R;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:60@(%1H92!I9"!O9B!T:&4@<VAA<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($1A=&%4<F5E3V)J96-T7U-H87)E*"1I9"D*("`@('L*("`@("`@
M("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T*"1I9"D["B`@("`@("`@:68@*&ES
M7VYU;&PH)'1H:7,M/F1A=&$I*2!["B`@("`@("`@("`@("1T:&ES+3YD871A
M(#T@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M<W-O8VEA=&5S(&$@4VAA<F4@;V)J96-T('=I=&@@=&AI<R!S:&%R92X*("`@
M("`J"B`@("`@*B!`<&%R86T@2&]R9&5?4VAA<F4@)'-H87)E3V(@(%1H92!3
M:&%R92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-H87)E3V(H
M)B1S:&%R94]B*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VAA<F5/8B`]("8D
M<VAA<F5/8CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AI<R!S
M:&%R92=S('!A<F5N="!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!$
M871A5')E94]B:F5C=%]3:&%R92`@5&AE('!A<F5N="!S:&%R92P@:68@:70@
M97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4&%R96YT*"D*("`@
M('L*("`@("`@("`D<&%R96YT(#T@)'1H:7,M/E]S:&%R94]B+3YG971087)E
M;G0H)'1H:7,I.PH@("`@("`@(')E='5R;B`D<&%R96YT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1VEV97,@82!U<V5R(&$@8V5R=&%I;B!P<FEV:6QE9V4@
M9F]R('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7-E<FED("`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S97(N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@02!015)-4U\J(&-O;G-T86YT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R4&5R;6ES<VEO;B@D=7-E
M<FED+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@("`D<&5R;2`]("8D=&AI
M<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@("1P97)M+3YA9&15<V5R4&5R
M;6ES<VEO;B@D=7-E<FED+"`D<&5R;6ES<VEO;BP@9F%L<V4I.PH@("`@("`@
M("1T:&ES+3YS971097)M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V97,@82!C97)T86EN('!R:79I;&5G92!F;W(@82!U<V5R
M(&9R;VT@=&AI<R!S:&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R:60@("`@("`@5&AE('5S97)I9"!O9B!T:&4@=7-E<BX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!!(%!%4DU37RH@8V]N<W1A
M;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97)097)M:7-S:6]N
M*"1U<V5R:60L("1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("1P97)M(#T@
M)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FTM/G)E;6]V
M955S97)097)M:7-S:6]N*"1U<V5R:60L("1P97)M:7-S:6]N+"!F86QS92D[
M"B`@("`@("`@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1VEV97,@82!G<F]U<"!C97)T86EN('!R:79I;&5G
M97,@9F]R('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9W)O=7`@("`@("`@(%1H92!G<F]U<"!T;R!A9&0@<&5R;6ES<VEO;G,@
M9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FUI<W-I;VX@($$@4$52
M35-?*B!C;VYS=&%N="X*("`@("`J+PH@("`@9G5N8W1I;VX@861D1W)O=7!0
M97)M:7-S:6]N*"1G<F]U<"P@)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@
M)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("`D<&5R
M;2T^861D1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@)'!E<FUI<W-I;VXL(&9A
M;'-E*3L*("`@("`@("`D=&AI<RT^<V5T4&5R;6ES<VEO;B@D<&5R;2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@8V5R=&%I;B!P<FEV:6QE
M9V4@9G)O;2!A(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&=R;W5P("`@("`@("`@5&AE(&=R;W5P('1O(')E;6]V92!P97)M:7-S:6]N
M<R!F<F]M+@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S:6]N("!!
M(%!%4DU37RH@8V]N<W1A;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L("1P97)M:7-S:6]N*0H@("`@>PH@
M("`@("`@("1P97)M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@
M("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L("1P97)M
M:7-S:6]N+"!F86QS92D["B`@("`@("`@)'1H:7,M/G-E=%!E<FUI<W-I;VXH
M)'!E<FTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O('-E92!I
M9B!A('5S97(@:&%S(&$@9VEV96X@<&5R;6ES<VEO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R:60@("`@("`@5&AE('5S97)I9"!O9B!T
M:&4@=7-E<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!!
M(%!%4DU37RH@8V]N<W1A;G0@=&\@=&5S="!F;W(N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C<F5A=&]R("`@("`@5&AE(&-R96%T;W(@;V8@=&AE(&5V96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@)'5S97)I9"!H87,@)'!E<FUI<W-I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AA<U!E<FUI<W-I;VXH)'5S97)I9"P@)'!E<FUI<W-I;VXL("1C<F5A
M=&]R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)'5S97)I9"`]/2`D=&AI
M<RT^9V5T*"=O=VYE<B<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=P97)M<R==+3YH
M87-097)M:7-S:6]N*"1T:&ES+3YG971097)M:7-S:6]N*"DL("1U<V5R:60L
M("1P97)M:7-S:6]N+"`D8W)E871O<BD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F5S(&$@=7-E<B!F<F]M('1H:7,@<VAA<F4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<FED("!4:&4@=7-E<FED(&]F('1H92!U
M<V5R('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E57-E
M<B@D=7-E<FED*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!A;&P@)'5S97)I
M9"=S('!E<FUI<W-I;VYS+B`J+PH@("`@("`@("1P97)M(#T@)B1T:&ES+3YG
M971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FTM/G)E;6]V955S97)097)M
M:7-S:6]N*"1U<V5R:60L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`D
M<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97)I9"P@4$5235-?4D5!
M1"P@9F%L<V4I.PH@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO
M;B@D=7-E<FED+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@)'!E<FTM
M/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R:60L(%!%4DU37T1%3$5412P@
M9F%L<V4I.PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T4&5R;6ES<VEO;B@D
M<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@9W)O=7`@
M9G)O;2!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1G<F]U<$ED("!4:&4@9W)O=7`@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96UO=F5'<F]U<"@D9W)O=7!)9"D*("`@('L*("`@("`@("`O
M*B!296UO=F4@86QL("1G<F]U<$ED)W,@<&5R;6ES<VEO;G,N("HO"B`@("`@
M("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("`D
M<&5R;2T^<F5M;W9E1W)O=7!097)M:7-S:6]N*"1G<F]U<$ED+"!015)-4U]3
M2$]7+"!F86QS92D["B`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES
M<VEO;B@D9W)O=7!)9"P@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("1P
M97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P260L(%!%4DU37T5$
M250L(&9A;'-E*3L*("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!097)M:7-S
M:6]N*"1G<F]U<$ED+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("!R
M971U<FX@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG(&%L;"!T
M:&4@=7-E<FED<R!O9B!T:&4@=7-E<G,@=VET:"!A8V-E<W,@=&\*("`@("`J
M('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E
M<FU?;&5V96P@($QI<W0@;VYL>2!U<V5R<R!W:71H('1H:7,@<&5R;6ES<VEO
M;B!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M969A=6QT<R!T;R!A;&P@=7-E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE('5S97)S('=I=&@@86-C97-S('1O('1H:7,@<VAA<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@D<&5R;5]L979E;"`](&YU
M;&PI"B`@("!["B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I
M;VXH*3L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D<&5R;2T^9V5T57-E
M<E!E<FUI<W-I;VYS*"1P97)M7VQE=F5L*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&%N(&%R<F%Y(&-O;G1A:6YI;F<@86QL('1H92!G<F]U
M<&ED<R!O9B!T:&4@9W)O=7!S('=I=&@@86-C97-S"B`@("`@*B!T;R!T:&ES
M('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M7VQE
M=F5L("!,:7-T(&]N;'D@=7-E<G,@=VET:"!T:&ES('!E<FUI<W-I;VX@;&5V
M96PN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L
M=',@=&\@86QL('5S97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!)1',@;V8@=&AE(&=R;W5P<R!W:71H(&%C8V5S<R!T;R!T:&ES('-H
M87)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1W)O=7!S*"1P97)M7VQE
M=F5L(#T@;G5L;"D*("`@('L*("`@("`@("`D<&5R;2`]("8D=&AI<RT^9V5T
M4&5R;6ES<VEO;B@I.PH@("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1P97)M
M+3YG971'<F]U<%!E<FUI<W-I;VYS*"1P97)M7VQE=F5L*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'!A<F%M(%1/1$\*
M("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@(%1/1$\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4&5R
M;6ES<VEO;B@F)'!E<FTL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@
M("1T:&ES+3YD871A6R=P97)M)UT@/2`D<&5R;2T^9V5T1&%T82@I.PH@("`@
M("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<V%V92@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`<F5T=7)N(%1/
M1$\*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!E<FUI<W-I;VXH*0H@("`@
M>PH@("`@("`@("1P97)M(#T@)FYE=R!$871A5')E94]B:F5C=%]097)M:7-S
M:6]N*"1T:&ES+3YG971.86UE*"DI.PH@("`@("`@("1P97)M+3YD871A(#T@
M:7-S970H)'1H:7,M/F1A=&%;)W!E<FTG72D@/R`D=&AI<RT^9&%T85LG<&5R
M;2==(#H@87)R87DH*3L*"B`@("`@("`@<F5T=7)N("1P97)M.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1F]R8V5S(&%L;"!C:&EL9')E;B!O9B!T:&ES('-H
M87)E('1O(&EN:&5R:70@=&AE('!E<FUI<W-I;VYS('-E="!O;B!T:&ES"B`@
M("`@*B!S:&%R92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1/1$\*("`@("`J
M+PH@("`@9G5N8W1I;VX@:6YH97)I=%!E<FUI<W-I;VYS*"D*("`@('L*("`@
M("`@("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@
M("1C:&EL9')E;B`]("1T:&ES+3Y?<VAA<F5/8BT^;&ES=$%L;%-H87)E<R@D
M=&AI<RT^9V5T3F%M92@I*3L*("`@("`@("!I9B`H:7-?82@D8VAI;&1R96XL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C:&EL9')E
M;CL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C:&EL9')E;B!A<R`D
M8VAI;&0I('L*("`@("`@("`@("`@)&-H:6QD+3YS971097)M:7-S:6]N*"1P
M97)M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V%V97,@86YY(&-H86YG97,@=&\@=&AI<R!O8FIE
M8W0@=&\@=&AE(&)A8VME;F0@<&5R;6%N96YT;'DN($YE=R!O8FIE8W1S"B`@
M("`@*B!A<F4@861D960@:6YS=&5A9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@?"!014%27T5R<F]R("!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H*0H@("`@>PH@("`@("`@("1R
M97-U;'0@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-H87)E7VUO
M9&EF>2<L(&%R<F%Y*"1T:&ES*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H;W)D92<L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ<V%V
M92@I.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P<R!T:&ES(&]B:F5C="=S
M(&%T=')I8G5T97,@9G)O;2!T:&4@9&%T82!A<G)A>2!I;G1O(&$@9F]R;6%T
M('1H870@=V4*("`@("`J(&-A;B!S=&]R92!I;B!T:&4@871T<FEB=71E<R!S
M=&]R86=E(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<&5R;7-O;FQY("!/
M;FQY('!R;V-E<W,@<&5R;6ES<VEO;G,_($QE=',@<W5B8VQA<W-E<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W9E<G)I9&4@<&%R="!O
M9B!T:&ES(&UE=&AO9"!W:&EL92!H86YD;&EN9PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE:7(@861D:71I;VYA;"!A='1R:6)U=&5S
M('-E<&5R871E;'DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&%T=')I8G5T97,@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T;T%T
M=')I8G5T97,H)'!E<FUS;VYL>2`](&9A;'-E*0H@("`@>PH@("`@("`@("\O
M($1E9F%U;'0@=&\@;F\@871T<FEB=71E<RX*("`@("`@("`D871T<FEB=71E
M<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD871A(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=P
M97)M)RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1T
M>7!E(#T^("1P97)M<RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&5R;7,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P97)M<R!A<R`D;65M8F5R(#T^("1P97)M*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D871T<FEB=71E<UM=(#T@87)R87DH)VYA;64G
M(#T^("=P97)M7R<@+B`D='EP92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:V5Y)R`]/B`D;65M8F5R+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QU92<@/3X@)'!E<FTI.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%T=')I8G5T97-;72`](&%R<F%Y*"=N86UE)R`]/B`G
M<&5R;5\G("X@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:V5Y)R`]/B`G)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'!E
M<FUS*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS96EF("@A)'!E<FUS;VYL>2D@>PH@("`@("`@
M("`@("`@("`@)&%T=')I8G5T97-;72`](&%R<F%Y*"=N86UE)R`]/B`D:V5Y
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97DG
M(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=V86QU92<@/3X@)'9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5&%K97,@:6X@82!L:7-T(&]F(&%T=')I8G5T97,@9G)O;2!T:&4@
M8F%C:V5N9"!A;F0@;6%P<R!I="!T;R!O=7(*("`@("`J(&EN=&5R;F%L(&1A
M=&$@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@("!4:&4@;&ES
M="!O9B!A='1R:6)U=&5S(&9R;VT@=&AE(&)A8VME;F0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("AA='1R:6)U=&4@;F%M92P@:V5Y+"!A
M;F0@=F%L=64I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!E<FUS;VYL>2`@
M3VYL>2!P<F]C97-S('!E<FUI<W-I;VYS/R!,971S('-U8F-L87-S97,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]V97)R:61E('!A<G0@
M;V8@=&AI<R!M971H;V0@=VAI;&4@:&%N9&QI;F<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H96ER(&%D9&ET:6]N86P@871T<FEB=71E
M<R!S97!E<F%T96QY+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9G)O;4%T=')I
M8G5T97,H)&%T=')I8G5T97,L("1P97)M<V]N;'D@/2!F86QS92D*("`@('L*
M("`@("`@("`O+R!);FET:6%L:7IE(&1A=&$@87)R87DN"B`@("`@("`@)'1H
M:7,M/F1A=&%;)W!E<FTG72`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@
M*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@(&EF("AS=6)S
M='(H)&%T=');)VYA;64G72P@,"P@-"D@/3T@)W!E<FTG*2!["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1A='1R6R=K97DG72DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9&%T85LG<&5R;2==6W-U8G-T<B@D871T<ELG
M;F%M92==+"`U*5U;)&%T=');)VME>2==72`]("1A='1R6R=V86QU92==.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^9&%T85LG<&5R;2==6W-U8G-T<B@D871T<ELG;F%M92==+"`U*5T@
M/2`D871T<ELG=F%L=64G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E:68@*"$D<&5R;7-O;FQY*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^9&%T85LD871T<ELG;F%M92==72`]("1A='1R6R=V86QU92==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12YP:'``````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8W,38V`#$P-3$U-#,Q,#8Q`#`Q-S0W
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RH@5V4@;F5E9"!T;R`H=6YF;W)T=6YA=&5L>2D@:&%R9"!C;V1E
M('1H97-E(&-O;G-T86YT<R!B96-A=7-E('1H97D@<F5S:61E(&EN"B`J('1H
M92!I;6%P(&UO9'5L92P@=VAI8V@@:7,@;F]T(')E<75I<F5D(&9O<B!(;W)D
M92X*("H@5&AE<V4@8V]N<W1A;G1S(&%R92!F;W5N9"!I;B!T:&4@55<M:6UA
M<"!C+6-L:65N="!D:7-T<FEB=71I;VXZ"B`J("`@9G1P.B\O9G1P+F-A8RYW
M87-H:6YG=&]N+F5D=2]I;6%P+PH@*B!4:&4@8V]N<W1A;G1S(&%P<&5A<B!I
M;B!T:&4@9FEL92!I;F-L=61E+VUA:6PN:"`J+PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U5T:6PN<&AP)SL*:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VEM
M87`G*2D@>PH@("`@+RH@4')I;6%R>2!B;V1Y('1Y<&5S("HO"B`@("!D969I
M;F4H)U194$5415A4)RP@,"D["B`@("!D969I;F4H)U194$5-54Q425!!4E0G
M+"`Q*3L*("`@(&1E9FEN92@G5%E014U%4U-!1T4G+"`R*3L*("`@(&1E9FEN
M92@G5%E014%04$Q)0T%424].)RP@,RD["B`@("!D969I;F4H)U194$5!541)
M3R<L(#0I.PH@("`@9&5F:6YE*"=465!%24U!1T4G+"`U*3L*("`@(&1E9FEN
M92@G5%E0159)1$5/)RP@-BD["B`@("!D969I;F4H)U194$5/5$A%4B<L(#@I
M.PH*("`@("\J($)O9'D@96YC;V1I;F=S("HO"B`@("!D969I;F4H)T5.0S="
M250G+"`P*3L*("`@(&1E9FEN92@G14Y#.$))5"<L(#$I.PH@("`@9&5F:6YE
M*"=%3D-"24Y!4EDG+"`R*3L*("`@(&1E9FEN92@G14Y#0D%3138T)RP@,RD[
M"B`@("!D969I;F4H)T5.0U%53U1%1%!224Y404),12<L(#0I.PH@("`@9&5F
M:6YE*"=%3D-/5$A%4B<L(#4I.PI]"@HO*BH*("H@3VQD97(@=F5R<VEO;G,@
M;V8@4$A0)W,@:6UA<"!E>'1E;G-I;VX@9&]N)W0@9&5F:6YE(%194$5-3T1%
M3"X*("HO"FEF("@A9&5F:6YE9"@G5%E014U/1$5,)RDI('L*("`@(&1E9FEN
M92@G5%E014U/1$5,)RP@-RD["GT*"B\J*@H@*B!2971U<FX@82!C;V1E(&9O
M<B!T>7!E*"DO96YC;V1I;F<H*2X*("HO"F1E9FEN92@G34E-15]#3T1%)RP@
M,2D["@HO*BH*("H@4F5T=7)N(&$@<W1R:6YG(&9O<B!T>7!E*"DO96YC;V1I
M;F<H*2X*("HO"F1E9FEN92@G34E-15]35%))3D<G+"`R*3L*"@HO*BH*("H@
M5&AE($U)344Z.B!C;&%S<R!P<F]V:61E<R!M971H;V1S(&9O<B!D96%L:6YG
M('=I=&@@34E-12!S=&%N9&%R9',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TU)344O34E-12YP:'`L=B`Q+C$S.2XT+C(P(#(P,#8O,#,O,C0@,#0Z,CDZ
M-3(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-
M10H@*B\*8VQA<W,@34E-12!["@H@("`@+RHJ"B`@("`@*B!!(&QI<W1I;F<@
M;V8@=&AE(&%L;&]W960@34E-12!T>7!E<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;6EM95]T>7!E<R`](&%R<F%Y*`H@
M("`@("`@(%194$5415A4(#T^("=T97AT)RP*("`@("`@("!465!%355,5$E0
M05)4(#T^("=M=6QT:7!A<G0G+`H@("`@("`@(%194$5-15-304=%(#T^("=M
M97-S86=E)RP*("`@("`@("!465!%05!03$E#051)3TX@/3X@)V%P<&QI8V%T
M:6]N)RP*("`@("`@("!465!%055$24\@/3X@)V%U9&EO)RP*("`@("`@("!4
M65!%24U!1T4@/3X@)VEM86=E)RP*("`@("`@("!465!%5DE$14\@/3X@)W9I
M9&5O)RP*("`@("`@("!465!%34]$14P@/3X@)VUO9&5L)RP*("`@("`@("!4
M65!%3U1(15(@/3X@)V]T:&5R)PH@("`@*3L*"B`@("`O*BH*("`@("`J($$@
M;&ES=&EN9R!O9B!T:&4@86QL;W=E9"!-24U%(&5N8V]D:6YG<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;6EM95]E;F-O
M9&EN9W,@/2!A<G)A>2@*("`@("`@("!%3D,W0DE4(#T^("<W8FET)RP*("`@
M("`@("!%3D,X0DE4(#T^("<X8FET)RP*("`@("`@("!%3D-"24Y!4ED@/3X@
M)V)I;F%R>2<L"B`@("`@("`@14Y#0D%3138T(#T^("=B87-E-C0G+`H@("`@
M("`@($5.0U%53U1%1%!224Y404),12`]/B`G<75O=&5D+7!R:6YT86)L92<L
M"B`@("`@("`@14Y#3U1(15(@/3X@)W5N:VYO=VXG"B`@("`I.PH*("`@("\J
M*@H@("`@("H@1FEL=&5R(&9O<B!21D,X,C(N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1R9F,X,C)?9FEL=&5R(#T@(B@I
M/#Y`+#LZ7%Q<(EM=7#%<,EPS7#1<-5PV7#=<,3!<,3%<,3)<,3-<,31<,35<
M,39<,3=<,C!<,C%<,C)<,C-<,C1<,C5<,C9<,C=<,S!<,S%<,S)<,S-<,S1<
M,S5<,S9<,S=<,3<W(CL*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@
M82!S=')I;F<@8V]N=&%I;G,@."UB:70@8VAA<F%C=&5R<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@(%1H92!S=')I;F<@=&\@8VAE
M8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&ET
M(&1O97,L(&9A;'-E(&EF(&ET(&1O97-N)W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES.&)I="@D<W1R:6YG*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-?
M<W1R:6YG*"1S=')I;F<I("8F('!R96=?;6%T8V@H)R];7'@X,"U<>&9F72\G
M+"`D<W1R:6YG*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O9&5S(&$@
M<W1R:6YG(&-O;G1A:6YI;F<@;F]N+4%30TE)(&-H87)A8W1E<G,@86-C;W)D
M:6YG('1O(%)&0R`R,#0W+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("`@(%1H92!T97AT('1O(&5N8V]D92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T(&]F('1H92!T97AT
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X="P@96YC
M;V1E9"!O;FQY(&EF(&ET(&-O;G1A:6YS(&YO;BU!4T-)20H@("`@("H@("`@
M("`@("`@("`@("`@(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5N8V]D92@D=&5X="P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\J(%)E='5R;B!I9B!N;W1H:6YG(&YE961S('1O(&)E(&5N8V]D960N("HO
M"B`@("`@("`@:68@*"%-24U%.CII<SAB:70H)'1E>'0I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N
M=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ
M9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@)&-H87)S970@/2!3
M=')I;F<Z.FQO=V5R*"1C:&%R<V5T*3L*("`@("`@("`D;&EN92`]("<G.PH*
M("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@96QE;65N=',@:6X@=&AE('-T
M<FEN9RX@*B\*("`@("`@("`D<VEZ92`]('!R96=?;6%T8VA?86QL*"<O*%M>
M7'-=*RDH6UQS72HI+R<L("1T97AT+"`D;6%T8VAE<RP@4%)%1U]3151?3U)$
M15(I.PH*("`@("`@("!F;W)E86-H("@D;6%T8VAE<R!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@:68@*$U)344Z.FES.&)I="@D=F%L6S%=*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"@H)&ME>2`K(#$I(#P@)'-I>F4I("8F
M"B`@("`@("`@("`@("`@("`@("`@34E-13HZ:7,X8FET*"1M871C:&5S6R1K
M97D@*R`Q75LQ72DI('L*("`@("`@("`@("`@("`@("`@("`D;&EN92`N/2!-
M24U%.CI?96YC;V1E*"1V86Q;,5T@+B`D=F%L6S)=+"`D8VAA<G-E="D@+B`G
M("<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1L:6YE("X]($U)344Z.E]E;F-O9&4H)'9A;%LQ72P@)&-H87)S970I
M("X@)'9A;%LR73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1L:6YE("X]("1V86Q;,5T@+B`D=F%L
M6S)=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M<G1R:6TH)&QI;F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@26YT97)N86P@
M<F5C=7)S:79E(&9U;F-T:6]N('1O(%)&0R`R,#0W(&5N8V]D92!A('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("`@("!4:&4@=&5X="!T;R!E;F-O9&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<F%C=&5R
M('-E="!O9B!T:&4@=&5X="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('1E>'0L(&5N8V]D960@;VYL>2!I9B!I="!C;VYT86EN<R!N;VXM
M05-#24D*("`@("`J("`@("`@("`@("`@("`@("!C:&%R86-T97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?96YC;V1E*"1T97AT+"`D8VAA<G-E="D*("`@
M('L*("`@("`@("`D8VAA<E]L96X@/2!S=')L96XH)&-H87)S970I.PH@("`@
M("`@("1T>'1?;&5N(#T@<W1R;&5N*"1T97AT*2`J(#(["@H@("`@("`@("\J
M(%)&0R`R,#0W(%LR72!S=&%T97,@=&AA="!N;R!E;F-O9&5D('=O<F0@8V%N
M(&)E(&UO<F4@=&AA;B`W-0H@("`@("`@("`@(&-H87)A8W1E<G,@;&]N9RX@
M268@;&]N9V5R+"!Y;W4@;75S="!S<&QI="!T:&4@=V]R9"X@*B\*("`@("`@
M("!I9B`H*"1T>'1?;&5N("L@)&-H87)?;&5N("L@-RD@/B`W-2D@>PH@("`@
M("`@("`@("`D<&]S(#T@:6YT=F%L*"@V."`M("1C:&%R7VQE;BD@+R`R*3L*
M("`@("`@("`@("`@<F5T=7)N($U)344Z.E]E;F-O9&4H<W5B<W1R*"1T97AT
M+"`P+"`D<&]S*2P@)&-H87)S970I("X@)R`G("X@34E-13HZ7V5N8V]D92AS
M=6)S='(H)'1E>'0L("1P;W,I+"`D8VAA<G-E="D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("<]/R<@+B`D8VAA<G-E="`N("<_8C\G
M("X@=')I;2AB87-E-C1?96YC;V1E*"1T97AT*2D@+B`G/STG.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($5N8V]D97,@82!L:6YE('9I82!Q
M=6]T960M<')I;G1A8FQE(&5N8V]D:6YG+@H@("`@("H@5W)A<',@;&EN97,@
M870@-S8@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!4:&4@=&5X="!T;R!E;F-O9&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1E;VP@("!4:&4@14],('-E<75E;F-E('1O('5S92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('%U;W1E9"UP<FEN=&%B;&4@96YC
M;V1E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E9%!R:6YT
M86)L945N8V]D92@D=&5X="P@)&5O;"D*("`@('L*("`@("`@("`D;W5T<'5T
M(#T@)R<["@H@("`@("`@(&9O<F5A8V@@*'!R96=?<W!L:70H(B]<<C]<;B\B
M+"`D=&5X="D@87,@)&QI;F4I('L*("`@("`@("`@("`@+RH@5V4@;F5E9"!T
M;R!G;R!C:&%R86-T97(@8GD@8VAA<F%C=&5R('1H<F]U9V@@=&AE(&QI;F4N
M("HO"B`@("`@("`@("`@("1L96YG=&@@/2!S=')L96XH)&QI;F4I.PH@("`@
M("`@("`@("`D8W5R<F5N=%]L:6YE(#T@)R<["B`@("`@("`@("`@("1C=7)R
M96YT7VQE;F=T:"`](#`["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D;&5N9W1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D8VAA<B`]('-U
M8G-T<B@D;&EN92P@)&DL(#$I.PH@("`@("`@("`@("`@("`@)&%S8VEI(#T@
M;W)D*"1C:&%R*3L*"B`@("`@("`@("`@("`@("`O*B!3<&%C97,@;W(@=&%B
M<R!A="!T:&4@96YD(&]F('1H92!L:6YE(&%R92!.3U0@86QL;W=E9"X*("`@
M("`@("`@("`@("`@("`J($%L<V\L($-H87)A8W1E<G,@:6X@05-#24D@8F5L
M;W<@,S(@;W(@86)O=F4@,3(V($%.1"`V,0H@("`@("`@("`@("`@("`@("H@
M;75S="!B92!E;F-O9&5D+B`J+PH@("`@("`@("`@("`@("`@:68@*"@H*"1A
M<V-I:2`]/3T@.2D@?'P@*"1A<V-I:2`]/3T@,S(I*2`F)B`H)&D@/3T@*"1L
M96YG=&@@+2`Q*2DI('Q\"B`@("`@("`@("`@("`@("`@("`@*"@D87-C:6D@
M/"`S,BD@?'P@*"1A<V-I:2`^(#$R-BD@?'P@*"1A<V-I:2`]/3T@-C$I*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1C:&%R(#T@)STG("X@4W1R:6YG.CIU
M<'!E<BAS<')I;G1F*"<E,#)S)RP@9&5C:&5X*"1A<V-I:2DI*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!,:6YE<R!M=7-T(&)E
M(#<V(&-H87)A8W1E<G,@;W(@;&5S<RX@*B\*("`@("`@("`@("`@("`@("1C
M:&%R7VQE;F=T:"`]('-T<FQE;B@D8VAA<BD["B`@("`@("`@("`@("`@("`D
M8W5R<F5N=%]L96YG=&@@*ST@)&-H87)?;&5N9W1H.PH@("`@("`@("`@("`@
M("`@:68@*"1C=7)R96YT7VQE;F=T:"`^(#<V*2!["B`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2`D8W5R<F5N=%]L:6YE("X@)STG("X@)&5O;#L*
M("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]L:6YE(#T@)R<["B`@("`@
M("`@("`@("`@("`@("`@)&-U<G)E;G1?;&5N9W1H(#T@)&-H87)?;&5N9W1H
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-U<G)E;G1?
M;&EN92`N/2`D8VAA<CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T
M<'5T("X]("1C=7)R96YT7VQI;F4@+B`D96]L.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O
M9&5S(&$@<W1R:6YG(&-O;G1A:6YI;F<@96UA:6P@861D<F5S<V5S(&%C8V]R
M9&EN9R!T;R!21D,@,C`T-RX*("`@("`J"B`@("`@*B!4:&ES(&1I9F9E<G,@
M9G)O;2!-24U%.CIE;F-O9&4H*2!B96-A=7-E(&ET(&ME97!S(&5M86EL(&%D
M9')E<W-E<R!L96=A;"P*("`@("`J(&]N;'D@96YC;V1I;F<@=&AE('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%D9')E<W-E<R`@5&AE(&5M86EL(&%D9')E<W-E<R!T;R!E;F-O9&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("`@(%1H92!C:&%R86-T97(@
M<V5T(&]F('1H92!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5F<V5R
M=F5R("!4:&4@9&5F875L="!D;VUA:6X@=&\@87!P96YD('1O(&UA:6QB;WAE
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0L(&5N
M8V]D960@;VYL>2!I9B!I="!C;VYT86EN<R!N;VXM87-C:6D*("`@("`J("`@
M("`@("`@("`@("`@("!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E;F-O9&5!9&1R97-S*"1A9&1R97-S97,L("1C:&%R<V5T(#T@;G5L;"P@
M)&1E9G-E<G9E<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1A9&1R97-S97,I*2!["B`@("`@("`@("`@("1A9&1R7V%R<B`]("1A9&1R
M97-S97,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@<&%R<V5!
M9&1R97-S3&ES="@I(&1O97,@;F]T('!R;V-E<W,@=&AE(&YU;&P@96YT<GD*
M("`@("`@("`@("`@("H@)W5N9&ES8VQO<V5D+7)E8VEP:65N=',Z.R<@8V]R
M<F5C=&QY+B`J+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+W5N9&ES
M8VQO<V5D+7)E8VEP:65N=',Z7',J.R]I)RP@=')I;2@D861D<F5S<V5S*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D861D<F5S<V5S.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#.#(R
M+G!H<"<["B`@("`@("`@("`@("1P87)S97(@/2`F;F5W($UA:6Q?4D9#.#(R
M*"D["B`@("`@("`@("`@("1A9&1R7V%R<B`]("1P87)S97(M/G!A<G-E061D
M<F5S<TQI<W0H)&%D9')E<W-E<RP@)&1E9G-E<G9E<BP@=')U92P@9F%L<V4I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D861D<E]A<G(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D861D<E]A<G(["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T97AT(#T@)R<["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1A9&1R7V%R<BDI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)&%D9')?87)R(&%S("1A9&1R*2!["B`@("`@("`@("`@("`@("`O
M+R!#:&5C:R!F;W(@9W)O=7!S+@H@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D861D<BT^9W)O=7!N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M97AT("X]($U)344Z.F5N8V]D92@D861D<BT^9W)O=7!N86UE+"`D8VAA<G-E
M="D@+B`G.B`G("X@34E-13HZ96YC;V1E061D<F5S<R@D861D<BT^861D<F5S
M<V5S*2`N("<[)SL*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&%D
M9'(M/G!E<G-O;F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("1P97)S;VYA
M;"`]("<G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H*'-U8G-T<B@D861D<BT^<&5R<V]N86PL(#`L(#$I(#T]
M("<B)RD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@*'-U8G-T<B@D861D
M<BT^<&5R<V]N86PL("TQ*2`]/2`G(B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1A9&1R+3YP97)S;VYA;"`]('-U8G-T<B@D861D<BT^<&5R<V]N
M86PL(#$L("TQ*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)'!E<G-O;F%L(#T@34E-13HZ96YC;V1E*"1A9&1R+3YP97)S
M;VYA;"P@)&-H87)S970I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*'-T<FQE;B@D=&5X="D@(3T@,"D@>PH@("`@("`@("`@("`@
M("`@("`@("1T97AT("X]("<L("<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D=&5X="`N/2!-24U%.CIT<FEM16UA:6Q!9&1R97-S*$U)
M344Z.G)F8S@R,E=R:71E061D<F5S<R@D861D<BT^;6%I;&)O>"P@)&%D9'(M
M/FAO<W0L("1P97)S;VYA;"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96-O9&5S(&%N(%)&0R`R,#0W+65N8V]D960@<W1R:6YG+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@("`@(%1H92!T97AT('1O(&1E
M8V]D92X*("`@("`J($!P87)A;2!S=')I;F<@)'1O7V-H87)S970@(%1H92!C
M:&%R<V5T('1H870@=&AE('1E>'0@<VAO=6QD(&)E(&1E8V]D960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9&5C;V1E9"!T97AT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!D96-O9&4H)'-T<FEN9RP@)'1O7V-H87)S970@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D<W1R:6YG+"`G
M/3\G*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D<W1R:6YG
M.PH@("`@("`@('T*"B`@("`@("`@+RH@5&%K92!O=70@86YY('-P86-E<R!B
M971W965N(&UU;'1I<&QE(&5N8V]D960@=V]R9',N("HO"B`@("`@("`@)'-T
M<FEN9R`]('!R96=?<F5P;&%C92@G?%P_/5QS/5P_?"<L("<_/3T_)RP@)'-T
M<FEN9RD["@H@("`@("`@("\J(%-A=F4@86YY('!R96-E9&EN9R!T97AT+B`J
M+PH@("`@("`@("1P<F5C961I;F<@/2!S=6)S='(H)'-T<FEN9RP@,"P@)'!O
M<RD["@H@("`@("`@("1S96%R8V@@/2!S=6)S='(H)'-T<FEN9RP@)'!O<R`K
M(#(I.PH@("`@("`@("1D,2`]('-T<G!O<R@D<V5A<F-H+"`G/R<I.PH@("`@
M("`@(&EF("@D9#$@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D
M<W1R:6YG.PH@("`@("`@('T*"B`@("`@("`@)&-H87)S970@/2!S=6)S='(H
M)'-T<FEN9RP@)'!O<R`K(#(L("1D,2D["B`@("`@("`@)'-E87)C:"`]('-U
M8G-T<B@D<V5A<F-H+"`D9#$@*R`Q*3L*"B`@("`@("`@)&0R(#T@<W1R<&]S
M*"1S96%R8V@L("<_)RD["B`@("`@("`@:68@*"1D,B`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("`@("`@?0H*("`@("`@
M("`D96YC;V1I;F<@/2!S=6)S='(H)'-E87)C:"P@,"P@)&0R*3L*("`@("`@
M("`D<V5A<F-H(#T@<W5B<W1R*"1S96%R8V@L("1D,B`K(#$I.PH*("`@("`@
M("`D96YD(#T@<W1R<&]S*"1S96%R8V@L("<_/2<I.PH@("`@("`@(&EF("@D
M96YD(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D96YD(#T@<W1R;&5N*"1S
M96%R8V@I.PH@("`@("`@('T*"B`@("`@("`@)&5N8V]D961?=&5X="`]('-U
M8G-T<B@D<V5A<F-H+"`P+"`D96YD*3L*("`@("`@("`D<F5S="`]('-U8G-T
M<B@D<W1R:6YG+"`H<W1R;&5N*"1P<F5C961I;F<@+B`D8VAA<G-E="`N("1E
M;F-O9&EN9R`N("1E;F-O9&5D7W1E>'0I("L@-BDI.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1T;U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`D=&]?8VAA<G-E
M="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@<W=I
M=&-H("@D96YC;V1I;F<I('L*("`@("`@("!C87-E("=1)SH*("`@("`@("!C
M87-E("=Q)SH*("`@("`@("`@("`@)&5N8V]D961?=&5X="`]('-T<E]R97!L
M86-E*"=?)RP@)R`G+"`D96YC;V1E9%]T97AT*3L*("`@("`@("`@("`@)&1E
M8V]D960@/2!P<F5G7W)E<&QA8V4H)R\]*%LP+3EA+69=>S)]*2]I92<L("=C
M:'(H,'A<,2DG+"`D96YC;V1E9%]T97AT*3L*("`@("`@("`@("`@)&1E8V]D
M960@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D96-O9&5D+"`D8VAA<G-E
M="P@)'1O7V-H87)S970I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G0B<Z"B`@("`@("`@8V%S92`G8B<Z"B`@("`@("`@("`@("1D96-O
M9&5D(#T@8F%S938T7V1E8V]D92@D96YC;V1E9%]T97AT*3L*("`@("`@("`@
M("`@)&1E8V]D960@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D96-O9&5D
M+"`D8VAA<G-E="P@)'1O7V-H87)S970I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)&1E8V]D960@/2`G/3\G
M("X@)&-H87)S970@+B`G/R<@+B`D96YC;V1I;F<@+B`G/R<@+B`D96YC;V1E
M9%]T97AT("X@)S\])SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'!R96-E9&EN9R`N("1D96-O9&5D("X@34E-13HZ
M9&5C;V1E*"1R97-T+"`D=&]?8VAA<G-E="D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96-O9&5S(&%N(%)&0R`R,C,Q+65N8V]D960@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@(%1H92!E;G1I<F4@
M<W1R:6YG('1O(&1E8V]D92P@:6YC;'5D:6YG('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@<&%R86UE=&5R(&YA;64N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T:&%T('1H92!T97AT
M('-H;W5L9"!B92!D96-O9&5D('1O+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!D96-O9&5D('1E>'0L(&]R('1H92!O<FEG:6YA;"!S=')I
M;F<@:68@:70@=V%S(&YO=`H@("`@("H@("`@("`@("`@("`@("`@96YC;V1E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E4D9#,C(S,2@D<W1R:6YG
M+"`D=&]?8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"@D<&]S
M(#T@<W1R<&]S*"1S=')I;F<L("<J)RDI(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES
M<V5T*"1T;U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`D=&]?8VAA<G-E="`]
M($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@)&%T=')I
M8G5T92`]('-U8G-T<B@D<W1R:6YG+"`P+"`D<&]S*3L*("`@("`@("`D8VAA
M<G-E="`]("1L86YG(#T@;G5L;#L*("`@("`@("`D;W5T<'5T(#T@)R<["@H@
M("`@("`@("\J($=E="!T:&4@8VAA<F%C=&5R('-E="!A;F0@;&%N9W5A9V4@
M=7-E9"!I;B!T:&4@96YC;V1I;F<L(&EF"B`@("`@("`@("H@86YY+B`J+PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7EM>/5TK7"I</2A;7B==*BDG*%M>
M)UTJ*2<O(BP@)'-T<FEN9RP@)&UA=&-H97,I*2!["B`@("`@("`@("`@("1C
M:&%R<V5T(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("1L86YG(#T@)&UA
M=&-H97-;,ET["B`@("`@("`@("`@("1S=')I;F<@/2!S=')?<F5P;&%C92@D
M8VAA<G-E="`N("(G(B`N("1L86YG("X@(B<B+"`G)RP@)'-T<FEN9RD["B`@
M("`@("`@?0H*("`@("`@("`D;&EN97,@/2!P<F5G7W-P;&ET*"<O)R`N('!R
M96=?<75O=&4H)&%T=')I8G5T92D@+B`G*#\Z7"I<9"DJ+R<L("1S=')I;F<I
M.PH@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@
M("`@("`D<&]S(#T@<W1R<&]S*"1L:6YE+"`G*CTG*3L*("`@("`@("`@("`@
M:68@*"1P;W,@/3T](#`I('L*("`@("`@("`@("`@("`@("1L:6YE(#T@<W5B
M<W1R*"1L:6YE+"`R*3L*("`@("`@("`@("`@("`@("1L:6YE(#T@<W1R7W)E
M<&QA8V4H)U\G+"`G)3(P)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@)&QI
M;F4@/2!S=')?<F5P;&%C92@G/2<L("<E)RP@)&QI;F4I.PH@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2!U<FQD96-O9&4H)&QI;F4I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2!S=6)S='(H)&QI
M;F4L(#$I.PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4D9#(#(R,S$@=7-E
M<R!Q=6]T960@<')I;G1A8FQE(&5N8V]D:6YG+B`J+PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@)&]U='!U="`](%-T
M<FEN9SHZ8V]N=F5R=$-H87)S970H)&]U='!U="P@)&-H87)S970L("1T;U]C
M:&%R<V5T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@*("`@
M("`@("`@("`@)V%T=')I8G5T92<@/3X@)&%T=')I8G5T92P*("`@("`@("`@
M("`@)W9A;'5E)R`]/B`D;W5T<'5T"B`@("`@("`@*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($EF(&%N(&5M86EL(&%D9')E<W,@:&%S(&YO('!E<G-O;F%L
M(&EN9F]R;6%T:6]N+"!G970@<FED(&]F(&%N>2!A;F=L90H@("`@("H@8G)A
M8VME=',@*#P^*2!A<F]U;F0@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D861D<F5S<R`@5&AE(&%D9')E<W,@=&\@=')I;2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1R:6UM960@861D<F5S<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@=')I;45M86EL061D<F5S<R@D861D<F5S<RD*
M("`@('L*("`@("`@("`D861D<F5S<R`]('1R:6TH)&%D9')E<W,I.PH*("`@
M("`@("!I9B`H*'-U8G-T<B@D861D<F5S<RP@,"P@,2D@/3T@)SPG*2`F)B`H
M<W5B<W1R*"1A9&1R97-S+"`M,2D@/3T@)SXG*2D@>PH@("`@("`@("`@("`D
M861D<F5S<R`]('-U8G-T<B@D861D<F5S<RP@,2P@+3$I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1A9&1R97-S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0G5I;&1S(&%N(%)&0R`X,C(@8V]M<&QI86YT(&5M86EL(&%D9')E<W,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@($UA:6QB
M;W@@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&AO<W0@("`@("!$;VUA
M:6X@;F%M92!O9B!M86EL8F]X)W,@:&]S="X*("`@("`J($!P87)A;2!S=')I
M;F<@)'!E<G-O;F%L("!097)S;VYA;"!N86UE('!H<F%S92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O<G)E8W1L>2!E<V-A<&5D(&%N
M9"!Q=6]T960*("`@("`J("`@("`@("`@("`@("`@("`B)'!E<G-O;F%L(#PD
M;6%I;&)O>$`D:&]S=#XB('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F9C.#(R5W)I=&5!9&1R97-S*"1M86EL8F]X+"`D:&]S="`](&YU;&PL("1P
M97)S;VYA;"`]("<G*0H@("`@>PH@("`@("`@("1A9&1R97-S(#T@)R<["@H@
M("`@("`@(&EF("@A96UP='DH)'!E<G-O;F%L*2D@>PH@("`@("`@("`@("`D
M=F%R<R`](&=E=%]C;&%S<U]V87)S*"=-24U%)RD["B`@("`@("`@("`@("1A
M9&1R97-S("X]($U)344Z.E]R9F,X,C)%;F-O9&4H)'!E<G-O;F%L+"`D=F%R
M<ULG<F9C.#(R7V9I;'1E<B==("X@)RXG*3L*("`@("`@("`@("`@)&%D9')E
M<W,@+CT@)R`\)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D
M:&]S="DI('L*("`@("`@("`@("`@)&%D9')E<W,@+CT@34E-13HZ7W)F8S@R
M,D5N8V]D92@D;6%I;&)O>"D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&AO
M<W0L(#`L(#$I("$]("=`)RD@>PH@("`@("`@("`@("`@("`@)&%D9')E<W,@
M+CT@)T`G("X@)&AO<W0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)'!E<G-O;F%L*2D@>PH@("`@("`@("`@("`D861D
M<F5S<R`N/2`G/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%D9')E
M<W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!L;V1E<R!A(%)&0R`X,C(@
M<W1R:6YG+"!I9VYO<FEN9R!A(&1E;&EM:71E<B!I9B!P<F5C961E9"!B>2!A
M(")<(@H@("`@("H@8VAA<F%C=&5R+"!O<B!I9B!D96QI;6ET97(@:7,@:6YS
M:61E('-I;F=L92!O<B!D;W5B;&4@<75O=&5S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'-T<B`@("`@("`@5&AE(%)&0R`X,C(@<W1R:6YG+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&5L:6UI=&5R("!4:&4@9&5L:6UT97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&5X<&QO9&5D('-T
M<FEN9R!I;B!A;B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@<F9C.#(R
M17AP;&]D92@D<W1R+"`D9&5L:6UI=&5R*0H@("`@>PH@("`@("`@("1A<G(@
M/2!A<G)A>2@I.PH@("`@("`@("1M871C:"`](#`["B`@("`@("`@)'%U;W1E
M<R`](&%R<F%Y*"<B)RP@(B<B*3L*("`@("`@("`D:6Y?<75O=&4@/2!N=6QL
M.PH@("`@("`@("1I;E]G<F]U<"`](&9A;'-E.PH@("`@("`@("1P<F5V(#T@
M;G5L;#L*"B`@("`@("`@:68@*&5M<'1Y*"1S='(I*2!["B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@D<W1R*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M;E]A<G)A>2@D<W1R>S!]+"`D<75O=&5S*2D@>PH@("`@("`@("`@("`D:6Y?
M<75O=&4@/2`D<W1R>S!].PH@("`@("`@('T@96QS96EF("@D<W1R>S!](#T]
M("<Z)RD@>PH@("`@("`@("`@("`D:6Y?9W)O=7`@/2!T<G5E.PH@("`@("`@
M('T@96QS96EF("@D<W1R>S!](#T]("1D96QI;6ET97(I('L*("`@("`@("`@
M("`@)&%R<EM=(#T@)R<["B`@("`@("`@("`@("1M871C:"`](#$["B`@("`@
M("`@?0H*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"!S=')L96XH)'-T<BD[
M("1I*RLI('L*("`@("`@("`@("`@)&-H87(@/2`D<W1R>R1I?3L*("`@("`@
M("`@("`@:68@*&EN7V%R<F%Y*"1C:&%R+"`D<75O=&5S*2D@>PH@("`@("`@
M("`@("`@("`@:68@*"1P<F5V("$]/2`G7%PG*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1I;E]Q=6]T92`]/3T@)&-H87(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN7W%U;W1E(#T@;G5L;#L*("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?;G5L;"@D:6Y?<75O=&4I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1I;E]Q=6]T92`]("1C:&%R.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E:68@*"1I;E]G<F]U<"D@>PH@("`@("`@("`@("`@("`@:68@*"1C:&%R
M(#T]("<[)RD@>PH@("`@("`@("`@("`@("`@("`@("1A<G);72`]('-U8G-T
M<B@D<W1R+"`D;6%T8V@L("1I("T@)&UA=&-H("L@,2D["B`@("`@("`@("`@
M("`@("`@("`@)&UA=&-H(#T@)&D@*R`Q.PH@("`@("`@("`@("`@("`@("`@
M("1I;E]G<F]U<"`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V5I9B`H)&-H87(@/3T@)SHG*2!["B`@("`@("`@("`@("`@
M("`D:6Y?9W)O=7`@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H)&-H
M87(@/3T@)&1E;&EM:71E<B`F)@H@("`@("`@("`@("`@("`@("`@("`@)'!R
M978@(3T]("=<7"<@)B8*("`@("`@("`@("`@("`@("`@("`@(&ES7VYU;&PH
M)&EN7W%U;W1E*2D@>PH@("`@("`@("`@("`@("`@)&%R<EM=(#T@<W5B<W1R
M*"1S='(L("1M871C:"P@)&D@+2`D;6%T8V@I.PH@("`@("`@("`@("`@("`@
M)&UA=&-H(#T@)&D@*R`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P
M<F5V(#T@)&-H87(["B`@("`@("`@?0H*("`@("`@("!I9B`H)&UA=&-H("$]
M("1I*2!["B`@("`@("`@("`@("\J(%1H92!S=')I;F<@96YD960@=VET:&]U
M="!A("1D96QI;6ET97(N("HO"B`@("`@("`@("`@("1A<G);72`]('-U8G-T
M<B@D<W1R+"`D;6%T8V@L("1I("T@)&UA=&-H*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D87)R.PH@("`@?0H*("`@("\J*@H@("`@("H@5&%K97,@
M86X@861D<F5S<R!O8FIE8W0L(&%S(')E='5R;F5D(&)Y(&EM87!?:&5A9&5R
M*"D@9F]R(&5X86UP;&4L(&%N9`H@("`@("H@9F]R;6%T<R!I="!A<R!A('-T
M<FEN9RX*("`@("`J"B`@("`@*B!/8FIE8W0@9F]R;6%T(&9O<B!T:&4@861D
M<F5S<R`B2F]H;B!$;V4@/&IO:&Y?9&]E0&5X86UP;&4N8V]M/B(@:7,Z"B`@
M("`@*B`\<')E/@H@("`@("H@("`D;V)J96-T+3YP97)S;VYA;"`](%!E<G-O
M;F%L(&YA;64@*")*;VAN($1O92(I"B`@("`@*B`@("1O8FIE8W0M/FUA:6QB
M;W@@(#T@5&AE('5S97(G<R!M86EL8F]X("@B:F]H;E]D;V4B*0H@("`@("H@
M("`D;V)J96-T+3YH;W-T("`@("`](%1H92!H;W-T('1H92!M86EL8F]X(&ES
M(&]N("@B97AA;7!L92YC;VTB*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T9$-L87-S("1O8B`@(%1H92!A9&1R97-S(&]B:F5C="!T
M;R!B92!T=7)N960@:6YT;R!A('-T<FEN9RX*("`@("`J($!P87)A;2!M:7AE
M9"`D9FEL=&5R("!!('5S97)`97AA;7!L92YC;VT@<W1Y;&4@8F%R92!A9&1R
M97-S('1O(&EG;F]R92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!%
M:71H97(@<VEN9VQE('-T<FEN9R!O<B!A;B!A<G)A>2!O9B!S=')I;F=S+B`@
M268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@861D<F5S<R!M
M871C:&5S("1F:6QT97(L(&%N(&5M<'1Y('-T<FEN9R!W:6QL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@8F4@<F5T=7)N960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@861D<F5S<R`H17AA
M;7!L93H@2F]H;B!$;V4*("`@("`J("`@("`@("`@("`@("`@("`\:F]H;E]D
M;V5`97AA;7!L92YC;VT^*2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D<D]B
M:F5C=#)3=')I;F<H)&]B+"`D9FEL=&5R(#T@)R<I"B`@("!["B`@("`@("`@
M+RH@268@=&AE('!E<G-O;F%L(&YA;64@:7,@<V5T+"!D96-O9&4@:70N("HO
M"B`@("`@("`@)&]B+3YP97)S;VYA;"`](&ES<V5T*"1O8BT^<&5R<V]N86PI
M(#\@34E-13HZ9&5C;V1E*"1O8BT^<&5R<V]N86PI(#H@)R<["@H@("`@("`@
M("\J($EF(&)O=&@@=&AE(&UA:6QB;W@@86YD('1H92!H;W-T(&%R92!E;7!T
M>2P@<F5T=7)N(&%N(&5M<'1Y"B`@("`@("`@("`@<W1R:6YG+B`@268@=V4@
M:G5S="!L970@=&AI<R!C87-E(&9A;&P@=&AR;W5G:"P@=&AE(&-A;&P@=&\*
M("`@("`@("`@("!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H*2!W:6QL(&5N
M9"!U<"!R971U<FX@:G5S="!A("=`)RP@=VAI8V@*("`@("`@("`@("!I<R!U
M;F1E<VER86)L92X@*B\*("`@("`@("!I9B`H96UP='DH)&]B+3YM86EL8F]X
M*2`F)B!E;7!T>2@D;V(M/FAO<W0I*2!["B`@("`@("`@("`@(')E='5R;B`G
M)SL*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!T:&5S92!T=V\@
M=F%R:6%B;&5S(&AA=F4@<V]M92!S;W)T(&]F('9A;'5E+B`J+PH@("`@("`@
M(&EF("@A:7-S970H)&]B+3YM86EL8F]X*2D@>PH@("`@("`@("`@("`D;V(M
M/FUA:6QB;W@@/2`G)SL*("`@("`@("!](&5L<V5I9B`H)&]B+3YM86EL8F]X
M(#T]("=U;F1I<V-L;W-E9"UR96-I<&EE;G1S)RD@>PH@("`@("`@("`@("!R
M971U<FX@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)&]B+3YH
M;W-T*2D@>PH@("`@("`@("`@("`D;V(M/FAO<W0@/2`G)SL*("`@("`@("!]
M"@H@("`@("`@("\J($9I;'1E<B!O=70@=6YW86YT960@861D<F5S<V5S(&)A
M<V5D(&]N('1H92`D9FEL=&5R('-T<FEN9RX@*B\*("`@("`@("!I9B`H)&9I
M;'1E<BD@>PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QT97(I*2![
M"B`@("`@("`@("`@("`@("`D9FEL=&5R(#T@87)R87DH)&9I;'1E<BD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&9I;'1E<B!A<R`D
M9BD@>PH@("`@("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&8L("1O8BT^
M;6%I;&)O>"`N("=`)R`N("1O8BT^:&]S="D@/3T@,"D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N('1H92!T<FEM
M;65D+"!F;W)M871T960@96UA:6P@861D<F5S<RX@*B\*("`@("`@("!R971U
M<FX@34E-13HZ=')I;45M86EL061D<F5S<RA-24U%.CIR9F,X,C)7<FET94%D
M9')E<W,H)&]B+3YM86EL8F]X+"`D;V(M/FAO<W0L("1O8BT^<&5R<V]N86PI
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%N(&%R<F%Y(&]F(&%D
M9')E<W,@;V)J96-T<RP@87,@<F5T=7)N960@8GD@:6UA<%]H96%D97)I;F9O
M*"DL"B`@("`@*B!F;W(@97AA;7!L92P@86YD('!A<W-E<R!E86-H(&]F('1H
M96T@=&AR;W5G:"!-24U%.CIA9&1R3V)J96-T,E-T<FEN9R@I+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D861D<F5S<V5S("!4:&4@87)R87D@;V8@
M861D<F5S<R!O8FIE8W1S+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@
M("`@($$@=7-E<D!E>&%M<&QE+F-O;2!S='EL92!B87)E(&%D9')E<W,@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I9VYO<F4N("!)9B!A
M;GD@861D<F5S<R!M871C:&5S("1F:6QT97(L(&ET"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@=VEL;"!N;W0@8F4@:6YC;'5D960@:6X@=&AE
M(&9I;F%L('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M06QL(&]F('1H92!A9&1R97-S97,@:6X@82!C;VUM82UD96QI;6ET960@<W1R
M:6YG+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE(&5M<'1Y
M('-T<FEN9R!O;B!E<G)O<B]N;R!A9&1R97-S97,@9F]U;F0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9')!<G)A>3)3=')I;F<H)&%D9')E<W-E<RP@)&9I
M;'1E<B`]("<G*0H@("`@>PH@("`@("`@("1A9&1R3&ES="`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@A:7-?87)R87DH)&%D9')E<W-E<RDI('L*("`@("`@
M("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)&%D9')E<W-E<R!A<R`D861D<BD@>PH@("`@("`@("`@("`D=F%L(#T@34E-
M13HZ861D<D]B:F5C=#)3=')I;F<H)&%D9'(L("1F:6QT97(I.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1V86PI*2!["B`@("`@("`@("`@("`@("`D8F%R
M94%D9'(@/2!3=')I;F<Z.FQO=V5R*$U)344Z.F)A<F5!9&1R97-S*"1V86PI
M*3L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&%D9'),:7-T6R1B87)E
M061D<ETI*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9'),:7-T6R1B87)E
M061D<ET@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)&%D9'),:7-T*2D@>PH@
M("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(&EM<&QO9&4H)RP@)RP@)&%D9'),:7-T*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!B87)E(&%D
M9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S<R`@
M("!4:&4@861D<F5S<R!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M969S97)V97(@(%1H92!D969A=6QT(&1O;6%I;B!T;R!A<'!E;F0@=&\@;6%I
M;&)O>&5S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&UU;'1I<&QE("!3:&]U
M;&0@=V4@<F5T=7)N(&UU;'1I<&QE(')E<W5L=',_"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@268@)&UU;'1I<&QE(&ES(&9A;'-E+"!R971U<FYS
M('1H92!M86EL8F]X0&AO<W0@92UM86EL"B`@("`@*B`@("`@("`@("`@("`@
M("!A9&1R97-S+B`@268@)&UU;'1I<&QE(&ES('1R=64L(')E='5R;G,@86X@
M87)R87D@;V8*("`@("`J("`@("`@("`@("`@("`@('1H97-E(&%D9')E<W-E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8F%R94%D9')E<W,H)&%D9')E<W,L
M("1D969S97)V97(@/2!N=6QL+"`D;75L=&EP;&4@/2!F86QS92D*("`@('L*
M("`@("`@("`D861D<F5S<TQI<W0@/2!A<G)A>2@I.PH*("`@("`@("`O*B!5
M<V4@8G5I;'0M:6X@24U!4"!F=6YC=&EO;B!O;FQY(&EF(&%V86EL86)L92!A
M;F0@:68@;F]T('!A<G-I;F<*("`@("`@("`@*B!D:7-T<FEB=71I;VX@;&ES
M=',@8F5C875S92!I="!D;V5S;B=T('!A<G-E(&1I<W1R:6)U=&EO;B!L:7-T
M<PH@("`@("`@("`J('!R;W!E<FQY+B`J+PH@("`@("`@(&EF("A5=&EL.CIE
M>'1E;G-I;VY%>&ES=',H)VEM87`G*2`F)B!S=')P;W,H)&%D9')E<W,L("<Z
M)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1F<F]M(#T@:6UA<%]R9F,X
M,C)?<&%R<V5?861R;&ES="@D861D<F5S<RP@)&1E9G-E<G9E<BD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+U)&
M0S@R,BYP:'`G.PH@("`@("`@("`@("`D<&%R<V5R(#T@;F5W($UA:6Q?4D9#
M.#(R*"D["B`@("`@("`@("`@("1F<F]M(#T@)'!A<G-E<BT^<&%R<V5!9&1R
M97-S3&ES="@D861D<F5S<RP@)&1E9G-E<G9E<BP@9F%L<V4L(&9A;'-E*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)&9R;VTL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D;75L=&EP;&4@/R!A<G)A>2@I(#H@
M)R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1F<F]M(&%S("1E;G1R>2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&5N
M=')Y+3YM86EL8F]X*2`F)@H@("`@("`@("`@("`@("`@)&5N=')Y+3YM86EL
M8F]X("$]("=U;F1I<V-L;W-E9"UR96-I<&EE;G1S)R`F)@H@("`@("`@("`@
M("`@("`@)&5N=')Y+3YM86EL8F]X("$]("=53D584$5#5$5$7T1!5$%?0494
M15)?041$4D534R<I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96YT
M<GDM/FAO<W0I*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9')E<W-,:7-T
M6UT@/2`D96YT<GDM/FUA:6QB;W@@+B`G0"<@+B`D96YT<GDM/FAO<W0["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1A
M9&1R97-S3&ES=%M=(#T@)&5N=')Y+3YM86EL8F]X.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&UU;'1I<&QE(#\@)&%D9')E<W-,:7-T(#H@87)R87E?<&]P*"1A9&1R97-S
M3&ES="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=6]T97,@86YD(&5S8V%P
M97,@=&AE(&=I=F5N('-T<FEN9R!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<W1R("`@("!4:&4@<W1R:6YG('1O(&)E('%U;W1E9"!A;F0@97-C87!E
M9"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;'1E<B`@02!L:7-T(&]F(&-H
M87)A8W1E<G,@=&AA="!M86ME(&ET(&YE8V5S<V%R>2!T;PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!Q=6]T92!T:&4@<W1R:6YG(&EF('1H97D@
M;V-C=7(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;W)R
M96-T;'D@<75O=&5D(&%N9"!E<V-A<&5D('-T<FEN9RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W)F8S@R,D5N8V]D92@D<W1R+"`D9FEL=&5R(#T@)R<I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1F:6QT97(I*2!["B`@("`@("`@("`@
M("1V87)S(#T@9V5T7V-L87-S7W9A<G,H)TU)344G*3L*("`@("`@("`@("`@
M)&9I;'1E<B`]("1V87)S6R=R9F,X,C)?9FEL=&5R)UT@+B`G("<["B`@("`@
M("`@?0H*("`@("`@("`O+R!3=')I<"!D;W5B;&4@<75O=&5S(&EF('1H97D@
M87)E(&%R;W5N9"!T:&4@<W1R:6YG(&%L<F5A9'DN"B`@("`@("`@:68@*'-U
M8G-T<B@D<W1R+"`P+"`Q*2`]/2`G(B<@)B8@<W5B<W1R*"1S='(L("TQ*2`]
M/2`G(B<I('L*("`@("`@("`@("`@)'-T<B`]('-U8G-T<B@D<W1R+"`Q+"`M
M,2D["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R8W-P;B@D<W1R+"`D9FEL
M=&5R*2`A/2!S=')L96XH)'-T<BDI('L*("`@("`@("`@("`@)'-T<B`]('-T
M<E]R97!L86-E*"=<(B<L("<B)RP@)'-T<BD["B`@("`@("`@("`@(')E='5R
M;B`G(B<@+B!S=')?<F5P;&%C92@G(B<L("=<7"(G+"!S=')?<F5P;&%C92@G
M7%PG+"`G7%Q<7"<L("1S='(I*2`N("<B)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@)'-T<CL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!-24U%('1Y<&4@9F]R('1H92!G:79E
M;B!I;G!U="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&EN<'5T("`@
M("!%:71H97(@=&AE($U)344@8V]D92!O<B!T>7!E('-T<FEN9RX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1F;W)M870@($EF($U)345?0T]$12P@<F5T=7)N
M(&-O9&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!)9B!-24U%
M7U-44DE.1RP@<F5T=7)N<R!L;W=E<F-A<V4@<W1R:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%-E92!A8F]V92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@='EP92@D:6YP=70L("1F;W)M870@/2!N=6QL*0H@("`@>PH@("`@
M("`@(')E='5R;B!-24U%.CI?9V5T0V]D92@D:6YP=70L("1F;W)M870L("=M
M:6UE7W1Y<&5S)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!-24U%(&5N8V]D:6YG(&9O<B!T:&4@9VEV96X@:6YP=70N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1I;G!U="`@("`@16ET:&5R('1H92!-24U%
M(&-O9&4@;W(@96YC;V1I;F<@<W1R:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&9O<FUA="`@268@34E-15]#3T1%+"!R971U<FX@8V]D92X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@($EF($U)345?4U1224Y'+"!R971U
M<FYS(&QO=V5R8V%S92!S=')I;F<N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!)9B!N;W0@<V5T+"!R971U<FYS('1H92!O<'!O<VET92!V86QU
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!3964@86)O=F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D:6YG*"1I;G!U="P@)&9O<FUA="`]
M(&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N($U)344Z.E]G971#;V1E*"1I
M;G!U="P@)&9O<FUA="P@)VUI;65?96YC;V1I;F=S)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971R:65V97,@34E-12!E;F-O9&EN9R]T>7!E(&1A=&$@
M9G)O;2!T:&4@:6YT97)N86P@87)R87ES+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:6YP=70@
M("`@16ET:&5R('1H92!-24U%(&-O9&4@;W(@96YC;V1I;F<@<W1R:6YG+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!)9B!-24U%7T-/1$4L(')E
M='5R;G,@8V]D92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@268@
M34E-15]35%))3D<L(')E='5R;G,@;&]W97)C87-E('-T<FEN9RX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@268@;G5L;"P@<F5T=7)N<R!T:&4@
M;W!P<&]S:71E('9A;'5E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M("!4:&4@;F%M92!O9B!T:&4@:6YT97)N86P@87)R87DN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@4V5E(&%B;W9E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9V5T0V]D92@D:6YP=70L("1F;W)M870L("1T>7!E*0H@("`@>PH@
M("`@("`@("1N=6UE<FEC(#T@:7-?;G5M97)I8R@D:6YP=70I.PH@("`@("`@
M(&EF("@A)&YU;65R:6,I('L*("`@("`@("`@("`@)&EN<'5T(#T@4W1R:6YG
M.CIL;W=E<B@D:6YP=70I.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D
M9F]R;6%T*2!["B`@("`@("`@8V%S92!-24U%7T-/1$4Z"B`@("`@("`@("`@
M(&EF("@D;G5M97)I8RD@<F5T=7)N("1I;G!U=#L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@34E-15]35%))3D<Z"B`@("`@("`@("`@(&EF
M("@A)&YU;65R:6,I(')E='5R;B`D:6YP=70["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*"B`@("`@("`@)'9A<G,@/2!G971?8VQA<W-?=F%R<R@G
M34E-12<I.PH*("`@("`@("!I9B`H)&YU;65R:6,I('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1V87)S6R1T>7!E75LD:6YP=71=*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1V87)S6R1T>7!E75LD:6YP=71=.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"@D<V5A<F-H
M(#T@87)R87E?<V5A<F-H*"1I;G!U="P@)'9A<G-;)'1Y<&5=*2DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D<V5A<F-H.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E<R!A($UE<W-A9V4M240@<W1R:6YG(&-O;F9O<FUI
M;F<@=&\@4D9#(#(X,C(@6S,N-BXT72!A;F0@=&AE"B`@("`@*B!S=&%N9&%R
M9',@;W5T;&EN960@:6X@)V1R869T+6EE=&8M=7-E9F]R+6UE<W-A9V4M:60M
M,#$N='AT)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!!(&UE<W-A
M9V4@240@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T94UE
M<W-A9V5)1"@I"B`@("!["B`@("`@("`@<F5T=7)N("<\)R`N(&1A=&4H)UEM
M9$AI<R<I("X@)RXG("X*("`@("`@("`@("`@<W5B<W1R*&)A<V5?8V]N=F5R
M="AM:6-R;W1I;64H*2`N(&UT7W)A;F0H*2P@,3`L(#,V*2P@+3$V*2`N"B`@
M("`@("`@("`@("=`)R`N("1?4T525D526R=315)615)?3D%-12==("X@)SXG
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!P<F]P97(@;&EN96)R96%K
M<R!T;R!A(&AE861E<B!S=')I;F<N"B`@("`@*B!21D,@,C@R,B!;,BXR+C-=
M('-A>7,@=&AA="!H96%D97)S(%-(3U5,1"!B92!W<F%P<&5D(&%T(#<X(&-H
M87)A8W1E<G,N"B`@("`@*B!(;W=E=F5R+"!S:6YC92!W92!M87D@8F4@9&5A
M;&EN9R!W:71H('%U;W1E9"!T97AT('1H870@8V]N=&%I;G,@<W!A8V5S+`H@
M("`@("H@<W1R:6-T('=R87!P:6YG(&%T(#<X(&-H87)A8W1E<G,@;6%Y(&%D
M9"!U;G=A;G1E9"!N97=L:6YE<R!A;F0@=&%B<R!T;PH@("`@("H@=&AE('%U
M;W1E9"!P87)A;65T97(N("!4:&4@8V]R<F5C="!W87D@=&\@9V5T(&%R;W5N
M9"!T:&ES(&ES('1O(&5N8V]D90H@("`@("H@<&%R865T97)S(&%C8V]R9&EN
M9R!T;R!21D,@,C(S,2X@($AO=V5V97(L('-I;F-E(&UO<W0@;6%I;&5R<R!D
M;R!N;W0*("`@("`J('-E96T@=&\@<W5P<&]R="!T:&ES+"!W92!W:6QL(&EN
M<W1E860@<VEM<&QY('5S92!L;VYG(&QI;F5S+B`@4D9#(#(X,C(*("`@("`J
M('-A>7,@:&5A9&5R<R!32$]53$0@;VYL>2!B92`W."!C:&%R86-T97)S(&$@
M;&EN92P@8G5T(&%L<V\@<V%Y<R!T:&%T"B`@("`@*B!A(&AE861E<B!L:6YE
M($U54U0@;F]T(&)E(&UO<F4@=&AA;B`Y.3@@8VAA<F%C=&5R<RX@(%1H97)E
M9F]R92P@=&AE"B`@("`@*B!C;VUP<F]M:7-E(&ES('1O('!U="!E86-H('!A
M<F%M971E<B!O;B!A('-E<&%R871E(&QI;F4@86YD(&-H;W`@:70*("`@("`J
M(&]N;'D@:68@:70@:7,@;&]N9V5R('1H86X@.3DX(&-H87)A8W1E<G,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4:&4@:&5A9&5R
M(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@(%1H92!T97AT
M(&]F('1H92!H96%D97(@9FEE;&0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1E
M;VP@("`@(%1H92!%3TP@<W1R:6YG('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&AE861E<B!T97AT+"!W:71H(&QI;F5B<F5A
M:W,@:6YS97)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R87!(96%D97)S
M*"1H96%D97(L("1T97AT+"`D96]L(#T@(EQR7&XB*0H@("`@>PH@("`@("`@
M("1H96%D97(@/2!R=')I;2@D:&5A9&5R*3L*"B`@("`@("`@+RH@4F5M;W9E
M(&%N>2!E>&ES=&EN9R!L:6YE8G)E86MS+B`J+PH@("`@("`@("1T97AT(#T@
M<')E9U]R97!L86-E*"(O7'(_7&Y<<S\O(BP@)R`G+"`D=&5X="D["B`@("`@
M("`@)'1E>'0@/2`D:&5A9&5R("X@)SH@)R`N(')T<FEM*"1T97AT*3L*"B`@
M("`@("`@)&5O;&QE;F=T:"`]('-T<FQE;B@D96]L*3L*("`@("`@("`D:&5A
M9&5R7VQO=V5R(#T@<W1R=&]L;W=E<B@D:&5A9&5R*3L*"B`@("`@("`@:68@
M*"@D:&5A9&5R7VQO=V5R("$]("=C;VYT96YT+71Y<&4G*2`F)@H@("`@("`@
M("`@("`H)&AE861E<E]L;W=E<B`A/2`G8V]N=&5N="UD:7-P;W-I=&EO;B<I
M*2!["B`@("`@("`@("`@("\J(%=R87`@=&AE(&QI;F4N("HO"B`@("`@("`@
M("`@("1L:6YE(#T@=V]R9'=R87`H)'1E>'0L(#<U+"`D96]L("X@(EQT(BD[
M"@H@("`@("`@("`@("`O*B!-86ME('-U<F4@=&AE<F4@87)E(&YO(&5M<'1Y
M(&QI;F5S+B`J+PH@("`@("`@("`@("`D;&EN92`]('!R96=?<F5P;&%C92@G
M+R<@+B`D96]L("X@(EQT7',J(B`N("1E;VP@+B`B7'0O(BP@)R\G("X@)&5O
M;"`N(")<="\B+"`D;&EN92D["@H@("`@("`@("`@("!R971U<FX@<W5B<W1R
M*"1L:6YE+"!S=')L96XH)&AE861E<BD@*R`R*3L*("`@("`@("!]"@H@("`@
M("`@("\J(%-P;&ET('1H92!L:6YE(&)Y('1H92!21D,@<&%R86UE=&5R('-E
M<&%R871O<B`G.R<N("HO"B`@("`@("`@)'!A<F%M<R`]('!R96=?<W!L:70H
M(B]<<RH[7',J+R(L("1T97AT*3L*"B`@("`@("`@)&QI;F4@/2`G)SL*("`@
M("`@("`D;&5N9W1H(#T@,3`P,"`M("1E;VQL96YG=&@["B`@("`@("`@)'!A
M<F%M8V]U;G0@/2!C;W5N="@D<&%R86US*3L*"B`@("`@("`@9F]R96%C:"`H
M)'!A<F%M<R!A<R`D8V]U;G0@/3X@)'9A;"D@>PH@("`@("`@("`@("`O*B!)
M9B!L;VYG97(@=&AA;B!21D,@86QL;W=S+"!T:&5N('-I;7!L>2!C:&]P(&]F
M9B!T:&4@97AC97-S+B`J+PH@("`@("`@("`@("`D;6]R97!A<F%M<R`]("@H
M)&-O=6YT("L@,2D@(3T@)'!A<F%M8V]U;G0I.PH@("`@("`@("`@("`D;6%X
M;&5N9W1H(#T@)&QE;F=T:"`M("@A96UP='DH)&QI;F4I(#\@,2`Z(#`I("T@
M*"@D;6]R97!A<F%M<RD@/R`Q(#H@,"D["B`@("`@("`@("`@(&EF("AS=')L
M96XH)'9A;"D@/B`D;6%X;&5N9W1H*2!["B`@("`@("`@("`@("`@("`D=F%L
M(#T@<W5B<W1R*"1V86PL(#`L("1M87AL96YG=&@I.PH*("`@("`@("`@("`@
M("`@("\J($EF('=E(&AA=F4@86X@;W!E;FEN9R!Q=6]T92P@861D(&$@8VQO
M<VEN9R!Q=6]T92!A9G1E<@H@("`@("`@("`@("`@("`@("H@8VAO<'!I;F<@
M=&AE(')E<W0@;V8@=&AE('1E>'0N("HO"B`@("`@("`@("`@("`@("!I9B`H
M<W1R<&]S*"1V86PL("<B)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@)'9A;"`]('-U8G-T<B@D=F%L+"`P+"`M,2D["B`@("`@("`@("`@
M("`@("`@("`@)'9A;"`N/2`G(B<["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1L:6YE*2D@>PH@
M("`@("`@("`@("`@("`@)&QI;F4@+CT@(EQT(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D;&EN92`N/2`D=F%L("X@*"@D;6]R97!A<F%M<RD@/R`G
M.R<@.B`G)RD@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('-U
M8G-T<B@D;&EN92P@<W1R;&5N*"1H96%D97(I("L@,BP@*"1E;VQL96YG=&@@
M*B`M,2DI.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O07)R
M87DN<&AP````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$W,3(S`#$P-3$U-#,Q,#8Q`#`R,#`P-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E
M7T%R<F%Y.CH@8VQA<W,@<')O=FED97,@=F%R:6]U<R!M971H;V1S(&9O<B!A
M<G)A>2!M86YI<'5L871I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U5T
M:6PO07)R87DN<&AP+'8@,2XR-BXR+C@@,C`P-B\P,2\P,2`R,3HR.#HT,2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`875T
M:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?571I;`H@*B\*8VQA<W,@2&]R
M9&5?07)R87D@>PH*("`@("\J*@H@("`@("H@4')E<&%R92!A(&QI<W0@;V8@
M861D<F5S<V5S(&9O<B!S=&]R86=E+@H@("`@("H@3F%M96QY+"!T<FEM<R!A
M;F0@;&]W97)C87-E<R!A;&P@861D<F5S<V5S(&%N9"!T:&5N('-O<G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A9&1R("!4:&4@;&ES="!O9B!A
M9&1R97-S97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI
M<W0@;V8@861D<F5S<V5S+"!P<F5P87)E9"!F;W(@<W1O<F%G92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<')E<&%R94%D9')E<W-,:7-T*"1A9&1R*0H@("`@
M>PH@("`@("`@("\J(%)E;6]V92!A;GD@97AT<F$@<W!A8V4@:6X@=&AE(&%D
M9')E<W,@86YD(&UA:V4@:70@;&]W97)C87-E+B`J+PH@("`@("`@("1A9&1R
M(#T@87)R87E?;6%P*"=T<FEM)RP@)&%D9'(I.PH@("`@("`@("1A9&1R(#T@
M87)R87E?;6%P*&%R<F%Y*"=3=')I;F<G+"`G;&]W97(G*2P@)&%D9'(I.PH*
M("`@("`@("`O*B!296UO=F4@9'5P;&EC871E(&5N=')I97,N("HO"B`@("`@
M("`@)&%D9'(@/2!A<G)A>5]U;FEQ=64H)&%D9'(I.PH*("`@("`@("`O*B!3
M;W)T('1H92!L:7-T+B`J+PH@("`@("`@('5S;W)T*"1A9&1R+"!A<G)A>2@G
M2&]R9&5?07)R87DG+"`G<V]R=$%D9')E<W-,:7-T)RDI.PH*("`@("`@("!R
M971U<FX@)&%D9'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!U
M<V5D(&)Y('5S;W)T*"D@=&\@<V]R="!A;B!A9&1R97-S(&QI<W0N"B`@("`@
M*B!E+F<N('5S;W)T*"1F;V\L(&%R<F%Y*"=(;W)D95]!<G)A>2<L("=S;W)T
M061D<F5S<TQI<W0G*2D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M82`@061D<F5S<R`C,2X*("`@("`J($!P87)A;2!S=')I;F<@)&(@($%D9')E
M<W,@(S(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`M,2P@,"P@
M;W(@,2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$%D9')E<W-,:7-T*"1A
M+"`D8BD*("`@('L*("`@("`@("`D82`](&5X<&QO9&4H)T`G+"`D82D["B`@
M("`@("`@)&(@/2!E>'!L;V1E*"=`)RP@)&(I.PH*("`@("`@("`O*B!/;F4@
M;V8@=&AE(&%D9')E<W-E<R!D;V5S;B=T(&AA=F4@82!H;W-T(&YA;64N("HO
M"B`@("`@("`@:68@*&5M<'1Y*"1A6S!=*2D@>PH@("`@("`@("`@("!A<G)A
M>5]S:&EF="@D82D["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D8ELP
M72DI('L*("`@("`@("`@("`@87)R87E?<VAI9G0H)&(I.PH@("`@("`@('T*
M("`@("`@("!I9B`H8V]U;G0H)&$I("$](&-O=6YT*"1B*2D@>PH@("`@("`@
M("`@("!R971U<FX@*&-O=6YT*"1A*2`^(&-O=6YT*"1B*2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!4:&4@861D<F5S<V5S(&AA=F4@9&EF9F5R96YT(&AO
M<W1N86UE(&]R(&YO="!H;W-T;F%M92!A;F0*("`@("`@("`@("!D:69F97)E
M;G0@;6%I;&)O>"!N86UE<RX@*B\*("`@("`@("!I9B`H)&%;*&-O=6YT*"1A
M*2`M(#$I72`A/2`D8ELH8V]U;G0H)&(I("T@,2E=*2!["B`@("`@("`@("`@
M(')E='5R;B!S=')C;7`H)&%;*&-O=6YT*"1A*2`M(#$I72P@)&);*&-O=6YT
M*"1B*2`M(#$I72D["B`@("`@("`@?0H*("`@("`@("`O*B!#;VUP87)E(&UA
M:6QB;W@@;F%M97,N("HO"B`@("`@("`@<F5T=7)N('-T<F-M<"@D85LP72P@
M)&);,%TI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R=',@86X@87)R87D@
M;VX@82!S<&5C:69I960@:V5Y+B!)9B!T:&4@:V5Y(&1O97,@;F]T(&5X:7-T
M+`H@("`@("H@9&5F875L=',@=&\@=&AE(&9I<G-T(&ME>2!O9B!T:&4@87)R
M87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D87)R87D@("`@("`@
M5&AE(&%R<F%Y('1O(&)E('-O<G1E9"P@<&%S<V5D(&)Y(')E9F5R96YC92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@(%1H92!K97D@8GD@
M=VAI8V@@=&\@<V]R="X@268@;F]T('-P96-I9FEE9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE;B!T:&4@9FER<W0@:V5Y(&ES('5S
M960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("!3;W)T(&1I
M<F5C=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@
M/2!A<V-E;F1I;F<@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@,2`](&1E<V-E;F1I;F<*("`@("`J($!P87)A;2!B;V]L
M96%N("1A<W-O8VEA=&4@($ME97`@:V5Y('9A;'5E(&%S<V]C:6%T:6]N/PH@
M("`@("HO"B`@("!F=6YC=&EO;B!A<G)A>5-O<G0H)B1A<G)A>2P@)&ME>2`]
M(&YU;&PL("1D:7)E8W1I;VX@/2`P+"`D87-S;V-I871E(#T@=')U92D*("`@
M('L*("`@("`@("`O*B!2971U<FX@:68@=&AE(&%R<F%Y(&ES(&5M<'1Y+B`J
M+PH@("`@("`@(&EF("AE;7!T>2@D87)R87DI*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($EF(&YO(&ME>2!T;R!S;W)T
M(&)Y(&ES('-P96-I9FEE9"P@=7-E('1H92!F:7)S="!K97DN("HO"B`@("`@
M("`@:68@*&ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)&ME>7,@/2!A
M<G)A>5]K97ES*&5A8V@H)&%R<F%Y*2D["B`@("`@("`@("`@("1K97D@/2`D
M:V5Y<ULP73L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T:&4@9G5N
M8W1I;VX@=&AA="!W:6QL(&)E('5S960@=&\@<V]R="!T:&4@:V5Y<RX@*B\*
M("`@("`@("!I9B`H)&1I<F5C=&EO;BD@>PH@("`@("`@("`@("`D9G5N8W1I
M;VX@/2!S<')I;G1F*"=R971U<FX@<W1R8V]L;"A3=')I;F<Z.FQO=V5R*"1B
M6UPG)3$D<UPG72P@=')U92DL(%-T<FEN9SHZ;&]W97(H)&%;7"<E,21S7"==
M+"!T<G5E*2D[)RP@)&ME>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9U;F-T:6]N(#T@<W!R:6YT9B@G<F5T=7)N('-T<F-O;&PH4W1R:6YG
M.CIL;W=E<B@D85M<)R4Q)'-<)UTL('1R=64I+"!3=')I;F<Z.FQO=V5R*"1B
M6UPG)3$D<UPG72P@=')U92DI.R<L("1K97DI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@0V%L;"!T:&4@87!P<F]P<FEA=&4@<V]R="!F=6YC=&EO;BX@*B\*
M("`@("`@("!I9B`H)&%S<V]C:6%T92D@>PH@("`@("`@("`@("!U87-O<G0H
M)&%R<F%Y+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L("1F=6YC=&EO;BDI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5S;W)T*"1A<G)A>2P@
M8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`D9G5N8W1I;VXI*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!(5$U,('1Y<&4@
M87)R87D@9FEE;&0@(F5X86UP;&5;:V5Y,5U;:V5Y,EU;:V5Y,UTB(&)R96%K
M<R!U<`H@("`@("H@=&AE(&ME>7,@<V\@=&AA="!T:&5Y(&-O=6QD(&)E('5S
M960@=&\@<F5F97)E;F-E(&$@<F5G=6QA<B!02%`@87)R87DN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@(%1H92!F:65L9"!N86UE('1O
M(&)E(&5X86UI;F5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&)A<V4@(%-E
M="!T;R!T:&4@8F%S92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M:V5Y<R`@(%-E="!T;R!T:&4@;&ES="!O9B!K97ES+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-E<W,L(&9A;'-E(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!<G)A>5!A<G1S*"1F:65L
M9"P@)B1B87-E+"`F)&ME>7,I"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)WPH6UY<6UTJ*2@H7%M;7EQ;7%U=*EQ=*2LI?"<L("1F:65L9"P@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@("1B87-E(#T@)&UA=&-H97-;,5T["B`@
M("`@("`@("`@("1K97ES(#T@97AP;&]D92@G75LG+"`D;6%T8VAE<ULR72D[
M"B`@("`@("`@("`@("1K97ES6S!=(#T@<W5B<W1R*"1K97ES6S!=+"`Q*3L*
M("`@("`@("`@("`@)&ME>7-;8V]U;G0H)&ME>7,I("T@,5T@/2!S=6)S='(H
M)&ME>7-;8V]U;G0H)&ME>7,I("T@,5TL(#`L('-T<FQE;B@D:V5Y<UMC;W5N
M="@D:V5Y<RD@+2`Q72D@+2`Q*3L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5S:6YG(&%N(&%R<F%Y
M(&]F(&ME>7,@:71A<F%T92!T:')O=6=H('1H92!A<G)A>2!F;VQL;W=I;F<@
M=&AE"B`@("`@*B!K97ES('1O(&9I;F0@=&AE(&9I;F%L(&ME>2!V86QU92X@
M268@82!V86QU92!I<R!P87-S960@=&AE;B!S970*("`@("`J('1H870@=F%L
M=64N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D87)R87D@(%1H92!A
M<G)A>2!T;R!B92!U<V5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D:V5Y<R`@
M(%1H92!K97D@<&%T:"!T;R!F;VQL;W<@87,@86X@87)R87DN"B`@("`@*B!`
M<&%R86T@87)R87D@)'9A;'5E("`@268@<V5T('1H92!T87)G970@96QE;65N
M="!W:6QL(&AA=F4@=&AI<R!V86QU92!S970*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!T;R!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@9FEN86P@=F%L=64@;V8@=&AE(&ME>2!P871H+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971%;&5M96YT*"8D87)R87DL("8D:V5Y<RP@)'9A;'5E
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)&ME>7,I*2!["B`@
M("`@("`@("`@("1K97D@/2!A<G)A>5]S:&EF="@D:V5Y<RD["B`@("`@("`@
M("`@(&EF("AI<W-E="@D87)R87E;)&ME>5TI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@2&]R9&5?07)R87DZ.F=E=$5L96UE;G0H)&%R<F%Y6R1K97E=
M+"`D:V5Y<RP@)'9A;'5E*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=F%L=64I*2![
M"B`@("`@("`@("`@("`@("`D87)R87D@/2`D=F%L=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N("1A<G)A>3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5C=&%N9VQE(&]F(&$@='=O
M+61I;65N<VEO;F%L(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`F)&%R<F%Y("`@(%1H92!A<G)A>2!T;R!E>'1R86-T('1H92!R96-T86YG
M;&4@9G)O;2X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@("`@(%1H92!S
M=&%R="!R;W<@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@("`@(%1H92!S=&%R="!C;VQU;6X@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@
M;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1W:61T
M:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@(%1H92!E>'1R86-T960@<F5C=&%N9VQE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9V5T4F5C=&%N9VQE*"8D87)R87DL("1R;W<L
M("1C;VPL("1H96EG:'0L("1W:61T:"D*("`@('L*("`@("`@("`D<F5C(#T@
M87)R87DH*3L*("`@("`@("!F;W(@*"1Y(#T@)')O=SL@)'D@/"`D<F]W("L@
M)&AE:6=H=#L@)'DK*RD@>PH@("`@("`@("`@("`D<F5C6UT@/2!A<G)A>5]S
M;&EC92@D87)R87E;)'E=+"`D8V]L+"`D=VED=&@I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)')E8SL*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N
M(&%N(&%R<F%Y+"!R971U<FYS(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@
M96%C:"!E;&5M96YT(&ME>0H@("`@("H@9&5R:79E9"!F<F]M(&ET<R!V86QU
M92X*("`@("`J($9O<B!E>&%M<&QE.@H@("`@("H@("!A<G)A>2@P(#T^("=F
M;V\G+"`Q(#T^("=B87(G*0H@("`@("H@=V]U;&0@8F5C;VUE.@H@("`@("H@
M("!A<G)A>2@G9F]O)R`]/B`G9F]O)RP@)V)A<B<@/3X@)V)A<B<I"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2`@06X@87)R87D@;V8@=F%L
M=65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y('=I
M=&@@:V5Y<R!T:&4@<V%M92!A<R!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('9A;'5E<U1O2V5Y<R@D87)R87DI"B`@("!["B`@("`@("`@)&UA<'!E
M9"`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1V86QU
M92D@>PH@("`@("`@("`@("`D;6%P<&5D6R1V86QU95T@/2`D=F%L=64["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D;6%P<&5D.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A;B!A<G)A>2!B>2!U<VEN9R!O;F4@87)R87D@
M9F]R(&ME>7,@86YD(&%N;W1H97(@9F]R"B`@("`@*B!I=',@=F%L=65S+B!/
M;FQY(&5X:7-T<R!I;B!02%`U+"!S;R!W92!C86QL(&%R<F%Y7V-O;6)I;F4@
M:68@:70*("`@("`J(&5X:7-T<R!A;F0@;W1H97)W:7-E(&5M=6QA=&4@:70N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1K97ES("`@($ME>2!A<G)A
M>2X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("!686QU92!A<G)A>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&86QS92!I9B!T:&5R92!A
M<F4@;F\@96QE;65N=',L(&]R('1H92!C;VUB:6YE9"!A<G)A>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]M8FEN92@D:V5Y<RP@)'9A;'5E<RD*("`@('L*
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=A<G)A>5]C;VUB:6YE)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7V-O;6)I;F4H)&ME>7,L("1V
M86QU97,I.PH@("`@("`@('T*"B`@("`@("`@)'-I>F4@/2!C;W5N="@D:V5Y
M<RD["B`@("`@("`@:68@*"@D<VEZ92`A/2!C;W5N="@D=F%L=65S*2D@?'P@
M*"1S:7IE(#T](#`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(&9O<B`H)'@@/2`P.R`D>"`\("1S:7IE.R`D>"LK
M*2!["B`@("`@("`@("`@("1A<G)A>5LD:V5Y<ULD>%U=(#T@)'9A;'5E<ULD
M>%T["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87)R87D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1O:V5N+G!H<```````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S4P,0`Q,#4Q-30S,3`V,0`P,C`P,#4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J(%1H92!(;W)D
M95]4;VME;CHZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&%B<W1R86-T960@
M:6YT97)F86-E(&EN=&\@=&AE"B`J('9A<FEO=7,@=&]K96X@9V5N97)A=&EO
M;B!M961I=6US+B!)="!A;'-O(&EN8VQU9&5S(&%L;"!O9B!T:&4*("H@9G5N
M8W1I;VYS(&9O<B!R971R:65V:6YG+"!S=&]R:6YG+"!A;F0@8VAE8VMI;F<@
M=&]K96YS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]4;VME;B]4;VME;BYP
M:'`L=B`Q+C,S+C8N."`R,#`V+S`T+S$Y(#(Q.C$T.C`U(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($UA>"!+86QI:V$@/&UA>$!H;W)D
M92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G/@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,2XS"B`J($!P86-K86=E($AO<F1E7U1O:V5N"B`J+PIC;&%S<R!(;W)D
M95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(87-H(&]F('!A<F%M971E<G,@
M;F5C97-S87)Y('1O('5S92!T:&4@8VAO<V5N(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U1O:V5N
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N
M(&5N8V]D95)E;6]T94%D9')E<W,H*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72DI('L*("`@("`@("`@("`@<F5T
M=7)N(&)A<V4V-%]E;F-O9&4H)%]315)615);)U)%34]415]!1$12)UTI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@82!C;VYN96-T
M:6]N(&ED(&%N9"!R971U<FYS(&ET+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'-E960@($$@=6YI<75E($E$('1O(&)E(&EN8VQU9&5D(&EN('1H
M92!T;VME;BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&EF(&ET(&YE
M961S('1O(&)E(&UO<F4@=6YI<75E('1H86X@=&EM92`H:6X@<V5C;VYD<RD*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@(&%N9"!T:&4@<F5M;W1E($E0
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&=E;F5R871E
M9"!I9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E260H
M)'-E960@/2`G)RD*("`@('L*("`@("`@("!R971U<FX@;60U*'1I;64H*2`N
M("==6R<@+B`D<V5E9"`N("==6R<@+B!(;W)D95]4;VME;CHZ96YC;V1E4F5M
M;W1E061D<F5S<R@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I
M9B!T:&4@9VEV96X@=&]K96X@:&%S(&)E96X@<')E=FEO=7-L>2!U<V5D+B!&
M:7)S=`H@("`@("H@<'5R9V5S(&%L;"!E>'!I<F5D('1O:V5N<RX@5&AE;B!R
M971R:65V97,@8W5R<F5N="!T;VME;G,@9F]R"B`@("`@*B!T:&4@9VEV96X@
M:7`@861D<F5S<RX@268@=&AE('-P96-I9FEE9"!T;VME;B!W87,@;F]T(&9O
M=6YD+`H@("`@("H@861D<R!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T;VME;B`@5&AE('9A;'5E(&]F('1H92!T;VME;B!T;R!C:&5C:RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("`@("`@5')U92!I9B!T
M:&4@=&]K96X@:&%S(&YO="!B965N('5S960L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!V97)I9GDH)'1O:V5N*0H@("`@>PH@("`@("`@("1T:&ES+3YP=7)G
M92@I.PH@("`@("`@("1E>&ES=',@/2`D=&AI<RT^97AI<W1S*"1T;VME;BD[
M"B`@("`@("`@:68@*&ES7V$H)&5X:7-T<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&5X:7-T<SL*("`@("`@("!](&5L<V5I9B`H
M)&5X:7-T<RD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YA9&0H)'1O:V5N
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&ES(&%N
M(&%B<W1R86-T(&UE=&AO9"!T:&%T('-H;W5L9"!B92!O=F5R<FED9&5N(&)Y
M(&$*("`@("`J('-U8F-L87-S(&EM<&QE;65N=&%T:6]N+B!4:&4@8F%S92!I
M;7!L96UE;G1A=&EO;B!A;&QO=W,@86QL"B`@("`@*B!T;VME;B!V86QU97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!I<R!A
M;B!A8G-T<F%C="!M971H;V0@=&AA="!S:&]U;&0@8F4@;W9E<G)I9&1E;B!B
M>2!A"B`@("`@*B!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;BX@5&AE(&)A<V4@
M:6UP;&5M96YT871I;VX@86QL;W=S(&%L;`H@("`@("H@=&]K96X@=F%L=65S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H*0H@("`@>PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!I<R!A;B!A
M8G-T<F%C="!M971H;V0@=&AA="!S:&]U;&0@8F4@;W9E<G)I9&1E;B!B>2!A
M"B`@("`@*B!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;BX@5&AE(&)A<V4@:6UP
M;&5M96YT871I;VX@86QL;W=S(&%L;`H@("`@("H@=&]K96X@=F%L=65S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P=7)G92@I"B`@("!["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!C;VYC<F5T92!(;W)D95]4;VME;B!I;G-T86YC92!B87-E9"!O
M;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R
M("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]4;VME;B!S=6)C;&%S<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R
M:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]4;VME;B\@
M9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A
M9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M
M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?5&]K96X@
M(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7U1O:V5N(&EN<W1A
M;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@9F%L<V4@86X@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L
M("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1A<'`L("1D<FEV97(I
M(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E
M;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)&%P<"`N("<O;&EB+U1O:V5N+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E
M>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U1O:V5N+R<@+B`D9')I=F5R
M("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+U1O:V5N+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO
M<F1E+U1O:V5N+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@
M("`@("`@)&-L87-S(#T@)TAO<F1E7U1O:V5N7R<@+B`D9')I=F5R.PH@("`@
M("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D
M=&]K96X@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&]K96X@/2`F;F5W($AO<F1E7U1O:V5N*"1P87)A
M;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T;VME;CL*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC
M92!T;R!A(&-O;F-R971E($AO<F1E7U1O:V5N(&EN<W1A;F-E(&)A<V5D"B`@
M("`@*B!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($ET('=I;&P@;VYL>2!C
M<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?5&]K96X@:6YS=&%N
M8V4@=VET:"!T:&4*("`@("`J('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@
M97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@
M;75L=&EP;&4@='EP97,@;V8@=&]K96X@9V5N97)A=&]R<R`H86YD+"!T:'5S
M+`H@("`@("H@;75L=&EP;&4@2&]R9&5?5&]K96X@:6YS=&%N8V5S*2!A<F4@
M<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I
M;G9O:V5D(&%S.@H@("`@("H@/&-O9&4^)'9A<B`]("9(;W)D95]4;VME;CHZ
M<VEN9VQE=&]N*"D[/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]4;VME;B!S
M=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI
M8B]4;VME;B\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S
M=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R
M9&5?5&]K96X@(%1H92!C;VYC<F5T92!(;W)D95]4;VME;B!R969E<F5N8V4L
M(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A
M;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@
M("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@
M("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R
M86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U
M<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@
M)DAO<F1E7U1O:V5N.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O26UA9V4N<&AP````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,U,S<T`#$P-3$U-#,Q,#8Q`#`Q-S<V,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M<F5Q=6ER95]O;F-E("=(;W)D92]5=&EL+G!H<"<["@HO*BH*("H@5&AI<R!C
M;&%S<R!D969I;F5S('1H92!(;W)D95]);6%G93HZ($%022P@86YD(&%L<V\@
M<')O=FED97,@<V]M90H@*B!U=&EL:71Y(&9U;F-T:6]N<RP@<W5C:"!A<R!G
M96YE<F%T:6YG(&AI9VAL:6=H=',@;V8@82!C;VQO<BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO26UA9V4O26UA9V4N<&AP+'8@,2XS.2XQ,"XQ,R`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]);6%G90H@*B\*8VQA<W,@2&]R9&5?26UA9V4@>PH*("`@("\J
M*@H@("`@("H@0W5R<F5N="!C;VQO<BX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]R9V(@/2`G9F8P,#`P)SL*"B`@("`O
M*BH*("`@("`J($)A8VMG<F]U;F0@8V]L;W(N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F%C:V=R;W5N9"`]("=W:&ET
M92<["@H@("`@+RHJ"B`@("`@*B!/8G-E<G9E<G,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O8G-E<G9E<G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0V%P86)I;&ET97,@;V8@=&AI<R!D<FEV
M97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]C87!A8FEL:71I97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE
M(&-U<G)E;G0@:6UA9V4@9&%T82X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]D871A(#T@)R<["@H@("`@+RHJ"B`@("`@
M*B!4:&4@8W5R<F5N="!I;6%G92!I9"X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]I9"`]("<G.PH*("`@("\J*@H@("`@
M("H@5&AE(&-U<G)E;G0@=VED=&@@;V8@=&AE(&EM86=E(&1A=&$N"B`@("`@
M*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W=I9'1H
M(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&AE:6=H="!O9B!T
M:&4@:6UA9V4@9&%T82X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?:&5I9VAT(#T@,#L*"B`@("`O*BH*("`@("`J($$@
M9&ER96-T;W)Y(&9O<B!T96UP;W)A<GD@9FEL97,N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&UP9&ER.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F=B("!4:&4@8F%S92!C;VQO<B!F;W(@9V5N97)A=&5D('!I>&5L
M<R]I;6%G97,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TEM86=E*"1P
M87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]T;7!D:7(@/2`D<&%R86US
M6R=T96UP)UT["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W=I9'1H)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D<&%R86US6R=W:61T
M:"==.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG:&5I
M9VAT)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:&5I9VAT(#T@)'!A<F%M
M<ULG:&5I9VAT)UT["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'!A
M<F%M<ULG<F=B)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F=B(#T@)'!A
M<F%M<ULG<F=B)UT["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?8F%C:V=R
M;W5N9"`](&ES<V5T*"1P87)A;7-;)V)A8VMG<F]U;F0G72D@/R`D<&%R86US
M6R=B86-K9W)O=6YD)UT@.B`G=VAI=&4G.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$-A<&%B:6QI=&EE<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V%P86)I;&ET:65S.PH@("`@?0H*("`@(&9U;F-T:6]N(&AA<T-A<&%B
M:6QI='DH)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@<F5T=7)N(&EN7V%R
M<F%Y*"1C87!A8FEL:71Y+"`D=&AI<RT^7V-A<&%B:6QI=&EE<RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T3&EN:R@D=7)L+"`D=&ET;&4@/2`G)RD*("`@
M('L*("`@("`@("!R971U<FX@2&]R9&4Z.FEM9R@D=7)L+"`D=&ET;&4L("<G
M+"`G)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!I;6%G92!H
M96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!H96%D97)S*"D*("`@('L*
M("`@("`@("!H96%D97(H)T-O;G1E;G0M='EP93H@)R`N("1T:&ES+3YG971#
M;VYT96YT5'EP92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T
M92!A(&QI9VAT97(@*&]R(&1A<FME<BD@=F5R<VEO;B!O9B!A(&-O;&]R+@H@
M("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;VQO<B`@($%N($A434P@8V]L;W(L(&4N9RXZ("-F9F9F8V,N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F86-T;W(@(%1/1$\*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@02!M;V1I9FEE9"!(5$U,(&-O;&]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!M;V1I9GE#;VQO<B@D8V]L;W(L("1F86-T;W(@
M/2`P>#$Q*0H@("`@>PH@("`@("`@("1R(#T@:&5X9&5C*'-U8G-T<B@D8V]L
M;W(L(#$L(#(I*2`K("1F86-T;W(["B`@("`@("`@)&<@/2!H97AD96,H<W5B
M<W1R*"1C;VQO<BP@,RP@,BDI("L@)&9A8W1O<CL*("`@("`@("`D8B`](&AE
M>&1E8RAS=6)S='(H)&-O;&]R+"`U+"`R*2D@*R`D9F%C=&]R.PH*("`@("`@
M("`D<B`](&UI;BAM87@H)'(L(#`I+"`R-34I.PH@("`@("`@("1G(#T@;6EN
M*&UA>"@D9RP@,"DL(#(U-2D["B`@("`@("`@)&(@/2!M:6XH;6%X*"1B+"`P
M*2P@,C4U*3L*"B`@("`@("`@<F5T=7)N("<C)R`N('-T<E]P860H9&5C:&5X
M*"1R*2P@,BP@)S`G+"!35%)?4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H
M)&<I+"`R+"`G,"<L(%-44E]0041?3$5&5"D@+B!S=')?<&%D*&1E8VAE>"@D
M8BDL(#(L("<P)RP@4U127U!!1%],1494*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-A;&-U;&%T92!A(&UO<F4@:6YT96YS92!V97)S:6]N(&]F(&$@8V]L
M;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&-O;&]R("`@06X@2%1-3"!C;VQO<BP@92YG+CH@(V9F9F9C
M8RX*("`@("`J($!P87)A;2!S=')I;F<@)&9A8W1O<B`@5$]$3PH@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!!(&UO<F4@:6YT96YS92!(5$U,(&-O
M;&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W)E26YT96YS94-O;&]R*"1C
M;VQO<BP@)&9A8W1O<B`](#!X,3$I"B`@("!["B`@("`@("`@)'(@/2!H97AD
M96,H<W5B<W1R*"1C;VQO<BP@,2P@,BDI.PH@("`@("`@("1G(#T@:&5X9&5C
M*'-U8G-T<B@D8V]L;W(L(#,L(#(I*3L*("`@("`@("`D8B`](&AE>&1E8RAS
M=6)S='(H)&-O;&]R+"`U+"`R*2D["@H@("`@("`@(&EF("@D<B`^/2`D9R`F
M)B`D<B`^/2`D8BD@>PH@("`@("`@("`@("`D9R`]("1G("\@)'(["B`@("`@
M("`@("`@("1B(#T@)&(@+R`D<CL*"B`@("`@("`@("`@("1R("L]("1F86-T
M;W(["B`@("`@("`@("`@("1G(#T@9FQO;W(H)&<@*B`D<BD["B`@("`@("`@
M("`@("1B(#T@9FQO;W(H)&(@*B`D<BD["B`@("`@("`@?2!E;'-E:68@*"1G
M(#X]("1R("8F("1G(#X]("1B*2!["B`@("`@("`@("`@("1R(#T@)'(@+R`D
M9SL*("`@("`@("`@("`@)&(@/2`D8B`O("1G.PH*("`@("`@("`@("`@)&<@
M*ST@)&9A8W1O<CL*("`@("`@("`@("`@)'(@/2!F;&]O<B@D<B`J("1G*3L*
M("`@("`@("`@("`@)&(@/2!F;&]O<B@D8B`J("1G*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<B`]("1R("\@)&(["B`@("`@("`@("`@("1G
M(#T@)&<@+R`D8CL*"B`@("`@("`@("`@("1B("L]("1F86-T;W(["B`@("`@
M("`@("`@("1R(#T@9FQO;W(H)'(@*B`D8BD["B`@("`@("`@("`@("1G(#T@
M9FQO;W(H)&<@*B`D8BD["B`@("`@("`@?0H*("`@("`@("`D<B`](&UI;BAM
M87@H)'(L(#`I+"`R-34I.PH@("`@("`@("1G(#T@;6EN*&UA>"@D9RP@,"DL
M(#(U-2D["B`@("`@("`@)&(@/2!M:6XH;6%X*"1B+"`P*2P@,C4U*3L*"B`@
M("`@("`@<F5T=7)N("<C)R`N('-T<E]P860H9&5C:&5X*"1R*2P@,BP@)S`G
M+"!35%)?4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H)&<I+"`R+"`G,"<L
M(%-44E]0041?3$5&5"D@+B!S=')?<&%D*&1E8VAE>"@D8BDL(#(L("<P)RP@
M4U127U!!1%],1494*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&)R:6=H=&YE<W,@;V8@82!C;VQO<BX*("`@("`J"B`@("`@*B!`<W1A
M=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@($%N($A4
M34P@8V]L;W(L(&4N9RXZ("-F9F9F8V,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@8G)I9VAT;F5S<R!O;B!A('-C86QE(&]F(#`@=&\@
M,C4U+@H@("`@("HO"B`@("!F=6YC=&EO;B!B<FEG:'1N97-S*"1C;VQO<BD*
M("`@('L*("`@("`@("`D<B`](&AE>&1E8RAS=6)S='(H)&-O;&]R+"`Q+"`R
M*2D["B`@("`@("`@)&<@/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@,RP@,BDI
M.PH@("`@("`@("1B(#T@:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#4L(#(I*3L*
M"B`@("`@("`@<F5T=7)N(')O=6YD*"@H)'(@*B`R.3DI("L@*"1G("H@-3@W
M*2`K("@D8B`J(#$Q-"DI("\@,3`P,"D["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T4D="*"1C;VQO<FYA;64I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R]);6%G92]R9V(N<&AP)SL*("`@("`@
M("!R971U<FX@:7-S970H)$=,3T)!3%-;)VAO<F1E7VEM86=E7W)G8E]C;VQO
M<G,G75LD8V]L;W)N86UE72D@/PH@("`@("`@("`@("`D1TQ/0D%,4ULG:&]R
M9&5?:6UA9V5?<F=B7V-O;&]R<R==6R1C;VQO<FYA;65=(#H*("`@("`@("`@
M("`@87)R87DH,"P@,"P@,"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T2&5X
M0V]L;W(H)&-O;&]R;F%M92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+TEM86=E+W)G8BYP:'`G.PH@("`@("`@
M(&EF("AI<W-E="@D1TQ/0D%,4ULG:&]R9&5?:6UA9V5?<F=B7V-O;&]R<R==
M6R1C;VQO<FYA;65=*2D@>PH@("`@("`@("`@("!L:7-T*"1R+"`D9RP@)&(I
M(#T@)$=,3T)!3%-;)VAO<F1E7VEM86=E7W)G8E]C;VQO<G,G75LD8V]L;W)N
M86UE73L*("`@("`@("`@("`@<F5T=7)N("<C)R`N('-T<E]P860H9&5C:&5X
M*&UI;B@D<BP@,C4U*2DL(#(L("<P)RP@4U127U!!1%],1494*2`N('-T<E]P
M860H9&5C:&5X*&UI;B@D9RP@,C4U*2DL(#(L("<P)RP@4U127U!!1%],1494
M*2`N('-T<E]P860H9&5C:&5X*&UI;B@D8BP@,C4U*2DL(#(L("<P)RP@4U12
M7U!!1%],1494*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)V)L86-K)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M<F%W(&$@<VAA<&5D('!O:6YT(&%T('1H92!S<&5C:69I960@*'@L>2D@<&]I
M;G0N(%5S969U;"!F;W(*("`@("`J('-C871T97(@9&EA9W)A;7,L(&1E8G5G
M('!O:6YT<RP@971C+B!$<F%W<R!S<75A<F5S+"!C:7)C;&5S+`H@("`@("H@
M9&EA;6]N9',L(&%N9"!T<FEA;F=L97,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE('!O:6YT
M('1O(&)R=7-H+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@(%1H92!Y
M(&-O;W)D:6YA=&4@;V8@=&AE('!O:6YT('1O(&)R=7-H+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]L;W(@(%1H92!C;VQO<B!T;R!B<G5S:"!T:&4@<&]I
M;G0@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)'-H87!E("!7:&%T(&)R
M=7-H('1O('5S93\@1&5F875L=',@=&\@82!S<75A<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&)R=7-H*"1X+"`D>2P@)&-O;&]R(#T@)V)L86-K)RP@)'-H
M87!E(#T@)W-Q=6%R92<I"B`@("!["B`@("`@("`@<W=I=&-H("@D<VAA<&4I
M('L*("`@("`@("!C87-E("=T<FEA;F=L92<Z"B`@("`@("`@("`@("1V97)T
M<ULP72`](&%R<F%Y*"=X)R`]/B`D>"`K(#,L("=Y)R`]/B`D>2`K(#,I.PH@
M("`@("`@("`@("`D=F5R='-;,5T@/2!A<G)A>2@G>"<@/3X@)'@L("=Y)R`]
M/B`D>2`M(#,I.PH@("`@("`@("`@("`D=F5R='-;,ET@/2!A<G)A>2@G>"<@
M/3X@)'@@+2`S+"`G>2<@/3X@)'D@*R`S*3L*("`@("`@("`@("`@)'1H:7,M
M/G!O;'EG;VXH)'9E<G1S+"`D8V]L;W(L("1C;VQO<BD["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=C:7)C;&4G.@H@("`@("`@("`@("`D
M=&AI<RT^8VER8VQE*"1X+"`D>2P@,RP@)&-O;&]R+"`D8V]L;W(I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G9&EA;6]N9"<Z"B`@("`@
M("`@("`@("1V97)T<ULP72`](&%R<F%Y*"=X)R`]/B`D>"`M(#,L("=Y)R`]
M/B`D>2D["B`@("`@("`@("`@("1V97)T<ULQ72`](&%R<F%Y*"=X)R`]/B`D
M>"P@)WDG(#T^("1Y("L@,RD["B`@("`@("`@("`@("1V97)T<ULR72`](&%R
M<F%Y*"=X)R`]/B`D>"`K(#,L("=Y)R`]/B`D>2D["B`@("`@("`@("`@("1V
M97)T<ULS72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y("T@,RD["B`@
M("`@("`@("`@("1T:&ES+3YP;VQY9V]N*"1V97)T<RP@)&-O;&]R+"`D8V]L
M;W(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<W%U87)E
M)SH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI<RT^<F5C=&%N
M9VQE*"1X("T@,BP@)'D@+2`R+"`T+"`T+"`D8V]L;W(L("1C;VQO<BD["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!A;B!O8G-E<G9E<B!T;R!T:&ES(&EM86=E+B!4:&4@;V)S97)V
M97(@=VEL;"!B92!N;W1I9FEE9`H@("`@("H@=VAE;B!T:&4@:6UA9V4G<R!C
M:&%N9V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1/8G-E<G9E<B@D;65T
M:&]D+"`F)&]B:F5C="D*("`@('L*("`@("`@("`D=&AI<RT^7V]B<V5R=F5R
M<UM=(#T@87)R87DH)&UE=&AO9"P@)B1O8FIE8W0I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3&5T(&]B<V5R=F5R<R!K;F]W('1H870@<V]M971H:6YG(&AA
M<'!E;F5D('=O<G1H(&%C=&EN9R!O;BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M;F]T:69Y3V)S97)V97)S*"D*("`@('L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D=&AI<RT^7V]B<V5R=F5R<RD[("LK)&DI('L*("`@("`@
M("`@("`@)&]B:B`]("8D=&AI<RT^7V]B<V5R=F5R<ULD:5U;,5T["B`@("`@
M("`@("`@("1M971H;V0@/2`D=&AI<RT^7V]B<V5R=F5R<ULD:5U;,%T["B`@
M("`@("`@("`@("1O8FHM/B1M971H;V0H)'1H:7,I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G92!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]D871A(#T@)R<["B`@("`@("`@)'1H:7,M/E]I9"`]("<G.PH@("`@("`@
M("1T:&ES+3Y?=VED=&@@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?:&5I9VAT
M(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7V)A8VMG<F]U;F0@/2`G=VAI=&4G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!H96EG:'0@86YD('=I
M9'1H(&]F('1H92!C=7)R96YT(&EM86=E(&1A=&$N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@06X@:&%S:"!W:71H("=W:61T:"<@8V]N=&%I;FEN
M9R!T:&4@=VED=&@L"B`@("`@*B`@("`@("`@("`@("`@("`G:&5I9VAT)R!C
M;VYT86EN:6YG('1H92!H96EG:'0@;V8@=&AE(&EM86=E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971$:6UE;G-I;VYS*"D*("`@('L*("`@("`@("`D=&UP
M(#T@)'1H:7,M/G1O1FEL92@I.PH@("`@("`@("1D971A:6QS(#T@0&=E=&EM
M86=E<VEZ92@D=&UP*3L*("`@("`@("!U;FQI;FLH)'1M<"D["@H@("`@("`@
M(')E='5R;B!A<G)A>2@G=VED=&@G(#T^("1D971A:6QS6S!=+`H@("`@("`@
M("`@("`@("`@("`@("`G:&5I9VAT)R`]/B`D9&5T86EL<ULQ72D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,;V%D('1H92!I;6%G92!D871A(&9R;VT@82!S
M=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@
M("`@06X@87)B:71R87)Y(&ED(&9O<B!T:&4@:6UA9V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I;6%G95]D871A("!4:&4@9&%T82!T;R!U<V4@9F]R('1H
M92!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9%-T<FEN9R@D:60L
M("1I;6%G95]D871A*0H@("`@>PH@("`@("`@(&EF("@D:60@(3T@)'1H:7,M
M/E]I9"D@>PH@("`@("`@("`@("`D=&AI<RT^<F5S970H*3L*("`@("`@("`@
M("`@)'1H:7,M/E]D871A(#T@)&EM86=E7V1A=&$["B`@("`@("`@("`@("1T
M:&ES+3Y?:60@/2`D:60["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@3&]A9"!T:&4@:6UA9V4@9&%T82!F<F]M(&$@9FEL92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9U;&P@<&%T:"!A
M;F0@9FEL96YA;64@=&\@=&AE(&9I;&4@=&\@;&]A9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!I;6%G92!D871A(&9R;VTN(%1H92!F
M:6QE;F%M92!W:6QL(&%L<V\@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!U<V5D(&9O<B!T:&4@:6UA9V4@:60N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@4$5!4B!%<G)O<B!I9B!F:6QE(&1O97,@;F]T(&5X
M:7-T(&]R(&-O=6QD(&YO="!B92!L;V%D960*("`@("`J("`@("`@("`@("`@
M("`@(&]T:&5R=VES92!.54Q,(&EF('-U8V-E<W-F=6P@;W(@86QR96%D>2!L
M;V%D960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO861&:6QE*"1F:6QE;F%M
M92D*("`@('L*("`@("`@("!I9B`H)&9I;&5N86UE("$]("1T:&ES+3Y?:60I
M('L*("`@("`@("`@("`@)'1H:7,M/G)E<V5T*"D["B`@("`@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1H92!I;6%G92!F:6QE("<@+B`D
M:6UA9V4@+B`G(&1O97,@;F]T(&5X:7-T+B<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V1A=&$@/2!F:6QE7V=E=%]C;VYT96YT
M<R@D9FEL96YA;64I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VED(#T@
M)&9I;&5N86UE.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!L;V%D('1H
M92!I;6%G92!F:6QE("<@+B`D:6UA9V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('1O1FEL92@D9&%T82`](&9A;'-E
M*0H@("`@>PH@("`@("`@("1T;7`@/2!5=&EL.CIG971496UP1FEL92@G:6UG
M)RP@9F%L<V4L("1T:&ES+3Y?=&UP9&ER*3L*("`@("`@("`D9G`@/2!`9F]P
M96XH)'1M<"P@)W=B)RD["B`@("`@("`@9G=R:71E*"1F<"P@)&1A=&$@/R`D
M9&%T82`Z("1T:&ES+3YR87<H*2D["B`@("`@("`@9F-L;W-E*"1F<"D["B`@
M("`@("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-P
M;&%Y('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M:7-P;&%Y*"D*("`@('L*("`@("`@("`D=&AI<RT^:&5A9&5R<R@I.PH@("`@
M("`@(&5C:&\@)'1H:7,M/G)A=R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@<F%W(&1A=&$@9F]R('1H:7,@:6UA9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&-O;G9E<G0@($EF('1R=64L('1H92!I
M;6%G92!D871A('=I;&P@8F4@<F5T=7)N960@:6X@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&%R9V5T(&9O<FUA="P@:6YD97!E;F1E
M;G1L>2!F<F]M(&%N>2!I;6%G90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&]P97)A=&EO;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!R87<@:6UA9V4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F%W*"1C;VYV97)T(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;B!X+'D@
M<&%I<B!O;B!C:7)C;&4L(&%S<W5M:6YG(&-E;G1E<B!I<R`P+#`N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&1O=6)L92`D9&5G<F5E<R`@("!4:&4@9&5G<F5E<R!O9B!A<F,@=&\@9V5T
M('1H92!P;VEN="!F;W(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&EA;65T
M97(@(%1H92!D:6%M971E<B!O9B!T:&4@8VER8VQE+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@("AX(&-O;W)D:6YA=&4L('D@8V]O<F1I;F%T92D@
M;V8@=&AE('!O:6YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VER8VQE4&]I
M;G0H)&1E9W)E97,L("1D:6%M971E<BD*("`@('L*("`@("`@("`O+R!!=F]I
M9"!P<F]B;&5M<R!W:71H(&1O=6)L97,N"B`@("`@("`@)&1E9W)E97,@*ST@
M,"XP,#`Q.PH*("`@("`@("!R971U<FX@87)R87DH8V]S*&1E9S)R860H)&1E
M9W)E97,I*2`J("@D9&EA;65T97(@+R`R*2P*("`@("`@("`@("`@("`@("`@
M("`@<VEN*&1E9S)R860H)&1E9W)E97,I*2`J("@D9&EA;65T97(@+R`R*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@<&]I;G0@8V]O<F1I;F%T97,@
M870@=&AE(&QI;6ET<R!O9B!A;B!A<F,N($]N;'D@=F%L:60@9F]R"B`@("`@
M*B!A;F=L97,@*"1E;F0@+2`D<W1A<G0I(#P](#0U(&1E9W)E97,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R=&EN9R!A;F=L92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1E;F0@("`@5&AE(&5N9&EN9R!A;F=L
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<W1A<G0@<&]I
M;G0L(&5N9"!P;VEN="P@86YD(&%N8VAO<B!P;VEN="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V%R8U!O:6YT<R@D<BP@)'-T87)T+"`D96YD*0H@("`@>PH@
M("`@("`@("\O(%-T87)T('!O:6YT+@H@("`@("`@("1P='-;)W@Q)UT@/2`D
M<B`J(&-O<RAD96<R<F%D*"1S=&%R="DI.PH@("`@("`@("1P='-;)WDQ)UT@
M/2`D<B`J('-I;BAD96<R<F%D*"1S=&%R="DI.PH*("`@("`@("`O+R!%;F0@
M<&]I;G0N"B`@("`@("`@)'!T<ULG>#(G72`]("1R("H@8V]S*&1E9S)R860H
M)&5N9"DI.PH@("`@("`@("1P='-;)WDR)UT@/2`D<B`J('-I;BAD96<R<F%D
M*"1E;F0I*3L*"B`@("`@("`@+R\@06YC:&]R('!O:6YT+@H@("`@("`@("1A
M,R`]("@D<W1A<G0@*R`D96YD*2`O(#(["B`@("`@("`@)'(S(#T@)'(@+R!C
M;W,H9&5G,G)A9"@H)&5N9"`M("1S=&%R="D@+R`R*2D["B`@("`@("`@)'!T
M<ULG>#,G72`]("1R,R`J(&-O<RAD96<R<F%D*"1A,RDI.PH@("`@("`@("1P
M='-;)WDS)UT@/2`D<C,@*B!S:6XH9&5G,G)A9"@D83,I*3L*"B`@("`@("`@
M<F5T=7)N("1P=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]);6%G92!I;G-T86YC92!B87-E
M9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I
M=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]);6%G92!S=6)C;&%S
M<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@5&AI
M<R!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`H)&1R:79E<BDN(%1H92!C;V1E(&ES(&1Y;F%M
M:6-A;&QY(&EN8VQU9&5D+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72]L:6(O
M26UA9V4O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B
M8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E
M7TEM86=E?&)O;VQE86X@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO
M<F1E7TEM86=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EN<W1A;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@
M("`@("`@(&QI<W0H)&%P<"P@)&1R:79E<BD@/2`D9')I=F5R.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O
M;W0G+"`D87!P*2`N("<O;&EB+TEM86=E+R<@+B`D9')I=F5R("X@)RYP:'`G
M.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+TEM86=E+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TEM
M86=E+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+TEM86=E+R<@+B`D9')I
M=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@/2`G2&]R
M9&5?26UA9V5?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I;6%G92`]("9N97<@)&-L87-S
M*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;6%G
M92`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N
M("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1I;6%G93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7TEM
M86=E(&EN<W1A;F-E(&)A<V5D"B`@("`@*B!O;B`D9')I=F5R+B!)="!W:6QL
M(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E7TEM86=E
M"B`@("`@*B!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R
M<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U
M<V5D(&EF(&UU;'1I<&QE('1Y<&5S(&]F(&EM86=E(')E;F1E<F5R<R`H86YD
M+"!T:'5S+`H@("`@("H@;75L=&EP;&4@2&]R9&5?26UA9V4@:6YS=&%N8V5S
M*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S
M="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)DAO<F1E7TEM86=E.CIS:6YG;&5T
M;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@
M='EP92!O9B!C;VYC<F5T92!(;W)D95]);6%G92!S=6)C;&%S<R!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@5&AI<R!I<R!B87-E
M9"!O;B!T:&4@<W1O<F%G92!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`H)&1R:79E<BDN(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN
M8VQU9&5D+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV
M97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K(&EN"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72]L:6(O26UA9V4O(&9O
M<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I
M;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D
M:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG
M:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7TEM86=E?&)O
M;VQE86X@(%1H92!C;VYC<F5T92!(;W)D95]);6%G92!R969E<F5N8V4L(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D
M<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I
M8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV
M97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;
M)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA
M='5R95T@/2`F2&]R9&5?26UA9V4Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M
M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E73L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I
M0V%L96YD87(N<&AP````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`Q,S`U,#0`,3`U,34T,S$P-C$`,#(P-C$R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G
M92!(;W)D95]I0V%L96YD87(*("HO"@HO*BH*("H@4W1R:6YG('!A8VMA9V4*
M("HO"FEN8VQU9&5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@
M0VQA<W,@<F5P<F5S96YT:6YG(&E#86QE;F1A<B!F:6QE<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<BYP:'`L=B`Q+C4W
M+C0N,S0@,C`P-B\P."\P-2`Q,SHT,SHT-R!K87)S=&5N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO
M"F-L87-S($AO<F1E7VE#86QE;F1A<B!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<&%R96YT("AC;VYT86EN:6YG*2!I0V%L96YD87(@;V)J96-T+@H@("`@("H*
M("`@("`J($!V87(@2&]R9&5?:4-A;&5N9&%R"B`@("`@*B\*("`@('9A<B`D
M7V-O;G1A:6YE<B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE(&YA;64O
M=F%L=64@<&%I<G,@;V8@871T<FEB=71E<R!F;W(@=&AI<R!O8FIE8W0@*%5)
M1"P*("`@("`J($144U1!4E0L(&5T8RXI+B!7:&EC:"!A<F4@<')E<V5N="!D
M97!E;F1S(&]N('1H92!O8FIE8W0@86YD(&]N"B`@("`@*B!W:&%T(&MI;F0@
M;V8@8V]M<&]N96YT(&ET(&ES+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?871T<FEB=71E<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!!;GD@8VAI;&1R96X@*&-O;G1A:6YE9"D@:4-A;&5N9&%R
M(&-O;7!O;F5N=',@;V8@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C;VUP;VYE;G1S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($%C8V]R9&EN9R!T;R!21D,@,C0R-2P@=V4@
M<VAO=6QD(&%L=V%Y<R!U<V4@0U),1BUT97)M:6YA=&5D(&QI;F5S+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VYE=VQI
M;F4@/2`B7')<;B(["@H@("`@+RHJ"B`@("`@*B!I0V%L96YD87(@9F]R;6%T
M('9E<G-I;VX@*&1I9F9E<F5N="!B96AA=FEO<B!F;W(@,2XP(&%N9"`R+C`*
M("`@("`J(&5S<&5C:6%L;'D@=VET:"!R96-U<G)I;F<@979E;G1S*2X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]V97)S
M:6]N.PH*("`@(&9U;F-T:6]N($AO<F1E7VE#86QE;F1A<B@D=F5R<VEO;B`]
M("<R+C`G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F5R<VEO;B`]("1V97)S
M:6]N.PH@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)U9%4E-)3TXG+"`D
M=F5R<VEO;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!R969E
M<F5N8V4@=&\@82!N97<@8V]M<&]N96YT+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("`@("`@("`@)'1Y<&4@("`@("`@5&AE('1Y<&4@;V8@8V]M
M<&]N96YT('1O(')E='5R;@H@("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A
M<B`D8V]N=&%I;F5R("!!(&-O;G1A:6YE<B!T:&%T('1H:7,@8V]M<&]N96YT
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I
M;&P@8F4@87-S;V-I871E9"!W:71H+@H@("`@("H*("`@("`J($!R971U<FX@
M;V)J96-T("!2969E<F5N8V4@=&\@82!(;W)D95]I0V%L96YD87)?*B!O8FIE
M8W0@87,@<W!E8VEF:65D+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@)FYE=T-O;7!O;F5N="@D='EP92P@)B1C;VYT86EN
M97(I"B`@("!["B`@("`@("`@)'1Y<&4@/2!3=')I;F<Z.FQO=V5R*"1T>7!E
M*3L*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?:4-A;&5N9&%R7R<@+B`D='EP
M93L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@
M("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+R<@+B`D='EP
M92`N("<N<&AP)SL*("`@("`@("!]"B`@("`@("`@:68@*&-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1C;VUP;VYE;G0@/2!N97<@)&-L
M87-S*"D["B`@("`@("`@("`@(&EF("@D8V]N=&%I;F5R("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@)&-O;7!O;F5N="T^7V-O;G1A:6YE<B`]("8D
M8V]N=&%I;F5R.PH@("`@("`@("`@("`@("`@+R\@57-E('9E<G-I;VX@;V8@
M8V]N=&%I;F5R+"!N;W0@9&5F875L="!S970@8GD@8V]M<&]N96YT"B`@("`@
M("`@("`@("`@("`O+R!C;VYS=')U8W1O<BX*("`@("`@("`@("`@("`@("1C
M;VUP;VYE;G0M/E]V97)S:6]N(#T@)&-O;G1A:6YE<BT^7W9E<G-I;VX["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!3
M:&]U;&0@<F5T=7)N(&%N(&1U;6UY('@M=6YK;F]W;B!T>7!E(&-L87-S(&AE
M<F4N"B`@("`@("`@("`@("1C;VUP;VYE;G0@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8V]M<&]N96YT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T<R!T:&4@=F%L=64@;V8@86X@871T<FEB=71E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N86UE(&]F('1H
M92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@("!4
M:&4@=F%L=64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("`@($%R<F%Y(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N('!A
M<F%M971E<G,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&ES(&%T=')I8G5T92X*("`@("`J($!P87)A;2!B;V]L96%N("1A<'!E;F0@
M(%1R=64@=&\@87!P96YD('1H92!A='1R:6)U=&4L($9A;'-E('1O(')E<&QA
M8V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F:7)S="!M
M871C:&EN9R!A='1R:6)U=&4@9F]U;F0N"B`@("`@*B!`<&%R86T@87)R87D@
M)'9A;'5E<R`@("!!<G)A>2!R97!R97-E;G1A=&EO;B!O9B`D=F%L=64N("!&
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-O;6UA+W-E;6EC
M;VQO;B!S97!E<F%T960@;&ES=',@;V8@=F%L=65S+B`@268*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&YO="!S970@=7-E("1V86QU92!A<R!S
M:6YG;&4@87)R87D@96QE;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M071T<FEB=71E*"1N86UE+"`D=F%L=64L("1P87)A;7,@/2!A<G)A>2@I+"`D
M87!P96YD(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L
M=65S(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@36%K92!S=7)E('=E('5P
M9&%T92!T:&4@:6YT97)N86P@9F]R;6%T('9E<G-I;VX@:68*("`@("`@("`O
M+R!S971!='1R:6)U=&4H)U9%4E-)3TXG+"`N+BXI(&ES(&-A;&QE9"X*("`@
M("`@("!I9B`H)&YA;64@/3T@)U9%4E-)3TXG*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?=F5R<VEO;B`]("1V86QU93L*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?8V]N=&%I;F5R("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C;VYT86EN97(M/E]V97)S:6]N(#T@)'9A;'5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(21V86QU97,I('L*("`@("`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1V86QU92D["B`@("`@("`@?0H@("`@
M("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@(&EF("@A)&%P<&5N9"D@>PH@
M("`@("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]A='1R:6)U
M=&5S*3L*("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG
M;F%M92==(#T](%-T<FEN9SHZ=7!P97(H)&YA;64I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A;7,G72`]
M("1P87)A;7,["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U
M=&5S6R1K97E=6R=V86QU92==(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG=F%L=65S)UT@/2`D=F%L
M=65S.PH@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D87!P96YD('Q\("$D
M9F]U;F0I('L*("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6UT@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("=N86UE)R`@("`@(#T^(%-T<FEN9SHZ
M=7!P97(H)&YA;64I+`H@("`@("`@("`@("`@("`@)W!A<F%M<R<@("`@/3X@
M)'!A<F%M<RP*("`@("`@("`@("`@("`@("=V86QU92<@("`@(#T^("1V86QU
M92P*("`@("`@("`@("`@("`@("=V86QU97,G("`@(#T^("1V86QU97,*("`@
M("`@("`@("`@*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S('!A<F%M971E<BAS*2!F;W(@86X@*&%L<F5A9'D@97AI<W1I;F<I(&%T
M=')I8G5T92X@(%1H90H@("`@("H@<&%R86UE=&5R('-E="!I<R!M97)G960@
M:6YT;R!T:&4@97AI<W1I;F<@<V5T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%R<F%Y(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@<&%R86UE=&5R<R!F;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!T:&ES(&%T=')I8G5T92X*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!I9B!N;R!A='1R:6)U=&4@
M)&YA;64@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971087)A;65T
M97(H)&YA;64L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1K
M97ES(#T@87)R87E?:V5Y<R@D=&AI<RT^7V%T=')I8G5T97,I.PH@("`@("`@
M(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG;F%M92==(#T]("1N86UE*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)W!A<F%M
M<R==(#T*("`@("`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D=&AI<RT^
M7V%T=')I8G5T97-;)&ME>5U;)W!A<F%M<R==+"`D<&%R86US*3L*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@=&AE('9A;'5E(&]F(&%N(&%T=')I8G5T92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@;F%M92!O9B!T:&4@871T
M<FEB=71E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!A<F%M<R`@4F5T=7)N
M('1H92!P87)A;65T97)S(&9O<B!T:&ES(&%T=')I8G5T92!I;G-T96%D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!O9B!I=',@=F%L=64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`H;V)J96-T*2`@4$5!4E]%<G)O
M<B!I9B!T:&4@871T<FEB=71E(&1O97,@;F]T(&5X:7-T+@H@("`@("H@("`@
M("`@("`@("`@("`H<W1R:6YG*2`@5&AE('9A;'5E(&]F('1H92!A='1R:6)U
M=&4N"B`@("`@*B`@("`@("`@("`@("`@("AA<G)A>2D@("!4:&4@<&%R86UE
M=&5R<R!F;W(@=&AE(&%T=')I8G5T92!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@;75L=&EP;&4@=F%L=65S(&9O<B!A;B!A='1R:6)U=&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T92@D;F%M92P@)'!A
M<F%M<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1R97-U;'0@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D871T
M<FEB=71E*2!["B`@("`@("`@("`@(&EF("@D871T<FEB=71E6R=N86UE)UT@
M/3T@)&YA;64I('L*("`@("`@("`@("`@("`@(&EF("@D<&%R86US*2!["B`@
M("`@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@)&%T=')I8G5T95LG<&%R
M86US)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1R97-U;'1;72`]("1A='1R:6)U=&5;)W9A;'5E)UT["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M:68@*"%C;W5N="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T%T=')I8G5T92`B)R`N("1N86UE("X@)R(@3F]T($9O=6YD)RD[
M"B`@("`@("`@?2!I9B`H8V]U;G0H)')E<W5L="D@/3T@,2`F)B`A)'!A<F%M
M<RD@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=%LP73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!V86QU97,@;V8@86X@
M871T<FEB=71E(&%S(&%N(&%R<F%Y+B`@375L=&EP;&4@=F%L=65S"B`@("`@
M*B!A<F4@<&]S<VEB;&4@9'5E('1O.@H@("`@("H*("`@("`J("!A*2!M=6QT
M:7!L8V4@;V-C=7)E;F-E<R!O9B`G;F%M92<*("`@("`J("!B*2`H=6YS96-A
M<&0I(&-O;6UA('-E<&5R871E9"!L:7-T<RX*("`@("`J"B`@("`@*B!3;R!F
M;W(@82!V8V%R9"!L:6ME(")+15DZ82QB7&Y+15DZ8R(@9V5T071T<FEB=71E
M<U9A;'5E<R@G2T59)RD*("`@("`J('=I;&P@<F5T=7)N(&%R<F%Y*"=A)RPG
M8B<L)V,G*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;F%M92`@
M("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E+@H@("`@("H@0')E='5R;B!M
M:7AE9"`H;V)J96-T*2`@4$5!4E]%<G)O<B!I9B!T:&4@871T<FEB=71E(&1O
M97,@;F]T(&5X:7-T+@H@("`@("H@("`@("`@("`@("`@("`H87)R87DI("`@
M375L=&EP;&4@=F%L=65S(&9O<B!A;B!A='1R:6)U=&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$%T=')I8G5T959A;'5E<R@D;F%M92D*("`@('L*("`@
M("`@("`D<F5S=6QT(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!I
M9B`H)&%T=')I8G5T95LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@87)R87E?;65R9V4H)&%T=')I8G5T95LG=F%L=65S
M)UTL("1R97-U;'0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&EF("@A8V]U;G0H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T%T=')I8G5T92`B)R`N("1N86UE("X@)R(@3F]T
M($9O=6YD)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L=64@;V8@86X@
M871T<FEB=71E+"!O<B!A('-P96-I9FEE9"!D969A=6QT('9A;'5E"B`@("`@
M*B!I9B!T:&4@871T<FEB=71E(&1O97,@;F]T(&5X:7-T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&YA;64@;V8@=&AE(&%T
M=')I8G5T92X*("`@("`J($!P87)A;2!M:7AE9"`D9&5F875L="`@5VAA="!T
M;R!R971U<FX@:68@=&AE(&%T=')I8G5T92!S<&5C:69I960@8GD*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@9&]E<R!N;W0@97AI<W0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`H<W1R:6YG*2!4:&4@=F%L
M=64@;V8@)&YA;64N"B`@("`@*B`@("`@("`@("`@("`@("AM:7AE9"D@("1D
M969A=6QT(&EF("1N86UE(&1O97,@;F]T(&5X:7-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971!='1R:6)U=&5$969A=6QT*"1N86UE+"`D9&5F875L="`]
M("<G*0H@("`@>PH@("`@("`@("1V86QU92`]("1T:&ES+3YG971!='1R:6)U
M=&4H)&YA;64I.PH@("`@("`@(')E='5R;B!I<U]A*"1V86QU92P@)U!%05)?
M17)R;W(G*2`_("1D969A=6QT(#H@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5M;W9E(&%L;"!O8V-U<F5N8V5S(&]F(&%N(&%T=')I8G5T92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O
M9B!T:&4@871T<FEB=71E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5!
M='1R:6)U=&4H)&YA;64I"B`@("!["B`@("`@("`@)&ME>7,@/2!A<G)A>5]K
M97ES*"1T:&ES+3Y?871T<FEB=71E<RD["B`@("`@("`@9F]R96%C:"`H)&ME
M>7,@87,@)&ME>2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]A='1R:6)U
M=&5S6R1K97E=6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@871T<FEB
M=71E<R!F;W(@86QL('1A9W,@;W(@9F]R(&$@9VEV96X@=&%G+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1A9R`@4F5T=7)N(&%T=')I8G5T97,@
M9F]R('1H:7,@=&%G+"!O<B!A;&P@871T<FEB=71E<R!I9@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("!N;W0@9VEV96XN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@06X@87)R87D@8V]N=&%I;FEN9R!A;&P@=&AE(&%T=')I
M8G5T97,@86YD('1H96ER('1Y<&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971!;&Q!='1R:6)U=&5S*"1T86<@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H)'1A9R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?871T<FEB=71E<SL*("`@("`@("!]"B`@("`@("`@)')E<W5L="`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S
M("1A='1R:6)U=&4I('L*("`@("`@("`@("`@:68@*"1A='1R:6)U=&5;)VYA
M;64G72`]/2`D=&%G*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2`D
M871T<FEB=71E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@=D-A
M;&5N9&%R(&-O;7!O;F5N="`H96<@=D5V96YT+"!V5&EM97IO;F4L(&5T8RXI
M+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]I0V%L96YD87(@)&-O;7!O
M;F5N="`@0V]M<&]N96YT("AS=6)C;&%S<RD@=&\@861D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1#;VUP;VYE;G0H)&-O;7!O;F5N="D*("`@('L*("`@
M("`@("!I9B`H:7-?82@D8V]M<&]N96YT+"`G2&]R9&5?:4-A;&5N9&%R)RDI
M('L*("`@("`@("`@("`@)&-O;7!O;F5N="T^7V-O;G1A:6YE<B`]("8D=&AI
M<SL*("`@("`@("`@("`@)'1H:7,M/E]C;VUP;VYE;G1S6UT@/2`F)&-O;7!O
M;F5N=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M92!A;&P@=&AE(&-O;7!O;F5N=',N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@07)R87D@;V8@2&]R9&5?:4-A;&5N9&%R(&]B:F5C=',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-O;7!O;F5N=',H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-O;7!O;F5N=',["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=V8V%L96YD87(G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C;&%S<V5S("AE
M;G1R>2!T>7!E<RD@=V4@:&%V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!(87-H('=I=&@@8VQA<W,@;F%M97,@2&]R9&5?:4-A;&5N9&%R7WAX
M>"!A<R!K97ES"B`@("`@*B`@("`@("`@("`@("`@("!A;F0@;G5M8F5R(&]F
M(&-O;7!O;F5N=',@;V8@=&AI<R!C;&%S<R!A<R!V86QU92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0V]M<&]N96YT0VQA<W-E<R@I"B`@("!["B`@("`@
M("`@)'(@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8V]M
M<&]N96YT<R!A<R`D8RD@>PH@("`@("`@("`@("`D8VX@/2!S=')T;VQO=V5R
M*&=E=%]C;&%S<R@D8RDI.PH@("`@("`@("`@("!I9B`H96UP='DH)');)&-N
M72DI('L*("`@("`@("`@("`@("`@("1R6R1C;ET@/2`Q.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)');)&-N72LK.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'(["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@8V]M<&]N96YT<R!I;B!T:&ES(&-O
M;G1A:6YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($YU;6)E
M<B!O9B!C;VUP;VYE;G1S(&EN('1H:7,@8V]N=&%I;F5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971#;VUP;VYE;G1#;W5N="@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&-O=6YT*"1T:&ES+3Y?8V]M<&]N96YT<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971R:65V92!A('-P96-I9FEC(&-O;7!O;F5N="X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:61X("!4:&4@:6YD97@@;V8@
M=&AE(&]B:F5C="!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("`@("AB;V]L96%N*2!&86QS92!I9B!T:&4@:6YD97@@9&]E<R!N
M;W0@97AI<W0N"B`@("`@*B`@("`@("`@("`@("`@("`@("A(;W)D95]I0V%L
M96YD87)?*BD@5&AE(')E<75E<W1E9"!C;VUP;VYE;G0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-O;7!O;F5N="@D:61X*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V-O;7!O;F5N='-;)&ED>%TI*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-O;7!O;F5N='-;)&ED>%T["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($QO8V%T97,@=&AE(&9I<G-T(&-H:6QD
M(&-O;7!O;F5N="!O9B!T:&4@<W!E8VEF:65D(&-L87-S+"!A;F0*("`@("`J
M(')E='5R;G,@82!R969E<F5N8V4@=&\@=&AI<R!C;VUP;VYE;G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE('1Y<&4@;V8@8V]M
M<&]N96YT('1O(&9I;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`H
M8F]O;&5A;BD@1F%L<V4@:68@;F\@<W5B8V]M<&]N96YT(&]F('1H92!S<&5C
M:69I960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-L87-S(&5X
M:7-T<RX*("`@("`J("`@("`@("`@("`@("`@*$AO<F1E7VE#86QE;F1A<E\J
M*2!!(')E9F5R96YC92!T;R!T:&4@<F5Q=65S=&5D(&-O;7!O;F5N="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F9I;F1#;VUP;VYE;G0H)&-H:6QD8VQA<W,I
M"B`@("!["B`@("`@("`@)&-H:6QD8VQA<W,@/2`G2&]R9&5?:4-A;&5N9&%R
M7R<@+B!3=')I;F<Z.FQO=V5R*"1C:&EL9&-L87-S*3L*("`@("`@("`D:V5Y
M<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]C;VUP;VYE;G1S*3L*("`@("`@("!F
M;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@(&EF("AI<U]A
M*"1T:&ES+3Y?8V]M<&]N96YT<ULD:V5Y72P@)&-H:6QD8VQA<W,I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUP;VYE;G1S6R1K97E=
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@=&AE(&E#86QE;F1A
M<B!O8FIE8W0@*')E<V5T<R!T:&4@8V]M<&]N96YT<R!A;F0@871T<FEB=71E
M<PH@("`@("H@87)R87ES*2X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87(H
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]M<&]N96YT<R`](&%R<F%Y*"D[
M"B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S(#T@87)R87DH*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!E;G1R>2!I<R!V8V%L96YD87(@
M,2XP+"!V8V%R9"`R+C$@;W(@=FYO=&4@,2XQ+@H@("`@("H*("`@("`J(%1H
M97-E("=O;&0G(&9O<FUA=',@87)E(&1E9FEN960@8GD@=W=W+FEM8RYO<F<N
M(%1H92`G;F5W)R`H;F]N+6]L9"D*("`@("`J(&9O<FUA=',@:6-A;&5N9&%R
M(#(N,"!A;F0@=F-A<F0@,RXP(&%R92!D969I;F5D(&EN(')F8S(T,C8@86YD
M(')F8S(T-#4*("`@("`J(')E<W!E8W1I=F5L>2X*("`@("`J"B`@("`@*B!`
M<VEN8V4@2&]R9&4@,RXQ+C(*("`@("`J+PH@("`@9G5N8W1I;VX@:7-/;&1&
M;W)M870H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;G1A:6YE<B`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&%I
M;F5R+3YI<T]L9$9O<FUA="@I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/F=E=%1Y<&4H*2`]/2`G=F-A<F0G*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W9E<G-I;VX@/"`S(#\@=')U92`Z(&9A;'-E.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'1H:7,M/F=E=%1Y<&4H*2`]/2`G=DYO=&4G*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9E<G-I;VX@/"`R(#\@=')U
M92`Z(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]V97)S
M:6]N(#X](#(I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X<&]R="!A<R!V0V%L96YD87(@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@("\O($1E9F%U
M;'0@=F%L=65S+@H@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)U!23T1)
M1"==(#T@)RTO+U1H92!(;W)D92!0<F]J96-T+R](;W)D95]I0V%L96YD87(@
M3&EB<F%R>2<@+B`H9&5F:6YE9"@G2$]21$5?5D524TE/3B<I(#\@)RP@2&]R
M9&4@)R`N(&-O;G-T86YT*"=(3U)$15]615)324].)RD@.B`G)RD@+B`G+R]%
M3B<["B`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG34542$]$)UT@/2`G
M4%5"3$E32"<["@H@("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T=')I8G5T
M97,@87,@)&YA;64@/3X@)&1E9F%U;'1?=F%L=64I('L*("`@("`@("`@("`@
M:68@*&ES7V$H)'1H:7,M/F=E=&%T=')I8G5T92@D;F%M92DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H
M)&YA;64L("1D969A=6QT7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AP;W)T=D1A=&$H)U9#04Q%
M3D1!4B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T('1H:7,@96YT
M<GD@87,@82!H87-H(&%R<F%Y('=I=&@@=&%G(&YA;65S(&%S(&ME>7,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!A<F%M<TEN2V5Y<PH@("`@
M("H@("`@("`@("`@("`@("`@268@9F%L<V4L('1H92!O<&5R871I;VX@8V%N
M(&)E('%U:71E(&QO<W-Y(&%S('1H90H@("`@("H@("`@("`@("`@("`@("`@
M<&%R86UE=&5R<R!A<F4@:6=N;W)E9"!W:&5N(&)U:6QD:6YG('1H92!A<G)A
M>2!K97ES+@H@("`@("H@("`@("`@("`@("`@("`@4V\@:68@>6]U(&5X<&]R
M="!A('9C87)D('=I=&@*("`@("`J("`@("`@("`@("`@("`@($Q!0D5,.U19
M4$4]5T]22SIF;V\*("`@("`J("`@("`@("`@("`@("`@($Q!0D5,.U194$4]
M2$]-13IB87(*("`@("`J("`@("`@("`@("`@("`@('1H92!R97-U;'1I;F<@
M:&%S:"!C;VYT86EN<R!O;FQY(&]N92!L86)E;"!F:65L9"$*("`@("`J("`@
M("`@("`@("`@("`@($EF('-E="!T;R!T<G5E+"!A<G)A>2!K97ES(&QO;VL@
M;&EK92`G3$%"14P[5%E013U73U)+)PH@("`@("H@0')E='5R;B!A<G)A>2`@
M02!H87-H(&%R<F%Y('=I=&@@=&%G(&YA;65S(&%S(&ME>7,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1O2&%S:"@D<&%R86US26Y+97ES(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)&AA<V@@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D82D@('L*("`@("`@("`@("`@)&L@
M/2`D85LG;F%M92==.PH@("`@("`@("`@("!I9B`H)'!A<F%M<TEN2V5Y<R`F
M)B!I<U]A<G)A>2@D85LG<&%R86US)UTI*2!["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D85LG<&%R86US)UT@87,@)'`@/3X@)'8I('L*("`@("`@("`@
M("`@("`@("`@("`D:R`N/2`B.R1P/21V(CL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D:&%S:%LD:UT@/2`D85LG=F%L
M=64G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:&%S:#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%!A<G-E<R!A('-T<FEN9R!C;VYT86EN:6YG('9#
M86QE;F1A<B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@("`@(%1H92!D871A('1O('!A<G-E+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8F%S92`@("`@5&AE('1Y<&4@;V8@=&AE(&)A<V4@;V)J96-T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&5N8V]D:6YG(&-H87)S
M970@9F]R("1T97AT+B!$969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@=71F+3@N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8VQE
M87(@("!)9B!T<G5E(&-L96%R<R!T:&4@:4-A;"!O8FIE8W0@8F5F;W)E('!A
M<G-I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('-U8V-E<W-F=6P@:6UP;W)T+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1T97AT+"`D8F%S92`]("=6
M0T%,14Y$05(G+"`D8VAA<G-E="`]("=U=&8M."<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8VQE87(@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF
M("@D8VQE87(I('L*("`@("`@("`@("`@)'1H:7,M/F-L96%R*"D["B`@("`@
M("`@?0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*$)%1TE..B<@+B`D8F%S
M92`N("=<<C]<;C\I*%M<5UQW72HI*$5.1#HG("X@)&)A<V4@+B`G7'(_7&X_
M*2]I)RP@)'1E>'0L("1M871C:&5S*2D@>PH@("`@("`@("`@("`D=D-A;"`]
M("1M871C:&5S6S)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M(%1E>'0@:7-N)W0@96YC;&]S960@:6X@0D5'24XZ5D-!3$5.1$%2"B`@("`@
M("`@("`@("\O("XN($5.1#I60T%,14Y$05(N(%=E)VQL('1R>2!T;R!P87)S
M92!I="!A;GEW87DN"B`@("`@("`@("`@("1V0V%L(#T@)'1E>'0["B`@("`@
M("`@?0H*("`@("`@("`O+R!!;&P@<W5B8V]M<&]N96YT<RX*("`@("`@("`D
M;6%T8VAE<R`](&YU;&P["B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O
M0D5'24XZ*%M<5UQW72HI*%QR7&Y\7')\7&XI*%M<5UQW72HI14Y$.EPQ*%QR
M7&Y\7')\7&XI+U5I)RP@)'9#86PL("1M871C:&5S*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D;6%T8VAE<ULP72!A<R`D:V5Y(#T^("1D871A*2!["B`@
M("`@("`@("`@("`@("`D='EP92`]('1R:6TH)&UA=&-H97-;,5U;)&ME>5TI
M.PH@("`@("`@("`@("`@("`@)&-O;7!O;F5N="`]("9(;W)D95]I0V%L96YD
M87(Z.FYE=T-O;7!O;F5N="@D='EP92P@)'1H:7,I.PH@("`@("`@("`@("`@
M("`@:68@*"1C;VUP;VYE;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E5N86)L92!T;R!C<F5A
M=&4@;V)J96-T(&9O<B!T>7!E("1T>7!E(BD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D8V]M<&]N96YT+3YP87)S979#86QE;F1A<B@D
M9&%T82D["@H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$-O;7!O;F5N="@D
M8V]M<&]N96YT*3L*"B`@("`@("`@("`@("`@("`O+R!296UO=F4@9G)O;2!T
M:&4@=D-A;&5N9&%R(&1A=&$N"B`@("`@("`@("`@("`@("`D=D-A;"`]('-T
M<E]R97!L86-E*"1D871A+"`G)RP@)'9#86PI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!5;F9O;&0@86YY(&9O;&1E9"!L:6YE<RX*
M("`@("`@("`D=D-A;"`]('!R96=?<F5P;&%C92@G+UM<<EQN72M;(%QT72\G
M+"`G)RP@)'9#86PI.PH*("`@("`@("`O+R!5;F9O;&0@(G%U;W1E9"!P<FEN
M=&%B;&4B(&9O;&1E9"!L:6YE<R!L:6ME.@H@("`@("`@("\O("!"3T19.T5.
M0T]$24Y'/5%53U1%1"U04DE.5$%"3$4Z/0H@("`@("`@("\O("!A;F]T:&5R
M/3(P;&EN93T*("`@("`@("`O+R`@;&%S=#TR,&QI;F4*("`@("`@("!W:&EL
M92`H<')E9U]M871C:%]A;&PH)R]>*%M>.ETK.UQS*D5.0T]$24Y'/5%53U1%
M1"U04DE.5$%"3$4H+BH]7'(_7&XI*R@N*EM>/5TI/UQR/UQN*2]M52<L("1V
M0V%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&UA=&-H
M97-;,5T@87,@)',I('L*("`@("`@("`@("`@("`@("1R(#T@<')E9U]R97!L
M86-E*"<O/5QR/UQN+R<L("<G+"`D<RD["B`@("`@("`@("`@("`@("`D=D-A
M;"`]('-T<E]R97!L86-E*"1S+"`D<BP@)'9#86PI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!087)S92!T:&4@<F5M86EN:6YG(&%T
M=')I8G5T97,N"B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O*"XJ*3HH
M6UY<<EQN72HI6UQR7&Y=*R\G+"`D=D-A;"P@)&UA=&-H97,I*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1M871C:&5S6S!=(&%S("1A='1R:6)U=&4I('L*
M("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)R\H6UX[7CI=*BDH*#M;7CI=
M*BD_*3HH6UY<<EQN72HI6UQR7&Y=*B\G+"`D871T<FEB=71E+"`D<&%R=',I
M.PH@("`@("`@("`@("`@("`@)'1A9R`](%-T<FEN9SHZ=7!P97(H)'!A<G1S
M6S%=*3L*("`@("`@("`@("`@("`@("1V86QU92`]("1P87)T<ULT73L*("`@
M("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@
M("`@("\O(%!A<G-E('!A<F%M971E<G,N"B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1P87)T<ULR72DI('L*("`@("`@("`@("`@("`@("`@("!P<F5G
M7VUA=&-H7V%L;"@G+SLH*%M>.SU=*BDH/2A;7CM=*BDI/RDO)RP@)'!A<G1S
M6S)=+"`D<&%R86U?<&%R=',I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P87)A;5]P87)T<ULR72!A<R`D:V5Y(#T^("1P87)A;4YA;64I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M5F%L=64@/2`D<&%R86U?
M<&%R='-;-%U;)&ME>5T["B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A
M;7-;4W1R:6YG.CIU<'!E<B@D<&%R86U.86UE*5T@/2`D<&%R86U686QU93L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@+R\@0VAA<G-E="!A;F0@96YC;V1I;F<@:&%N9&QI;F<N
M"B`@("`@("`@("`@("`@("!I9B`H*&ES<V5T*"1P87)A;7-;)T5.0T]$24Y'
M)UTI"B`@("`@("`@("`@("`@("`@("`@("8F(%-T<FEN9SHZ=7!P97(H)'!A
M<F%M<ULG14Y#3T1)3D<G72D@/3T@)U%53U1%1"U04DE.5$%"3$4G*0H@("`@
M("`@("`@("`@("`@("`@('Q\(&ES<V5T*"1P87)A;7-;)U%53U1%1"U04DE.
M5$%"3$4G72DI('L*"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<75O
M=&5D7W!R:6YT86)L95]D96-O9&4H)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("`@("`O+R!1=6]T960@<')I;G1A8FQE(&ES(&YO<FUA;&QY(&5N8V]D960@
M87,@=71F+3@N"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A
M;7-;)T-(05)3150G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1P87)A;7-;
M)T-(05)3150G72D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D=F%L=64L("=U=&8M."<I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<&%R86US6R=#
M2$%24T54)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1P87)A;7-;)T-(05)3150G
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("\O($%S('!E<B!21D,@,C(W.2P@87-S=6UE(%541C@@:68@=V4@9&]N
M)W0@:&%V92!A;@H@("`@("`@("`@("`@("`@("`@("\O(&5X<&QI8VET(&-H
M87)S970@<&%R86UE=&5R+@H@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"`D8VAA<G-E="D["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@<W=I=&-H("@D=&%G
M*2!["B`@("`@("`@("`@("`@("`O+R!$871E(&9I96QD<RX*("`@("`@("`@
M("`@("`@(&-A<V4@)T-/35!,151%1"<Z"B`@("`@("`@("`@("`@("!C87-E
M("=#4D5!5$5$)SH*("`@("`@("`@("`@("`@(&-A<V4@)TQ!4U0M34]$249)
M140G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H
M)'1A9RP@)'1H:7,M/E]P87)S941A=&54:6UE*"1V86QU92DL("1P87)A;7,I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)T)$05DG.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!
M='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A=&4H)'9A;'5E*2P@)'!A
M<F%M<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G1%1%3D0G.@H@("`@("`@("`@("`@("`@8V%S92`G1%13
M5$%25"<Z"B`@("`@("`@("`@("`@("!C87-E("=$5%-404U0)SH*("`@("`@
M("`@("`@("`@(&-A<V4@)T1512<Z"B`@("`@("`@("`@("`@("!C87-E("=!
M04Q!4DTG.@H@("`@("`@("`@("`@("`@8V%S92`G4D5#55)214Y#12U)1"<Z
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)U9!3%5%
M)UTI("8F("1P87)A;7-;)U9!3%5%)UT@/3T@)T1!5$4G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'1H
M:7,M/E]P87)S941A=&4H)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$%T=')I8G5T92@D=&%G+"`D=&AI<RT^7W!A<G-E1&%T951I;64H
M)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)U1224='15(G.@H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R=604Q512==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)'!A<F%M<ULG5D%,544G72`]/2`G1$%412U424U%)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"`D
M=&AI<RT^7W!A<G-E1&%T951I;64H)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1T:&ES+3Y?
M<&%R<V5$=7)A=&EO;B@D=F%L=64I+"`D<&%R86US*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A
M9RP@)'1H:7,M/E]P87)S941U<F%T:6]N*"1V86QU92DL("1P87)A;7,I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("`O+R!#;VUM82!S97!E<F%T960@9&%T97,N
M"B`@("`@("`@("`@("`@("!C87-E("=%6$1!5$4G.@H@("`@("`@("`@("`@
M("`@8V%S92`G4D1!5$4G.@H@("`@("`@("`@("`@("`@("`@("1D871E<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@<')E9U]M871C:%]A;&PH
M)R\L*%M>+%TJ*2\G+"`G+"<@+B`D=F%L=64L("1V86QU97,I.PH*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=65S6S%=(&%S("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;72`]("1T:&ES+3Y?
M<&%R<V5$871E*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@:7-S
M970H)&1A=&5S6S!=*2`_("1D871E<ULP72`Z(&YU;&PL("1P87)A;7,L('1R
M=64L("1D871E<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@+R\@1'5R871I;VX@9FEE;&1S+@H@("`@("`@("`@("`@
M("`@8V%S92`G1%52051)3TXG.@H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941U<F%T:6]N*"1V
M86QU92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@("\O(%!E<FEO9"!O9B!T:6UE(&9I96QD<RX*("`@
M("`@("`@("`@("`@(&-A<V4@)T92145"55-9)SH*("`@("`@("`@("`@("`@
M("`@("`D<&5R:6]D<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@
M<')E9U]M871C:%]A;&PH)R\L*%M>+%TJ*2\G+"`G+"<@+B`D=F%L=64L("1V
M86QU97,I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU97-;
M,5T@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P97)I
M;V1S6UT@/2`D=&AI<RT^7W!A<G-E4&5R:6]D*"1V86QU92D["B`@("`@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M071T<FEB=71E*"1T86<L(&ES<V5T*"1P97)I;V1S6S!=*2`_("1P97)I;V1S
M6S!=(#H@;G5L;"P@)'!A<F%M<RP@=')U92P@)'!E<FEO9',I.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("\O(%540R!O
M9F9S970@9FEE;&1S+@H@("`@("`@("`@("`@("`@8V%S92`G5%I/1D93151&
M4D]-)SH*("`@("`@("`@("`@("`@(&-A<V4@)U1:3T9&4T545$\G.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'1H
M:7,M/E]P87)S955T8T]F9G-E="@D=F%L=64I+"`D<&%R86US*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!);G1E
M9V5R(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A<V4@)U!%4D-%3E0M0T]-
M4$Q%5$4G.@H@("`@("`@("`@("`@("`@8V%S92`G4%))3U))5%DG.@H@("`@
M("`@("`@("`@("`@8V%S92`G4D5014%4)SH*("`@("`@("`@("`@("`@(&-A
M<V4@)U-%455%3D-%)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M071T<FEB=71E*"1T86<L(&EN='9A;"@D=F%L=64I+"`D<&%R86US*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!'
M96\@9FEE;&1S+@H@("`@("`@("`@("`@("`@8V%S92`G1T5/)SH*("`@("`@
M("`@("`@("`@("`@("`D9FQO871S(#T@97AP;&]D92@G.R<L("1V86QU92D[
M"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=L871I='5D92==(#T@9FQO
M871V86PH)&9L;V%T<ULP72D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M6R=L;VYG:71U9&4G72`](&9L;V%T=F%L*"1F;&]A='-;,5TI.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'9A;'5E
M+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("`O+R!296-U<G-I;VX@9FEE;&1S+@H@("`@("`@("`@("`@
M("`@8V%S92`G15A254Q%)SH*("`@("`@("`@("`@("`@(&-A<V4@)U)254Q%
M)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T
M86<L('1R:6TH)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@0412+"!A;F0@3B!A<F4@
M;&ES=',@<V5P97)A=&5D(&)Y('5N97-C87!E9`H@("`@("`@("`@("`@("`@
M+R\@<V5M:6-O;&]N<R!W:71H(&$@<W!E8VEF:6,@;G5M8F5R(&]F('-L;W1S
M+@H@("`@("`@("`@("`@("`@8V%S92`G0412)SH*("`@("`@("`@("`@("`@
M(&-A<V4@)TXG.@H@("`@("`@("`@("`@("`@("`@("1V86QU92`]('1R:6TH
M)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`O+R!!<R!O9B!R9F,@,C0R
M-B`R+C0N,B!S96UI8V]L;VXL(&-O;6UA+"!A;F0*("`@("`@("`@("`@("`@
M("`@("`O+R!C;VQO;B!M=7-T(&)E(&5S8V%P960@*&-O;6UA(&ES('5N97-C
M87!E9"!A9G1E<@H@("`@("`@("`@("`@("`@("`@("\O('-P;&ET=&EN9R!B
M96QO=RDN"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA
M8V4H87)R87DH)UQ<;B<L("=<7#LG+"`G7%PZ)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M/E]N97=L
M:6YE+"`G.R<L("<Z)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E*3L*"B`@("`@("`@("`@("`@("`@("`@+R\@
M4W!L:70@8GD@=6YE<V-A<&5D('-E;6EC;VQO;G,Z"B`@("`@("`@("`@("`@
M("`@("`@)'9A;'5E<R`]('!R96=?<W!L:70H)R\H/SPA7%Q<7"D[+R<L("1V
M86QU92D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA
M8V4H)UQ<.R<L("<[)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`D
M=F%L=65S(#T@<W1R7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A;'5E<RD["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"!T
M<FEM*"1V86QU92DL("1P87)A;7,L('1R=64L("1V86QU97,I.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("\O($]21R!I
M<R!A(&QI<W0@<V5P97)A=&5D(&)Y('5N97-C87!E9"!S96UI8V]L;VYS(&)U
M=`H@("`@("`@("`@("`@("`@+R\@=VET:"!N;R!E;7!T>2!V86QU97,N"B`@
M("`@("`@("`@("`@("!C87-E("=/4D<G.@H@("`@("`@("`@("`@("`@("`@
M("1V86QU92`]('1R:6TH)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`O
M+R!!<R!O9B!R9F,@,C0R-B`R+C0N,B!S96UI8V]L;VXL(&-O;6UA+"!A;F0*
M("`@("`@("`@("`@("`@("`@("`O+R!C;VQO;B!M=7-T(&)E(&5S8V%P960@
M*&-O;6UA(&ES('5N97-C87!E9"!A9G1E<@H@("`@("`@("`@("`@("`@("`@
M("\O('-P;&ET=&EN9R!B96QO=RDN"B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@<W1R7W)E<&QA8V4H87)R87DH)UQ<;B<L("=<7#LG+"`G7%PZ)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)'1H:7,M/E]N97=L:6YE+"`G.R<L("<Z)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E*3L*"B`@("`@("`@
M("`@("`@("`@("`@+R\@4W!L:70@8GD@=6YE<V-A<&5D('-E;6EC;VQO;G,Z
M"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E<R`]('!R96=?<W!L:70H)R\H
M/SPA7%Q<7"D[+R<L("1V86QU92P@+3$L(%!214=?4U!,251?3D]?14U05%DI
M.PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*"=<
M7#LG+"`G.R<L("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M<R`]('-T<E]R97!L86-E*"=<7#LG+"`G.R<L("1V86QU97,I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@=')I;2@D
M=F%L=64I+"`D<&%R86US+"!T<G5E+"`D=F%L=65S*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!3=')I;F<@9FEE
M;&1S+@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/FES3VQD1F]R;6%T*"DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@=F-A;&5N9&%R(#$N,"!A;F0@=F-A<F0@,BXQ(&]N
M;'D@97-C87!E('-E;6EC;VQO;G,*("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@86YD('5S92!U;F5S8V%P960@<V5M:6-O;&]N<R!T;R!C<F5A=&4@;&ES
M=',N"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]('1R:6TH)'9A
M;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@4W!L:70@8GD@=6YE
M<V-A<&5D('-E;6EC;VQO;G,Z"B`@("`@("`@("`@("`@("`@("`@("`@("1V
M86QU97,@/2!P<F5G7W-P;&ET*"<O*#\\(5Q<7%PI.R\G+"`D=F%L=64I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92@G
M7%P[)RP@)SLG+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=65S(#T@<W1R7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A;'5E<RD["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A
M9RP@=')I;2@D=F%L=64I+"`D<&%R86US+"!T<G5E+"`D=F%L=65S*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=64@/2!T<FEM*"1V86QU92D["B`@("`@("`@("`@("`@("`@
M("`@("`@("\O($%S(&]F(')F8R`R-#(V(#(N-"XR('-E;6EC;VQO;BP@8V]M
M;6$L(&%N9`H@("`@("`@("`@("`@("`@("`@("`@("`O+R!C;VQO;B!M=7-T
M(&)E(&5S8V%P960@*&-O;6UA(&ES('5N97-C87!E9"!A9G1E<@H@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!S<&QI='1I;F<@8F5L;W<I+@H@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92AA<G)A>2@G
M7%QN)RP@)UQ<.R<L("=<7#HG*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M/E]N97=L:6YE+"`G
M.R<L("<Z)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V86QU92D["@H@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!3<&QI="!B>2!U;F5S8V%P960@8V]M;6%S.@H@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=65S(#T@<')E9U]S<&QI="@G+R@_/"%<7%Q<*2PO)RP@
M)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R
M7W)E<&QA8V4H)UQ<+"<L("<L)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E<R`]('-T<E]R97!L86-E*"=<7"PG+"`G+"<L("1V
M86QU97,I.PH*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T
M=')I8G5T92@D=&%G+"!T<FEM*"1V86QU92DL("1P87)A;7,L('1R=64L("1V
M86QU97,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!%>'!O<G0@=&AI<R!C;VUP;VYE;G0@:6X@=D-A;"!F;W)M870N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F%S92`@5&AE('1Y<&4@
M;V8@=&AE(&)A<V4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!V0V%L(&9O<FUA="!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M97AP;W)T=D1A=&$H)&)A<V4@/2`G5D-!3$5.1$%2)RD*("`@('L*("`@("`@
M("`D<F5S=6QT(#T@)T)%1TE..B<@+B!3=')I;F<Z.G5P<&5R*"1B87-E*2`N
M("1T:&ES+3Y?;F5W;&EN93L*"B`@("`@("`@+R\@5D524TE/3B!I<R!N;W0@
M86QL;W=E9"!F;W(@96YT<FEE<R!E;F-L;W-E9"!I;B!60T%,14Y$05(O24-!
M3$5.1$%2+`H@("`@("`@("\O(&%S(&ET(&ES('!A<G0@;V8@=&AE(&5N8VQO
M<VEN9R!60T%,14Y$05(O24-!3$5.1$%2+B!3964@<F9C,C0T-0H@("`@("`@
M(&EF("@D8F%S92`A/3T@)U9%5D5.5"<@)B8@)&)A<V4@(3T]("=65$]$3R<@
M)B8@)&)A<V4@(3T]("=604Q!4DTG("8F"B`@("`@("`@("`@("1B87-E("$]
M/2`G5DI/55).04PG("8F("1B87-E("$]/2`G5D92145"55-9)RD@>PH@("`@
M("`@("`@("`O+R!%;G-U<F4@=&AA="!V97)S:6]N(&ES('1H92!F:7)S="!A
M='1R:6)U=&4N"B`@("`@("`@("`@("1R97-U;'0@+CT@)U9%4E-)3TXZ)R`N
M("1T:&ES+3Y?=F5R<VEO;B`N("1T:&ES+3Y?;F5W;&EN93L*("`@("`@("!]
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1A='1R
M:6)U=&4I('L*("`@("`@("`@("`@)&YA;64@/2`D871T<FEB=71E6R=N86UE
M)UT["B`@("`@("`@("`@(&EF("@D;F%M92`]/2`G5D524TE/3B<I('L*("`@
M("`@("`@("`@("`@("\O($%L<F5A9'D@9&]N92X*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&%R86US
M7W-T<B`]("<G.PH@("`@("`@("`@("`D<&%R86US(#T@)&%T=')I8G5T95LG
M<&%R86US)UT["B`@("`@("`@("`@(&EF("@D<&%R86US*2!["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;5]N86UE(#T^("1P
M87)A;5]V86QU92D@>PH@("`@("`@("`@("`@("`@("`@("\O(%-K:7`@0TA!
M4E-%5"!F;W(@:4-A;&5N9&%R(#(N,"!D871A+"!N;W0*("`@("`@("`@("`@
M("`@("`@("`O+R!A;&QO=V5D+@H@("`@("`@("`@("`@("`@("`@(&EF("@D
M<&%R86U?;F%M92`]/2`G0TA!4E-%5"<@)B8@(21T:&ES+3YI<T]L9$9O<FUA
M="@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D<&%R86US
M7W-T<B`N/2`B.R1P87)A;5]N86UE/21P87)A;5]V86QU92(["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1V86QU92`]
M("1A='1R:6)U=&5;)W9A;'5E)UT["B`@("`@("`@("`@('-W:71C:"`H)&YA
M;64I('L*("`@("`@("`@("`@+R\@1&%T92!F:65L9',N"B`@("`@("`@("`@
M(&-A<V4@)T-/35!,151%1"<Z"B`@("`@("`@("`@(&-A<V4@)T-214%4140G
M.@H@("`@("`@("`@("!C87-E("=$0U)%051%1"<Z"B`@("`@("`@("`@(&-A
M<V4@)TQ!4U0M34]$249)140G.@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M)'1H:7,M/E]E>'!O<G1$871E5&EM92@D=F%L=64I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=$5$5.1"<Z"B`@("`@("`@
M("`@(&-A<V4@)T144U1!4E0G.@H@("`@("`@("`@("!C87-E("=$5%-404U0
M)SH*("`@("`@("`@("`@8V%S92`G1%5%)SH*("`@("`@("`@("`@8V%S92`G
M04%,05)-)SH*("`@("`@("`@("`@8V%S92`G4D5#55)214Y#12U)1"<Z"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG5D%,544G72DI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G
M1$%412<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H
M:7,M/E]E>'!O<G1$871E*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H
M:7,M/E]E>'!O<G1$871E5&EM92@D=F%L=64I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'9A;'5E(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92@D=F%L=64I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`O+R!#;VUM82!S97!E<F%T960@9&%T97,N"B`@("`@("`@
M("`@(&-A<V4@)T581$%412<Z"B`@("`@("`@("`@(&-A<V4@)U)$051%)SH*
M("`@("`@("`@("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D=F%L=64@87,@)&1A=&4I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG5D%,544G72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1P87)A;7-;)U9!3%5%)UT@/3T@)T1!
M5$4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;72`]
M("1T:&ES+3Y?97AP;W)T1&%T92@D9&%T92D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@D<&%R86US6R=604Q512==(#T]("=015))3T0G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;72`]("1T
M:&ES+3Y?97AP;W)T4&5R:6]D*"1D871E*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871E<UM=(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92@D9&%T92D["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;72`]("1T:&ES
M+3Y?97AP;W)T1&%T951I;64H)&1A=&4I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V86QU92`]
M(&EM<&QO9&4H)RPG+"`D9&%T97,I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=44DE'1T52)SH*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=604Q512==*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D<&%R86US6R=604Q512==(#T]("=$051%+51)344G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP
M;W)T1&%T951I;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G1%52051)3TXG*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T1'5R
M871I;VXH)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M("1T:&ES+3Y?97AP;W)T1'5R871I;VXH)'9A;'5E*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@
M1'5R871I;VX@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=$55)!5$E/3B<Z
M"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V5X<&]R=$1U<F%T
M:6]N*"1V86QU92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("\O(%!E<FEO9"!O9B!T:6UE(&9I96QD<RX*("`@("`@("`@("`@8V%S
M92`G1E)%14)54UDG.@H@("`@("`@("`@("`@("`@)'9A;'5E7W-T<B`]("<G
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1P97)I;V0I
M('L*("`@("`@("`@("`@("`@("`@("`D=F%L=65?<W1R("X](&5M<'1Y*"1V
M86QU95]S='(I(#\@)R<@.B`G+"<["B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E7W-T<B`N/2`D=&AI<RT^7V5X<&]R=%!E<FEO9"@D<&5R:6]D*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V86QU92`]("1V86QU
M95]S='(["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O
M(%540R!O9F9S970@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=46D]&1E-%
M5$923TTG.@H@("`@("`@("`@("!C87-E("=46D]&1E-%5%1/)SH*("`@("`@
M("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T571C3V9F<V5T*"1V
M86QU92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O
M($EN=&5G97(@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=015)#14Y4+4-/
M35!,151%)SH*("`@("`@("`@("`@8V%S92`G4%))3U))5%DG.@H@("`@("`@
M("`@("!C87-E("=215!%050G.@H@("`@("`@("`@("!C87-E("=315%514Y#
M12<Z"B`@("`@("`@("`@("`@("`D=F%L=64@/2`B)'9A;'5E(CL*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@1V5O(&9I96QD<RX*
M("`@("`@("`@("`@8V%S92`G1T5/)SH*("`@("`@("`@("`@("`@("1V86QU
M92`]("1V86QU95LG;&%T:71U9&4G72`N("<L)R`N("1V86QU95LG;&]N9VET
M=61E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O
M(%)E8W5R<F5N8V4@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=%6%)53$4G
M.@H@("`@("`@("`@("!C87-E("=24E5,12<Z"B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("\O($%T=&5N9&%N8V4*("`@("`@("`@("`@
M8V%S92`G051414Y$144G.@H@("`@("`@("`@("`@("`@+R\@2W)O;F]L:71H
M(&-R96%T97,@871T96YD964@9FEE;&0@:6X@=F-A;&5N9&%R,BXP(&9O<FUA
M="X*("`@("`@("`@("`@("`@("\O($-O;G9E<G0@=&\@=F-A;&5N9&%R,2XP
M(&EF(&YE8V5S<V%R>2X*("`@("`@("`@("`@("`@("\O($5X86UP;&4@;V8@
M,2XP('-T>6QE.@H@("`@("`@("`@("`@("`@+R\@051414Y$144[4D],13U/
M5TY%4CM35$%455,]0T].1DE2345$.DIO:&X@4VUI=&@@/&IS;6ET:$!H;W-T
M,2YC;VT^"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES3VQD1F]R;6%T
M*"DI('L*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!P<F5G7W)E<&QA
M8V4H)R]-04E,5$\Z+R<L("<G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@
M("`@("1V86QU92`]("`D=F%L=64@+B`G(#PG("X@)'9A;'5E("X@)SXG.PH@
M("`@("`@("`@("`@("`@("`@("1P87)A;7-?<W1R(#T@<W1R7W)E<&QA8V4H
M)U!!4E135$%4/2<L("=35$%455,])RP@)'!A<F%M<U]S='(I.PH@("`@("`@
M("`@("`@("`@("`@("1P87)A;7-?<W1R(#T@<W1R7W)E<&QA8V4H)U-40515
M4SU.145$4RU!0U1)3TXG+"`G4U1!5%53/4Y%1413($%#5$E/3B<L("1P87)A
M;7-?<W1R*3L*("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T<B`]('-T
M<E]R97!L86-E*"=23TQ%/5)%42U005)424-)4$%.5"<L("=%6%!%0U0]4D51
M54E212<L("1P87)A;7-?<W1R*3L*("`@("`@("`@("`@("`@("`@("`D<&%R
M86US7W-T<B`]('-T<E]R97!L86-E*"=23TQ%/4]05"U005)424-)4$%.5"<L
M("=%6%!%0U0]4D5154535"<L("1P87)A;7-?<W1R*3L*("`@("`@("`@("`@
M("`@("`@("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=23TQ%/4Y/3BU0
M05)424-)4$%.5"<L("=%6%!%0U0]1EE))RP@)'!A<F%M<U]S='(I.PH@("`@
M("`@("`@("`@("`@("`@("1P87)A;7-?<W1R(#T@<W1R7W)E<&QA8V4H)U)3
M5E`]5%)512<L("=24U90/5E%4R<L("1P87)A;7-?<W1R*3L*("`@("`@("`@
M("`@("`@("`@("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=24U90/49!
M3%-%)RP@)U)35E`]3D\G+"`D<&%R86US7W-T<BD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-/;&1&;W)M870H*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D871T<FEB=71E
M6R=V86QU97,G72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("8F(&-O
M=6YT*"1A='1R:6)U=&5;)W9A;'5E<R==*3XQ*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1V86QU97,@/2`D871T<FEB=71E6R=V86QU97,G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1N86UE(#T]("=.)R!\?"`D;F%M
M92`]/2`G0412)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=L
M=64@/2`G.R<["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9VQU92`]("<L)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=65S("`]('-T<E]R97!L86-E*&%R<F%Y*"<[)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=<7#LG
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E<RD["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M(&EM<&QO9&4H)&=L=64L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("\J('9C87)D(#(N
M,2!A;F0@=F-A;&5N9&%R(#$N,"!E<V-A<&4@;VYL>0H@("`@("`@("`@("`@
M("`@("`@("`@("`@*B!S96UI8V]L;VYS("HO"B`@("`@("`@("`@("`@("`@
M("`@("`@("1V86QU92`]('-T<E]R97!L86-E*&%R<F%Y*"<[)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=<7#LG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1N86UE(#T]("=35$%455,G*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\O('9C86QE;F1A<B`Q+C`@:&%S(%-40515
M4SI.145$4R!!0U1)3TX@=VAI;&4@,BXP(&AA<PH@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!35$%455,Z3D5%1%,M04-424].+@H@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92@G3D5%1%,M04-424].
M)RP@)TY%1413($%#5$E/3B<L("1V86QU92D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("\O(%1E>'0@8V]N=&%I;FEN9R!N
M97=L:6YE<R!O<B!!4T-)22`^/2`Q,C<@;75S="!B92!"05-%-C0*("`@("`@
M("`@("`@("`@("`@("`O+R!O<B!154]4140M4%))3E1!0DQ%(&5N8V]D960N
M($-U<G)E;G1L>2!W92!U<V4*("`@("`@("`@("`@("`@("`@("`O+R!154]4
M140M4%))3E1!0DQ%(&%S(&1E9F%U;'0N"B`@("`@("`@("`@("`@("`@("`@
M+R\@1DE8344Z(&1E86P@=VET:"!B87-E-C0@96YC;V1I;F=S(0H@("`@("`@
M("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O6UY<>#(P+5QX-T9=+R(L
M("1V86QU92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("8F(&5M<'1Y
M*"1P87)A;7-;)T5.0T]$24Y')UTI*2`@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86US6R=%3D-/1$E.1R==(#T@)U%53U1%1"U04DE.5$%"3$4G
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T<B`N/2`G.T5.
M0T]$24Y'/5%53U1%1"U04DE.5$%"3$4G.PH@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!!9&0@0TA!4E-%5"!A<R!W96QL+B!!="!L96%S="!T:&4@<WEN
M=&AE<VES(&-L:65N=`H@("`@("`@("`@("`@("`@("`@("`@("`O+R!G971S
M(&-O;F9U<V5D(&]T:&5R=VES90H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)'!A<F%M<ULG0TA!4E-%5"==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M<ULG0T%24T54)UT@/2!.3%,Z.F=E=$-H
M87)S970H*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7-?
M<W1R("X]("<[0TA!4E-%5#TG("X@)'!A<F%M<ULG0T%24T54)UT["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D871T<FEB=71E6R=V86QU97,G72D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("8F(&-O=6YT*"1A='1R:6)U=&5;)W9A;'5E<R==
M*3XQ*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2`D871T
M<FEB=71E6R=V86QU97,G73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1N86UE(#T]("=.)R!\?"`D;F%M92`]/2`G0412)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&=L=64@/2`G.R<["B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9VQU92`]("<L)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%L=65S(#T@<W1R7W)E<&QA8V4H87)R
M87DH)SLG+"`G.B<L("<L)RP@)TU!24Q43UQ<.B<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G7%P[)RP@
M)UQ<.B<L("=<7"PG+"`G34%)3%1/.B<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E(#T@:6UP;&]D92@D9VQU92P@)'9A;'5E
M<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@07,@;V8@<F9C(#(T,C8@,BXT+C(@<V5M:6-O;&]N
M+"!C;VUM82P@86YD(&-O;&]N"B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&UU<W0@8F4@97-C87!E9"X@17AC;'5D92!-04E,5$\Z('1H;W5G:"X@5&AI
M<R!I<R!A"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&AA8VLA"B`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*&%R<F%Y
M*"<[)RP@)SHG+"`G+"<L("=-04E,5$]<7#HG*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)UQ<.R<L("=<
M7#HG+"`G7%PL)RP@)TU!24Q43SHG*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M<&%R86US6R=%3D-/1$E.1R==*2`F)@H@("`@("`@("`@("`@("`@)'!A<F%M
M<ULG14Y#3T1)3D<G72`]/2`G455/5$5$+5!224Y404),12<@)B8@<W1R;&5N
M*'1R:6TH)'9A;'5E*2D@/B`P*2!["B`@("`@("`@("`@("`@("`O*B!Q=6]T
M9610<FEN=&%B;&5%;F-O9&4@9&]E<R!N;W0@97-C87!E($-23$9S+"!B=70@
M<W1R86YG90H@("`@("`@("`@("`@("`@("H@96YO=6=H('-I;F=L92!,1G,N
M('-O(&-O;G9E<G0@979E<GET:&EN9R!T;R!,1B!O;FQY(&%N9`H@("`@("`@
M("`@("`@("`@("H@<F5P;&%C92!A9G1E<G=A<F1S+B`J+PH@("`@("`@("`@
M("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H(EQR(BP@)R<L("1V86QU92D[
M"B`@("`@("`@("`@("`@("`D<F5S=6QT("X]("(D;F%M921P87)A;7-?<W1R
M.CTB("X@)'1H:7,M/E]N97=L:6YE"B`@("`@("`@("`@("`@("`@("`@+B!S
M=')?<F5P;&%C92@G/3!!)RP@)STP1#TP02<L("1T:&ES+3Y?<75O=&5D4')I
M;G1A8FQE16YC;V1E*"1V86QU92DI"B`@("`@("`@("`@("`@("`@("`@+B`D
M=&AI<RT^7VYE=VQI;F4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D871T<E]S=')I;F<@/2`B)&YA;64D<&%R86US7W-T<CHD=F%L
M=64B.PH@("`@("`@("`@("`@("`@)')E<W5L="`N/2`D=&AI<RT^7V9O;&1,
M:6YE*"1A='1R7W-T<FEN9RD@+B`D=&AI<RT^7VYE=VQI;F4["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8V]M
M<&]N96YT<R!A<R`D8V]M<&]N96YT*2!["B`@("`@("`@("`@("1R97-U;'0@
M+CT@)&-O;7!O;F5N="T^97AP;W)T=D-A;&5N9&%R*"D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')E<W5L="`N("=%3D0Z)R`N("1B87-E("X@)'1H
M:7,M/E]N97=L:6YE.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@82!5
M5$,@3V9F<V5T(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V55
M=&-/9F9S970H)'1E>'0I"B`@("!["B`@("`@("`@)&]F9G-E="`](&%R<F%Y
M*"D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H7"M\+2DH6S`M.5U[,GTI
M*%LP+3E=>S)]*2A;,"TY77LR?2D_+R<L("1T97AT+"`D=&EM95!A<G1S*2D@
M>PH@("`@("`@("`@("`D;V9F<V5T6R=A:&5A9"==("`]("AB;V]L*2@D=&EM
M95!A<G1S6S%=(#T]("<K)RD["B`@("`@("`@("`@("1O9F9S971;)VAO=7(G
M72`@(#T@:6YT=F%L*"1T:6UE4&%R='-;,ETI.PH@("`@("`@("`@("`D;V9F
M<V5T6R=M:6YU=&4G72`](&EN='9A;"@D=&EM95!A<G1S6S-=*3L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:6UE4&%R='-;-%TI*2!["B`@("`@("`@("`@
M("`@("`D;V9F<V5T6R=S96-O;F0G72`](&EN='9A;"@D=&EM95!A<G1S6S1=
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&]F9G-E=#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T(&$@551#($]F
M9G-E="!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R=%5T8T]F
M9G-E="@D=F%L=64I"B`@("!["B`@("`@("`@)&]F9G-E="`]("1V86QU95LG
M86AE860G72`_("<K)R`Z("<M)SL*("`@("`@("`D;V9F<V5T("X]('-P<FEN
M=&8H)R4P,F0E,#)D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E6R=H;W5R)UTL("1V86QU95LG;6EN=71E)UTI.PH@("`@("`@(&EF("AI
M<W-E="@D=F%L=65;)W-E8V]N9"==*2D@>PH@("`@("`@("`@("`D;V9F<V5T
M("X]('-P<FEN=&8H)R4P,F0G+"`D=F%L=65;)W-E8V]N9"==*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;V9F<V5T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&%R<V4@82!4:6UE(%!E<FEO9"!F:65L9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W!A<G-E4&5R:6]D*"1T97AT*0H@("`@>PH@("`@("`@("1P
M97)I;V1087)T<R`](&5X<&QO9&4H)R\G+"`D=&5X="D["@H@("`@("`@("1S
M=&%R="`]("1T:&ES+3Y?<&%R<V5$871E5&EM92@D<&5R:6]D4&%R='-;,%TI
M.PH*("`@("`@("!I9B`H)&1U<F%T:6]N(#T@)'1H:7,M/E]P87)S941U<F%T
M:6]N*"1P97)I;V1087)T<ULQ72DI('L*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=S=&%R="<@/3X@)'-T87)T+"`G9'5R871I;VXG(#T^("1D=7)A=&EO
M;BD["B`@("`@("`@?2!E;'-E:68@*"1E;F0@/2`D=&AI<RT^7W!A<G-E1&%T
M951I;64H)'!E<FEO9%!A<G1S6S%=*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH)W-T87)T)R`]/B`D<W1A<G0L("=E;F0G(#T^("1E;F0I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A(%1I;64@4&5R
M:6]D(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T4&5R:6]D
M*"1V86QU92D*("`@('L*("`@("`@("`D<&5R:6]D(#T@)'1H:7,M/E]E>'!O
M<G1$871E5&EM92@D=F%L=65;)W-T87)T)UTI.PH@("`@("`@("1P97)I;V0@
M+CT@)R\G.PH@("`@("`@(&EF("AI<W-E="@D=F%L=65;)V1U<F%T:6]N)UTI
M*2!["B`@("`@("`@("`@("1P97)I;V0@+CT@)'1H:7,M/E]E>'!O<G1$=7)A
M=&EO;B@D=F%L=65;)V1U<F%T:6]N)UTI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1P97)I;V0@+CT@)'1H:7,M/E]E>'!O<G1$871E5&EM92@D
M=F%L=65;)V5N9"==*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1P97)I
M;V0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@82!$871E5&EM92!F
M:65L9"!I;G1O(&$@=6YI>"!T:6UE<W1A;7`N"B`@("`@*@H@("`@("H@0'1O
M9&\@5&AI<R!F=6YC=&EO;B!S:&]U;&0@8F4@;6]V960@=&\@2&]R9&5?1&%T
M92!A;F0@;6%D92!P=6)L:6,N"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]P87)S941A=&54:6UE*"1T97AT*0H@("`@>PH@("`@("`@
M("1D871E4&%R=',@/2!E>'!L;V1E*"=4)RP@)'1E>'0I.PH@("`@("`@(&EF
M("AC;W5N="@D9&%T95!A<G1S*2`A/2`R("8F("%E;7!T>2@D=&5X="DI('L*
M("`@("`@("`@("`@+R\@3F]T(&$@9&%T971I;64@9FEE;&0@8G5T(&UA>2!B
M92!J=7-T(&$@9&%T92!F:65L9"X*("`@("`@("`@("`@:68@*"$D9&%T92`]
M($AO<F1E7VE#86QE;F1A<CHZ7W!A<G-E1&%T92@D=&5X="DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D9&%T93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@0&=M;6MT:6UE*#`L(#`L(#`L("1D871E6R=M;VYT:"==
M+"`D9&%T95LG;61A>2==+"`D9&%T95LG>65A<B==*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A)&1A=&4@/2!(;W)D95]I0V%L96YD87(Z.E]P87)S941A
M=&4H)&1A=&5087)T<ULP72DI('L*("`@("`@("`@("`@<F5T=7)N("1D871E
M.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:6UE(#T@2&]R9&5?:4-A;&5N
M9&%R.CI?<&%R<V54:6UE*"1D871E4&%R='-;,5TI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&EM93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&EM95LG
M>F]N92==(#T]("=55$,G*2!["B`@("`@("`@("`@(')E='5R;B!`9VUM:W1I
M;64H)'1I;65;)VAO=7(G72P@)'1I;65;)VUI;G5T92==+"`D=&EM95LG<V5C
M;VYD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5;)VUO
M;G1H)UTL("1D871E6R=M9&%Y)UTL("1D871E6R=Y96%R)UTI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!`;6MT:6UE*"1T:6UE6R=H
M;W5R)UTL("1T:6UE6R=M:6YU=&4G72P@)'1I;65;)W-E8V]N9"==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T95LG;6]N=&@G72P@)&1A=&5;
M)VUD87DG72P@)&1A=&5;)WEE87(G72D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@17AP;W)T(&$@1&%T951I;64@9FEE;&0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]E>'!O<G1$871E5&EM92@D=F%L=64I"B`@("!["B`@
M("`@("`@)'1E;7`@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-?;V)J96-T
M*"1V86QU92D@)B8@(6ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@
M)'1Z(#T@9&%T92@G3R<L("1V86QU92D["B`@("`@("`@("`@("146D]F9G-E
M="`]("@S-C`P("H@<W5B<W1R*"1T>BP@,"P@,RDI("L@*#8P("H@<W5B<W1R
M*&1A=&4H)T\G+"`D=F%L=64I+"`S+"`R*2D["B`@("`@("`@("`@("1V86QU
M92`M/2`D5%I/9F9S970["@H@("`@("`@("`@("`D=&5M<%LG>F]N92==("`@
M/2`G551#)SL*("`@("`@("`@("`@)'1E;7!;)WEE87(G72`@(#T@9&%T92@G
M62<L("1V86QU92D["B`@("`@("`@("`@("1T96UP6R=M;VYT:"==("`](&1A
M=&4H)VXG+"`D=F%L=64I.PH@("`@("`@("`@("`D=&5M<%LG;61A>2==("`@
M/2!D871E*"=J)RP@)'9A;'5E*3L*("`@("`@("`@("`@)'1E;7!;)VAO=7(G
M72`@(#T@9&%T92@G1R<L("1V86QU92D["B`@("`@("`@("`@("1T96UP6R=M
M:6YU=&4G72`](&1A=&4H)VDG+"`D=F%L=64I.PH@("`@("`@("`@("`D=&5M
M<%LG<V5C;VYD)UT@/2!D871E*"=S)RP@)'9A;'5E*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9&%T94]B(#T@;F5W($AO<F1E7T1A=&4H)'9A
M;'5E*3L*("`@("`@("`@("`@<F5T=7)N($AO<F1E7VE#86QE;F1A<CHZ7V5X
M<&]R=$1A=&54:6UE*"1D871E3V(M/G1I;65S=&%M<"@I*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!(;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$871E
M*"1T96UP*2`N("=4)R`N($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=%1I;64H
M)'1E;7`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&$@5&EM92!F
M:65L9"X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P87)S951I;64H)'1E>'0I"B`@("!["B`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R\H6S`M.5U[,GTI*%LP+3E=>S)]*2A;,"TY77LR?2DH6BD_+R<L
M("1T97AT+"`D=&EM95!A<G1S*2D@>PH@("`@("`@("`@("`D=&EM95LG:&]U
M<B==(#T@:6YT=F%L*"1T:6UE4&%R='-;,5TI.PH@("`@("`@("`@("`D=&EM
M95LG;6EN=71E)UT@/2!I;G1V86PH)'1I;65087)T<ULR72D["B`@("`@("`@
M("`@("1T:6UE6R=S96-O;F0G72`](&EN='9A;"@D=&EM95!A<G1S6S-=*3L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:6UE4&%R='-;-%TI*2!["B`@("`@
M("`@("`@("`@("`D=&EM95LG>F]N92==(#T@)U540R<["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&EM95LG>F]N92==(#T@)TQO
M8V%L)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1I;64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R=',@82!4:6UE
M(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T5&EM92@D=F%L
M=64I"B`@("!["B`@("`@("`@)'1I;64@/2!S<')I;G1F*"<E,#)D)3`R9"4P
M,F0G+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;)VAO=7(G72P@
M)'9A;'5E6R=M:6YU=&4G72P@)'9A;'5E6R=S96-O;F0G72D["B`@("`@("`@
M:68@*"1V86QU95LG>F]N92==(#T]("=55$,G*2!["B`@("`@("`@("`@("1T
M:6UE("X]("=:)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:6UE.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&$@1&%T92!F:65L9"X*("`@
M("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S
M941A=&4H)'1E>'0I"B`@("!["B`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G
M5"<L("1T97AT*3L*("`@("`@("!I9B`H8V]U;G0H)'!A<G1S*2`]/2`R*2![
M"B`@("`@("`@("`@("1T97AT(#T@)'!A<G1S6S!=.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7BA<9'LT?2DM/RA<9'LR?2DM/RA<
M9'LR?2DD+R<L("1T97AT+"`D;6%T8V@I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@G>65A
M<B<@/3X@)&UA=&-H6S%=+`H@("`@("`@("`@("`@("`@("`@("`G;6]N=&@G
M(#T^("1M871C:%LR72P*("`@("`@("`@("`@("`@("`@("`@)VUD87DG(#T^
M("1M871C:%LS72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@82!$
M871E(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T1&%T92@D
M=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES7V]B:F5C="@D=F%L=64I*2![
M"B`@("`@("`@("`@("1V86QU92`](&%R<F%Y*"=Y96%R)R`]/B`D=F%L=64M
M/GEE87(L("=M;VYT:"<@/3X@)'9A;'5E+3YM;VYT:"P@)VUD87DG(#T^("1V
M86QU92T^;61A>2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S<')I;G1F
M*"<E,#1D)3`R9"4P,F0G+"`D=F%L=65;)WEE87(G72P@)'9A;'5E6R=M;VYT
M:"==+"`D=F%L=65;)VUD87DG72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S92!A($1U<F%T:6]N(%9A;'5E(&9I96QD+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&%R<V5$=7)A=&EO;B@D=&5X="D*("`@('L*("`@("`@("!I9B`H
M<')E9U]M871C:"@G+RA;*UT_?%LM72E0*"A;,"TY72M7*7PH6S`M.5TK1"E\
M*2A4*"A;,"TY72M(*7PH6S`M.5TK32E\*%LP+3E=*U,I*2LI/R\G+"!T<FEM
M*"1T97AT*2P@)&1U<G9A;'5E*2D@>PH@("`@("`@("`@("`O+R!7965K<RX*
M("`@("`@("`@("`@)&1U<F%T:6]N(#T@-R`J(#@V-#`P("H@:6YT=F%L*"1D
M=7)V86QU95LS72D["@H@("`@("`@("`@("!I9B`H8V]U;G0H)&1U<G9A;'5E
M*2`^(#0I('L*("`@("`@("`@("`@("`@("\O($1A>7,N"B`@("`@("`@("`@
M("`@("`D9'5R871I;VX@*ST@.#8T,#`@*B!I;G1V86PH)&1U<G9A;'5E6S1=
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H8V]U;G0H)&1U<G9A
M;'5E*2`^(#4I('L*("`@("`@("`@("`@("`@("\O($AO=7)S+@H@("`@("`@
M("`@("`@("`@)&1U<F%T:6]N("L](#,V,#`@*B!I;G1V86PH)&1U<G9A;'5E
M6S==*3L*"B`@("`@("`@("`@("`@("`O+R!-:6YS+@H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D=7)V86QU95LX72DI('L*("`@("`@("`@("`@("`@
M("`@("`D9'5R871I;VX@*ST@-C`@*B!I;G1V86PH)&1U<G9A;'5E6SA=*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!396-S+@H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D=7)V86QU95LY72DI('L*("`@
M("`@("`@("`@("`@("`@("`D9'5R871I;VX@*ST@:6YT=F%L*"1D=7)V86QU
M95LY72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O(%-I9VXN"B`@("`@("`@("`@(&EF("@D9'5R=F%L=65;,5T@
M/3T@(BTB*2!["B`@("`@("`@("`@("`@("`D9'5R871I;VX@*CT@+3$["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B`D9'5R871I;VX["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A(&1U<F%T:6]N
M('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T1'5R871I;VXH
M)'9A;'5E*0H@("`@>PH@("`@("`@("1D=7)A=&EO;B`]("<G.PH@("`@("`@
M(&EF("@D=F%L=64@/"`P*2!["B`@("`@("`@("`@("1V86QU92`J/2`M,3L*
M("`@("`@("`@("`@)&1U<F%T:6]N("X]("<M)SL*("`@("`@("!]"B`@("`@
M("`@)&1U<F%T:6]N("X]("=0)SL*"B`@("`@("`@)'=E96MS(#T@9FQO;W(H
M)'9A;'5E("\@*#<@*B`X-C0P,"DI.PH@("`@("`@("1V86QU92`]("1V86QU
M92`E("@W("H@.#8T,#`I.PH@("`@("`@(&EF("@D=V5E:W,I('L*("`@("`@
M("`@("`@)&1U<F%T:6]N("X]("1W965K<R`N("=7)SL*("`@("`@("!]"@H@
M("`@("`@("1D87ES(#T@9FQO;W(H)'9A;'5E("\@*#@V-#`P*2D["B`@("`@
M("`@)'9A;'5E(#T@)'9A;'5E("4@*#@V-#`P*3L*("`@("`@("!I9B`H)&1A
M>7,I('L*("`@("`@("`@("`@)&1U<F%T:6]N("X]("1D87ES("X@)T0G.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1V86QU92D@>PH@("`@("`@("`@("`D
M9'5R871I;VX@+CT@)U0G.PH*("`@("`@("`@("`@)&AO=7)S(#T@9FQO;W(H
M)'9A;'5E("\@,S8P,"D["B`@("`@("`@("`@("1V86QU92`]("1V86QU92`E
M(#,V,#`["B`@("`@("`@("`@(&EF("@D:&]U<G,I('L*("`@("`@("`@("`@
M("`@("1D=7)A=&EO;B`N/2`D:&]U<G,@+B`G2"<["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1M:6YS(#T@9FQO;W(H)'9A;'5E("\@-C`I.PH@("`@
M("`@("`@("`D=F%L=64@/2`D=F%L=64@)2`V,#L*("`@("`@("`@("`@:68@
M*"1M:6YS*2!["B`@("`@("`@("`@("`@("`D9'5R871I;VX@+CT@)&UI;G,@
M+B`G32<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=F%L=64I
M('L*("`@("`@("`@("`@("`@("1D=7)A=&EO;B`N/2`D=F%L=64@+B`G4R<[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9'5R
M871I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9O;&1E
M9"!V97)S:6]N(&]F(&$@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9O
M;&1,:6YE*"1L:6YE*0H@("`@>PH@("`@("`@("1L:6YE(#T@<')E9U]R97!L
M86-E*"(O7')<;GQ<;GQ<<B\B+"`G7&XG+"`D;&EN92D["B`@("`@("`@:68@
M*'-T<FQE;B@D;&EN92D@/B`W-2D@>PH@("`@("`@("`@("`D9F]L9&5D;&EN
M92`]("<G.PH@("`@("`@("`@("!W:&EL92`H(65M<'1Y*"1L:6YE*2D@>PH@
M("`@("`@("`@("`@("`@)&UA>$QI;F4@/2!S=6)S='(H)&QI;F4L(#`L(#<U
M*3L*("`@("`@("`@("`@("`@("1C=710;VEN="`](&UA>"@V,"P@;6%X*'-T
M<G)P;W,H)&UA>$QI;F4L("<[)RDL('-T<G)P;W,H)&UA>$QI;F4L("<Z)RDI
M("L@,2D["@H@("`@("`@("`@("`@("`@)&9O;&1E9&QI;F4@+CT@*&5M<'1Y
M*"1F;VQD961L:6YE*2D@/PH@("`@("`@("`@("`@("`@("`@('-U8G-T<B@D
M;&EN92P@,"P@)&-U=%!O:6YT*2`Z"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]N97=L:6YE("X@)R`G("X@<W5B<W1R*"1L:6YE+"`P+"`D8W5T4&]I
M;G0I.PH*("`@("`@("`@("`@("`@("1L:6YE(#T@*'-T<FQE;B@D;&EN92D@
M/#T@)&-U=%!O:6YT*2`_("<G(#H@<W5B<W1R*"1L:6YE+"`D8W5T4&]I;G0I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9F]L9&5D;&EN
M93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]N=F5R="!A;B`X8FET('-T<FEN9R!T;R!A('%U;W1E
M9"UP<FEN=&%B;&4@<W1R:6YG(&%C8V]R9&EN9PH@("`@("H@=&\@4D9#,C`T
M-2P@<V5C=&EO;B`V+C<N"B`@("`@*@H@("`@("H@57-E<R!I;6%P7SAB:70@
M:68@879A:6QA8FQE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN
M<'5T("!4:&4@<W1R:6YG('1O(&)E(&5N8V]D960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!Q=6]T960M<')I;G1A8FQE(&5N8V]D960@
M<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75O=&5D4')I;G1A8FQE
M16YC;V1E*"1I;G!U="`]("<G*0H@("`@>PH@("`@("`@("\O($EF(&EM87!?
M.&)I="@I(&ES(&%V86EL86)L92P@=7-E(&ET+@H@("`@("`@(&EF("AF=6YC
M=&EO;E]E>&ES=',H)VEM87!?.&)I="<I*2!["B`@("`@("`@("`@(')E='5R
M;B!I;6%P7SAB:70H)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@("\O(%)A
M=&AE<B!D=6UB(')E<&QA8VUE;G0Z(&IU<W0@96YC;V1E(&5V97)Y=&AI;F<N
M"B`@("`@("`@)&AE>"`](&%R<F%Y*"<P)RP@)S$G+"`G,B<L("<S)RP@)S0G
M+"`G-2<L("<V)RP@)S<G+"`G."<L("<Y)RP*("`@("`@("`@("`@("`@("`@
M("`@)T$G+"`G0B<L("=#)RP@)T0G+"`G12<L("=&)RD["@H@("`@("`@("1O
M=71P=70@/2`G)SL*("`@("`@("`D;&5N(#T@<W1R;&5N*"1I;G!U="D["B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE;CL@*RLD:2D@>PH@("`@("`@
M("`@("`D8R`]('-U8G-T<B@D:6YP=70L("1I+"`Q*3L*("`@("`@("`@("`@
M)&1E8R`](&]R9"@D8RD["B`@("`@("`@("`@("1O=71P=70@+CT@)STG("X@
M)&AE>%MF;&]O<B@D9&5C("\@,38I72`N("1H97A;9FQO;W(H)&1E8R`E(#$V
M*5T["B`@("`@("`@("`@(&EF("@H)&D@*R`Q*2`E(#(U(#T](#`I('L*("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@(CU<<EQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4
M96UP;&%T92YP:'``````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-3(U-C<`,3`U,34T,S$P-C$`,#(P-3$W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!(;W)D92!4
M96UP;&%T92!S>7-T96TN($%D87!T960@9G)O;2!B5&5M<&QA=&4@8GD@0G)I
M86X@3&]Z:65R"B`J(#QB<FEA;D!M87-S87-S:2YN970^+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`L=B`Q+C,X+C$P
M+C$P(#(P,#8O,#8O,3,@,#,Z-30Z,#,@8VAU8VL@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?5&5M<&QA=&4*("HO"F-L87-S($AO<F1E7U1E
M;7!L871E('L*"B`@("`O*BH*("`@("`J($]P=&EO;B!V86QU97,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O<'1I;VYS
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($1I<F5C=&]R>2!T:&%T('1E
M;7!L871E<R!S:&]U;&0@8F4@<F5A9"!F<F]M+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)A<V5P871H(#T@)R<["@H@
M("`@+RHJ"B`@("`@*B!297-E="!T96UP;&%T92!V87)I86)L97,@869T97(@
M<&%R<VEN9S\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?<F5S971687)S(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1A
M9R`H<V-A;&%R*2!V86QU97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]S8V%L87)S(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($QO;W`@=&%G('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V%R<F%Y<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!#;&]O<"!T86<@=F%L=65S+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%R<F%Y<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!)9B!T86<@=F%L=65S+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:69S(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($YA;64@;V8@8V%C:&5D('1E;7!L871E(&9I;&4N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M=&5M<&QA=&5&:6QE(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-A8VAE9"!S
M;W5R8V4@;V8@=&5M<&QA=&4@9FEL92X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]T96UP;&%T92`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX@0V%N('-E="!T:&4@=&5M<&QA=&4@
M8F%S92!P871H(&%N9"!W:&5T:&5R(&]R(&YO=`H@("`@("H@=&\@9')O<"!T
M96UP;&%T92!V87)I86)L97,@869T97(@82!P87)S:6YG(&$@=&5M<&QA=&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&)A<V5P871H("`@5&AE
M(&1I<F5C=&]R>2!W:&5R92!T96UP;&%T97,@87)E(')E860@9G)O;2X*("`@
M("`J($!P87)A;2!B;V]L96%N("1R97-E=%9A<G,@($1R;W`@=&5M<&QA=&4@
M=F%R<R!A9G1E<B!P87)S:6YG(&$@=&5M<&QA=&4_"B`@("`@*B\*("`@(&9U
M;F-T:6]N($AO<F1E7U1E;7!L871E*"1B87-E<&%T:"`](&YU;&PL("1R97-E
M=%9A<G,@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D8F%S
M97!A=&@I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8F%S97!A=&@@/2`D8F%S
M97!A=&@["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?<F5S971687)S(#T@
M*&)O;VPI)')E<V5T5F%R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M86X@;W!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]P=&EO
M;B`@5&AE(&]P=&EO;B!N86UE+@H@("`@("H@0'!A<F%M(&UI>&5D("`D=F%L
M("`@("!4:&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$]P=&EO;B@D;W!T:6]N+"`D=F%L*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;W!T:6]N<ULD;W!T:6]N72`]("1V86P["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE('1E;7!L871E(&-O;G1E;G1S('1O(&$@<W1R:6YG+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E;7!L871E("!4:&4@=&5M
M<&QA=&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&5M<&QA=&4H
M)'1E;7!L871E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&5M<&QA=&4@/2`D
M=&5M<&QA=&4["B`@("`@("`@)'1H:7,M/E]T96UP;&%T949I;&4@/2`G<W1R
M:6YG)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@;W!T:6]N
M)W,@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N
M("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(&]P=&EO;B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971/<'1I;VXH)&]P=&EO;BD*("`@('L*("`@("`@("!R971U<FX@:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=*2`_("1T:&ES+3Y?;W!T:6]N<ULD
M;W!T:6]N72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@
M=&%G+"!L;V]P+"!O<B!I9B!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG?&%R<F%Y("1T86<@("!%:71H97(@=&AE('1A9R!N86UE(&]R
M(&$@:&%S:"!W:71H('1A9R!N86UE<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87,@:V5Y<R!A;F0@=&%G('9A;'5E<R!A<R!V86QU97,N
M"B`@("`@*B!`<&%R86T@;6EX960@("`@("`@("1V87(@("!4:&4@=F%L=64@
M=&\@<F5P;&%C92!T:&4@=&%G('=I=&@N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`@("`@("1I<TEF("!)<R!T:&ES(&9O<B!A;B`\:68Z/B!T86<_("A$969A
M=6QT.B!N;RDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D=&%G+"`D=F%R
M+"`D:7-)9B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M=&%G*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&%G(&%S("1T5&%G(#T^
M("1T5F%R*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T*"1T5&%G+"`D
M=%9A<BP@)&ES268I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@
M*&ES7V%R<F%Y*"1V87(I('Q\(&ES7V]B:F5C="@D=F%R*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V%R<F%Y<ULD=&%G72`]("1V87(["B`@("`@("`@("`@
M(&EF("@D:7-)9BD@>PH@("`@("`@("`@("`@("`@+R\@2G5S="!S=&]R92!T
M:&4@<V%M92!V87)I86)L92!T:&%T('=E('-T;W)E9"!I;@H@("`@("`@("`@
M("`@("`@+R\@)'1H:7,M/E]A<G)A>7,@+2!I9B!W92!D;VXG="!M;V1I9GD@
M:70L(%!(4"=S"B`@("`@("`@("`@("`@("`O+R!R969E<F5N8V4@8V]U;G1I
M;F<@96YS=7)E<R!W92=R92!N;W0@=7-I;F<@86YY"B`@("`@("`@("`@("`@
M("`O+R!A9&1I=&EO;F%L(&UE;6]R>2!H97)E+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I9G-;)'1A9UT@/2`D=F%R.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S8V%L87)S6R1T86==
M(#T@)'9A<CL*("`@("`@("`@("`@:68@*"1I<TEF*2!["B`@("`@("`@("`@
M("`@("`O+R!*=7-T('-T;W)E('1H92!S86UE('9A<FEA8FQE('1H870@=V4@
M<W1O<F5D(&EN"B`@("`@("`@("`@("`@("`O+R`D=&AI<RT^7W-C86QA<G,@
M+2!I9B!W92!D;VXG="!M;V1I9GD@:70L(%!(4"=S"B`@("`@("`@("`@("`@
M("`O+R!R969E<F5N8V4@8V]U;G1I;F<@96YS=7)E<R!W92=R92!N;W0@=7-I
M;F<@86YY"B`@("`@("`@("`@("`@("`O+R!A9&1I=&EO;F%L(&UE;6]R>2!H
M97)E+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]I9G-;)'1A9UT@/2`D=F%R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=F%L=64@;V8@82!T86<@;W(@;&]O<"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86<@(%1H92!T86<@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=&%G('9A;'5E(&]R(&YU
M;&P@:68@=&AE('1A9R!H87-N)W0@8F5E;B!S970@>65T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G970H)'1A9RD*("`@('L*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]A<G)A>7-;)'1A9UTI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V%R<F%Y<ULD=&%G73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<V-A;&%R<ULD=&%G72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<V-A;&%R<ULD=&%G73L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('9A;'5E
M<R!F;W(@82!C;&]O<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M86<@("!4:&4@;F%M92!O9B!T:&4@8VQO;W`N"B`@("`@*B!`<&%R86T@87)R
M87D@)&%R<F%Y("!4:&4@=F%L=65S(&9O<B!T:&4@8VQO;W`N"B`@("`@*B!`
M<&%R86T@87)R87D@)&-A<V5S("!4:&4@8V%S97,@*'1E<W0@=F%L=65S*2!F
M;W(@=&AE(&-L;V]P<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0VQO;W`H
M)'1A9RP@)&%R<F%Y+"`D8V%S97,I"B`@("!["B`@("`@("`@)'1H:7,M/E]C
M87)R87ES6R1T86==(#T@87)R87DH"B`@("`@("`@("`@("=A<G)A>2<@/3X@
M)&%R<F%Y+`H@("`@("`@("`@("`G8V%S97,G(#T^("1C87-E<PH@("`@("`@
M("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E=',@=&AE('1E;7!L871E
M('9A<FEA8FQE<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V-A
M;&%R<R`@4F5S970@<V-A;&%R("AB87-I8R!T86<I('9A<FEA8FQE<S\*("`@
M("`J($!P87)A;2!B;V]L96%N("1A<G)A>7,@("!297-E="!L;V]P('9A<FEA
M8FQE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1C87)R87ES("!297-E="!C
M;&]O<"!V87)I86)L97,_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:69S("`@
M("`@4F5S970@:68@=F%R:6%B;&5S/PH@("`@("HO"B`@("!F=6YC=&EO;B!R
M97-E=%9A<G,H)'-C86QA<G,L("1A<G)A>7,L("1C87)R87ES+"`D:69S*0H@
M("`@>PH@("`@("`@(&EF("@D<V-A;&%R<R`]/3T@=')U92D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-C86QA<G,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@
M("`@("!I9B`H)&%R<F%Y<R`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V%R<F%Y<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D
M8V%R<F%Y<R`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^7V-A<G)A
M>7,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("!I9B`H)&EF<R`]/3T@
M=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^7VEF<R`](&%R<F%Y*"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@;&ES="!O
M9B!B;&]C:W,@<')E<V5N="!I;B!T:&4@=&5M<&QA=&4@<V]U<F-E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@9FEL92!T
M;R!F971C:"!T:&4@=&5M<&QA=&4@9G)O;2X*("`@("`J($!R971U<FX@;6EX
M960@($%N(&%R<F%Y(&]F(&%P<&QI8V%T:6]N<RP@;W(@4$5!4E]%<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T0FQO8VMS*"D*
M("`@('L*("`@("`@("`D8FQO8VMS(#T@87)R87DH*3L*("`@("`@("!I9B`H
M<')E9U]M871C:%]A;&PH)SQB;&]C:SHH6V$M>D$M6C`M.5]=*SI;82UZ02U:
M,"TY7UTK*3XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W1E;7!L871E+"`D;6%T8VAE<RP@4%)%1U]3151?3U)$15(I*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1M871C:&5S(&%S("1M871C:"D@>PH@("`@("`@
M("`@("`@("`@)&)L;V-K<UM=(#T@)&UA=&-H6S%=.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)L;V-K<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($9E=&-H97,@82!T96UP;&%T92!F<F]M('1H92!S<&5C
M:69I960@9FEL92!A;F0@<F5T=7)N('1H92!P87)S960*("`@("`J(&-O;G1E
M;G1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4
M:&4@9FEL92!T;R!F971C:"!T:&4@=&5M<&QA=&4@9G)O;2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!T96UP;&%T92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9F5T8V@H)&9I;&5N86UE*0H@("`@>PH@("`@
M("`@("1C;VYT96YT<R`]("1T:&ES+3Y?9V5T5&5M<&QA=&4H)&9I;&5N86UE
M*3L*("`@("`@("!I9B`H:7-?82@D8V]N=&5N=',L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1C;VYT96YT<SL*("`@("`@("!]"@H@
M("`@("`@("\O(%!A<G-E(&%N9"!R971U<FX@=&AE(&-O;G1E;G1S+@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<&%R<V4H)&-O;G1E;G1S*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%!A<G-E<R!A;&P@=F%R:6%B;&5S+W1A9W,@:6X@=&AE
M('1E;7!L871E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E
M;G1S("!4:&4@=6YP87)S960@=&5M<&QA=&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!P87)S960@=&5M<&QA=&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!A<G-E*"1C;VYT96YT<R`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"$D8V]N=&5N=',I('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M)'1H:7,M/E]T96UP;&%T93L*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E
M<W,@:69S+@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I9G,I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:69S(&%S("1T86<@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^7W!A
M<G-E268H)'1A9RP@)&-O;G1E;G1S*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+R\@4')O8V5S<R!T86=S+@H@("`@("`@("1S96%R8V@@
M/2!A<G)A>2@I.PH@("`@("`@("1R97!L86-E(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7W-C86QA<G,@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@)'-E87)C:%M=(#T@)'1H:7,M/E]G971486<H)&ME
M>2D["B`@("`@("`@("`@("1R97!L86-E6UT@/2`D=F%L=64["B`@("`@("`@
M?0H@("`@("`@(&EF("AC;W5N="@D<V5A<F-H*2D@>PH@("`@("`@("`@("`D
M8V]N=&5N=',@/2!S=')?<F5P;&%C92@D<V5A<F-H+"`D<F5P;&%C92P@)&-O
M;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E<W,@;&]O<',@
M86YD(&%R<F%Y<RX*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%R<F%Y<R!A
M<R`D:V5Y(#T^("1A<G)A>2D@>PH@("`@("`@("`@("`D8V]N=&5N=',@/2`D
M=&AI<RT^7W!A<G-E3&]O<"@D:V5Y+"`D87)R87DL("1C;VYT96YT<RD["B`@
M("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&-L;V]P<RX*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V-A<G)A>7,@87,@)&ME>2`]/B`D87)R87DI('L*
M("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94-L;V]P*"1K
M97DL("1A<G)A>2P@)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O
M(%!A<G-E(&=E='1E>'0@=&%G<RP@:68@=&AE(&]P=&EO;B!I<R!E;F%B;&5D
M+@H@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=G971T97AT)RDI('L*
M("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94=E='1E>'0H
M)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O(%!A<G-E(&5M8F5D
M9&5D(&)L;V-K<PH@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=B;&]C
M:W,G*2D@>PH@("`@("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^7W!A<G-E
M0FQO8VMS*"1C;VYT96YT<RD["B`@("`@("`@?0H*("`@("`@("`O+R!297-E
M="!T96UP;&%T92!D871A('5N;&5S<R!W92=R92!S=7!P;W-E9"!T;R!K965P
M(&ET"B`@("`@("`@+R\@87)O=6YD+@H@("`@("`@(&EF("@D=&AI<RT^7W)E
M<V5T5F%R<RD@>PH@("`@("`@("`@("`D=&AI<RT^<F5S971687)S*&9A;'-E
M+"!T<G5E+"!T<G5E+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`O+R!2
M971U<FX@<&%R<V5D('1E;7!L871E+@H@("`@("`@(')E='5R;B`D8V]N=&5N
M=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&9U;&P@<W1A<G0@
M86YD(&5N9"!T86=S(&9O<B!A(&YA;65D('1A9RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M86<*("`@("`J($!P87)A;2!S=')I;F<@)&1I<F5C=&EV92`@5&AE(&MI;F0@
M;V8@=&%G("T@=&%G+"!I9BP@;&]O<"P@8VQO;W`N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@)V(G(#T^(%-T87)T('1A9RX*("`@("`J("`@("`@
M("`@("`@("`@("=E)R`]/B!%;F0@=&%G+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T5&%G<R@D=&%G+"`D9&ER96-T:79E*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2@G8B<@/3X@)SPG("X@)&1I<F5C=&EV92`N("<Z)R`N("1T
M86<@+B`G/B<L"B`@("`@("`@("`@("`@("`@("`@("=E)R`]/B`G/"\G("X@
M)&1I<F5C=&EV92`N("<Z)R`N("1T86<@+B`G/B<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1F]R;6%T<R!A('-C86QA<B!T86<@*&1E9F%U;'0@9F]R;6%T
M(&ES(#QT86<Z;F%M93XI+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A9R`@5&AE(&YA;64@
M;V8@=&AE('1A9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&9U;&P@=&%G('=I=&@@=&AE(&-U<G)E;G0@<W1A<G0O96YD(&1E;&EM:71E
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971486<H)'1A9RD*("`@('L*
M("`@("`@("!R971U<FX@)SQT86<Z)R`N("1T86<@+B`G("\^)SL*("`@('T*
M"B`@("`O*BH*("`@("`J($5X=')A8W1S(&$@<&]R=&EO;B!O9B!A('1E;7!L
M871E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D="`@("`@("`@("`@5&AE('1A9R!T;R!E>'1R
M86-T+B!(87-H(&9O<FUA="!I<SH*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=%LG8B==("T@5&AE('-T87)T('1A9PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T6R=E)UT@+2!4:&4@96YD('1A
M9PH@("`@("H@0'!A<F%M('-T<FEN9R`F)&-O;G1E;G1S("!4:&4@=&5M<&QA
M=&4@=&\@97AT<F%C="!F<F]M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T
M4W1A=&5M96YT*"1T+"`F)&-O;G1E;G1S*0H@("`@>PH@("`@("`@("\O($QO
M8V%T92!T:&4@<W1A=&5M96YT+@H@("`@("`@("1P;W,@/2!S=')P;W,H)&-O
M;G1E;G1S+"`D=%LG8B==*3L*("`@("`@("!I9B`H)'!O<R`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)'1A9U]L96YG=&@@/2!S=')L96XH)'1;)V(G72D["B`@("`@("`@)&9P
M;W,@/2`D<&]S("L@)'1A9U]L96YG=&@["B`@("`@("`@)&QP;W,@/2!S=')P
M;W,H)&-O;G1E;G1S+"`D=%LG92==*3L*("`@("`@("`D;&5N9W1H(#T@)&QP
M;W,@+2`D9G!O<SL*"B`@("`@("`@+R\@17AT<F%C="`F(')E='5R;B!T:&4@
M<W1A=&5M96YT+@H@("`@("`@(')E='5R;B!S=6)S='(H)&-O;G1E;G1S+"`D
M9G!O<RP@)&QE;F=T:"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@
M9V5T=&5X="!T86=S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;G1E;G1S("!4:&4@=6YP87)S960@8V]N=&5N="!O9B!T:&4@9FEL92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!C;VYT96YT
M<R!O9B!T:&4@9V5T=&5X="!B;&]C:W,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]P87)S94=E='1E>'0H)&-O;G1E;G1S*0H@("`@>PH@("`@("`@("\O($=E
M="!T:&4@=&%G<R`F(&QO;W`N"B`@("`@("`@)'0@/2!A<G)A>2@G8B<@/3X@
M)SQG971T97AT/B<L"B`@("`@("`@("`@("`@("`@("`G92<@/3X@)SPO9V5T
M=&5X=#XG*3L*("`@("`@("!W:&EL92`H)'1E>'0@/2`D=&AI<RT^7V=E=%-T
M871E;65N="@D="P@)&-O;G1E;G1S*2D@>PH@("`@("`@("`@("`D8V]N=&5N
M=',@/2!S=')?<F5P;&%C92@D=%LG8B==("X@)'1E>'0@+B`D=%LG92==+"!?
M*"1T97AT*2P@)&-O;G1E;G1S*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1C;VYT96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!B;&]C
M:R!T86=S+@H@("`@("H*("`@("`J($AE<F4@=V4@<&%R<V4@8FQO8VL@=&%G
M<R!I;B!T:&4@9F]R;3H*("`@("`J"B`@("`@*B`@/&)L;V-K.F%P<#IN86UE
M/@H@("`@("H@("`\<&%R86TZ9F]O/F9O;R!P87)A;65T97(G<R!V86QU93PO
M<&%R86TZ9F]O/@H@("`@("H@("`\<&%R86TZ8F%R/F)A<B!P87)A;65T97(G
M<R!V86QU93PO<&%R86TZ8F%R/@H@("`@("H@("`\<V5R:6%L.F)A>CYS.C(Q
M.B)B87H@<&%R86UE=&5R)W,@=F%L=64B.SPO<V5R:6%L.F)A>CX*("`@("`J
M("`\+V)L;V-K.F%P<#IN86UE/@H@("`@("H*("`@("`J("XN+B!A;F0@<F5P
M;&%C92!T:&5M('=I=&@@<F5N9&5R960@87!P;&EC871I;VX@8FQO8VMS+@H@
M("`@("H*("`@("`J($)L;V-K('!A<F%M971E<G,@87)E('!R;W9I9&5D('=I
M=&@@=&AE(&YE<W1E9"`B<&%R86TZ9F]O(B!A;F0*("`@("`J(")S97)I86PZ
M9F]O(B!T86=S+B`@5&AE('-E<FEA;"US='EL92!T86=S('1A:V4@82!S97)I
M86QI>F5D(%!(4`H@("`@("H@=F%L=64L('-O('EO=2!C86X@=7-E(&ET('1O
M('!R;W9I9&4@87)R87DL(&)O;VQE86XL(&%N9"!C;VUP;&5X"B`@("`@*B!T
M>7!E('!A<F%M971E<G,N("!4:&4@<&%R86TM<W1Y;&4@=&%G<R!P<F]V:61E
M('-T<FEN9R!P87)A;65T97)S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G1S("!4
M:&4@=6YP87)S960@8V]N=&5N=',@;V8@=&AE(&9I;&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@;V8@=&AE
M(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94)L;V-K<R@D8V]N
M=&5N=',I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G(3QB
M;&]C:SHH6V$M>D$M6E\P+3E=*RDZ*%MA+7I!+5I?,"TY72LI/B@N*C\I)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/"]B;&]C:SHH6V$M>D$M
M6E\P+3E=*RDZ*%MA+7I!+5I?,"TY72LI/B%S92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`B7"1T:&ES+3Y?<&%R<V5";&]C:R@G7%PQ)RP@)UQ<
M,B<L("=<7#,G*2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5N=',I.PH@("`@?0H*("`@("\J*@H@("`@("H@2&%N9&QE('1H92!C;VYT
M96YT<R!O9B!O;F4@8FQO8VL@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5";&]C:R@D87!P
M+"`D;F%M92P@)&-O;G1E;G1S*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O0FQO8VLN<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*"B`@("`@("`@+R\@56YD;R!P
M<F5G7W)E<&QA8V4H*2!E;F-O9&EN9R!S=')A;F=E;F5S<RX*("`@("`@("`D
M8V]N=&5N=',@/2!S=')?<F5P;&%C92@G7%PB)RP@)R(G+"`D8V]N=&5N=',I
M.PH*("`@("`@("`O+R!&:6YD(&)L;V-K)W,@<&%R86UE=&5R<RX*("`@("`@
M("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("!I9B`H<')E9U]M871C:%]A
M;&PH)R$\<&%R86TZ*%MA+7I!+5I?,"TY72LI/B@N*C\I)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<\+W!A<F%M.BA;82UZ02U:7S`M.5TK*3XA
M<R<L("1C;VYT96YT<RP@)&UA=&-H97,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%!214=?4T547T]21$52*2D@>PH@("`@("`@("`@("!F;W)E86-H
M("@D;6%T8VAE<R!A<R`D;6%T8V@I('L*("`@("`@("`@("`@("`@("1P87)A
M;7-;)&UA=&-H6S%=72`](&AT;6Q?96YT:71Y7V1E8V]D92@D;6%T8VA;,ETI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AP<F5G7VUA
M=&-H7V%L;"@G(3QS97)I86PZ*%MA+7I!+5I?,"TY72LI/B@N*C\I)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<\+W-E<FEA;#HH6V$M>D$M6E\P
M+3E=*RD^(7,G+"`D8V]N=&5N=',L("1M871C:&5S+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("!04D5'7U-%5%]/4D1%4BDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&UA=&-H97,@87,@)&UA=&-H*2!["B`@("`@("`@("`@("`@
M("`D<&%R86US6R1M871C:%LQ75T@/2!U;G-E<FEA;&EZ92AH=&UL7V5N=&ET
M>5]D96-O9&4H)&UA=&-H6S)=*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O($-O;G-T<G5C="!T:&4@8FQO8VLN"B`@("`@("`@)&)L
M;V-K(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1A<'`L
M("1N86UE+"`D<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D8FQO8VLL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)')E<W5L="`]("<\<W1R;VYG
M/B<@+B!S<')I;G1F*%\H(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1B;&]C:RT^
M9V5T365S<V%G92@I*2`N("<\+W-T<F]N9SXG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1R97-U;'0@/2`D8FQO8VLM/F=E=$-O;G1E;G0H*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("<\<W1R;VYG/B<@+B!S<')I
M;G1F*%\H(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="T^9V5T
M365S<V%G92@I*2`N("<\+W-T<F]N9SXG.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%!A<G-E<R!A(&=I=F5N(&EF('-T871E;65N="X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T86<@("`@("`@5&AE(&YA;64@;V8@=&AE(&EF(&)L;V-K('1O('!A
M<G-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=',@(%1H92!U;G!A
M<G-E9"!C;VYT96YT<R!O9B!T:&4@:68@8FQO8VLN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@;V8@=&AE(&EF
M(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5)9B@D=&%G+"`D
M8V]N=&5N=',L("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@("\O($=E="!T
M:&4@=&%G<R`F(&EF('-T871E;65N="X*("`@("`@("`D="`]("1T:&ES+3Y?
M9V5T5&%G<R@D=&%G+"`G:68G*3L*("`@("`@("`D970@/2`D=&AI<RT^7V=E
M=%1A9W,H)'1A9RP@)V5L<V4G*3L*"B`@("`@("`@+R\@97AP;&]D92!T:&4@
M=&%G+"!S;R!W92!H879E('1H92!C;W)R96-T(&ME>7,@9F]R('1H92!A<G)A
M>0H@("`@("`@(&EF("AI<W-E="@D:V5Y*2D@>PH@("`@("`@("`@("!L:7-T
M*"1T9RP@)&LI(#T@97AP;&]D92@G+B<L("1T86<I.PH@("`@("`@('T*("`@
M("`@("!W:&EL92`H*"1I9B`]("1T:&ES+3Y?9V5T4W1A=&5M96YT*"1T+"`D
M8V]N=&5N=',I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@+R\@0VAE8VL@
M9F]R(&5L<V4@<W1A=&5M96YT+@H@("`@("`@("`@("!I9B`H)&5L<V4@/2`D
M=&AI<RT^7V=E=%-T871E;65N="@D970L("1I9BDI('L*("`@("`@("`@("`@
M("`@("\O(%!R;V-E<W,@=&AE(&EF('-T871E;65N="X*("`@("`@("`@("`@
M("`@(&EF("@H:7-S970H)&ME>2D@)B8@)'1H:7,M/E]I9G-;)'1G75LD:V5Y
M75LD:UTI('Q\"B`@("`@("`@("`@("`@("`@("`@*&ES<V5T*"1T:&ES+3Y?
M:69S6R1T86==*2`F)B`D=&AI<RT^7VEF<ULD=&%G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D<F5P;&%C92`]('-T<E]R97!L86-E*"1E=%LG8B==("X@
M)&5L<V4@+B`D971;)V4G72P@)R<L("1I9BD["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R97!L86-E(#T@)&5L<V4[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`O+R!0<F]C97-S('1H92!I9B!S=&%T96UE;G0N"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&ME>2DI('L*("`@("`@("`@("`@("`@
M("`@("`D<F5P;&%C92`]("1T:&ES+3Y?:69S6R1T9UU;)&ME>5U;)&M=(#\@
M)&EF(#H@;G5L;#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)')E<&QA8V4@/2`D=&AI<RT^7VEF<ULD=&%G72`_("1I
M9B`Z(&YU;&P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\O(%!A<G-E('1H92!T96UP;&%T92X*("`@("`@("`@("`@
M)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'1;)V(G72`N("1I9B`N("1T6R=E
M)UTL("1R97!L86-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]N=&5N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@4F5T=7)N
M('!A<G-E9"!T96UP;&%T92X*("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S('1H92!G:79E;B!A<G)A>2!F
M;W(@86YY(&QO;W!S(&]R(&]T:&5R('5S97,@;V8@=&AE(&%R<F%Y+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1A9R`@("`@("!4:&4@;F%M92!O9B!T:&4@;&]O<"!T;R!P
M87)S92X*("`@("`J($!P87)A;2!A<G)A>2`@)&%R<F%Y("`@("!4:&4@=F%L
M=65S(&9O<B!T:&4@;&]O<"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E
M;G1S("!4:&4@=6YP87)S960@8V]N=&5N=',@;V8@=&AE(&QO;W`N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@
M;V8@=&AE(&QO;W`N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94QO;W`H
M)'1A9RP@)&%R<F%Y+"`D8V]N=&5N=',I"B`@("!["B`@("`@("`@+R\@1V5T
M('1H92!T86=S("8@;&]O<"X*("`@("`@("`D="`]("1T:&ES+3Y?9V5T5&%G
M<R@D=&%G+"`G;&]O<"<I.PH@("`@("`@("1L;V]P(#T@)'1H:7,M/E]G9713
M=&%T96UE;G0H)'0L("1C;VYT96YT<RD["@H@("`@("`@("\O(%-E92!I9B!W
M92!H879E(&$@9&EV:61E<BX*("`@("`@("`D;"`]("1T:&ES+3Y?9V5T5&%G
M<R@D=&%G+"`G9&EV:61E<B<I.PH@("`@("`@("1D:79I9&5R(#T@)'1H:7,M
M/E]G9713=&%T96UE;G0H)&PL("1L;V]P*3L*("`@("`@("`D8V]N=&5N=',@
M/2!S=')?<F5P;&%C92@D;%LG8B==("X@)&1I=FED97(@+B`D;%LG92==+"`G
M)RP@)&-O;G1E;G1S*3L*"B`@("`@("`@+R\@4')O8V5S<R!T:&4@87)R87DN
M"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D<&%R<V5D(#T@)R<["B`@("`@
M("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@("`@(&9O<F5A8V@@*"1A
M<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1V86QU92D@?'P@:7-?;V)J96-T*"1V86QU92DI('L*("`@
M("`@("`@("`@("`@("`@("`D:2`]("1L;V]P.PH@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]N=6UE<FEC*"1K97DI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:V5Y,B`]/B`D=F%L=64R*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V
M86QU93(I("8F("%I<U]O8FIE8W0H)'9A;'5E,BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!297!L86-E(&%S<V]C:6%T:79E(&%R
M<F%Y('1A9W,N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%A
M7W1A9R`]("1T86<@+B`G+B<@+B`D:V5Y,CL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:2`]('-T<E]R97!L86-E*"1T:&ES+3Y?9V5T5&%G
M*"1A85]T86<I+"`D=F%L=64R+"`D:2D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D=&%G+"`G+B<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@H)'!O<R`A/3T@9F%L<V4I
M("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%E;7!T
M>2@D=&AI<RT^7VEF<UMS=6)S='(H)'1A9RP@,"P@)'!O<RE=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEF<ULD
M86%?=&%G72`]("1V86QU93(["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I(#T@)'1H:7,M/E]P87)S94EF*"1A85]T86<L("1I*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]I9G-;)&%A7W1A9UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@0VAE8VL@=&\@
M<V5E(&EF(&ET)W,@82!N97-T960@;&]O<"X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:2`]("1T:&ES+3Y?<&%R<V5,;V]P*"1T86<@+B`G
M+B<@+B`D:V5Y,BP@)'9A;'5E,BP@)&DI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1I(#T@<W1R7W)E
M<&QA8V4H)'1H:7,M/E]G971486<H)'1A9RDL("1K97DL("1I*3L*("`@("`@
M("`@("`@("`@('T@96QS96EF("AI<U]S=')I;F<H)&ME>2D@)B8@(6ES7V%R
M<F%Y*"1V86QU92D@)B8@(6ES7V]B:F5C="@D=F%L=64I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'1H:7,M/E]G
M971486<H)'1A9R`N("<N)R`N("1K97DI+"`D=F%L=64L("1C;VYT96YT<RD[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1V86QU92D@
M)B8@(6ES7V]B:F5C="@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&D@/2!S=')?<F5P;&%C92@D=&AI<RT^7V=E=%1A9R@D=&%G("X@)R<I+"`D
M=F%L=64L("1L;V]P*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&D@/2!N=6QL.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("\O(%!A<G-E(&-O;F1I=&EO;G,@:6X@=&AE(&%R
M<F%Y+@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VEF<ULD
M=&%G75LD:V5Y72D@)B8@:7-?87)R87DH)'1H:7,M/E]I9G-;)'1A9UU;)&ME
M>5TI("8F("1T:&ES+3Y?:69S6R1T86==6R1K97E=*2!["B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I9G-;)'1A9UU;)&ME>5T@87,@
M)&-486<@/3X@)&-686QU92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M:2`]("1T:&ES+3Y?<&%R<V5)9B@D=&%G("X@)RXG("X@)&-486<L("1I+"`D
M:V5Y*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@+R\@061D('1H92!P87)S960@:71E<F%T:6]N
M+@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I*2D@>PH@("`@("`@("`@
M("`@("`@("`@("\O($EF(&ET)W,@;F]T('1H92!F:7)S="!T:6UE('1H<F]U
M9V@L('!R969I>"!T:&4*("`@("`@("`@("`@("`@("`@("`O+R!L;V]P(&1I
M=FED97(L(&EF('1H97)E(&ES(&]N92X*("`@("`@("`@("`@("`@("`@("!I
M9B`H(21F:7)S="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:2`]("1D
M:79I9&5R("X@)&D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1P87)S960@+CT@<G1R:6TH)&DI.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\O($YO(&QO;F=E<B!T:&4@9FER<W0@
M=&EM92!T:')O=6=H+@H@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L<V4[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%)E<&QA8V4@=&AE('!A
M<G-E9"!P:65C97,@;V8@=&AE('1E;7!L871E+@H@("`@("`@("`@("`D8V]N
M=&5N=',@/2!S=')?<F5P;&%C92@D=%LG8B==("X@)&QO;W`@+B`D=%LG92==
M+"`D<&%R<V5D+"`D8V]N=&5N=',I.PH@("`@("`@('T@=VAI;&4@*"1L;V]P
M(#T@)'1H:7,M/E]G9713=&%T96UE;G0H)'0L("1C;VYT96YT<RDI.PH*("`@
M("`@("!R971U<FX@)&-O;G1E;G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4&%R<V5S('1H92!G:79E;B!C87-E(&QO;W`@*&-L;V]P*2X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T86<@("`@("`@5&AE(&YA;64@;V8@=&AE(&-L;V]P('1O('!A<G-E
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D87)R87D@("`@(%1H92!V86QU97,@
M9F]R('1H92!C;&]O<"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G1S
M("!4:&4@=6YP87)S960@8V]N=&5N=',@;V8@=&AE(&-L;V]P+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R<V5D(&-O;G1E;G1S(&]F
M('1H92!C;&]O<"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E0VQO;W`H
M)'1A9RP@)&%R<F%Y+"`D8V]N=&5N=',I"B`@("!["B`@("`@("`@+R\@1V5T
M('1H92!T86=S("8@8VQO;W`N"B`@("`@("`@)'0@/2`D=&AI<RT^7V=E=%1A
M9W,H)'1A9RP@)V-L;V]P)RD["@H@("`@("`@('=H:6QE("@D;&]O<"`]("1T
M:&ES+3Y?9V5T4W1A=&5M96YT*"1T+"`D8V]N=&5N=',I*2!["B`@("`@("`@
M("`@("\O(%-E="!U<"!T:&4@8V%S97,N"B`@("`@("`@("`@("1A<G)A>5LG
M8V%S97,G75M=(#T@)V1E9F%U;'0G.PH@("`@("`@("`@("`D8V%S95]C;VYT
M96YT(#T@87)R87DH*3L*"B`@("`@("`@("`@("\O($=E="!T:&4@8V%S92!S
M=')I;F=S+@H@("`@("`@("`@("!F;W)E86-H("@D87)R87E;)V-A<V5S)UT@
M87,@)&-A<V4I('L*("`@("`@("`@("`@("`@("1C=&%G<ULD8V%S95T@/2`D
M=&AI<RT^7V=E=%1A9W,H)&-A<V4L("=C87-E)RD["B`@("`@("`@("`@("`@
M("`D8V%S95]C;VYT96YT6R1C87-E72`]("1T:&ES+3Y?9V5T4W1A=&5M96YT
M*"1C=&%G<ULD8V%S95TL("1L;V]P*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@4')O8V5S<R!T:&4@8VQO;W`N"B`@("`@("`@("`@("1P87)S
M960@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y6R=A<G)A>2==
M(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?
M;G5M97)I8R@D:V5Y*2`F)B`H:7-?87)R87DH)'9A;'5E*2!\?"!I<U]O8FIE
M8W0H)'9A;'5E*2DI('L*("`@("`@("`@("`@("`@("`@("`O+R!3970@=7`@
M=&AE(&-A<V5S+@H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L
M=65;)V-A<V4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?8V%S92`]("1V86QU95LG8V%S92==.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-A
M<V4@/2`G9&5F875L="<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1V86QU95LG8V%S92==*3L*("`@("`@("`@
M("`@("`@("`@("`D:2`]("1C87-E7V-O;G1E;G1;)&-U<G)E;G1?8V%S95T[
M"@H@("`@("`@("`@("`@("`@("`@("\O($QO;W`@=&AR;W5G:"!E86-H('9A
M;'5E+@H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D
M:V5Y,B`]/B`D=F%L=64R*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D=F%L=64R*2!\?"!I<U]O8FIE8W0H)'9A;'5E,BDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I(#T@)'1H:7,M/E]P87)S
M94QO;W`H)'1A9R`N("<N)R`N("1K97DR+"`D=F%L=64R+"`D:2D["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:2`]('-T<E]R97!L86-E*"1T:&ES+3Y?9V5T5&%G*"1T
M86<@+B`G+B<@+B`D:V5Y,BDL("1V86QU93(L("1I*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!!9&0@=&AE('!A<G-E9"!I
M=&5R871I;VXN"B`@("`@("`@("`@("`@("`D<&%R<V5D("X](')T<FEM*"1I
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4&%R<V4@=&AE(&-L
M;V]P+@H@("`@("`@("`@("`D8V]N=&5N=',@/2!S=')?<F5P;&%C92@D=%LG
M8B==("X@)&QO;W`@+B`D=%LG92==+"`D<&%R<V5D+"`D8V]N=&5N=',I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;VYT96YT<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($9E=&-H('1H92!C;VYT96YT<R!O9B!A('1E;7!L871E
M(&EN=&\@)'1H:7,M/E]T96UP;&%T93L@8V%C:&4*("`@("`J('1H92!F:6QE
M;F%M92!I;B`D=&AI<RT^7W1E;7!L871E1FEL92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE;F%M92`@3&]C871I;VX@;V8@=&5M<&QA=&4@9FEL92!O;B!D:7-K+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]A9&5D('1E;7!L
M871E(&-O;G1E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971496UP;&%T
M92@D9FEL96YA;64@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D9FEL96YA;64I("8F("@D9FEL96YA;64@(3T@)'1H:7,M/E]T96UP;&%T
M949I;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&5M<&QA=&4@/2!N=6QL
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?=&5M
M<&QA=&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1E;7!L871E
M.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T('1H92!C;VYT96YT<R!O9B!T
M:&4@9FEL92X*("`@("`@("`D9FEL92`]("1T:&ES+3Y?8F%S97!A=&@@+B`D
M9FEL96YA;64["B`@("`@("`@)&-O;G1E;G1S(#T@0&9I;&5?9V5T7V-O;G1E
M;G1S*"1F:6QE*3L*("`@("`@("!I9B`H)&-O;G1E;G1S(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")496UP
M;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(I+"`D9FEL92DI.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]T96UP;&%T92`]("1C;VYT96YT<SL*("`@("`@
M("`D=&AI<RT^7W1E;7!L871E1FEL92`]("1F:6QE;F%M93L*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=&5M<&QA=&4["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@N<&AP````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,T,S$P`#$P-3$U-#,Q
M,#8Q`#`Q-S<V-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($AO<F1E(&=R87!H:6YG('-U:71E
M+@H@*@H@*B!0<F]V:61E<R!A('-E="!O9B!G<F%P:"!B86-K96YD<R!A;F0@
M;65T:&]D<R!F;W(@8W)E871I;F<@9W)A<&AS(&%S"B`J($A434P@=&%B;&5S
M+"!35D<@:6UA9V5S+"!E=&,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T=R
M87!H+T=R87!H+G!H<"QV(#$N,C<N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C$X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@
M*B\*8VQA<W,@2&]R9&5?1W)A<&@@>PH*("`@("\J*@H@("`@("H@5&AE($AO
M<F1E7TEM86=E(&EN<W1A;F-E('1H870@=V4@87)E(&1R87=I;F<@=&AE(&=R
M87!H('1O+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*B!`=F%R($AO<F1E7TEM86=E"B`@("`@*B\*("`@('9A<B`D:6UG.PH*("`@
M('9A<B`D7V=R87!H<R`](&%R<F%Y*"D["@H@("`@=F%R("1?:&5I9VAT.PH@
M("`@=F%R("1?=VED=&@["@H@("`@=F%R("1?=&ET;&4@/2`G)SL*"B`@("!V
M87(@)%]B86-K9W)O=6YD(#T@)VQI9VAT9W)A>2<["B`@("!V87(@)%]T:71L
M949O;G0@/2`G<V%N<RUS97)I9B<["B`@("!V87(@)%]L86)E;$9O;G0@/2`G
M<V%N<RUS97)I9B<["B`@("!V87(@)%]A>&ES1F]N="`]("=M;VYO<W!A8V4G
M.PH*("`@('9A<B`D7W!A9&1I;F=,969T(#T@-C`["B`@("!V87(@)%]P861D
M:6YG0F]T=&]M(#T@-#`["B`@("!V87(@)%]P861D:6YG5&]P(#T@,S`["B`@
M("!V87(@)%]P861D:6YG4FEG:'0@/2`R,#L*"B`@("!V87(@)%]O9F9S971'
M<FED6"`](#`["@H@("`@=F%R("1?:6UG5'EP92`]("=G9"<["@H@("`@=F%R
M("1?9&%T82`](&%R<F%Y*"=X)R`]/B!A<G)A>2@I+`H@("`@("`@("`@("`@
M("`@("`@("`@("=Y)R`]/B!A<G)A>2@I*3L*"B`@("!V87(@)%]T;7!D:7([
M"@H@("`@=F%R("1?<&QO=',@/2!A<G)A>2@I.PH@("`@=F%R("1?8VAA<G1S
M(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!(;W)D95]'<F%P:"@D<&%R86US
M*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG=&5M<"==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W1M<&1I<B`]("1P87)A;7-;)W1E;7`G
M73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG=VED
M=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]W:61T:"`]("1P87)A;7-;
M)W=I9'1H)UT["B`@("`@("`@("`@("1T:&ES+3Y?:&5I9VAT(#T@)'!A<F%M
M<ULG:&5I9VAT)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1P
M87)A;7-;)VEM9U1Y<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]I;6=4
M>7!E(#T@)'!A<F%M<ULG:6UG5'EP92==.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B`F861D4&QO="@D<&QO=%1Y<&4L("1P;&]T4&%R86US*0H@
M("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7V-H87)T<RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TUI>&EN9R!O9B!#
M:&%R=',@86YD(%!L;W1S(&ES(&YO="!A;&QO=V5D+B<I.PH@("`@("`@('T*
M"B`@("`@("`@)'!L;W14>7!E(#T@8F%S96YA;64H)'!L;W14>7!E*3L*("`@
M("`@("!`:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]'<F%P
M:"]0;&]T+R<@+B`D<&QO=%1Y<&4@+B`G+G!H<"<["@H@("`@("`@("1C;&%S
M<R`]("=(;W)D95]'<F%P:%]0;&]T7R<@+B`D<&QO=%1Y<&4["B`@("`@("`@
M:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1P;&]T
M(#T@)FYE=R`D8VQA<W,H)'1H:7,L("1P;&]T4&%R86US*3L*("`@("`@("`@
M("`@)'1H:7,M/E]P;&]T<UM=(#T@)B1P;&]T.PH@("`@("`@("`@("!R971U
M<FX@)'!L;W0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)U!L;W0@='EP92!N;W0@9F]U;F0G*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@)F%D9$-H87)T*"1C:&%R=%1Y
M<&4L("1C:&%R=%!A<F%M<RD*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H
M:7,M/E]P;&]T<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)TUI>&EN9R!O9B!#:&%R=',@86YD(%!L;W1S(&ES(&YO="!A;&QO
M=V5D+B<I.PH@("`@("`@('T*"B`@("`@("`@)&-H87)T5'EP92`](&)A<V5N
M86UE*"1C:&%R=%1Y<&4I.PH@("`@("`@($!I;F-L=61E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+T=R87!H+T-H87)T+R<@+B`D8VAA<G14>7!E("X@
M)RYP:'`G.PH*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?1W)A<&A?0VAA<G1?
M)R`N("1C:&%R=%1Y<&4["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA
M<W,I*2!["B`@("`@("`@("`@("1C:&%R="`]("9N97<@)&-L87-S*"1T:&ES
M+"`D8VAA<G1087)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^7V-H87)T<UM=
M(#T@)B1C:&%R=#L*("`@("`@("`@("`@<F5T=7)N("1C:&%R=#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G0VAA<G0@='EP92!N;W0@9F]U;F0G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@861D6$1A=&$H)&1A=&$I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]D871A6R=X)UT@/2`D9&%T83L*("`@('T*"B`@("!F=6YC=&EO;B!A
M9&191&%T82@D9&%T82P@)&YA;64@/2`G)RD*("`@('L*("`@("`@("!I9B`H
M96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("1N86UE(#T@;60U*'-E<FEA
M;&EZ92@D9&%T82DI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V1A=&%;
M)WDG75LD;F%M95T@/2`D9&%T83L*("`@("`@("!R971U<FX@)&YA;64["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T*"1P87)A;2D*("`@('L*("`@("`@("`D
M:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI
M<RT^)&ME>2D@/R`D=&AI<RT^)&ME>2`Z(&YU;&P["B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T*"1P87)A;2P@)'9A;'5E*0H@("`@>PH@("`@("`@("1K97D@
M/2`G7R<@+B`D<&%R86T["B`@("`@("`@)'1H:7,M/B1K97D@/2`D=F%L=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86-H92!T:&4@:6UA9V4@86YD(')E
M='5R;B!A(&QI;FL@=&\@=FEE=R!I="!O=70@;V8@=&AE(&-A8VAE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8L("1R96=I<W1R>3L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+T-A8VAE+G!H<"<["B`@("`@("`@)&-A8VAE(#T@)DAO<F1E7T-A8VAE
M.CIS:6YG;&5T;VXH)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==+"!(;W)D93HZ
M9V5T1')I=F5R0V]N9FEG*"=C86-H92<L("1C;VYF6R=C86-H92==6R=D<FEV
M97(G72DI.PH*("`@("`@("`D=&AI<RT^:6YI=&EA;&EZ92@I.PH*("`@("`@
M("`D8VED(#T@;60U*'-E<FEA;&EZ92@D=&AI<RDI.PH@("`@("`@("1C86-H
M92T^<V5T*"1C:60L('-E<FEA;&EZ92AA<G)A>2@G9&%T82<@/3X@)'1H:7,M
M/F1R87<H9F%L<V4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8W1Y<&4G(#T^("1T:&ES+3YI;6<M/F=E=$-O;G1E;G14
M>7!E*"DI*2D["@H@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R
M>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+V-A8VAE
M=FEE=RYP:'`G*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=C:60G+"`D8VED*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YI
M;6<M/F=E=$QI;FLH)'5R;"P@)'1H:7,M/E]T:71L92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!0<F]C97-S(&%L;"!O9B!T:&4@9&%T82!S971S(&%N9"!S
M970@9W)A<&@@<')O<&5R=&EE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI
M=&EA;&EZ92@D;6EN62`](&9A;'-E+"`D<W1E<$QA8F5L<UD@/2!F86QS92D*
M("`@('L*("`@("`@("`O+R!,;V%D(&$@2&]R9&5?26UA9V4@8V%N=F%S('1O
M(&1R87<@;VXN"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]);6%G92YP
M:'`G.PH@("`@("`@("1T:&ES+3YI;6<@/2`F2&]R9&5?26UA9V4Z.F9A8W1O
M<GDH)'1H:7,M/E]I;6=4>7!E+"!A<G)A>2@G:&5I9VAT)R`]/B`D=&AI<RT^
M7VAE:6=H="P@)W=I9'1H)R`]/B`D=&AI<RT^7W=I9'1H+"`G=&5M<"<@/3X@
M)'1H:7,M/E]T;7!D:7(I*3L*"B`@("`@("`@+R\@5&]T86P@:6UA9V4@86YD
M(&=R87!H(&%R96$@9&EM96YS:6]N<RX*("`@("`@("`D=VED=&@@/2`D=&AI
M<RT^7W=I9'1H("T@,3L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/E]H96EG
M:'0@+2`Q.PH*("`@("`@("`D=&AI<RT^7V=R87!H5&]P(#T@)'1H:7,M/E]P
M861D:6YG5&]P.PH@("`@("`@("1T:&ES+3Y?9W)A<&A";W1T;VT@/2`D=&AI
M<RT^7VAE:6=H="`M(#$@+2`H)'1H:7,M/E]P861D:6YG5&]P("L@)'1H:7,M
M/E]P861D:6YG0F]T=&]M*3L*("`@("`@("`D=&AI<RT^7V=R87!H3&5F="`]
M("1T:&ES+3Y?<&%D9&EN9TQE9G0["B`@("`@("`@)'1H:7,M/E]G<F%P:%)I
M9VAT(#T@)'1H:7,M/E]W:61T:"`M("1T:&ES+3Y?<&%D9&EN9U)I9VAT("T@
M,3L*("`@("`@("`D=&AI<RT^7V=R87!H2&5I9VAT(#T@)'1H:7,M/E]G<F%P
M:$)O='1O;2`M("1T:&ES+3Y?9W)A<&A4;W`["B`@("`@("`@)'1H:7,M/E]G
M<F%P:%=I9'1H(#T@)'1H:7,M/E]G<F%P:%)I9VAT("T@)'1H:7,M/E]G<F%P
M:$QE9G0["@H@("`@("`@("1T:&ES+3Y?9W)I9%@@/2!M:6XH8V]U;G0H)'1H
M:7,M/E]D871A6R=X)UTI+"!R;W5N9"@D=&AI<RT^7V=R87!H5VED=&@@+R`T
M,"DI.PH@("`@("`@(&EF("@A)'1H:7,M/E]G<FED6"D@>PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)TYO(&1A=&$N)RD["B`@("`@("`@?0H*("`@
M("`@("`O+R!&:6YD('1H92!R86YG92!O9B!A;&P@>2!V86QU97,N"B`@("`@
M("`@)'ED871A(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V=R:619(#T@
M,#L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&%;)WDG72!A<R`D9&%T
M82D@>PH@("`@("`@("`@("`D=&AI<RT^7V=R:619(#T@;6%X*"1T:&ES+3Y?
M9W)I9%DL(&-O=6YT*"1D871A*2D["B`@("`@("`@("`@("1Y9&%T82`](&%R
M<F%Y7VUE<F=E*"1Y9&%T82P@)&1A=&$I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]M87A8(#T@8V]U;G0H)'1H:7,M/E]D871A6R=X)UTI.PH@("`@
M("`@(&QI<W0H)'1H:7,M/E]M:6Y9+"`D=&AI<RT^7VUA>%DI(#T@)'1H:7,M
M/E]F:6YD4F%N9V4H)'ED871A*3L*("`@("`@("!I9B`H)&UI;ED@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1T:&ES+3Y?;6EN62`]("1M:6Y9.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]D:69F62`]("1T:&ES+3Y?;6%X62`M
M("1T:&ES+3Y?;6EN63L*"B`@("`@("`@+R\@0V%L8W5L871E('1H92!N=6UB
M97(@;V8@62!G<FED;&EN97,@*&%N9"!T:'5S+"!L86)E;',I('1O"B`@("`@
M("`@+R\@<VAO=RX@5')Y('1O(&UA:V4@<W5R92!W92!D;VXG="!E;F0@=7`@
M=VET:"!T;V\@9&5N<V4@80H@("`@("`@("\O(&=R:60L(&)U="!A;'-O(&UA
M:V4@<W5R92!T:&%T('=E(&AA=F4@82!F97<@9W)I9"!L:6YE<R!T;PH@("`@
M("`@("\O(&)R96%K('5P('-M86QL(&1A=&%S971S+@H@("`@("`@(&EF("@D
M<W1E<$QA8F5L<UD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M9W)I9%D@/2!M87@H;6EN*"1T:&ES+3Y?9W)I9%DL(&9L;V]R*"1T:&ES+3Y?
M9W)A<&A(96EG:'0@+R`S,"DI+"!F;&]O<B@D=&AI<RT^7V=R87!H2&5I9VAT
M("\@-C`I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7V=R:619(#T@9FQO;W(H*"1T:&ES+3Y?;6%X62`M("1T:&ES+3Y?;6EN62D@
M+R`D<W1E<$QA8F5L<UDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D=&AI
M<RT^7VUA>%D@+2`D=&AI<RT^7VUI;EDI(#T](#`I('L*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=.;R!R86YG92!T;R!G<F%P:"X@0VAE8VL@9&%T
M82XG*3L*("`@("`@("!]"@H@("`@("`@("\O($9O<FUA="!T97AT(&9O<B!L
M86)E;&EN9R!T:&4@62!A>&ES+@H@("`@("`@(&EF("@D<W1E<$QA8F5L<UD@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("1D96QT84QA8F5L<UD@/2`H)'1H
M:7,M/E]M87A9("T@)'1H:7,M/E]M:6Y9*2`O("@D=&AI<RT^7V=R:619*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&5L=&%,86)E;'-9(#T@
M)'-T97!,86)E;'-9.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P]("1T:&ES+3Y?9W)I9%D[("1I*RLI('L*("`@("`@("`@("`@)'1E
M>'0@/2`D=&AI<RT^7VUI;ED@*R`H)&1E;'1A3&%B96QS62`J("1I*3L*("`@
M("`@("`@("`@)'1H:7,M/E]L86)E;'-96R1I72`](&YU;6)E<E]F;W)M870H
M)'1E>'0L(#(I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]L86)E;'-9*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO
M(%D@87AI<R!D871A+B<I.PH@("`@("`@('T*"B`@("`@("`@+R\@0V%L8W5L
M871E('1H92!S<&%C:6YG(&9O<B!T:6-K<R!A;F0@9W)I9"!L:6YE<RX*("`@
M("`@("`D9&5N;VUI;F%T;W(@/2`D=&AI<RT^7VUA>%@@+2`Q("L@*#(@*B`D
M=&AI<RT^7V]F9G-E=$=R:618*3L*("`@("`@("!I9B`H)&1E;F]M:6YA=&]R
M(#T](#`I('L*("`@("`@("`@("`@)&1E;F]M:6YA=&]R(#T@,3L*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/E]F86-T;W)8(#T@)'1H:7,M/E]G<F%P:%=I
M9'1H("\@)&1E;F]M:6YA=&]R.PH@("`@("`@("1T:&ES+3Y?9F%C=&]R62`]
M("1T:&ES+3Y?9W)A<&A(96EG:'0@+R`D=&AI<RT^7V1I9F99.PH*("`@("`@
M("`D9&5N;VUI;F%T;W(@/2`D=&AI<RT^7V=R:618("T@,2`K(#(@*B`D=&AI
M<RT^7V]F9G-E=$=R:618.PH@("`@("`@(&EF("@D9&5N;VUI;F%T;W(@/3T@
M,"D@>PH@("`@("`@("`@("`D9&5N;VUI;F%T;W(@/2`Q.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7V1E;'1A5&EC:W-8(#T@*"1T:&ES+3Y?9W)A<&A7
M:61T:"`O("1D96YO;6EN871O<BD@+R`D=&AI<RT^7V9A8W1O<E@["B`@("`@
M("`@:68@*"1S=&5P3&%B96QS62`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M)'1H:7,M/E]D96QT851I8VMS62`]("@D=&AI<RT^7V=R87!H2&5I9VAT("\@
M)'1H:7,M/E]G<FED62D@+R`D=&AI<RT^7V9A8W1O<ED["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]D96QT851I8VMS62`]("1S=&5P
M3&%B96QS63L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&1R87<H)&1I<W!L87D@/2!T<G5E+"`D;6EN62`]
M(&9A;'-E+"`D9&5L=&%,86)E;'-9(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YI;FET:6%L:7IE*"1M:6Y9+"`D9&5L=&%,86)E
M;'-9*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@)'!L;W1S(#T@8V]U;G0H)'1H:7,M/E]P;&]T<RD["B`@("`@("`@
M)&-H87)T<R`](&-O=6YT*"1T:&ES+3Y?8VAA<G1S*3L*"B`@("`@("`@:68@
M*"1P;&]T<RD@>PH@("`@("`@("`@("`D=&AI<RT^9')A=T)A8VMG<F]U;F0H
M*3L*("`@("`@("`@("`@)'1H:7,M/F1R87=4:71L92@I.PH@("`@("`@("`@
M("`D=&AI<RT^9')A=T=R:618*"D["B`@("`@("`@("`@("1T:&ES+3YD<F%W
M1W)I9%DH*3L*("`@("`@("`@("`@)'1H:7,M/F1R87=0;&]T0F]X*"D["B`@
M("`@("`@("`@("1T:&ES+3YD<F%W3&%B96QS6"@I.PH@("`@("`@("`@("`D
M=&AI<RT^9')A=TQA8F5L<UDH*3L*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1P;&]T<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P;&]T<ULD:5TM/F1R87<H)'1H:7,M/E]M:6Y9*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS96EF("@D8VAA<G1S*2!["B`@("`@("`@("`@("1T
M:&ES+3YD<F%W5&ET;&4H*3L*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1C:&%R=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8VAA<G1S6R1I72T^9')A=R@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&1I<W!L87D@/R`D=&AI<RT^:6UG+3YD:7-P;&%Y
M*"D@.B`D=&AI<RT^:6UG+3YR87<H*3L*("`@('T*"B`@("!F=6YC=&EO;B!D
M<F%W0F%C:V=R;W5N9"@I"B`@("!["B`@("`@("`@)'1H:7,M/FEM9RT^<F5C
M=&%N9VQE*#`L(#`L("1T:&ES+3Y?=VED=&@@+2`Q+"`D=&AI<RT^7VAE:6=H
M="`M(#$L("=B;&%C:R<L("1T:&ES+3Y?8F%C:V=R;W5N9"D["B`@("`@("`@
M)'1H:7,M/FEM9RT^<F5C=&%N9VQE*"1T:&ES+3Y?9W)A<&A,969T+"`D=&AI
M<RT^7V=R87!H5&]P+"`D=&AI<RT^7V=R87!H5VED=&@L("1T:&ES+3Y?9W)A
M<&A(96EG:'0L("=B;&%C:R<L("=W:&ET92<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1')A=R!A(&)O>"!A<F]U;F0@=&AE('!L;W0@87)E82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9')A=U!L;W1";W@H*0H@("`@>PH@("`@("`@("1T
M:&ES+3YI;6<M/G)E8W1A;F=L92@D=&AI<RT^7V=R87!H3&5F="P@)'1H:7,M
M/E]G<F%P:%1O<"P@)'1H:7,M/E]G<F%P:%=I9'1H+"`D=&AI<RT^7V=R87!H
M2&5I9VAT+"`G8FQA8VLG*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87=S
M(&=R:60@;&EN97,@9G)O;2!T;W`@=&\@8F]T=&]M(&]N('1H92!I;6%G92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9')A=T=R:618*"D*("`@('L*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^7V=R:618.R`D:2LK*2!["B`@
M("`@("`@("`@("1X(#T@)'1H:7,M/G1R86YS;&%T95@H)'1H:7,M/E]D96QT
M851I8VMS6"`J("1I*3L*("`@("`@("`@("`@)'1H:7,M/FEM9RT^9&%S:&5D
M3&EN92@D>"P@)'1H:7,M/E]G<F%P:%1O<"P@)'@L("1T:&ES+3Y?9W)A<&A"
M;W1T;VTL("=G<F%Y)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1')A=W,@9W)I9"!L:6YE<R!F<F]M(&QE9G0@=&\@<FEG:'0@;VX@=&AE
M(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D<F%W1W)I9%DH*0H@("`@
M>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\/2`D=&AI<RT^7V=R:619.R`D
M:2LK*2!["B`@("`@("`@("`@("1Y(#T@)'1H:7,M/G1R86YS;&%T95DH)'1H
M:7,M/E]M:6Y9("L@)'1H:7,M/E]D96QT851I8VMS62`J("1I*3L*("`@("`@
M("`@("`@)'1H:7,M/FEM9RT^9&%S:&5D3&EN92@D=&AI<RT^7V=R87!H3&5F
M="P@)'DL("1T:&ES+3Y?9W)A<&A2:6=H="P@)'DL("=G<F%Y)RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!T:&4@=&ET;&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1R87=4:71L92@I"B`@("!["B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W1I=&QE*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^:6UG+3YT97AT*"1T:&ES+3Y?=&ET;&4L("1T:&ES+3Y?9W)A<&A,969T
M("L@*"1T:&ES+3Y?9W)A<&A7:61T:"`O(#(I("T@*"AS=')L96XH)'1H:7,M
M/E]T:71L92D@+R`R*2`J(#<I+"`D=&AI<RT^7V=R87!H5&]P("T@,C`L("1T
M:&ES+3Y?=&ET;&5&;VYT*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$<F%W<R!T:&4@87AI<R!T86<@=&5X="!O=71S:61E('1H92!P;&]T
M=&EN9R!A<F5A(&]N('1H92!X"B`@("`@*B!A>&ES+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D<F%W3&%B96QS6"@I"B`@("!["B`@("`@("`@+R\@1')A=R!8
M(&%X:7,@;&%B96PN"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7WAL86)E
M;"DI('L*("`@("`@("`@("`@)'@@/2`D=&AI<RT^7V=R87!H3&5F="`K("@D
M=&AI<RT^7V=R87!H5VED=&@@+R`R*2`M("AS=')L96XH)'1H:7,M/E]X;&%B
M96PI("H@,RD["B`@("`@("`@("`@("1Y(#T@)'1H:7,M/E]G<F%P:$)O='1O
M;2`K(#4P.PH@("`@("`@("`@("`D=&AI<RT^:6UG+3YT97AT*"1T:&ES+3Y?
M>&QA8F5L+"`D>"P@)'DL("1T:&ES+3Y?;&%B96Q&;VYT*3L*("`@("`@("!]
M"@H@("`@("`@("1L87-T6"`](#`["B`@("`@("`@)&UI;D1I9F8@/2`R,#L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&%;)W@G72!A<R`D:2`]/B`D
M=&5X="D@>PH@("`@("`@("`@("`D>"`]("1T:&ES+3YT<F%N<VQA=&58*"1I
M*3L*("`@("`@("`@("`@:68@*"1X("T@)&QA<W18(#X]("1M:6Y$:69F*2![
M"B`@("`@("`@("`@("`@("`D;&%S=%@@/2`D>#L*("`@("`@("`@("`@("`@
M("1T:&ES+3YI;6<M/G1E>'0H)'1E>'0L("1X("T@-2P@)'1H:7,M/E]G<F%P
M:$)O='1O;2`K("AS=')L96XH)'1E>'0I("H@-RDL("1T:&ES+3Y?87AI<T9O
M;G0L("=B;&%C:R<L("TY,"D["B`@("`@("`@("`@("`@("`D=&AI<RT^:6UG
M+3YL:6YE*"1X+"`D=&AI<RT^7V=R87!H0F]T=&]M("L@,BP@)'@L("1T:&ES
M+3Y?9W)A<&A";W1T;VT@+2`R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1R87=S('1H92!A>&ES('1A9R!T97AT
M(&]U='-I9&4@=&AE('!L;W1T:6YG(&%R96$@;VX@=&AE('D*("`@("`J(&%X
M:7,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R87=,86)E;'-9*"D*("`@('L*
M("`@("`@("`O+R!$<F%W(%D@87AI<R!L86)E;"X*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?>6QA8F5L*2D@>PH@("`@("`@("`@("`D>2`]("1T:&ES
M+3Y?9W)A<&A4;W`@*R`H)'1H:7,M/E]G<F%P:$AE:6=H="`O(#(I("L@*"AS
M=')L96XH)'1H:7,M/E]Y;&%B96PI("\@,BD@*B`U*3L*("`@("`@("`@("`@
M)'1H:7,M/FEM9RT^=&5X="@D=&AI<RT^7WEL86)E;"P@-2P@)'DL("1T:&ES
M+3Y?;&%B96Q&;VYT+"`G8FQA8VLG+"`M.3`I.PH@("`@("`@('T*"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]L86)E;'-9(&%S("1I(#T^("1L86)E;"D@
M>PH@("`@("`@("`@("`D>2`]("1T:&ES+3YT<F%N<VQA=&59*"1T:&ES+3Y?
M;6EN62`K("1I("H@)'1H:7,M/E]D96QT851I8VMS62D["B`@("`@("`@("`@
M("1T:&ES+3YI;6<M/G1E>'0H)&QA8F5L+"`D=&AI<RT^7V=R87!H3&5F="`M
M("AS=')L96XH)&QA8F5L*2`J(#<I+"`D>2`M(#4L("1T:&ES+3Y?87AI<T9O
M;G0I.PH@("`@("`@("`@("`D=&AI<RT^:6UG+3YL:6YE*"1T:&ES+3Y?9W)A
M<&A,969T("T@,BP@)'DL("1T:&ES+3Y?9W)A<&A,969T("L@,BP@)'DI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@82!P86ER(&]F
M("AX+'DI(&=R87!H(&-O;W)D:6YA=&5S(&%N9"!R971U<FX@=&AE"B`@("`@
M*B!S8W)E96XM<&EX96P@8V]O<F1I;F%T97,@9F]R('1H96TN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&9L;V%T("8D>"`@("`@5&AE('@@<&]S:71I;VX@:6X@
M=V]R;&0@8V]O<F1I;F%T97,N"B`@("`@*B!`<&%R86T@9FQO870@)B1Y("`@
M("!4:&4@>2!P;W-I=&EO;B!I;B!W;W)L9"!C;V]R9&EN871E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@=')A;G-L871E*"8D>"P@)B1Y*0H@("`@>PH@("`@
M("`@("1X(#T@)'1H:7,M/G1R86YS;&%T95@H)'@I.PH@("`@("`@("1Y(#T@
M)'1H:7,M/G1R86YS;&%T95DH)'DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5')A;G-L871E('1H92!X(&-O;W)D:6YA=&4@;V8@82!P;VEN="!O;B!T:&4@
M<&QO="!T;R!S8W)E96X*("`@("`J(&-O;W)D:6YA=&5S+@H@("`@("H*("`@
M("`J($!P87)A;2!F;&]A="`D>"`@5&AE('@@=V]R;&0@*'!L;W0I(&-O;W)D
M:6YA=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R86YS;&%T95@H)'@I"B`@
M("!["B`@("`@("`@<F5T=7)N("@H)'@@*R`D=&AI<RT^7V]F9G-E=$=R:618
M*2`J("1T:&ES+3Y?9F%C=&]R6"D@*R`D=&AI<RT^7V=R87!H3&5F=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1R86YS;&%T92!T:&4@>2!C;V]R9&EN871E
M(&]F(&$@<&]I;G0@;VX@=&AE('!L;W0@=&\@<V-R965N"B`@("`@*B!C;V]R
M9&EN871E<RX*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'D@(%1H92!Y
M('=O<FQD("AP;&]T*2!C;V]R9&EN871E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!T<F%N<VQA=&59*"1Y*0H@("`@>PH@("`@("`@(&EF("@D>2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]G<F%P:$)O='1O;2`M("@H)'D@+2`D
M=&AI<RT^7VUI;EDI("H@)'1H:7,M/E]F86-T;W)9*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G<F%P:$)O='1O;3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD('1H92!M:6YI
M;75M(&%N9"!M87AI;75M('9A;'5E<R!F;W(@82!S970@;V8@9&%T82X*("`@
M("`J"B`@("`@*B!4:&4@)')E<V]L=71I;VX@=F%R:6%B;&4@:7,@=7-E9"!F
M;W(@<F]U;F1I;F<@;6%X:6UU;2!A;F0*("`@("`J(&UI;FEM=6T@=F%L=65S
M+B!)9B!M87AI;75M('9A;'5E(&ES(#@V-#4@=&AE;CH*("`@("`J"B`@("`@
M*B!)9B`D<F5S;VQU=&EO;B!I<R`P+"!T:&5N(&UA>&EM=6T@=F%L=64@8F5C
M;VUE<R`Y,#`P+@H@("`@("H@268@)')E<V]L=71I;VX@:7,@,2P@=&AE;B!M
M87AI;75M('9A;'5E(&)E8V]M97,@.#<P,"X*("`@("`J($EF("1R97-O;'5T
M:6]N(&ES(#(L('1H96X@;6%X:6UU;2!V86QU92!B96-O;65S(#@V-3`N"B`@
M("`@*B!)9B`D<F5S;VQU=&EO;B!I<R`S+"!T:&5N(&UA>&EM=6T@=F%L=64@
M8F5C;VUE<R`X-C0U+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)&1A
M=&$@("`@("`@("!4:&4@1&%T87-E="!T;R!F:6YD('1H92!R86YG92!F;W(N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6EN("`@("`@("`@36EN:6UU;2!V
M86QU92!T;R!S=&%R="!A="X@5&AE(&QO=V5S="!N=6UB97(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@9&%T87-E="!I<R!U
M<V5D(&EF(&ET)W,@;&]W97(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X
M("`@("`@("`@36%X:6UU;2!V86QU92!T;R!S=&%R="!A="X@5&AE(&AI9VAE
M<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6UB97(@
M:6X@=&AE(&1A=&%S970@:7,@=7-E9"!I9B!I="=S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:&EG:&5R+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)')E<V]L=71I;VX@(%1H92!R97-O;'5T:6]N('1O('5S92!F;W(@
M=&AE(')A;F=E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!M
M:6YI;75M(&%N9"!M87AI;75M('9A;'5E<R!F;W(@=&AE(')A;F=E+@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F:6YD
M4F%N9V4H)&1A=&$L("1M:6X@/2`P+"`D;6%X(#T@,"P@)')E<V]L=71I;VX@
M/2`P*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&1A=&$I*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@G;6EN)R`]/B`P+"`G;6%X)R`]/B`P*3L*
M("`@("`@("!]"@H@("`@("`@("1D871A6UT@/2`D;6%X.PH@("`@("`@("1D
M871A6UT@/2`D;6EN.PH@("`@("`@("1M87@@/2!M87@H)&1A=&$I.PH@("`@
M("`@("1M:6X@/2!M:6XH)&1A=&$I.PH*("`@("`@("!I9B`H)&UA>"`]/2`P
M*2!["B`@("`@("`@("`@("1F86-T;W(@/2`Q.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("@D;6%X(#P@,"D@>PH@("`@("`@("`@("`@("`@
M)&9A8W1O<B`]("UP;W<H,3`L("AF;&]O<BAL;V<Q,"AA8G,H)&UA>"DI*2`K
M("1R97-O;'5T:6]N*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D9F%C=&]R(#T@<&]W*#$P+"`H9FQO;W(H;&]G,3`H86)S*"1M
M87@I*2D@+2`D<F5S;VQU=&EO;BDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D;6%X(#T@)&9A8W1O<B`J($!C96EL*"1M87@@+R`D9F%C
M=&]R*3L*("`@("`@("`D;6EN(#T@)&9A8W1O<B`J($!F;&]O<B@D;6EN("\@
M)&9A8W1O<BD["@H@("`@("`@(')E='5R;B!A<G)A>2@D;6EN+"`D;6%X*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4U%,
M+G!H<```````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#,T,S<W`#$P-3$U-#,Q,#8Q`#`Q-S0P,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AI<R!I<R!A
M('5T:6QI='D@8VQA<W,L(&5V97)Y(&UE=&AO9"!I<R!S=&%T:6,N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U-13"]344PN<&AP+'8@,2XS,"XR+C$W(#(P
M,#8O,#0O,3D@,#,Z-#DZ-#D@8F5N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U(&1I9`H@*B!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J
M($!P86-K86=E($AO<F1E7U-13`H@*B\*8VQA<W,@2&]R9&5?4U%,('L*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!B;V]L96%N(&5X<')E<W-I;VX@=7-I
M;F<@=&AE('-P96-I9FEE9"!O<&5R871O<BX@57-E<PH@("`@("H@9&%T86)A
M<V4M<W!E8VEF:6,@8V%S=&EN9RP@:68@;F5C97-S87)Y+@H@("`@("H*("`@
M("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@4$5!4CHZ1$(@9&%T86)A
M<V4@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&AS("`@(%1H92!C
M;VQU;6X@;W(@97AP<F5S<VEO;B!T;R!T97-T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;W`@("`@(%1H92!O<&5R871O<BX*("`@("`J($!P87)A;2!S=')I
M;F<@)')H<R`@("!4:&4@8V]M<&%R:7-O;B!V86QU92X*("`@("`J($!P87)A
M;2!B;V]L96%N("1B:6YD("!)9B!T<G5E+"!T:&4@;65T:&]D(')E='5R;G,@
M=&AE('%U97)Y(&%N9"!A(&QI<W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!O9B!V86QU97,@<W5I=&%B;&4@9F]R(&)I;F1I;F<@87,@86X@87)R
M87DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!344P@=&5S
M="!F<F%G;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I;&1#;&%U<V4H
M)B1D8F@L("1L:',L("1O<"P@)')H<RP@)&)I;F0@/2!F86QS92D*("`@('L*
M("`@("`@("!S=VET8V@@*"1O<"D@>PH@("`@("`@(&-A<V4@)WPG.@H@("`@
M("`@(&-A<V4@)R8G.@H@("`@("`@("`@("!S=VET8V@@*"1D8F@M/G!H<'1Y
M<&4I('L*("`@("`@("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@("`@("`@
M("`@+R\@3VYL>2!09U-13"`W+C,K('5N9&5R<W1A;F1S(%-13#DY("=324U)
M3$%2(%1/)SL@=7-E"B`@("`@("`@("`@("`@("`O+R!^(&9O<B!G<F5A=&5R
M(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+@H@("`@("`@("`@("`@("`@)'%U
M97)Y(#T@)T-!4T4@5TA%3B!#05-4*"5S($%3(%9!4D-(05(I('X@7"=>+3];
M,"TY72LD7"<@5$A%3B`H0T%35"@E<R!!4R!)3E1%1T52*2`E<R`E<RD@/#X@
M,"!%3%-%($9!3%-%($5.1"<["B`@("`@("`@("`@("`@("!I9B`H)&)I;F0I
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH<W!R:6YT9BA(
M;W)D95]344PZ.F5S8V%P95!R97!A<F4H)'%U97)Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]344PZ.F5S8V%P
M95!R97!A<F4H)&QH<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1L:',I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E
M7U-13#HZ97-C87!E4')E<&%R92@D;W`I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<_)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"AI;G0I)')H<RDI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@<W!R
M:6YT9B@D<75E<GDL("1L:',L("1L:',L("1O<"P@*&EN="DD<FAS*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-A<V4@)V]C:3@G.@H@("`@
M("`@("`@("`@("`@+R\@3W)A8VQE('5S97,@)B!F;W(@=F%R:6%B;&5S+B!7
M92!N965D('1O('5S92!T:&4@8FET86YD"B`@("`@("`@("`@("`@("`O+R!F
M=6YC=&EO;B!T:&%T(&ES(&%V86EL86)L92P@8G5T(&UA>2!B92!U;G-U<'!O
M<G1E9"X*("`@("`@("`@("`@("`@("1Q=65R>2`]("=B:71A;F0H)7,L("5S
M*2`]("5S)SL*("`@("`@("`@("`@("`@(&EF("@D8FEN9"D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*$AO<F1E7U-13#HZ
M97-C87!E4')E<&%R92@D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D
M;&AS*2P@)S\G+"`G/R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@H:6YT*21R:',L("AI;G0I)')H<RDI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@<W!R
M:6YT9B@D<75E<GDL("1L:',L("AI;G0I)')H<RP@*&EN="DD<FAS*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@
M("`@("`@("`@("`@("\O($U34U%,(&UU<W0@:&%V92!A('9A;&ED(&)O;VQE
M86X@97AP<F5S<VEO;@H@("`@("`@("`@("`@("`@)'%U97)Y(#T@)RA#05-%
M(%=(14X@25-.54U%4DE#*"5S*2`](#$@5$A%3B`H)7,@)B`E<RD@14Q312`E
M<R!%3D0I(#T@)7,G.PH@("`@("`@("`@("`@("`@:68@*"1B:6YD*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*'-P<FEN=&8H2&]R9&5?
M4U%,.CIE<V-A<&50<F5P87)E*"1Q=65R>2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?4U%,.CIE<V-A<&50<F5P
M87)E*"1L:',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;&AS*2P@)S\G+"`G
M/R<L("<_)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"AI;G0I)')H<RP@*&EN="DD<FAS("T@,2P@*&EN="DD<FAS*2D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!S<')I;G1F*"1Q=65R>2P@)&QH<RP@)&QH<RP@*&EN="DD<FAS+"`H
M:6YT*21R:',@+2`Q+"`H:6YT*21R:',I.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@8V%S92`G;V1B8R<Z"B`@("`@("`@("`@("`@("`O+R!/
M1$)#(&UU<W0@:&%V92!A('9A;&ED(&)O;VQE86X@97AP<F5S<VEO;@H@("`@
M("`@("`@("`@("`@)'%U97)Y(#T@)R@E<R`F("5S*2`]("5S)SL*("`@("`@
M("`@("`@("`@(&EF("@D8FEN9"D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!A<G)A>2AS<')I;G1F*$AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D
M<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;&AS*2P@)S\G+"`G/R<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@H:6YT
M*21R:',L("AI;G0I)')H<RDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@D<75E<GDL("1L
M:',L("AI;G0I)')H<RP@*&EN="DD<FAS*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!I9B`H)&)I
M;F0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH)&QH<R`N
M("<@)R`N($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;W`I("X@)R`_)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH*&EN="DD
M<FAS*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D;&AS("X@)R`G("X@)&]P("X@)R`G("X@*&EN="DD
M<FAS.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M(&-A<V4@)WXG.@H@("`@("`@("`@("!I9B`H)&1B:"T^<&AP='EP92`]/2`G
M;7ES<6PG*2!["B`@("`@("`@("`@("`@("`D;W`@/2`G4D5'15A0)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&)I;F0I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@D;&AS("X@)R`G("X@)&]P("X@)R`_)RP@
M87)R87DH)')H<RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1L:',@+B`G("<@+B`D;W`@+B`G("<@+B`D<FAS.PH@
M("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@)TE.)SH*("`@("`@("`@("`@
M:68@*"1B:6YD*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')H
M<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH)&QH<R`N
M("<@24X@*#\G("X@<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)')H<RD@+2`Q
M*2`N("<I)RP@)')H<RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("\O(%=E(&YE960@=&\@8FEN9"!E86-H(&UE;6)E
M<B!O9B!T:&4@24X@8VQA=7-E"B`@("`@("`@("`@("`@("`@("`@+R\@<V5P
M87)A=&5L>2!T;R!E;G-U<F4@<')O<&5R('%U;W1I;F<N"B`@("`@("`@("`@
M("`@("`@("`@:68@*'-U8G-T<B@D<FAS+"`P+"`Q*2`]/2`G*"<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)')H<R`]('-U8G-T<B@D<FAS+"`Q*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@
M*'-U8G-T<B@D<FAS+"`M,2D@/3T@)RDG*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1R:',@/2!S=6)S='(H)')H<RP@,"P@+3$I.PH@("`@("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)&ED<R`]('!R96=?
M<W!L:70H)R]<<RHL7',J+R<L("1R:',I.PH*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@87)R87DH)&QH<R`N("<@24X@*#\G("X@<W1R7W)E<&5A="@G
M+"`_)RP@8V]U;G0H)&ED<RD@+2`Q*2`N("<I)RP@)&ED<RD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)')H<RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&QH<R`N("<@24X@)R`N(&EM<&QO9&4H)RP@)RP@)')H<RD["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D;&AS("X@)R!)3B`G("X@)')H<SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("!C87-E("=,24M%)SH*("`@("`@("`@
M("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)W!G<W%L)RD@>PH@("`@("`@("`@
M("`@("`@)'%U97)Y(#T@)R5S($E,24M%("5S)SL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1Q=65R>2`]("=,3U=%4B@E<RD@3$E+
M12!,3U=%4B@E<RDG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M8FEN9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*'-P<FEN=&8H
M)'%U97)Y+"!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&QH<RDL("<_)RDL
M(&%R<F%Y*"<E)R`N("1R:',@+B`G)2<I*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"1Q=65R>2P@)&QH
M<RP@)&1B:"T^<75O=&4H)R4G("X@)')H<R`N("<E)RDI.PH@("`@("`@("`@
M("!]"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&EF("@D8FEN9"D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1L:',@+B`G("<@+B!(
M;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&]P*2`N("<@/R<L(&%R<F%Y*"1R
M:',I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D;&AS("X@)R`G("X@)&]P("X@)R`G("X@)&1B:"T^<75O=&4H)')H
M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!%<V-A<&5S(&%L;"!C:&%R86-T97)S(&EN(&$@<W1R:6YG('1H870@
M87)E('!L86-E:&]L9&5R<R!F;W(@=&AE"B`@("`@*B!P<F5P87)E+V5X96-U
M=&4@;65T:&]D<R!O9B!T:&4@1$(@<&%C:V%G92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1Q=65R>2`@02!S=')I;F<@=&\@97-C87!E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]R<F5C=&QY(&5S8V%P
M960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&50<F5P87)E
M*"1Q=65R>2D*("`@('L*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O
M6S\A)ETO)RP@)UQ<7%PD,"<L("1Q=65R>2D["B`@("!]"@H@("`@9G5N8W1I
M;VX@<F5A9$)L;V(H)B1D8F@L("1T86)L92P@)&9I96QD+"`D8W)I=&5R:6$I
M"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I=&5R:6$I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=9;W4@;75S="!S<&5C
M:69Y('1H92!F971C:"!C<FET97)I82<I.PH@("`@("`@('T*"B`@("`@("`@
M)'=H97)E(#T@)R<["@H@("`@("`@('-W:71C:"`H)&1B:"T^9&)S>6YT87@I
M('L*("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@9F]R96%C:"`H
M)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1W:&5R92DI('L*("`@("`@("`@("`@("`@("`@("`D
M=VAE<F4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("AE;7!T>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'=H97)E("X]("1K97D@+B`G($E3($Y53$PG.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)&ME
M>2`N("<@/2`G("X@)&1B:"T^<75O=&4H)'9A;'5E*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-T871E;65N="`]
M($]#25!A<G-E*"1D8F@M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!7
M2$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:65L9"P@)'1A8FQE+"`D=VAE<F4I*3L*("`@("`@("`@("`@
M3T-)17AE8W5T92@D<W1A=&5M96YT*3L*("`@("`@("`@("`@:68@*$]#249E
M=&-H26YT;R@D<W1A=&5M96YT+"`D;&]B*2D@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1L;V);,%TM/FQO860H*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR86ES945R<F]R
M*"=5;F%B;&4@=&\@;&]A9"!344P@1&%T82<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!F
M;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)'=H97)E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1W:&5R92`N/2`G($%.1"`G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'=H97)E("X]("1K97D@+B`G(#T@)R`N("1D8F@M
M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E
M<W5L="`]("1D8F@M/F=E=$]N92AS<')I;G1F*"=314Q%0U0@)7,@1E)/32`E
M<R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9FEE;&0L("1T86)L92P@)'=H97)E*2D["@H@("`@("`@
M("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@("`@("`@("`@(&-A
M<V4@)W!G<W%L)SH*("`@("`@("`@("`@("`@("1R97-U;'0@/2!P86-K*"=(
M)R`N('-T<FQE;B@D<F5S=6QT*2P@)')E<W5L="D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@:6YS97)T0FQO8B@F
M)&1B:"P@)'1A8FQE+"`D9FEE;&0L("1D871A+"`D871T<FEB=71E<RD*("`@
M('L*("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*("`@("`@("`D=F%L=65S
M(#T@87)R87DH*3L*"B`@("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@
M>PH@("`@("`@(&-A<V4@)V]C:3@G.@H@("`@("`@("`@("!F;W)E86-H("@D
M871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@)&9I96QD<UM=(#T@)&ME>3L*("`@("`@("`@("`@("`@("1V86QU97-;
M72`]("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1S=&%T96UE;G0@/2!/0TE087)S92@D9&)H+3YC;VYN96-T:6]N
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G
M24Y315)4($E.5$\@)7,@*"5S+"`E<RDG("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R!604Q515,@*"5S+"!%35!465]"
M3$]"*"DI(%)%5%523DE.1R`E<R!)3E1/(#IB;&]B)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L
M("<L("1F:65L9',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9FEE;&0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)'9A;'5E<RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:65L9"DI
M.PH*("`@("`@("`@("`@)&QO8B`]($]#24YE=T1E<V-R:7!T;W(H)&1B:"T^
M8V]N;F5C=&EO;BD["B`@("`@("`@("`@($]#24)I;F1">4YA;64H)'-T871E
M;65N="P@)SIB;&]B)RP@)&QO8BP@+3$L(%-13%1?0DQ/0BD["B`@("`@("`@
M("`@($]#245X96-U=&4H)'-T871E;65N="P@3T-)7T1%1D%53%0I.PH@("`@
M("`@("`@("`D;&]B+3YS879E*"1D871A*3L*("`@("`@("`@("`@)')E<W5L
M="`]($]#24-O;6UI="@D9&)H+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@
M)&QO8BT^9G)E92@I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S
M=&%T96UE;G0I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L="`_('1R=64@
M.B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N($5R<F]R)RD["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D9FEE;&1S6UT@
M/2`D:V5Y.PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'9A;'5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=)
M3E-%4E0@24Y43R`E<R`H)7,L("5S*2!604Q515,@*"5S*2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&9I96QD<RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I96QD+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<_)R`N('-T<E]R97!E870H)RP@/R<L(&-O=6YT*"1V
M86QU97,I*2D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@
M("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A<V4@)VUS
M<W%L)SH*("`@("`@("!C87-E("=P9W-Q;"<Z"B`@("`@("`@("`@("1V86QU
M97-;72`](&)I;C)H97@H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'9A;'5E<UM=(#T@)&1A=&$[
M"B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"
M54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U-13"!1=65R>2!B>2!(;W)D95]344PZ.FEN<V5R=$)L;V(H*3H@
M<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@=7!D871E0FQO8B@F)&1B:"P@)'1A8FQE+"`D9FEE;&0L
M("1D871A+"`D=VAE<F4L("1A;'-O=7!D871E*0H@("`@>PH@("`@("`@("1F
M:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH*
M("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@("`@("`@8V%S
M92`G;V-I."<Z"B`@("`@("`@("`@("1W:&5R97-T<FEN9R`]("<G.PH@("`@
M("`@("`@("!F;W)E86-H("@D=VAE<F4@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E<W1R:6YG*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`G($%.1"`G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG
M("X]("1K97D@+B`G(#T@)R`N("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE;G0@/2!/0TE087)S92@D
M9&)H+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%4D4@)7,@1D]2
M(%501$%412<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=VAE<F5S=')I;F<I*3L*"B`@("`@("`@("`@
M($]#245X96-U=&4H)'-T871E;65N="P@3T-)7T1%1D%53%0I.PH@("`@("`@
M("`@("!/0TE&971C:$EN=&\H)'-T871E;65N="P@)&QO8BD["B`@("`@("`@
M("`@("1L;V);,%TM/G-A=F4H)&1A=&$I.PH@("`@("`@("`@("`D<F5S=6QT
M(#T@3T-)0V]M;6ET*"1D8F@M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D
M;&]B6S!=+3YF<F5E*"D["B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H
M)'-T871E;65N="D["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT(#\@=')U
M92`Z(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@17)R;W(G*3L*"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@)'5P9&%T97-T<FEN9R`]("<G.PH@
M("`@("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)&%L<V]U<&1A=&4@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@("1U<&1A=&5S=')I;F<@+CT@)&ME>2`N("<@/2`_+"`G.PH@
M("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'9A;'5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1U<&1A=&5S=')I;F<@+CT@)&9I96QD("X@)R`]
M(#\G.PH@("`@("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@
M("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@8V%S92`G<&=S
M<6PG.@H@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@8FEN,FAE>"@D9&%T
M82D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D9&%T83L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'=H97)E<W1R:6YG(#T@)R<["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1W:&5R92!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=VAE<F5S=')I;F<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG("X]("<@04Y$("<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VAE<F5S=')I;F<@
M+CT@)&ME>2`N("<@/2`_)SL*("`@("`@("`@("`@("`@("1V86QU97-;72`]
M("1V86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R!72$5212`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1U<&1A=&5S=')I;F<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=H97)E<W1R:6YG*3L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"
M54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U-13"!1=65R>2!B>2!(;W)D95]344PZ.G5P9&%T94)L;V(H*3H@
M<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@<F5T=7)N
M("1D8F@M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!"=6EL9"!A;B!344P@4T54(&-L875S92X*("`@("`J"B`@("`@
M*B!4:&ES(&9U;F-T:6]N('1A:V5S(&%N(&%R<F%Y(&EN('1H92!F;W)M(&-O
M;'5M;B`]/B!V86QU92!A;F0@<F5T=7)N<PH@("`@("H@86X@4U%,(%-%5"!C
M;&%U<V4@*'=I=&AO=70@=&AE(%-%5"!K97EW;W)D*2!W:71H('1H92!V86QU
M97,@<')O<&5R;'D*("`@("`J('%U;W1E9"X@($9O<B!E>&%M<&QE+"!T:&4@
M9F]L;&]W:6YG.@H@("`@("H*("`@("`J("`@("`@87)R87DH)V9O;R<@/3X@
M,2P*("`@("`J("`@("`@("`@("`@)V)A<B<@/3X@)VAE;&QO)RD*("`@("`J
M"B`@("`@*B!W;W5L9"!R97-U;'0@:6X@=&AE(&9R86=M96YT.@H@("`@("H*
M("`@("`J("`@("`@9F]O(#T@,2P@8F%R(#T@)VAE;&QO)PH@("`@("H*("`@
M("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@4$5!4CHZ1$(@9&%T86)A
M<V4@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU97,@(%1H92!A
M<G)A>2!O9B!C;VQU;6X@/3X@=F%L=64@<&%I<G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!344P@4T54(&9R86=M96YT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!U<&1A=&5686QU97,H)B1D8F@L("1V86QU97,I"B`@
M("!["B`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H
M)'9A;'5E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D<F5T
M6UT@/2`D:V5Y("X@)R`]("<@+B`H)'9A;'5E(#T]/2!N=6QL(#\@)TY53$PG
M(#H@)&1B:"T^<75O=&4H)'9A;'5E*2D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!I;7!L;V1E*"<L("<L("1R970I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0G5I;&0@86X@4U%,($E.4T525"]604Q515,@8VQA=7-E+@H@("`@("H*
M("`@("`J(%1H:7,@9G5N8W1I;VX@=&%K97,@86X@87)R87D@:6X@=&AE(&9O
M<FT@8V]L=6UN(#T^('9A;'5E(&%N9"!R971U<FYS"B`@("`@*B!A;B!344P@
M9G)A9VUE;G0@<W!E8VEF>6EN9R!T:&4@8V]L=6UN(&YA;65S(&%N9"!I;G-E
M<G0@=F%L=65S+"!W:71H"B`@("`@*B!T:&4@=F%L=65S('!R;W!E<FQY('%U
M;W1E9"X@($9O<B!E>&%M<&QE+"!T:&4@9F]L;&]W:6YG.@H@("`@("H*("`@
M("`J("`@("`@87)R87DH)V9O;R<@/3X@,2P*("`@("`J("`@("`@("`@("`@
M)V)A<B<@/3X@)VAE;&QO)RD*("`@("`J"B`@("`@*B!W;W5L9"!R97-U;'0@
M:6X@=&AE(&9R86=M96YT.@H@("`@("H*("`@("`J("`@("`@*"!F;V\L(&)A
M<B`I(%9!3%5%4R`H(#$L("=H96QL;R<@*0H@("`@("H*("`@("`J($!P87)A
M;2!$0B`D9&)H("`@("`@("!4:&4@4$5!4CHZ1$(@9&%T86)A<V4@;V)J96-T
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU97,@(%1H92!A<G)A>2!O9B!C
M;VQU;6X@/3X@=F%L=64@<&%I<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!344P@9G)A9VUE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&EN<V5R=%9A;'5E<R@F)&1B:"P@)'9A;'5E<RD*("`@('L*("`@("`@("`D
M8V]L=6UN<R`](&%R<F%Y*"D["B`@("`@("`@)'9A;',@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@)&-O;'5M;G-;72`]("1K97D["B`@("`@("`@("`@("1V
M86QS6UT@/2`D=F%L=64@/3T](&YU;&P@/R`G3E5,3"<@.B`D9&)H+3YQ=6]T
M92@D=F%L=64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)R@@)R`N(&EM
M<&QO9&4H)RP@)RP@)&-O;'5M;G,I("X@)R`I(%9!3%5%4R`H("<@+B!I;7!L
M;V1E*"<L("<L("1V86QS*2`N("<@*2<["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O4W1R:6YG+G!H<```````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#0T-S$V`#$P-3$U-#,Q,#8Q`#`R,#(P-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==(#T@)VES;RTX.#4Y
M+3$G.PH*+RHJ"B`J(%1H92!3=')I;F<Z.B!C;&%S<R!P<F]V:61E<R!S=&%T
M:6,@;65T:&]D<R!F;W(@8VAA<G-E="!A;F0@;&]C86QE('-A9F4*("H@<W1R
M:6YG(&UA;FEP=6QA=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO571I
M;"]3=')I;F<N<&AP+'8@,2XT,RXV+C$S(#(P,#8O,#,O,3,@,#DZ-#8Z,#<@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]5=&EL"B`J+PIC;&%S<R!3
M=')I;F<@>PH*("`@("\J*@H@("`@("H@0V%C:&5S('1H92!R97-U;'0@;V8@
M97AT96YS:6]N7VQO861E9"@I(&-A;&QS+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&5X="`@5&AE(&5X=&5N<VEO;B!N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@27,@=&AE(&5X=&5N<VEO;B!L;V%D960_
M"B`@("`@*@H@("`@("H@0'-E92!5=&EL.CIE>'1E;G-I;VY%>&ES=',H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!E>'1E;G-I;VY%>&ES=',H)&5X="D*("`@
M('L*("`@("`@("!S=&%T:6,@)&-A8VAE(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*"%I<W-E="@D8V%C:&5;)&5X=%TI*2!["B`@("`@("`@("`@("1C86-H
M95LD97AT72`](&5X=&5N<VEO;E]L;V%D960H)&5X="D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&-A8VAE6R1E>'1=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T<R!A(&1E9F%U;'0@8VAA<G-E="!T:&%T('1H92!3=')I;F<Z
M.B!M971H;V1S('=I;&P@=7-E(&EF(&YO;F4@:7,*("`@("`J(&5X<&QI8VET
M96QY('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U<V4@87,@=&AE(&1E9F%U;'0@;VYE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$969A=6QT0VAA<G-E="@D8VAA
M<G-E="D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#
M2$%24T54)UT@/2`D8VAA<G-E=#L*("`@("`@("!I9B`H4W1R:6YG.CIE>'1E
M;G-I;VY%>&ES=',H)VUB<W1R:6YG)RD@)B8*("`@("`@("`@("`@9G5N8W1I
M;VY?97AI<W1S*"=M8E]R96=E>%]E;F-O9&EN9R<I*2!["B`@("`@("`@("`@
M($!M8E]R96=E>%]E;F-O9&EN9R@D8VAA<G-E="D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!S=')I;F<@9G)O;2!O;F4@
M8VAA<G-E="!T;R!A;F]T:&5R+@H@("`@("H*("`@("`J(%=O<FMS(&]N;'D@
M:68@96ET:&5R('1H92!I8V]N=B!O<B!T:&4@;6)S=')I;F<@97AT96YS:6]N
M"B`@("`@*B!A<F4@<')E<V5N="!A;F0@8F5S="!I9B!B;W1H(&%R92!A=F%I
M;&%B;&4N"B`@("`@*B!4:&4@;W)I9VEN86P@<W1R:6YG(&ES(')E='5R;F5D
M(&EF(&-O;G9E<G-I;VX@9F%I;&5D(&]R(&YO;F4*("`@("`J(&]F('1H92!E
M>'1E;G-I;VYS('=E<F4@879A:6QA8FQE+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D:6YP=70@(%1H92!D871A('1O(&)E(&-O;G9E<G1E9"X@268@
M)&EN<'5T(&ES(&%N(&%N(&%R<F%Y+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@=&AE(&%R<F%Y)W,@=F%L=65S(&=E="!C;VYV97)T960@<F5C=7)S
M:79E;'DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<F]M("!4:&4@<W1R:6YG
M)W,@8W5R<F5N="!C:&%R<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@
M("`@5&AE(&-H87)S970@=&\@8V]N=F5R="!T:&4@<W1R:6YG('1O+B!)9B!N
M;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@('-P96-I9FEE9"P@=&AE
M(&=L;V)A;"!V87)I86)L90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M)%](3U)$15]35%))3D=?0TA!4E-%5"!W:6QL(&)E('5S960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYV97)T960@<W1R:6YG+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T0VAA<G-E="@D:6YP=70L("1F
M<F]M+"`D=&\@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@=7-E
M<B=S(&1E9F%U;'0@8VAA<F%C=&5R('-E="!I9B!N;VYE('!A<W-E9"!I;BX@
M*B\*("`@("`@("!I9B`H:7-?;G5L;"@D=&\I*2!["B`@("`@("`@("`@("1T
M;R`]("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G73L*("`@("`@
M("!]"@H@("`@("`@("\J($EF('1H92!F<F]M(&%N9"!T;R!C:&%R86-T97(@
M<V5T<R!A<F4@:61E;G1I8V%L+"!R971U<FX@;F]W+B`J+PH@("`@("`@("1F
M<F]M(#T@4W1R:6YG.CIL;W=E<B@D9G)O;2D["B`@("`@("`@)'1O(#T@4W1R
M:6YG.CIL;W=E<B@D=&\I.PH@("`@("`@(&EF("@D9G)O;2`]/2`D=&\I('L*
M("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]A<G)A>2@D:6YP=70I*2!["B`@("`@("`@("`@("1T;7`@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D:6YP=70@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&UP6U-T<FEN9SHZ7V-O;G9E
M<G1#:&%R<V5T*"1K97DL("1F<F]M+"`D=&\I72`](%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)'9A;"P@)&9R;VTL("1T;RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<U]O8FIE8W0H)&EN<'5T*2D@>PH@("`@("`@("`@("`D=F%R<R`](&=E=%]O
M8FIE8W1?=F%R<R@D:6YP=70I.PH@("`@("`@("`@("!F;W)E86-H("@D=F%R
M<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("1I;G!U="T^
M)&ME>2`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;"P@)&9R;VTL("1T
M;RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<W1R:6YG*"1I;G!U="DI('L*
M("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!3=')I;F<Z.E]C;VYV97)T0VAA<G-E="@D:6YP=70L("1F<F]M
M+"`D=&\I.PH@("`@?0H*("`@("\J*@H@("`@("H@26YT97)N86P@9G5N8W1I
M;VX@=7-E9"!T;R!D;R!C:&%R<V5T(&-O;G9E<G-I;VXN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1I;G!U="`@4V5E(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H*2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&9R;VT@(%-E92!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;R`@("!3964@4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8V]N=F5R=&5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-O;G9E<G1#:&%R<V5T*"1I;G!U="P@)&9R;VTL("1T;RD*("`@('L*
M("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@("\J(%5S92!U=&8X7UME
M;GQD95UC;V1E*"D@:68@<&]S<VEB;&4N("HO"B`@("`@("`@)&9R;VU?8VAE
M8VL@/2`H*"1F<F]M(#T]("=I<V\M.#@U.2TQ)RD@?'P@*"1F<F]M(#T]("=U
M<RUA<V-I:2<I*3L*("`@("`@("!I9B`H)&9R;VU?8VAE8VL@)B8@*"1T;R`]
M/2`G=71F+3@G*2D@>PH@("`@("`@("`@("!R971U<FX@=71F.%]E;F-O9&4H
M)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@("1T;U]C:&5C:R`]("@H)'1O
M(#T]("=I<V\M.#@U.2TQ)RD@?'P@*"1T;R`]/2`G=7,M87-C:6DG*2D["B`@
M("`@("`@:68@*"@D9G)O;2`]/2`G=71F+3@G*2`F)B`D=&]?8VAE8VLI('L*
M("`@("`@("`@("`@<F5T=7)N('5T9CA?9&5C;V1E*"1I;G!U="D["B`@("`@
M("`@?0H*("`@("`@("`O*B!&:7)S="!T<GD@:6-O;G8@=VET:"!T<F%N<VQI
M=&5R871I;VXN("HO"B`@("`@("`@:68@*"@D9G)O;2`A/2`G=71F-RUI;6%P
M)RD@)B8*("`@("`@("`@("`@*"1T;R`A/2`G=71F-RUI;6%P)RD@)B8*("`@
M("`@("`@("`@4W1R:6YG.CIE>'1E;G-I;VY%>&ES=',H)VEC;VYV)RDI('L*
M("`@("`@("`@("`@+RH@5V4@;F5E9"!T;R!T86-K(&%N(&5X=')A(&-H87)A
M8W1E<B!T96UP;W)A<FEL>2!B96-A=7-E"B`@("`@("`@("`@("`J(&]F(&$@
M8G5G(&EN(&EC;VYV*"D@:68@=&AE(&QA<W0@8VAA<F%C=&5R(&ES(&YO="!A
M(#<*("`@("`@("`@("`@("H@8FET($%30TE)(&-H87)A8W1E<BX@*B\*("`@
M("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@("`@
M("`@("1O=71P=70@/2!`:6-O;G8H)&9R;VTL("1T;R`N("<O+U1204Y33$E4
M)RP@)&EN<'5T("X@)W@G*3L*("`@("`@("`@("`@)&]U='!U="`]("AI<W-E
M="@D<&AP7V5R<F]R;7-G*2D@/R!F86QS92`Z("!3=')I;F<Z.G-U8G-T<B@D
M;W5T<'5T+"`P+"`M,2P@)'1O*3L*("`@("`@("`@("`@:6YI7W)E<W1O<F4H
M)W1R86-K7V5R<F]R<R<I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F5X="!T
M<GD@;6)S=')I;F<N("HO"B`@("`@("`@:68@*"$D;W5T<'5T("8F(%-T<FEN
M9SHZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@
M("1O=71P=70@/2!`;6)?8V]N=F5R=%]E;F-O9&EN9R@D:6YP=70L("1T;RP@
M)&9R;VTI.PH@("`@("`@('T*"B`@("`@("`@+RH@070@;&%S="!T<GD@:6UA
M<%]U=&8W7UME;GQD95UC;V1E(&EF(&%P<')O<')I871E+B`J+PH@("`@("`@
M(&EF("@A)&]U='!U="`F)B!3=')I;F<Z.F5X=&5N<VEO;D5X:7-T<R@G:6UA
M<"<I*2!["B`@("`@("`@("`@(&EF("@D9G)O;5]C:&5C:R`F)B`H)'1O(#T]
M("=U=&8W+6EM87`G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N($!I;6%P
M7W5T9C=?96YC;V1E*"1I;G!U="D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"@D9G)O;2`]/2`G=71F-RUI;6%P)RD@)B8@)'1O7V-H96-K*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@0&EM87!?=71F-U]D96-O9&4H)&EN
M<'5T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("@A)&]U='!U="D@/R`D:6YP=70@.B`D;W5T<'5T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@36%K97,@82!S=')I;F<@;&]W97)C87-E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1S=')I;F<@("!4:&4@<W1R:6YG('1O(&)E
M(&-O;G9E<G1E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1L;V-A;&4@("!)
M9B!T<G5E('1H92!S=')I;F<@=VEL;"!B92!C;VYV97)T960@8F%S960@;VX@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&=I=F5N(&-H87)S
M970L(&QO8V%L92!I;F1E<&5N9&5N="!E;'-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&-H87)S970@($EF("1L;V-A;&4@:7,@=')U92P@=&AE(&-H87)S
M970@=&\@=7-E('=H96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYV97)T:6YG+B!)9B!N;W0@<')O=FED960@=&AE(&-U<G)E;G0@8VAA
M<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN
M9R!W:71H(&QO=V5R8V%S92!C:&%R86-T97)S"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QO=V5R*"1S=')I;F<L("1L;V-A;&4@/2!F86QS92P@)&-H87)S970@
M/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D;&]W97)S.PH*("`@("`@
M("!I9B`H)&QO8V%L92D@>PH@("`@("`@("`@("`O*B!4:&4@97AI<W1E;F-E
M(&]F(&UB7W-T<G1O;&]W97(H*2!D97!E;F1S(&]N('1H92!P;&%T9F]R;2X@
M*B\*("`@("`@("`@("`@:68@*%-T<FEN9SHZ97AT96YS:6]N17AI<W1S*"=M
M8G-T<FEN9R<I("8F"B`@("`@("`@("`@("`@("!F=6YC=&EO;E]E>&ES=',H
M)VUB7W-T<G1O;&]W97(G*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7VYU
M;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`@("`@)&-H87)S970@
M/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T(#T@0&UB7W-T<G1O;&]W
M97(H)'-T<FEN9RP@)&-H87)S970I.PH@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D<F5T*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B!S=')T;VQO=V5R*"1S=')I;F<I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<W-E="@D;&]W97)S*2D@>PH@("`@("`@("`@("`D;&]W97)S
M(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D;&]W
M97)S6R1S=')I;F==*2D@>PH@("`@("`@("`@("`D;&%N9W5A9V4@/2!S971L
M;V-A;&4H3$-?0U194$4L(#`I.PH@("`@("`@("`@("!S971L;V-A;&4H3$-?
M0U194$4L("=E;E]54R<I.PH@("`@("`@("`@("`D;&]W97)S6R1S=')I;F==
M(#T@<W1R=&]L;W=E<B@D<W1R:6YG*3L*("`@("`@("`@("`@<V5T;&]C86QE
M*$Q#7T-465!%+"`D;&%N9W5A9V4I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1L;W=E<G-;)'-T<FEN9UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-
M86ME<R!A('-T<FEN9R!U<'!E<F-A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@8F4@8V]N=F5R=&5D
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8V%L92`@($EF('1R=64@=&AE
M('-T<FEN9R!W:6QL(&)E(&-O;G9E<G1E9"!B87-E9"!O;B!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@9VEV96X@8VAA<G-E="P@;&]C86QE
M(&EN9&5P96YD96YT(&5L<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8VAA
M<G-E="`@268@)&QO8V%L92!I<R!T<G5E+"!T:&4@8VAA<G-E="!T;R!U<V4@
M=VAE;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G9E<G1I
M;F<N($EF(&YO="!P<F]V:61E9"!T:&4@8W5R<F5N="!C:&%R<V5T+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<W1R:6YG('=I=&@@=7!P
M97)C87-E(&-H87)A8W1E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@=7!P97(H
M)'-T<FEN9RP@)&QO8V%L92`](&9A;'-E+"`D8VAA<G-E="`](&YU;&PI"B`@
M("!["B`@("`@("`@<W1A=&EC("1U<'!E<G,["@H@("`@("`@(&EF("@D;&]C
M86QE*2!["B`@("`@("`@("`@("\J(%1H92!E>&ES=&5N8V4@;V8@;6)?<W1R
M=&]U<'!E<B@I(&1E<&5N9',@;VX@=&AE"B`@("`@("`@("`@("`J('!L871F
M;W)M+B`J+PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=M8E]S
M=')T;W5P<&5R)RDI('L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C
M:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@)$=,
M3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)')E="`]($!M8E]S=')T;W5P<&5R*"1S
M=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)')E="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@<W1R=&]U<'!E<B@D<W1R:6YG*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-S970H)'5P<&5R<RDI('L*("`@("`@("`@("`@)'5P<&5R<R`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'5P<&5R<ULD
M<W1R:6YG72DI('L*("`@("`@("`@("`@)&QA;F=U86=E(#T@<V5T;&]C86QE
M*$Q#7T-465!%+"`P*3L*("`@("`@("`@("`@<V5T;&]C86QE*$Q#7T-465!%
M+"`G96Y?55,G*3L*("`@("`@("`@("`@)'5P<&5R<ULD<W1R:6YG72`]('-T
M<G1O=7!P97(H)'-T<FEN9RD["B`@("`@("`@("`@('-E=&QO8V%L92A,0U]#
M5%E012P@)&QA;F=U86=E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=7!P97)S6R1S=')I;F==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A('-T<FEN9R!W:71H('1H92!F:7)S="!L971T97(@8V%P:71A;&EZ960@
M:68@:70@:7,*("`@("`J(&%L<&AA8F5T:6,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@8F4@8V%P:71A
M;&EZ960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]C86QE("`@268@=')U
M92!T:&4@<W1R:6YG('=I;&P@8F4@8V]N=F5R=&5D(&)A<V5D(&]N(&$*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G:79E;B!C:&%R<V5T+"!L
M;V-A;&4@:6YD97!E;F1E;G0@96QS92X*("`@("`J($!P87)A;2!S=')I;F<@
M("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U<V4L(&1E9F%U;'1S('1O(&-U
M<G)E;G0@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&-A<&ET86QI>F5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M=6-F:7)S="@D<W1R:6YG+"`D;&]C86QE(#T@9F%L<V4L("1C:&%R<V5T(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H)&QO8V%L92D@>PH@("`@("`@("`@
M("`D9FER<W0@/2!3=')I;F<Z.G-U8G-T<B@D<W1R:6YG+"`P+"`Q+"`D8VAA
M<G-E="D["B`@("`@("`@("`@(&EF("A3=')I;F<Z.FES06QP:&$H)&9I<G-T
M+"`D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("1S=')I;F<@/2!3=')I
M;F<Z.G5P<&5R*"1F:7)S="P@=')U92P@)&-H87)S970I("X@4W1R:6YG.CIS
M=6)S='(H)'-T<FEN9RP@,2P@;G5L;"P@)&-H87)S970I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T<FEN9R`](%-T
M<FEN9SHZ=7!P97(H<W5B<W1R*"1S=')I;F<L(#`L(#$I+"!F86QS92D@+B!S
M=6)S='(H)'-T<FEN9RP@,2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<W1R:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!P87)T(&]F
M(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN
M9R`@(%1H92!S=')I;F<@=&\@8F4@8V]N=F5R=&5D+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'-T87)T("`@5&AE('!A<G0G<R!S=&%R="!P;W-I=&EO;BP@
M>F5R;R!B87-E9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1L96YG=&@@(%1H
M92!P87)T)W,@;&5N9W1H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E
M="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@8V%L8W5L871I;F<@=&AE('!A
M<G0G<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&]S:71I;VX@
M86YD(&QE;F=T:"P@9&5F875L=',@=&\@8W5R<F5N=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('-T<FEN9R=S('!A<G0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-U8G-T<B@D<W1R:6YG+"`D<W1A<G0L("1L96YG=&@@/2!N=6QL
M+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*%-T<FEN9SHZ
M97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@(&EF
M("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@)&-H87)S
M970@/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&QE;F=T:"DI('L*
M("`@("`@("`@("`@("`@("1L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D<W1R
M:6YG+"`D8VAA<G-E="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E
M="`]($!M8E]S=6)S='(H)'-T<FEN9RP@)'-T87)T+"`D;&5N9W1H+"`D8VAA
M<G-E="D["B`@("`@("`@("`@(&EF("@A96UP='DH)')E="DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]N=6QL*"1L96YG=&@I*2!["B`@("`@("`@("`@
M("1L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D<W1R:6YG*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N('-U8G-T<B@D<W1R:6YG+"`D<W1A<G0L("1L96YG
M=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C
M=&5R("AN;W0@8GET92D@;&5N9W1H(&]F(&$@<W1R:6YG+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@5&AE('-T<FEN9R!T;R!R971U
M<FX@=&AE(&QE;F=T:"!O9BX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S
M970@5&AE(&-H87)S970@=&\@=7-E('=H96X@8V%L8W5L871I;F<@=&AE('-T
M<FEN9R=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&QE;F=T:"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN9R=S('!A
M<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QE;F=T:"@D<W1R:6YG+"`D8VAA
M<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&-H87)S
M970I*2!["B`@("`@("`@("`@("1C:&%R<V5T(#T@)$=,3T)!3%-;)U](3U)$
M15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@('T*("`@("`@("`D8VAA<G-E
M="`](%-T<FEN9SHZ;&]W97(H)&-H87)S970I.PH@("`@("`@(&EF("@D8VAA
M<G-E="`]/2`G=71F+3@G('Q\("1C:&%R<V5T(#T]("=U=&8X)RD@>PH@("`@
M("`@("`@("!R971U<FX@<W1R;&5N*'5T9CA?9&5C;V1E*"1S=')I;F<I*3L*
M("`@("`@("!]"B`@("`@("`@:68@*%-T<FEN9SHZ97AT96YS:6]N17AI<W1S
M*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@("1R970@/2!`;6)?<W1R;&5N
M*"1S=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M<F5T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N('-T<FQE;B@D<W1R:6YG
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;65R:6,@
M<&]S:71I;VX@;V8@=&AE(&9I<G-T(&]C8W5R<F5N8V4@;V8@)&YE961L90H@
M("`@("H@:6X@=&AE("1H87ES=&%C:R!S=')I;F<N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:&%Y<W1A8VL@(%1H92!S=')I;F<@=&\@<V5A<F-H
M('1H<F]U9V@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N965D;&4@("`@5&AE
M('-T<FEN9R!T;R!S96%R8V@@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&]F9G-E="`@($%L;&]W<R!T;R!S<&5C:69Y('=H:6-H(&-H87)A8W1E<B!I
M;B!H87ES=&%C:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1O
M('-T87)T('-E87)C:&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S
M970@("!4:&4@8VAA<G-E="!T;R!U<V4@=VAE;B!S96%R8VAI;F<@9F]R('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("1N965D;&4@<W1R
M:6YG+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('!O<VET
M:6]N(&]F(&9I<G-T(&]C8W5R<F5N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!O<R@D:&%Y<W1A8VLL("1N965D;&4L("1O9F9S970@/2`P+"`D8VAA<G-E
M="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*%-T<FEN9SHZ97AT96YS:6]N
M17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@(&EF("AI<U]N=6QL
M*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@)&-H87)S970@/2`D1TQ/
M0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@
M("`@("`@("1R970@/2!`;6)?<W1R<&]S*"1H87ES=&%C:RP@)&YE961L92P@
M)&]F9G-E="P@)&-H87)S970I.PH@("`@("`@("`@("!I;FE?<F5S=&]R92@G
M=')A8VM?97)R;W)S)RD["B`@("`@("`@("`@(&EF("@A:7-S970H)'!H<%]E
M<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=')P;W,H)&AA
M>7-T86-K+"`D;F5E9&QE+"`D;V9F<V5T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!S=')I;F<@<&%D9&5D('1O(&$@8V5R=&%I;B!L96YG
M=&@@=VET:"!A;F]T:&5R('-T<FEN9RX*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!B96AA=F5S(&5X86-T;'D@;&EK92!S=')?<&%D(&)U="!I<R!M=6QT
M:6)Y=&4@<V%F92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G!U
M="`@("!4:&4@<W1R:6YG('1O(&)E('!A9&1E9"X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1L96YG=&@@(%1H92!L96YG=&@@;V8@=&AE(')E<W5L=&EN9R!S
M=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P860@("`@("!4:&4@<W1R
M:6YG('1O('!A9"!T:&4@:6YP=70@<W1R:6YG('=I=&@N($UU<W0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&)E(&EN('1H92!S86UE(&-H87)S
M970@;&EK92!T:&4@:6YP=70@<W1R:6YG+@H@("`@("H@0'!A<F%M(&-O;G-T
M("1T>7!E("`@("`@5&AE('!A9&1I;F<@='EP92X@3VYE(&]F(%-44E]0041?
M3$5&5"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%-44E]0041?
M4DE'2%0L(&]R(%-44E]0041?0D]42"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-H87)S970@(%1H92!C:&%R<V5T(&]F('1H92!I;G!U="!A;F0@=&AE('!A
M9&1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9W,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P861D960@<W1R
M:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!P860H)&EN<'5T+"`D;&5N9W1H
M+"`D<&%D(#T@)R`G+"`D='EP92`](%-44E]0041?4DE'2%0L"B`@("`@("`@
M("`@("`@("`@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@("1M8E]L
M96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D:6YP=70L("1C:&%R<V5T*3L*("`@
M("`@("`D<V)?;&5N9W1H(#T@<W1R;&5N*"1I;G!U="D["B`@("`@("`@)'!A
M9%]L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D<&%D+"`D8VAA<G-E="D["@H@
M("`@("`@("\J(%)E='5R;B!I9B!W92!A;')E861Y(&AA=F4@=&AE(&QE;F=T
M:"X@*B\*("`@("`@("!I9B`H)&UB7VQE;F=T:"`^/2`D;&5N9W1H*2!["B`@
M("`@("`@("`@(')E='5R;B`D:6YP=70["B`@("`@("`@?0H*("`@("`@("`O
M*B!3:&]R=&-U="!F;W(@<VEN9VQE(&)Y=&4@<W1R:6YG<RX@*B\*("`@("`@
M("!I9B`H)&UB7VQE;F=T:"`]/2`D<V)?;&5N9W1H("8F("1P861?;&5N9W1H
M(#T]('-T<FQE;B@D<&%D*2D@>PH@("`@("`@("`@("!R971U<FX@<W1R7W!A
M9"@D:6YP=70L("1L96YG=&@L("1P860L("1T>7!E*3L*("`@("`@("!]"@H@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E(%-44E]0041?
M3$5&5#H*("`@("`@("`@("`@)&QE9G0@/2`D;&5N9W1H("T@)&UB7VQE;F=T
M:#L*("`@("`@("`@("`@)&]U='!U="`](%-T<FEN9SHZ<W5B<W1R*'-T<E]R
M97!E870H)'!A9"P@8V5I;"@D;&5F="`O("1P861?;&5N9W1H*2DL(#`L("1L
M969T+"`D8VAA<G-E="D@+B`D:6YP=70["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&-A<V4@4U127U!!1%]"3U1(.@H@("`@("`@("`@("`D;&5F="`]
M(&9L;V]R*"@D;&5N9W1H("T@)&UB7VQE;F=T:"D@+R`R*3L*("`@("`@("`@
M("`@)')I9VAT(#T@8V5I;"@H)&QE;F=T:"`M("1M8E]L96YG=&@I("\@,BD[
M"B`@("`@("`@("`@("1O=71P=70@/2!3=')I;F<Z.G-U8G-T<BAS=')?<F5P
M96%T*"1P860L(&-E:6PH)&QE9G0@+R`D<&%D7VQE;F=T:"DI+"`P+"`D;&5F
M="P@)&-H87)S970I("X*("`@("`@("`@("`@("`@("1I;G!U="`N"B`@("`@
M("`@("`@("`@("!3=')I;F<Z.G-U8G-T<BAS=')?<F5P96%T*"1P860L(&-E
M:6PH)')I9VAT("\@)'!A9%]L96YG=&@I*2P@,"P@)')I9VAT+"`D8VAA<G-E
M="D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@4U127U!!1%]2
M24=(5#H*("`@("`@("`@("`@)')I9VAT(#T@)&QE;F=T:"`M("1M8E]L96YG
M=&@["B`@("`@("`@("`@("1O=71P=70@/2`D:6YP=70@+B!3=')I;F<Z.G-U
M8G-T<BAS=')?<F5P96%T*"1P860L(&-E:6PH)')I9VAT("\@)'!A9%]L96YG
M=&@I*2P@,"P@)')I9VAT+"`D8VAA<G-E="D["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!7<F%P<R!T:&4@=&5X="!O9B!A(&UE<W-A9V4N"B`@
M("`@*@H@("`@("H@0'1O9&\@36%K92!M=6QT:6)Y=&4M<V%V92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("`@("!3=')I;F<@8V]N
M=&%I;FEN9R!T:&4@=&5X="!T;R!W<F%P+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&QE;F=T:"`@("`@5W)A<"`D=&5X="!A="!T:&ES(&YU;6)E<B!O9B!C
M:&%R86-T97)S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8G)E86M?8VAA<B`@
M0VAA<F%C=&5R*',I('1O('5S92!W:&5N(&)R96%K:6YG(&QI;F5S+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@0VAA<F%C=&5R('-E="!T
M;R!U<V4@=VAE;B!B<F5A:VEN9R!L:6YE<RX*("`@("`J($!P87)A;2!B;V]L
M96%N("1Q=6]T92`@("`@($EG;F]R92!L:6YE<R!T:&%T(&%R92!W<F%P<&5D
M('=I=&@@=&AE("<^)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8VAA<F%C=&5R("A21D,@,C8T-BD_($EF('1R=64L('=E(&1O;B=T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F4@86YY('!A
M9&1I;F<@=VAI=&5S<&%C92!A="!T:&4@96YD(&]F"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@<W1R:6YG+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@=W)A<'!E
M9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<F%P*"1T97AT+"`D;&5N
M9W1H(#T@.#`L("1B<F5A:U]C:&%R(#T@(EQN(BP@)&-H87)S970@/2!N=6QL
M+`H@("`@("`@("`@("`@("`@("`D<75O=&4@/2!F86QS92D*("`@('L*("`@
M("`@("`D<&%R86=R87!H<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@
M*'!R96=?<W!L:70H)R]<<C]<;B\G+"`D=&5X="D@87,@)&EN<'5T*2!["B`@
M("`@("`@("`@(&EF("@D<75O=&4@)B8@*'-T<G!O<R@D:6YP=70L("<^)RD@
M/3T](#`I*2!["B`@("`@("`@("`@("`@("`D;&EN92`]("1I;G!U=#L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J(%=E(&YE960@
M=&\@:&%N9&QE('1H92!5<V5N970M<W1Y;&4@<VEG;F%T=7)E(&QI;F4*("`@
M("`@("`@("`@("`@("`J('-E<&%R871E;'D[('-I;F-E('1H92!S<&%C92!A
M9G1E<B!T:&4@='=O(&1A<VAE<R!I<PH@("`@("`@("`@("`@("`@("H@4D51
M54E2140L('=E(&1O;B=T('=A;G0@=&\@=')I;2!T:&4@;&EN92X@*B\*("`@
M("`@("`@("`@("`@(&EF("@D:6YP=70@(3T@)RTM("<I('L*("`@("`@("`@
M("`@("`@("`@("`D:6YP=70@/2!R=')I;2@D:6YP=70I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&QI;F4@/2!W;W)D=W)A<"@D:6YP
M=70L("1L96YG=&@L("1B<F5A:U]C:&%R*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'!A<F%G<F%P:'-;72`]("1L:6YE.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&EM<&QO9&4H)&)R96%K7V-H87(L("1P87)A9W)A<&AS
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I9B!T:&4@
M979E<GD@8VAA<F%C=&5R(&EN('1H92!P87)A;65T97(@:7,@86X*("`@("`J
M(&%L<&AA8F5T:6,@8VAA<F%C=&5R+B!4:&ES(&UE=&AO9"!D;V5S;B=T('=O
M<FL@=VET:"!A;GD@8VAA<G-E=`H@("`@("H@;W1H97(@=&AA;B!T:&4@8W5R
M<F5N="!C:&%R<V5T('EE="X*("`@("`J"B`@("`@*B!`<&%R86T@)'-T<FEN
M9R`@(%1H92!S=')I;F<@=&\@=&5S="X*("`@("`J($!P87)A;2`D8VAA<G-E
M="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@=&5S=&EN9R!T:&4@<W1R:6YG
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@
M<&%R86UE=&5R('=A<R!A;'!H86)E=&EC(&]N;'DN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&ES06QP:&$H)'-T<FEN9RP@)&-H87)S970@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N<VEO;D5X:7-T<R@G;6)S=')I
M;F<G*2D@>PH@("`@("`@("`@("`D;VQD7V-H87)S970@/2!M8E]R96=E>%]E
M;F-O9&EN9R@I.PH@("`@("`@("`@("!I9B`H)&-H87)S970@(3T@)&]L9%]C
M:&%R<V5T*2!["B`@("`@("`@("`@("`@("!`;6)?<F5G97A?96YC;V1I;F<H
M)&-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A;'!H82`]
M("%M8E]E<F5G7VUA=&-H*"=;7ELZ86QP:&$Z75TG+"`D<W1R:6YG*3L*("`@
M("`@("`@("`@:68@*"1C:&%R<V5T("$]("1O;&1?8VAA<G-E="D@>PH@("`@
M("`@("`@("`@("`@0&UB7W)E9V5X7V5N8V]D:6YG*"1O;&1?8VAA<G-E="D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1A;'!H83L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!C='EP95]A;'!H82@D<W1R:6YG*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I9B!E=F5R>2!C
M:&%R86-T97(@:6X@=&AE('!A<F%M971E<B!I<R!A(&QO=V5R8V%S90H@("`@
M("H@;&5T=&5R(&EN('1H92!C=7)R96YT(&QO8V%L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@=&5S="X*("`@("`J
M($!P87)A;2`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@=&5S
M=&EN9R!T:&4@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&4@<&%R86UE=&5R('=A<R!L;W=E<F-A<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES3&]W97(H)'-T<FEN9RP@)&-H87)S970@/2!N
M=6QL*0H@("`@>PH@("`@("`@(')E='5R;B`H*%-T<FEN9SHZ;&]W97(H)'-T
M<FEN9RP@=')U92P@)&-H87)S970I(#T]/2`D<W1R:6YG*2`F)@H@("`@("`@
M("`@("`@("`@4W1R:6YG.CII<T%L<&AA*"1S=')I;F<L("1C:&%R<V5T*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@979E<GD@
M8VAA<F%C=&5R(&EN('1H92!P87)A;65T97(@:7,@86X*("`@("`J('5P<&5R
M8V%S92!L971T97(@:6X@=&AE(&-U<G)E;G0@;&]C86QE+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@=&5S
M="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T
M('1O('5S92!W:&5N('1E<W1I;F<@=&AE('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('!A<F%M971E<B!W87,@
M=7!P97)C87-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U5P<&5R*"1S=')I
M;F<L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@*"A3
M=')I;F<Z.G5P<&5R*"1S=')I;F<L('1R=64L("1C:&%R<V5T*2`]/3T@)'-T
M<FEN9RD@)B8*("`@("`@("`@("`@("`@(%-T<FEN9SHZ:7-!;'!H82@D<W1R
M:6YG+"`D8VAA<G-E="DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4&5R9F]R
M;7,@82!M=6QT:6)Y=&4@<V%F92!R96=E>"!M871C:"!S96%R8V@@;VX@=&AE
M('1E>'0@<')O=FED960N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N
M,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@(%1H92!T
M97AT('1O('-E87)C:"X*("`@("`J($!P87)A;2!A<G)A>2`D<F5G97@@("`@
M(%1H92!R96=U;&%R(&5X<')E<W-I;VYS('1O('5S92P@=VET:&]U="!P97)L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!R96=E>"!D96QI;6ET
M97)S("AE+F<N("<O)R!O<B`G?"<I+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@;V8@=&AE('1E>'0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&UA=&-H97,@87)R87D@9G)O
M;2!T:&4@9FER<W0@<F5G97@@=&AA="!M871C:&5S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96=E>$UA=&-H*"1T97AT+"`D<F5G97@L("1C:&%R<V5T(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@>PH@
M("`@("`@("`@("`D<F5G97@@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1R
M96=E>"P@)&-H87)S970L("=U=&8M."<I.PH@("`@("`@("`@("`D=&5X="`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'1E>'0L("1C:&%R<V5T+"`G=71F
M+3@G*3L*("`@("`@("!]"@H@("`@("`@("1M871C:&5S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D<F5G97@@87,@)'9A;"D@>PH@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+R<@+B`D=F%L("X@)R]U)RP@)'1E>'0L("1M
M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&-H87)S970I*2![
M"B`@("`@("`@("`@("1M871C:&5S(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E
M="@D;6%T8VAE<RP@)W5T9BTX)RP@)&-H87)S970I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1M871C:&5S.PH@("`@?0H*?0H`````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;BYP:'``
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S`S,@`Q,#4Q-30S
M,3`V,0`P,C$S-38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!.;W1I9FEC871I;VXZ.B!C;&%S
M<R!P<F]V:61E<R!A('-U8FIE8W0M;V)S97)V97(@<&%T=&5R;B!F;W(*("H@
M<F%I<VEN9R!A;F0@<VAO=VEN9R!M97-S86=E<R!O9B!D:69F97)E;G0@='EP
M97,@86YD('1O(&1I9F9E<F5N=`H@*B!L:7-T96YE<G,N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXN<&AP+'8@
M,2XT-BXR+C$Q(#(P,#8O,#$O,3@@,34Z,3DZ,#$@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`Q+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`
M<&%C:V%G92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A
M=&EO;B!["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@86QL(&%T
M=&%C:&5D(&QI<W1E;F5R(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]L:7-T96YE<G,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('-E<W-I;VX@=F%R:6%B
M;&4@=VAE<F4@=V4@<W1O<F4@=&AE(&UE<W-A9V5S+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-T86-K(#T@)VAO<F1E
M365S<V%G95-T86-K<R<["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F
M97)E;F-E('1O('1H92!G;&]B86P@3F]T:69I8V%T:6]N(&]B:F5C="P@;VYL
M>0H@("`@("H@8W)E871I;F<@:70@:68@:70@9&]E<VXG="!A;')E861Y(&5X
M:7-T+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH*("`@("`J("`@)&YO=&EF:6-A=&EO;B`]("9.;W1I9FEC871I;VXZ
M.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1A
M8VL@(%1H92!N86UE(&]F('1H92!M97-S86=E('-T86-K('1O('5S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N($YO=&EF:6-A=&EO;B`@5&AE($AO<F1E($YO
M=&EF:6-A=&EO;B!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D<W1A8VL@/2`G:&]R9&5-97-S86=E4W1A8VMS)RD*("`@('L*
M("`@("`@("!S=&%T:6,@)&YO=&EF:6-A=&EO;B`](&%R<F%Y*"D["@H@("`@
M("`@(&EF("@A:7-S970H)&YO=&EF:6-A=&EO;ELD<W1A8VM=*2D@>PH@("`@
M("`@("`@("`D;F]T:69I8V%T:6]N6R1S=&%C:UT@/2!N97<@3F]T:69I8V%T
M:6]N*"1S=&%C:RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&YO=&EF
M:6-A=&EO;ELD<W1A8VM=.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA
M;&EZ92!T:&4@;F]T:69I8V%T:6]N('-Y<W1E;2P@<V5T('5P(&%N>2!N965D
M960@<V5S<VEO;@H@("`@("H@=F%R:6%B;&5S+"!E=&,N(%-H;W5L9"!N979E
M<B!B92!C86QL960@97AC97!T(&)Y"B`@("`@*B`F3F]T:69I8V%T:6]N.CIS
M:6YG;&5T;VXH*3L*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=&%C
M:R`@5&AE(&YA;64@;V8@=&AE(&UE<W-A9V4@<W1A8VL@=&\@=7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VXH)'-T86-K(#T@)VAO<F1E
M365S<V%G95-T86-K<R<I"B`@("!["B`@("`@("`@)'1H:7,M/E]S=&%C:R`]
M("1S=&%C:SL*"B`@("`@("`@+RH@36%K92!S=7)E('1H92!M97-S86=E('-T
M86-K(&ES(')E9VES=&5R960@:6X@=&AE('-E<W-I;VXL"B`@("`@("`@("H@
M86YD(&]B=&%I;B!A(&=L;V)A;"US8V]P92!R969E<F5N8V4@=&\@:70N("HO
M"B`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UTI
M*2!["B`@("`@("`@("`@("1?4T534TE/3ELD=&AI<RT^7W-T86-K72`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5G:7-T
M97)S(&$@;&ES=&5N97(@=VET:"!T:&4@;F]T:69I8V%T:6]N(&]B:F5C="!A
M;F0@:6YC;'5D97,*("`@("`J('1H92!N96-E<W-A<GD@;&EB<F%R>2!F:6QE
M(&1Y;F%M:6-A;&QY+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R
M:79E<B`@5&AE(&YA;64@;V8@=&AE(&QI<W1E;F5R('1O(&%T=&%C:"X@5&AE
M<V4@;F%M97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@;75S="!B
M92!U;FEQ=64[(&9U<G1H97(@;&ES=&5N97)S('=I=&@@=&AE('-A;64*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@;F%M92!W:6QL(&)E(&EG;F]R
M960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT
M86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S
M(&$@;&ES=&5N97(@9')I=F5R(&UI9VAT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(&YE960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@
M(%1H92!C;&%S<R!N86UE(&9R;VT@=VAI8V@@=&AE(&1R:79E<B!W87,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N=&EA=&5D(&EF(&YO
M="!T:&4@9&5F875L="!O;F4N($EF(&=I=F5N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@('EO=2!H879E('1O(&EN8VQU9&4@=&AE(&QI8G)A<GD@
M9FEL92!C;VYT86EN:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M('1H:7,@8VQA<W,@>6]U<G-E;&8N(%1H:7,@:7,@=7-E9G5L(&EF('EO=2!W
M86YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H92!L:7-T96YE
M<B!D<FEV97(@=&\@8F4@;W9E<G)I9&5N(&)Y(&%N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N)W,@:6UP;&5M96YT871I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9A='1A8V@H)&QI<W1E;F5R+"`D<&%R
M86US(#T@87)R87DH*2P@)&-L87-S(#T@;G5L;"D*("`@('L*("`@("`@("`D
M;&ES=&5N97(@/2!B87-E;F%M92@D;&ES=&5N97(I.PH@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<ET["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8VQA<W,I*2!["B`@("`@
M("`@("`@($!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B\G("X@)&QI<W1E;F5R("X@)RYP:'`G.PH@
M("`@("`@("`@("`D8VQA<W,@/2`G3F]T:69I8V%T:6]N7TQI<W1E;F5R7R<@
M+B`D;&ES=&5N97(["B`@("`@("`@?0H@("`@("`@(&EF("AC;&%S<U]E>&ES
M=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD
M;&ES=&5N97)=(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@("`@
M(&EF("@A:7-S970H)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1L:7-T96YE
M<ETI*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]S=&%C
M:UU;)&QI<W1E;F5R72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<ET["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9B@G3F]T:69I8V%T:6]N(&QI<W1E;F5R("5S(&YO="!F
M;W5N9"XG+"`D;&ES=&5N97(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F4@82!L:7-T96YE<B!F<F]M('1H92!N;W1I9FEC871I
M;VX@;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L:7-T;F5R
M("!4:&4@;F%M92!O9B!T:&4@;&ES=&5N97(@=&\@9&5T86-H+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D971A8V@H)&QI<W1E;F5R*0H@("`@>PH@("`@("`@
M("1L:7-T96YE<B`](&)A<V5N86UE*"1L:7-T96YE<BD["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=.;W1I
M9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+B<L("1L:7-T96YE<BDI
M.PH@("`@("`@('T*"B`@("`@("`@)&QI<W0@/2`D=&AI<RT^7VQI<W1E;F5R
M<ULD;&ES=&5N97)=.PH@("`@("`@('5N<V5T*"1T:&ES+3Y?;&ES=&5N97)S
M6R1L:7-T96YE<ETI.PH@("`@("`@('5N<V5T*"1?4T534TE/3ELD=&AI<RT^
M7W-T86-K75LD;&ES="T^9V5T3F%M92@I72D["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@979E;G0@=&\@=&AE
M($AO<F1E(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@5&AE(&5V96YT
M('1Y<&4@<&%R86UE=&5R('-H;W5L9"!B96=I;B!W:71H("=H;W)D92XG('5N
M;&5S<R!T:&4*("`@("`J(&%P<&QI8V%T:6]N(&1E9FEN97,@:71S(&]W;B!.
M;W1I9FEC871I;VY?3&ES=&5N97(@<W5B8VQA<W,@=&AA=`H@("`@("H@:&%N
M9&QE<R!A9&1I=&EO;F%L(&-O9&5S+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D979E;G0@("!.;W1I9FEC871I;VY?179E;G0@;V)J96-T(&]R(&UE
M<W-A9V4@<W1R:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'1Y<&4@(%1H
M92!T>7!E(&]F(&UE<W-A9V4Z("=H;W)D92YE<G)O<B<L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@)VAO<F1E+G=A<FYI;F<G+"`G:&]R9&4N<W5C
M8V5S<R<L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E
M+FUE<W-A9V4G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F;&%G<R`@($%R<F%Y
M(&]F(&]P=&EO;F%L(&9L86=S('1H870@=VEL;"!B92!P87-S960@=&\@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5G:7-T97)E9"!L:7-T
M96YE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N('!U<V@H)&5V96YT+"`D='EP
M92`](&YU;&PL("1F;&%G<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*"%I<U]A*"1E=F5N="P@)TYO=&EF:6-A=&EO;E]%=F5N="<I("8F"B`@("`@
M("`@("`@("%I<U]A*"1E=F5N="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`O*B!4<F%N<W!A<F5N=&QY(&-R96%T92!A($YO=&EF:6-A=&EO;E]%
M=F5N="!O8FIE8W0@86YD"B`@("`@("`@("`@("`J('-E="!T:&4@;65S<V%G
M92!A='1R:6)U=&4N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O3F]T:69I8V%T:6]N+T5V96YT+G!H<"<["B`@
M("`@("`@("`@("1E=F5N="`]("9N97<@3F]T:69I8V%T:6]N7T5V96YT*"1E
M=F5N="D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1E=F5N="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T>7!E*2D@
M>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`G:&]R9&4N97)R;W(G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1E=F5N
M="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-S970H)'1Y<&4I*2!["B`@("`@("`@("`@
M("1T>7!E(#T@)VAO<F1E+FUE<W-A9V4G.PH@("`@("`@('T*"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]L:7-T96YE<G,@87,@)&QI<W1E;F5R*2!["B`@
M("`@("`@("`@(&EF("@D;&ES=&5N97(M/FAA;F1L97,H)'1Y<&4I*2!["B`@
M("`@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;)&QI<W1E
M;F5R+3YG971.86UE*"E=6UT@/0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=T>7!E)R`]/B`D='EP92P*("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8VQA<W,G(#T^(&=E=%]C;&%S<R@D979E;G0I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("=E=F5N="<@/3X@<V5R:6%L:7IE*"1E=F5N="DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V9L86=S)R`]/B!S97)I86QI>F4H)&9L
M86=S*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!087-S97,@=&AE(&UE<W-A9V4@<W1A8VL@=&\@86QL(&QI<W1E
M;F5R<R!A;F0@87-K<R!T:&5M('1O"B`@("`@*B!H86YD;&4@=&AE:7(@;65S
M<V%G97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS("!!
M;B!A<G)A>2!C;VYT86EN:6YG(&1I<W!L87D@;W!T:6]N<R!F;W(@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W1E;F5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@;F]T:69Y*"1O<'1I;VYS(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=L:7-T96YE<G,G72DI
M('L*("`@("`@("`@("`@)&]P=&EO;G-;)VQI<W1E;F5R<R==(#T@87)R87E?
M:V5Y<R@D=&AI<RT^7VQI<W1E;F5R<RD["B`@("`@("`@?2!E;'-E:68@*"%I
M<U]A<G)A>2@D;W!T:6]N<ULG;&ES=&5N97)S)UTI*2!["B`@("`@("`@("`@
M("1O<'1I;VYS6R=L:7-T96YE<G,G72`](&%R<F%Y*"1O<'1I;VYS6R=L:7-T
M96YE<G,G72D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS
M6R=L:7-T96YE<G,G72!A<R`D;&ES=&5N97(I('L*("`@("`@("`@("`@)'1H
M:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72T^;F]T:69Y*"1?4T534TE/3ELD
M=&AI<RT^7W-T86-K75LD=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=+3YG
M971.86UE*"E=+"`D;W!T:6]N<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!N=6UB97(@;V8@;F]T:69I8V%T:6]N(&UE
M<W-A9V5S(&EN('1H92!S=&%C:RX*("`@("`J"B`@("`@*B!`875T:&]R($1A
M=FED(%5L979I=&-H(#QD879I9'5`979E<GED;G,N;F5T/@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&UY7VQI<W1E;F5R("!4:&4@;F%M92!O9B!T
M:&4@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@;G5M8F5R(&]F(&UE<W-A9V5S(&EN('1H92!S=&%C:RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]U;G0H)&UY7VQI<W1E;F5R(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H:7-?;G5L;"@D;7E?;&ES=&5N97(I*2!["B`@("`@("`@
M("`@("1C;W5N="`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M;&ES=&5N97)S(&%S("1L:7-T96YE<BD@>PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD;&ES=&5N97(M/F=E
M=$YA;64H*5TI*2!["B`@("`@("`@("`@("`@("`@("`@)&-O=6YT("L](&-O
M=6YT*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD;&ES=&5N97(M/F=E=$YA
M;64H*5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D8V]U;G0["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N($!C;W5N="@D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;
M)'1H:7,M/E]L:7-T96YE<G-;)&UY7VQI<W1E;F5R72T^9V5T3F%M92@I72D[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]687)I86)L97,N<&AP````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,34U-C0`,3`U,34T,S$P-C$`,#(P-C4P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+U5T:6PN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A
M>2YP:'`G.PH*+RHJ"B`J(%9A<FEA8FQE<SHZ(&-L87-S+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]5=&EL+U9A<FEA8FQE<RYP:'`L=B`Q+C@N,3`N-B`R
M,#`V+S`S+S(X(#$R.C,Q.C$R(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!2
M;V)E<G0@12X@0V]Y;&4@/')O8F5R=&5C;WEL94!H;W1M86EL+F-O;3X*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!P86-K86=E($AO<F1E7U5T:6P*("HO"F-L87-S(%9A<FEA8FQE<R!["@H@
M("`@=F%R("1?=F%R<SL*("`@('9A<B`D7V5X<&5C=&5D5F%R:6%B;&5S(#T@
M87)R87DH*3L*"B`@("!F=6YC=&EO;B!687)I86)L97,H)'9A<G,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1V87)S*2D@>PH@("`@
M("`@("`@("`D=F%R<R`](%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4D51
M54535"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=F%R<ULG7V9O
M<FUV87)S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?97AP96-T961687)I
M86)L97,@/2!`=6YS97)I86QI>F4H)'9A<G-;)U]F;W)M=F%R<R==*3L*("`@
M("`@("`@("`@=6YS970H)'9A<G-;)U]F;W)M=F%R<R==*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]V87)S(#T@)'9A<G,["B`@("!]"@H@("`@9G5N
M8W1I;VX@)F=E=$1E9F%U;'1687)I86)L97,H*0H@("`@>PH@("`@("`@("1V
M87)S(#T@)FYE=R!687)I86)L97,H571I;#HZ9&ES<&5L36%G:6-1=6]T97,H
M)%]215%515-4*2D["B`@("`@("`@<F5T=7)N("1V87)S.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&5X:7-T<R@D=F%R;F%M92D*("`@('L*("`@("`@("!I9B`H
M8V]U;G0H)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RD@)B8*("`@("`@("`@
M("`@)'1H:7,M/E]E>&ES=',H)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@
M)'9A<FYA;64L(&9A;'-E*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AI<W1S*"1T:&ES
M+3Y?=F%R<RP@)'9A<FYA;64L(&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!G970H)'9A<FYA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]G971%>&ES
M=',H)'1H:7,M/E]V87)S+"`D=F%R;F%M92P@)'9A;'5E*3L*("`@("`@("!R
M971U<FX@)'9A;'5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$5X:7-T<R@D
M=F%R;F%M92P@)B1E>&ES=',I"B`@("!["B`@("`@("`@)&5X:7-T<R`]("1T
M:&ES+3Y?9V5T17AI<W1S*"1T:&ES+3Y?=F%R<RP@)'9A<FYA;64L("1V86QU
M92D["B`@("`@("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("!F=6YC=&EO
M;B!S970H)'9A<FYA;64L("1V86QU92D*("`@('L*("`@("`@("`D:V5Y<R`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*"%(;W)D95]!<G)A>3HZ9V5T07)R87E0
M87)T<R@D=F%R;F%M92P@)&)A<V4L("1K97ES*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W9A<G-;)'9A<FYA;65=(#T@)'9A;'5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&ME>7,L("1B87-E*3L*
M("`@("`@("`@("`@)'!L86-E(#T@)B1T:&ES+3Y?=F%R<SL*"B`@("`@("`@
M("`@('=H:6QE("AC;W5N="@D:V5Y<RDI('L*("`@("`@("`@("`@("`@("1K
M97D@/2!A<G)A>5]S:&EF="@D:V5Y<RD["B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P;&%C95LD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<&QA8V5;)&ME>5T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)'!L86-E(#T@)B1P;&%C95LD:V5Y73L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'!L86-E(#T@)'9A;'5E.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!M97)G92@D=F%R<RD*("`@('L*("`@("`@
M("!F;W)E86-H("@D=F%R<R!A<R`D=F%R;F%M92`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@)'1H:7,M/G-E="@D=F%R;F%M92P@)'9A;'5E*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@861D*"1V87)N86UE+"`D=F%L=64I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)'9A<FYA;64I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/E]V87)S6R1V87)N86UE72`]("1V86QU93L*("`@('T*"B`@("!F
M=6YC=&EO;B!R96UO=F4H)'9A<FYA;64I"B`@("!["B`@("`@("`@2&]R9&5?
M07)R87DZ.F=E=$%R<F%Y4&%R=',H)'9A<FYA;64L("1B87-E+"`D:V5Y<RD[
M"B`@("`@("`@:68@*"%I<U]N=6QL*"1B87-E*2D@>PH@("`@("`@("`@("`D
M<'1R(#T@)B1T:&ES+3Y?=F%R<ULD8F%S95T["B`@("`@("`@("`@("1E;F0@
M/2!C;W5N="@D:V5Y<RD@+2`Q.PH@("`@("`@("`@("!F;W)E86-H("@D:V5Y
M<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'!T<ELD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D96YD(#T]
M("1K97DI('L*("`@("`@("`@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)'!T
M<BP@87)R87E?<V5A<F-H*"1V86PL(&%R<F%Y7VME>7,H)'!T<BDI+"`Q*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'!T<B`]("8D<'1R6R1V86Q=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]V87)S6R1V87)N86UE72D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9"!O=70@=VAE=&AE<B!O<B!N;W0@)'9A<FYA;64@=V%S
M('-E="!I;B`D87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&%R<F%Y("`@("`@("`@
M("`@("`@("`@(%1H92!A<G)A>2!T;R!S96%R8V@@:6X@*'5S=6%L;'D*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M:71H97(@)'1H:7,M/E]V87)S(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'!E8W1E9%9A<FEA
M8FQE<RDN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=F%R;F%M92`@("`@("`@
M("`@("`@("`@5&AE(&YA;64@;V8@=&AE('9A<FEA8FQE('1O(&QO;VL*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;W(N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8VAE8VM%>'!E8W1E9%9A<FEA
M8FQE<R`@268@=V4@9&]N)W0@9FEN9"`D=F%R;F%M92P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S:&]U;&0@=V4@
M8VAE8VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S('1O('-E90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M('-H;W5L9"!H879E(&5X:7-T960@*&QI:V4@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H96-K8F]X(&]R('-E
M;&5C="!M=6QT:7!L92DN"B`@("`@*@H@("`@("H@0')E='5R;B`@5VAE=&AE
M<B!O<B!N;W0@=&AE('9A<FEA8FQE('=A<R!S970@*&]R+"!I9B!W92=V92!C
M:&5C:V5D"B`@("`@*B`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B
M;&5S+"!S:&]U;&0@:&%V92!B965N('-E="DN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]E>&ES=',H)&%R<F%Y+"`D=F%R;F%M92P@)&-H96-K17AP96-T9616
M87)I86)L97,@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V=E=$5X:7-T<R@D87)R87DL("1V87)N86UE+"`D=F%L=64L("1C:&5C:T5X
M<&5C=&5D5F%R:6%B;&5S*3L*("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H
M('1H92!R97%U97-T960@=F%R:6%B;&4@*"1V87)N86UE*2!I;G1O("1V86QU
M92P@86YD(')E='5R;@H@("`@("H@=VAE=&AE<B!O<B!N;W0@=&AE('9A<FEA
M8FQE('=A<R!S970@:6X@)&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1A<G)A>2`@
M("`@("`@("`@("`@("`@("!4:&4@87)R87D@=&\@<V5A<F-H(&EN("AU<W5A
M;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@96ET:&5R("1T:&ES+3Y?=F%R<R!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97AP96-T
M961687)I86)L97,I+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'9A<FYA;64@
M("`@("`@("`@("`@("`@(%1H92!N86UE(&]F('1H92!V87)I86)L92!T;R!L
M;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R+@H@("`@("H@0'!A<F%M(&UI>&5D("`F)'9A;'5E("`@("`@
M("`@("`@("`@("`@("1V87)N86UE)W,@=F%L=64@9V5T<R!A<W-I9VYE9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1O+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H:7,@=F%R:6%B;&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`@268@=V4@9&]N)W0@9FEN9"`D=F%R
M;F%M92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S:&]U;&0@=V4@8VAE8VL*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R
M:6%B;&5S('1O('-E90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF(&ET('-H;W5L9"!H879E(&5X:7-T960@*&QI
M:V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A(&-H96-K8F]X(&]R('-E;&5C="!M=6QT:7!L92DN"B`@("`@*@H@
M("`@("H@0')E='5R;B`@5VAE=&AE<B!O<B!N;W0@=&AE('9A<FEA8FQE('=A
M<R!S970@*&]R+"!I9B!W92=V92!C:&5C:V5D"B`@("`@*B`@("`@("`@("`D
M=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S+"!S:&]U;&0@:&%V92!B965N('-E
M="DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971%>&ES=',H)&%R<F%Y+"`D
M=F%R;F%M92P@)B1V86QU92P@)&-H96-K17AP96-T961687)I86)L97,@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("A(;W)D95]!<G)A>3HZ9V5T07)R87E0
M87)T<R@D=F%R;F%M92P@)&)A<V4L("1K97ES*2D@>PH@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1A<G)A>5LD8F%S95TI*2!["B`@("`@("`@("`@("`@("`D
M=F%L=64@/2!N=6QL.PH@("`@("`@("`@("`@("`@+R\@268@=V4G<F4@<W5P
M<&]S960@=&\@8VAE8VL@)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@9&\@
M<V\L"B`@("`@("`@("`@("`@("`O+R!B=70@;6%K92!S=7)E(&YO="!T;R!C
M:&5C:R!I="!A9V%I;BX*("`@("`@("`@("`@("`@(')E='5R;B`D8VAE8VM%
M>'!E8W1E9%9A<FEA8FQE<R`_("1T:&ES+3Y?97AI<W1S*"1T:&ES+3Y?97AP
M96-T961687)I86)L97,L("1V87)N86UE+"!F86QS92D@.B!F86QS93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S96%R8VAS<&%C
M92`]("8D87)R87E;)&)A<V5=.PH@("`@("`@("`@("`@("`@=VAI;&4@*&-O
M=6YT*"1K97ES*2D@>PH@("`@("`@("`@("`@("`@("`@("1K97D@/2!A<G)A
M>5]S:&EF="@D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<V5A<F-H<W!A8V5;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU92`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@("`@("\O
M($EF('=E)W)E('-U<'!O<V5D('1O(&-H96-K"B`@("`@("`@("`@("`@("`@
M("`@("`@("\O("1T:&ES+3Y?97AP96-T961687)I86)L97,L(&1O('-O+"!B
M=70@;6%K90H@("`@("`@("`@("`@("`@("`@("`@("`O+R!S=7)E(&YO="!T
M;R!C:&5C:R!I="!A9V%I;BX*("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1C:&5C:T5X<&5C=&5D5F%R:6%B;&5S(#\@)'1H:7,M/E]E>&ES=',H
M)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@)'9A<FYA;64L(&9A;'-E*2`Z
M(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D<V5A<F-H<W!A8V4@/2`F)'-E87)C:'-P86-E6R1K97E=.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'-E87)C
M:'-P86-E.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L=64@/2!I
M<W-E="@D87)R87E;)'9A<FYA;65=*2`_("1A<G)A>5LD=F%R;F%M95T@.B!N
M=6QL.PH@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'9A;'5E*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS96EF
M("@D8VAE8VM%>'!E8W1E9%9A<FEA8FQE<RD@>PH@("`@("`@("`@("`@("`@
M+R\@268@=V4G<F4@<W5P<&]S960@=&\@8VAE8VL*("`@("`@("`@("`@("`@
M("\O("1T:&ES+3Y?97AP96-T961687)I86)L97,L(&1O('-O+"!B=70@;6%K
M92!S=7)E(&YO=`H@("`@("`@("`@("`@("`@+R\@=&\@8VAE8VL@:70@86=A
M:6XN"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]E>&ES=',H)'1H
M:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@)'9A<FYA;64L(&9A;'-E*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#;VYF:6<N<&AP````
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-#<Q,3(`,3`U
M,34T,S$P-C$`,#(P,30P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN
M<&AP)SL*"B\J*@H@*B!4:&4@0V]N9FEG.CH@<&%C:V%G92!P<F]V:61E<R!A
M(&9R86UE=V]R:R!F;W(@;6%N86=I;F<@=&AE"B`J(&-O;F9I9W5R871I;VX@
M;V8@2&]R9&4@87!P;&EC871I;VYS+"!W<FET:6YG(&-O;F8N<&AP(&9I;&5S
M(&9R;VT*("H@8V]N9BYX;6P@<V]U<F-E(&9I;&5S+"!G96YE<F%T:6YG('5S
M97(@:6YT97)F86-E<RP@971C+@H@*@H@*B!4:&4@2&]R9&5?0V]N9FEG7TYO
M9&4@1$]-(&-L87-S97,@86YD('-U8F-L87-S97,*("H@*$AO<F1E7T-O;F9I
M9U]$;V-U;65N="P@2&]R9&5?0V]N9FEG7T5L96UE;G0I(&%R92!S:6UP;'D@
M;6%S<V%G960*("H@9G)O;2!C;V1E('=R:71T96X@8GD@=&\@96UU;&%T92!0
M2%`T)W,@1$]-6$U,(&5X=&5N<VEO;B!W:71H(%!(4#4G<PH@*B!$3TT@<W5P
M<&]R="X@3VYL>2!C:&%N9V5S(&%R92!N86UI;F<@86YD('-Y;G1A8W1I8R!S
M=6=A<B](;W)D90H@*B!C;V1I;F<@<W1A;F1A<F1S.R!A;&P@8W)E9&ET(&=O
M97,@=&\@06QE>&%N9')E(&%N9"!T:&4@8V]D92!I<R!U<V5D"B`J('=I=&@@
M:&ES('!E<FUI<W-I;VXN($AI<R!O<FEG:6YA;"!C;V1E(&-A;B!B92!F;W5N
M9"!A=#H*("H*("H@("!H='1P.B\O86QE>&%N9')E+F%L87!E=&ET92YN970O
M9&]C+6%L97@O9&]M>&UL+7!H<#0M<&AP-2\*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O0V]N9FEG+G!H<"QV(#$N.#`N,BXR-B`R,#`V
M+S`V+S`Q(#(S.C0T.C,R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]&<F%M97=O<FL*("HO"F-L87-S($AO<F1E7T-O;F9I9R!["@H@
M("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@8V]N9FEG=7)E9"!A<'!L
M:6-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]A<'`["@H@("`@+RHJ"B`@("`@*B!4:&4@6$U,('1R964@;V8@
M=&AE(&-O;F9I9W5R871I;VX@9FEL92!T<F%V97)S960@=&\@86X*("`@("`J
M(&%S<V]C:6%T:79E(&%R<F%Y+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?>&UL0V]N9FEG5')E92`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!O9B!T:&4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@9FEL92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]P:'!#;VYF:6<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M8V]N=&5N="!O9B!T:&4@;VQD(&-O;F9I9W5R871I;VX@9FEL92X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]O;&1#;VYF
M:6<["@H@("`@+RHJ"B`@("`@*B!4:&4@;6%N=6%L(&-O;F9I9W5R871I;VX@
M:6X@9G)O;G0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R94-O
M;F9I9SL*"B`@("`O*BH*("`@("`J(%1H92!M86YU86P@8V]N9FEG=7)A=&EO
M;B!A9G1E<B!T:&4@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&]S=$-O;F9I
M9SL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT("1C;VYF(&%R<F%Y(&]F
M('1H92!C;VYF:6=U<F5D(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=$-O;F9I9R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@0U93('9E<G-I;VX@=&%G(&]F
M('1H92!C;VYF+GAM;"!F:6QE('=H:6-H('=I;&P@8F4@8V]P:65D(&EN=&\@
M=&AE"B`@("`@*B!C;VYF+G!H<"!F:6QE+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W9E<G-I;VY486<@/2`G)SL*"B`@
M("`O*BH*("`@("`J(%1H92!L:6YE(&UA<FMI;F<@=&AE(&)E9VEN(&]F('1H
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYF:6="96=I;B`]("(O*B!#
M3TY&24<@4U1!4E0N($1/($Y/5"!#2$%.1T4@04Y95$A)3D<@24X@3U(@0494
M15(@5$A)4R!,24Y%+B`J+UQN(CL*"B`@("`O*BH*("`@("`J(%1H92!L:6YE
M(&UA<FMI;F<@=&AE(&5N9"!O9B!T:&4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?8V]N9FEG16YD(#T@(B\J($-/3D9)1R!%3D0N($1/($Y/5"!#2$%.1T4@
M04Y95$A)3D<@24X@3U(@0D5&3U)%(%1(25,@3$E.12X@*B]<;B(["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A<'`@(%1H92!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!T;R!B
M92!C;VYF:6=U<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]#;VYF
M:6<H)&%P<"D*("`@('L*("`@("`@("`D=&AI<RT^7V%P<"`]("1A<'`["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!T:&4@87!P;&EC871I;VXG<R!C
M;VYF+GAM;"!F:6QE(&%N9"!B=6EL9',@86X@87-S;V-I871I=F4@87)R87D*
M("`@("`J(&9R;VT@:71S(%A-3"!T<F5E+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D8W5S=&]M7V-O;F8@("!!;GD@<V5T=&EN9W,@=&AA="!S:&%L
M;"!B92!I;F-L=61E9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!R97!R
M97-E;G1I;F<@=&AE(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5A9%A-3$-O;F9I9R@D8W5S=&]M7V-O;F8@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?>&UL0V]N9FEG5')E
M92D@?'P@)&-U<W1O;5]C;VYF*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*("`@("`@("`@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G9FEL
M97)O;W0G+"`D=&AI<RT^7V%P<"D@+B`G+V-O;F9I9R<["@H@("`@("`@("`@
M("!I9B`H)&-U<W1O;5]C;VYF*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-U<G)E;G1#;VYF:6<@/2`D8W5S=&]M7V-O;F8["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O*B!&971C:"!T:&4@8W5R<F5N="!C
M;VYF+G!H<"!C;VYT96YT<RX@*B\*("`@("`@("`@("`@("`@($!E=F%L*"1T
M:&ES+3YG97102%!#;VYF:6<H*2D["B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&-O;F8I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT0V]N9FEG(#T@)&-O;F8["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($QO860@=&AE($1/32!O8FIE8W0N("HO
M"B`@("`@("`@("`@("1D;V,@/2!(;W)D95]#;VYF:6=?1&]C=6UE;G0Z.F9A
M8W1O<GDH)'!A=&@@+B`G+V-O;F8N>&UL)RD["@H@("`@("`@("`@("`O*B!#
M:&5C:R!I9B!T:&5R92!I<R!A($-64R!V97)S:6]N('1A9R!A;F0@<W1O<F4@
M:70N("HO"B`@("`@("`@("`@("1N;V1E(#T@)&1O8RT^9FER<W1?8VAI;&0H
M*3L*("`@("`@("`@("`@=VAI;&4@*"%E;7!T>2@D;F]D92DI('L*("`@("`@
M("`@("`@("`@(&EF("@D;F]D92T^='EP92`]/2!834Q?0T]-345.5%].3T1%
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]<)"XJ
M/V-O;F9<+GAM;"QV("XJ/R`N*EPD+R<L("1N;V1E+3YN;V1E7W9A;'5E*"DL
M("1M871C:"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M97)S:6]N5&%G(#T@)&UA=&-H6S!=("X@(EQN(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&YO9&4@/2`D;F]D92T^;F5X
M=%]S:6)L:6YG*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%!A
M<G-E('1H92!C;VYF:6<@9FEL92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]X
M;6Q#;VYF:6=4<F5E(#T@87)R87DH*3L*("`@("`@("`@("`@)')O;W0@/2`D
M9&]C+3YR;V]T*"D["B`@("`@("`@("`@(&EF("@D<F]O="T^:&%S7V-H:6QD
M7VYO9&5S*"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,979E
M;"@D=&AI<RT^7WAM;$-O;F9I9U1R964L("1R;V]T+3YC:&EL9%]N;V1E<R@I
M+"`G)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7WAM;$-O;F9I9U1R964["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!F:6QE(&-O;G1E;G0@;V8@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;B!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=6YP87)S960@8V]N9FEG=7)A=&EO;B!F:6QE(&-O;G1E;G0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!(4$-O;F9I9R@I"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)'1H:7,M/E]O;&1#;VYF:6<I*2!["B`@("`@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@("1P871H(#T@)')E
M9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)'1H:7,M/E]A<'`I("X@)R]C;VYF
M:6<G.PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)'!A=&@@+B`G+V-O
M;F8N<&AP)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;VQD0V]N9FEG
M(#T@9FEL95]G971?8V]N=&5N=',H)'!A=&@@+B`G+V-O;F8N<&AP)RD["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;VQD0V]N9FEG*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;VQD0V]N9FEG(#T@<')E
M9U]R97!L86-E*"<O/%P_<&AP7&X_+R<L("<G+"`D=&AI<RT^7V]L9$-O;F9I
M9RD["B`@("`@("`@("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D=&AI<RT^
M7V]L9$-O;F9I9RP@)'1H:7,M/E]C;VYF:6="96=I;BD["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<')E0V]N9FEG(#T@<W5B<W1R*"1T:&ES+3Y?
M;VQD0V]N9FEG+"`P+"`D<&]S*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O;&1#;VYF:6<@/2!S=6)S='(H)'1H:7,M/E]O;&1#;VYF:6<L
M("1P;W,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D<&]S(#T@<W1R<&]S*"1T:&ES+3Y?;VQD0V]N9FEG+"`D=&AI<RT^
M7V-O;F9I9T5N9"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1P;W,@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&]S
M=$-O;F9I9R`]('-U8G-T<B@D=&AI<RT^7V]L9$-O;F9I9RP@)'!O<R`K('-T
M<FQE;B@D=&AI<RT^7V-O;F9I9T5N9"DI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V]L9$-O;F9I9R`]('-U8G-T<B@D=&AI<RT^7V]L9$-O
M;F9I9RP@,"P@)'!O<RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]O;&1#;VYF:6<@/2`G)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]O;&1#;VYF:6<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE(&-O;G1E;G0@;V8@=&AE
M(&%P<&QI8V%T:6]N)W,@8V]N9FEG=7)A=&EO;B!F:6QE+@H@("`@("H*("`@
M("`J($!P87)A;2!687)I86)L97,@)&9O<FUV87)S("!4:&4@<')O8V5S<V5D
M(&-O;F9I9W5R871I;VX@9F]R;2!D871A+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C=7-T;VU?8V]N9B`@($%N>2!S971T:6YG<R!T:&%T('-H86QL(&)E(&EN
M8VQU9&5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!O9B!T:&4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A
M=&502%!#;VYF:6<H)&9O<FUV87)S+"`D8W5S=&]M7V-O;F8@/2!N=6QL*0H@
M("`@>PH@("`@("`@("1T:&ES+3YR96%D6$U,0V]N9FEG*"1C=7-T;VU?8V]N
M9BD["B`@("`@("`@)'1H:7,M/F=E=%!(4$-O;F9I9R@I.PH*("`@("`@("`D
M=&AI<RT^7W!H<$-O;F9I9R`]("(\/W!H<%QN(CL*("`@("`@("`D=&AI<RT^
M7W!H<$-O;F9I9R`N/2`D=&AI<RT^7W!R94-O;F9I9SL*("`@("`@("`D=&AI
M<RT^7W!H<$-O;F9I9R`N/2`D=&AI<RT^7V-O;F9I9T)E9VEN.PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]V97)S:6]N5&%G*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`G+R\@)R`N("1T:&ES+3Y?=F5R<VEO
M;E1A9SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]G96YE<F%T95!(4$-O
M;F9I9R@D=&AI<RT^7WAM;$-O;F9I9U1R964L("<G+"`D9F]R;79A<G,I.PH@
M("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("1T:&ES+3Y?8V]N9FEG16YD
M.PH@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("1T:&ES+3Y?<&]S=$-O
M;F9I9SL*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&AP0V]N9FEG.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@:71E;7,@9F]R(&$@<&%R="!O9B!T:&4@8V]N9FEG=7)A=&EO;@H@
M("`@("H@=')E92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'-E8W1I;VX@($%N(&%S<V]C:6%T
M:79E(&%R<F%Y(&-O;G1A:6YI;F<@=&AE('!A<G0@;V8@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('1R879E<G-E9"!834P@8V]N9FEG=7)A
M=&EO;B!T<F5E('1H870@<VAO=6QD(&)E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@('!R;V-E<W-E9"X*("`@("`J($!P87)A;2!S=')I;F<@)'!R
M969I>"`@02!C;VYF:6=U<F%T:6]N('!R969I>"!D971E<FUI;FEN9R!T:&4@
M8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!P;W-I=&EO
M;B!I;G-I9&4@=&AE(&-O;F9I9W5R871I;VX@9FEL92X@5&AI<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!P<F5F:7@@=VEL;"!B92!T<F%N<VQA
M=&5D('1O(&ME>7,@;V8@=&AE("1C;VYF"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y(&EN('1H92!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!F:6QE+@H@("`@("H@0'!A<F%M(%9A<FEA8FQE<R`D9F]R;79A<G,@(%1H
M92!P<F]C97-S960@8V]N9FEG=7)A=&EO;B!F;W)M(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G96YE<F%T95!(4$-O;F9I9R@D<V5C=&EO;BP@)'!R
M969I>"P@)&9O<FUV87)S*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH
M)'-E8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1S96-T:6]N(&%S("1N86UE(#T^("1C;VYF:6=I
M=&5M*2!["B`@("`@("`@("`@("1P<F5F:7AE9&YA;64@/2!E;7!T>2@D<')E
M9FEX*2`_("1N86UE(#H@)'!R969I>"`N("=\)R`N("1N86UE.PH@("`@("`@
M("`@("`D8V]N9FEG;F%M92`]('-T<E]R97!L86-E*"=\)RP@)U]?)RP@)'!R
M969I>&5D;F%M92D["B`@("`@("`@("`@("1Q=6]T92`]("%I<W-E="@D8V]N
M9FEG:71E;5LG<75O=&4G72D@?'P@)&-O;F9I9VET96U;)W%U;W1E)UT@(3T]
M(&9A;'-E.PH@("`@("`@("`@("!I9B`H)&-O;F9I9VET96T@/3T@)W!L86-E
M:&]L9&5R)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P:'!#;VYF:6<@
M+CT@)R1C;VYF6UPG)R`N('-T<E]R97!L86-E*"=\)RP@)UPG75M<)R<L("1P
M<F5F:7@I("X@(B==(#T@87)R87DH*3M<;B(["B`@("`@("`@("`@('T@96QS
M96EF("AI<W-E="@D8V]N9FEG:71E;5LG<W=I=&-H)UTI*2!["B`@("`@("`@
M("`@("`@("`D=F%L(#T@)&9O<FUV87)S+3YG971%>&ES=',H)&-O;F9I9VYA
M;64L("1W87-S970I.PH@("`@("`@("`@("`@("`@:68@*"$D=V%S<V5T*2![
M"B`@("`@("`@("`@("`@("`@("`@)'9A;"`](&ES<V5T*"1C;VYF:6=I=&5M
M6R=D969A=6QT)UTI(#\@)&-O;F9I9VET96U;)V1E9F%U;'0G72`Z(&YU;&P[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&-O;F9I9VET96U;)W-W:71C:"==6R1V86Q=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1V86QU92`]("1V86P["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1Q=6]T92`F)B`D=F%L=64@(3T@)W1R=64G("8F("1V86QU92`A/2`G9F%L
M<V4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("(G(B`N
M("1V86QU92`N("(G(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G96YE<F%T95!(4$-O;F9I9R@D8V]N9FEG
M:71E;5LG<W=I=&-H)UU;)'9A;%U;)V9I96QD<R==+"`D<')E9FEX+"`D9F]R
M;79A<G,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I
M9B`H:7-S970H)&-O;F9I9VET96U;)U]T>7!E)UTI*2!["B`@("`@("`@("`@
M("`@("`D=F%L(#T@)&9O<FUV87)S+3YG971%>&ES=',H)&-O;F9I9VYA;64L
M("1W87-S970I.PH@("`@("`@("`@("`@("`@:68@*"$D=V%S<V5T*2!["B`@
M("`@("`@("`@("`@("`@("`@)'9A;"`](&ES<V5T*"1C;VYF:6=I=&5M6R=D
M969A=6QT)UTI(#\@)&-O;F9I9VET96U;)V1E9F%U;'0G72`Z(&YU;&P["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'1Y<&4@/2`D8V]N
M9FEG:71E;5LG7W1Y<&4G73L*("`@("`@("`@("`@("`@('-W:71C:"`H)'1Y
M<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I96YU;2<Z"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1E;F-V86QS(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;"!A<R`D=BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5N8W9A;'-;72`]("1T:&ES+3Y?<75O
M=&4H)'8I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("1A<G)A>79A;"`]("(G(B`N(&EM<&QO9&4H)UPG+"!<
M)R<L("1E;F-V86QS*2`N("(G(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1A<G)A>79A;"`]/2`B)R<B*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D87)R87EV86P@/2`G)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A<G)A>79A;"`]("<G.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`G87)R87DH)R`N
M("1A<G)A>79A;"`N("<I)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=B;V]L96%N)SH*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-?8F]O;"@D=F%L*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2`D=F%L(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=64@/2`H)'9A;"`]/2`G;VXG*2`_("=T<G5E)R`Z("=F86QS
M92<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W-T<FEN9VQI<W0G.@H@
M("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!E>'!L;V1E*"<L)RP@)'9A
M;"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%L=65S
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`B87)R87DH
M)R(@+B`D=&AI<RT^7W%U;W1E*'1R:6TH)'9A;'5E<RDI("X@(B<I(CL*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D96YC=F%L<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'8I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E;F-V86QS6UT@/2`D=&AI<RT^7W%U;W1E*'1R:6TH
M)'8I*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`D87)R87EV86P@/2`B)R(@+B!I;7!L;V1E*"=<)RP@7"<G
M+"`D96YC=F%L<RD@+B`B)R(["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D87)R87EV86P@/3T@(B<G(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R<F%Y=F%L(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)V%R<F%Y*"<@
M+B`D87)R87EV86P@+B`G*2<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)VEN="<Z"B`@("`@("`@("`@("`@("`@("`@:68@*"1V86P@(3T]("<G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("AI;G0I)'9A;#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G;V-T86PG.@H@("`@("`@("`@
M("`@("`@("`@("1V86QU92`]('-P<FEN=&8H)S`E;R<L(&]C=&1E8R@D=F%L
M*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G:&5A9&5R)SH*("`@("`@("`@("`@("`@(&-A<V4@)V1E<V-R
M:7!T:6]N)SH*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L
M("$]("<G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("1V
M86P["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<75O=&4@)B8@)'9A
M;'5E("$]("=T<G5E)R`F)B`D=F%L=64@(3T@)V9A;'-E)RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@(B<B("X@)'1H:7,M/E]Q
M=6]T92@D=F%L=64I("X@(B<B.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]G96YE<F%T95!(4$-O;F9I9R@D8V]N
M9FEG:71E;2P@)'!R969I>&5D;F%M92P@)&9O<FUV87)S*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU92DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("<D8V]N9EM<)R<@+B!S
M=')?<F5P;&%C92@G7U\G+"`G7"==6UPG)RP@)&-O;F9I9VYA;64I("X@)UPG
M72`]("<@+B`D=F%L=64@+B`B.UQN(CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!U;G-E="@D=F%L=64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%!A<G-E<R!O;F4@;&5V96P@;V8@=&AE(&-O;F9I9W5R871I;VX@
M6$U,('1R964@:6YT;R!T:&4@87-S;V-I871I=F4*("`@("`J(&%R<F%Y(&-O
M;G1A:6YI;F<@=&AE('1R879E<G-E9"!C;VYF:6=U<F%T:6]N('1R964N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("8D8V]N9B`@("`@5&AE(&%L<F5A9'D@97AI<W1I;F<@87)R
M87D@=VAE<F4@=&AE('!R;V-E<W-E9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,('1R964@<&]R=&EO;B!S:&]U;&0@8F4@87!P96YD960@
M=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&-H:6QD<F5N("!!;B!A<G)A>2!C
M;VYT86EN:6YG('1H92!834P@;F]D97,@;V8@=&AE(&QE=F5L"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&%T('-H;W5L9"!B92!P87)S960N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C='@@("`@("!!('-T<FEN9R!R97!R
M97-E;G1I;F<@=&AE(&-U<G)E;G0@<&]S:71I;VX*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("AC;VYT97AT('!R969I>"D@:6YS:61E('1H92!C
M;VYF:6=U<F%T:6]N(%A-3`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E3&5V96PH)B1C
M;VYF+"`D8VAI;&1R96XL("1C='@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH*("`@("`@("!F;W)E86-H
M("@D8VAI;&1R96X@87,@)&YO9&4I('L*("`@("`@("`@("`@:68@*"1N;V1E
M+3YT>7!E("$](%A-3%]%3$5-14Y47TY/1$4I('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1N86UE(#T@
M)&YO9&4M/F=E=%]A='1R:6)U=&4H)VYA;64G*3L*("`@("`@("`@("`@)&1E
M<V,@/2!497AT7T9I;'1E<CHZ9FEL=&5R*"1N;V1E+3YG971?871T<FEB=71E
M*"=D97-C)RDL("=L:6YK=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@/3X@)TAO
M<F1E.CIE>'1E<FYA;%5R;"<I*3L*("`@("`@("`@("`@)')E<75I<F5D(#T@
M(2@D;F]D92T^9V5T7V%T=')I8G5T92@G<F5Q=6ER960G*2`]/2`G9F%L<V4G
M*3L*("`@("`@("`@("`@)'%U;W1E(#T@(2@D;F]D92T^9V5T7V%T=')I8G5T
M92@G<75O=&4G*2`]/2`G9F%L<V4G*3L*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D8W1X*2D@>PH@("`@("`@("`@("`@("`@)&-U<F-T>"`]("1C='@@+B`G
M?"<@+B`D;F%M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1C=7)C='@@/2`D;F%M93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@<W=I=&-H("@D;F]D92T^=&%G;F%M92D@>PH@("`@("`@("`@("!C87-E
M("=C;VYF:6=D97-C<FEP=&EO;B<Z"B`@("`@("`@("`@("`@("!I9B`H96UP
M='DH)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!M9#4H
M;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G9&5S8W)I<'1I
M;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^(%1E>'1?1FEL=&5R.CIF:6QT97(H)'1H:7,M/E]D969A=6QT*"1C
M=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2DL("=L:6YK
M=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@/3X@)TAO<F1E.CIE>'1E<FYA;%5R
M;"<I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)V-O;F9I9VAE861E<B<Z"B`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!M9#4H;6EC
M<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G:&5A9&5R)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`D
M=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E
M>'0H)&YO9&4I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)V-O;F9I9W-W:71C:"<Z"B`@("`@("`@("`@("`@("`D=F%L
M=65S(#T@)'1H:7,M/E]G9713=VET8VA686QU97,H)&YO9&4L("1C='@I.PH@
M("`@("`@("`@("`@("`@:68@*"1Q=6]T92D@>PH@("`@("`@("`@("`@("`@
M("`@("1D969A=6QT(#T@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L("1T:&ES
M+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1D969A=6QT(#T@)'1H:7,M
M/E]D969A=6QT4F%W*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT
M*"1N;V1E*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)&1E9F%U;'0@/3T]("<G*2!["B`@("`@("`@("`@("`@("`@("`@)&1E
M9F%U;'0@/2!K97DH)'9A;'5E<RD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H:7-?8F]O;"@D9&5F875L="DI('L*("`@("`@("`@
M("`@("`@("`@("`D9&5F875L="`]("1D969A=6QT(#\@)W1R=64G(#H@)V9A
M;'-E)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C;VYF
M6R1N86UE72`](&%R<F%Y*"=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S=VET8V@G(#T^("1V86QU97,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@)&1E9F%U;'0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=C;VYF:6=E;G5M)SH*("`@("`@("`@("`@("`@("1V
M86QU97,@/2`D=&AI<RT^7V=E=$5N=6U686QU97,H)&YO9&4I.PH@("`@("`@
M("`@("`@("`@:68@*"1Q=6]T92D@>PH@("`@("`@("`@("`@("`@("`@("1D
M969A=6QT(#T@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L("1T:&ES+3Y?9V5T
M3F]D94]N;'E497AT*"1N;V1E*2D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1D969A=6QT(#T@)'1H:7,M/E]D969A
M=6QT4F%W*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E
M*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&1E
M9F%U;'0@/3T]("<G*2!["B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@
M/2!K97DH)'9A;'5E<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H:7-?8F]O;"@D9&5F875L="DI('L*("`@("`@("`@("`@("`@
M("`@("`D9&5F875L="`]("1D969A=6QT(#\@)W1R=64G(#H@)V9A;'-E)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE
M72`](&%R<F%Y*"=?='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q=6ER960L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<75O=&4G
M(#T^("1Q=6]T92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QU97,G(#T^("1V86QU97,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)&1E9F%U
M;'0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=C;VYF:6=L:7-T)SH*("`@("`@("`@("`@("`@("1D969A=6QT(#T@)'1H
M:7,M/E]D969A=6QT*"1C=7)C='@L(&YU;&PI.PH@("`@("`@("`@("`@("`@
M:68@*"1D969A=6QT(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@
M)&1E9F%U;'0@/2`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92D["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&1E9F%U;'0I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@/2!I;7!L;V1E*"<L("<L
M("1D969A=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1C;VYF6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)W-T<FEN9VQI<W0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I
M<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)&1E9F%U;'0I.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=C;VYF
M:6=M=6QT:65N=6TG.@H@("`@("`@("`@("`@("`@)'9A;'5E<R`]("1T:&ES
M+3Y?9V5T16YU;59A;'5E<R@D;F]D92D["B`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("`@("`D
M8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=M=6QT:65N=6TG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D
M)R`]/B`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=F%L=65S)R`]/B`D=F%L=65S+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^($AO
M<F1E7T%R<F%Y.CIV86QU97-4;TME>7,H)'1H:7,M/E]D969A=6QT*"1C=7)C
M='@L(&5X<&QO9&4H)RPG+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D
M92DI*2DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=C;VYF:6=P87-S=V]R9"<Z"B`@("`@("`@("`@("`@("`D8V]N9ELD
M;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=P87-S=V]R9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^("1R
M97%U:7)E9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T
M>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*2D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W-T<FEN
M9R<Z"B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y
M<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R97%U:7)E9"<@/3X@)')E<75I<F5D+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M("1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/;FQY
M5&5X="@D;F]D92DI*3L*("`@("`@("`@("`@("`@(&EF("@D8V]N9ELD;F%M
M95U;)V1E9F%U;'0G72`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@
M("`D8V]N9ELD;F%M95U;)V1E9F%U;'0G72`]("=F86QS92<["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&-O;F9;)&YA;65=6R=D969A=6QT)UT@/3T]
M('1R=64I('L*("`@("`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95U;)V1E
M9F%U;'0G72`]("=T<G5E)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N9FEG8F]O;&5A
M;B<Z"B`@("`@("`@("`@("`@("`D9&5F875L="`]("1T:&ES+3Y?9V5T3F]D
M94]N;'E497AT*"1N;V1E*3L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D
M9&5F875L="D@?'P@)&1E9F%U;'0@/3T]("=F86QS92<I('L*("`@("`@("`@
M("`@("`@("`@("`D9&5F875L="`](&9A;'-E.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L="`]('1R=64[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M
M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=B;V]L96%N)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@)')E<75I
M<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"`D
M9&5F875L="DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E("=C;VYF:6=I;G1E9V5R)SH*("`@("`@("`@("`@("`@("1V86QU
M97,@/2`D=&AI<RT^7V=E=$5N=6U686QU97,H)&YO9&4I.PH@("`@("`@("`@
M("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G:6YT)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E
M9"<@/3X@)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W9A;'5E<R<@/3X@)'9A;'5E<RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`D9&5S8RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D
M=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E
M>'0H)&YO9&4I*2D["B`@("`@("`@("`@("`@("!I9B`H)&YO9&4M/F=E=%]A
M='1R:6)U=&4H)V]C=&%L)RD@/3T@)W1R=64G("8F"B`@("`@("`@("`@("`@
M("`@("`@)&-O;F9;)&YA;65=6R=D969A=6QT)UT@(3T@)R<I('L*("`@("`@
M("`@("`@("`@("`@("`D8V]N9ELD;F%M95U;)U]T>7!E)UT@/2`G;V-T86PG
M.PH@("`@("`@("`@("`@("`@("`@("1C;VYF6R1N86UE75LG9&5F875L="==
M(#T@<W!R:6YT9B@G,"5O)RP@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L(&]C
M=&1E8R@D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)V-O;F9I9W!H<"<Z"B`@("`@("`@("`@("`@("`D8V]N9ELD
M;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=P:'`G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q=6ER
M960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<75O
M=&4G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L=%)A
M=R@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N
M9FEG<W%L)SH*("`@("`@("`@("`@("`@("1C;VYF6R1N;V1E+3YG971?871T
M<FEB=71E*"=S=VET8VAN86UE)RE=(#T@)'1H:7,M/E]C;VYF:6=344PH)&-T
M>"P@)&YO9&4I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E("=C;VYF:6=V9G,G.@H@("`@("`@("`@("`@("`@)&-O;F9;)&YO
M9&4M/F=E=%]A='1R:6)U=&4H)W-W:71C:&YA;64G*5T@/2`D=&AI<RT^7V-O
M;F9I9U9&4R@D8W1X+"`D;F]D92D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W-E8W1I;VXG.@H@("`@("`@("`@
M("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@
M("1C=7(@/2`F)&-O;F9;)&YA;65=.PH@("`@("`@("`@("`@("`@:68@*"1N
M;V1E+3YH87-?8VAI;&1?;F]D97,H*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R<V5,979E;"@D8W5R+"`D;F]D92T^8VAI;&1?;F]D97,H
M*2P@)&-U<F-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W1A8B<Z"B`@("`@
M("`@("`@("`@("`D:V5Y(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`@
M("`@("`@("1C;VYF6R1K97E=(#T@87)R87DH)W1A8B<@/3X@)&YA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`D
M9&5S8RD["B`@("`@("`@("`@("`@("!I9B`H)&YO9&4M/FAA<U]C:&EL9%]N
M;V1E<R@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S94QE
M=F5L*"1C;VYF+"`D;F]D92T^8VAI;&1?;F]D97,H*2P@)&-T>"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)V-O;F9I9W!L86-E:&]L9&5R)SH*("`@("`@("`@("`@("`@
M("1C;VYF6VUD-2AM:6-R;W1I;64H*2E=(#T@)W!L86-E:&]L9&5R)SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("`D8W5R(#T@)B1C;VYF6R1N86UE73L*("`@("`@("`@("`@("`@
M(&EF("@D;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<G-E3&5V96PH)&-U<BP@)&YO9&4M/F-H:6QD
M7VYO9&5S*"DL("1C=7)C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VYF:6=U<F%T:6]N('1R
M964@9F]R(&%N(%-13"!B86-K96YD(&-O;F9I9W5R871I;VX@=&\*("`@("`J
M(')E<&QA8V4@82`\8V]N9FEG<W%L/B!T86<N"B`@("`@*B!3=6)N;V1E<R!W
M:6QL(&)E('!A<G-E9"!A;F0@861D960@=&\@8F]T:"!T:&4@2&]R9&4@9&5F
M875L=',@86YD('1H90H@("`@("H@0W5S=&]M(&-O;F9I9W5R871I;VX@<&%R
M=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8W1X("`@("`@("`@5&AE(&-O;G1E>'0@;V8@
M=&AE(#QC;VYF:6=S<6P^('1A9RX*("`@("`J($!P87)A;2!$;VU.;V1E("1N
M;V1E("`@("`@(%1H92!$;VU.;V1E(')E<')E<V5N=&%T:6]N(&]F('1H92`\
M8V]N9FEG<W%L/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&%G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W=I=&-H;F%M92`@268@1&]M
M3F]D92!I<R!N;W0@<V5T+"!T:&4@=F%L=64@;V8@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T86<G<R!S=VET8VAN86UE(&%T=')I
M8G5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<W-O8VEA
M=&EV92!A<G)A>2!W:71H('1H92!344P@8V]N9FEG=7)A=&EO;B!T<F5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N9FEG4U%,*"1C='@L("1N;V1E(#T@
M;G5L;"P@)'-W:71C:&YA;64@/2`G9')I=F5R8V]N9FEG)RD*("`@('L*("`@
M("`@("`D<&5R<VES=&5N="`](&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G
M(#T^("=B;V]L96%N)RP*("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS
M92P*("`@("`@("`@("`@)V1E<V,G(#T^("=297%U97-T('!E<G-I<W1E;G0@
M8V]N;F5C=&EO;G,_)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES
M+3Y?9&5F875L="@D8W1X("X@)WQP97)S:7-T96YT)RP@9F%L<V4I*3L*("`@
M("`@("`D:&]S='-P96,@/2!A<G)A>2@*("`@("`@("`@("`@)U]T>7!E)R`]
M/B`G=&5X="<L"B`@("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@
M("`@("`@("`@)V1E<V,G(#T^("=$871A8F%S92!S97)V97(O:&]S="<L"B`@
M("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N
M("=\:&]S='-P96,G+"`G)RDI.PH@("`@("`@("1U<V5R;F%M92`](&%R<F%Y
M*`H@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@
M)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@("`@("`@("`G9&5S8R<@/3X@)U5S
M97)N86UE('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%S)RP*("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQU
M<V5R;F%M92<L("<G*2D["B`@("`@("`@)'!A<W-W;W)D(#T@87)R87DH"B`@
M("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`G<F5Q
M=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@("`G9&5S8R<@/3X@)U!A<W-W
M;W)D('1O(&-O;FYE8W0@=VET:"<L"B`@("`@("`@("`@("=D969A=6QT)R`]
M/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\<&%S<W=O<F0G+"`G)RDI.PH@
M("`@("`@("1D871A8F%S92`](&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G
M(#T^("=T97AT)RP*("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@
M("`@("`@("`@("`G9&5S8R<@/3X@)T1A=&%B87-E(&YA;64@=&\@=7-E)RP*
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X
M("X@)WQD871A8F%S92<L("<G*2D["B`@("`@("`@)'-O8VME="`](&%R<F%Y
M*`H@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@
M)W)E<75I<F5D)R`]/B!F86QS92P*("`@("`@("`@("`@)V1E<V,G(#T^("=,
M;V-A=&EO;B!O9B!53DE8('-O8VME="<L"B`@("`@("`@("`@("=D969A=6QT
M)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\<V]C:V5T)RP@)R<I*3L*
M("`@("`@("`D<&]R="`](&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G(#T^
M("=I;G0G+`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@
M("`@("`@("`G9&5S8R<@/3X@)U!O<G0@=&AE($1"(&ES(')U;FYI;F<@;VXL
M(&EF(&YO;BUS=&%N9&%R9"<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D
M=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\<&]R="<L(&YU;&PI*3L*("`@("`@
M("`D<')O=&]C;VP@/2!A<G)A>2@*("`@("`@("`@("`@)V1E<V,G(#T^("=(
M;W<@<VAO=6QD('=E(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E/R<L"B`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\
M<')O=&]C;VPG+"`G=6YI>"<I+`H@("`@("`@("`@("`G<W=I=&-H)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("=U;FEX)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`G9&5S8R<@/3X@)U5.25@@4V]C:V5T<R<L"B`@("`@
M("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("=S;V-K970G(#T^("1S;V-K970I*2P*("`@("`@("`@
M("`@("`@("=T8W`G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D
M97-C)R`]/B`G5$-0+TE0)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!O<G0G(#T^
M("1P;W)T*2DI*3L*("`@("`@("`D;7ES<6Q?<')O=&]C;VP@/2`D<')O=&]C
M;VP["B`@("`@("`@)&UY<W%L7W!R;W1O8V]L6R=S=VET8V@G75LG=&-P)UU;
M)V9I96QD<R==6R=P;W)T)UU;)V1E9F%U;'0G72`]("1T:&ES+3Y?9&5F875L
M="@D8W1X("X@)WQP;W)T)RP@,S,P-BD["B`@("`@("`@)&-H87)S970@/2!A
M<G)A>2@*("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@
M("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@)V1E<V,G(#T^
M("=);G1E<FYA;&QY('5S960@8VAA<G-E="<L"B`@("`@("`@("`@("=D969A
M=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\8VAA<G-E="<L("=I
M<V\M.#@U.2TQ)RDI.PH*("`@("`@("`D;V-I.%]F:65L9',@/2!A<G)A>2@*
M("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@
M("`@("`@("`G=7-E<FYA;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@
M)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0I.PH@("`@("`@(&EF("AF=6YC=&EO
M;E]E>&ES=',H)V]C:5]C;VYN96-T)RDI('L*("`@("`@("`@("`@)&]C:3A?
M9FEE;&1S6R=D871A8F%S92==(#T@87)R87DH"B`@("`@("`@("`@("`@("`G
M7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("=R97%U:7)E9"<@
M/3X@=')U92P*("`@("`@("`@("`@("`@("=D97-C)R`]/B`G1&%T86)A<V4@
M;F%M92!O<B!%87-Y($-O;FYE8W0@<&%R86UE=&5R)RP*("`@("`@("`@("`@
M("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\9&%T
M86)A<V4G+"`G:&]R9&4G*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&]C:3A?9FEE;&1S6R=H;W-T<W!E8R==(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("=R
M97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("=D97-C)R`]/B`G
M1&%T86)A<V4@;F%M92!O<B!%87-Y($-O;FYE8W0@<&%R86UE=&5R)RP*("`@
M("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T
M>"`N("=\:&]S='-P96,G+"`G:&]R9&4G*2D["B`@("`@("`@?0H@("`@("`@
M("1O8VDX7V9I96QD<ULG8VAA<G-E="==(#T@)&-H87)S970["@H@("`@("`@
M("1C=7-T;VU?9FEE;&1S(#T@87)R87DH"B`@("`@("`@("`@("=R97%U:7)E
M9"<@/3X@=')U92P*("`@("`@("`@("`@)V1E<V,G(#T^("=7:&%T(&1A=&%B
M87-E(&)A8VME;F0@<VAO=6QD('=E('5S93\G+`H@("`@("`@("`@("`G9&5F
M875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?'!H<'1Y<&4G+"`G
M9F%L<V4G*2P*("`@("`@("`@("`@)W-W:71C:"<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`G9F%L<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=D97-C)R`]/B`G6TYO;F5=)RP*("`@("`@("`@("`@("`@("`@("`G
M9FEE;&1S)R`]/B!A<G)A>2@I*2P*("`@("`@("`@("`@("`@("=D8F%S92<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=D0F%S
M92<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G06)S
M;VQU=&4@<&%T:"!T;R!T:&4@9&%T86)A<V4@9FEL92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT
M*"1C='@@+B`G?&1A=&%B87-E)RP@)R<I*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@)VUO9&4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U]T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9&5S8R<@/3X@)U1H92!M;V1E('1O(&]P96X@=&AE(&9I;&4@
M=VET:"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=65S)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P(#T^
M("=296%D($]N;'DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#(@/3X@)U)E860@5W)I=&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\;6]D
M92<L(#(I*2P*"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]
M/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)VEB87-E)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T9I<F5B:7)D+TEN
M=&5R0F%S92<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=D8G-Y;G1A>"<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=E
M;G5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G
M5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O('5S92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEB87-E)R`]/B`G26YT
M97)"87-E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9FER
M96)I<F0G(#T^("=&:7)E8FER9"<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD
M8G-Y;G1A>"<L("=F:7)E8FER9"<I*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@
M("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("1D871A8F%S
M92P*("`@("`@("`@("`@("`@("`@("`@("`@)V)U9F9E<G,G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G:6YT
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G5&AE
M(&YU;6)E<B!O9B!D871A8F%S92!B=69F97)S('1O(&%L;&]C871E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H
M:7,M/E]D969A=6QT*"1C='@@+B`G?&)U9F9E<G,G+"!N=6QL*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=D:6%L96-T)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@)VEN="<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U1H92!D969A=6QT
M(%-13"!D:6%L96-T(&9O<B!A;GD@<W1A=&5M96YT(&5X96-U=&5D('=I=&AI
M;B!A(&-O;FYE8W1I;VXN)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&1I
M86QE8W0G+"!N=6QL*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=R;VQE
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?='EP
M92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("=2;VQE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?')O;&4G
M+"!N=6QL*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]
M/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)V9B<W%L)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T9R;VYT8F%S92<L
M"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N
M="P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`D:&]S
M='-P96,L"B`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M92<@/3X@
M)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&%S<W=O<F0G
M(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B
M87-E)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C
M:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)VEF>"<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=);F9O
M<FUI>"<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R
M<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]
M/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R
M9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&%T
M86)A<V4G(#T^("1D871A8F%S92P*("`@("`@("`@("`@("`@("`@("`@("`@
M)V-H87)S970G(#T^("1C:&%R<V5T*2DL"B`@("`@("`@("`@("`@("`G;7-Q
M;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=M
M4U%,)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S
M:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^
M("1H;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE
M)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S
M=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M<&]R="<@/3X@)'!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A
M8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@("`@("`@("`@("=M<W-Q
M;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=-
M4R!344P@4V5R=F5R)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G
M(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S
M='-P96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@("`@("`@
M)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G<&]R="<@/3X@)'!O<G0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@("`@("`@
M("`@("=M>7-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("=->5-13"<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT
M)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO
M<W1S<&5C)R`]/B`D:&]S='-P96,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=U<V5R;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@)W!R;W1O8V]L)R`]/B`D;7ES<6Q?<')O=&]C;VPL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I
M*2P*("`@("`@("`@("`@("`@("=M>7-Q;&DG(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=D97-C)R`]/B`G37E344P@*&UY<W%L:2DG+`H@("`@
M("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@)'!E<G-I<W1E;G0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)&AO<W1S<&5C
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;64G(#T^("1U<V5R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`D
M<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("=P;W)T)R`]/B`D
M<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@)W-O8VME="<@/3X@)'-O
M8VME="P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`D
M9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]
M/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)V]C:3@G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G3W)A8VQE)RP*("`@
M("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B`D;V-I.%]F:65L9',I+`H@
M("`@("`@("`@("`@("`@)V]D8F,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=D97-C)R`]/B`G3T1"0R<L"B`@("`@("`@("`@("`@("`@("`@
M)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P
M97)S:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@
M("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G:&]S='-P96,G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T133B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A
M=6QT*"1C='@@+B`G?&AO<W1S<&5C)RP@)R<I*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)V1B<WEN=&%X)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=?='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E<V,G(#T^("=4:&4@9&%T86)A<V4@<WEN=&%X
M('9A<FEA;G0@=&\@=7-E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<W%L.3(G(#T^("=344PY,B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V%C8V5S<R<@/3X@)T%C8V5S<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1B,B<@/3X@)T1",B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-O;&ED)R`]/B`G4V]L
M:60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N879I<VEO
M;B<@/3X@)TYA=FES:6]N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;7-S<6PG(#T^("=-4R!344P@4V5R=F5R)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<WEB87-E)R`]/B`G4WEB87-E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;7ES<6PG(#T^("=->5-1
M3"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUY<W%L:2<@
M/3X@)TUY4U%,("AM>7-Q;&DI)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U
M;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD8G-Y;G1A>"<L("=S
M<6PY,B<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V-U<G-O<B<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^
M("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`G0W5R<V]R('1Y<&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W%U;W1E)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;G5L;"<@/3X@)TYO;F4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=344Q?0U527T1%1D%53%0G(#T^("=$969A=6QT
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G4U%,7T-54E]5
M4T5?1%))5D52)R`]/B`G57-E($1R:79E<B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U-13%]#55)?55-%7T]$0D,G(#T^("=5<V4@3T1"
M0R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U-13%]#55)?
M55-%7TE&7TY%141%1"<@/3X@)U5S92!)9B!.965D960G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U
M;'0H)&-T>"`N("=\8W5R<V]R)RP@;G5L;"DI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@("`@("`@
M("`@("=P9W-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("=0;W-T9W)E4U%,)RP*("`@("`@("`@("`@("`@("`@("`G9FEE
M;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I
M<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<')O=&]C;VPG(#T^("1P<F]T;V-O;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`D9&%T86)A<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI
M+`H@("`@("`@("`@("`@("`@)W-Q;&ET92<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)V1E<V,G(#T^("=344QI=&4G+`H@("`@("`@("`@("`@
M("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`G9&%T86)A<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5Q=6ER960G(#T^('1R=64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&5S8R<@/3X@)T%B<V]L=71E('!A=&@@=&\@=&AE
M(&1A=&%B87-E(&9I;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD871A8F%S
M92<L("<G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=M;V1E)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@
M)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^
M("=4:&4@;6]D92!T;R!O<&5N('1H92!F:6QE('=I=&@G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L
M="@D8W1X("X@)WQM;V1E)RP@)S`V-#0G*2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@
M("`@)W-Y8F%S92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("=3>6)A<V4G+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N
M="<@/3X@)'!E<G-I<W1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=H
M;W-T<W!E8R<@/3X@)&AO<W1S<&5C+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G=7-E<FYA;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G87!P;F%M92<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G07!P;&EC871I;VX@3F%M
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQA<'!N86UE)RP@)R<I*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T
M*2DI*3L*"B`@("`@("`@:68@*&ES<V5T*"1N;V1E*2`F)B`D;F]D92T^9V5T
M7V%T=')I8G5T92@G8F%S96-O;F9I9R<I(#T]("=T<G5E)RD@>PH@("`@("`@
M("`@("!R971U<FX@)&-U<W1O;5]F:65L9',["B`@("`@("`@?0H*("`@("`@
M("`D8V]N9FEG(#T@87)R87DH"B`@("`@("`@("`@("=D97-C)R`]/B`G1')I
M=F5R(&-O;F9I9W5R871I;VXG+`H@("`@("`@("`@("`G9&5F875L="<@/3X@
M)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?"<@+B`H:7-S970H)&YO9&4I(#\@
M)&YO9&4M/F=E=%]A='1R:6)U=&4H)W-W:71C:&YA;64G*2`Z("1S=VET8VAN
M86UE*2P@)VAO<F1E)RDL"B`@("`@("`@("`@("=S=VET8V@G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@)VAO<F1E)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`G9&5S8R<@/3X@)TAO<F1E(&1E9F%U;'1S)RP*("`@("`@
M("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@I*2P*("`@("`@("`@
M("`@("`@("=C=7-T;VTG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("=D97-C)R`]/B`G0W5S=&]M('!A<F%M971E<G,G+`H@("`@("`@("`@("`@
M("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("!M9#4H;6EC<F]T:6UE*"DI(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G9&5S8W)I<'1I;VXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=!;GD@<&%R86UE
M=&5R<R!T:&%T('1H92!S=&]R86=E(&1R:79E<B!N965D<RXG*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)W!H<'1Y<&4G(#T^("1C=7-T;VU?9FEE;&1S
M*2DI*3L*"B`@("`@("`@:68@*&ES<V5T*"1N;V1E*2`F)B`D;F]D92T^:&%S
M7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@)&-U<B`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,979E;"@D8W5R+"`D;F]D92T^
M8VAI;&1?;F]D97,H*2P@)&-T>"D["B`@("`@("`@("`@("1C;VYF:6=;)W-W
M:71C:"==6R=H;W)D92==6R=F:65L9',G72`](&%R<F%Y7VUE<F=E*"1C;VYF
M:6=;)W-W:71C:"==6R=H;W)D92==6R=F:65L9',G72P@)&-U<BD["B`@("`@
M("`@("`@("1C;VYF:6=;)W-W:71C:"==6R=C=7-T;VTG75LG9FEE;&1S)UT@
M/2!A<G)A>5]M97)G92@D8V]N9FEG6R=S=VET8V@G75LG8W5S=&]M)UU;)V9I
M96QD<R==+"`D8W5R*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V]N
M9FEG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N9FEG
M=7)A=&EO;B!T<F5E(&9O<B!A(%9&4R!B86-K96YD(&-O;F9I9W5R871I;VX@
M=&\*("`@("`J(')E<&QA8V4@82`\8V]N9FEG=F9S/B!T86<N"B`@("`@*B!3
M=6)N;V1E<R!W:6QL(&)E('!A<G-E9"!A;F0@861D960@=&\@8F]T:"!T:&4@
M2&]R9&4@9&5F875L=',@86YD('1H90H@("`@("H@0W5S=&]M(&-O;F9I9W5R
M871I;VX@<&%R=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W1X("`@(%1H92!C;VYT97AT
M(&]F('1H92`\8V]N9FEG=F9S/B!T86<N"B`@("`@*B!`<&%R86T@1&]M3F]D
M92`D;F]D92`@5&AE($1O;4YO9&4@<F5P<F5S96YT871I;VX@;V8@=&AE(#QC
M;VYF:6=V9G,^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&%G+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R
M<F%Y('=I=&@@=&AE(%9&4R!C;VYF:6=U<F%T:6]N('1R964N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;VYF:6=61E,H)&-T>"P@)&YO9&4I"B`@("!["B`@
M("`@("`@)'-Q;"`]("1T:&ES+3Y?8V]N9FEG4U%,*"1C='@@+B`G?'!A<F%M
M<R<I.PH@("`@("`@("1C;VYF:6<@/0H@("`@("`@("`@("!A<G)A>2@*("`@
M("`@("`@("`@("`@("=D97-C)R`]/B`G5VAA="!61E,@9')I=F5R('-H;W5L
M9"!W92!U<V4_)RP*("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI
M<RT^7V1E9F%U;'0H)&-T>"`N("=\)R`N("1N;V1E+3YG971?871T<FEB=71E
M*"=S=VET8VAN86UE)RDL("=H;W)D92<I+`H@("`@("`@("`@("`@("`@)W-W
M:71C:"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)VYO;F4G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)TYO
M;F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A
M>2@I*2P*("`@("`@("`@("`@("`@("`@("`G:&]R9&4G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)TAO<F1E(&1E9F%U
M;'1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R
M87DH*2DL"B`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T9I;&5S(&]N('1H
M92!L;V-A;"!S>7-T96TG+`H@("`@("`@("`@("`@("`@("`@("`@("`G9FEE
M;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P
M87)A;7,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V9G-R;V]T)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G5VAE<F4@;VX@
M=&AE(')E86P@9FEL97-Y<W1E;2!S:&]U;&0@2&]R9&4@=7-E(&%S(')O;W0@
M;V8@=&AE('9I<G1U86P@9FEL97-Y<W1E;3\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A
M=6QT*"1C='@@+B`G?'!A<F%M<WQV9G-R;V]T)RP@)R]T;7`G*2DI*2DL"B`@
M("`@("`@("`@("`@("`@("`@)W-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("=D97-C)R`]/B`G4U%,(&1A=&%B87-E)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9')I=F5R8V]N9FEG)R`]/B`D
M<W%L*2DI*2D["@H@("`@("`@("1C87-E<R`]("1T:&ES+3Y?9V5T4W=I=&-H
M5F%L=65S*"1N;V1E+"`D8W1X("X@)WQP87)A;7,G*3L*("`@("`@("!F;W)E
M86-H("@D8V%S97,@87,@)&-A<V4@/3X@)&9I96QD<RD@>PH@("`@("`@("`@
M("!I9B`H:7-S970H)&-O;F9I9ULG<W=I=&-H)UU;)&-A<V5=*2D@>PH@("`@
M("`@("`@("`@("`@)&-O;F9I9ULG<W=I=&-H)UU;)&-A<V5=6R=F:65L9',G
M75LG<&%R86US)UT@/2!A<G)A>5]M97)G92@D8V]N9FEG6R=S=VET8V@G75LD
M8V%S95U;)V9I96QD<R==6R=P87)A;7,G72P@)&9I96QD<ULG9FEE;&1S)UTI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O
M;F9I9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!C97)T86EN
M('9A;'5E(&9R;VT@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;B!A<G)A>2!O
M<@H@("`@("H@82!D969A=6QT('9A;'5E+"!I9B!N;W0@9F]U;F0N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8W1X("`@("!!('-T<FEN9R!R97!R97-E;G1I;F<@=&AE(&ME
M>2!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N9FEG
M=7)A=&EO;B!A<G)A>2!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@;6EX960@
M)&1E9F%U;'0@(%1H92!D969A=6QT('9A;'5E('1O(')E='5R;B!I9B!T:&4@
M:V5Y('=A<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!F;W5N
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@=&AE('9A
M;'5E(&]F('1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y)W,@<F5Q=65S=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("!K97D@;W(@=&AE(&1E9F%U;'0@=F%L=64@
M:68@=&AE(&ME>2!W87-N)W0@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]D969A=6QT*"1C='@L("1D969A=6QT*0H@("`@>PH@("`@("`@("1C='@@
M/2!E>'!L;V1E*"=\)RP@)&-T>"D["B`@("`@("`@)'!T<B`]("1T:&ES+3Y?
M8W5R<F5N=$-O;F9I9SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N
M="@D8W1X*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1P=');
M)&-T>%LD:5U=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D969A=6QT
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!T<B`]
M("1P=');)&-T>%LD:5U=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("AI<U]S=')I;F<H)'!T<BDI('L*("`@("`@("`@("`@<F5T=7)N
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'!T<BP@)VES;RTX.#4Y+3$G*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'!T<CL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8V5R=&%I
M;B!V86QU92!F<F]M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VX@9FEL92!O
M<@H@("`@("H@82!D969A=6QT('9A;'5E+"!I9B!N;W0@9F]U;F0N"B`@("`@
M*B!)="!D;V5S($Y/5"!R971U<FX@=&AE(&%C='5A;"!V86QU92P@8G5T('1H
M92!02%`@97AP<F5S<VEO;B!A<R!U<V5D"B`@("`@*B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-T>"`@("`@02!S=')I;F<@
M<F5P<F5S96YT:6YG('1H92!K97D@;V8@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;F9I9W5R871I;VX@87)R87D@=&\@<F5T=7)N+@H@
M("`@("H@0'!A<F%M(&UI>&5D("1D969A=6QT("!4:&4@9&5F875L="!V86QU
M92!T;R!R971U<FX@:68@=&AE(&ME>2!W87-N)W0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@9F]U;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@16ET:&5R('1H92!V86QU92!O9B!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE)W,@<F5Q=65S=&5D"B`@("`@*B`@("`@("`@("`@("`@("!K97D@;W(@
M=&AE(&1E9F%U;'0@=F%L=64@:68@=&AE(&ME>2!W87-N)W0@9F]U;F0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]D969A=6QT4F%W*"1C='@L("1D969A=6QT
M*0H@("`@>PH@("`@("`@("1C='@@/2!E>'!L;V1E*"=\)RP@)&-T>"D["B`@
M("`@("`@)'!A='1E<FX@/2`G+UY<)&-O;F9<6UPG)R`N(&EM<&QO9&4H(B=<
M75Q;)R(L("1C='@I("X@)UPG7%T@/2`H+BHI.R0O;2<["B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)'!A='1E<FXL("1T:&ES+3YG97102%!#;VYF:6<H*2P@
M)&UA=&-H97,I*2!["B`@("`@("`@("`@(')E='5R;B`D;6%T8VAE<ULQ73L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D969A=6QT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N="!O9B!A;&P@=&5X="!N
M;V1E(&-H:6QD<F5N(&]F('1H92!S<&5C:69I960@;F]D92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@1&]M
M3F]D92`D;F]D92`@02!$;VU.;V1E(&]B:F5C="!W:&]S92!T97AT(&YO9&4@
M8VAI;&1R96X@=&\@<F5T=7)N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8V]N8V%T96YA=&5D('9A;'5E<R!O9B!A;&P@=&5X="!N;V1E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$YO9&5/;FQY5&5X="@D;F]D
M92D*("`@('L*("`@("`@("`D=&5X="`]("<G.PH@("`@("`@(&EF("@A)&YO
M9&4M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@(')E='5R;B`D
M;F]D92T^9V5T7V-O;G1E;G0H*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C
M:"`H)&YO9&4M/F-H:6QD7VYO9&5S*"D@87,@)'1N;V1E*2!["B`@("`@("`@
M("`@(&EF("@D=&YO9&4M/G1Y<&4@/3T@6$U,7U1%6%1?3D]$12D@>PH@("`@
M("`@("`@("`@("`@)'1E>'0@+CT@)'1N;V1E+3YC;VYT96YT.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')I;2@D=&5X="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%S<V]C:6%T:79E
M(&%R<F%Y(&-O;G1A:6YI;F<@86QL('!O<W-I8FQE('9A;'5E<R!O9B!T:&4*
M("`@("`J('-P96-I9FEE9"`\8V]N9FEG96YU;3X@=&%G+@H@("`@("H@5&AE
M(&ME>7,@8V]N=&%I;B!T:&4@86-T=6%L(&5N=6T@=F%L=65S('=H:6QE('1H
M92!V86QU97,@8V]N=&%I;B!T:&5I<@H@("`@("H@8V]R<F5S<&]N9&EN9R!D
M97-C<FEP=&EO;G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M($1O;4YO9&4@)&YO9&4@(%1H92!$;VU.;V1E
M(')E<')E<V5N=&%T:6]N(&]F('1H92`\8V]N9FEG96YU;3X@=&%G"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=VAO<V4@=F%L=65S('-H;W5L9"!B
M92!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<W-O8VEA=&EV92!A<G)A>2!W:71H(&%L;"!P;W-S:6)L92!E;G5M('9A;'5E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$5N=6U686QU97,H)&YO9&4I
M"B`@("!["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@:68@
M*"$D;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1N;V1E
M+3YC:&EL9%]N;V1E<R@I(&%S("1V;F]D92D@>PH@("`@("`@("`@("!I9B`H
M)'9N;V1E+3YT>7!E(#T](%A-3%]%3$5-14Y47TY/1$4@)B8*("`@("`@("`@
M("`@("`@("1V;F]D92T^=&%G;F%M92`]/2`G=F%L=65S)RD@>PH@("`@("`@
M("`@("`@("`@:68@*"$D=FYO9&4M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=FYO9&4M/F-H:6QD
M7VYO9&5S*"D@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1V86QU92T^='EP92`]/2!834Q?14Q%345.5%].3T1%*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D=F%L=64M/G1A9VYA;64@/3T@)V-O;F9I
M9W-P96-I86PG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]H86YD;&53<&5C:6%L<R@D=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)'9A;'5E+3YT86=N86UE(#T]("=V
M86QU92<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97AT(#T@
M)'9A;'5E+3YG971?8V]N=&5N="@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<V,@/2`D=F%L=64M/F=E=%]A='1R:6)U=&4H)V1E<V,G*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&1E<V,I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<ULD
M=&5X=%T@/2`D9&5S8SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M<ULD=&5X=%T@/2`D=&5X=#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@)'9A;'5E<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!M=6QT:61I;65N<VEO;F%L(&%S<V]C:6%T:79E(&%R
M<F%Y(')E<')E<V5N=&EN9R!T:&4@<W!E8VEF:65D"B`@("`@*B`\8V]N9FEG
M<W=I=&-H/B!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M($1O;4YO9&4@)B1N;V1E("!4:&4@1&]M3F]D
M92!R97!R97-E;G1A=&EO;B!O9B!T:&4@/&-O;F9I9W-W:71C:#X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@=&%G('1O('!R;V-E<W,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87-S;V-I871I=F4@87)R87D@
M<F5P<F5S96YT:6YG('1H92!N;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T4W=I=&-H5F%L=65S*"8D;F]D92P@)&-U<F-T>"D*("`@('L*("`@("`@
M("!I9B`H(21N;V1E+3YH87-?8VAI;&1?;F]D97,H*2D@>PH@("`@("`@("`@
M("!R971U<FX@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&YO9&4M/F-H:6QD7VYO9&5S
M*"D@87,@)&-A<V4I('L*("`@("`@("`@("`@:68@*"1C87-E+3YT>7!E(#T]
M(%A-3%]%3$5-14Y47TY/1$4I('L*("`@("`@("`@("`@("`@("1N86UE(#T@
M)&-A<V4M/F=E=%]A='1R:6)U=&4H)VYA;64G*3L*("`@("`@("`@("`@("`@
M("1V86QU97-;)&YA;65=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1V
M86QU97-;)&YA;65=6R=D97-C)UT@/2`D8V%S92T^9V5T7V%T=')I8G5T92@G
M9&5S8R<I.PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD;F%M95U;)V9I96QD
M<R==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@(&EF("@D8V%S92T^:&%S
M7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<G-E3&5V96PH)'9A;'5E<ULD;F%M95U;)V9I96QD<R==+"`D8V%S92T^
M8VAI;&1?;F]D97,H*2P@)&-U<F-T>"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1V86QU97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%S<V]C:6%T:79E
M(&%R<F%Y(&-O;G1A:6YI;F<@=&AE('!O<W-I8FQE('9A;'5E<R!O9B!A"B`@
M("`@*B`\8V]N9FEG<W!E8VEA;#X@=&%G(&%S('5S960@:6YS:61E(&]F(&5N
M=6T@8V]N9FEG=7)A=&EO;G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M($1O;4YO9&4@)&YO9&4@(%1H92!$
M;VU.;V1E(')E<')E<V5N=&%T:6]N(&]F('1H92`\8V]N9FEG<W!E8VEA;#X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T86<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87-S;V-I871I=F4@87)R87D@=VET:"!T
M:&4@<&]S<VEB;&4@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&%N
M9&QE4W!E8VEA;',H)&YO9&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D;F]D
M92T^9V5T7V%T=')I8G5T92@G;F%M92<I*2!["B`@("`@("`@8V%S92`G;&ES
M="UH;W)D92UA<'!S)SH*("`@("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@
M("`@("`@("`@("`D87!P<R`]($AO<F1E7T%R<F%Y.CIV86QU97-4;TME>7,H
M)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G:&ED9&5N)RP@)VYO=&]O;&)A
M<B<L("=A8W1I=F4G*2DI.PH@("`@("`@("`@("!A<V]R="@D87!P<RD["B`@
M("`@("`@("`@(')E='5R;B`D87!P<SL*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)VQI<W0M:&]R9&4M;&%N9W5A9V5S)SH*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y7VUA<"AC<F5A=&5?9G5N8W1I;VXH)R1V86PG+"`G
M<F5T=7)N('!R96=?<F5P;&%C92AA<G)A>2@B+R8C>"A;,"TY82UF77LT?2D[
M+VEE(BP@(B\H)EM>.UTK.RDO92(I+"!A<G)A>2@B4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="AP86-K*%PB2"I<(BP@7"(D,5PB*2P@7")U8W,M,EPB+"!<(B<@
M+B!.3%,Z.F=E=$-H87)S970H*2`N("=<(BDB+"`B4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="AH=&UL7V5N=&ET>5]D96-O9&4H7"(D,5PB+"!%3E1?0T]-4$%4
M+"!<(FES;RTX.#4Y+3%<(BDL(%PB:7-O+3@X-3DM,5PB+"!<(B<@+B!.3%,Z
M.F=E=$-H87)S970H*2`N("=<(BDB*2P@)'9A;"D[)RDL("1'3$]"04Q36R=N
M;',G75LG;&%N9W5A9V5S)UTI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G;&ES="UB;&]C:W,G.@H@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*("`@("`@("`@("`@
M)&-O;&QE8W1I;VX@/2`F2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ<VEN9VQE
M=&]N*"=P;W)T86PG*3L*("`@("`@("`@("`@<F5T=7)N("1C;VQL96-T:6]N
M+3YG971";&]C:W-,:7-T*"D["@H@("`@("`@(&-A<V4@)VQI<W0M8VQI96YT
M+69I96QD<R<Z"B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@
M("`@("`@("1F(#T@87)R87DH*3L*("`@("`@("`@("`@:68@*"1R96=I<W1R
M>2T^:&%S365T:&]D*"=C;&EE;G1S+V=E=$-L:65N=%-O=7)C92<I*2!["B`@
M("`@("`@("`@("`@("`D861D<F5S<V)O;VL@/2`D<F5G:7-T<GDM/F-A;&PH
M)V-L:65N=',O9V5T0VQI96YT4V]U<F-E)RD["B`@("`@("`@("`@("`@("`D
M9FEE;&1S(#T@)')E9VES=')Y+3YC86QL*"=C;&EE;G1S+V9I96QD<R<L(&%R
M<F%Y*"1A9&1R97-S8F]O:RDI.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A
M*"1F:65L9',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9FEE;&1S(&%S("1F:65L9"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D9ELD9FEE;&1;)VYA;64G75T@/2`D9FEE;&1;)VQA8F5L
M)UT["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9CL*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-P96-I9FEE9"!S
M=')I;F<@=VET:"!E<V-A<&5D('-I;F=L92!Q=6]T97,*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S=')I;F<@($$@<W1R:6YG('1O(&5S8V%P92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('-P96-I9FEE9"!S=')I;F<@=VET:"!S:6YG
M;&4@<75O=&5S(&)E:6YG(&5S8V%P960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]Q=6]T92@D<W1R:6YG*0H@("`@>PH@("`@("`@(')E='5R;B!S=')?<F5P
M;&%C92@B)R(L(")<)R(L("1S=')I;F<I.PH@("`@?0H*?0H*+RHJ"B`J($$@
M2&]R9&5?1F]R;3HZ(&9O<FT@=&AA="!I;7!L96UE;G1S(&$@=7-E<B!I;G1E
M<F9A8V4@9F]R('1H92!C;VYF:6<*("H@<WES=&5M+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T9R86UE=V]R:PH@*B\*
M8VQA<W,@0V]N9FEG1F]R;2!E>'1E;F1S($AO<F1E7T9O<FT@>PH*("`@("\J
M*@H@("`@("H@1&]N)W0@=7-E(&9O<FT@=&]K96YS(&9O<B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M("T@=VAI;&4*("`@("`J(&=E;F5R871I;F<@8V]N9FEG
M=7)A=&EO;B!I;F9O+"!T:&EN9W,@;&EK92!T:&4@5&]K96X@<WES=&5M"B`@
M("`@*B!M:6=H="!N;W0@=V]R:R!C;W)R96-T;'DN(%1H:7,@<V%V97,@<V]M
M92!H96%D86-H97,N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7W5S949O<FU4;VME;B`](&9A;'-E.PH*("`@("\J*@H@
M("`@("H@0V]N=&%I;G,@=&AE($AO<F1E7T-O;F9I9R!O8FIE8W0@=&AA="!T
M:&ES(&9O<FT@<F5P<F5S96YT<RX*("`@("`J"B`@("`@*B!`=F%R($AO<F1E
M7T-O;F9I9PH@("`@("HO"B`@("!V87(@)%]X;6Q#;VYF:6<["@H@("`@+RHJ
M"B`@("`@*B!#;VYT86EN<R!T:&4@5F%R:6%B;&5S(&]B:F5C="!O9B!T:&ES
M(&9O<FTN"B`@("`@*@H@("`@("H@0'9A<B!687)I86)L97,*("`@("`J+PH@
M("`@=F%R("1?=F%R<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!P87)A;2!687)I86)L97,@)B1V87)S("!4:&4@5F%R
M:6%B;&5S(&]B:F5C="!O9B!T:&ES(&9O<FTN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<'`@("`@("`@("`@("`@5&AE(&YA;64@;V8@=&AE(&%P<&QI8V%T
M:6]N('1H870@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;F9I9W5R871I;VX@9F]R;2!I<R!F;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($-O;F9I9T9O<FTH)B1V87)S+"`D87!P*0H@("`@>PH@("`@
M("`@('!A<F5N=#HZ2&]R9&5?1F]R;2@D=F%R<RD["@H@("`@("`@("1T:&ES
M+3Y?>&UL0V]N9FEG(#T@)FYE=R!(;W)D95]#;VYF:6<H)&%P<"D["B`@("`@
M("`@)'1H:7,M/E]V87)S(#T@)B1V87)S.PH@("`@("`@("1C;VYF:6<@/2`D
M=&AI<RT^7WAM;$-O;F9I9RT^<F5A9%A-3$-O;F9I9R@I.PH@("`@("`@("1T
M:&ES+3YA9&1(:61D96XH)R<L("=A<'`G+"`G=&5X="<L('1R=64I.PH@("`@
M("`@("1T:&ES+3Y?8G5I;&1687)I86)L97,H)&-O;F9I9RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!"=6EL9',@=&AE(&9O<FT@8F%S960@;VX@=&AE('-P
M96-I9FEE9"!L979E;"!O9B!T:&4@8V]N9FEG=7)A=&EO;B!T<F5E+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D8V]N9FEG("`@5&AE('!O<G1I;VX@;V8@=&AE(&-O;F9I9W5R
M871I;VX@=')E92!F;W(@=&AA=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@9F]R;2!F:65L9',@<VAO=6QD(&)E(&-R96%T960N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P<F5F:7@@($$@<W1R:6YG(')E<')E<V5N=&EN
M9R!T:&4@8W5R<F5N="!P;W-I=&EO;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!I;G-I9&4@=&AE(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V)U:6QD5F%R:6%B;&5S*"1C;VYF:6<L("1P<F5F
M:7@@/2`G)RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C;VYF:6<I
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@9F]R
M96%C:"`H)&-O;F9I9R!A<R`D;F%M92`]/B`D8V]N9FEG:71E;2D@>PH@("`@
M("`@("`@("`D<')E9FEX961N86UE(#T@96UP='DH)'!R969I>"D@/R`D;F%M
M92`Z("1P<F5F:7@@+B`G?"<@+B`D;F%M93L*("`@("`@("`@("`@)'9A<FYA
M;64@/2!S=')?<F5P;&%C92@G?"<L("=?7R<L("1P<F5F:7AE9&YA;64I.PH@
M("`@("`@("`@("`D9&5S8W)I<'1I;VX@/2!N=6QL.PH@("`@("`@("`@("!I
M9B`H)&-O;F9I9VET96T@/3T@)W!L86-E:&]L9&5R)RD@>PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D
M8V]N9FEG:71E;5LG=&%B)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T4V5C=&EO;B@D8V]N9FEG:71E;5LG=&%B)UTL("1C;VYF:6=I=&5M6R=D
M97-C)UTI.PH@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&-O;F9I9VET
M96U;)W-W:71C:"==*2D@>PH@("`@("`@("`@("`@("`@)'-E;&5C=&5D(#T@
M)'1H:7,M/E]V87)S+3YG971%>&ES=',H)'9A<FYA;64L("1W87-S970I.PH@
M("`@("`@("`@("`@("`@)'9A<E]P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@)'-E;&5C=%]O<'1I;VX@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@:68@*&ES7V)O;VPH)&-O;F9I9VET96U;)V1E9F%U;'0G72DI('L*("`@
M("`@("`@("`@("`@("`@("`D8V]N9FEG:71E;5LG9&5F875L="==(#T@)&-O
M;F9I9VET96U;)V1E9F%U;'0G72`_("=T<G5E)R`Z("=F86QS92<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!F;W)E86-H("@D8V]N9FEG
M:71E;5LG<W=I=&-H)UT@87,@)&]P=&EO;B`]/B`D8V%S92D@>PH@("`@("`@
M("`@("`@("`@("`@("1V87)?<&%R86US6R1O<'1I;VY=(#T@)&-A<V5;)V1E
M<V,G73L*("`@("`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;B`]/2`D8V]N
M9FEG:71E;5LG9&5F875L="==*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1S96QE8W1?;W!T:6]N(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A)'=A<W-E="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-E;&5C=&5D(#T@)&]P=&EO;CL*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1V(#T@)B1T:&ES+3YA9&1687)I86)L92@D8V]N
M9FEG:71E;5LG9&5S8R==+"`D=F%R;F%M92P@)V5N=6TG+"!T<G5E+"!F86QS
M92P@;G5L;"P@87)R87DH)'9A<E]P87)A;7,L("1S96QE8W1?;W!T:6]N*2D[
M"B`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G9&5F875L
M="<L("1C;VYF:6=I=&5M*2D@>PH@("`@("`@("`@("`@("`@("`@("1V+3YS
M971$969A=6QT*"1C;VYF:6=I=&5M6R=D969A=6QT)UTI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)'9?86-T:6]N(#T@)DAO<F1E7T9O
M<FU?06-T:6]N.CIF86-T;W)Y*"=R96QO860G*3L*("`@("`@("`@("`@("`@
M("1V+3YS971!8W1I;VXH)'9?86-T:6]N*3L*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<V5L96-T960I("8F(&ES<V5T*"1C;VYF:6=I=&5M6R=S=VET
M8V@G75LD<V5L96-T961=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8G5I;&1687)I86)L97,H)&-O;F9I9VET96U;)W-W:71C:"==6R1S96QE
M8W1E9%U;)V9I96QD<R==+"`D<')E9FEX*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF:6=I=&5M6R=?='EP
M92==*2D@>PH@("`@("`@("`@("`@("`@)')E<75I<F5D(#T@*&ES<V5T*"1C
M;VYF:6=I=&5M6R=R97%U:7)E9"==*2D@/R`D8V]N9FEG:71E;5LG<F5Q=6ER
M960G72`Z('1R=64["B`@("`@("`@("`@("`@("`D='EP92`]("1C;VYF:6=I
M=&5M6R=?='EP92==.PH@("`@("`@("`@("`@("`@+R\@1DE8344Z(&UU;'1I
M96YU;2!F:65L9',@8V%N('=E;&P@8F4@<F5Q=6ER960L(&UE86YI;F<@=&AA
M=`H@("`@("`@("`@("`@("`@+R\@>6]U(&YE960@=&\@<V5L96-T(&%T(&QE
M87-T(&]N92!E;G1R>2X@0VAA;F=I;F<@=&AI<R!B969O<F4*("`@("`@("`@
M("`@("`@("\O($AO<F1E(#0N,"!W;W5L9"!B<F5A:R!A(&QO="!O9B!C;VYF
M:6=U<F%T:6]N(&9I;&5S('1H;W5G:"X*("`@("`@("`@("`@("`@(&EF("@D
M='EP92`]/2`G;75L=&EE;G5M)R!\?"`D='EP92`]/2`G:&5A9&5R)R!\?`H@
M("`@("`@("`@("`@("`@("`@("1T>7!E(#T]("=D97-C<FEP=&EO;B<I('L*
M("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER960@/2!F86QS93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G;75L
M=&EE;G5M)R!\?"`D='EP92`]/2`G96YU;2<I('L*("`@("`@("`@("`@("`@
M("`@("`D=F%R7W!A<F%M<R`](&%R<F%Y*"1C;VYF:6=I=&5M6R=V86QU97,G
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1V87)?<&%R86US(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G<&AP)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1T>7!E(#T@)W1E>'0G.PH@("`@("`@("`@("`@("`@
M("`@("1D97-C<FEP=&EO;B`]("=%;G1E<B!A('9A;&ED(%!(4"!E>'!R97-S
M:6]N+B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=B`]
M("8D=&AI<RT^861D5F%R:6%B;&4H)&-O;F9I9VET96U;)V1E<V,G72P@)'9A
M<FYA;64L("1T>7!E+"`D<F5Q=6ER960L(&9A;'-E+"`D9&5S8W)I<'1I;VXL
M("1V87)?<&%R86US*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8V]N
M9FEG:71E;5LG9&5F875L="==*2D@>PH@("`@("`@("`@("`@("`@("`@("1V
M+3YS971$969A=6QT*"1C;VYF:6=I=&5M6R=D969A=6QT)UTI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]B=6EL9%9A<FEA8FQE<R@D8V]N9FEG:71E;2P@)'!R969I
M>&5D;F%M92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@IC
M;&%S<R!(;W)D95]#;VYF:6=?1&]C=6UE;G0@97AT96YD<R!(;W)D95]#;VYF
M:6=?3F]D92!["@H@("`@9G5N8W1I;VX@9F%C=&]R>2@D9FEL92D*("`@('L*
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D;VUX;6Q?;W!E;E]F:6QE
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(&1O;7AM;%]O<&5N7V9I;&4H)&9I
M;&4I.PH@("`@("`@('T@96QS96EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R
M<VEO;B@I+"`G-2<L("<^/2<I*2!["B`@("`@("`@("`@(')E='5R;B`D9&]C
M(#T@;F5W($AO<F1E7T-O;F9I9U]$;V-U;65N="@D9FEL92D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=$3TT@<W5P<&]R
M="!N;W0@<')E<V5N="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!(;W)D95]#;VYF:6=?1&]C=6UE;G0H
M)&9I;&5N86UE*0H@("`@>PH@("`@("`@("1T:&ES+3YN;V1E(#T@;F5W($1/
M341O8W5M96YT*"D["B`@("`@("`@)'1H:7,M/FYO9&4M/FQO860H)&9I;&5N
M86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!R;V]T*"D*("`@('L*("`@("`@
M("!R971U<FX@)')O;W0@/2!N97<@2&]R9&5?0V]N9FEG7T5L96UE;G0H)'1H
M:7,M/FYO9&4M/F1O8W5M96YT16QE;65N="D["B`@("!]"@I]"@IC;&%S<R!(
M;W)D95]#;VYF:6=?3F]D92!["@H@("`@=F%R("1N;V1E.PH*("`@(&9U;F-T
M:6]N($AO<F1E7T-O;F9I9U].;V1E*"1A1&]M3F]D92D@>R1T:&ES+3YN;V1E
M/21A1&]M3F]D93M]"@H@("`@9G5N8W1I;VX@7U]G970H)&YA;64I"B`@("![
M"B`@("`@("`@<W=I=&-H("@D;F%M92D@>PH@("`@("`@(&-A<V4@)W1Y<&4G
M.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/FYO9&54>7!E.PH*
M("`@("`@("!C87-E("=T86=N86UE)SH*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YN;V1E+3YT86=.86UE.PH*("`@("`@("!C87-E("=C;VYT96YT)SH*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YN;V1E+3YT97AT0V]N=&5N=#L*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!C:&EL9%]N;V1E<R@I"B`@
M("!["B`@("`@("`@)&YO9&5,:7-T(#T@)'1H:7,M/FYO9&4M/F-H:6QD3F]D
M97,["B`@("`@("`@)&YO9&53970@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI
M<W-E="@D;F]D94QI<W0I*2!["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@
M("`@("`@=VAI;&4@*"1N;V1E(#T@)&YO9&5,:7-T+3YI=&5M*"1I*2D@>PH@
M("`@("`@("`@("`@("`@)&YO9&53971;72`](&YE=R!(;W)D95]#;VYF:6=?
M16QE;65N="@D;F]D92D["B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;F]D95-E=#L*("`@
M('T*"B`@("!F=6YC=&EO;B!F:7)S=%]C:&EL9"@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&YE=R!(;W)D95]#;VYF:6=?16QE;65N="@D=&AI<RT^;F]D92T^
M9FER<W1#:&EL9"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T7V-O;G1E;G0H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F]D92T^=&5X=$-O;G1E
M;G0["B`@("!]"@H@("`@9G5N8W1I;VX@:&%S7V-H:6QD7VYO9&5S*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/FAA<T-H:6QD3F]D97,H
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!N97AT7W-I8FQI;F<H*0H@("`@>PH@
M("`@("`@(')E='5R;B!N97<@2&]R9&5?0V]N9FEG7T5L96UE;G0H)'1H:7,M
M/FYO9&4M/FYE>'13:6)L:6YG*3L*("`@('T*"B`@("!F=6YC=&EO;B!N;V1E
M7W9A;'5E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/FYO
M9&5686QU93L*("`@('T*"GT*"F-L87-S($AO<F1E7T-O;F9I9U]%;&5M96YT
M(&5X=&5N9',@2&]R9&5?0V]N9FEG7TYO9&4@>PH*("`@(&9U;F-T:6]N(&=E
M=%]A='1R:6)U=&4H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YN;V1E+3YG971!='1R:6)U=&4H)&YA;64I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]'<F]U<"YP:'``````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3`U,S0`,3`U,34T,S$P-C$`,#(P,#,P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O2&ES=&]R>2YP:'`G.PH*+RHJ"B`J(%1H92!'<F]U
M<#HZ(&-L87-S('!R;W9I9&5S('1H92!(;W)D92!G<F]U<',@<WES=&5M+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`L=B`Q+C8W
M+C(N,34@,C`P-B\P-R\Q-R`Q-#HT,#HQ.2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!3=&5P:&%N92!(=71H97(@/'-H=71H97)`8FEG
M9F]O="YC;VT^"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!3=&5P:&%N92!(=71H97(@/'-H=71H97)`8FEG9F]O="YC;VT^"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?1W)O=7`*
M("HO"F-L87-S($=R;W5P('L*"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@
M82!$871A5')E92!I;G-T86YC92!T;R!M86YA9V4@=&AE(&1I9F9E<F5N="!G
M<F]U<',N"B`@("`@*@H@("`@("H@0'9A<B!$871A5')E90H@("`@("HO"B`@
M("!V87(@)%]D871A=')E93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R
M"B`@("`@*B\*("`@(&9U;F-T:6]N($=R;W5P*"D*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AE;7!T>2@D8V]N9ELG9&%T871R
M964G75LG9')I=F5R)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@G
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M1W)O=7!S+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`D9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==.PH@
M("`@("`@("1T:&ES+3Y?9&%T871R964@/2`F1&%T851R964Z.G-I;F=L971O
M;B@D9')I=F5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>5]M97)G92A(;W)D93HZ9V5T1')I=F5R0V]N
M9FEG*"=D871A=')E92<L("1D<FEV97(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G9W)O=7`G(#T^("=H;W)D92YG<F]U<',G*2DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&$@;F5W(&=R;W5P(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@(%1H92!G<F]U<"=S(&YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)E;G0@(%1H92!G<F]U<"=S('!A
M<F5N="=S(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B
M:F5C=%]'<F]U<"`@02!N97<@9W)O=7`@;V)J96-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F;F5W1W)O=7`H)&YA;64L("1P87)E;G0@/2!$051!5%)%15]2
M3T]4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='DB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'!A<F5N="`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@("1N86UE
M(#T@)'1H:7,M/F=E=$=R;W5P3F%M92@D<&%R96YT*2`N("<Z)R`N($1A=&%4
M<F5E.CIE;F-O9&5.86UE*"1N86UE*3L*("`@("`@("!]"@H@("`@("`@("1G
M<F]U<"`]("9N97<@1&%T851R965/8FIE8W1?1W)O=7`H)&YA;64I.PH@("`@
M("`@("1G<F]U<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@<F5T=7)N
M("1G<F]U<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A($1A=&%4
M<F5E3V)J96-T7T=R;W5P(&]B:F5C="!C;W)R97-P;VYD:6YG('1O('1H92!N
M86UE9`H@("`@("H@9W)O=7`L('=I=&@@=&AE('5S97)S(&%N9"!O=&AE<B!D
M871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@5&AE(&YA;64@;V8@=&AE(&=R;W5P('1O(')E
M=')I979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1W)O=7`H)&YA;64I
M"B`@("!["B`@("`@("`@+RH@8V%C:&4@;V8@<')E=FEO=7,@<F5T<FEE=F5D
M(&=R;W5P<R`J+PH@("`@("`@('-T871I8R`D9W)O=7!#86-H93L*"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D9W)O=7!#86-H92DI('L*("`@("`@("`@("`@
M)&=R;W5P0V%C:&4@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D9W)O=7!#86-H95LD;F%M95TI*2!["B`@("`@("`@("`@("1G
M<F]U<$-A8VAE6R1N86UE72`]("1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C
M="@D;F%M92P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RD["B`@("`@("`@("`@
M(&EF("@A:7-?82@D9W)O=7!#86-H95LD;F%M95TL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1G<F]U<$-A8VAE6R1N86UE72T^<V5T1W)O
M=7!/8B@D=&AI<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9W)O=7!#86-H95LD;F%M95T["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@82!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W0@8V]R
M<F5S<&]N9&EN9R!T;R!T:&4@9VEV96X*("`@("`J('5N:7%U92!)1"P@=VET
M:"!T:&4@=7-E<G,@86YD(&]T:&5R(&1A=&$@<F5T<FEE=F5D"B`@("`@*B!A
M<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C
M:60@(%1H92!U;FEQ=64@240@;V8@=&AE(&=R;W5P('1O(')E=')I979E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1W)O=7!">4ED*"1C:60I"B`@("![
M"B`@("`@("`@)&=R;W5P(#T@)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T
M0GE)9"@D8VED+"`G1&%T851R965/8FIE8W1?1W)O=7`G*3L*("`@("`@("!I
M9B`H(6ES7V$H)&=R;W5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1G<F]U<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!G
M;&]B86QL>2!U;FEQ=64@240@9F]R(&$@9W)O=7`N"B`@("`@*@H@("`@("H@
M0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U<"`@5&AE(&=R;W5P
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!($=5240@<F5F97)R
M:6YG('1O("1G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1U5)1"@D
M9W)O=7`I"B`@("!["B`@("`@("`@<F5T=7)N("=H;W)D93IG<F]U<#HG("X@
M)'1H:7,M/F=E=$=R;W5P260H)&=R;W5P*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!A(&=R;W5P('1O('1H92!G<F]U<',@<WES=&5M+B!4:&4@9W)O
M=7`@;75S="!F:7)S="!B90H@("`@("H@8W)E871E9"!W:71H($=R;W5P.CIN
M97='<F]U<"@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@
M861D960@=&\@:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?1W)O=7`@)&=R
M;W5P("!4:&4@;F5W(&=R;W5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D1W)O=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A
M5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S
M+B<I.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D871A
M=')E92T^861D*"1G<F]U<"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("\J($QO9R!T:&4@861D:71I;VX@;V8@=&AE
M(&=R;W5P(&EN('1H92!H:7-T;W)Y(&QO9RX@*B\*("`@("`@("`D:&ES=&]R
M>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D;&]G
M(#T@)&AI<W1O<GDM/FQO9R@D=&AI<RT^9V5T1U5)1"@D9W)O=7`I+"!A<G)A
M>2@G86-T:6]N)R`]/B`G861D)RDL('1R=64I.PH@("`@("`@(&EF("AI<U]A
M*"1L;V<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L
M;V<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-T;W)E('5P9&%T960@9&%T82`M('5S97)S+"!E
M=&,N("T@;V8@82!G<F]U<"!T;R!T:&4@8F%C:V5N9"!S>7-T96TN"B`@("`@
M*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U<"`@
M5&AE(&=R;W5P('1O('5P9&%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D
M871E1W)O=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9W)O
M=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A5')E
M94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I
M.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D871A=')E
M92T^=7!D871E1&%T82@D9W)O=7`I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE('5P9&%T92!O9B!T
M:&4@9W)O=7`@=7-E<G,@;VX@=&AE(&AI<W1O<GD@;&]G+B`J+PH@("`@("`@
M("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@
M("`@("1G=6ED(#T@)'1H:7,M/F=E=$=5240H)&=R;W5P*3L*("`@("`@("!F
M;W)E86-H("@D9W)O=7`M/F=E=$%U9&ET3&]G*"D@87,@)'5S97))9"`]/B`D
M86-T:6]N*2!["B`@("`@("`@("`@("1H:7-T;W)Y+3YL;V<H)&=U:60L(&%R
M<F%Y*"=A8W1I;VXG(#T^("1A8W1I;VXL("=U<V5R)R`]/B`D=7-E<DED*2P@
M=')U92D["B`@("`@("`@?0H@("`@("`@("1G<F]U<"T^8VQE87)!=61I=$QO
M9R@I.PH*("`@("`@("`O*B!,;V<@=&AE(&=R;W5P(&UO9&EF:6-A=&EO;BX@
M*B\*("`@("`@("`D:&ES=&]R>2T^;&]G*"1G=6ED+"!A<G)A>2@G86-T:6]N
M)R`]/B`G;6]D:69Y)RDL('1R=64I.PH@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E('1H92!N86UE(&]F(&$@
M9W)O=7`@=VET:&]U="!C:&%N9VEN9R!I=',@8V]N=&5N=',@;W(*("`@("`J
M('=H97)E(&ET(&ES(&EN('1H92!G<F]U<',@:&EE<F%R8VAY+@H@("`@("H*
M("`@("`J($!P87)A;2!$871A5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H
M92!G<F]U<"!T;R!R96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=.
M86UE("`@("`@("`@("`@("!4:&4@9W)O=7`G<R!N97<@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N86UE1W)O=7`H)&=R;W5P+"`D;F5W3F%M92D*
M("`@('L*("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G1&%T851R965/8FIE
M8W1?1W)O=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE8W1?1W)O=7`@;V)J
M96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?9&%T871R964M/G)E;F%M92@D9W)O=7`L
M("1N97=.86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@+RH@2&ES=&]R>2!,;V<@=&AE(&YA;64@8VAA;F=E(&]F
M('1H92!G<F]U<"X@*B\*("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T
M;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D:&ES=&]R>2T^;&]G*"1T:&ES
M+3YG971'54E$*"1G<F]U<"DL(&%R<F%Y*"=A8W1I;VXG(#T^("=R96YA;64G
M*2P@=')U92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296UO=F4@82!G<F]U<"!F<F]M('1H92!G<F]U<',@<WES
M=&5M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E
M94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!G<F]U<"!T;R!R96UO=F4N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@("`@("`@("`@("`@("!&;W)C
M92!T;R!R96UO=F4@979E<GD@8VAI;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V94=R;W5P*"1G<F]U<"P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T=R
M;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C=',@;W(@
M97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`D:&ES
M=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D
M:&ES=&]R>2T^;&]G*"1T:&ES+3YG971'54E$*"1G<F]U<"DL(&%R<F%Y*"=A
M8W1I;VXG(#T^("=D96QE=&4G*2P@=')U92D["@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1A=&%T<F5E+3YR96UO=F4H)&=R;W5P+"`D9F]R8V4I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&YA;64@;V8@82!G<F]U
M<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9VED("!4:&4@:60@
M;V8@=&AE(&=R;W5P('1O(')E=')I979E('1H92!N86UE(&9O<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&=R;W5P)W,@;F%M92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!.86UE*"1G:60I"B`@("!["B`@
M("`@("`@:68@*&ES7V$H)&=I9"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$YA
M;64H)&=I9"T^9V5T260H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$YA;64H)&=I9"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4W1R:7!S(&%L;"!P87)E
M;G0@<F5F97)E;F-E<R!O9F8@;V8@=&AE(&=I=F5N(&=R;W5P(&YA;64N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@($YA;64@;V8@=&AE
M(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@5&AE(&YA;64@;V8@=&AE
M(&=R;W5P('=I=&AO=70@<&%R96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1W)O=7!3:&]R=$YA;64H)&=R;W5P*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1A=&%T<F5E+3YG9713:&]R=$YA;64H)&=R;W5P*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!)1"!O9B!A(&=R;W5P
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4:&4@9W)O
M=7`@=&\@<F5T<FEE=F4@=&AE($E$(&9O<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!G<F]U<"=S($E$+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971'<F]U<$ED*"1G<F]U<"D*("`@('L*("`@("`@("!I9B`H:7-?
M82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971)9"@D9W)O=7`M/F=E
M=$YA;64H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&%T871R964M/F=E=$ED*"1G<F]U<"D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@82!G<F]U<"!E>&ES=',@
M:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G
M<F]U<"`@5&AE(&=R;W5P('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@9W)O=7`@97AI<W1S+"!F86QS92!O
M=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D9W)O=7`I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F5X:7-T
M<R@D9W)O=7`I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O
M9B!T:&4@<&%R96YT<R!O9B!A(&-H:6QD(&=R;W5P+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1G:60@5&AE(&ED(&]F('1H92!C:&EL9"!G<F]U
M<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$=R;W5P4&%R96YT<R@D9VED*0H@("`@>PH@("`@("`@("1N
M86UE(#T@)'1H:7,M/F=E=$=R;W5P3F%M92@D9VED*3L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT<R@D;F%M92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I;F=L92!P87)E;G0@;V8@
M=&AE(&=I=F5N(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1G:60@(%1H92!$871A5')E92!)1"!O9B!T:&4@8VAI;&0@9W)O=7`N"B`@
M("`@*@H@("`@("H@0')E='5R;B!T:&4@<&%R96YT(&]F('1H92!G:79E;B!G
M<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!087)E;G0H)&=I
M9"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T
M4&%R96YT0GE)9"@D9VED*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M(&QI<W0@;V8@<&%R96YT<R!A;&P@=&AE('=A>2!U<"!T;R!T:&4@<F]O="!O
M8FIE8W0@9F]R("1G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9VED("!4:&4@:60@;V8@=&AE(&=R;W5P+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@9FQA="!L:7-T(&]F(&%L;"!O9B!T:&4@<&%R96YT
M<R!O9B`D9W)O=7`L"B`@("`@*B`@("`@("`@("`@("`@("!H87-H960@:6X@
M)&ED(#T^("1N86UE(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1W)O=7!087)E;G1,:7-T*"1G:60I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&%T871R964M/F=E=%!A<F5N=$QI<W0H)&=I9"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P+"!I;B!T
M:&4@9F]R;6%T(&-I9"`]/B!G<F]U<&YA;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)')E9G)E<V@@($EF('1R=64L('1H92!C86-H960@=F%L
M=64@:7,@:6=N;W)E9"!A;F0@=&AE(&=R;W5P"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@;&ES="!I<R!R969R97-H960@9G)O;2!T:&4@9W)O
M=7`@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!#240@
M/3X@9W)O=7!N86UE(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1'
M<F]U<',H)')E9G)E<V@@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@
M)&=R;W5P<SL*"B`@("`@("`@:68@*"1R969R97-H('Q\(&ES7VYU;&PH)&=R
M;W5P<RDI('L*("`@("`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?9&%T871R
M964M/F=E="A$051!5%)%15]&3U)-051?1DQ!5"P@1$%40512145?4D]/5"P@
M=')U92D["B`@("`@("`@("`@('5N<V5T*"1G<F]U<'-;1$%40512145?4D]/
M5%TI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G<F]U<',["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA
M="!I<R!A('!A<G0@;V8@=&AI<R!G<F]U<"!/3DQ9+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1G:60@(%1H92!)1"!O9B!T:&4@9W)O=7`N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('5S97(@;&ES="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"1G:60I"B`@("!["B`@("`@
M("`@)&=R;W5P3V(@/2`F)'1H:7,M/F=E=$=R;W5P0GE)9"@D9VED*3L*("`@
M("`@("!I9B`H:7-?82@D9W)O=7!/8BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&=R;W5P3V(["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES<V5T*"1G<F]U<$]B+3YD871A6R=U<V5R<R==*2!\?`H@("`@("`@
M("`@("`A:7-?87)R87DH)&=R;W5P3V(M/F1A=&%;)W5S97)S)UTI*2!["B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&%R<F%Y7VME>7,H)&=R;W5P3V(M/F1A=&%;)W5S97)S)UTI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!U<V5R
M('1H870@:7,@<&%R="!O9B!T:&4@<W!E8VEF:65D(&=R;W5P"B`@("`@*B!A
M;F0@86YY(&]F(&ET<R!S=6)G<F]U<',N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&=R;W5P("!4:&4@240@;V8@=&AE('!A<F5N="!G<F]U<"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]M<&QE=&4@=7-E
M<B!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T06QL57-E<G,H)&=I
M9"D*("`@('L*("`@("`@("`O+R!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P
M('1H870@:7,@82!S=6(M9W)O=7`@;V8@)&=R;W5P+@H@("`@("`@("1G<F]U
M<',@/2`D=&AI<RT^7V1A=&%T<F5E+3YG970H1$%40512145?1D]234%47T9,
M050L("1T:&ES+3YG971'<F]U<$YA;64H)&=I9"DL('1R=64I.PH@("`@("`@
M(&EF("AI<U]A*"1G<F]U<',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1G<F]U<',["B`@("`@("`@?0H*("`@("`@("`D9W)O=7!S
M(#T@87)R87E?:V5Y<R@D9W)O=7!S*3L*("`@("`@("`D=7-E<G,@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1G<F]U<',@87,@)&=R;W5P260I('L*
M("`@("`@("`@("`@)'5S97)S(#T@87)R87E?;65R9V4H)'5S97)S+"`D=&AI
M<RT^;&ES=%5S97)S*"1G<F]U<$ED*2D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!A<G)A>5]V86QU97,H87)R87E?9FQI<"AA<G)A>5]F;&EP*"1U<V5R
M<RDI*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E
M<GD@9W)O=7`@=&AA="`D=7-E<B!I<R!I;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!G970@9W)O
M=7!S(&9O<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P87)E;G1'<F]U<',@
M($%L<V\@<F5T=7)N('1H92!P87)E;G1S(&]F(&%N>2!G<F]U<',_"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL(&=R;W5P
M<R!T:&4@=7-E<B!I<R!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O
M=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<R`](&9A;'-E*0H@
M("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("AE;7!T
M>2@D8V%C:&5;)'5S97)=*2D@>PH@("`@("`@("`@("`D8W)I=&5R:6$@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^
M("<])RP@)W1E<W0G(#T^("=U<V5R)RDL"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH)V9I96QD)R`]/B`G:V5Y)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]
M/B`D=7-E<BDI*3L*("`@("`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?9&%T
M871R964M/F=E=$)Y071T<FEB=71E<R@D8W)I=&5R:6$I.PH*("`@("`@("`@
M("`@:68@*&ES7V$H)&=R;W5P<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&=R;W5P<RP@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E)/4BD["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M<&%R96YT1W)O=7!S*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9W)O
M=7!S(&%S("1I9"`]/B`D9RD@>PH@("`@("`@("`@("`@("`@("`@("1P87)E
M;G1S(#T@)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT3&ES="@D:60I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P87)E;G1S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<&%R
M96YT<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&=R;W5P<R`K/2`D<&%R96YT<SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&-A8VAE6R1U<V5R72`]("1G<F]U
M<',["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1U<V5R73L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-A>2!I9B!A('5S97(@:7,@82!M96UB
M97(@;V8@82!G<F]U<"!O<B!N;W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<B`@("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D9VED("`@("`@("!4:&4@240@;V8@=&AE(&=R
M;W5P+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-U8F=R;W5P<R`@4F5T=7)N
M('1R=64@:68@=&AE('5S97(@:7,@:6X@86YY('-U8F=R;W5P<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;V8@9W)O=7`@=VET:"!)1"`D
M9VED+"!A;'-O+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@
M("HO"B`@("!F=6YC=&EO;B!U<V5R27-);D=R;W5P*"1U<V5R+"`D9VED+"`D
M<W5B9W)O=7!S(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YE
M>&ES=',H)'1H:7,M/F=E=$=R;W5P3F%M92@D9VED*2DI('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("@D<W5B9W)O=7!S
M*2!["B`@("`@("`@("`@("1G<F]U<',@/2`D=&AI<RT^9V5T1W)O=7!-96UB
M97)S:&EP<R@D=7-E<BP@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1G
M<F]U<',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"1G<F]U<',L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("%E;7!T>2@D9W)O=7!S
M6R1G:61=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7-E<G,@
M/2`D=&AI<RT^;&ES=%5S97)S*"1G:60I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D=7-E<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"1U<V5R<RP@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!I;E]A<G)A>2@D=7-E
M<BP@)'5S97)S*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!$871A5')E92!L979E;"!O9B!T:&4@9VEV96X@9W)O=7`N
M(#`@:7,@<F5T=7)N960@9F]R"B`@("`@*B!A;F0@;V)J96-T(&1I<F5C=&QY
M(&)E;&]W($1!5$%44D5%7U)/3U0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&=I9"`@5&AE($1A=&%4<F5E($E$(&]F('1H92!G<F]U<"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%1H92!$871A5')E92!L979E;"!O9B!T:&4@
M9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QE=F5L*"1G:60I"B`@
M("!["B`@("`@("`@)&YA;64@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971.86UE
M*"1G:60I.PH@("`@("`@(')E='5R;B!S=6)S=')?8V]U;G0H)&YA;64L("<Z
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!C;VYC<F5T92!'<F]U<"!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O
M9B!C;VYC<F5T92!'<F]U<"!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D
M9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI
M9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!'<F]U<"`@5&AE(&YE
M=VQY(&-R96%T960@8V]N8W)E=&4@1W)O=7`@:6YS=&%N8V4L(&]R(&$*("`@
M("`J("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N(&%N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R(#T@
M)R<L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B
M87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*$!F:6QE7V5X:7-T<RAD
M:7)N86UE*%]?1DE,15]?*2`N("<O1W)O=7`O)R`N("1D<FEV97(@+B`G+G!H
M<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O1W)O=7`O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O1W)O
M=7`O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C
M;&%S<R`]("='<F]U<%\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?
M97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&=R;W5P(#T@)FYE=R`D
M8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&=R;W5P(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O
M9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@1W)O
M=7`@:6YS=&%N8V4N"B`@("`@*B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W
M(&EN<W1A;F-E(&EF(&YO($=R;W5P(&EN<W1A;F-E"B`@("`@*B!C=7)R96YT
M;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH@)'9A<B`]("9'<F]U<#HZ<VEN9VQE=&]N*"D*("`@("`J
M"B`@("`@*B!`<F5T=7)N($=R;W5P("!4:&4@8V]N8W)E=&4@1W)O=7`@<F5F
M97)E;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)G-I;F=L971O;B@I"B`@("!["B`@("`@("`@<W1A=&EC("1G<F]U
M<#L*"B`@("`@("`@:68@*"%I<W-E="@D9W)O=7`I*2!["B`@("`@("`@("`@
M(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O075T:"YP:'`G.PH@("`@("`@("`@("`D875T:"`]("9!=71H.CIS:6YG
M;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH@("`@("`@("`@("!I
M9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)V=R;W5P<R<I*2!["B`@("`@("`@
M("`@("`@("`D9W)O=7`@/2`F1W)O=7`Z.F9A8W1O<GDH)&%U=&@M/F=E=$1R
M:79E<B@I+"`D875T:"D["B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH
M)&-O;F9;)V=R;W5P)UU;)V1R:79E<B==*2`F)B`D8V]N9ELG9W)O=7`G75LG
M9')I=F5R)UT@(3T@)V1A=&%T<F5E)RD@>PH@("`@("`@("`@("`@("`@)&=R
M;W5P(#T@)D=R;W5P.CIF86-T;W)Y*"1C;VYF6R=G<F]U<"==6R=D<FEV97(G
M72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9W)O
M=7`@/2!N97<@1W)O=7`H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1G<F]U<#L*("`@('T*"GT*"B\J*@H@*B!%>'1E;G-I
M;VX@;V8@=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O<B!S=&]R:6YG($=R
M;W5P(&EN9F]R;6%T:6]N"B`J(&EN('1H92!#871E9V]R:65S(&1R:79E<BX@
M268@>6]U('=A;G0@=&\@<W1O<F4@<W!E8VEA;&EZ960@1W)O=7`*("H@:6YF
M;W)M871I;VXL('EO=2!S:&]U;&0@97AT96YD('1H:7,@8VQA<W,@:6YS=&5A
M9"!O9B!E>'1E;F1I;F<*("H@1&%T851R965/8FIE8W0@9&ER96-T;'DN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?1W)O
M=7`*("HO"F-L87-S($1A=&%4<F5E3V)J96-T7T=R;W5P(&5X=&5N9',@1&%T
M851R965/8FIE8W0@>PH*("`@("\J*@H@("`@("H@5&AE($=R;W5P(&]B:F5C
M="!W:&EC:"!T:&ES(&=R;W5P(&ES(&%S<V]C:6%T960@=VET:"`M(&YE961E
M9`H@("`@("H@9F]R('5P9&%T:6YG(&1A=&$@:6X@=&AE(&)A8VME;F0@=&\@
M;6%K92!C:&%N9V5S('-T:6-K+"!E=&,N"B`@("`@*@H@("`@("H@0'9A<B!'
M<F]U<`H@("`@("HO"B`@("!V87(@)%]G<F]U<$]B.PH*("`@("\J*@H@("`@
M("H@5&AI<R!V87)I86)L92!C86-H97,@=&AE('5S97)S(&%D9&5D(&]R(')E
M;6]V960@9G)O;2!T:&4@9W)O=7`*("`@("`J(&9O<B!(:7-T;W)Y(&QO9V=I
M;F<@;V8@=7-E<BUG<F]U<',@<F5L871I;VYS:&EP+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?875D:71,;V<@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T7T=R;W5P
M(&-O;G-T<G5C=&]R+B!*=7-T(&UA:V5S('-U<F4@=&\@8V%L;`H@("`@("H@
M=&AE('!A<F5N="!C;VYS=')U8W1O<B!S;R!T:&%T('1H92!G<F]U<"=S(&YA
M;64@:7,@<V5T"B`@("`@*B!P<F]P97)L>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@9W)O=7`N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($1A=&%4<F5E3V)J96-T7T=R;W5P*"1N86UE*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ1&%T851R965/8FIE8W0H)&YA;64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@07-S;V-I871E<R!A($=R;W5P(&]B:F5C
M="!W:71H('1H:7,@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M($=R;W5P
M("1G<F]U<$]B("!4:&4@1W)O=7`@;V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971'<F]U<$]B*"8D9W)O=7!/8BD*("`@('L*("`@("`@("`D=&AI
M<RT^7V=R;W5P3V(@/2`F)&=R;W5P3V(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&971C:"!T:&4@240@;V8@=&AI<R!G<F]U<`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG(%1H92!G<F]U<"=S($E$"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G<F]U
M<$]B+3YG971'<F]U<$ED*"1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-A=F4@86YY(&-H86YG97,@=&\@=&AI<R!O8FIE8W0@=&\@=&AE(&)A8VME
M;F0@<&5R;6%N96YT;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/G5P9&%T94=R
M;W5P*"1T:&ES*3L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=7-E
M<B!T;R!T:&ES(&=R;W5P+"!A;F0@;6%K97,@<W5R92!T:&%T('1H92!B86-K
M96YD(&ES"B`@("`@*B!U<&1A=&5D(&%S('=E;&PN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@5&AE('5S97(@=&\@861D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R;F%M92P@)'5P9&%T92`]
M('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S
M97)N86UE72`](#$["B`@("`@("`@)'1H:7,M/E]A=61I=$QO9ULD=7-E<FYA
M;65=(#T@)V%D9%5S97(G.PH@("`@("`@(&EF("@D=7!D871E("8F("1T:&ES
M+3Y?9W)O=7!/8BT^97AI<W1S*"1T:&ES+3YG971.86UE*"DI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!U<V5R(&9R;VT@=&AI<R!G<F]U
M<"P@86YD(&UA:V5S('-U<F4@=&AA="!T:&4@8F%C:V5N9`H@("`@("H@:7,@
M=7!D871E9"!A<R!W96QL+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97)N86UE(%1H92!U<V5R('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E57-E<B@D=7-E<FYA;64L("1U<&1A=&4@/2!T<G5E*0H@
M("`@>PH@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R
M;F%M95TI.PH@("`@("`@("1T:&ES+3Y?875D:71,;V=;)'5S97)N86UE72`]
M("=D96QE=&55<V5R)SL*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I
M<R!A('!A<G0@;V8@=&AI<R!G<F]U<`H@("`@("H@*&%N9"!O;FQY('1H:7,@
M9W)O=7`I"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('5S97(@
M;&ES=`H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/FQI<W15<V5R<R@D=&AI
M<RT^9V5T260H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T
M(&]F(&5V97)Y('5S97(@=&AA="!I<R!A('!A<G0@;V8@=&AI<R!G<F]U<"!A
M;F0*("`@("`J(&%N>2!O9B!I="=S('-U8F=R;W5P<PH@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@(%1H92!C;VUP;&5T92!U<V5R(&QI<W0*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&ES=$%L;%5S97)S*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]G<F]U<$]B+3YL:7-T06QL57-E<G,H)'1H:7,M/F=E
M=$ED*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&%L;"!T:&4@=7-E
M<G,@<F5C96YT;'D@861D960@;W(@<F5M;W9E9"!F<F]M('1H92!G<F]U<"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T075D:71,;V<H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V%U9&ET3&]G.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VQE87)S('1H92!A=61I="!L;V<N(%1O(&)E(&-A;&QE9"!A9G1E
M<B!G<F]U<"!U<&1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R075D
M:71,;V<H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?875D:71,;V<@/2!A<G)A
M>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P('1H:7,@;V)J96-T)W,@
M871T<FEB=71E<R!F<F]M('1H92!D871A(&%R<F%Y(&EN=&\@82!F;W)M870*
M("`@("`J('1H870@=V4@8V%N('-T;W)E(&EN('1H92!A='1R:6)U=&5S('-T
M;W)A9V4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4
M:&4@871T<FEB=71E<R!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1O
M071T<FEB=71E<R@I"B`@("!["B`@("`@("`@+R\@1&5F875L="!T;R!N;R!A
M='1R:6)U=&5S+@H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*3L*"B`@
M("`@("`@+R\@3&]O<"!T:')O=6=H(&%L;"!U<V5R<RP@:68@86YY+@H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^9&%T85LG=7-E<G,G72D@)B8@:7-?87)R
M87DH)'1H:7,M/F1A=&%;)W5S97)S)UTI("8F(&-O=6YT*"1T:&ES+3YD871A
M6R=U<V5R<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%T
M85LG=7-E<G,G72!A<R`D=7-E<B`]/B`D86-T:79E*2!["B`@("`@("`@("`@
M("`@("`D871T<FEB=71E<UM=(#T@87)R87DH)VYA;64G(#T^("=U<V5R)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:V5Y)R`]
M/B`D=7-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=F%L=64G(#T^("1A8W1I=F4I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@("1A='1R:6)U=&5S6UT@/2!A<G)A>2@G;F%M92<@/3X@)V5M
M86EL)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@/3X@
M)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@
M)'1H:7,M/F=E="@G96UA:6PG*2D["@H@("`@("`@(')E='5R;B`D871T<FEB
M=71E<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@:6X@82!L:7-T(&]F
M(&%T=')I8G5T97,@9G)O;2!T:&4@8F%C:V5N9"!A;F0@;6%P(&ET('1O(&]U
M<@H@("`@("H@:6YT97)N86P@9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&%T=')I8G5T97,@(%1H92!L:7-T(&]F(&%T=')I8G5T
M97,@9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8F%C:V5N9"`H871T<FEB=71E(&YA;64L(&ME>2P@86YD('9A;'5E*2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V9R;VU!='1R:6)U=&5S*"1A='1R:6)U=&5S
M*0H@("`@>PH@("`@("`@("\O($EN:71I86QI>F4@9&%T82!A<G)A>2X*("`@
M("`@("`D=&AI<RT^9&%T85LG=7-E<G,G72`](&%R<F%Y*"D["@H@("`@("`@
M(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@
M(&EF("@D871T<ELG;F%M92==(#T]("=U<V5R)RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;)&%T=');)VME>2==72`]("1A='1R
M6R=V86QU92==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/F1A=&%;)&%T=');)VYA;64G75T@/2`D871T<ELG=F%L=64G
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]#:7!H97(N<&AP````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8P-#0`,3`U,34T,S$P-C$`,#(P,30S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@2&]R9&5?0VEP:&5R.CH@8VQA<W,@<')O=FED97,@82!C;VUM
M;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@=&\*("H@=F%R:6]U<R!#:7!H97)S
M(&9O<B!E;F-R>7!T:6]N(&]F(&%R8FET<F%R>2!L96YG=&@@<&EE8V5S(&]F
M(&1A=&$N"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(N<&AP+'8@,2XQ-BXQ
M,BXX(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($!A=71H
M;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*
M("HO"F-L87-S($AO<F1E7T-I<&AE<B!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M8FQO8VL@;6]D92!F;W(@=&AE(&-I<&AE<B!C:&%I;FEN9PH@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)L;V-K36]D92`]
M("=#0D,G.PH*("`@("\J*@H@("`@("H@5&AE(&EN:71I86QI>F%T:6]N('9E
M8W1O<@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7VEV(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%-E="!T:&4@8FQO8VL@
M;6]D92!F;W(@8VEP:&5R(&-H86EN:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&)L;V-K36]D92`@5&AE(&YE=R!B;&]C:VUO9&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$)L;V-K36]D92@D8FQO8VM-;V1E*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?8FQO8VM-;V1E(#T@)&)L;V-K36]D93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@258N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:78@(%1H92!N97<@258N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$E6*"1I=BD*("`@('L*("`@("`@("`D=&AI<RT^7VEV(#T@
M)&EV.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A('-T<FEN9RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@(%1H92!D
M871A('1O(&5N8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!E;F-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC
M<GEP="@D<&QA:6YT97AT*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O0VEP:&5R+T)L;V-K36]D92YP:'`G.PH@
M("`@("`@("1B;&]C:TUO9&4@/2`F2&]R9&5?0VEP:&5R7T)L;V-K36]D93HZ
M9F%C=&]R>2@D=&AI<RT^7V)L;V-K36]D92D["B`@("`@("`@:68@*"%I<U]N
M=6QL*"1T:&ES+3Y?:78I*2!["B`@("`@("`@("`@("1B;&]C:TUO9&4M/G-E
M=$E6*"1T:&ES+3Y?:78I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1B
M;&]C:TUO9&4M/F5N8W)Y<'0H)'1H:7,L("1P;&%I;G1E>'0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5C<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C:7!H97)T97AT("!4:&4@9&%T82!T;R!D96-R
M>7!T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP
M=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'0H)&-I<&AE
M<G1E>'0I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]#:7!H97(O0FQO8VM-;V1E+G!H<"<["B`@("`@("`@)&)L
M;V-K36]D92`]("9(;W)D95]#:7!H97)?0FQO8VM-;V1E.CIF86-T;W)Y*"1T
M:&ES+3Y?8FQO8VM-;V1E*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M
M/E]I=BDI('L*("`@("`@("`@("`@)&)L;V-K36]D92T^<V5T258H)'1H:7,M
M/E]I=BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)L;V-K36]D92T^
M9&5C<GEP="@D=&AI<RP@)&-I<&AE<G1E>'0I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?0VEP
M:&5R(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-I
M<&AE<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0VEP:&5R('-U8F-L
M87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI
M;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!A"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!(;W)D95]#:7!H97(@(%1H92!N97=L>2!C<F5A=&5D
M(&-O;F-R971E($AO<F1E7T-I<&AE<B!I;G-T86YC92P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D8VEP:&5R+"`D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&-I<&AE
M<BD["@H@("`@("`@(&EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+T-I<&AE<B\G("X@)&-I<&AE<B`N("<N<&AP)RDI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]#:7!H
M97(O)R`N("1C:7!H97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D
M8VQA<W,@/2`G2&]R9&5?0VEP:&5R7R<@+B`D8VEP:&5R.PH@("`@("`@(&EF
M("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D8VEP:&5R
M(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&-I<&AE<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E
M9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1C:7!H97(["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O4F5G:7-T<GDN<&AP````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,3$Q-S(S`#$P-3$U-#,Q,#8Q`#`R,#4T,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ($1O(&YO="!S=&%R="!A('-E<W-I;VXN("HO"F1E9FEN92@G2$]21$5?
M4T534TE/3E].3TY%)RP@,2D["@HO*BH@1&\@;F]T('=R:71E(&-H86YG97,@
M=&\@<V5S<VEO;BX@*B\*9&5F:6YE*"=(3U)$15]315-324].7U)%041/3DQ9
M)RP@,BD["@HO*BH*("H@5&AE(%)E9VES=')Y.CH@8VQA<W,@<')O=FED97,@
M82!S970@;V8@;65T:&]D<R!F;W(@8V]M;75N:6-A=&EO;@H@*B!B971W965N
M($AO<F1E(&%P<&QI8V%T:6]N<R!A;F0@:V5E<&EN9R!T<F%C:R!O9B!A<'!L
M:6-A=&EO;@H@*B!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`L=B`Q
M+C(T,RXR+C(R(#(P,#8O,#4O,#0@,C(Z,S4Z,C8@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\
M:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA
M9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]&<F%M97=O
M<FL*("HO"F-L87-S(%)E9VES=')Y('L*"B`@("`O*BH*("`@("`J($AA<V@@
M<W1O<FEN9R!A;&P@;V8@=&AE(&MN;W=N('-E<G9I8V5S(&%N9"!C86QL8F%C
M:W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]A<&E#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(87-H('-T
M;W)I;F<@86QL(&MN;W=N(&1A=&$@='EP97,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T>7!E0V%C:&4@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@2&%S:"!S=&]R:6YG(&%L;"!O9B!T:&4@<F5G
M:7-T97)E9"!I;G1E<F9A8V5S('1H870@87!P;&EC871I;VYS"B`@("`@*B!P
M<F]V:61E+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?:6YT97)F86-E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(
M87-H('-T;W)I;F<@:6YF;W)M871I;VX@;VX@96%C:"!R96=I<W1R>2UA=V%R
M92!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D87!P;&EC871I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%-T86-K(&]F(&EN+75S92!A<'!L:6-A=&EO;G,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!3=&%C:R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!1=6EC:R!P;VEN=&5R('1O('1H
M92!C=7)R96YT(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1!<'`@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@0V%C:&4@;V8@)'!R969S(&]B:F5C=',*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!R969S0V%C:&4@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&4@;V8@87!P;&EC871I
M;VX@8V]N9FEG=7)A=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]C;VYF0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@07)E('=E('5S:6YG(')E9VES=')Y(&-A8VAI;F<_"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=7-E
M8V%C:&4@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%5P9&%T92!T:&5S92!C
M86-H92!E;G1R:65S(&]N('-H=71D;W=N+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U<&1A=&5C86-H92`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE<V4@;71I;64@96YT<FEE
M<R!O;B!S:'5T9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D*("`@
M("`J+PH@("`@=F%R("1?=7!D871E;71I;64@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@1&]N)W0@=7!D871E(&-A8VAE(&%T(&5N9"!O9B!R97%U97-T
M/PH@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7VYO8V%C:&4@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!R969E<F5N8V4@=&\@=&AE(&=L;V)A;"!296=I<W1R>2!O8FIE8W0L(&]N
M;'D*("`@("`J(&-R96%T:6YG(&ET(&EF(&ET(&1O97-N)W0@86QR96%D>2!E
M>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K
M960@87,Z("1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*"D*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V5S<VEO;E]F;&%G<R`@06YY
M('-E<W-I;VX@9FQA9W,N"B`@("`@*@H@("`@("H@0')E='5R;B!296=I<W1R
M>2`@5&AE($AO<F1E(%)E9VES=')Y(&EN<W1A;F-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<VEN9VQE=&]N*"1S97-S:6]N7V9L86=S(#T@,"D*("`@('L*
M("`@("`@("!S=&%T:6,@)')E9VES=')Y.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1R96=I<W1R>2DI('L*("`@("`@("`@("`@)')E9VES=')Y(#T@;F5W(%)E
M9VES=')Y*"1S97-S:6]N7V9L86=S*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5G:7-T<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@
M82!N97<@<F5G:7-T<GD@:6YS=&%N8V4N(%-H;W5L9"!N979E<B!B92!C86QL
M960@97AC97!T"B`@("`@*B!B>2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S97-S:6]N7V9L86=S("!!
M;GD@<V5S<VEO;B!F;&%G<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@4F5G:7-T<GDH)'-E<W-I;VY?9FQA
M9W,@/2`P*0H@("`@>PH@("`@("`@("\J($EM<&]R="!A;F0@9VQO8F%L($AO
M<F1E)W,@8V]N9FEG=7)A=&EO;B!V86QU97,N("HO"B`@("`@("`@)'1H:7,M
M/FEM<&]R=$-O;F9I9R@G:&]R9&4G*3L*"B`@("`@("`@+RH@4W1A<G0@82!S
M97-S:6]N+B`J+PH@("`@("`@(&EF("@D<V5S<VEO;E]F;&%G<R`F($A/4D1%
M7U-%4U-)3TY?3D].12D@>PH@("`@("`@("`@("`O*B!.979E<B!S=&%R="!A
M('-E<W-I;VX@:68@=&AE('-E<W-I;VX@9FQA9W,@:6YC;'5D90H@("`@("`@
M("`@("`@("!(3U)$15]315-324].7TY/3D4N("HO"B`@("`@("`@("`@("1?
M4T534TE/3B`](&%R<F%Y*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@2&]R9&4Z.G-E='5P4V5S<VEO;DAA;F1L97(H*3L*("`@("`@("`@("`@
M0'-E<W-I;VY?<W1A<G0H*3L*("`@("`@("`@("`@:68@*"1S97-S:6]N7V9L
M86=S("8@2$]21$5?4T534TE/3E]214%$3TY,62D@>PH@("`@("`@("`@("`@
M("`@+RH@0VQO<V4@=&AE('-E<W-I;VX@:6UM961I871E;'D@<V\@;F\@8VAA
M;F=E<R!C86X@8F4*("`@("`@("`@("`@("`@("`@(&UA9&4@8G5T('9A;'5E
M<R!A<F4@<W1I;&P@879A:6QA8FQE+B`J+PH@("`@("`@("`@("`@("`@0'-E
M<W-I;VY?=W)I=&5?8VQO<V4H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=7-E8V%C:&4@/2!T<G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!);FET:6%L:7IE('1H92!L
M;V-A;&EZ871I;VX@<F]U=&EN97,@86YD('9A<FEA8FQE<RX@*B\*("`@("`@
M("!.3%,Z.G-E=$QA;F<H*3L*("`@("`@("!.3%,Z.G-E=%1E>'1D;VUA:6XH
M)VAO<F1E)RP@2$]21$5?0D%312`N("<O;&]C86QE)RP@3DQ3.CIG971#:&%R
M<V5T*"DI.PH@("`@("`@(%-T<FEN9SHZ<V5T1&5F875L=$-H87)S970H3DQ3
M.CIG971#:&%R<V5T*"DI.PH*("`@("`@("`D<F5G7VUT:6UE(#T@9FEL96UT
M:6UE*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP:'`G*3L*"B`@
M("`@("`@+RH@3&]A9"!R96=I<W1R>2!I;F9O<FUA=&EO;B!F<F]M('1H92!S
M97-S:6]N+"!I9B!A=F%I;&%B;&4N("HO"B`@("`@("`@:68@*"%E;7!T>2@D
M7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE)UTI("8F"B`@("`@("`@("`@("@D
M7U-%4U-)3TY;)U]R96=I<W1R>6UT:6UE)UU;)W)E9VES=')Y+G!H<"==(#T]
M("1R96=?;71I;64I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1?4T534TE/
M3ELG7W)E9VES=')Y8V%C:&4G72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;#L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%)E860@=&AE(')E9VES
M=')Y(&-O;F9I9W5R871I;VX@9FEL92X@*B\*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP:'`G.PH*
M("`@("`@("`@("`@+RH@4W1O<"!S>7-T96T@:68@2&]R9&4@:7,@:6YA8W1I
M=F4N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^87!P;&EC871I;VYS6R=H
M;W)D92==6R=S=&%T=7,G72`]/2`G:6YA8W1I=F4G*2!["B`@("`@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH7R@B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!38V%N(&9O<B!A;&P@05!)<R!P<F]V
M:61E9"!B>2!E86-H(&%P<"P@86YD('-E="!O=&AE<@H@("`@("`@("`@("`@
M*B!C;VUM;VX@9&5F875L=',@;&EK92!T96UP;&%T97,@86YD(&=R87!H:6-S
M+B`J+PH@("`@("`@("`@("`D87!P3&ES="`](&%R<F%Y7VME>7,H)'1H:7,M
M/F%P<&QI8V%T:6]N<RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1A<'!,:7-T
M(&%S("1A<'!.86UE*2!["B`@("`@("`@("`@("`@("`D87!P(#T@)B1T:&ES
M+3YA<'!L:6-A=&EO;G-;)&%P<$YA;65=.PH@("`@("`@("`@("`@("`@:68@
M*"@D87!P6R=S=&%T=7,G72`]/2`G:&5A9&EN9R<I('Q\"B`@("`@("`@("`@
M("`@("`@("`@*"1A<'!;)W-T871U<R==(#T]("=I;F%C=&EV92<I('Q\"B`@
M("`@("`@("`@("`@("`@("`@*"1A<'!;)W-T871U<R==(#T]("=A9&UI;B<@
M)B8@(4%U=&@Z.FES061M:6XH*2DI('L*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D87!P6R=P<F]V:61E<R==*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D87!P6R=P<F]V:61E<R==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D87!P6R=P<F]V:61E<R==(&%S
M("1I;G1E<F9A8V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72`]("1A<'!.86UE.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G1E<F9A
M8V5S6R1A<'!;)W!R;W9I9&5S)UU=(#T@)&%P<$YA;64["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D87!P6R=T96UP;&%T97,G72D@)B8@:7-S970H)&%P<%LG
M9FEL97)O;W0G72DI('L*("`@("`@("`@("`@("`@("`@("`D87!P6R=T96UP
M;&%T97,G72`]("1A<'!;)V9I;&5R;V]T)UT@+B`G+W1E;7!L871E<R<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1A
M<'!;)VIS=7)I)UTI("8F(&ES<V5T*"1A<'!;)W=E8G)O;W0G72DI('L*("`@
M("`@("`@("`@("`@("`@("`D87!P6R=J<W5R:2==(#T@)&%P<%LG=V5B<F]O
M="==("X@)R]J<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1A<'!;)VIS9G,G72D@)B8@:7-S970H)&%P<%LG9FEL
M97)O;W0G72DI('L*("`@("`@("`@("`@("`@("`@("`D87!P6R=J<V9S)UT@
M/2`D87!P6R=F:6QE<F]O="==("X@)R]J<R<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1A<'!;)W1H96UE<W5R:2==
M*2`F)B!I<W-E="@D87!P6R=W96)R;V]T)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&%P<%LG=&AE;65S=7)I)UT@/2`D87!P6R=W96)R;V]T)UT@+B`G
M+W1H96UE<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1A<'!;)W1H96UE<V9S)UTI("8F(&ES<V5T*"1A<'!;)V9I
M;&5R;V]T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&%P<%LG=&AE;65S
M9G,G72`]("1A<'!;)V9I;&5R;V]T)UT@+B`G+W1H96UE<R<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-L96%R
M(&]U="!T:&4@05!)("8@5'EP92!C86-H97,L(&EF('1H97D@97AI<W1S+B`J
M+PH@("`@("`@("`@("`D=&AI<RT^7V%P:4-A8VAE(#T@)'1H:7,M/E]T>7!E
M0V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("`@("`@)'1H:7,M/E]C86-H959A
M<G,H87)R87DH)V%P<&QI8V%T:6]N<R<L("=?:6YT97)F86-E<R<L("=?87!I
M0V%C:&4G+"`G7W1Y<&5#86-H92<I+"!A<G)A>2@G<F5G:7-T<GDN<&AP)R`]
M/B`D<F5G7VUT:6UE*2D["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@
M=&AE(&=L;V)A;"!097)M<R!O8FIE8W0N("HO"B`@("`@("`@)$=,3T)!3%-;
M)W!E<FUS)UT@/2`F4&5R;7,Z.G-I;F=L971O;B@I.PH*("`@("`@("`O*B!!
M='1A8V@@:F%V87-C<FEP="!N;W1I9FEC871I;VX@;&ES=&5N97(N("HO"B`@
M("`@("`@)&YO=&EF:6-A=&EO;B`]("9.;W1I9FEC871I;VXZ.G-I;F=L971O
M;B@I.PH@("`@("`@("1N;W1I9FEC871I;VXM/F%T=&%C:"@G:F%V87-C<FEP
M="<I.PH*("`@("`@("`O*B!296=I<W1E<B!A8V-E<W,@:V5Y(&QO9V=E<B!F
M;W(@=')A;G-L871O<G,N("HO"B`@("`@("`@:68@*$`D1TQ/0D%,4ULG8V]N
M9B==6R=L;V=?86-C97-S:V5Y<R==*2!["B`@("`@("`@("`@(')E9VES=&5R
M7W-H=71D;W=N7V9U;F-T:6]N*&-R96%T95]F=6YC=&EO;B@G)RP@)TAO<F1E
M.CIG971!8V-E<W-+97DH;G5L;"P@;G5L;"P@=')U92D[)RDI.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A(&QI<W0@;V8@=F%R:6%B
M;&4@;F%M97,@86YD(&UO9&EF:6-A=&EO;B!T:6UE<R!T;R!B92!C86-H960N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1V87)S("`@($$@;&ES="!O9B!V87)I86)L92!N86UE
M<R!T;R!B92!C86-H960N"B`@("`@*B!`<&%R86T@87)R87D@)&UT:6UE<R`@
M02!L:7-T(&]F(&9I;&4@;6]D:69I8V%I;VX@=&EM97,@=&\@8F4@8V%C:&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%C:&5687)S*"1V87)S(#T@87)R
M87DH*2P@)&UT:6UE<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC
M("1R96=C86-H97-H=71D;W=N(#T@9F%L<V4["@H@("`@("`@(&EF("@D=&AI
M<RT^7W5S96-A8VAE*2!["B`@("`@("`@("`@("1T:&ES+3Y?=7!D871E8V%C
M:&4@/2!A<G)A>5]M97)G92@D=&AI<RT^7W5P9&%T96-A8VAE+"`D=F%R<RD[
M"B`@("`@("`@("`@("1T:&ES+3Y?=7!D871E;71I;64@/2!A<G)A>5]M97)G
M92@D=&AI<RT^7W5P9&%T96UT:6UE+"`D;71I;65S*3L*("`@("`@("`@("`@
M:68@*"$D<F5G8V%C:&5S:'5T9&]W;BD@>PH@("`@("`@("`@("`@("`@<F5G
M:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G7W-H=71D
M;W=N8V%C:&4G*2D["B`@("`@("`@("`@("`@("`D<F5G8V%C:&5S:'5T9&]W
M;B`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3=&]R97,@8V%C:&5A8FQE(&UE;6)E<B!V87)I86)L97,@
M:6X@=&AE('-E<W-I;VX@870@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:'5T9&]W;F-A
M8VAE*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].*2`F)B!!
M=71H.CIG971!=71H*"D@)B8@(21T:&ES+3Y?;F]C86-H92D@>PH@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG7W)E9VES=')Y8V%C:&4G72DI
M('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG7W)E9VES=')Y8V%C:&4G
M72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*&%R<F%Y7W5N:7%U92@D=&AI<RT^7W5P9&%T96-A8VAE*2!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE
M)UU;)'9A;%T@/2`D=&AI<RT^)'9A;#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)U]R96=I<W1R>6UT:6UE)UTI
M*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)U]R96=I<W1R>6UT:6UE
M)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E
M86-H("AA<G)A>5]U;FEQ=64H)'1H:7,M/E]U<&1A=&5M=&EM92D@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)U]R96=I
M<W1R>6UT:6UE)UU;)&ME>5T@/2`D=F%L.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VQE87(@=&AE(')E9VES=')Y
M(&-A8VAE+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J
M+PH@("`@9G5N8W1I;VX@8VQE87)#86-H92@I"B`@("!["B`@("`@("`@=6YS
M970H)%]315-324].6R=?<F5G:7-T<GEC86-H92==*3L*("`@("`@("`D=&AI
M<RT^7VYO8V%C:&4@/2!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEL
M;',@=&AE(')E9VES=')Y)W,@05!)(&-A8VAE('=I=&@@=&AE(&%V86EL86)L
M92!S97)V:6-E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V9I;&Q!4$E#86-H92@I"B`@("!["B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7V%P:4-A8VAE*2D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@87)R87DH
M)V%C=&EV92<L("=N;W1O;VQB87(G+"`G:&ED9&5N)RD["B`@("`@("`@:68@
M*$%U=&@Z.FES061M:6XH*2D@>PH@("`@("`@("`@("`D<W1A='5S6UT@/2`G
M861M:6XG.PH@("`@("`@('T*("`@("`@("`D87!P<R`]("1T:&ES+3YL:7-T
M07!P<R@D<W1A='5S*3L*("`@("`@("!F;W)E86-H("@D87!P<R!A<R`D87!P
M*2!["B`@("`@("`@("`@("1?<V5R=FEC97,@/2`D7W1Y<&5S(#T@;G5L;#L*
M("`@("`@("`@("`@)&%P:2`]("1T:&ES+3YG970H)V9I;&5R;V]T)RP@)&%P
M<"D@+B`G+VQI8B]A<&DN<&AP)SL*("`@("`@("`@("`@:68@*&ES7W)E861A
M8FQE*"1A<&DI*2!["B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)&%P
M:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1?<V5R
M=FEC97,I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%P:4-A8VAE6R1A
M<'!=(#T@87)R87DH*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?87!I0V%C:&5;)&%P<%T@/2`D7W-E<G9I8V5S.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D7W1Y<&5S*2D@
M>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)%]T>7!E<R!A<R`D='EP92`]
M/B`D<&%R86US*2!["B`@("`@("`@("`@("`@("`@("`@+RH@4')E9FEX(&YO
M;BU(;W)D92!T>7!E<R!W:71H('1H92!A<'!L:6-A=&EO;@H@("`@("`@("`@
M("`@("`@("`@("`J(&YA;64N("HO"B`@("`@("`@("`@("`@("`@("`@)'!R
M969I>"`]("1A<'`@/3T@)VAO<F1E)R`_("<G(#H@(B1[87!P?5\B.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?='EP94-A8VAE6R1P<F5F:7@@+B`D
M='EP95T@/2`D<&%R86US.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-A8VAE5F%R<RAA<G)A
M>2@G7V%P:4-A8VAE)RP@)U]T>7!E0V%C:&4G*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@82!L:7-T(&]F('1H92!I;G-T86QL960@86YD(')E
M9VES=&5R960@87!P;&EC871I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`@("1F:6QT97(@("`@("!!;B!A<G)A>2!O9B!T:&4@<W1A='5S97,@
M=&AA="!S:&]U;&0@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FYE9"X@1&5F875L=',@=&\@;F]N+6AI9&1E;BX*("`@("`J
M($!P87)A;2!B;V]L96%N("1A<W-O8R`@("`@("!!<W-O8VEA=&EV92!A<G)A
M>2!W:71H(&%P<"!N86UE<R!A<R!K97ES+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N(&QE=F5L('1O(&-H96-K
M(&9O<B!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!L:7-T+B!$969A=6QT<R!T;R!015)-4U]32$]7+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($QI<W0@;V8@87!P<R!R96=I<W1E<F5D('=I=&@@
M2&]R9&4N($EF(&YO"B`@("`@*B`@("`@("`@("`@("`@("!A<'!L:6-A=&EO
M;G,@87)E(&1E9FEN960@<F5T=7)N<R!A;B!E;7!T>2!A<G)A>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&ES=$%P<',H)&9I;'1E<B`](&YU;&PL("1A<W-O
M8R`](&9A;'-E+"`D<&5R;6ES<VEO;B`](%!%4DU37U-(3U<I"B`@("!["B`@
M("`@("`@)&%P<',@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<U]N=6QL*"1F
M:6QT97(I*2!["B`@("`@("`@("`@("1F:6QT97(@/2!A<G)A>2@G;F]T;V]L
M8F%R)RP@)V%C=&EV92<I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/F%P<&QI8V%T:6]N<R!A<R`D87!P(#T^("1P87)A;7,I('L*("`@
M("`@("`@("`@:68@*&EN7V%R<F%Y*"1P87)A;7-;)W-T871U<R==+"`D9FEL
M=&5R*2`F)@H@("`@("`@("`@("`@("`@*&1E9FEN960H)T%55$A?2$%.1$Q%
M4B<I('Q\("1T:&ES+3YH87-097)M:7-S:6]N*"1A<'`L("1P97)M:7-S:6]N
M*2DI('L*("`@("`@("`@("`@("`@("1A<W-O8R`_("1A<'!S6R1A<'!=(#T@
M)&%P<"`Z("1A<'!S6UT@/2`D87!P.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&%P<',["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&%L;"!A=F%I;&%B;&4@<F5G:7-T<GD@05!)<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@05!)(&QI<W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QI<W1!4$ES*"D*("`@('L*("`@("`@("!S=&%T:6,@
M)&%P:7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D87!I<RD@>PH@("`@("`@
M("`@("!R971U<FX@)&%P:7,["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H
M("AA<G)A>5]K97ES*"1T:&ES+3Y?:6YT97)F86-E<RD@87,@)&EN=&5R9F%C
M92D@>PH@("`@("`@("`@("!`;&ES="@D87!I+"`I(#T@97AP;&]D92@G+R<L
M("1I;G1E<F9A8V4I.PH@("`@("`@("`@("`D87!I<UM=(#T@)&%P:3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>5]U;FEQ=64H)&%P:7,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@;V8@=&AE(&%V86EL
M86)L92!R96=I<W1R>2!M971H;V1S+"!O<B!A;'1E<FYA=&5L>0H@("`@("H@
M;VYL>2!T:&]S92!F;W(@82!S<&5C:69I960@05!)+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%P:2`@1&5F:6YE<R!T:&4@05!)(&9O<B!W:&EC
M:"!T:&4@;65T:&]D<R!S:&%L;"!B90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4
M:&4@;65T:&]D(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1-971H
M;V1S*"1A<&D@/2!N=6QL*0H@("`@>PH@("`@("`@("1M971H;V1S(#T@87)R
M87DH*3L*"B`@("`@("`@)'1H:7,M/E]F:6QL05!)0V%C:&4H*3L*"B`@("`@
M("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^87!P;&EC871I;VYS*2!A
M<R`D87!P*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^87!P;&EC
M871I;VYS6R1A<'!=6R=P<F]V:61E<R==*2D@>PH@("`@("`@("`@("`@("`@
M)'!R;W9I9&5S(#T@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG<')O=FED
M97,G73L*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'!R;W9I9&5S
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1P<F]V:61E<R`](&%R<F%Y*"1P
M<F]V:61E<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<')O=FED97,@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D<')O=FED97,@87,@
M)&UE=&AO9"D@>PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;65T:&]D
M+"`G+R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]N=6QL*"1A<&DI('Q\"B`@("`@("`@("`@("`@("`@("`@("`@("AS=6)S
M='(H)&UE=&AO9"P@,"P@<W1R;&5N*"1A<&DI*2`]/2`D87!I*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;65T:&]D<UM=(#T@)&UE=&AO9#L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-?;G5L;"@D87!I*2!\?"`H)&UE=&AO9"`]/2`D87!I*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V%P:4-A8VAE6R1A<'!=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K
M97ES*"1T:&ES+3Y?87!I0V%C:&5;)&%P<%TI(&%S("1S97)V:6-E*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;65T:&]D<UM=(#T@)&UE=&AO
M9"`N("<O)R`N("1S97)V:6-E.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87E?=6YI
M<75E*"1M971H;V1S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M86QL(&]F('1H92!A=F%I;&%B;&4@<F5G:7-T<GD@9&%T82!T>7!E<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9&%T82!T>7!E(&QI<W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W14>7!E<R@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]F:6QL05!)0V%C:&4H*3L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]T>7!E0V%C:&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@;65T:&]D)W,@<VEG;F%T=7)E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&UE=&AO9"`@5&AE(&9U;&P@;F%M92!O9B!T:&4@;65T:&]D('1O
M(&-H96-K(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!('1W
M;R!D:6UE;G-I;VYA;"!A<G)A>2X@5&AE(&9I<G-T(&5L96UE;G0@8V]N=&%I
M;G,@86X*("`@("`J("`@("`@("`@("`@("`@(&%R<F%Y('=I=&@@=&AE('!A
M<F%M971E<B!N86UE<RP@=&AE('-E8V]N9"!O;F4@=&AE(')E='5R;@H@("`@
M("H@("`@("`@("`@("`@("`@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4VEG;F%T=7)E*"1M971H;V0I"B`@("!["B`@("`@("`@:68@*"$H)&%P
M<"`]("1T:&ES+3YH87--971H;V0H)&UE=&AO9"DI*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9FEL;$%024-A
M8VAE*"D["@H@("`@("`@($!L:7-T*"P@)&9U;F-T:6]N*2`](&5X<&QO9&4H
M)R\G+"`D;65T:&]D*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]A<&E#
M86-H95LD87!P75LD9G5N8W1I;VY=6R=T>7!E)UTI("8F"B`@("`@("`@("`@
M(&ES<V5T*"1T:&ES+3Y?87!I0V%C:&5;)&%P<%U;)&9U;F-T:6]N75LG87)G
M<R==*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)'1H:7,M/E]A<&E#
M86-H95LD87!P75LD9G5N8W1I;VY=6R=A<F=S)UTL("1T:&ES+3Y?87!I0V%C
M:&5;)&%P<%U;)&9U;F-T:6]N75LG='EP92==*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@:68@86X@:6YT97)F86-E(&ES
M(&EM<&QE;65N=&5D(&)Y(&%N(&%C=&EV92!A<'!L:6-A=&EO;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G1E<F9A8V4@(%1H92!I;G1E<F9A
M8V4@=&\@8VAE8VL@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!A<'!L:6-A=&EO;B!I;7!L96UE;G1I;F<@)&EN=&5R9F%C92!I9B!W
M92!H879E(&ET+`H@("`@("H@("`@("`@("`@("`@("`@9F%L<V4@:68@=&AE
M(&EN=&5R9F%C92!I<R!N;W0@:6UP;&5M96YT960N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&AA<TEN=&5R9F%C92@D:6YT97)F86-E*0H@("`@>PH@("`@("`@
M(')E='5R;B`A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A8V5=
M*2`_"B`@("`@("`@("`@("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E
M72`Z"B`@("`@("`@("`@(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5T97)M:6YE(&EF(&$@;65T:&]D(&AA<R!B965N(')E9VES=&5R960@=VET
M:"!T:&4@<F5G:7-T<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;65T:&]D("!4:&4@9G5L;"!N86UE(&]F('1H92!M971H;V0@=&\@8VAE8VL@
M9F]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("!/;FQY(&-H96-K
M('1H:7,@87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(&%P<&QI8V%T:6]N(&EM<&QE;65N=&EN9R`D;65T:&]D(&EF('=E
M(&AA=F4@:70L"B`@("`@*B`@("`@("`@("`@("`@("!F86QS92!I9B!T:&4@
M;65T:&]D(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA
M<TUE=&AO9"@D;65T:&]D+"`D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H:7-?;G5L;"@D87!P*2D@>PH@("`@("`@("`@("!`;&ES="@D:6YT97)F
M86-E+"`D8V%L;"D@/2!E>'!L;V1E*"<O)RP@)&UE=&AO9"D["B`@("`@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=*2D@
M>PH@("`@("`@("`@("`@("`@)&%P<"`]("1T:&ES+3Y?:6YT97)F86-E<ULD
M;65T:&]D73L*("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=&AI<RT^
M7VEN=&5R9F%C97-;)&EN=&5R9F%C95TI*2!["B`@("`@("`@("`@("`@("`D
M87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A8V5=.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A
M;&P@/2`D;65T:&]D.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]F:6QL
M05!)0V%C:&4H*3L*"B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^7V%P
M:4-A8VAE6R1A<'!=6R1C86QL72D@/R`D87!P(#H@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&AO;VL@8V]R<F5S<&]N9&EN9R!T
M;R!T:&4@9&5F875L="!P86-K86=E('1H870*("`@("`J('!R;W9I9&5S('1H
M92!F=6YC=&EO;F%L:71Y(')E<75E<W1E9"!B>2!T:&4@)&UE=&AO9`H@("`@
M("H@<&%R86UE=&5R+B`D;65T:&]D(&ES(&$@<W1R:6YG(&-O;G-I<W1I;F<@
M;V8*("`@("`J(")P86-K86=E='EP92]M971H;V1N86UE(BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@(%1H92!M971H;V0@=&\@8V%L
M;"X*("`@("`J($!P87)A;2!A<G)A>2`D87)G<R`@("`@07)G=6UE;G1S('1O
M('1H92!M971H;V0N"B`@("`@*@H@("`@("H@0')E='5R;B`@5$]$3PH@("`@
M("H@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C86QL*"1M971H;V0L("1A<F=S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!`;&ES="@D:6YT97)F86-E+"`D8V%L;"D@/2!E
M>'!L;V1E*"<O)RP@)&UE=&AO9"D["@H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=*2D@>PH@("`@("`@("`@("`D87!P
M(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=.PH@("`@("`@('T@96QS
M96EF("@A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A8V5=*2D@
M>PH@("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E
M<F9A8V5=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=4:&4@;65T:&]D("(G("X@)&UE=&AO9"`N("<B
M(&ES(&YO="!D969I;F5D(&EN('1H92!(;W)D92!296=I<W1R>2XG*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^8V%L;$)Y4&%C:V%G92@D
M87!P+"`D8V%L;"P@)&%R9W,I.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T
M<'5T('1H92!H;V]K(&-O<G)E<W!O;F1I;F<@=&\@=&AE('-P96-I9FEC('!A
M8VMA9V4@;F%M960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P
M("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A;&QE9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-A;&P@(%1H92!M971H;V0@=&\@8V%L;"X*("`@("`J($!P
M87)A;2!A<G)A>2`D87)G<R`@($%R9W5M96YT<R!T;R!T:&4@;65T:&]D+@H@
M("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J("`@("`@("`@(%)E
M='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V%L;$)Y4&%C:V%G92@D87!P+"`D8V%L;"P@)&%R9W,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("\J($YO=&4Z(&-A;&QI;F<@:&%S365T:&]D*"D@
M;6%K97,@<W5R92!T:&%T('=E)W9E(&-A8VAE9`H@("`@("`@("`J("1A<'`G
M<R!S97)V:6-E<R!A;F0@:6YC;'5D960@=&AE($%022!F:6QE+"!S;R!W92!D
M;VXG="!T<GD*("`@("`@("`@*B!T;R!D;R!I="!A9V%I;B!E>'!L:6-I=&QY
M(&EN('1H:7,@;65T:&]D+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/FAA<TUE
M=&AO9"@D8V%L;"P@)&%P<"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9B@G5&AE(&UE=&AO9"`B)7,B(&ES(&YO="!D
M969I;F5D(&EN('1H92!!4$D@9F]R("5S+B<L("1C86QL+"`D87!P*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!,;V%D('1H92!!4$D@;F]W+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)%]315-324].6R=?<F5G:7-T<GEC86-H92==6R=?
M87!I0V%C:&4G72DI('L*("`@("`@("`@("`@)&%P:2`]("1T:&ES+3YG970H
M)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]A<&DN<&AP)SL*("`@("`@("`@
M("`@:68@*&ES7W)E861A8FQE*"1A<&DI*2!["B`@("`@("`@("`@("`@("!I
M;F-L=61E7V]N8V4@)&%P:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@36%K92!S=7)E('1H870@=&AE(&9U;F-T:6]N(&%C='5A;&QY
M(&5X:7-T<RX@*B\*("`@("`@("`D9G5N8W1I;VX@/2`G7R<@+B`D87!P("X@
M)U\G("X@)&-A;&P["B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H)&9U
M;F-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G5&AE(&9U;F-T:6]N(&EM<&QE;65N=&EN9R`G("X@)&-A;&P@+B`G("@G
M("X@)&9U;F-T:6]N("X@)RD@:7,@;F]T(&1E9FEN960@:6X@)R`N("1A<'`@
M+B`G7"=S($%022XG*3L*("`@("`@("!]"@H@("`@("`@("1C:&5C:U!E<FUS
M(#T@:7-S970H)'1H:7,M/E]A<&E#86-H95LD87!P75LD8V%L;%U;)V-H96-K
M<&5R;7,G72D@/PH@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A<&E#
M86-H95LD87!P75LD8V%L;%U;)V-H96-K<&5R;7,G72`Z('1R=64["@H@("`@
M("`@("\J(%-W:71C:"!A<'!L:6-A=&EO;B!C;VYT97AT<R!N;W<L(&EF(&YE
M8V5S<V%R>2P@8F5F;W)E"B`@("`@("`@("H@:6YC;'5D:6YG(&%N>2!F:6QE
M<R!W:&EC:"!M:6=H="!D;R!I="!F;W(@=7,N(%)E='5R;B!A;@H@("`@("`@
M("`J(&5R<F]R(&EM;65D:6%T96QY(&EF('!U<VA!<'`H*2!F86EL<RX@*B\*
M("`@("`@("`D<'5S:&5D(#T@)'1H:7,M/G!U<VA!<'`H)&%P<"P@)&-H96-K
M4&5R;7,I.PH@("`@("`@(&EF("AI<U]A*"1P=7-H960L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1P=7-H960["B`@("`@("`@?0H*
M("`@("`@("`D<F5S(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH)&9U;F-T:6]N
M+"`D87)G<RD["@H@("`@("`@("\J($EF('=E(&-H86YG960@87!P;&EC871I
M;VX@8V]N=&5X="!I;B!T:&4@8V]U<G-E(&]F('1H:7,*("`@("`@("`@*B!C
M86QL+"!U;F1O('1H870@8VAA;F=E(&YO=RX@*B\*("`@("`@("!I9B`H)'!U
M<VAE9"`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^<&]P07!P*"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@:&]O:R!C;W)R97-P;VYD:6YG('1O('1H
M92!D969A=6QT('!A8VMA9V4@=&AA=`H@("`@("H@<')O=FED97,@=&AE(&9U
M;F-T:6]N86QI='D@<F5Q=65S=&5D(&)Y('1H92`D;65T:&]D"B`@("`@*B!P
M87)A;65T97(N("1M971H;V0@:7,@82!S=')I;F<@8V]N<VES=&EN9R!O9@H@
M("`@("H@(G!A8VMA9V5T>7!E+VUE=&AO9&YA;64B+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&UE=&AO9"!T;R!L:6YK('1O
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("`@("!!<F=U;65N=',@=&\@
M=&AE(&UE=&AO9"X*("`@("`J($!P87)A;2!M:7AE9"`D97AT<F$@("`@17AT
M<F$L(&YO;BUS=&%N9&%R9"!A<F=U;65N=',@=&\@=&AE(&UE=&AO9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U
M<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI;FLH)&UE=&AO9"P@)&%R9W,@/2!A<G)A>2@I+"`D97AT<F$@/2`G)RD*
M("`@('L*("`@("`@("!`;&ES="@D:6YT97)F86-E+"`D8V%L;"D@/2!E>'!L
M;V1E*"<O)RP@)&UE=&AO9"D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]I;G1E<F9A8V5S6R1M971H;V1=*2D@>PH@("`@("`@("`@("`D87!P(#T@
M)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=.PH@("`@("`@('T@96QS96EF
M("@A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A8V5=*2D@>PH@
M("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A
M8V5=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=4:&4@;65T:&]D("(G("X@)&UE=&AO9"`N("<B(&ES
M(&YO="!D969I;F5D(&EN('1H92!(;W)D92!296=I<W1R>2XG*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^;&EN:T)Y4&%C:V%G92@D87!P
M+"`D8V%L;"P@)&%R9W,L("1E>'1R82D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!/=71P=70@=&AE(&AO;VL@8V]R<F5S<&]N9&EN9R!T;R!T:&4@<W!E8VEF
M:6,@<&%C:V%G92!N86UE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A<'`@("!4:&4@87!P;&EC871I;VX@8F5I;F<@8V%L;&5D+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V%L;"`@5&AE(&UE=&AO9"!T;R!L:6YK('1O+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("`@07)G=6UE;G1S('1O('1H92!M
M971H;V0N"B`@("`@*B!`<&%R86T@;6EX960@)&5X=')A("!%>'1R82P@;F]N
M+7-T86YD87)D(&%R9W5M96YT<R!T;R!T:&4@;65T:&]D+@H@("`@("H*("`@
M("`J($!R971U<FX@(%1/1$\*("`@("`J("`@("`@("`@(%)E='5R;G,@4$5!
M4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@;&EN:T)Y
M4&%C:V%G92@D87!P+"`D8V%L;"P@)&%R9W,@/2!A<G)A>2@I+"`D97AT<F$@
M/2`G)RD*("`@('L*("`@("`@("`O*B!.;W1E.B!C86QL:6YG(&AA<TUE=&AO
M9"!M86ME<R!S=7)E('1H870@=V4G=F4@8V%C:&5D("1A<'`G<PH@("`@("`@
M("`J('-E<G9I8V5S(&%N9"!I;F-L=61E9"!T:&4@05!)(&9I;&4L('-O('=E
M(&1O;B=T('1R>2!T;R!D;PH@("`@("`@("`J(&ET(&ET(&%G86EN(&5X<&QI
M8VET;'D@:6X@=&AI<R!M971H;V0N("HO"B`@("`@("`@:68@*"$D=&AI<RT^
M:&%S365T:&]D*"1C86QL+"`D87!P*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G5&AE(&UE=&AO9"`B)R`N("1C86QL("X@)R(@
M:7,@;F]T(&1E9FEN960@:6X@)R`N("1A<'`@+B`G7"=S($%022XG*3L*("`@
M("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!T:&4@;&EN:R!I<R!D969I
M;F5D+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V%P:4-A8VAE6R1A
M<'!=6R1C86QL75LG;&EN:R==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G5&AE(&QI;FL@)R`N("1C86QL("X@)R!I<R!N;W0@
M9&5F:6YE9"!I;B`G("X@)&%P<"`N("=<)W,@05!)+B<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@26YI=&EA;"!L:6YK('9A;'5E+B`J+PH@("`@("`@("1L
M:6YK(#T@)'1H:7,M/E]A<&E#86-H95LD87!P75LD8V%L;%U;)VQI;FLG73L*
M"B`@("`@("`@+RH@1FEL;"!I;B!H=&UL+65N8V]D960@87)G=6UE;G1S+B`J
M+PH@("`@("`@(&9O<F5A8V@@*"1A<F=S(&%S("1K97D@/3X@)'9A;"D@>PH@
M("`@("`@("`@("`D;&EN:R`]('-T<E]R97!L86-E*"<E)R`N("1K97D@+B`G
M)2<L(&AT;6QE;G1I=&EE<R@D=F%L*2P@)&QI;FLI.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG=V5B
M<F]O="==*2D@>PH@("`@("`@("`@("`D;&EN:R`]('-T<E]R97!L86-E*"<E
M87!P;&EC871I;VXE)RP@)'1H:7,M/F=E="@G=V5B<F]O="<L("1A<'`I+"`D
M;&EN:RD["B`@("`@("`@?0H*("`@("`@("`O*B!297!L86-E(&AT;6QE;F-O
M9&5D(&%R9W5M96YT<R!T:&%T(&AA=F5N)W0@8F5E;B!S<&5C:69I960@=VET
M:`H@("`@("`@("`@(&%N(&5M<'1Y('-T<FEN9R`H=&AI<R!I<R!W:&5R92!T
M:&4@9&5F875L="!W;W5L9"!B92!S=6)S=&ET=71E9`H@("`@("`@("`@(&EN
M(&$@<W1R:6-T97(@<F5G:7-T<GD@:6UP;&5M96YT871I;VXI+B`J+PH@("`@
M("`@("1L:6YK(#T@<')E9U]R97!L86-E*"=\)2XK)7Q5)RP@)R<L("1L:6YK
M*3L*"B`@("`@("`@+RH@1FEL;"!I;B!U<FQE;F-O9&5D(&%R9W5M96YT<RX@
M*B\*("`@("`@("!F;W)E86-H("@D87)G<R!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@)&QI;FL@/2!S=')?<F5P;&%C92@G?"<@+B!3=')I;F<Z
M.FQO=V5R*"1K97DI("X@)WPG+"!U<FQE;F-O9&4H)'9A;"DL("1L:6YK*3L*
M("`@("`@("!]"@H@("`@("`@("\J($%P<&5N9"!A;GD@97AT<F$L(&YO;BUS
M=&%N9&%R9"!A<F=U;65N=',N("HO"B`@("`@("`@:68@*&ES7V%R<F%Y*"1E
M>'1R82DI('L*("`@("`@("`@("`@)&5X=')A7V%R9W,@/2`G)SL*("`@("`@
M("`@("`@9F]R96%C:"`H)&5X=')A(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@)&5X=')A7V%R9W,@+BT@)R8G("X@=7)L96YC;V1E*"1K
M97DI("X@)STG("X@=7)L96YC;V1E*"1V86PI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5X=')A7V%R9W,@/2`D97AT
M<F$["B`@("`@("`@?0H@("`@("`@("1L:6YK(#T@<W1R7W)E<&QA8V4H)WQE
M>'1R87PG+"`D97AT<F%?87)G<RP@)&QI;FLI.PH*("`@("`@("`O*B!297!L
M86-E(&AT;6PM96YC;V1E9"!A<F=U;65N=',@=&AA="!H879E;B=T(&)E96X@
M<W!E8VEF:65D('=I=&@*("`@("`@("`@("!A;B!E;7!T>2!S=')I;F<@*'1H
M:7,@:7,@=VAE<F4@=&AE(&1E9F%U;'0@=V]U;&0@8F4@<W5B<W1I='5T960*
M("`@("`@("`@("!I;B!A('-T<FEC=&5R(')E9VES=')Y(&EM<&QE;65N=&%T
M:6]N*2X@*B\*("`@("`@("`D;&EN:R`]('!R96=?<F5P;&%C92@G?%Q\+BM<
M?'Q5)RP@)R<L("1L:6YK*3L*"B`@("`@("`@<F5T=7)N("1L:6YK.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5P;&%C92!A;GD@)6%P<&QI8V%T:6]N)2!S
M=')I;F=S('=I=&@@=&AE(&9I;&5S>7-T96T@<&%T:"!T;R!T:&4*("`@("`J
M(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@(%1H92!A<'!L:6-A=&EO;B!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<'`@("!4:&4@87!P;&EC871I;VX@8F5I;F<@8V%L;&5D+@H@("`@
M("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J("`@("`@("`@(%)E='5R
M;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M87!P;&EC871I;VY&:6QE4&%T:"@D<&%T:"P@)&%P<"`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7VYU;&PH)&%P<"DI('L*("`@("`@("`@("`@)&%P
M<"`]("1T:&ES+3Y?8W5R<F5N=$%P<#L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P72DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")<(B5S
M7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(I
M+"`D87!P*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<W1R7W)E<&QA
M8V4H)R5A<'!L:6-A=&EO;B4G+"`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=
M6R=F:6QE<F]O="==+"`D<&%T:"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M97!L86-E(&%N>2`E87!P;&EC871I;VXE('-T<FEN9W,@=VET:"!T:&4@=V5B
M('!A=&@@=&\@=&AE(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!A<'!L:6-A=&EO;B!S=')I;F<N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A<'`@("!4:&4@87!P;&EC871I;VX@8F5I;F<@
M8V%L;&5D+@H@("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J("`@
M("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@87!P;&EC871I;VY796)0871H*"1P871H+"`D87!P(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1A<'`I*2!["B`@("`@
M("`@("`@("1A<'`@/2`D=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)R5A<'!L:6-A=&EO;B4G+"`D
M=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=W96)R;V]T)UTL("1P871H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@8W5R<F5N="!A<'!L:6-A
M=&EO;BP@861D:6YG(&ET('1O('1H92!T;W`@;V8@=&AE($AO<F1E"B`@("`@
M*B!A<'!L:6-A=&EO;B!S=&%C:RX@268@=&AI<R!I<R!T:&4@9FER<W0@87!P
M;&EC871I;VX@=&\@8F4*("`@("`J('!U<VAE9"P@<F5T<FEE=F4@<V5S<VEO
M;B!I;F9O<FUA=&EO;B!A<R!W96QL+@H@("`@("H*("`@("`J('!U<VA!<'`H
M*2!A;'-O(')E861S('1H92!A<'!L:6-A=&EO;B=S(&-O;F9I9W5R871I;VX@
M9FEL92!A;F0*("`@("`J('-E=',@=7`@:71S(&=L;V)A;"`D8V]N9B!H87-H
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1A<'`@("`@("`@("!4
M:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VX@=&\@<'5S:"X*("`@("`J($!P
M87)A;2!B;V]L96%N("1C:&5C:U!E<FUS("!-86ME('-U<F4@=&AA="!T:&4@
M8W5R<F5N="!U<V5R(&AA<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('!E<FUI<W-I;VYS('1O('1H92!A<'!L:6-A=&EO;B!B96EN9R!L
M;V%D960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A
M=6QT<R!T;R!T<G5E+B!3:&]U;&0@3TY,62!B92!D:7-A8FQE9"!B>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-Y<W1E;2!S8W)I<'1S
M("AC<F]N(&IO8G,L(&5T8RXI(&%N9"!S8W)I<'1S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AA="!H86YD;&4@;&]G:6XN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@
M7V%P<%-T86-K('=A<R!M;V1I9FEE9"X*("`@("`J("`@("`@("`@("`@("`@
M("`@4F5T=7)N(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!U<VA!<'`H)&%P<"P@)&-H96-K4&5R;7,@/2!T<G5E*0H@("`@
M>PH@("`@("`@(&EF("@D87!P(#T]("1T:&ES+3Y?8W5R<F5N=$%P<"D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!"86EL(&]U="!I9B!A<'!L:6-A=&EO;B!I<R!N;W0@<')E<V5N="!O<B!I
M;F%C=&EV92X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YA<'!L:6-A
M=&EO;G-;)&%P<%TI('Q\"B`@("`@("`@("`@("1T:&ES+3YA<'!L:6-A=&EO
M;G-;)&%P<%U;)W-T871U<R==(#T]("=I;F%C=&EV92<@?'P*("`@("`@("`@
M("`@*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W-T871U<R==(#T]("=A
M9&UI;B<@)B8@(4%U=&@Z.FES061M:6XH*2DI('L*("`@("`@("`@("`@2&]R
M9&4Z.F9A=&%L*"1A<'`@+B`G(&ES(&YO="!A8W1I=F%T960G+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@<&5R;6ES
M<VEO;G,@8VAE8VMI;F<@:7,@<F5Q=65S=&5D+"!R971U<FX@86X@97)R;W(@
M:68*("`@("`@("`@*B!T:&4@8W5R<F5N="!U<V5R(&1O97,@;F]T(&AA=F4@
M<F5A9"!P97)M<R!T;R!T:&4*("`@("`@("`@*B!A<'!L:6-A=&EO;B!B96EN
M9R!L;V%D960N(%=E(&%L;&]W(&%C8V5S<SH*("`@("`@("`@*@H@("`@("`@
M("`J("`M(%1O(&%L;"!A9&UI;G,N"B`@("`@("`@("H@("T@5&\@86QL(&%U
M=&AE;G1I8V%T960@=7-E<G,@:68@;F\@<&5R;6ES<VEO;B!I<R!S970@;VX@
M)&%P<"X*("`@("`@("`@*B`@+2!4;R!A;GEO;F4@=VAO(&ES(&%L;&]W960@
M8GD@86X@97AP;&EC:70@04-,(&]N("1A<'`N("HO"B`@("`@("`@:68@*"1C
M:&5C:U!E<FUS("8F("$D=&AI<RT^:&%S4&5R;6ES<VEO;B@D87!P*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=5<V5R("5S
M(&1O97,@;F]T(&AA=F4@4D5!1"!P97)M:7-S:6]N(&9O<B`E<R<L($%U=&@Z
M.F=E=$%U=&@H*2P@)&%P<"DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+B(I+"!!=71H.CIG971!=71H*"DL("1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P
M<%U;)VYA;64G72DL("=P97)M:7-S:6]N7V1E;FEE9"<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@26UP;W)T('1H:7,@87!P;&EC871I;VXG<R!C;VYF:6=U
M<F%T:6]N('9A;'5E<RX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3YI
M;7!O<G1#;VYF:6<H)&%P<"D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=6-C97-S
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A9"!P<F5F97)E;F-E<R!A9G1E
M<B!T:&4@8V]N9FEG=7)A=&EO;B!H87,@8F5E;B!L;V%D960@=&\*("`@("`@
M("`@*B!M86ME('-U<F4@=&AE('!R969S(&9I;&4@:&%S(&%L;"!T:&4@:6YF
M;W)M871I;VX@:70@;F5E9',N("HO"B`@("`@("`@)'1H:7,M/FQO8610<F5F
M<R@D87!P*3L*"B`@("`@("`@+RH@4F5S970@=&AE(&QA;F=U86=E(&EN(&-A
M<V4@=&AE<F4@:7,@82!D:69F97)E;G0@;VYE"B`@("`@("`@("H@<V5L96-T
M960@:6X@=&AE('!R969E<F5N8V5S+B`J+PH@("`@("`@("1L86YG=6%G92`]
M("<G.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R969S0V%C:&5;)&%P
M<%TI("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?<')E9G-#86-H95LD
M87!P72T^7W!R969S6R=L86YG=6%G92==*2D@>PH@("`@("`@("`@("`D;&%N
M9W5A9V4@/2`D=&AI<RT^7W!R969S0V%C:&5;)&%P<%TM/F=E=%9A;'5E*"=L
M86YG=6%G92<I.PH@("`@("`@('T*("`@("`@("!.3%,Z.G-E=$QA;F<H)&QA
M;F=U86=E*3L*("`@("`@("!.3%,Z.G-E=%1E>'1D;VUA:6XH)&%P<"P@)'1H
M:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG9FEL97)O;W0G72`N("<O;&]C86QE
M)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@(%-T<FEN9SHZ<V5T1&5F
M875L=$-H87)S970H3DQ3.CIG971#:&%R<V5T*"DI.PH*("`@("`@("`O*B!/
M;F-E('=E(&MN;W<@979E<GET:&EN9R!S=6-C965D960@86YD(&ES(&EN(&$@
M8V]N<VES=&5N=`H@("`@("`@("`J('-T871E(&%G86EN+"!P=7-H('1H92!N
M97<@87!P;&EC871I;VX@;VYT;R!T:&4@<W1A8VLN("HO"B`@("`@("`@)'1H
M:7,M/E]A<'!3=&%C:UM=(#T@)&%P<#L*("`@("`@("`D=&AI<RT^7V-U<G)E
M;G1!<'`@/2`D87!P.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E;6]V92!T:&4@8W5R<F5N="!A<'`@9G)O;2!T:&4@
M87!P;&EC871I;VX@<W1A8VLL('-E='1I;F<@=&AE(&-U<G)E;G0*("`@("`J
M(&%P<"!T;R!W:&EC:&5V97(@87!P('=A<R!C=7)R96YT(&)E9F]R92!T:&ES
M(&]N92!T;V]K(&]V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!T:&%T('=A<R!P;W!P960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!O<$%P<"@I"B`@("!["B`@("`@("`@
M+RH@4&]P('1H92!C=7)R96YT(&%P<&QI8V%T:6]N(&]F9B!O9B!T:&4@<W1A
M8VLN("HO"B`@("`@("`@)'!R979I;W5S(#T@87)R87E?<&]P*"1T:&ES+3Y?
M87!P4W1A8VLI.PH*("`@("`@("`O*B!);7!O<G0@=&AE(&YE=R!A8W1I=F4@
M87!P;&EC871I;VXG<R!C;VYF:6=U<F%T:6]N('9A;'5E<PH@("`@("`@("`J
M(&%N9"!S970@=&AE(&=E='1E>'0@9&]M86EN(&%N9"!T:&4@<')E9F5R<F5D
M(&QA;F=U86=E+B`J+PH@("`@("`@("1T:&ES+3Y?8W5R<F5N=$%P<"`](&-O
M=6YT*"1T:&ES+3Y?87!P4W1A8VLI(#\@96YD*"1T:&ES+3Y?87!P4W1A8VLI
M(#H@;G5L;#L*("`@("`@("!I9B`H)'1H:7,M/E]C=7)R96YT07!P*2!["B`@
M("`@("`@("`@("1T:&ES+3YI;7!O<G1#;VYF:6<H)'1H:7,M/E]C=7)R96YT
M07!P*3L*("`@("`@("`@("`@)'1H:7,M/FQO8610<F5F<R@D=&AI<RT^7V-U
M<G)E;G1!<'`I.PH@("`@("`@("`@("`D;&%N9W5A9V4@/2`D1TQ/0D%,4ULG
M<')E9G,G72T^9V5T5F%L=64H)VQA;F=U86=E)RD["B`@("`@("`@("`@(&EF
M("AI<W-E="@D;&%N9W5A9V4I*2!["B`@("`@("`@("`@("`@("!.3%,Z.G-E
M=$QA;F<H)&QA;F=U86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!.
M3%,Z.G-E=%1E>'1D;VUA:6XH)'1H:7,M/E]C=7)R96YT07!P+"`D=&AI<RT^
M87!P;&EC871I;VYS6R1T:&ES+3Y?8W5R<F5N=$%P<%U;)V9I;&5R;V]T)UT@
M+B`G+VQO8V%L92<L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@
M4W1R:6YG.CIS971$969A=6QT0VAA<G-E="A.3%,Z.F=E=$-H87)S970H*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!R979I;W5S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C=7)R96YT(&%P<&QI8V%T:6]N
M("T@=&AE(&%P<"!A="!T:&4@=&]P(&]F('1H92!A<'!L:6-A=&EO;@H@("`@
M("H@<W1A8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M=7)R96YT(&%P<&QI8V%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!
M<'`H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-U<G)E;G1!<'`[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!P97)M:7-S:6]N<R!O;B!A
M;B!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T(&%C8V5S<R!I<R!A;&QO=V5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1A<'`L("1P97)M:7-S:6]N(#T@
M4$5235-?4D5!1"D*("`@('L*("`@("`@("!R971U<FX@075T:#HZ:7-!9&UI
M;B@I('Q\"B`@("`@("`@("`@("@D1TQ/0D%,4ULG<&5R;7,G72T^97AI<W1S
M*"1A<'`I"B`@("`@("`@("`@("`_("1'3$]"04Q36R=P97)M<R==+3YH87-0
M97)M:7-S:6]N*"1A<'`L($%U=&@Z.F=E=$%U=&@H*2P@)'!E<FUI<W-I;VXI
M"B`@("`@("`@("`@("`Z("AB;V]L*4%U=&@Z.F=E=$%U=&@H*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296%D<R!T:&4@8V]N9FEG=7)A=&EO;B!V86QU
M97,@9F]R('1H92!G:79E;B!A<'!L:6-A=&EO;B!A;F0@:6UP;W)T<PH@("`@
M("H@=&AE;2!I;G1O('1H92!G;&]B86P@)&-O;F8@=F%R:6%B;&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@;F%M92!O9B!T:&4@
M87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&EM<&]R=$-O;F9I9R@D87!P*0H@("`@>PH@("`@("`@
M("\J($1O;B=T(&UA:V4@8V]N9FEG(&9I;&5S(&=L;V)A;"`D<F5G:7-T<GD@
M=&AE;7-E;'9E<RX@*B\*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@
M("`@("`O*B!#86-H92!C;VYF:6<@=F%L=65S('-O('1H870@=V4@9&]N)W0@
M<F4M<F5A9"!F:6QE<R!O;B!E=F5R>0H@("`@("`@("`J('!O<$%P<"@I(&-A
M;&PN("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-O;F9#86-H95LD
M87!P72DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-O;F9#
M86-H95LG:&]R9&4G72DI('L*("`@("`@("`@("`@("`@("1C;VYF(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@("`@
M("`@("`D<W5C8V5S<R`](&EN8VQU9&4@2$]21$5?0D%312`N("<O8V]N9FEG
M+V-O;F8N<&AP)SL*("`@("`@("`@("`@("`@("1E<G)O<G,@/2!O8E]G971?
M8V]N=&5N=',H*3L*("`@("`@("`@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D97)R;W)S*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@
M=&\@:6UP;W)T($AO<F1E(&-O;F9I9W5R871I;VXZ("<@+B!S=')I<%]T86=S
M*"1E<G)O<G,I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&EM<&]R="!(;W)D92!C;VYF
M:6=U<F%T:6]N+B<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\J($EN:71I86P@2&]R9&4M=VED92!S971T:6YG<RX@*B\*"B`@("`@
M("`@("`@("`@("`O*B!3970@=&AE(&5R<F]R(')E<&]R=&EN9R!L979E;"!I
M;B!A8V-O<F1A;F-E('=I=&@*("`@("`@("`@("`@("`@("`J('1H92!C;VYF
M:6<@<V5T=&EN9W,N("HO"B`@("`@("`@("`@("`@("!E<G)O<E]R97!O<G1I
M;F<H)&-O;F9;)V1E8G5G7VQE=F5L)UTI.PH*("`@("`@("`@("`@("`@("\J
M(%-E="!T:&4@;6%X:6UU;2!E>&5C=71I;VX@=&EM92!I;B!A8V-O<F1A;F-E
M('=I=&@*("`@("`@("`@("`@("`@("`J('1H92!C;VYF:6<@<V5T=&EN9W,N
M("HO"B`@("`@("`@("`@("`@("!`<V5T7W1I;65?;&EM:70H)&-O;F9;)VUA
M>%]E>&5C7W1I;64G72D["@H@("`@("`@("`@("`@("`@+RH@4V5T('1H92!U
M;6%S:R!A8V-O<F1I;F<@=&\@8V]N9FEG('-E='1I;F=S+B`J+PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=U;6%S:R==*2D@>PH@("`@("`@
M("`@("`@("`@("`@('5M87-K*"1C;VYF6R=U;6%S:R==*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1C;VYF(#T@)'1H:7,M/E]C;VYF0V%C:&5;)VAO<F1E)UT["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D87!P("$]/2`G:&]R9&4G*2!["B`@
M("`@("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("`@("`@)'-U
M8V-E<W,@/2!I;F-L=61E("1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)V9I
M;&5R;V]T)UT@+B`G+V-O;F9I9R]C;VYF+G!H<"<["B`@("`@("`@("`@("`@
M("`D97)R;W)S(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@("`@("`@
M("!O8E]E;F1?8VQE86XH*3L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)&5R<F]R<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G1F%I;&5D('1O(&EM<&]R="!A<'!L:6-A=&EO;B!C;VYF
M:6=U<F%T:6]N(&9O<B`G("X@)&%P<"`N("<Z("<@+B!S=')I<%]T86=S*"1E
M<G)O<G,I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@A)'-U8V-E<W,I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&EM<&]R="!A<'!L:6-A=&EO;B!C
M;VYF:6=U<F%T:6]N(&9O<B`G("X@)&%P<"D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5687)S
M*&%R<F%Y*"=?8V]N9D-A8VAE)RDI.PH*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYF0V%C:&5;)&%P<%T@/2`F)&-O;F8["B`@("`@("`@?0H*("`@("`@("`D
M1TQ/0D%,4ULG8V]N9B==(#T@)B1T:&ES+3Y?8V]N9D-A8VAE6R1A<'!=.PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A
M9',@=&AE('!R969E<F5N8V5S(&9O<B!T:&4@8W5R<F5N="!U<V5R(&9O<B!T
M:&4@8W5R<F5N="!A<'!L:6-A=&EO;@H@("`@("H@86YD(&EM<&]R=',@=&AE
M;2!I;G1O('1H92!G;&]B86P@)'!R969S('9A<FEA8FQE+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&YA;64@;V8@=&AE(&%P<&QI
M8V%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V%D4')E9G,H)&%P<"`]
M(&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1P<F5F<U]D969A=6QT(#T@
M9F%L<V4["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4')E9G,N<&AP
M)SL*"B`@("`@("`@:68@*"1A<'`@/3T](&YU;&PI('L*("`@("`@("`@("`@
M)&%P<"`]("1T:&ES+3Y?8W5R<F5N=$%P<#L*("`@("`@("!]"@H@("`@("`@
M("\J($EF('1H97)E(&ES(&YO(&QO9V=E9"!I;B!U<V5R+"!R971U<FX@86X@
M96UP='D@4')E9G,Z.@H@("`@("`@("`J(&]B:F5C="!W:71H(&IU<W0@9&5F
M875L="!P<F5F97)E;F-E<RX@*B\*("`@("`@("!I9B`H(4%U=&@Z.F=E=$%U
M=&@H*2D@>PH@("`@("`@("`@("`D<')E9G,@/2`F4')E9G,Z.F9A8W1O<GDH
M)W-E<W-I;VXG+"`D87!P+"`G)RP@)R<L(&YU;&PL(&9A;'-E*3L*("`@("`@
M("`@("`@)'!R969S+3YR971R:65V92@I.PH@("`@("`@("`@("`D=&AI<RT^
M7W!R969S0V%C:&5;)&%P<%T@/2`F)'!R969S.PH@("`@("`@("`@("`D1TQ/
M0D%,4ULG<')E9G,G72`]("8D=&AI<RT^7W!R969S0V%C:&5;)&%P<%T["B`@
M("`@("`@("`@("1P<F5F<U]D969A=6QT(#T@=')U93L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@0V%C:&4@<')E9G,@;V)J
M96-T<R!S;R!T:&%T('=E(&1O;B=T(')E+6QO860@=&AE;2!O;B!E=F5R>0H@
M("`@("`@("`J('!O<$%P<"@I(&-A;&PN("HO"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!R969S0V%C:&5;)&%P<%TI('Q\"B`@("`@("`@("`@("%E
M;7!T>2@D<')E9G-?9&5F875L="DI('L*("`@("`@("`@("`@)'!R969S(#T@
M)E!R969S.CIF86-T;W)Y*"1'3$]"04Q36R=C;VYF)UU;)W!R969S)UU;)V1R
M:79E<B==+"`D87!P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@075T:#HZ9V5T075T:"@I+"!!=71H.CIG971#<F5D96YT:6%L*"=P
M87-S=V]R9"<I*3L*("`@("`@("`@("`@)'!R969S+3YR971R:65V92@I.PH@
M("`@("`@("`@("`D=&AI<RT^7W!R969S0V%C:&5;)&%P<%T@/2`F)'!R969S
M.PH@("`@("`@('T*"B`@("`@("`@)$=,3T)!3%-;)W!R969S)UT@/2`F)'1H
M:7,M/E]P<F5F<T-A8VAE6R1A<'!=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M56YL;V%D('!R969E<F5N8V5S(&9R;VT@86X@87!P;&EC871I;VX@;W(@*&EF
M(&YO(&%P<&QI8V%T:6]N(&ES"B`@("`@*B!S<&5C:69I960I(&9R;VT@04Q,
M(&%P<&QI8V%T:6]N<RX@57-E9G5L('=H96X@82!U<V5R(&AA<R!L;V=G960*
M("`@("`J(&]U="!B=70@>6]U(&YE960@=&\@8V]N=&EN=64@;VX@=&AE('-A
M;64@<&%G92P@971C+@H@("`@("H*("`@("`J($%F=&5R('5N;&]A9&EN9RP@
M:68@=&AE<F4@:7,@86X@87!P;&EC871I;VX@;VX@=&AE(&%P<"!S=&%C:R!T
M;PH@("`@("H@;&]A9"!P<F5F97)E;F-E<R!F<F]M+"!T:&5N('=E(')E;&]A
M9"!A(&9R97-H('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U;FQO860@<')E9G)E;F-E<R!F;W(N
M($EF(&YU;&PL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($%,3"!P<F5F
M97)E;F-E<R!A<F4@<F5S970N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N;&]A
M9%!R969S*"1A<'`@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D87!P(#T]
M/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-#86-H92`](&%R
M<F%Y*"D["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?<')E9G-#
M86-H95LD87!P72DI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P<F5F
M<T-A8VAE6R1A<'!=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]C=7)R96YT
M07!P*2!["B`@("`@("`@("`@("1T:&ES+3YL;V%D4')E9G,H*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(')E<75E<W1E
M9"!C;VYF:6=U<F%T:6]N('!A<F%M971E<B!F;W(@=&AE('-P96-I9FEE9`H@
M("`@("H@87!P;&EC871I;VXN($EF(&YO(&%P<&QI8V%T:6]N(&ES('-P96-I
M9FEE9"P@=&AE('9A;'5E(&]F"B`@("`@*B`D=&AI<RT^7V-U<G)E;G1!<'`@
M*'1H92!C=7)R96YT(&%P<&QI8V%T:6]N*2!I<R!U<V5D+B!(;W=E=F5R+`H@
M("`@("H@:68@=&AE('!A<F%M971E<B!I<R!N;W0@<')E<V5N="!F;W(@=&AA
M="!A<'!L:6-A=&EO;BP@=&AE"B`@("`@*B!(;W)D92UW:61E('9A;'5E(&ES
M('5S960@:6YS=&5A9"X@268@=&AA="!I<R!N;W0@<')E<V5N="P@=V4*("`@
M("`J(')E='5R;B!N=6QL+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<F%M971E<B`@5&AE(&-O;F9I9W5R871I;VX@=F%L=64@=&\@<F5T<FEE
M=F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@("`@(%1H92!A<'!L
M:6-A=&EO;B!T;R!G970@=&AE('9A;'5E(&9O<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(')E<75E<W1E9"!P87)A;65T97(L(&]R(&YU
M;&P@:68@:70@:7,@;F]T('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M*"1P87)A;65T97(L("1A<'`@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI
M<U]N=6QL*"1A<'`I*2!["B`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7V-U
M<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F%P<&QI8V%T:6]N<ULD87!P75LD<&%R86UE=&5R72DI('L*("`@("`@("`@
M("`@)'!V86P@/2`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R1P87)A;65T
M97)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D<&%R86UE
M=&5R(#T]("=I8V]N)RD@>PH@("`@("`@("`@("`@("`@)'!V86P@/2`D=&AI
M<RT^7V=E=$EC;VXH)&%P<"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<'9A;"`](&ES<V5T*"1T:&ES+3YA<'!L:6-A=&EO;G-;
M)VAO<F1E)UU;)'!A<F%M971E<ETI(#\@)'1H:7,M/F%P<&QI8V%T:6]N<ULG
M:&]R9&4G75LD<&%R86UE=&5R72`Z(&YU;&P["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D<&%R86UE=&5R(#T]("=N86UE)RD@>PH@
M("`@("`@("`@("!R971U<FX@7R@D<'9A;"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1P=F%L.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($9U;F-T:6]N('1O('=O<FL@;W5T(&%N(&%P<&QI8V%T
M:6]N)W,@9W)A<&AI8W,@55))+"!T86MI;F<@:6YT;R!A8V-O=6YT"B`@("`@
M*B!A;GD@=&AE;65S(&1I<F5C=&]R:65S('1H870@;6%Y(&)E('-E="!U<"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A
M=&EO;B!F;W(@=VAI8V@@=&\@9V5T('1H92!I;6%G90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!D:7)E8W1O<GDN($EF(&)L86YK('=I;&P@9&5F875L
M="!T;R!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&%P<&QI
M8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:6UA
M9V4@9&ER96-T;W)Y('5R:2!P871H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971);6%G941I<B@D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)&%P<"DI('L*("`@("`@("`@("`@)&%P<"`]("1T:&ES+3Y?8W5R<F5N
M=$%P<#L*("`@("`@("!]"@H@("`@("`@('-T871I8R`D:6UG7V1I<B`](&%R
M<F%Y*"D["B`@("`@("`@:68@*&ES<V5T*"1I;6=?9&ER6R1A<'!=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&EM9U]D:7);)&%P<%T["B`@("`@("`@?0H*
M("`@("`@("`O*B!4:&ES(&ES('1H92!D969A=6QT(&QO8V%T:6]N(&9O<B!T
M:&4@9W)A<&AI8W,N("HO"B`@("`@("`@)&EM9U]D:7);)&%P<%T@/2`D=&AI
M<RT^9V5T*"=T:&5M97-U<FDG+"`D87!P*2`N("<O9W)A<&AI8W,G.PH*("`@
M("`@("!S=&%T:6,@)'1H96UE7VEC;VYS.PH*("`@("`@("`O*B!&:6=U<F4@
M;W5T(&EF('1H:7,@:7,@9V]I;F<@=&\@8F4@;W9E<G)I9&1E;B!B>2!A;GD@
M=&AE;64*("`@("`@("`@*B!S971T:6YG<RX@*B\*("`@("`@("!I9B`H:7-S
M970H)$=,3T)!3%-;)W!R969S)UTI("8F"B`@("`@("`@("`@("@D=&AE;64@
M/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W1H96UE)RDI("8F"B`@
M("`@("`@("`@("AI<W-E="@D=&AE;65?:6-O;G,I('Q\"B`@("`@("`@("`@
M("`H*$!I;F-L=61E("1T:&ES+3YG970H)W1H96UE<V9S)RP@)VAO<F1E)RD@
M+B`G+R<@+B`D=&AE;64@+B`G+VEN9F\N<&AP)RD@)B8*("`@("`@("`@("`@
M("!I<W-E="@D=&AE;65?:6-O;G,I*2D@)B8*("`@("`@("`@("`@:6Y?87)R
M87DH)&%P<"P@)'1H96UE7VEC;VYS*2D@>PH@("`@("`@("`@("`D:6UG7V1I
M<ELD87!P72`]("1T:&ES+3YG970H)W1H96UE<W5R:2<L("1A<'`I("X@)R\G
M("X@)'1H96UE("X@)R]G<F%P:&EC<R<["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&EM9U]D:7);)&%P<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!P871H('1O(&%N(&%P<&QI8V%T:6]N)W,@:6-O;BP@<F5S
M<&5C=&EN9R!W:&5T:&5R('1H90H@("`@("H@8W5R<F5N="!T:&5M92!H87,@
M:71S(&]W;B!I8V]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A
M=&EO;B!F;W(@=VAI8V@@=&\@9V5T('1H92!I8V]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T26-O;B@D87!P*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9V5T26UA9V5$:7(H)&%P<"D@+B`G+R<@+B`D87!P("X@)RYP;F<G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@475E<GD@=&AE(&EN:71I86P@<&%G
M92!F;W(@86X@87!P;&EC871I;VX@+2!T:&4@=V5B<F]O="P@:68@=&AE<F4@
M:7,@;F\*("`@("`J(&EN:71I86Q?<&%G92!S970L(&%N9"!T:&4@:6YI=&EA
M;%]P86=E+"!I9B!I="!I<R!S970N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D87!P("!4:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VXN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%523"!P;VEN=&EN9R!T;R!T:&4@
M:6YI=&%L('!A9V4@;V8@=&AE(&%P<&QI8V%T:6]N+@H@("`@("H@("`@("`@
M("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T26YI=&EA;%!A9V4H)&%P<"`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)&%P<"DI('L*("`@("`@("`@("`@
M)&%P<"`]("1T:&ES+3Y?8W5R<F5N=$%P<#L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P72DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")<
M(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y
M+B(I+"`D87!P*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^
M87!P;&EC871I;VYS6R1A<'!=6R=W96)R;V]T)UT@+B`G+R<@+B`H:7-S970H
M)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG:6YI=&EA;%]P86=E)UTI(#\@
M)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG:6YI=&EA;%]P86=E)UT@.B`G
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]?9V5T*"1A<&DI"B`@("!["B`@("`@("`@
M:68@*&EN7V%R<F%Y*"1A<&DL("1T:&ES+3YL:7-T05!)<R@I*2D@>PH@("`@
M("`@("`@("!R971U<FX@;F5W(%)E9VES=')Y0V%L;&5R*"1T:&ES+"`D87!I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]N92!S:&]U
M;&0@;F5V97(@8F4@8V%L;&5D(&]N(%)E9VES=')Y(&]B:F5C=',N($EF(&ET
M(&ES+"!D:64N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("HO"B`@("!F=6YC=&EO;B!?7V-L;VYE*"D*("`@('L*("`@("`@("!(;W)D
M93HZ9F%T86PH)U)E9VES=')Y(&]B:F5C=',@<VAO=6QD(&YE=F5R(&)E(&-L
M;VYE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@?0H*?0H*+RHJ"B`J
M($!P86-K86=E($AO<F1E7T9R86UE=V]R:PH@*B!`<VEN8V4@2&]R9&4@,RXQ
M"B`J+PIC;&%S<R!296=I<W1R>4-A;&QE<B!["@H@("`@=F%R("1R96=I<W1R
M>3L*("`@('9A<B`D87!I.PH*("`@(&9U;F-T:6]N(%]?8V]N<W1R=6-T*"1R
M96=I<W1R>2P@)&%P:2D*("`@('L*("`@("`@("`D=&AI<RT^<F5G:7-T<GD@
M/2`D<F5G:7-T<GD["B`@("`@("`@)'1H:7,M/F%P:2`]("1A<&D["B`@("!]
M"@H@("`@9G5N8W1I;VX@7U]C86QL*"1M971H;V0L("1A<F=S*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F5G:7-T<GDM/F-A;&PH)'1H:7,M/F%P
M:2`N("<O)R`N("1M971H;V0L("1A<F=S*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,N<&AP````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-3(W`#$P-3$U-#,Q
M,#8Q`#`R,#4S,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-O;7!R97-S.CH@8VQA
M<W,@<')O=FED97,@86X@05!)(&9O<B!V87)I;W5S(&-O;7!R97-S:6]N"B`J
M('1E8VAN:7%U97,@=&AA="!C86X@8F4@=7-E9"!B>2!(;W)D92!A<'!L:6-A
M=&EO;G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+G!H<"QV(#$N-RXQ,BXQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C$Q(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S
M<R!["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC
M<F5T92!(;W)D95]#;VUP<F5S<R!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R
M+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP
M92!O9B!C;VYC<F5T92!(;W)D95]#;VUP<F5S<R!S=6)C;&%S<R!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I
M<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#;VUP<F5S<R\@9F]R
M('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM
M<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I
M=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T-O;7!R97-S("!4:&4@;F5W;'D@
M8W)E871E9"!C;VYC<F5T92!(;W)D95]#;VUP<F5S<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@:6YS=&%N8V4L(&]R(&9A;'-E(&]N(&%N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)&1R:79E<BDI('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I=F5R*2`]
M("1D<FEV97(["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA
M;64H)&1R:79E<BD["@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("1A<'`@+B`G+VQI8B]#;VUP<F5S<R\G
M("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?
M97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]#;VUP<F5S<R\G("X@)&1R
M:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]#;VUP<F5S<R\G("X@)&1R:79E<B`N("<N
M<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O
M;F-E("=(;W)D92]#;VUP<F5S<R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#;VUP<F5S<U\G("X@
M)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*
M("`@("`@("`@("`@)&-O;7!R97-S(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;7!R97-S(#T@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;7!R97-S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E
M;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,@:6YS=&%N8V4*("`@
M("`J(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N
M97<@:6YS=&%N8V4@:68@;F\*("`@("`J($AO<F1E7T-O;7!R97-S(&EN<W1A
M;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A
M<SH*("`@("`J("`@)'9A<B`]("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE=&]N
M*"D["B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%-E92!(
M;W)D95]#;VUP<F5S<SHZ9F%C=&]R>2@I+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@(%-E92!(;W)D95]#;VUP<F5S<SHZ9F%C=&]R>2@I+@H@("`@
M("H*("`@("`J($!R971U<FX@2&]R9&5?0V]M<')E<W,@(%1H92!C;VYC<F5T
M92!(;W)D95]#;VUP<F5S<R!R969E<F5N8V4L(&]R(&9A;'-E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!O;B!A;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y
M*"D["@H@("`@("`@("1S:6=N871U<F4@/2!M9#4H<V5R:6%L:7IE*&%R<F%Y
M*"1D<FEV97(L("1P87)A;7,I*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS
M=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S
M6R1S:6=N871U<F5=(#T@)DAO<F1E7T-O;7!R97-S.CIF86-T;W)Y*"1D<FEV
M97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T
M86YC97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M4&%R86UE=&5R(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]#
M;VUP<F5S<R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;7!R97-S('1H92!D871A+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!C;VUP<F5S<RX*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!O9B!A<F=U;65N
M=',@;F5E9&5D('1O(&-O;7!R97-S('1H92!D871A+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1H92!C;VUP<F5S<V5D(&1A=&$N"B`@("`@*B`@
M("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUP<F5S<R@D9&%T82P@)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U5N<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$96-O;7!R97-S('1H92!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!D96-O;7!R97-S+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y(&]F(&%R9W5M96YT<R!N
M965D960@=&\@9&5C;VUP<F5S<R!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H
M92!D96-O;7!R97-S960@9&%T82X*("`@("`J("`@("`@("`@("`@("`@(%)E
M='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1E8V]M<')E<W,H)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U
M<'!O<G1E9"<I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M3DQ3+G!H<```````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#0P,S8T`#$P-3$U-#,Q,#8Q`#`Q-S,W,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($Y,
M4SHZ(&-L87-S('!R;W9I9&5S($YA=&EV92!,86YG=6%G92!3=7!P;W)T+B!4
M:&ES(&EN8VQU9&5S(&-O;6UO;@H@*B!M971H;V1S(&9O<B!H86YD;&EN9R!L
M86YG=6%G92!D971E8W1I;VX@86YD('-E;&5C=&EO;BP@=&EM97IO;F5S+"!A
M;F0*("H@:&]S=&YA;64M/F-O=6YT<GD@;&]O:W5P<RX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO3DQ3+TY,4RYP:'`L=B`Q+C@R+C0N,3,@,C`P-B\P,2\R
M-"`P-SHU,#HR-B!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D
M92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7TY,4PH@*B\*8VQA<W,@3DQ3('L*"B`@("`O*BH*("`@("`J(%-E;&5C
M=',@=&AE(&UO<W0@<')E9F5R<F5D(&QA;F=U86=E(&9O<B!T:&4@8W5R<F5N
M="!C;&EE;G0@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('-E;&5C=&5D(&QA;F=U86=E(&%B8G)E=FEA=&EO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5L96-T*"D*("`@('L*("`@("`@("!G;&]B86P@
M)&YL<RP@)'!R969S.PH*("`@("`@("`D;&%N9R`](%5T:6PZ.F=E=$9O<FU$
M871A*"=N97=?;&%N9R<I.PH*("`@("`@("`O*B!&:7)S="P@8VAE8VL@:68@
M;&%N9W5A9V4@<')E9B!I<R!L;V-K960@86YD+"!I9B!S;RP@<V5T(&ET('1O
M(&ET<PH@("`@("`@("`@('9A;'5E("HO"B`@("`@("`@:68@*&ES<V5T*"1P
M<F5F<RD@)B8@)'!R969S+3YI<TQO8VME9"@G;&%N9W5A9V4G*2D@>PH@("`@
M("`@("`@("`D;&%N9W5A9V4@/2`D<')E9G,M/F=E=%9A;'5E*"=L86YG=6%G
M92<I.PH@("`@("`@("\J($-H96-K(&EF('1H92!U<V5R('-E;&5C=&5D(&$@
M;&%N9W5A9V4@9G)O;2!T:&4@;&]G:6X@<V-R965N("HO"B`@("`@("`@?2!E
M;'-E:68@*"%E;7!T>2@D;&%N9RDI('L*("`@("`@("`@("`@)&QA;F=U86=E
M(#T@)&QA;F<["B`@("`@("`@+RH@0VAE8VL@:68@=V4@:&%V92!A(&QA;F=U
M86=E('-E="!I;B!A(&-O;VMI92`J+PH@("`@("`@('T@96QS96EF("AI<W-E
M="@D7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UTI*2!["B`@("`@("`@("`@
M("1L86YG=6%G92`]("1?4T534TE/3ELG:&]R9&5?;&%N9W5A9V4G73L*("`@
M("`@("`O*B!5<V4@<VET92UW:61E(&1E9F%U;'0L(&EF(&]N92!I<R!D969I
M;F5D("HO"B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D;FQS6R=D969A=6QT
M<R==6R=L86YG=6%G92==*2D@>PH@("`@("`@("`@("`D;&%N9W5A9V4@/2`D
M;FQS6R=D969A=6QT<R==6R=L86YG=6%G92==.PH@("`@("`@("\J(%1R>2!B
M<F]W<V5R+6%C8V5P=&5D(&QA;F=U86=E<RX@*B\*("`@("`@("!](&5L<V5I
M9B`H(65M<'1Y*"1?4T525D526R=(5%107T%#0T505%],04Y'54%'12==*2D@
M>PH@("`@("`@("`@("`O*B!4:&4@8G)O=W-E<B!S=7!P;&EE<R!A(&QI<W0L
M('-O(')E='5R;B!T:&4@9FER<W0@=F%L:60@;VYE+B`J+PH@("`@("`@("`@
M("`D8G)O=W-E<E]L86YG<R`](&5X<&QO9&4H)RPG+"`D7U-%4E9%4ELG2%14
M4%]!0T-%4%1?3$%.1U5!1T4G72D["B`@("`@("`@("`@(&9O<F5A8V@@*"1B
M<F]W<V5R7VQA;F=S(&%S("1L86YG*2!["B`@("`@("`@("`@("`@("`O*B!3
M=')I<"!Q=6%L:71Y('9A;'5E(&9O<B!L86YG=6%G92`J+PH@("`@("`@("`@
M("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1L86YG+"`G.R<I*2`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@("`@("`@("`D;&%N9R`]('-U8G-T<B@D;&%N
M9RP@,"P@)'!O<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D;&%N9R`]($Y,4SHZ7VUA<"AT<FEM*"1L86YG*2D["B`@("`@("`@("`@
M("`@("!I9B`H3DQ3.CII<U9A;&ED*"1L86YG*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1L86YG=6%G92`]("1L86YG.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+RH@
M26X@8V%S92!N;R!F=6QL(&UA=&-H+"!S879E(&)E<W0@9W5E<W,@8F%S960@
M;VX@<')E9FEX("HO"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)T
M:6%L7VQA;F<I("8F"B`@("`@("`@("`@("`@("`@("`@3DQ3.CII<U9A;&ED
M*$Y,4SHZ7VUA<"AS=6)S='(H)&QA;F<L(#`L(#(I*2DI('L*("`@("`@("`@
M("`@("`@("`@("`D<&%R=&EA;%]L86YG(#T@3DQ3.CI?;6%P*'-U8G-T<B@D
M;&%N9RP@,"P@,BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1L86YG=6%G92DI('L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T:6%L7VQA;F<I*2!["B`@("`@
M("`@("`@("`@("`D;&%N9W5A9V4@/2`D<&%R=&EA;%]L86YG.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@3F\@9&EC92!A=71O
M+61E=&5C=&EN9RP@9&5F875L="!T;R!54R!%;F=L:7-H+B`J+PH@("`@("`@
M("`@("`@("`@)&QA;F=U86=E(#T@)V5N7U53)SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&)A<V5N86UE*"1L86YG=6%G92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!L86YG=6%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86YG("!4:&4@;&%N9W5A9V4@
M86)B<F5V:6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,86YG*"1L
M86YG(#T@;G5L;"D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@2$]21$5?
M0D%312`N("<O8V]N9FEG+VYL<RYP:'`G.PH*("`@("`@("!I9B`H96UP='DH
M)&QA;F<I('Q\("%.3%,Z.FES5F%L:60H)&QA;F<I*2!["B`@("`@("`@("`@
M("1L86YG(#T@3DQ3.CIS96QE8W0H*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<W-E="@D1TQ/0D%,4ULG;&%N9W5A9V4G72DI('L*("`@("`@("`@("`@
M:68@*"1'3$]"04Q36R=L86YG=6%G92==(#T]("1L86YG*2!["B`@("`@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8VQE87)#86-H92@I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D1TQ/0D%,4ULG;&%N
M9W5A9V4G72`]("1L86YG.PH@("`@("`@("1?4T534TE/3ELG:&]R9&5?;&%N
M9W5A9V4G72`]("1L86YG.PH*("`@("`@("`O*B!&:7)S="!T<GD@;&%N9W5A
M9V4@=VET:"!T:&4@8W5R<F5N="!C:&%R<V5T+B`J+PH@("`@("`@("1L86YG
M7V-H87)S970@/2`D;&%N9R`N("<N)R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@
M("`@("`@(&EF("@D;&%N9U]C:&%R<V5T("$]('-E=&QO8V%L92A,0U]!3$PL
M("1L86YG7V-H87)S970I*2!["B`@("`@("`@("`@("\J($YE>'0@=')Y(&QA
M;F=U86=E('=I=&@@:71S(&1E9F%U;'0@8VAA<G-E="X@*B\*("`@("`@("`@
M("`@9VQO8F%L("1N;',["B`@("`@("`@("`@("1C:&%R<V5T(#T@(65M<'1Y
M*"1N;'-;)V-H87)S971S)UU;)&QA;F==*2`_("1N;'-;)V-H87)S971S)UU;
M)&QA;F==(#H@)TE33RTX.#4Y+3$G.PH@("`@("`@("`@("`D;&%N9U]C:&%R
M<V5T(#T@)&QA;F<@+B`G+B<@+B`D8VAA<G-E=#L*("`@("`@("`@("`@3DQ3
M.CI?8V%C:&5D0VAA<G-E="@P+"`D8VAA<G-E="D["B`@("`@("`@("`@(&EF
M("@D;&%N9U]C:&%R<V5T("$]('-E=&QO8V%L92A,0U]!3$PL("1L86YG7V-H
M87)S970I*2!["B`@("`@("`@("`@("`@("`O*B!!="!L87-T('1R>2!L86YG
M=6%G92!S;VQE;'DN("HO"B`@("`@("`@("`@("`@("`D;&%N9U]C:&%R<V5T
M(#T@)&QA;F<["B`@("`@("`@("`@("`@("!S971L;V-A;&4H3$-?04Q,+"`D
M;&%N9U]C:&%R<V5T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!`<'5T96YV*"=,04Y'/2<@+B`D;&%N9U]C:&%R<V5T*3L*("`@("`@("!`
M<'5T96YV*"=,04Y'54%'13TG("X@)&QA;F=?8VAA<G-E="D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S('1H92!G971T97AT(&1O;6%I;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@("`@(%1H92!A<'!L:6-A
M=&EO;B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER96-T;W)Y("!4
M:&4@9&ER96-T;W)Y('=H97)E('1H92!A<'!L:6-A=&EO;B=S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@($Q#7TU%4U-!1T53(&1I<F5C=&]R
M>2!R97-I9&5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("!4
M:&4@8VAA<G-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&5X=&1O;6%I
M;B@D87!P+"`D9&ER96-T;W)Y+"`D8VAA<G-E="D*("`@('L*("`@("`@("!B
M:6YD=&5X=&1O;6%I;B@D87!P+"`D9&ER96-T;W)Y*3L*("`@("`@("!T97AT
M9&]M86EN*"1A<'`I.PH*("`@("`@("`O*B!4:&4@97AI<W1E;F-E(&]F('1H
M:7,@9G5N8W1I;VX@9&5P96YD<R!O;B!T:&4@<&QA=&9O<FTN("HO"B`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G8FEN9%]T97AT9&]M86EN7V-O9&5S
M970G*2D@>PH@("`@("`@("`@("!.3%,Z.E]C86-H961#:&%R<V5T*#`L(&)I
M;F1?=&5X=&1O;6%I;E]C;V1E<V5T*"1A<'`L("1C:&%R<V5T*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(6AE861E<G-?<V5N="@I*2!["B`@("`@("`@
M("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+VAT;6P[(&-H87)S970]
M)R`N("1C:&%R<V5T*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S('=H971H97(@=&AE('-U<'!L:65D(&QA;F=U86=E(&ES
M('9A;&ED+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA;F=U86=E
M("!4:&4@86)B<F5V:6%T960@;F%M92!O9B!T:&4@;&%N9W5A9V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!L86YG=6%G
M92!I<R!V86QI9"P@9F%L<V4@:68@:70G<R!N;W0*("`@("`J("`@("`@("`@
M("`@("`@("`@=F%L:60@;W(@=6YK;F]W;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-686QI9"@D;&%N9W5A9V4I"B`@("!["B`@("`@("`@<F5T=7)N("%E
M;7!T>2@D1TQ/0D%,4ULG;FQS)UU;)VQA;F=U86=E<R==6R1L86YG=6%G95TI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P<R!L86YG=6%G97,@=VET:"!C
M;VUM;VX@='=O+6QE='1E<B!C;V1E<R`H<W5C:"!A<R!N;"D@=&\@=&AE"B`@
M("`@*B!F=6QL(&=E='1E>'0@8V]D92`H:6X@=&AI<R!C87-E+"!N;%].3"DN
M(%)E='5R;G,@=&AE(&QA;F=U86=E"B`@("`@*B!U;FUO9&EF:65D(&EF(&ET
M(&ES;B=T(&%N(&%L:6%S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA;F=U86=E("!4:&4@
M;&%N9W5A9V4@8V]D92!T;R!M87`N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!M87!P960@;&%N9W5A9V4@8V]D92X*("`@("`J+PH*("`@
M(&9U;F-T:6]N(%]M87`H)&QA;F=U86=E*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@H@("`@("`@("1A;&EA<V5S
M(#T@)B1'3$]"04Q36R=N;',G75LG86QI87-E<R==.PH*("`@("`@("`O+R!4
M<F%N<VQA=&4@=&AE("1L86YG=6%G92!T;R!G970@8G)O861E<B!M871C:&5S
M+@H@("`@("`@("\O("AE9RX@9&4M1$4@<VAO=6QD(&UA=&-H(&1E7T1%*0H@
M("`@("`@("1T<F%N<U]L86YG(#T@<W1R7W)E<&QA8V4H)RTG+"`G7R<L("1L
M86YG=6%G92D["B`@("`@("`@)&QA;F=?<&%R=',@/2!E>'!L;V1E*"=?)RP@
M)'1R86YS7VQA;F<I.PH@("`@("`@("1T<F%N<U]L86YG(#T@4W1R:6YG.CIL
M;W=E<B@D;&%N9U]P87)T<ULP72D["B`@("`@("`@:68@*&ES<V5T*"1L86YG
M7W!A<G1S6S%=*2D@>PH@("`@("`@("`@("`D=')A;G-?;&%N9R`N/2`G7R<@
M+B!3=')I;F<Z.G5P<&5R*"1L86YG7W!A<G1S6S%=*3L*("`@("`@("!]"@H@
M("`@("`@("\O(%-E92!I9B!W92!G970@82!M871C:"!F;W(@=&AI<PH@("`@
M("`@(&EF("@A96UP='DH)&%L:6%S97-;)'1R86YS7VQA;F==*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&%L:6%S97-;)'1R86YS7VQA;F==.PH@("`@("`@
M('T*"B`@("`@("`@+R\@268@=V4@9V5T('1H870@9F%R(&1O=VXL('1H92!L
M86YG=6%G92!C86YN;W0@8F4@9F]U;F0N"B`@("`@("`@+R\@4F5T=7)N("1T
M<F%N<U]L86YG+@H@("`@("`@(')E='5R;B`D=')A;G-?;&%N9SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)S970@9F]R('1H92!C
M=7)R96YT(&QA;F=U86=E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1O<FEG:6YA;"`@268@=')U92!R971U<FYS('1H92!O<FEG:6YA;"!C:&%R
M<V5T(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M<F%N<VQA=&EO;BP@=&AE(&%C='5A;&QY('5S960@;VYE(&]T:&5R=VES92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-H87)A8W1E<B!S
M970@=&AA="!S:&]U;&0@8F4@=7-E9"!W:71H('1H92!C=7)R96YT"B`@("`@
M*B`@("`@("`@("`@("`@("`@;&]C86QE('-E='1I;F=S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971#:&%R<V5T*"1O<FEG:6YA;"`](&9A;'-E*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D;&%N9W5A9V4L("1N;',["@H@("`@("`@("\J
M($=E="!C86-H960@<F5S=6QT<RX@*B\*("`@("`@("`D8V%C:&5+97D@/2!I
M;G1V86PH)&]R:6=I;F%L*3L*("`@("`@("`D8VAA<G-E="`]($Y,4SHZ7V-A
M8VAE9$-H87)S970H)&-A8VAE2V5Y*3L*("`@("`@("!I9B`H(6ES7VYU;&PH
M)&-H87)S970I*2!["B`@("`@("`@("`@(')E='5R;B`D8VAA<G-E=#L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D;W)I9VEN86PI('L*("`@("`@("`@("`@
M)&-H87)S970@/2!E;7!T>2@D;FQS6R=C:&%R<V5T<R==6R1L86YG=6%G95TI
M(#\@)TE33RTX.#4Y+3$G(#H@)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O0G)O=W-E<BYP:'`G.PH@("`@("`@("`@("`D8G)O=W-E<B`]("9"
M<F]W<V5R.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@("`@(&EF("@D8G)O=W-E
M<BT^:&%S1F5A='5R92@G=71F)RD@)B8*("`@("`@("`@("`@("`@("A5=&EL
M.CIE>'1E;G-I;VY%>&ES=',H)VEC;VYV)RD@?'P*("`@("`@("`@("`@("`@
M("!5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VUB<W1R:6YG)RDI*2!["B`@("`@
M("`@("`@("`@("`D8VAA<G-E="`]("=55$8M."<["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@
M("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T17AT97)N86Q#:&%R<V5T
M*"D["B`@("`@("`@?0H*("`@("`@("!.3%,Z.E]C86-H961#:&%R<V5T*"1C
M86-H94ME>2P@)&-H87)S970I.PH@("`@("`@(')E='5R;B`D8VAA<G-E=#L*
M("`@('T*"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT(&-H
M87)S970@;V8@=&AE(&5N=FER;VYM96YT"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!C:&%R86-T97(@<V5T('1H870@<VAO=6QD(&)E('5S
M960@=VET:"!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@(&QO
M8V%L92!S971T:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T17AT97)N
M86Q#:&%R<V5T*"D*("`@('L*("`@("`@("!G;&]B86P@)&QA;F=U86=E+"`D
M;FQS.PH*("`@("`@("`O*B!'970@8V%C:&5D(')E<W5L=',N("HO"B`@("`@
M("`@)&-H87)S970@/2!.3%,Z.E]C86-H961#:&%R<V5T*#(I.PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@<F5T=7)N
M("1C:&%R<V5T.PH@("`@("`@('T*"B`@("`@("`@)&QA;F=?8VAA<G-E="`]
M('-E=&QO8V%L92A,0U]!3$PL(#`I.PH@("`@("`@(&EF("AS=')P;W,H)&QA
M;F=?8VAA<G-E="P@)SLG*2`]/3T@9F%L<V4@)B8*("`@("`@("`@("`@<W1R
M<&]S*"1L86YG7V-H87)S970L("<O)RD@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@("1L86YG7V-H87)S970@/2!E>'!L;V1E*"<N)RP@)&QA;F=?8VAA<G-E
M="D["B`@("`@("`@("`@(&EF("@H8V]U;G0H)&QA;F=?8VAA<G-E="D@/3T@
M,BD@)B8@(65M<'1Y*"1L86YG7V-H87)S971;,5TI*2!["B`@("`@("`@("`@
M("`@("!.3%,Z.E]C86-H961#:&%R<V5T*#(L("1L86YG7V-H87)S971;,5TI
M.PH@("`@("`@("`@("`@("`@<F5T=7)N("1L86YG7V-H87)S971;,5T["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H(65M<'1Y
M*"1N;'-;)V-H87)S971S)UU;)&QA;F=U86=E72DI(#\@)&YL<ULG8VAA<G-E
M=',G75LD;&%N9W5A9V5=(#H@)TE33RTX.#4Y+3$G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!O<B!R971U<FYS('1H92!C:&%R<V5T('5S960@=6YD
M97(@8V5R=&%I;B!C;VYD:71I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@
M(%1H92!)1"!O9B!A(&-A8VAE('-L;W0N(#`@9F]R('1H92!522!C:&%R<V5T
M+"`Q"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@=&AE('1R
M86YS;&%T:6]N(&-H87)S970@86YD(#(@9F]R('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@97AT97)N86P@8VAA<G-E="X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-H87)S970@($EF('-P96-I9FEE9"P@=&AI<R!C:&%R
M<V5T('=I;&P@8F4@<W1O<F5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@9VEV96X@8V%C:&4@<VQO="X@3W1H97)W:7-E('1H92!C
M;VYT96YT(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<W!E8VEF:65D(&-A8VAE('-L;W0@=VEL;"!B92!R971U<FYE9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-A8VAE9$-H87)S970H)&EN9&5X+"`D8VAA<G-E
M="`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1C86-H93L*"B`@("`@
M("`@:68@*"%I<W-E="@D8V%C:&4I*2!["B`@("`@("`@("`@("1C86-H92`]
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&-H87)S970@/3T@
M;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@:7-S970H)&-A8VAE6R1I;F1E
M>%TI(#\@)&-A8VAE6R1I;F1E>%T@.B!N=6QL.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1C86-H95LD:6YD97A=(#T@)&-H87)S970["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<G-E
M="!T;R!U<V4@9F]R(&]U=&=O:6YG(&5M86EL<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('!R969E<G)E9"!C:&%R<V5T(&9O<B!O=71G
M;VEN9R!M86EL<R!B87-E9"!O;@H@("`@("H@("`@("`@("`@("`@("`@('1H
M92!U<V5R)W,@<')E9F5R96YC97,@86YD('1H92!C=7)R96YT(&QA;F=U86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%;6%I;$-H87)S970H*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<')E9G,L("1L86YG=6%G92P@)&YL<SL*"B`@
M("`@("`@)&-H87)S970@/2`D<')E9G,M/F=E=%9A;'5E*"=S96YD:6YG7V-H
M87)S970G*3L*("`@("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&-H87)S970["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!I<W-E="@D;FQS6R=E;6%I;',G75LD;&%N9W5A9V5=*2`_("1N;'-;
M)V5M86EL<R==6R1L86YG=6%G95T@.@H@("`@("`@("`@("`@("`H:7-S970H
M)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=*2`_("1N;'-;)V-H87)S971S
M)UU;)&QA;F=U86=E72`Z("=)4T\M.#@U.2TQ)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:R!T;R!S964@:68@8VAA<F%C=&5R('-E="!I<R!V86QI
M9"!F;W(@:'1M;'-P96-I86QC:&%R<R@I(&-A;&QS+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T('1O
M(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@27,@8VAA
M<G-E="!V86QI9"!F;W(@=&AE(&-U<G)E;G0@<WES=&5M/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!C:&5C:T-H87)S970H)&-H87)S970I"B`@("!["B`@("`@
M("`@<W1A=&EC("1C:&5C:SL*"B`@("`@("`@:68@*&ES7VYU;&PH)&-H87)S
M970I('Q\(&5M<'1Y*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-H96-K6R1C
M:&%R<V5T72DI('L*("`@("`@("`@("`@<F5T=7)N("1C:&5C:ULD8VAA<G-E
M=%T["B`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D8VAE8VLI*2!["B`@("`@
M("`@("`@("1C:&5C:R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D
M=F%L:60@/2!T<G5E.PH*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G
M+"`Q*3L*("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@G)RP@14Y47T-/35!!
M5"P@)&-H87)S970I.PH@("`@("`@(&EF("AI<W-E="@D<&AP7V5R<F]R;7-G
M*2D@>PH@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("!]"B`@
M("`@("`@:6YI7W)E<W1O<F4H)W1R86-K7V5R<F]R<R<I.PH*("`@("`@("`D
M8VAE8VM;)&-H87)S971=(#T@)'9A;&ED.PH*("`@("`@("!R971U<FX@)'9A
M;&ED.PH@("`@?0H*("`@+RHJ"B`@("`@*B!3971S('1H92!C:&%R<V5T+@H@
M("`@("H@26X@9V5N97)A;"P@=&AE(&%P<&QI960@8VAA<G-E="!I<R!A=71O
M;6%T:6-A;&QY(&1E=&5R;6EN960@8GD@8G)O=W-E<@H@("`@("H@;&%N9W5A
M9V4@86YD(&)R;W=S97(@8V%P86)I;&ET:65S(&%N9"!T:&5R92=S(&YO(&YE
M960@=&\@;6%N=6%L;'D@8V%L;`H@("`@("H@<V5T0VAA<G-E="X@2&]W979E
M<B!F;W(@:&5A9&QE<W,@*%)00RD@;W!E<F%T:6]N<R!T:&4@8VAA<G-E="!M
M87D@8F4*("`@("`J('-E="!M86YU86QL>2!T;R!E;G-U<F4@8V]R<F5C="!C
M:&%R86-T97(@8V]N=F5R<VEO;B!I;B!T:&4@8F%C:V5N9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!)9B!S<&5C:69I960L('1H
M:7,@8VAA<G-E="!W:6QL(&)E('-T;W)E9"!I;B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&=I=F5N(&-A8VAE('-L;W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("`@5&AE($E$(&]F(&$@8V%C
M:&4@<VQO="X@,"!F;W(@=&AE(%5)(&-H87)S970L(#$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<B!T:&4@=')A;G-L871I;VX@8VAA<G-E
M="!A;F0@,B!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!E>'1E<FYA;"!C:&%R<V5T+B!$969A=6QT<R!T;R`P.B!T:&ES(&ES('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@8VAA<G-E="!R971U
M<FYE9"!B>2!G971#:&%R<V5T(&%N9"!U<V5D(&9O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=F5R<VEO;BX*("`@("`J+PH*("`@(&9U
M;F-T:6]N('-E=$-H87)S970H)&-H87)S970L)&EN9&5X(#T@,"D*("`@('L*
M("`@("`@("!.3%,Z.E]C86-H961#:&%R<V5T*"1I;F1E>"P@)&-H87)S970I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@8W5R<F5N="!T:6UE
M>F]N92P@:68@879A:6QA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9714
M:6UE6F]N92@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@
M("`@)'1Z(#T@)'!R969S+3YG971686QU92@G=&EM97IO;F4G*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1T>BDI('L*("`@("`@("`@("`@0'!U=&5N=B@G5%H]
M)R`N("1T>BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!L;V-A;&4@:6YF;R!R971U<FYE9"!B>2!L;V-A;&5C;VYV*"DL(&)U
M="!C86-H92!I="P@=&\*("`@("`J(&%V;VED(')E<&5A=&5D(&-A;&QS+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!R97-U;'1S(&]F(&QO
M8V%L96-O;G8H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]C86QE26YF
M;R@I"B`@("!["B`@("`@("`@<W1A=&EC("1L8U]I;F9O.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1L8U]I;F9O*2D@>PH@("`@("`@("`@("`D;&-?:6YF;R`]
M(&QO8V%L96-O;G8H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&-?
M:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@;&%N9W5A9V4@
M:6YF;R!R971U<FYE9"!B>2!N;%]L86YG:6YF;R@I+"!B=70@8V%C:&4@:70L
M('1O"B`@("`@*B!A=F]I9"!R97!E871E9"!C86QL<RX*("`@("`J"B`@("`@
M*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T
M("1I=&5M("!4:&4@;&%N9VEN9F\@:71E;2!T;R!R971U<FXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE(')E<W5L=',@;V8@;FQ?;&%N9VEN
M9F\H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&%N9TEN9F\H)&ET96TI
M"B`@("!["B`@("`@("`@<W1A=&EC("1N;%]I;F9O(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*"%I<W-E="@D;FQ?:6YF;ULD:71E;5TI*2!["B`@("`@("`@
M("`@("1N;%]I;F9O6R1I=&5M72`](&YL7VQA;F=I;F9O*"1I=&5M*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;FQ?:6YF;ULD:71E;5T["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@8V]U;G1R>2!I;F9O<FUA=&EO;B!F<F]M
M(&$@:&]S=&YA;64@;W(@25`@861D<F5S<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1H;W-T("!4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!/;B!S=6-C97-S+"!R971U
M<FX@86X@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&5N=')I97,Z"B`@("`@
M*B`@("`@("`@("`@("`@("`G8V]D92<@(#T^("!#;W5N=')Y($-O9&4*("`@
M("`J("`@("`@("`@("`@("`@("=N86UE)R`@/3X@($-O=6YT<GD@3F%M90H@
M("`@("H@("`@("`@("`@("`@("`@3VX@9F%I;'5R92P@<F5T=7)N(&9A;'-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;W5N=')Y0GE(;W-T*"1H;W-T
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@+RH@3&ES
M="!O9B!G96YE<FEC(&1O;6%I;G,@=&AA="!W92!K;F]W(&ES(&YO="!I;B!T
M:&4@8V]U;G1R>2!43$0*("`@("`@("`@("!L:7-T+B!3964Z(&AT='`Z+R]W
M=W<N:6%N82YO<F<O9W1L9"]G=&QD+FAT;2`J+PH@("`@("`@("1G96YE<FEC
M(#T@87)R87DH"B`@("`@("`@("`@("=A97)O)RP@)V)I>B<L("=C;VTG+"`G
M8V]O<"<L("=E9'4G+"`G9V]V)RP@)VEN9F\G+"`G:6YT)RP@)VUI;"<L"B`@
M("`@("`@("`@("=M=7-E=6TG+"`G;F%M92<L("=N970G+"`G;W)G)RP@)W!R
M;R<*("`@("`@("`I.PH*("`@("`@("`D8VAE8VM(;W-T(#T@)&AO<W0["B`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R]>7&0K7"Y<9"M<+EQD*UPN7&0K)"\G
M+"`D:&]S="DI('L*("`@("`@("`@("`@)&-H96-K2&]S="`]($!G971H;W-T
M8GEA9&1R*"1H;W-T*3L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@
M5$Q$(&]F('1H92!H;W-T;F%M92X@*B\*("`@("`@("`D<&]S(#T@<W1R<G!O
M<R@D8VAE8VM(;W-T+"`G+B<I.PH@("`@("`@(&EF("@D<&]S(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M("`@("1D;VUA:6X@/2!3=')I;F<Z.FQO=V5R*'-U8G-T<B@D8VAE8VM(;W-T
M+"`D<&]S("L@,2DI.PH*("`@("`@("`O*B!4<GD@;&]O:W5P('9I82!43$0@
M9FER<W0N("HO"B`@("`@("`@:68@*"%I;E]A<G)A>2@D9&]M86EN+"`D9V5N
M97)I8RDI('L*("`@("`@("`@("`@<F5Q=6ER92`G2&]R9&4O3DQ3+W1L9"YP
M:'`G.PH@("`@("`@("`@("!I9B`H:7-S970H)'1L9%LD9&]M86EN72DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@G8V]D92<@/3X@)&1O;6%I
M;BP@)VYA;64G(#T^("1T;&1;)&1O;6%I;ETI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!4<GD@1V5O25`@;&]O:W5P(&YE>'0N("HO
M"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG9V5O:7`G75LG9&%T869I;&4G
M72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92].3%,O1V5O
M25`N<&AP)SL*("`@("`@("`@("`@)&=E;VEP(#T@)DY,4U]'96])4#HZ<VEN
M9VQE=&]N*"1C;VYF6R=G96]I<"==6R=D871A9FEL92==*3L*("`@("`@("`@
M("`@)&ED(#T@)&=E;VEP+3YC;W5N=')Y261">4YA;64H)&-H96-K2&]S="D[
M"B`@("`@("`@("`@(&EF("@A96UP='DH)&ED*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=C;V1E)R`]/B!3=')I;F<Z.FQO=V5R*"1'3$]"
M04Q36R='14])4%]#3U5.5%)97T-/1$53)UU;)&ED72DL("=N86UE)R`]/B`D
M1TQ/0D%,4ULG1T5/25!?0T]53E1265].04U%4R==6R1I9%TI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@2&]R9&4@:6UA9V4@;&EN:R!T
M;R!T:&4@8V]U;G1R>2!F;&%G+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&AO<W0@(%1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:6UA9V4@55),+"!O<B!T:&4@
M96UP='D@<W1R:6YG(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M96YE<F%T949L86=);6%G94)Y2&]S="@D:&]S="D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D9&%T82`]($Y,4SHZ9V5T0V]U
M;G1R>4)Y2&]S="@D:&]S="D["B`@("`@("`@:68@*"1D871A("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`D:6UG(#T@)&1A=&%;)V-O9&4G72`N("<N<&YG
M)SL*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1R96=I<W1R>2T^9V5T
M*"=T:&5M97-F<R<L("=H;W)D92<I("X@)R]G<F%P:&EC<R]F;&%G<R\G("X@
M)&EM9RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!(;W)D93HZ:6UG*"1I
M;6<L("1D871A6R=N86UE)UTL(&%R<F%Y*"=T:71L92<@/3X@)&1A=&%;)VYA
M;64G72DL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+V9L
M86=S)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@)ULG("X@)&1A=&%;)VYA;64G72`N("==)SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!E:71H97(@82!S<&5C:69I8R!O<B!A;&P@25-/
M+3,Q-C8@8V]U;G1R>2!N86UE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;V1E("!4:&4@25-/(#,Q-C8@8V]U;G1R>2!C;V1E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($EF(&$@8V]U;G1R>2!C;V1E(&AA<R!B
M965N(')E<75E<W1E9"!W:6QL(')E='5R;B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@(&-O<G)E<W!O;F1I;F<@8V]U;G1R>2!N86UE+B!)9B!E;7!T>2!W
M:6QL(')E='5R;B!A;@H@("`@("H@("`@("`@("`@("`@("`@87)R87D@;V8@
M86QL('1H92!C;W5N=')Y(&-O9&5S(&%N9"!T:&5I<B!N86UE<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F=E=$-O=6YT<GE)4T\H)&-O9&4@/2`G)RD*("`@
M('L*("`@("`@("!S=&%T:6,@)&-O=6YT<FEE<R`](&%R<F%Y*"D["B`@("`@
M("`@:68@*&5M<'1Y*"1C;W5N=')I97,I*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`G.PH@("`@("`@('T*
M("`@("`@("!I9B`H96UP='DH)&-O9&4I*2!["B`@("`@("`@("`@(')E='5R
M;B`D8V]U;G1R:65S.PH@("`@("`@('T@96QS96EF("AI<W-E="@D8V]U;G1R
M:65S6R1C;V1E72DI('L*("`@("`@("`@("`@<F5T=7)N("1C;W5N=')I97-;
M)&-O9&5=.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#<GEP="YP
M:'``````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(U
M-S<`,3`U,34T,S$P-C$`,#(P,#0R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0W)Y
M<'0Z.B!C;&%S<R!P<F]V:61E<R!A;B!!4$D@9F]R('9A<FEO=7,@8W)Y<'1O
M9W)A<&AI8PH@*B!S>7-T96US('5S960@8GD@2&]R9&4@87!P;&EC871I;VYS
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`L=B`Q
M+C(W+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,B!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]#<GEP=`H@*B\*8VQA<W,@2&]R9&5?0W)Y<'0@>PH*("`@("\J*@H@("`@
M("H@5&AE('1E;7!O<F%R>2!D:7)E8W1O<GD@=&\@=7-E+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1E;7!D:7(["@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(
M;W)D95]#<GEP="!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC
M<F5T92!(;W)D95]#<GEP="!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@
M=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!I;B`D9')I=F5R6S!=+VQI8B]#<GEP="\@9F]R('1H92!S=6)C;&%S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA
M;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R
M871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N($AO<F1E7T-R>7!T("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!(
M;W)D95]#<GEP="!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@
M;&ES="@D87!P+"`D9')I=F5R*2`]("1D<FEV97(["B`@("`@("`@?0H*("`@
M("`@("`O*B!2971U<FX@82!B87-E($AO<F1E7T-R>7!T(&]B:F5C="!I9B!N
M;R!D<FEV97(@:7,@<W!E8VEF:65D+B`J+PH@("`@("`@("1D<FEV97(@/2!B
M87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I9B`H96UP='DH)&1R:79E<BD@
M?'P@*'-T<F-M<"@D9')I=F5R+"`G;F]N92<I(#T](#`I*2!["B`@("`@("`@
M("`@("1C<GEP="`]("9N97<@2&]R9&5?0W)Y<'0H*3L*("`@("`@("`@("`@
M<F5T=7)N("1C<GEP=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH
M)&%P<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]#<GEP
M="\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I
M;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]#<GEP="\G("X@)&1R
M:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]#<GEP="\G("X@)&1R:79E<B`N("<N<&AP
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E
M("=(;W)D92]#<GEP="\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]
M"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7T-R>7!T7R<@+B`D9')I=F5R.PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("`D8W)Y<'0@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8W)Y<'0@/2!014%2.CIR86ES945R<F]R*"=#
M;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8W)Y<'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@
M=&\@82!C;VYC<F5T92!(;W)D95]#<GEP="!I;G-T86YC90H@("`@("H@8F%S
M960@;VX@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T
M86YC92!I9B!N;PH@("`@("H@2&]R9&5?0W)Y<'0@:6YS=&%N8V4@=VET:"!T
M:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@
M("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!C<GEP=&\@
M8F%C:V5N9',@*&%N9"P@=&AU<RP*("`@("`J(&UU;'1I<&QE($AO<F1E7T-R
M>7!T(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9(;W)D95]#
M<GEP=#HZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0W)Y<'0@<W5B
M8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN
M($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O
M0W)Y<'0O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B
M8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E
M7T-R>7!T("!4:&4@8V]N8W)E=&4@2&]R9&5?0W)Y<'0@<F5F97)E;F-E+"!O
M<B!F86QS92!O;B!A;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T
M86YC97,["@H@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@
M("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P
M87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA
M='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@
M/2`F2&]R9&5?0W)Y<'0Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M73L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U=',@97)R;W(@;65S<V%G
M92!I9B!W92!A<F4@;F]T('5S:6YG(&$@<V5C=7)E(&-O;FYE8W1I;VXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!014%27T5R<F]R("!2971U<FYS(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@:68@=&AE<F4@:7,@;F\@<V5C=7)E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E<75I<F5396-U<F5#;VYN96-T:6]N*"D*("`@('L*("`@("`@
M("!G;&]B86P@)&)R;W=S97(["@H@("`@("`@(&EF("@A)&)R;W=S97(M/G5S
M:6YG4U-,0V]N;F5C=&EO;B@I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(BDI.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@=&AE(')E<75E<W1E9"!D871A
M+@H@("`@("H@5&AI<R!M971H;V0@<VAO=6QD(&)E('!R;W9I9&5D(&)Y(&%L
M;"!C;&%S<V5S('1H870@97AT96YD($AO<F1E7T-R>7!T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!E;F-R>7!T
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y(&]F(&%R
M9W5M96YT<R!N965D960@=&\@96YC<GEP="!T:&4@9&%T82X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)&1A=&$L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E8W)Y<'0@=&AE(')E<75E<W1E9"!D871A+@H@("`@("H@
M5&AI<R!M971H;V0@<VAO=6QD(&)E('!R;W9I9&5D(&)Y(&%L;"!C;&%S<V5S
M('1H870@97AT96YD($AO<F1E7T-R>7!T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y(&]F(&%R9W5M96YT<R!N
M965D960@=&\@9&5C<GEP="!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@9&5C<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E8W)Y<'0H)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J
M($-R96%T92!A('1E;7!O<F%R>2!F:6QE('1H870@=VEL;"!B92!D96QE=&5D
M(&%T('1H92!E;F0@;V8@=&AI<PH@("`@("H@<')O8V5S<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D9&5S8W)I<"`@1&5S8W)I<'1I;VX@<W1R:6YG('1O('5S92!I;B!F
M:6QE;F%M92X*("`@("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@("!$96QE
M=&4@=&AE(&9I;&4@875T;VUA=&EC86QL>3\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@1FEL96YA;64@;V8@82!T96UP;W)A<GD@9FEL92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-R96%T951E;7!&:6QE*"1D97-C<FEP(#T@
M)VAO<F1E+6-R>7!T)RP@)&1E;&5T92`]('1R=64I"B`@("!["B`@("`@("`@
M<F5T=7)N(%5T:6PZ.F=E=%1E;7!&:6QE*"1D97-C<FEP+"`D9&5L971E+"`D
M=&AI<RT^7W1E;7!D:7(L('1R=64I.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]";&]C:RYP:'``````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(W,C<`,3`U,34T,S$P-C$`,#$W-S<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@86)S=')A8W0@2&]R9&5?0FQO8VLZ.B!C;&%S<R!R
M97!R97-E;G1S(&$@<VEN9VQE(&)L;V-K('=I=&AI;@H@*B!T:&4@0FQO8VMS
M(&9R86UE=V]R:RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLN<&AP+'8@,2XS,RXQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,#@@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#,M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:R!["@H@("`@+RHJ"B`@("`@
M*B!";&]C:R!S<&5C:69I8R!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($%P<&QI8V%T:6]N('1H870@=&AI<R!B;&]C:R!O
M<FEG:6YA=&5D(&9R;VTN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?87!P.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y?&)O;VQE86X@)'!A<F%M
M<R`@06YY('!A<F%M971E<G,@=&AE(&)L;V-K(&YE961S+B!)9B!F86QS92P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!D969A
M=6QT('!A<F%M971E<B!W:6QL(&)E('5S960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($AO<F1E7T)L;V-K*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&EF("@D<&%R86US(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R
M86US(#T@)'1H:7,M/F=E=%!A<F%M<R@I.PH@("`@("`@("`@("!F;W)E86-H
M("@D<&%R86US(&%S("1N86UE(#T^("1P87)A;2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)&YA;65=(#T@)'!A<F%M6R=D969A=6QT)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@87!P;&EC871I;VX@=&AA="!T:&ES
M(&)L;V-K(&)E;&]N9W,@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!A<'!L:6-A=&EO;B!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971!<'`H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%P<#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86YY('-E='1A8FQE('!A
M<F%M971E<G,@9F]R('1H:7,@8FQO8VLN(%1H:7,@:7,@80H@("`@("H@<W1A
M=&EC(&UE=&AO9"X@270@9&]E<R`J;F]T*B!R969E<F5N8V4@)'1H:7,M/E]P
M87)A;7,[('1H870@:7,*("`@("`J(&9O<B!R=6YT:6UE('!A<F%M971E<G,@
M*'1H92!C:&]I8V5S(&UA9&4@9G)O;2!T:&5S92!O<'1I;VYS*2X*("`@("`J
M"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE(&)L;V-K)W,@8V]N9FEG=7)A8FQE('!A<F%M971E<G,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!A<F%M<R@I"B`@("!["B`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*"B`@("`@("`@+RH@4W=I=&-H(&%P<&QI8V%T:6]N(&-O
M;G1E>'1S+"!I9B!N96-E<W-A<GDN(%)E='5R;B!A;B!E<G)O<@H@("`@("`@
M("`J(&EM;65D:6%T96QY(&EF('!U<VA!<'`H*2!F86EL<RX@*B\*("`@("`@
M("`D87!P7W!U<VAE9"`]("1R96=I<W1R>2T^<'5S:$%P<"@D=&AI<RT^7V%P
M<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]P=7-H960L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?<'5S:&5D+3YG971-97-S
M86=E*"D["B`@("`@("`@?0H*("`@("`@("`D<&%R86US(#T@)'1H:7,M/E]P
M87)A;7,H*3L*"B`@("`@("`@+RH@268@=V4@8VAA;F=E9"!A<'!L:6-A=&EO
M;B!C;VYT97AT(&EN('1H92!C;W5R<V4@;V8@=&AI<PH@("`@("`@("`J(&-A
M;&PL('5N9&\@=&AA="!C:&%N9V4@;F]W+B`J+PH@("`@("`@(&EF("@D87!P
M7W!U<VAE9"`]/3T@=')U92D@>PH@("`@("`@("`@("`D<F5G:7-T<GDM/G!O
M<$%P<"@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T97AT('1O(&=O(&EN
M('1H92!T:71L92!O9B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J(%1H:7,@
M9G5N8W1I;VX@:&%N9&QE<R!T:&4@8VAA;F=I;F<@;V8@8W5R<F5N="!A<'!L
M:6-A=&EO;B!A<PH@("`@("H@;F5E9&5D('-O(&-O9&4@:7,@97AE8W5T960@
M:6X@=&AE('-C;W!E(&]F('1H92!A<'!L:6-A=&EO;B!T:&4*("`@("`J(&)L
M;V-K(&]R:6=I;F%T960@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&)L;V-K)W,@=&ET;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%1I=&QE*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*
M("`@("`@("`O*B!3=VET8V@@87!P;&EC871I;VX@8V]N=&5X=',L(&EF(&YE
M8V5S<V%R>2X@4F5T=7)N(&%N(&5R<F]R"B`@("`@("`@("H@:6UM961I871E
M;'D@:68@<'5S:$%P<"@I(&9A:6QS+B`J+PH@("`@("`@("1A<'!?<'5S:&5D
M(#T@)')E9VES=')Y+3YP=7-H07!P*"1T:&ES+3Y?87!P*3L*("`@("`@("!I
M9B`H:7-?82@D87!P7W!U<VAE9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&%P<%]P=7-H960M/F=E=$UE<W-A9V4H*3L*("`@("`@
M("!]"@H@("`@("`@("1T:71L92`]("1T:&ES+3Y?=&ET;&4H*3L*"B`@("`@
M("`@+RH@268@=V4@8VAA;F=E9"!A<'!L:6-A=&EO;B!C;VYT97AT(&EN('1H
M92!C;W5R<V4@;V8@=&AI<PH@("`@("`@("`J(&-A;&PL('5N9&\@=&AA="!C
M:&%N9V4@;F]W+B`J+PH@("`@("`@(&EF("@D87!P7W!U<VAE9"`]/3T@=')U
M92D@>PH@("`@("`@("`@("`D<F5G:7-T<GDM/G!O<$%P<"@I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:71L93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&-O;G1E;G0@9F]R('1H:7,@8FQO8VLN"B`@("`@
M*@H@("`@("H@5&AI<R!F=6YC=&EO;B!H86YD;&5S('1H92!C:&%N9VEN9R!O
M9B!C=7)R96YT(&%P<&QI8V%T:6]N(&%S"B`@("`@*B!N965D960@<V\@8V]D
M92!I<R!E>&5C=71E9"!I;B!T:&4@<V-O<&4@;V8@=&AE(&%P<&QI8V%T:6]N
M('1H90H@("`@("H@8FQO8VL@;W)I9VEN871E9"!F<F]M+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8FQO8VLG<R!C;VYT96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#;VYT96YT*"D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O*B!3=VET8V@@87!P;&EC871I
M;VX@8V]N=&5X=',L(&EF(&YE8V5S<V%R>2X@4F5T=7)N(&%N(&5R<F]R"B`@
M("`@("`@("H@:6UM961I871E;'D@:68@<'5S:$%P<"@I(&9A:6QS+B`J+PH@
M("`@("`@("1A<'!?<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"1T:&ES
M+3Y?87!P*3L*("`@("`@("!I9B`H:7-?82@D87!P7W!U<VAE9"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&%P<%]P=7-H960M/F=E
M=$UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@("1C;VYT96YT(#T@)'1H
M:7,M/E]C;VYT96YT*"D["@H@("`@("`@("\J($EF('=E(&-H86YG960@87!P
M;&EC871I;VX@8V]N=&5X="!I;B!T:&4@8V]U<G-E(&]F('1H:7,*("`@("`@
M("`@*B!C86QL+"!U;F1O('1H870@8VAA;F=E(&YO=RX@*B\*("`@("`@("!I
M9B`H)&%P<%]P=7-H960@/3T]('1R=64I('L*("`@("`@("`@("`@)')E9VES
M=')Y+3YP;W!!<'`H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V]N
M=&5N=#L*("`@('T*"B`@("!F=6YC=&EO;B!B=6EL9%1R964H)B1T<F5E+"`D
M:6YD96YT(#T@,"P@)'!A<F5N="`](&YU;&PI"B`@("!["B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@4W=I=&-H(&%P<&QI8V%T:6]N
M(&-O;G1E>'1S+"!I9B!N96-E<W-A<GDN(%)E='5R;B!A;B!E<G)O<@H@("`@
M("`@("`J(&EM;65D:6%T96QY(&EF('!U<VA!<'`H*2!F86EL<RX@*B\*("`@
M("`@("`D87!P7W!U<VAE9"`]("1R96=I<W1R>2T^<'5S:$%P<"@D=&AI<RT^
M7V%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]P=7-H960L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?<'5S:&5D+3YG971-
M97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V)U:6QD5')E
M92@D=')E92P@)&EN9&5N="P@)'!A<F5N="D["@H@("`@("`@("\J($EF('=E
M(&-H86YG960@87!P;&EC871I;VX@8V]N=&5X="!I;B!T:&4@8V]U<G-E(&]F
M('1H:7,*("`@("`@("`@*B!C86QL+"!U;F1O('1H870@8VAA;F=E(&YO=RX@
M*B\*("`@("`@("!I9B`H)&%P<%]P=7-H960@/3T]('1R=64I('L*("`@("`@
M("`@("`@)')E9VES=')Y+3YP;W!!<'`H*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T:71L92!T;R!G;R!I;B!T:&ES
M(&)L;V-K+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@8FQO8VL@=&ET;&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!N
M965D960@8GD@8FQO8VLN"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&)L;V-K)W,@<&%R86UE=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H:7,@8FQO8VLG<R!C;VYT96YT+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8FQO8VLG
M<R!C;VYT96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@
M("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&ES(&)L;V-K)W,@8V]N=&5N="X*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&)L
M;V-K)W,@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD5')E
M92@F)'1R964L("1I;F1E;G0@/2`P+"`D<&%R96YT(#T@;G5L;"D*("`@('L*
M("`@('T*"GT*````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92],1$%0
M+G!H<```````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#4Q,S,`,3`U,34T,S$P-C$`,#$W-#0W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&ES(&$@
M=71I;&ET>2!C;&%S<RP@979E<GD@;65T:&]D(&ES('-T871I8RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO3$1!4"],1$%0+G!H<"QV(#$N-2XQ,BXQ,"`R
M,#`V+S`Q+S`Q(#(Q.C(X.C(S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A
M8VMA9V4@2&]R9&5?3$1!4`H@*B\*8VQA<W,@2&]R9&5?3$1!4"!["@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@82!B;V]L96%N(&5X<')E<W-I;VX@=7-I;F<@
M=&AE('-P96-I9FEE9"!O<&5R871O<BX*("`@("`J"B`@("`@*B!`<W1A=&EC
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&AS("!4:&4@871T<FEB
M=71E('1O('1E<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<"`@(%1H92!O
M<&5R871O<BX*("`@("`J($!P87)A;2!S=')I;F<@)')H<R`@5&AE(&-O;7!A
M<FES;VX@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!,1$%0('-E87)C:"!F<F%G;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8G5I;&1#;&%U<V4H)&QH<RP@)&]P+"`D<FAS*0H@("`@>PH@("`@("`@('-W
M:71C:"`H)&]P*2!["B`@("`@("`@8V%S92`G3$E+12<Z"B`@("`@("`@("`@
M(')E='5R;B!E;7!T>2@D<FAS*2`_"B`@("`@("`@("`@("`@("!S<')I;G1F
M*"<H)7,]*BDG+"`D;&AS*2`Z"B`@("`@("`@("`@("`@("!S<')I;G1F*"<H
M)7,]*B5S*BDG+"`D;&AS+"!(;W)D95],1$%0.CIQ=6]T92@D<FAS*2D["@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"<H
M)7,E<R5S*2<L("1L:',L("1O<"P@2&]R9&5?3$1!4#HZ<75O=&4H)')H<RDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5S8V%P92!C:&%R
M86-T97)S('=I=&@@<W!E8VEA;"!M96%N:6YG(&EN($Q$05`@<V5A<F-H97,N
M"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-L875S92`@5&AE('-T<FEN9R!T;R!E<V-A<&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E<V-A<&5D('-T<FEN9RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<75O=&4H)&-L875S92D*("`@('L*("`@("`@
M("!R971U<FX@<W1R7W)E<&QA8V4H87)R87DH)UQ<)RP@("`G*"<L("`G*2<L
M("`G*B<L("`B7#`B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)UQ<-6,G+"`G7"@G+"`G7"DG+"`G7"HG+"`B7%PP,"(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8VQA=7-E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1A:V4@86X@87)R87D@;V8@1$X@96QE;65N=',@86YD('!R;W!E
M<FQY('%U;W1E(&ET(&%C8V]R9&EN9R!T;R!21D,*("`@("`J(#$T.#4N"B`@
M("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R=',@($%N(&%R<F%Y(&]F('1U<&QE<R!C;VYT86EN:6YG('1H92!A
M='1R:6)U=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&YA;64@86YD
M('1H870@871T<FEB=71E)W,@=F%L=64@=VAI8V@@;6%K90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@=7`@=&AE($1.+B!%>&%M<&QE.@H@("`@("H*
M("`@("`J("`@("1P87)T<R`](&%R<F%Y*#`@/3X@87)R87DH)V-N)RP@)TIO
M:&X@4VUI=&@G*2P*("`@("`J("`@("`@("`@("`@("`@("`@(#$@/3X@87)R
M87DH)V1C)RP@)V5X86UP;&4G*2P*("`@("`J("`@("`@("`@("`@("`@("`@
M(#(@/3X@87)R87DH)V1C)RP@)V-O;2<I*3L*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('!R;W!E<FQY('%U;W1E9"!S=')I;F<@1$XN"B`@
M("`@*B\*("`@(&9U;F-T:6]N('%U;W1E1$XH)'!A<G1S*0H@("`@>PH@("`@
M("`@("1D;B`]("<G.PH@("`@("`@("1C;W5N="`](&-O=6YT*"1P87)T<RD[
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@
M("`@("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@("`@("1D;B`N
M/2`G+"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1N("X]("1P87)T
M<ULD:5U;,%T@+B`G/2<["@H@("`@("`@("`@("`O+R!3964@:68@=V4@;F5E
M9"!T;R!Q=6]T92!T:&4@=F%L=64N"B`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O7EQS?%QS)'Q<<UQS?%LL*STB7')<;CP^(SM=+R<L("1P87)T<ULD
M:5U;,5TI*2!["B`@("`@("`@("`@("`@("`D9&X@+CT@)R(G("X@<W1R7W)E
M<&QA8V4H)R(G+"`G7%PB)RP@)'!A<G1S6R1I75LQ72D@+B`G(B<["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&X@+CT@)'!A<G1S
M6R1I75LQ73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1D;CL*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TED96YT:71Y+G!H<```````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,3<T,P`Q,#4Q-30S,3`V
M,0`P,C`U,C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@86X@:6YT
M97)F86-E('1O(&%L;"!I9&5N=&ET:65S(&$@=7-E<B!M:6=H="!H879E+B!)
M=',*("H@;65T:&]D<R!T86ME(&-A<F4@;V8@86YY('-I=&4M<W!E8VEF:6,@
M<F5S=')I8W1I;VYS(&-O;F9I9W5R960@:6X@<')E9G,N<&AP"B`J(&%N9"!C
M;VYF+G!H<"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O261E;G1I
M='DN<&AP+'8@,2XQ+C(N,B`R,#`V+S`V+S(X(#(P.C4R.C4S(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q
M+C,N-0H@*B!`<&%C:V%G92!(;W)D95])9&5N=&ET>0H@*B\*8VQA<W,@261E
M;G1I='D@>PH*("`@("\J*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!A;&P@
M=&AE('5S97(G<R!I9&5N=&ET:65S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?:61E;G1I=&EE<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!!('!O:6YT97(@=&\@=&AE('5S97(G<R!S=&%N9&%R
M9"!I9&5N=&ET>2X*("`@("`J(%1H:7,@;VYE(&ES('5S960@8GD@=&AE(&UE
M=&AO9',@<F5T=7)N:6YG('9A;'5E<R!I9B!N;R!O=&AE<B!O;F4@:7,*("`@
M("`J('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?9&5F875L="`](#`["@H@("`@+RHJ"B`@("`@*B!4
M:&4@=7-E<B!W:&]S92!I9&5N=&ET:65S('1H97-E(&%R92X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]U<V5R(#T@;G5L
M;#L*"B`@("`O*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@86QL(&]F('1H
M92!P<F]P97)T:65S(&EN('1H:7,@:61E;G1I='DN"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P<F]P97)T:65S(#T@87)R
M87DH)VED)RP@)V9U;&QN86UE)RP@)V9R;VU?861D<B<I.PH*("`@("\J*@H@
M("`@("H@4F5F97)E;F-E('1O('1H92!P<F5F<R!O8FIE8W0@=&AA="!T:&ES
M($ED96YT:71Y('!O:6YT<R!T;RX*("`@("`J"B`@("`@*B!`=F%R(%!R969S
M"B`@("`@*B\*("`@('9A<B`D7W!R969S.PH*("`@("\J*@H@("`@("H@4F5A
M9',@86QL('1H92!U<V5R)W,@:61E;G1I=&EE<R!F<F]M('1H92!P<F5F<R!O
M8FIE8W0@;W(@8G5I;&1S(&$@;F5W"B`@("`@*B!I9&5N=&ET>2!F<F]M('1H
M92!S=&%N9&%R9"!V86QU97,@9VEV96X@:6X@<')E9G,N<&AP+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@($EF('-P96-I9FEE9"P@=V4@
M<F5A9"!A;F]T:&5R('5S97(G<R!I9&5N=&ET:65S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!I;G-T96%D(&]F('1H92!C=7)R96YT('5S97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($ED96YT:71Y*"1U<V5R(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7W5S97(@/2`D=7-E<CL*("`@("`@("!I9B`H
M*&ES7VYU;&PH)'5S97(I('Q\("1U<V5R(#T]($%U=&@Z.F=E=$%U=&@H*2D@
M)B8*("`@("`@("`@("`@:7-S970H)$=,3T)!3%-;)W!R969S)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<')E9G,@/2`F)$=,3T)!3%-;)W!R969S)UT[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5F<R`]
M("90<F5F<SHZ<VEN9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)W!R969S)UU;
M)V1R:79E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$%P<"@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'5S97(L("<G+"!N=6QL+"!F86QS92D["B`@("`@("`@("`@("1T:&ES+3Y?
M<')E9G,M/G)E=')I979E*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(2@D
M=&AI<RT^7VED96YT:71I97,@/2!`=6YS97)I86QI>F4H)'1H:7,M/E]P<F5F
M<RT^9V5T5F%L=64H)VED96YT:71I97,G+"!F86QS92DI*2D@>PH@("`@("`@
M("`@("`O*B!#;VYV97)T(&ED96YT:71I97,@9G)O;2!T:&4@;VQD(&9O<FUA
M="X@*B\*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET:65S(#T@=6YS97)I
M86QI>F4H)'1H:7,M/E]P<F5F<RT^9V5T5F%L=64H)VED96YT:71I97,G*2D[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T:&ES+3Y?:61E;G1I=&EE
M<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET:65S(#T@)'1H:7,M
M/E]P<F5F<RT^8V]N=F5R=$9R;VU$<FEV97(H)'1H:7,M/E]I9&5N=&ET:65S
M+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^<V5T1&5F875L="@D=&AI<RT^7W!R969S+3YG971686QU92@G9&5F875L
M=%]I9&5N=&ET>2<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@
M82!D969A=6QT(&ED96YT:71Y(&EF(&YO;F4@97AI<W1S('EE="!A;F0@<V5T
M<R!T:&4@<')E9F5R96YC97,*("`@("`J('5P(&EF('1H92!I9&5N=&ET:65S
M(&%R92!L;V-K960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]I9&5N=&ET:65S*2!\
M?"`H8V]U;G0H)'1H:7,M/E]I9&5N=&ET:65S*2`\/2`P*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W!R;W!E<G1I97,@87,@)&ME>2D@>PH@
M("`@("`@("`@("`@("`@)&ED96YT:71Y6R1K97E=(#T@)'1H:7,M/E]P<F5F
M<RT^9V5T5F%L=64H)&ME>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*&5M<'1Y*"1I9&5N=&ET>5LG:60G72DI('L*("`@("`@("`@("`@("`@
M("1I9&5N=&ET>5LG:60G72`](%\H(D1E9F%U;'0@261E;G1I='DB*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET:65S(#T@
M87)R87DH)&ED96YT:71Y*3L*("`@("`@("`@("`@)'1H:7,M/G9E<FEF>2@P
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7W!R969S+3YI<TQO
M8VME9"@G9&5F875L=%]I9&5N=&ET>2<I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?<')O<&5R=&EE<R!A<R`D:V5Y*2!["B`@("`@("`@("`@
M("`@("`D=F%L=64@/2`D=&AI<RT^9V5T5F%L=64H)&ME>2D["B`@("`@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1V86QU92`](&EM<&QO9&4H(EQN(BP@)'9A;'5E*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E9G,M/G-E
M=%9A;'5E*"1K97DL("1V86QU92D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!R969S+3YS971$:7)T>2@D:V5Y+"!F86QS92D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E<R!A;&P@:61E
M;G1I=&EE<R!I;B!T:&4@<')E9G,@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V%V92@I"B`@("!["B`@("`@("`@)&ED96YT:71I97,@/2`D=&AI
M<RT^7VED96YT:71I97,["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9&5N=&ET
M:65S*2D@>PH@("`@("`@("`@("`D:61E;G1I=&EE<R`]("1T:&ES+3Y?<')E
M9G,M/F-O;G9E<G14;T1R:79E<B@D:61E;G1I=&EE<RP@3DQ3.CIG971#:&%R
M<V5T*"DI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]P<F5F<RT^<V5T
M5F%L=64H)VED96YT:71I97,G+"!S97)I86QI>F4H)&ED96YT:71I97,I+"!F
M86QS92D["B`@("`@("`@)'1H:7,M/E]P<F5F<RT^<V5T5F%L=64H)V1E9F%U
M;'1?:61E;G1I='DG+"`D=&AI<RT^7V1E9F%U;'0I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@061D<R!A(&YE=R!E;7!T>2!I9&5N=&ET>2!T;R!T:&4@87)R
M87D@;V8@:61E;G1I=&EE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1H92!P;VEN=&5R('1O('1H92!C<F5A=&5D(&ED96YT:71Y"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9"@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I
M9&5N=&ET:65S6UT@/2!A<G)A>2@I.PH@("`@("`@(')E='5R;B!C;W5N="@D
M=&AI<RT^7VED96YT:71I97,I("T@,3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V97,@86X@:61E;G1I='D@9G)O;2!T:&4@87)R87D@;V8@:61E;G1I
M=&EE<RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:61E;G1I='D@
M(%1H92!P;VEN=&5R('1O('1H92!I9&5N=&ET>2!T;R!B92!R96UO=F5D"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(')E;6]V960@:61E;G1I
M='D*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E*"1I9&5N=&ET>2D*("`@
M('L*("`@("`@("`D9&5L971E9"`](&%R<F%Y7W-P;&EC92@D=&AI<RT^7VED
M96YT:71I97,L("1I9&5N=&ET>2P@,2D["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]I9&5N=&ET:65S(&%S("1I9"`]/B`D;G5L;"D@>PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/G-E=$1E9F%U;'0H)&ED*2D@>PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/G-A=F4H*3L*("`@("`@("!R971U<FX@)&1E;&5T960["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<&]I;G1E<B!T;R!T:&4@8W5R<F5N
M="!D969A=6QT(&ED96YT:71Y+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE('!O:6YT97(@=&\@=&AE(&-U<G)E;G0@9&5F875L="!I9&5N
M=&ET>0H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D969A=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&4@8W5R<F5N="!D969A=6QT(&ED96YT:71Y+@H@
M("`@("H@268@=&AE(&ED96YT:71Y(&1O97-N)W0@97AI<W0L('1H92!O;&0@
M9&5F875L="!I9&5N=&ET>2!S=&%Y<R!T:&4@<V%M92X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D:61E;G1I='D@(%1H92!P;VEN=&5R('1O('1H
M92!N97<@9&5F875L="!I9&5N=&ET>0H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'0H)&ED96YT:71Y*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VED96YT:71I97-;)&ED96YT
M:71Y72DI('L*("`@("`@("`@("`@)'1H:7,M/E]D969A=6QT(#T@)&ED96YT
M:71Y.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A('!R;W!E<G1Y(&9R;VT@;VYE(&]F
M('1H92!I9&5N=&ET:65S+B!)9B!T:&ES('9A;'5E(&1O97-N)W0*("`@("`J
M(&5X:7-T(&]R(&ES(&QO8VME9"P@=&AE('!R;W!E<G1Y(&ES(')E=')I979E
M9"!F<F]M('1H92!P<F5F<R!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ME>2`@("`@("`@5&AE('!R;W!E<G1Y('1O(')E=')I979E
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED96YT:71Y("!4:&4@:61E;G1I
M='D@=&\@<F5T<FEE=F4@=&AE('!R;W!E<G1Y(&9R;VTN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE('9A;'5E(&]F('1H92!P<F]P97)T>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F%L=64H)&ME>2P@)&ED96YT:71Y
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1I9&5N=&ET>2D@
M?'P@(6ES<V5T*"1T:&ES+3Y?:61E;G1I=&EE<ULD:61E;G1I='E=*2D@>PH@
M("`@("`@("`@("`D:61E;G1I='D@/2`D=&AI<RT^7V1E9F%U;'0["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?:61E;G1I=&EE<ULD
M:61E;G1I='E=6R1K97E=*2!\?"`D=&AI<RT^7W!R969S+3YI<TQO8VME9"@D
M:V5Y*2D@>PH@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P<F5F<RT^9V5T
M5F%L=64H)&ME>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9A
M;"`]("1T:&ES+3Y?:61E;G1I=&EE<ULD:61E;G1I='E=6R1K97E=.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1V86P["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&%N(&%R<F%Y('=I=&@@=&AE('-P96-I9FEE9"!P<F]P
M97)T>2!F<F]M(&%L;"!E>&ES=&EN9PH@("`@("H@:61E;G1I=&EE<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!P<F]P97)T>2!T
M;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M87)R87D@=VET:"!T:&4@=F%L=65S(&9R;VT@86QL(&ED96YT:71I97,*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T06QL*"1K97DI"B`@("!["B`@("`@("`@
M)&QI<W0@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:61E
M;G1I=&EE<R!A<R`D:61E;G1I='D@/3X@)&YU;&PI('L*("`@("`@("`@("`@
M)&QI<W1;)&ED96YT:71Y72`]("1T:&ES+3YG971686QU92@D:V5Y+"`D:61E
M;G1I='DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&QI<W0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S(&$@<')O<&5R='D@=VET:"!A('-P96-I
M9FEE9"!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@
M("`@("`@(%1H92!P<F]P97)T>2!T;R!S970*("`@("`J($!P87)A;2!M:7AE
M9"`D=F%L("`@("`@("`@5&AE('9A;'5E('1O('=H:6-H('1H92!P<F]P97)T
M>2!S:&]U;&0@8F4@<V5T"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:61E;G1I
M='D@(%1H92!I9&5N=&ET>2!T;R!S970@=&AE('!R;W!E<G1Y(&EN+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!F86EL=7)E("AP<F]P97)T>2!W87,@;&]C:V5D*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971686QU92@D:V5Y+"`D=F%L+"`D:61E;G1I='D@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&ED96YT:71Y*2D@
M>PH@("`@("`@("`@("`D:61E;G1I='D@/2`D=&AI<RT^7V1E9F%U;'0["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?<')E9G,M/FES3&]C:V5D
M*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:61E;G1I=&EE<ULD:61E
M;G1I='E=6R1K97E=(#T@)'9A;#L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I
M9B!A;&P@<')O<&5R=&EE<R!A<F4@;&]C:V5D(&%N9"!T:&5R969O<F4@;F]T
M:&EN9R!I;B!T:&4*("`@("`J(&ED96YT:71I97,@8V%N(&)E(&-H86YG960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&%L;"!P
M<F]P97)T:65S(&%R92!L;V-K960L(&9A;'-E(&]T:&5R=VES90H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<TQO8VME9"@I"B`@("!["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]P<F]P97)T:65S(&%S("1K97DI('L*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^7W!R969S+3YI<TQO8VME9"@D:V5Y*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=')U92!I9B!T:&4@9VEV96X@861D<F5S<R!B96QO;F=S('1O
M(&]N92!O9B!T:&4@:61E;G1I=&EE<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1K97D@("`@5&AE(&ED96YT:71Y(&ME>2!T;R!S96%R8V@N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('9A;'5E('1O('-E87)C
M:"!F;W(@:6X@)&ME>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE("1V86QU92!W87,@9F]U;F0@:6X@)&ME>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:&%S5F%L=64H)&ME>2P@)'9A;'5E02D*("`@('L*
M("`@("`@("`D;&ES="`]("1T:&ES+3YG971!;&PH)&ME>2D["B`@("`@("`@
M9F]R96%C:"`H)&QI<W0@87,@)'9A;'5E0BD@>PH@("`@("`@("`@("!I9B`H
M<W1R<&]S*%-T<FEN9SHZ;&]W97(H)'9A;'5E02DL(%-T<FEN9SHZ;&]W97(H
M)'9A;'5E0BDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@5F5R:69I97,@86YD('-A
M;FET:7IE<R!A;&P@:61E;G1I='D@<')O<&5R=&EE<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D:61E;G1I='D@(%1H92!I9&5N=&ET>2!T;R!V
M97)I9GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L?&]B:F5C="`@5')U
M92!I9B!T:&4@<')O<&5R=&EE<R!A<F4@=F%L:60@;W(@82!014%27T5R<F]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!W:71H(&%N(&5R<F]R(&1E
M<V-R:7!T:6]N(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=F5R
M:69Y*"1I9&5N=&ET>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<W-E
M="@D:61E;G1I='DI*2!["B`@("`@("`@("`@("1I9&5N=&ET>2`]("1T:&ES
M+3Y?9&5F875L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/F=E
M=%9A;'5E*"=I9"<L("1I9&5N=&ET>2DI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=%9A;'5E*"=I9"<L(%\H(E5N;F%M960B*2P@)&ED96YT:71Y*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%)&0R`R.#(R(%LS+C(N-5T@9&]E<R!N;W0@
M86QL;W<@=&AE("=<)R!C:&%R86-T97(@=&\@8F4@=7-E9"!I;B!T:&4*("`@
M("`@("`@*B!P97)S;VYA;"!P;W)T:6]N(&]F(&%N(&4M;6%I;"!S=')I;F<N
M("HO"B`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^9V5T5F%L=64H)V9U;&QN
M86UE)RP@)&ED96YT:71Y*2P@)UQ<)RD@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(EEO=2!C86YN;W0@:&%V
M92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'96YE<F%T97,@=&AE(&9R;VT@861D<F5S<R!T;R!U<V4@9F]R
M('1H92!D969A=6QT(&ED96YT:71Y+@H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1F=6QL;F%M92`@26YC;'5D92!T:&4@9G5L;&YA;64@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D969A
M=6QT(&9R;VT@861D<F5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F
M875L=$9R;VU!9&1R97-S*"1F=6QL;F%M92`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1F<F]M7V%D9'(@/2`G)SL*"B`@("`@("`@:68@*"1F=6QL;F%M92D@
M>PH@("`@("`@("`@("`D;F%M92`]("1T:&ES+3YG971686QU92@G9G5L;&YA
M;64G*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;F%M92DI('L*("`@("`@
M("`@("`@("`@("1F<F]M7V%D9'(@/2`D;F%M92`N("<@)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&%D9'(@/2`D=&AI<RT^9V5T5F%L
M=64H)V9R;VU?861D<B<I.PH@("`@("`@(&EF("AE;7!T>2@D861D<BDI('L*
M("`@("`@("`@("`@)&%D9'(@/2!!=71H.CIG971!=71H*"D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&9R;VU?861D<B`N("<\)R`N("1A9&1R("X@
M)SXG.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@8V]N8W)E=&4@261E;G1I='D@:6YS=&%N8V4@8F%S960@;VX@)'1Y<&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1T>7!E("`@5&AE('1Y<&4@
M;V8@8V]N8W)E=&4@261E;G1I='D@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@5&AI<R!I<R!B87-E9"!O;B!T:&4@
M<W1O<F%G92!D<FEV97(@*"1T>7!E*2X@5&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+B!)9B`D
M='EP92!I<R!A;B!A<G)A>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M('1H96X@=V4@=VEL;"!L;V]K(&EN("1T>7!E6S!=+VQI8B])9&5N=&ET>2\@
M9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&4@<W5B8VQA<W,@
M:6UP;&5M96YT871I;VX@;F%M960@)'1Y<&5;,5TN<&AP+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<B`@268@<W!E8VEF:65D+"!W92!R96%D(&%N;W1H
M97(@=7-E<B=S(&ED96YT:71I97,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(&EN<W1E860@;V8@=&AE(&-U<G)E;G0@=7-E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N($ED96YT:71Y("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M92!)9&5N=&ET>2!I;G-T86YC92P@;W(@9F%L<V4*("`@("`J("`@("`@("`@
M("`@("`@("`@(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F%C=&]R>2@D='EP92`]("=N;VYE)RP@)'5S97(@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D='EP92DI('L*("`@("`@("`@("`@)&%P
M<"`]("1T>7!E6S!=.PH@("`@("`@("`@("`D='EP92`]("1T>7!E6S%=.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N(&$@8F%S92!)9&5N=&ET>2!O
M8FIE8W0@:68@;F\@9')I=F5R(&ES('-P96-I9FEE9"X@*B\*("`@("`@("`D
M='EP92`](&)A<V5N86UE*"1T>7!E*3L*("`@("`@("!I9B`H96UP='DH)'1Y
M<&4I('Q\("AS=')C;7`H)'1Y<&4L("=N;VYE)RD@/3T@,"DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E(#T@)FYE=R!)9&5N=&ET>2@D=7-E<BD["B`@("`@
M("`@("`@("1I;G-T86YC92T^:6YI="@I.PH@("`@("`@("`@("!R971U<FX@
M)&EN<W1A;F-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+TED96YT:71Y
M+R<@+B`D='EP92`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?
M97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R])9&5N=&ET>2\G("X@)'1Y
M<&4@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O261E;G1I='DO)R`N("1T>7!E("X@)RYP:'`G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@
M)TAO<F1E+TED96YT:71Y+R<@+B`D='EP92`N("<N<&AP)SL*("`@("`@("!]
M"B`@("`@("`@)&-L87-S(#T@)TED96YT:71Y7R<@+B`D='EP93L*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&EN
M<W1A;F-E(#T@)FYE=R`D8VQA<W,H)'5S97(I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;&%S<R!D
M969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@
M("`@("!]"@H@("`@("`@("1I;G-T86YC92T^:6YI="@I.PH@("`@("`@(')E
M='5R;B`D:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T
M<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!)9&5N=&ET
M>2!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)'1Y<&4N($ET('=I;&P@;VYL
M>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@261E;G1I='D@:6YS=&%N
M8V4@=VET:`H@("`@("H@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@
M97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@
M;75L=&EP;&4@='EP97,@;V8@:61E;G1I=&EE<R`H86YD+"!T:'5S+`H@("`@
M("H@;75L=&EP;&4@261E;G1I='D@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S
M.B`D=F%R(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D='EP92`@(%1H92!T>7!E(&]F(&-O;F-R971E($ED
M96YT:71Y('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@(%1H:7,@:7,@8F%S960@;VX@=&AE('-T;W)A9V4@9')I=F5R
M("@D='EP92DN(%1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@8V]D
M92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@)'1Y<&4@:7,@86X@87)R
M87DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&5N('=E('=I;&P@
M;&]O:R!I;B`D='EP95LP72]L:6(O261E;G1I='DO(&9O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@=&AE('-U8F-L87-S(&EM<&QE;65N=&%T:6]N
M(&YA;65D("1T>7!E6S%=+G!H<"X*("`@("`J($!P87)A;2!S=')I;F<@)'5S
M97(@($EF('-P96-I9FEE9"P@=V4@<F5A9"!A;F]T:&5R('5S97(G<R!I9&5N
M=&ET:65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F
M('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0')E='5R;B!)9&5N
M=&ET>2`@5&AE(&-O;F-R971E($ED96YT:71Y(')E9F5R96YC92P@;W(@9F%L
M<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T
M;VXH)'1Y<&4@/2`G;F]N92<L("1U<V5R(#T@;G5L;"D*("`@('L*("`@("`@
M("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T
M86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@
M("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A
M>2@D='EP92P@)'5S97(I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC
M97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I
M9VYA='5R95T@/2`F261E;G1I='DZ.F9A8W1O<GDH)'1Y<&4L("1U<V5R*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=.PH@("`@?0H*?0H``````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY/8FIE
M8W1S+G!H<```````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-34R-@`Q
M,#4Q-30S,3`V,0`P,C$V-S,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]397-S:6]N
M3V)J96-T<SHZ(&-L87-S('!R;W9I9&5S(&$@=V%Y(&9O<B!S=&]R:6YG(&1A
M=&$*("H@*'5S=6%L;'DL(&)U="!N;W0@;F5C97-S87)I;'DL(&]B:F5C=',I
M(&EN('1H92!C=7)R96YT('5S97(G<PH@*B!S97-S:6]N+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]397-S:6]N3V)J96-T<R]397-S:6]N3V)J96-T<RYP
M:'`L=B`Q+C8N,3(N."`R,#`V+S`Q+S`Q(#(Q.C(X.C,U(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=7$*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?4V5S<VEO;D]B:F5C=',*("HO
M"F-L87-S($AO<F1E7U-E<W-I;VY/8FIE8W1S('L*"B`@("`O*BH*("`@("`J
M(%1H92!L:7-T(&]F(&]I9',@=&\@<')U;F4@870@=&AE(&5N9"!O9B!A(')E
M<75E<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]P<G5N94QI<W0@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(&YA
M;64@;V8@=&AE('-T;W)E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7VYA;64@/2`G:&]R9&5?<V5S<VEO;E]O8FIE8W1S
M)SL*"B`@("`O*BH*("`@("`J($%L;&]W('-T;W)E*"D@=&\@;W9E<G=R:71E
M(&-U<G)E;G0@;V)J96-T<S\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?;W9E<G=R:71E(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;6%X:6UU;2!N=6UB97(@;V8@;V)J96-T<R!T:&%T('1H
M92!S=&]R92!S:&]U;&0@:&]L9"X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G
M97(*("`@("`J+PH@("`@=F%R("1?<VEZ92`](#(P.PH*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@9VQO8F%L($AO<F1E7U-E
M<W-I;VY/8FIE8W1S(&]B:F5C="P*("`@("`J(&]N;'D@8W)E871I;F<@:70@
M:68@:70@9&]E<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J("`@)&]B:F5C
M='-T;W)E(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*
M("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U-E<W-I;VY/8FIE8W1S("!4
M:&4@2&]R9&5?4V5S<VEO;D]B:F5C=',@:6YS=&%N8V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D
M;V)J96-T.PH*("`@("`@("!I9B`H(6ES<V5T*"1O8FIE8W0I*2!["B`@("`@
M("`@("`@("1O8FIE8W0@/2!N97<@2&]R9&5?4V5S<VEO;D]B:F5C=',H*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97(@87)R87DN"B`@("`@*B`\
M<')E/@H@("`@("H@3W!T:6]N86P@4&%R86UE=&5R<SH*("`@("`J("=N86UE
M)R`@+2T@(%1H92!N86UE(&]F('1H92!S97-S:6]N('9A<FEA8FQE('1O('-T
M;W)E('1H92!O8FIE8W1S(&EN+@H@("`@("H@)W-I>F4G("`M+2`@5&AE(&UA
M>&EM=6T@<VEZ92!O9B!T:&4@*&YO;BUP<G5N86)L92D@;V)J96-T('-T;W)E
M+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U-E
M<W-I;VY/8FIE8W1S*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=N86UE)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;F%M92`]("1P87)A;7-;)VYA;64G73L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D<&%R86US6R=S:7IE)UTI("8F(&ES7VEN="@D<&%R
M86US6R=S:7IE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VEZ92`]("1P
M87)A;7-;)W-I>F4G73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!7<F%P<&5R(&%R;W5N9"!S=&]R92!T:&%T('=I;&P@<F5T=7)N('1H92!O
M:60@:6YS=&5A9"X*("`@("`J"B`@("`@*B!`<V5E('-T;W)E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@("!4:&4@9&%T82!T;R!S=&]R
M92!I;B!T:&4@<V5S<VEO;B!S=&]R92X*("`@("`J($!P87)A;2!B;V]L96%N
M("1P<G5N92`@268@9F%L<V4L('1H:7,@;V)J96-T('=I;&P@;F]T(&)E('!R
M=6YE9"!F<F]M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S
M=&]R92!I9B!T:&4@;6%X:6UU;2!S=&]R92!S:7IE(&ES(&5X8V5E9&5D+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@340U('-T<FEN9R!R
M97!R97-E;G1I;F<@=&AE(&]B:F5C="=S($E$+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S=&]R94]I9"@D9&%T82P@)'!R=6YE(#T@=')U92D*("`@('L*("`@
M("`@("`D;VED(#T@)'1H:7,M/F]I9"@D9&%T82D["B`@("`@("`@)'1H:7,M
M/G-T;W)E*"1O:60L("1D871A+"`D<')U;F4I.PH@("`@("`@(')E='5R;B`D
M;VED.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<W1O<F4@
M86X@;V)J96-T(&EN('1H92!S97-S:6]N('-T;W)E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]I9"`@("`@3V)J96-T($E$('5S960@87,@=&AE
M('-T;W)A9V4@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@("!4
M:&4@9&%T82!T;R!S=&]R92!I;B!T:&4@<V5S<VEO;B!S=&]R92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1P<G5N92`@268@9F%L<V4L('1H:7,@;V)J96-T
M('=I;&P@;F]T(&)E('!R=6YE9"!F<F]M('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!S=&]R92!I9B!T:&4@;6%X:6UU;2!S=&]R92!S:7IE
M(&ES(&5X8V5E9&5D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S=&]R92@D;VED+"`D9&%T82P@)'!R=6YE(#T@=')U92D*
M("`@('L*("`@("`@("`O*B!3970@=7`@;V)J96-T(&YO=RX@*B\*("`@("`@
M("`D9&%T84]B:F5C="`](&%R<F%Y*"D["B`@("`@("`@)&1A=&%/8FIE8W1;
M)V1A=&$G72`]('-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@)&1A=&%/8FIE
M8W1;)W!R=6YE)UT@/2`D<')U;F4["@H@("`@("`@(&EF("@A:7-S970H)%]3
M15-324].6R1T:&ES+3Y?;F%M95TI*2!["B`@("`@("`@("`@("1?4T534TE/
M3ELD=&AI<RT^7VYA;65=(#T@87)R87DH*3L*("`@("`@("`@("`@)%]315-3
M24].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G72`](#`["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/E]O=F5R=W)I=&4@?'P@(6ES<V5T*"1?4T53
M4TE/3ELD=&AI<RT^7VYA;65=6R1O:61=*2D@>PH@("`@("`@("`@("`D7U-%
M4U-)3TY;)'1H:7,M/E]N86UE75LD;VED72`]("1D871A3V)J96-T.PH@("`@
M("`@("`@("!I9B`H)'!R=6YE*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)
M3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N92==*RL["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!P<G5N86)L92!/:61S
M+B`J+PH@("`@("`@("1T:&ES+3Y?<')U;F5/:61S*"D["@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@3W9E<G=R:71E<R!A
M(&-U<G)E;G0@96QE;65N="!I;B!T:&4@;V)J96-T('-T;W)E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&]I9"`@("`@3V)J96-T($E$('5S960@
M87,@=&AE('-T;W)A9V4@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A
M("`@("!4:&4@9&%T82!T;R!S=&]R92!I;B!T:&4@<V5S<VEO;B!S=&]R92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1P<G5N92`@268@9F%L<V4L('1H:7,@
M;V)J96-T('=I;&P@;F]T(&)E('!R=6YE9"!F<F]M('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!S=&]R92!I9B!T:&4@;6%X:6UU;2!S=&]R
M92!S:7IE(&ES(&5X8V5E9&5D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!O=F5R=W)I=&4H)&]I9"P@)&1A=&$L("1P<G5N
M92`]('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=F5R=W)I=&4@/2!T
M<G5E.PH@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/G-T;W)E*"1O:60L("1D
M871A+"`D<')U;F4I.PH@("`@("`@("1T:&ES+3Y?;W9E<G=R:71E(#T@9F%L
M<V4["B`@("`@("`@<F5T=7)N("1S=6-C97-S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@<F5T<FEV92!A;B!O8FIE8W0@9G)O;2!T:&4@
M<W1O<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VED("`@3V)J
M96-T($E$('1O('%U97)Y+@H@("`@("H@0'!A<F%M(&5N=6T@)'1Y<&4@("`@
M3D]4(%53140*("`@("`J($!P87)A;2!I;G1E9V5R("1V86P@($Y/5"!54T5$
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E<75E<W1E9"!O
M8FIE8W0L(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9Q=65R>2@D;VED+"`D='EP92`](&YU;&PL("1V86P@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)%]315-324].6R1T:&ES+3Y?;F%M
M95TI('Q\"B`@("`@("`@("`@("AI<U]N=6QL*"1O:60I('Q\("%I<W-E="@D
M7U-%4U-)3TY;)'1H:7,M/E]N86UE75LD;VED72DI*2!["B`@("`@("`@("`@
M("1O8FIE8W0@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;V)J96-T(#T@=6YS97)I86QI>F4H)%]315-324].6R1T:&ES+3Y?;F%M
M95U;)&]I9%U;)V1A=&$G72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@<')U;F4@
M9FQA9R!O;B!A('-T;W)E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1O:60@("`@(%1H92!O8FIE8W0@240N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D<')U;F4@(%1R=64@=&\@86QL;W<@<')U;FEN9RP@9F%L<V4@
M9F]R(&YO('!R=6YI;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%!R=6YE
M1FQA9R@D;VED+"`D<')U;F4I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?
M4T534TE/3ELD=&AI<RT^7VYA;65=6R1O:61=*2`F)@H@("`@("`@("`@("`H
M)%]315-324].6R1T:&ES+3Y?;F%M95U;)&]I9%U;)W!R=6YE)UT@(3T@)'!R
M=6YE*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LD
M;VED75LG<')U;F4G72`]("1P<G5N93L*("`@("`@("`@("`@:68@*"1P<G5N
M92D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;
M)U]?<')U;F4G72LK.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G72TM.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1V5N97)A=&5S(&%N($])1"!F;W(@86X@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D9&%T82`@5&AE(&1A=&$@=&\@<W1O<F4@:6X@=&AE
M('-T;W)E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("1O:60@($%N
M(&]B:F5C="!)1"!T;R!U<V4@87,@=&AE('-T;W)A9V4@:V5Y+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!O:60H)&1A=&$I"B`@("!["B`@("`@("`@<F5T=7)N
M(&UD-2AS97)I86QI>F4H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E('1H92!L:7-T(&]F('!R=6YA8FQE(&]I9',N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P
M<G5N94]I9',H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?
M<')U;F5,:7-T*2`F)@H@("`@("`@("`@("!I<W-E="@D7U-%4U-)3TY;)'1H
M:7,M/E]N86UE75LG7U]P<G5N92==*2`F)@H@("`@("`@("`@("`H)%]315-3
M24].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G72`^("1T:&ES+3Y?<VEZ92DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]P<G5N94QI<W0@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;)'1H:7,M/E]N86UE72!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("@D=F%L6R=P
M<G5N92==*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<G5N94QI
M<W1;72`]("1K97D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH
M)B1T:&ES+"`G7W!R=6YE)RDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%!R=6YE(&]L9"!S=&]R92!E;G1R:65S(&%T(')E<75E<W0@<VAU
M=&1O=VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]P<G5N92@I"B`@("!["B`@("`@("`@)'!R=6YE3VED
M<R`](&%R<F%Y7W-L:6-E*"1T:&ES+3Y?<')U;F5,:7-T+"`P+"`D7U-%4U-)
M3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N92==("T@)'1H:7,M/E]S:7IE*3L*
M("`@("`@("!F;W)E86-H("@D<')U;F5/:61S(&%S("1V86PI('L*("`@("`@
M("`@("`@=6YS970H)%]315-324].6R1T:&ES+3Y?;F%M95U;)'9A;%TI.PH@
M("`@("`@('T*("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LG7U]P
M<G5N92==("T](&-O=6YT*"1P<G5N94]I9',I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T)R;W=S97(N<&AP````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q,#8P-@`Q,#4Q-30S,3`V,0`P,C`S
M-30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*
M("H@5&AE($)R;W=S97(Z.B!C;&%S<R!P<F]V:61E<R!C87!A8FEL:71Y(&EN
M9F]R;6%T:6]N(&9O<B!T:&4@8W5R<F5N=`H@*B!W96(@8VQI96YT+@H@*@H@
M*B!"<F]W<V5R(&ED96YT:69I8V%T:6]N(&ES('!E<F9O<FUE9"!B>2!E>&%M
M:6YI;F<@=&AE($A45%!?55-%4E]!1T5.5`H@*B!E;G9I<F]N;65N="!V87)I
M86)L92!P<F]V:61E9"!B>2!T:&4@=V5B('-E<G9E<BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<"QV(#$N,34S+C(N-#<@
M,C`P-B\P-R\Q-R`P.3HU,CHP,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@
M/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]"<F]W<V5R"B`J+PIC;&%S<R!"<F]W<V5R('L*"B`@("`O
M*BH*("`@("`J($UA:F]R('9E<G-I;VX@;G5M8F5R+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M86IO<E9E<G-I;VX@
M/2`P.PH*("`@("\J*@H@("`@("H@36EN;W(@=F5R<VEO;B!N=6UB97(N"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VUI
M;F]R5F5R<VEO;B`](#`["@H@("`@+RHJ"B`@("`@*B!"<F]W<V5R(&YA;64N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M8G)O=W-E<B`]("<G.PH*("`@("\J*@H@("`@("H@1G5L;"!U<V5R(&%G96YT
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]A9V5N="`]("<G.PH*("`@("\J*@H@("`@("H@3&]W97(M8V%S
M92!U<V5R(&%G96YT('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]L;W=E<D%G96YT(#T@)R<["@H@("`@+RHJ
M"B`@("`@*B!(5%107T%#0T505"!S=')I;F<*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A8V-E<'0@/2`G)SL*"B`@("`O
M*BH*("`@("`J(%!L871F;W)M('1H92!B<F]W<V5R(&ES(')U;FYI;F<@;VXN
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M<&QA=&9O<FT@/2`G)SL*"B`@("`O*BH*("`@("`J($MN;W=N(')O8F]T<RX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W)O
M8F]T<R`](&%R<F%Y*`H@("`@("`@("\J(%1H92!M;W-T(&-O;6UO;B!O;F5S
M+B`J+PH@("`@("`@("=';V]G;&5B;W0G+`H@("`@("`@("=M<VYB;W0G+`H@
M("`@("`@("=3;'5R<"<L"B`@("`@("`@)UEA:&]O)RP*("`@("`@("`O*B!4
M:&4@<F5S="!A;'!H86)E=&EC86QL>2X@*B\*("`@("`@("`G87!P:64G+`H@
M("`@("`@("=!<F%C:&YO:61E82<L"B`@("`@("`@)T%R8VAI=&5X=%-P:61E
M<B<L"B`@("`@("`@)T%S:R!*965V97,G+`H@("`@("`@("="+6PM:2UT+7HM
M0F]T)RP*("`@("`@("`G0F%I9'5S<&ED97(G+`H@("`@("`@("="96-O;65"
M;W0G+`H@("`@("`@("=C9F5T8V@G+`H@("`@("`@("=#;VYV97)A0W)A=VQE
M<B<L"B`@("`@("`@)T5X=')A8W1O<E!R;R<L"B`@("`@("`@)T9!4U0M5V5B
M0W)A=VQE<B<L"B`@("`@("`@)T9$4T4@<F]B;W0G+`H@("`@("`@("=F:61O
M)RP*("`@("`@("`G9FEN9&QI;FMS)RP*("`@("`@("`G1G)A;F-I<R<L"B`@
M("`@("`@)V=E8VMO8F]T)RP*("`@("`@("`G1VEG86)O="<L"B`@("`@("`@
M)T=I<F%F86)O="<L"B`@("`@("`@)V=R=6(M8VQI96YT)RP*("`@("`@("`G
M1W5L;&EV97(G+`H@("`@("`@("=(5%1R86-K)RP*("`@("`@("`G:6%?87)C
M:&EV97(G+`H@("`@("`@("=I0T-R87=L97(G+`H@("`@("`@("=);F9O4V5E
M:R<L"B`@("`@("`@)VMI;FIA8F]T)RP*("`@("`@("`G2TE4+49I<F5B86QL
M)RP*("`@("`@("`G;&%R8FEN)RP*("`@("`@("`G3$5)02<L"B`@("`@("`@
M)VQM<W!I9&5R)RP*("`@("`@("`G;'=P+71R:79I86PG+`H@("`@("`@("=,
M>6-O<U]3<&ED97(G+`H@("`@("`@("=-961I87!A<G1N97)S+4=O;V=L92<L
M"B`@("`@("`@)TUU<V-A=$9E<G)E="<L"B`@("`@("`@)TYA=F5R0F]T)RP*
M("`@("`@("`G3VUN:45X<&QO<F5R7T)O="<L"B`@("`@("`@)W!O;'EB;W0G
M+`H@("`@("`@("=0;VUP;W,G+`H@("`@("`@("=2=69U<T)O="<L"B`@("`@
M("`@)U-C;V]T97(G+`H@("`@("`@("=3965K8F]T)RP*("`@("`@("`G<W!R
M;V]S92<L"B`@("`@("`@)U1E;VUA)RP*("`@("`@("`G5&AE4W5";W0G+`H@
M("`@("`@("=4=7)N:71I;D)O="<L"B`@("`@("`@)U5L=')A<V5E:R<L"B`@
M("`@("`@)U9I;VQA0F]T)RP*("`@("`@("`G=F]Y86=E<B<L"B`@("`@("`@
M)W=E8F)A;F1I="<L"B`@("`@("`@)W=W=RYA;&UA9&5N+FEB;2YC;VTO8W,O
M8W)A=VQE<B<L"B`@("`@("`@)WEA8WDG+`H@("`@("`@("=:>4)O<F<G+`H@
M("`@*3L*"B`@("`O*BH*("`@("`J($ES('1H:7,@82!M;V)I;&4@8G)O=W-E
M<C\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?;6]B:6QE(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!&96%T=7)E<RX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V9E
M871U<F5S(#T@87)R87DH"B`@("`@("`@)VAT;6PG("`@("`@(#T^('1R=64L
M"B`@("`@("`@)VAD;6PG("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=W;6PG
M("`@("`@("`]/B!F86QS92P*("`@("`@("`G:6UA9V5S)R`@("`@/3X@=')U
M92P*("`@("`@("`G:69R86UE<R<@("`@/3X@9F%L<V4L"B`@("`@("`@)V9R
M86UE<R<@("`@(#T^('1R=64L"B`@("`@("`@)W1A8FQE<R<@("`@(#T^('1R
M=64L"B`@("`@("`@)VIA=F$G("`@("`@(#T^('1R=64L"B`@("`@("`@)VIA
M=F%S8W)I<'0G(#T^('1R=64L"B`@("`@("`@)V1O;2<@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("=U=&8G("`@("`@("`]/B!F86QS92P*("`@("`@("`G
M<G1E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VAO;65P86=E)R`@(#T^
M(&9A;'-E+`H@("`@("`@("=A8V-E<W-K97DG("`]/B!F86QS92P*("`@("`@
M("`G;W!T9W)O=7`G("`@/3X@9F%L<V4L"B`@("`@("`@)WAM;&AT='!R97$G
M(#T^(&9A;'-E+`H@("`@("`@("=C:71E)R`@("`@("`]/B!F86QS92P*("`@
M("D["@H@("`@+RHJ"B`@("`@*B!1=6ER:W,*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W%U:7)K<R`](&%R<F%Y*`H@("`@
M("`@("=A=F]I9%]P;W!U<%]W:6YD;W=S)R`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@)V)R96%K7V1I<W!O<VET:6]N7VAE861E<B<@("`]/B!F86QS92P*
M("`@("`@("`G8G)E86M?9&ES<&]S:71I;VY?9FEL96YA;64G(#T^(&9A;'-E
M+`H@("`@("`@("=B<F]K96Y?;75L=&EP87)T7V9O<FTG("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@)V)U9V=Y7V-O;7!R97-S:6]N)R`@("`@("`@("`]/B!F
M86QS92P*("`@("`@("`G8V%C:&5?<V%M95]U<FPG("`@("`@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("=C86-H95]S<VQ?9&]W;FQO861S)R`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)V1O=6)L95]L:6YE8G)E86M?=&5X=&%R96$G
M("`]/B!F86QS92P*("`@("`@("`G96UP='E?9FEL95]I;G!U=%]V86QU92<@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=M=7-T7V-A8VAE7V9O<FUS)R`@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VYO7V9I;&5N86UE7W-P86-E<R<@
M("`@("`@("`]/B!F86QS92P*("`@("`@("`G;F]?:&ED9&5N7V]V97)F;&]W
M7W1A8FQE<R<@(#T^(&9A;'-E+`H@("`@("`@("=O=U]G=6E?,2XS)R`@("`@
M("`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W!N9U]T<F%N<W!A<F5N
M8WDG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G<V-R;VQL8F%R7VEN
M7W=A>2<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=S8W)O;&Q?=&1S
M)R`@("`@("`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W=I;F1O=V5D
M7V-O;G1R;VQS)R`@("`@("`@("`]/B!F86QS92P*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!,:7-T(&]F('9I97=A8FQE(&EM86=E($U)344@<W5B='EP97,N
M"B`@("`@*B!4:&ES(&QI<W0@;V8@=FEE=V%B;&4@:6UA9V5S('=O<FMS(&9O
M<B!)12!A;F0@3F5T<V-A<&4O36]Z:6QL82X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VEM86=E<R`](&%R<F%Y*"=J<&5G
M)RP@)V=I9B<L("=P;F<G+"`G<&IP96<G+"`G>"UP;F<G+"`G8FUP)RD["@H@
M("`@+RHJ"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O
M('1H92!G;&]B86P@0G)O=W-E<B!O8FIE8W0L(&]N;'D@8W)E871I;F<@:70*
M("`@("`J(&EF(&ET(&1O97-N)W0@86QR96%D>2!E>&ES="X*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z/'!R93X*("`@
M("`J("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*%LD=7-E<D%G
M96YT6RP@)&%C8V5P=%U=*3L\+W!R93X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R06=E;G0@(%1H92!B<F]W<V5R('-T<FEN9R!T;R!P87)S
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5P="`@("`@5&AE($A45%!?
M04-#15!4('-E='1I;F=S('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($)R;W=S97(@(%1H92!"<F]W<V5R(&]B:F5C="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)G-I;F=L971O;B@D=7-E<D%G96YT(#T@;G5L;"P@)&%C8V5P="`]
M(&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@
M("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN
M<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T
M=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1U<V5R06=E;G0L("1A8V-E<'0I*3L*
M("`@("`@("!I9B`H96UP='DH)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`](&YE=R!"<F]W
M<V5R*"1U<V5R06=E;G0L("1A8V-E<'0I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&4@82!B<F]W<V5R(&EN<W1A;F-E("A#;VYS=')U8W1O
M<BDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<D%G96YT("!4
M:&4@8G)O=W-E<B!S=')I;F<@=&\@<&%R<V4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A8V-E<'0@("`@(%1H92!(5%107T%#0T505"!S971T:6YG<R!T;R!U
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N($)R;W=S97(H)'5S97)!9V5N="`]
M(&YU;&PL("1A8V-E<'0@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3YM
M871C:"@D=7-E<D%G96YT+"`D86-C97!T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!A<G-E<R!T:&4@=7-E<B!A9V5N="!S=')I;F<@86YD(&EN:71I=&EA
M;&EZ97,@=&AE(&]B:F5C="!W:71H"B`@("`@*B!A;&P@=&AE(&MN;W=N(&9E
M871U<F5S(&%N9"!Q=6ER:W,@9F]R('1H92!G:79E;B!B<F]W<V5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)!9V5N="`@5&AE(&)R;W=S
M97(@<W1R:6YG('1O('!A<G-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-C
M97!T("`@("!4:&4@2%144%]!0T-%4%0@<V5T=&EN9W,@=&\@=7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!M871C:"@D=7-E<D%G96YT(#T@;G5L;"P@)&%C
M8V5P="`](&YU;&PI"B`@("!["B`@("`@("`@+R\@4V5T(&]U<B!A9V5N="!S
M=')I;F<N"B`@("`@("`@:68@*&ES7VYU;&PH)'5S97)!9V5N="DI('L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=(5%107U5315)?04=%3E0G
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?86=E;G0@/2!T<FEM*"1?
M4T525D526R=(5%107U5315)?04=%3E0G72D["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V%G96YT(#T@)'5S
M97)!9V5N=#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]L;W=E<D%G96YT
M(#T@4W1R:6YG.CIL;W=E<B@D=&AI<RT^7V%G96YT*3L*"B`@("`@("`@+R\@
M4V5T(&]U<B!A8V-E<'0@<W1R:6YG+@H@("`@("`@(&EF("AI<U]N=6QL*"1A
M8V-E<'0I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG2%14
M4%]!0T-%4%0G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?86-C97!T
M(#T@4W1R:6YG.CIL;W=E<BAT<FEM*"1?4T525D526R=(5%107T%#0T505"==
M*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^7V%C8V5P="`](%-T<FEN9SHZ;&]W97(H)&%C8V5P="D["B`@
M("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@551&('-U<'!O<G0N"B`@
M("`@("`@:68@*&ES<V5T*"1?4T525D526R=(5%107T%#0T505%]#2$%24T54
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G+"!S
M=')P;W,H4W1R:6YG.CIL;W=E<B@D7U-%4E9%4ELG2%144%]!0T-%4%1?0TA!
M4E-%5"==*2P@)W5T9B<I("$]/2!F86QS92D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?86=E;G0I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<V5T4&QA=&9O<FTH*3L*"B`@("`@("`@("`@(&EF("AS=')P;W,H
M)'1H:7,M/E]L;W=E<D%G96YT+"`G;6]B:6QE97AP;&]R97(G*2`A/3T@9F%L
M<V4@?'P*("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^7VQO=V5R06=E
M;G0L("=O<&5N=V%V92<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@
M<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V]P97)A(&UI;FDG*2`A/3T@
M9F%L<V4@?'P*("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^7VQO=V5R
M06=E;G0L("=O<&5R86UI;FDG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=F<F%M97,G+"!F86QS92D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A
M;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G879O:61?
M<&]P=7!?=VEN9&]W<R<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I
M;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G
M?$]P97)A6R\@72A;,"TY+ETK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO
M;BDI('L*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R
M*"=O<&5R82<I.PH@("`@("`@("`@("`@("`@("`@("`@;&ES="@D=&AI<RT^
M7VUA:F]R5F5R<VEO;BP@)'1H:7,M/E]M:6YO<E9E<G-I;VXI(#T@97AP;&]D
M92@G+B<L("1V97)S:6]N6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@=')U92D["B`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)VYO7V9I;&5N86UE7W-P
M86-E<R<I.PH*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VUA:F]R5F5R
M<VEO;B`^/2`W*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=I9G)A;65S)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U<"<I.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS9711=6ER:R@G9&]U8FQE7VQI;F5B<F5A:U]T97AT
M87)E82<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I
M9B`H<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V5L86EN92\G*2`A/3T@
M9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^
M7VQO=V5R06=E;G0L("=P86QM<V]U<F-E)RD@(3T](&9A;'-E('Q\"B`@("`@
M("`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G
M9&EG:71A;"!P871H<R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$)R;W=S97(H)W!A;&TG*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=I;6%G97,G+"!F86QS92D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G9G)A;65S)RP@9F%L<V4I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F
M86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED
M7W!O<'5P7W=I;F1O=W,G*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B
M:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"AP<F5G7VUA=&-H
M*"=\35-)12`H6S`M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI
M*2!\?`H@("`@("`@("`@("`@("`@("`@("`@*'!R96=?;6%T8V@H)WQ);G1E
M<FYE="!%>'!L;W)E<B\H6S`M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E
M<G-I;VXI*2D@>PH*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R
M*"=M<VEE)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V-A
M8VAE7W-S;%]D;W=N;&]A9',G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M9711=6ER:R@G8V%C:&5?<V%M95]U<FPG*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS9711=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?9FEL96YA;64G*3L*
M"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V97)S:6]N6S%=+"`G+B<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)'1H:7,M
M/E]M86IO<E9E<G-I;VXL("1T:&ES+3Y?;6EN;W)697)S:6]N*2`](&5X<&QO
M9&4H)RXG+"`D=F5R<VEO;ELQ72D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%J;W)697)S:6]N(#T@
M)'9E<G-I;VY;,5T["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M:6YO
M<E9E<G-I;VX@/2`P.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\J($E%("@\(#<I(&]N(%=I;F1O=W,@9&]E<R!N;W0@<W5P<&]R="!A
M;'!H82!T<F%N<W!A<F5N8WD@:6X*("`@("`@("`@("`@("`@("`J(%!.1R!I
M;6%G97,N("HO"B`@("`@("`@("`@("`@("!I9B`H*"1T:&ES+3Y?;6%J;W)6
M97)S:6]N(#P@-RD@)B8*("`@("`@("`@("`@("`@("`@("!P<F5G7VUA=&-H
M*"<O=VEN9&]W<R]I)RP@)'1H:7,M/E]A9V5N="DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T475I<FLH)W!N9U]T<F%N<W!A<F5N8WDG*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!)12`V("AP
M<F4M4U`Q*2!A;F0@-2XU("AP<F4M4U`Q*2!H879E(&)U9V=Y(&-O;7!R97-S
M:6]N+@H@("`@("`@("`@("`@("`@("H@5&AE('9E<G-I;VYS(&%F9F5C=&5D
M(&%R92!A<R!F;VQL;W=S.@H@("`@("`@("`@("`@("`@("H@-BXP,"XR-#8R
M+C`P,#`@($EN=&5R;F5T($5X<&QO<F5R(#8@4'5B;&EC(%!R979I97<@*$)E
M=&$I"B`@("`@("`@("`@("`@("`@*B`V+C`P+C(T-SDN,#`P-B`@26YT97)N
M970@17AP;&]R97(@-B!0=6)L:6,@4')E=FEE=R`H0F5T82D*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@4F5F<F5S:`H@("`@("`@("`@
M("`@("`@("H@-BXP,"XR-C`P+C`P,#`@($EN=&5R;F5T($5X<&QO<F5R(#8@
M*%=I;F1O=W,@6%`I"B`@("`@("`@("`@("`@("`@*B`U+C4P+C,X,C4N,3,P
M,"`@26YT97)N970@17AP;&]R97(@-2XU($1E=F5L;W!E<B!0<F5V:65W("A"
M971A*0H@("`@("`@("`@("`@("`@("H@-2XU,"XT,#,P+C(T,#`@($EN=&5R
M;F5T($5X<&QO<F5R(#4N-2`F($EN=&5R;F5T(%1O;VQS($)E=&$*("`@("`@
M("`@("`@("`@("`J(#4N-3`N-#$S-"XP,3`P("!);G1E<FYE="!%>'!L;W)E
M<B`U+C4@9F]R(%=I;F1O=W,@364@*#0N.3`N,S`P,"D*("`@("`@("`@("`@
M("`@("`J(#4N-3`N-#$S-"XP-C`P("!);G1E<FYE="!%>'!L;W)E<B`U+C4*
M("`@("`@("`@("`@("`@("`J(#4N-3`N-#,P."XR.3`P("!);G1E<FYE="!%
M>'!L;W)E<B`U+C4@061V86YC960@4V5C=7)I='D@4')I=F%C>2!"971A"B`@
M("`@("`@("`@("`@("`@*@H@("`@("`@("`@("`@("`@("H@4V5E.@H@("`@
M("`@("`@("`@("`@("H@/3T]/0H@("`@("`@("`@("`@("`@("H@:'1T<#HO
M+W-U<'!O<G0N;6EC<F]S;V9T+F-O;2]K8B\Q-C0U,SD["B`@("`@("`@("`@
M("`@("`@*B!H='1P.B\O<W5P<&]R="YM:6-R;W-O9G0N8V]M+V1E9F%U;'0N
M87-P>#]S8VED/6MB.V5N+75S.U$S,3(T.38I"B`@("`@("`@("`@("`@("`@
M*B!H='1P.B\O<W5P<&]R="YM:6-R;W-O9G0N8V]M+V1E9F%U;'0N87-P>#]S
M8VED/6MB.V5N+75S.U$S,3,W,3(*("`@("`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`@("`@)&EE7W9E<G,@/2`D=&AI<RT^9V5T245697)S:6]N*"D[
M"B`@("`@("`@("`@("`@("`D8G5G9WE?;&ES="`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("<V+#`P+#(T-C(L,#`P,"<L("<V+#`P+#(T-SDL,#`P
M-B<L("<V+#`P+#(V,#`L,#`P,"<L"B`@("`@("`@("`@("`@("`@("`@)S4L
M-3`L,S@R-2PQ,S`P)RP@)S4L-3`L-#`S,"PR-#`P)RP@)S4L-3`L-#$S-"PP
M,3`P)RP*("`@("`@("`@("`@("`@("`@("`G-2PU,"PT,3,T+#`V,#`G+"`G
M-2PU,"PT,S`X+#(Y,#`G"B`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@:68@*"%I<U]N=6QL*"1I95]V97)S*2`F)B!I;E]A<G)A>2@D:65?
M=F5R<RP@)&)U9V=Y7VQI<W0I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=%%U:7)K*"=B=6=G>5]C;VUP<F5S<VEO;B<I.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("\J(%-O;64@2&%N9&AE;&1S(&AA
M=F4@=&AE:7(@<V-R965N(')E<V]L=71I;VX@:6X@=&AE"B`@("`@("`@("`@
M("`@("`@*B!U<V5R(&%G96YT('-T<FEN9RP@=VAI8V@@=V4@8V%N('5S92!T
M;R!L;V]K(&9O<@H@("`@("`@("`@("`@("`@("H@;6]B:6QE(&%G96YT<RX@
M*B\*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O.R`H,3(P>#$V
M,'PR-#!X,C@P?#(T,'@S,C!\,S(P>#,R,"E<*2\G+"`D=&AI<RT^7V%G96YT
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U
M93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1T:&ES+3Y?;6%J;W)697)S:6]N*2!["B`@("`@("`@("`@("`@("!C87-E
M(#<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA
M=F%S8W)I<'0G+"`Q+C0I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=D;VTG*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G:69R86UE<R<I.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G<G1E)RD["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)VAO;65P86=E)RD["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U<"<I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X;6QH='1P
M<F5Q)RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`V.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=J879A<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=71F)RD["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W)T92<I.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H;VUE<&%G92<I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=A8V-E<W-K97DG
M*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G;W!T
M9W)O=7`G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G>&UL:'1T<')E<2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M9711=6ER:R@G<V-R;VQL8F%R7VEN7W=A>2<I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS9711=6ER:R@G8G)O:V5N7VUU;'1I<&%R=%]F;W)M)RD[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=W:6YD;W=E
M9%]C;VYT<F]L<R<I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@-3H*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/F=E=%!L871F;W)M*"D@/3T@)VUA8R<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q
M+C(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G;W!T9W)O=7`G*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!-4TE%(#4@9F]R(%=I;F1O=W,N
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J
M879A<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G>&UL:'1T<')E<2<I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]M:6YO<E9E<G-I;VX@/CT@-2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)W)T92<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=%%U:7)K*"=W:6YD;W=E9%]C;VYT<F]L<R<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I9G)A;65S)RD["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H;VUE<&%G92<I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=A8V-E
M<W-K97DG*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]M:6YO
M<E9E<G-I;VX@/3T@-2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T475I<FLH)V)R96%K7V1I<W!O<VET:6]N7VAE861E<B<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)R;VME;E]M
M=6QT:7!A<G1?9F]R;2<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E(#0Z
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S
M8W)I<'0G+"`Q+C(I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=A8V-E<W-K97DG*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]M:6YO<E9E<G-I;VX@/B`P*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`S.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XQ*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED7W!O<'5P7W=I;F1O=W,G*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ!3E1&<F5S8V\O
M*%LP+3E=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G9G)E<V-O)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$N
M,2D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED7W!O
M<'5P7W=I;F1O=W,G*3L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D
M=&AI<RT^7VQO=V5R06=E;G0L("=A=F%N=&=O)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G879A;G1G;R<I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@
M("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?$MO;G%U97)O<B\H6S`M.5TK
M*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BD@?'P*("`@("`@("`@("`@
M("`@("`@("`@('!R96=?;6%T8V@H)WQ3869A<FDO*%LP+3E=*RE<+C\H6S`M
M.5TK*3]\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!["B`@("`@("`@
M("`@("`@("`O+R!+;VYQ=65R;W(@86YD($%P<&QE)W,@4V%F87)I(&)O=&@@
M=7-E('1H92!+2%1-3`H@("`@("`@("`@("`@("`@+R\@<F5N9&5R:6YG(&5N
M9VEN92X*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=K;VYQ
M=65R;W(G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G96UP
M='E?9FEL95]I;G!U=%]V86QU92<I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=%%U:7)K*"=N;U]H:61D96Y?;W9E<F9L;W=?=&%B;&5S)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUA:F]R5F5R<VEO;B`]("1V97)S:6]N6S%=
M.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V97)S:6]N6S)=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6EN;W)697)S:6]N(#T@)'9E
M<G-I;VY;,ET["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G4V%F87)I)RD@(3T](&9A;'-E
M("8F"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M86IO<E9E<G-I;VX@
M/CT@-C`I('L*("`@("`@("`@("`@("`@("`@("`O+R!3869A<FDN"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T
M)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]M86IO<E9E<G-I;VX@/B`Q,C4@?'P*("`@("`@("`@("`@("`@("`@("`@
M("`@*"1T:&ES+3Y?;6%J;W)697)S:6]N(#T](#$R-2`F)@H@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]M:6YO<E9E<G-I;VX@/CT@,2DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C
M8V5S<VME>2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G>&UL:'1T<')E<2<I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M+R\@2V]N<75E<F]R+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=J879A<V-R:7!T)RP@,2XQ*3L*("`@("`@("`@("`@("`@("`@
M("!S=VET8V@@*"1T:&ES+3Y?;6%J;W)697)S:6]N*2!["B`@("`@("`@("`@
M("`@("`@("`@8V%S92`S.@H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=I9G)A;65S)RD["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H
M)WQ-;WII;&QA+RA;,"TY+ETK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO
M;BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=M;WII
M;&QA)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)VUU<W1?
M8V%C:&5?9F]R;7,G*3L*"B`@("`@("`@("`@("`@("!L:7-T*"1T:&ES+3Y?
M;6%J;W)697)S:6]N+"`D=&AI<RT^7VUI;F]R5F5R<VEO;BD@/2!E>'!L;V1E
M*"<N)RP@)'9E<G-I;VY;,5TI.PH@("`@("`@("`@("`@("`@<W=I=&-H("@D
M=&AI<RT^7VUA:F]R5F5R<VEO;BD@>PH@("`@("`@("`@("`@("`@8V%S92`U
M.@H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T4&QA=&9O<FTH
M*2`]/2`G=VEN)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T475I<FLH)V)R96%K7V1I<W!O<VET:6]N7V9I;&5N86UE)RD["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U<"<I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X;6QH='1P
M<F5Q)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)V-I=&4G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M?')V.B@N*BE<*7PG+"`D=&AI<RT^7V%G96YT+"`D<F5V:7-I;VXI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5V:7-I;VY;,5T@/CT@,2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)')E=FES:6]N6S%=(#X](#$N,RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)W)T92<I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@-#H*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$N,RD["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=B=6=G>5]C;VUP<F5S<VEO;B<I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@,SH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q*3L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)U9V=Y7V-O
M;7!R97-S:6]N)RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H
M*"=\3'EN>"\H6S`M.5TK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=L>6YX)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:6UA9V5S)RP@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V9R
M86UE<R<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=%%U:7)K*"=A=F]I9%]P;W!U<%]W:6YD;W=S)RD["B`@("`@("`@
M("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\3&EN:W,@7"@H6S`M.5TK*7PG
M+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YS971"<F]W<V5R*"=L:6YK<R<I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)VEM86=E<R<L(&9A;'-E*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=F<F%M97,G+"!F86QS92D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L
M(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G879O
M:61?<&]P=7!?=VEN9&]W<R<I.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:"@G?$AO=$IA=F$O*%LP+3E=*RE\)RP@)'1H:7,M/E]A9V5N="P@
M)'9E<G-I;VXI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E
M<B@G:&]T:F%V82<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VIA=F%S8W)I<'0G+"!F86QS92D["B`@("`@("`@("`@('T@96QS96EF
M("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)U50+R<I("$]/2!F86QS92!\?`H@
M("`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=5
M4"Y")RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("`@("`@("!S=')P
M;W,H)'1H:7,M/E]A9V5N="P@)U50+DPG*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=U<"<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A
M;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL
M)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD[
M"@H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G
M1U5))RD@(3T](&9A;'-E("8F"B`@("`@("`@("`@("`@("`@("`@<W1R<&]S
M*"1T:&ES+3Y?86=E;G0L("=54"Y,:6YK)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`@("`@+RH@5&AE(&1E=FEC92!A8V-E<'1S($]P96YW879E
M($=522!E>'1E;G-I;VYS(&9O<@H@("`@("`@("`@("`@("`@("`@("`J(%=-
M3"`Q+C,N($YO;BU54"Y,:6YK(&=A=&5W87ES('-O;65T:6UE<R!H879E"B`@
M("`@("`@("`@("`@("`@("`@("H@<')O8FQE;7,L('-O(&5X8VQU9&4@=&AE
M;2X@*B\*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V]W
M7V=U:5\Q+C,G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@
M*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G6&EI;F\O)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G>&EI;F\G*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@
M('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)U!A;&US8V%P92\G
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W
M<V5R*"=P86QM<V-A<&4G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)VAD;6PG*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=W;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O
M<R@D=&AI<RT^7V%G96YT+"`G3F]K:6$G*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=N;VMI82<I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G>&AT;6PG*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@
M?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G17)I8W-S;VXG*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R
M*"=E<FEC<W-O;B<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL
M92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M
M/E]L;W=E<D%G96YT+"`G=V%P)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G=V%P)RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G:'1M;"<L(&9A;'-E*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAD;6PG*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@
M("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=D;V-O
M;6\G*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("`@('-T<G!O
M<R@D=&AI<RT^7VQO=V5R06=E;G0L("=P;W)T86QM;6TG*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=I;6]D92<I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEM86=E<R<L
M(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U
M93L*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?86=E;G0L("="
M;&%C:T)E<G)Y)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T0G)O=W-E<B@G8FQA8VMB97)R>2<I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@
M('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)TU/5"TG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=M
M;W1O<F]L82<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A
M='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H
M)'1H:7,M/E]L;W=E<D%G96YT+"`G:BTG*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=M;6PG*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA=&-H('1H92!P;&%T
M9F]R;2!O9B!T:&4@8G)O=W-E<BX*("`@("`J"B`@("`@*B!4:&ES(&ES(&$@
M<')E='1Y('-I;7!L:7-T:6,@:6UP;&5M96YT871I;VXL(&)U="!I="=S(&EN
M=&5N9&5D"B`@("`@*B!T;R!L970@=7,@=&5L;"!W:&%T(&QI;F4@8G)E86MS
M('1O('-E;F0L('-O(&ET)W,@9V]O9"!E;F]U9V@*("`@("`J(&9O<B!I=',@
M<'5R<&]S92X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,BXR"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]S9710;&%T9F]R;2@I"B`@("!["B`@("`@("`@
M:68@*'-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=W:6YD)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&QA=&9O<FT@/2`G=VEN)SL*
M("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@
M)VUA8R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!L871F
M;W)M(#T@)VUA8R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/E]P;&%T9F]R;2`]("=U;FEX)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(&-U<G)E;G1L>2!M871C:&5D('!L871F
M;W)M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=7-E<B=S
M('!L871F;W)M+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`R+C(*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4&QA=&9O<FTH*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!L871F;W)M.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!T:&4@8W5R<F5N="!B<F]W<V5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&)R;W=S97(@(%1H92!B<F]W<V5R('1O('-E="!A<R!C
M=7)R96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971"<F]W<V5R*"1B<F]W
M<V5R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8G)O=W-E<B`]("1B<F]W<V5R
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('1H92!G:79E
M;B!B<F]W<V5R(&ES('1H92!S86UE(&%S('1H92!C=7)R96YT+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&)R;W=S97(@(%1H92!B<F]W<V5R('1O
M(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@27,@=&AE
M(&=I=F5N(&)R;W=S97(@=&AE('-A;64@87,@=&AE(&-U<G)E;G0_"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES0G)O=W-E<B@D8G)O=W-E<BD*("`@('L*("`@
M("`@("!R971U<FX@*"1T:&ES+3Y?8G)O=W-E<B`]/3T@)&)R;W=S97(I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&\@=V4@8V]N<VED97(@=&AE(&-U<G)E
M;G0@8G)O=W-E<B!T;R!B92!A(&UO8FEL92!D979I8V4_"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('=E(&1O+"!F86QS92!I9B!W
M92!D;VXG="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7--;V)I;&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUO8FEL93L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE(&)R;W=S97(@:7,@82!R;V)O
M="!O<B!N;W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF(&)R;W=S97(@:7,@82!K;F]W;B!R;V)O="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-2;V)O="@I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]R;V)O=',@87,@)')O8F]T*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H
M)'1H:7,M/E]A9V5N="P@)')O8F]T*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E('1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$)R;W=S97(H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V)R;W=S97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M92!T:&4@8W5R<F5N="!B<F]W<V5R)W,@;6%J;W(@=F5R<VEO;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C=7)R96YT(&)R;W=S97(G
M<R!M86IO<B!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-86IO
M<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%J;W)697)S:6]N
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&-U<G)E;G0@
M8G)O=W-E<B=S(&UI;F]R('9E<G-I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@8W5R<F5N="!B<F]W<V5R)W,@;6EN;W(@=F5R<VEO
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36EN;W(H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7VUI;F]R5F5R<VEO;CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E('1H92!C=7)R96YT(&)R;W=S97(G<R!V97)S
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N
M="!B<F]W<V5R)W,@=F5R<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%J;W)6
M97)S:6]N("X@)RXG("X@)'1H:7,M/E]M:6YO<E9E<G-I;VX["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U;&P@8G)O=W-E<B!A9V5N="!S
M=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!B<F]W
M<V5R(&%G96YT('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06=E
M;G13=')I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%G96YT
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('5N:7%U92!B96AA=FEO<B!F
M;W(@=&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1Q=6ER:R`@5&AE(&)E:&%V:6]R('1O('-E="X*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;'5E("!3<&5C:6%L(&)E:&%V:6]R('!A<F%M971E
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T475I<FLH)'%U:7)K+"`D=F%L
M=64@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<75I<FMS6R1Q=6ER
M:UT@/2`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!U;FEQ
M=64@8F5H879I;W(@9F]R('1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<75I<FL@(%1H92!B96AA=FEO<B!T;R!C
M:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($1O97,@=&AE
M(&)R;W=S97(@:&%V92!T:&4@8F5H879I;W(@<V5T/PH@("`@("HO"B`@("!F
M=6YC=&EO;B!H87-1=6ER:R@D<75I<FLI"B`@("!["B`@("`@("`@<F5T=7)N
M("%E;7!T>2@D=&AI<RT^7W%U:7)K<ULD<75I<FM=*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E('5N:7%U92!B96AA=FEO<B!F;W(@=&AE(&-U
M<G)E;G0@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q
M=6ER:R`@5&AE(&)E:&%V:6]R('1O(')E=')I979E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@=F%L=64@9F]R('1H92!R97%U97-T960@
M8F5H879I;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U:7)K*"1Q=6ER
M:RD*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]Q=6ER:W-;
M)'%U:7)K72D*("`@("`@("`@("`@("`@/R`D=&AI<RT^7W%U:7)K<ULD<75I
M<FM="B`@("`@("`@("`@("`@(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!C87!A8FEL:71I97,@9F]R('1H92!C=7)R96YT(&)R;W=S97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F5A='5R92`@5&AE(&-A
M<&%B:6QI='D@=&\@<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@
M("`@4W!E8VEA;"!C87!A8FEL:71Y('!A<F%M971E<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T1F5A='5R92@D9F5A='5R92P@)'9A;'5E(#T@=')U92D*
M("`@('L*("`@("`@("`D=&AI<RT^7V9E871U<F5S6R1F96%T=7)E72`]("1V
M86QU93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K('1H92!C=7)R96YT
M(&)R;W=S97(@8V%P86)I;&ET:65S+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9E871U<F4@(%1H92!C87!A8FEL:71Y('1O(&-H96-K+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@1&]E<R!T:&4@8G)O=W-E<B!H
M879E('1H92!C87!A8FEL:71Y('-E=#\*("`@("`J+PH@("`@9G5N8W1I;VX@
M:&%S1F5A='5R92@D9F5A='5R92D*("`@('L*("`@("`@("!R971U<FX@(65M
M<'1Y*"1T:&ES+3Y?9F5A='5R97-;)&9E871U<F5=*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E=')I979E('1H92!C=7)R96YT(&)R;W=S97(@8V%P86)I
M;&ET>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F96%T=7)E("!4
M:&4@8V%P86)I;&ET>2!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('9A;'5E(&]F('1H92!R97%U97-T960@8V%P86)I
M;&ET>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F5A='5R92@D9F5A='5R
M92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]F96%T=7)E
M<ULD9F5A='5R95TI"B`@("`@("`@("`@("`@(#\@)'1H:7,M/E]F96%T=7)E
M<ULD9F5A='5R95T*("`@("`@("`@("`@("`@.B!N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5T97)M:6YE(&EF('=E(&%R92!U<VEN9R!A('-E8W5R
M92`H4U-,*2!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!U<VEN9R!34TPL(&9A;'-E(&EF(&YO="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7-I;F=34TQ#;VYN96-T:6]N*"D*("`@('L*("`@
M("`@("!R971U<FX@*"AI<W-E="@D7U-%4E9%4ELG2%144%,G72D@)B8*("`@
M("`@("`@("`@("`@("`H)%]315)615);)TA45%!3)UT@/3T@)V]N)RDI('Q\
M"B`@("`@("`@("`@("`@("!G971E;G8H)U-33%]04D]43T-/3%]615)324].
M)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<V5R=F5R
M('!R;W1O8V]L(&EN('5S92!O;B!T:&4@8W5R<F5N="!S97)V97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5%10('-E<G9E<B!P<F]T
M;V-O;"!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(5%104')O
M=&]C;VPH*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG4T52
M5D527U!23U1/0T],)UTI*2!["B`@("`@("`@("`@(&EF("@H)'!O<R`]('-T
M<G)P;W,H)%]315)615);)U-%4E9%4E]04D]43T-/3"==+"`G+R<I*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D7U-%4E9%4ELG4T525D52
M7U!23U1/0T],)UTL("1P;W,@*R`Q*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F4@:68@9FEL97,@8V%N(&)E('5P;&]A9&5D('1O('1H92!S
M>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!)9B!U<&QO
M861S(&%L;&]W960L(')E='5R;G,@=&AE(&UA>&EM=6T@<VEZ92!O9B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@=7!L;V%D(&EN(&)Y=&5S+B`@4F5T
M=7)N<R`P(&EF('5P;&]A9',@87)E(&YO=`H@("`@("H@("`@("`@("`@("`@
M("`@("!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!A;&QO=T9I;&55
M<&QO861S*"D*("`@('L*("`@("`@("!I9B`H:6YI7V=E="@G9FEL95]U<&QO
M861S)RDI('L*("`@("`@("`@("`@:68@*"@D9&ER(#T@:6YI7V=E="@G=7!L
M;V%D7W1M<%]D:7(G*2D@)B8*("`@("`@("`@("`@("`@("%I<U]W<FET86)L
M92@D9&ER*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&9I;&5S:7IE(#T@:6YI7V=E="@G=7!L;V%D
M7VUA>%]F:6QE<VEZ92<I.PH@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W
M97(H<W5B<W1R*"1F:6QE<VEZ92P@+3$L(#$I*2D@>PH@("`@("`@("`@("!C
M87-E("=K)SH*("`@("`@("`@("`@("`@("1F:6QE<VEZ92`](&EN='9A;"AF
M;&]A='9A;"@D9FEL97-I>F4I("H@,3`R-"D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("`@("`@
M)&9I;&5S:7IE(#T@:6YT=F%L*&9L;V%T=F%L*"1F:6QE<VEZ92D@*B`Q,#(T
M("H@,3`R-"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D9FEL97-I>F4@/2!I;G1V86PH
M)&9I;&5S:7IE*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1P;W-T<VEZ92`](&EN:5]G970H)W!O<W1?;6%X
M7W-I>F4G*3L*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*'-U8G-T
M<B@D<&]S='-I>F4L("TQ+"`Q*2DI('L*("`@("`@("`@("`@8V%S92`G:R<Z
M"B`@("`@("`@("`@("`@("`D<&]S='-I>F4@/2!I;G1V86PH9FQO871V86PH
M)'!O<W1S:7IE*2`J(#$P,C0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@("`@("1P;W-T<VEZ
M92`](&EN='9A;"AF;&]A='9A;"@D<&]S='-I>F4I("H@,3`R-"`J(#$P,C0I
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@)'!O<W1S:7IE(#T@:6YT=F%L*"1P;W-T<VEZ
M92D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@;6EN*"1F:6QE<VEZ92P@)'!O<W1S:7IE*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF('1H92!F:6QE
M('=A<R!U<&QO861E9"!O<B!N;W0N("!)9B!N;W0L('=I;&P@<F5T=7)N('1H
M90H@("`@("H@87!P<F]P<FEA=&4@97)R;W(@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@5&AE(&YA;64@;V8@=&AE(&9I
M96QD(&-O;G1A:6YI;F<@=&AE('5P;&]A9&5D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("!4:&4@9FEL92!D97-C<FEP=&EO;B!S=')I;F<@=&\@=7-E(&EN('1H92!E
M<G)O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UE<W-A9V4N("!$
M969A=6QT.B`G9FEL92<N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!W87-&:6QE57!L;V%D960H)&9I96QD+"`D;F%M92`]
M(&YU;&PI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M"@H@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@("`@("`@("`D
M;F%M92`](%\H(F9I;&4B*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A*"1U
M<&QO8613:7IE(#T@0G)O=W-E<CHZ86QL;W=&:6QE57!L;V%D<R@I*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"XB*2D["B`@("`@("`@?0H*("`@("`@("`O
M*B!'970@86YY(&EN9&5X(&]N('1H92!F:65L9"!N86UE+B`J+PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@("`D:6YD
M97@@/2!(;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D9FEE;&0L("1B87-E
M+"`D:V5Y<RD["@H@("`@("`@(&EF("@D:6YD97@I('L*("`@("`@("`@("`@
M+RH@26YD97@@<')E<V5N="P@9F5T8V@@=&AE(&5R<F]R('9A<B!T;R!C:&5C
M:RX@*B\*("`@("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R
M<F%Y*"1B87-E+"`G97)R;W(G*2P@)&ME>7,I.PH@("`@("`@("`@("`D97)R
M;W(@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P
M871H*3L*"B`@("`@("`@("`@("\J($EN9&5X('!R97-E;G0L(&9E=&-H('1H
M92!T;7!?;F%M92!V87(@=&\@8VAE8VLN("HO"B`@("`@("`@("`@("1K97ES
M7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A>2@D8F%S92P@)W1M<%]N86UE)RDL
M("1K97ES*3L*("`@("`@("`@("`@)'1M<%]N86UE(#T@2&]R9&5?07)R87DZ
M.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH@3F\@:6YD97@L('-I;7!L92!S970@=7`@
M;V8@=F%R<R!T;R!C:&5C:RX@*B\*("`@("`@("`@("`@:68@*"%I<W-E="@D
M7T9)3$536R1F:65L9%TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*").;R!F:6QE('5P;&]A9&5D(BDL(%503$]!1%]%
M4E)?3D]?1DE,12D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5R<F]R
M(#T@)%]&24Q%4ULD9FEE;&1=6R=E<G)O<B==.PH@("`@("`@("`@("`D=&UP
M7VYA;64@/2`D7T9)3$536R1F:65L9%U;)W1M<%]N86UE)UT["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES<V5T*"1?1DE,15,I('Q\("@D97)R;W(@/3T@
M55!,3T%$7T524E].3U]&24Q%*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB*2P@
M)&YA;64I+"!54$Q/041?15)27TY/7T9)3$4I.PH@("`@("`@('T@96QS96EF
M("@H)&5R<F]R(#T](%503$]!1%]%4E)?3TLI("8F(&ES7W5P;&]A9&5D7V9I
M;&4H)'1M<%]N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!](&5L<V5I9B`H*"1E<G)O<B`]/2!54$Q/041?15)27TE.25]325I%
M*2!\?`H@("`@("`@("`@("`@("`@("`H)&5R<F]R(#T](%503$]!1%]%4E)?
M1D]235]325I%*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM
M=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(BDL("1N86UE+"`D=7!L;V%D
M4VEZ92DL("1E<G)O<BD["B`@("`@("`@?2!E;'-E:68@*"1E<G)O<B`]/2!5
M4$Q/041?15)27U!!4E1)04PI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+B(I+"`D;F%M92DL("1E<G)O<BD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:&5A9&5R<R!F;W(@82!B
M<F]W<V5R(&1O=VYL;V%D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&9I;&5N86UE("!4:&4@9FEL96YA;64@;V8@=&AE(&1O=VYL;V%D+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8U1Y<&4@("`@(%1H92!C;VYT96YT+71Y<&4@
M9&5S8W)I<'1I;VX@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D:6YL:6YE("`@5')U92!I9B!I;FQI;F4L(&9A;'-E(&EF(&%T=&%C:&UE
M;G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C3&5N9W1H("`@5&AE(&-O;G1E
M;G0M;&5N9W1H(&]F('1H:7,@9FEL92X*("`@("`J"B`@("`@*B!`<VEN8V4@
M2&]R9&4@,BXR"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O=VYL;V%D2&5A9&5R
M<R@D9FEL96YA;64@/2`G=6YK;F]W;B<L("1C5'EP92`](&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN;&EN92`](&9A;'-E+"`D8TQE
M;F=T:"`](&YU;&PI"B`@("!["B`@("`@("`@+RH@4F5M;W9E(&QI;F5B<F5A
M:W,@9G)O;2!F:6QE(&YA;65S+B`J+PH@("`@("`@("1F:6QE;F%M92`]('-T
M<E]R97!L86-E*&%R<F%Y*")<<EQN(BP@(EQR(BP@(EQN(BDL("<@)RP@)&9I
M;&5N86UE*3L*"B`@("`@("`@+RH@4V]M92!B<F]W<V5R<R!D;VXG="!L:6ME
M('-P86-E<R!I;B!T:&4@9FEL96YA;64N("HO"B`@("`@("`@:68@*"1T:&ES
M+3YH87-1=6ER:R@G;F]?9FEL96YA;65?<W!A8V5S)RDI('L*("`@("`@("`@
M("`@)&9I;&5N86UE(#T@<W1R='(H)&9I;&5N86UE+"`G("<L("=?)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!-4TE%(&1O97-N)W0@;&EK92!M=6QT:7!L
M92!P97)I;V1S(&EN('1H92!F:6QE(&YA;64N($-O;G9E<G0*("`@("`@("`@
M("!A;&P@<&5R:6]D<R`H97AC97!T('1H92!L87-T(&]N92D@=&\@=6YD97)S
M8V]R97,N("HO"B`@("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)VUS:64G
M*2D@>PH@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')R<&]S*"1F:6QE;F%M
M92P@)RXG*2DI('L*("`@("`@("`@("`@("`@("1F:6QE;F%M92`]('-T<G1R
M*'-U8G-T<B@D9FEL96YA;64L(#`L("1P;W,I+"`G+B<L("=?)RD@+B!S=6)S
M='(H)&9I;&5N86UE+"`D<&]S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@0V]N=&5N="U4>7!E+T-O;G1E;G0M1&ES<&]S:71I;VX@
M2&5A9&5R+B`J+PH@("`@("`@(&EF("@D:6YL:6YE*2!["B`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D8U1Y<&4I*2!["B`@("`@("`@("`@("`@("!H96%D
M97(H)T-O;G1E;G0M5'EP93H@)R`N('1R:6TH)&-4>7!E*2D["B`@("`@("`@
M("`@('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M<VEE)RDI('L*("`@
M("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO
M;B]X+6US9&]W;FQO860G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!H96%D
M97(H)T-O;G1E;G0M1&ES<&]S:71I;VXZ(&EN;&EN93L@9FEL96YA;64](B<@
M+B`D9FEL96YA;64@+B`G(B<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=M<VEE)RDI('L*("`@("`@("`@
M("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]X+6US
M9&]W;FQO860G*3L*("`@("`@("`@("`@?2!E;'-E:68@*"%I<U]N=6QL*"1C
M5'EP92DI('L*("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E
M.B`G("X@=')I;2@D8U1Y<&4I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO
M;B]O8W1E="US=')E86TG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1T:&ES+3YH87-1=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?:&5A9&5R
M)RDI('L*("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U$:7-P;W-I
M=&EO;CH@9FEL96YA;64](B<@+B`D9FEL96YA;64@+B`G(B<I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT
M+41I<W!O<VET:6]N.B!A='1A8VAM96YT.R!F:6QE;F%M93TB)R`N("1F:6QE
M;F%M92`N("<B)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($-O;G1E;G0M3&5N9W1H($AE861E<BX@*B\*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&-,96YG=&@I*2!["B`@("`@("`@("`@(&AE861E<B@G0V]N=&5N
M="U,96YG=&@Z("<@+B`D8TQE;F=T:"D["B`@("`@("`@?0H*("`@("`@("`O
M*B!/=F5R=W)I=&4@4')A9VUA.B!A;F0@;W1H97(@8V%C:&EN9R!H96%D97)S
M(&9O<B!)12X@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA<U%U:7)K*"=C86-H
M95]S<VQ?9&]W;FQO861S)RDI('L*("`@("`@("`@("`@:&5A9&5R*"=%>'!I
M<F5S.B`P)RD["B`@("`@("`@("`@(&AE861E<B@G0V%C:&4M0V]N=')O;#H@
M;75S="UR979A;&ED871E)RD["B`@("`@("`@("`@(&AE861E<B@G4')A9VUA
M.B!P=6)L:6,G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M971E<FUI;F5S(&EF(&$@8G)O=W-E<B!C86X@9&ES<&QA>2!A(&=I=F5N($U)
M344@='EP92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M:6UE='EP
M92`@5&AE($U)344@='EP92!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&)R;W=S97(@8V%N(&1I<W!L87D@
M=&AE($U)344@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-6:65W86)L
M92@D;6EM971Y<&4I"B`@("!["B`@("`@("`@)&UI;65T>7!E(#T@4W1R:6YG
M.CIL;W=E<B@D;6EM971Y<&4I.PH@("`@("`@(&QI<W0H)'1Y<&4L("1S=6)T
M>7!E*2`](&5X<&QO9&4H)R\G+"`D;6EM971Y<&4I.PH*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?86-C97!T*2D@>PH@("`@("`@("`@("`D=VEL9&-A
M<F1?;6%T8V@@/2!F86QS93L*"B`@("`@("`@("`@(&EF("AS=')P;W,H)'1H
M:7,M/E]A8V-E<'0L("1M:6UE='EP92D@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*'-T<G!O<R@D=&AI<RT^7V%C8V5P="P@)RHO*B<I("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@)'=I;&1C87)D7VUA=&-H(#T@=')U93L*
M("`@("`@("`@("`@("`@(&EF("@D='EP92`A/2`G:6UA9V4G*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(&EM86=E+VIP96<@86YD
M(&EM86=E+W!J<&5G("IA<'!E87(J('1O(&)E('1H92!S86UE"B`@("`@("`@
M("`@("`J(&5N=&ET>2P@8G5T($UO>FEL;&$@9&]E<VXG="!S965M('1O('=A
M;G0@=&\@86-C97!T('1H90H@("`@("`@("`@("`@*B!L871T97(N("!&;W(@
M;W5R('!U<G!O<V5S+"!W92!W:6QL('1R96%T('1H96T@=&AE"B`@("`@("`@
M("`@("`J('-A;64N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W
M<V5R*"=M;WII;&QA)RD@)B8*("`@("`@("`@("`@("`@("@D;6EM971Y<&4@
M/3T@)VEM86=E+W!J<&5G)RD@)B8*("`@("`@("`@("`@("`@("AS=')P;W,H
M)'1H:7,M/E]A8V-E<'0L("=I;6%G92]J<&5G)RD@(3T](&9A;'-E*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@A)'=I;&1C87)D7VUA=&-H*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@A)'1H:7,M/FAA<T9E871U<F4H)VEM86=E<R<I('Q\("@D
M='EP92`A/2`G:6UA9V4G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@:6Y?87)R87DH)'-U8G1Y<&4L
M("1T:&ES+3Y?:6UA9V5S*3L*("`@('T*"B`@("`O*BH*("`@("`J($5S8V%P
M92!C:&%R86-T97)S(&EN(&IA=F%S8W)I<'0@8V]D92!I9B!T:&4@8G)O=W-E
M<B!R97%U:7)E<R!I="X*("`@("`J("4R,RP@)3(V+"!A;F0@)3)"("AF;W(@
M<V]M92!B<F]W<V5R<RD@86YD("4R-R!N965D('1O(&)E(&5S8V%P960@;W(*
M("`@("`J(&5L<V4@:F%V87-C<FEP="!W:6QL(&EN=&5R<')E="!I="!A<R!A
M('-I;F=L92!Q=6]T92P@<&]U;F0@<VEG;BP@;W(*("`@("`J(&%M<&5R<V%N
M9"!A;F0@<F5F=7-E('1O('=O<FLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]D92`@5&AE($I3(&-O9&4@=&\@97-C87!E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@97-C87!E9"!C;V1E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E<V-A<&5*4T-O9&4H)&-O9&4I"B`@("!["B`@("`@
M("`@)&9R;VT@/2`D=&\@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M
M/FES0G)O=W-E<B@G;7-I92<I('Q\"B`@("`@("`@("`@("@D=&AI<RT^:7-"
M<F]W<V5R*"=M;WII;&QA)RD@)B8@*"1T:&ES+3YG971-86IO<B@I(#X](#4I
M*2!\?`H@("`@("`@("`@("`D=&AI<RT^:7-"<F]W<V5R*"=K;VYQ=65R;W(G
M*2D@>PH@("`@("`@("`@("`D9G)O;2`](&%R<F%Y*"<E,C,G+"`G)3(V)RP@
M)R4R0B<I.PH@("`@("`@("`@("`D=&\@/2!A<G)A>2AU<FQE;F-O9&4H)R4R
M,R<I+"!U<FQE;F-O9&4H)R4R-B<I+"!U<FQE;F-O9&4H)R4R0B<I*3L*("`@
M("`@("!]"B`@("`@("`@)&9R;VU;72`]("<E,C<G.PH@("`@("`@("1T;UM=
M(#T@)UPE,C<G.PH*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)&9R;VTL
M("1T;RP@)&-O9&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!)
M12!V97)S:6]N(&EN('1H92!S97-S:6]N+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'9E<B`@5&AE($E%(%9E<G-I;VX@<W1R:6YG+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971)159E<G-I;VXH)'9E<BD*("`@('L*("`@("`@
M("`D7U-%4U-)3TY;)U]?8G)O=W-E<B==(#T@87)R87DH"B`@("`@("`@("`@
M("=I95]V97)S:6]N)R`]/B`D=F5R"B`@("`@("`@*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@244@=F5R<VEO;B!S=&]R960@:6X@=&AE
M('-E<W-I;VXL(&EF(&%V86EL86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@244@5F5R<VEO;B!S=')I;F<@;W(@;G5L;"!I9B!N;R!S
M=')I;F<@:7,@<W1O<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971)159E
M<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D7U-%4U-)3TY;
M)U]?8G)O=W-E<B==6R=I95]V97)S:6]N)UTI(#\@)%]315-324].6R=?7V)R
M;W=S97(G75LG:65?=F5R<VEO;B==(#H@;G5L;#L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B].970O````````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#$U-S`T
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O````````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,3`V,0`P,38S-#8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'``````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#8R-3,Q`#$P-3$U-#,Q,#8Q`#`R,C`Q-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M3F5T7U--4U]S;7,R96UA:6Q?:'1T<"!#;&%S<R!I;7!L96UE;G1S('1H92!(
M5%10($%022!F;W(@86-C97-S:6YG('1H90H@*B!S;7,R96UA:6P@*'=W=RYS
M;7,R96UA:6PN8V]M*2!335,@9V%T97=A>2X*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP+'8@,2XR,RXQ,"XQ,"`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(Y(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R
M:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($YE=%]335,*("HO"F-L87-S($YE
M=%]335-?<VUS,F5M86EL7VAT='`@97AT96YD<R!.971?4TU3('L*"B`@("!V
M87(@)%]B87-E7W5R;"`]("=H;W)D92YS;7,R96UA:6PN8V]M+VAO<F1E+R<[
M"@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O
M('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R
M871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+B!0;W-S
M:6)L92!V86QU97,@87)E.CQP<F4^"B`@("`@*B`@(&%U=&@@("`@("`@("T@
M5&AE(&=A=&5W87D@<F5Q=6ER97,@875T:&5N=&EC871I;VX@8F5F;W)E('-E
M;F1I;F<["B`@("`@*B`@(&)A=&-H("`@("`@("T@0F%T8V@@<V5N9&EN9R!I
M<R!S=7!P;W)T960["B`@("`@*B`@(&UU;'1I("`@("`@("T@4V5N9&EN9R!O
M9B!M97-S86=E<R!T;R!M=6QT:7!L92!R96-I<&EE;G1S(&ES('-U<'!O<G1E
M9#L*("`@("`J("`@<F5C96EV92`@("`@+2!7:&5T:&5R('1H:7,@9')I=F5R
M(&ES(&-A<&%B;&4@;V8@<F5C96EV:6YG(%--4SL*("`@("`J("`@8W)E9&ET
M("`@("`@+2!)<R!U<V4@;V8@=&AE(&=A=&5W87D@8F%S960@;VX@8W)E9&ET
M<SL*("`@("`J("`@861D<F5S<V)O;VL@+2!!<F4@9V%T97=A>2!A9&1R97-S
M8F]O:W,@<W5P<&]R=&5D.PH@("`@("H@("!L:7-T<R`@("`@("`M($=A=&5W
M87D@<W5P<&]R="!F;W(@9&ES=')I8G5T:6]N(&QI<W1S+@H@("`@("H@/"]P
M<F4^"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A=71H)R`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B871C:"<@("`@("`@
M/3X@,3`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;75L=&DG
M("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R96-E:79E)R`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=C<F5D:70G("`@("`@/3X@=')U92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V%D9')E<W-B;V]K)R`]/B!T<G5E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES=',G("`@("`@(#T^('1R
M=64I.PH*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!D;V5S('1H92!A
M8W1U86P@<V5N9&EN9R!O9B!T:&4@;65S<V%G92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE
M<W-A9V4@(%1H92!A<G)A>2!C;VYT86EN:6YG('1H92!M97-S86=E(&%N9"!I
M=',@<V5N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T
M97)S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@("`@("!4:&4@9&5S=&EN
M871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N
M(&%R<F%Y('=I=&@@=&AE('-U8V-E<W,@<W1A='5S(&%N9"!A9&1I=&EO;F%L
M"B`@("`@*B`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-E;F0H)B1M97-S86=E+"`D=&\I"B`@("!["B`@("`@
M("`@+RH@4V5T('5P('1H92!S96YD:6YG('5R;"X@*B\*("`@("`@("`D=7)L
M(#T@<W!R:6YT9B@G<&]S=&US9RYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0]
M)7,F;65S<V%G93TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC
M;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@
M("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1M97-S86=E6R=T
M97AT)UTI*3L*"B`@("`@("`@+RH@0VAE8VL@:68@<V]U<F-E(&9R;VT@:7,@
M<V5T+B`J+PH@("`@("`@(&EF("@A96UP='DH)&UE<W-A9V5;)W-E;F1?<&%R
M86US)UU;)V9R;VTG72DI('L*("`@("`@("`@("`@)'5R;"`N/2`G)F]R:6<]
M)R`N('5R;&5N8V]D92@D;65S<V%G95LG<V5N9%]P87)A;7,G75LG9G)O;2==
M*3L*("`@("`@("!]"B`@("`@("`@+RH@0VAE8VL@:68@;65S<V%G92!T>7!E
M(&ES(&9L87-H+B`J+PH@("`@("`@(&EF("@A96UP='DH)&UE<W-A9V5;)W-E
M;F1?<&%R86US)UU;)VUS9U]T>7!E)UTI("8F"B`@("`@("`@("`@("1M97-S
M86=E6R=S96YD7W!A<F%M<R==6R=M<V=?='EP92==(#T]("=335-?1DQ!4T@G
M*2!["B`@("`@("`@("`@("1U<FP@+CT@)R9F;&%S:#TQ)SL*("`@("`@("!]
M"B`@("`@("`@+RH@0VAE8VL@:68@9&5L:79E<GD@<F5P;W)T('5R;"!H87,@
M8F5E;B!S970N("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG9&5L:79E<GE?<F5P;W)T)UTI*2!["B`@("`@("`@("`@("1U<FP@+CT@
M)R9D;'5R;#TG("X@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=D96QI=F5R
M>5]R97!O<G0G72D@+@H@("`@("`@("`@("`@("`@("`@("=R97!O<G1C;V1E
M/25C;V1E)F1E<W1I;F%T:6]N;G5M8F5R/25D97-T)SL*("`@("`@("!]"@H@
M("`@("`@("\J($QO;W`@=&AR;W5G:"!R96-I<&EE;G1S(&%N9"!D;R!S;VUE
M(&UI;FEM86P@=F%L:61I='D@8VAE8VMI;F<N("HO"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1T;RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)'1O(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]>+BH_/#]<*S\H7&1[-RQ]*2@^?"0I+R<L("1V86PL("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T;ULD:V5Y72`]("1M871C:&5S6S%=
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`O*B!&25A-13H@4VEL96YT;'D@9')O<"!B860@<F5C:7!I96YT<RX@5&AI
M<R!S:&]U;&0@8F4*("`@("`@("`@("`@("`@("`@("`@*B!L;V=G960@86YD
M+V]R(')E<&]R=&5D+B`J+PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T
M;ULD:V5Y72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1O(#T@:6UP;&]D92@G+"<L("1T;RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>+BH_/#]<*S\H
M7&1[-RQ]*2@^?"0I+R<L("1T;RP@)&UA=&-H97,I*2!["B`@("`@("`@("`@
M("`@("`D=&\@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@P+"!S<')I;G1F*%\H(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B*2P@)'1O*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J($%P<&5N9"!T:&4@<F5C:7!I96YT
M<R!O9B!T:&ES(&UE<W-A9V4@86YD(&-A;&P@=&AE('5R;"X@*B\*("`@("`@
M("`D=7)L("X]("<F=&]?;G5M/2<@+B`D=&\["B`@("`@("`@)')E<W!O;G-E
M(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R
M97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH,"P@)')E<W!O;G-E+3YG971-97-S86=E*"DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E+"!C:&5C:R!F;W(@;F5W
M(&QI;F5S(&EN(&-A<V4@;V8@;75L=&EP;&4*("`@("`@("`@*B!R96-I<&EE
M;G1S+B`J+PH@("`@("`@("1L:6YE<R`](&5X<&QO9&4H(EQN(BP@)')E<W!O
M;G-E*3L*("`@("`@("`D<F5S<&]N<V4@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H8V]U;G0H)&QI;F5S*2`^(#$I('L*("`@("`@("`@("`@+RH@375L=&EP
M;&4@<F5C:7!I96YT<RX@*B\*("`@("`@("`@("`@9F]R96%C:"`H)&QI;F5S
M(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E
M*"=4;SHG+"`D;&EN92D["B`@("`@("`@("`@("`@("`D<F5C:7!I96YT(#T@
M=')I;2@D<&%R='-;,5TI.PH@("`@("`@("`@("`@("`@:68@*"1L:6YE<ULP
M72`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W!O
M;G-E6R1R96-I<&EE;G1=(#T@87)R87DH,2P@;G5L;"D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS95LD
M<F5C:7!I96YT72`](&%R<F%Y*#`L("1L:6YE<ULP72D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O*B!3:6YG;&4@<F5C:7!I96YT+B`J+PH@("`@("`@("`@("!I9B`H
M)&QI;F5S6S!=(#T]("=!45--4RU/2R<I('L*("`@("`@("`@("`@("`@("1R
M97-P;VYS95LD=&]=(#T@87)R87DH,2P@;G5L;"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V5;)'1O72`](&%R<F%Y
M*#`L("1L:6YE<ULP72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C=7)R96YT(&-R961I="!B86QA;F-E(&]N('1H92!G871E
M=V%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-R961I="!B86QA;F-E(&%V86EL
M86)L92!O;B!T:&4@9V%T97=A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=$)A;&%N8V4H*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N
M9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T;7-G
M+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]8W)E9&ET)RP*("`@
M("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;
M)W5S97(G72DL"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T
M:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*2D["B`@("`@("`@)')E<W!O;G-E
M(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R
M97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@5')Y('-P;&ET=&EN
M9R!U<"!T:&4@<F5S<&]N<V4N("HO"B`@("`@("`@)&QI;F5S(#T@97AP;&]D
M92@G/2<L("1R97-P;VYS92D["@H@("`@("`@(&EF("@D;&EN97-;,%T@/3T@
M)T%14TU3+4-2141)5"<I('L*("`@("`@("`@("`@<F5T=7)N("1L:6YE<ULQ
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$5R<F]R*"1L:6YE<ULP72P@7R@B0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S(BDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@82!C;VYT86-T('1O('1H92!G871E=V%Y)W,@861D<F5S<V)O;VLN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@5&AE(&YA;64@
M9F]R('1H:7,@8V]N=&%C=`H@("`@("H@0'!A<F%M(&EN=&5G97(@)&YU;6)E
M<B`@5&AE(&-O;G1A8W0G<R!P:&]N92!N=6UB97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE(')E;6]T92!C;VYT86-T($E$(&]N('-U8V-E
M<W,@;W(@4$5!4B!%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D0V]N=&%C="@D;F%M92P@
M)&YU;6)E<BD*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@
M8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&-O;G1A
M8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]041$0T].5$%#
M5"9N86UE/25S)FYU;6)E<CTE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O
M<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1N86UE
M*2P*("`@("`@("`@("`@("`@("`@("`@("`D;G5M8F5R*3L*("`@("`@("`D
M<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@
M*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C
M:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@
M:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#$W*2`A/2`G05%335,M0T].5$%#
M5$E$3TLG*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H
M)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(BDI.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4W!L:70@=7`@=&AE(')E<W!O;G-E+B`J
M+PH@("`@("`@("1L:6YE<R`](&5X<&QO9&4H)RP])RP@)')E<W!O;G-E*3L*
M("`@("`@("!R971U<FX@)&QI;F5S6S%=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57!D871E<R!A(&-O;G1A8W0@:6X@=&AE(&=A=&5W87DG<R!A9&1R97-S
M8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@("!4
M:&4@8V]N=&%C="=S($E$(&]N('1H92!G871E=V%Y+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@("`@5&AE(&YA;64@9F]R('1H:7,@8V]N=&%C=`H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&YU;6)E<B`@5&AE(&-O;G1A8W0G<R!P
M:&]N92!N=6UB97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7!D871E0V]N=&%C="@D:60L("1N86UE+"`D;G5M
M8F5R*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N9"!C86QL
M(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T8V]N=&%C=',N
M<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U54$1!5$5#3TY404-4
M)FED/25S)FYA;64])7,F;G5M8F5R/25S)RP*("`@("`@("`@("`@("`@("`@
M("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W5S97(G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=P
M87-S=V]R9"==*2P*("`@("`@("`@("`@("`@("`@("`@("`D:60L"B`@("`@
M("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1N86UE*2P*("`@("`@("`@
M("`@("`@("`@("`@("`D;G5M8F5R*3L*("`@("`@("`D<F5S<&]N<V4@/2`D
M=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O
M;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!087)S92!T:&4@<F5S<&]N
M<V4N("HO"B`@("`@("`@:68@*"1R97-P;VYS92`]/2`G05%335,M3TLG*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E+"!?
M*")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(BDI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!C;VYT86-T(&EN('1H
M92!G871E=V%Y)W,@861D<F5S<V)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&ED("!4:&4@8V]N=&%C="=S($E$(&]N('1H92!G871E=V%Y
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E;&5T94-O;G1A8W0H)&ED*0H@("`@>PH@("`@("`@("\J(%-E="!U
M<"!T:&4@=7)L(&%N9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I
M;G1F*"=P;W-T8V]N=&%C=',N<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S
M)F-M9#U$14Q%5$5#3TY404-4)FED/25S)RP*("`@("`@("`@("`@("`@("`@
M("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W5S97(G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=P
M87-S=V]R9"==*2P*("`@("`@("`@("`@("`@("`@("`@("`D:60I.PH@("`@
M("`@("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@("`@("`@("\J
M(%!A<G-E('1H92!R97-P;VYS92X@*B\*("`@("`@("!I9B`H)')E<W!O;G-E
M(#T]("=!45--4RU/2R<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%
M<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,B*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1F5T8VAE
M<R!T:&4@96YT:7)E(&%D9')E<W,@8F]O:R!F<F]M('1H92!G871E=V%Y+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($%R<F%Y(&]F(&-O;G1A8W1S
M(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("H@
M("`@("`@("`@("`@("`@1F]R;6%T(&]F('1H92!R971U<FYE9"!C;VYT86-T
M<R!I<R!F;W(@97AA;7!L93H\8V]D93X*("`@("`J("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*#QU;FEQ=65I9#X@/3X@87)R87DH)VYA;64G("`@/3X@/&YA
M;64^+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;G5M8F5R)R`]/B`\;G5M8F5R/BDL"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`\=6YI<75E:60^(#T^(&%R<F%Y*"=N86UE
M)R`@(#T^(#QN86UE/BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VYU;6)E<B<@/3X@/&YU;6)E<CXI*3L*
M("`@("`J(#PO8V]D93X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T061D<F5S
M<T)O;VLH*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N9"!C
M86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T8V]N=&%C
M=',N<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U'151!1$1215-3
M0D]/2R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES
M+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R
M;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI.PH@("`@("`@
M("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@("`@("`@("\J($-H
M96-K(&EF('1H97)E('=A<R!A;B!E<G)O<B!R97-P;VYS92X@*B\*("`@("`@
M("!I9B`H<W5B<W1R*"1R97-P;VYS92P@,"P@,3DI("$]("=!45--4RU!1$12
M15-30D]/2T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5R
M<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B*2D["B`@("`@("`@?0H*("`@("`@("`O*B!087)S92!T:&4@
M<F5S<&]N<V4@86YD(&-O;G-T<G5C="!T:&4@87)R87DN("HO"B`@("`@("`@
M;&ES="@D<F5S<&]N<V4L("1C;VYT86-T<U]S='(I(#T@97AP;&]D92@G+"<L
M("1R97-P;VYS92P@,BD["@H@("`@("`@("\J($-H96-K('1H870@=&AE(&9U
M;&P@861D<F5S<R!B;V]K(&QI<W0@:&%S(&)E96X@<F5C96EV960N("HO"B`@
M("`@("`@)&QE;F=T:"`]('-U8G-T<B@D<F5S<&]N<V4L(#$Y*3L*("`@("`@
M("!I9B`H<W1R;&5N*"1C;VYT86-T<U]S='(I("$]("1L96YG=&@I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB*2D["B`@("`@("`@?0H@
M("`@("`@("1C;VYT86-T<U]L:6YE<R`](&5X<&QO9&4H(EQN(BP@)&-O;G1A
M8W1S7W-T<BD["B`@("`@("`@)&-O;G1A8W1S(#T@87)R87DH*3L*("`@("`@
M("`O*B!,;V]P('1H<F]U9V@@;&EN97,@86YD('!I8VL@;W5T('1H92!F:65L
M9',L(&UA:V4@<W5R92!T:&%T('1H92`B(@H@("`@("`@("`J(&%R92!N;W0@
M:6YC;'5D960@:6X@=&AE('9A;'5E<RP@<V\@9V5T('1H92!L:6YE(&QE<W,@
M,2!C:&%R(&]N(&5A8V@*("`@("`@("`@*B!E;F0@86YD('-P;&ET(&9O<B`B
M+"(N("HO"B`@("`@("`@9F]R96%C:"`H)&-O;G1A8W1S7VQI;F5S(&%S("1L
M:6YE*2!["B`@("`@("`@("`@(&QI<W0H)&ED+"`D;F%M92P@)&YU;6)E<BD@
M/2!E>'!L;V1E*"<B+"(G+"!S=6)S='(H)&QI;F4L(#$L("TQ*2D["B`@("`@
M("`@("`@("1C;VYT86-T<ULD:61=(#T@87)R87DH)VYA;64G(#T^("1N86UE
M+"`G;G5M8F5R)R`]/B`D;G5M8F5R*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8V]N=&%C=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&$@;F5W(&1I<W1R:6)U=&EO;B!L:7-T(&]N('1H92!G871E=V%Y+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@06X@87)B:71R87)Y
M(&YA;64@9F]R('1H92!N97<@;&ES="X*("`@("`J($!P87)A;2!A<G)A>2`D
M;G5M8F5R<R`@02!S:6UP;&4@87)R87D@;V8@;G5M8F5R<R!T;R!A9&0@=&\@
M=&AE(&QI<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1V%T97=A
M>2!)1"!F;W(@=&AE(&-R96%T960@;&ES="!O;B!S=6-C97-S(&]R(%!%05(@
M17)R;W(*("`@("`J("`@("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QI<W1#<F5A=&4H)&YA;64L("1N=6UB97)S*0H@
M("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N9"!C86QL(&ET+B`J
M+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T9&ES=')I8G5T:6]N+G!H
M<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]041$1$E35$Q)4U0F;F%M
M93TE<R9N=6UL:7-T/25S)RP*("`@("`@("`@("`@("`@("`@("`@("!U<FQE
M;F-O9&4H)'1H:7,M/E]P87)A;7-;)W5S97(G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==
M*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)&YA;64I+`H@
M("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RPG+"`D;G5M8F5R<RDI
M.PH@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@("`@
M("`@("\J($-H96-K(&EF('1H97)E('=A<R!A;B!E<G)O<B!R97-P;VYS92X@
M*B\*("`@("`@("!I9B`H<W5B<W1R*"1R97-P;VYS92P@,"P@,38I("$]("=!
M45--4RU$25-4251%34E$)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$5R<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T(&-R96%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B*2D["B`@("`@("`@?0H*("`@("`@("`O*B!0
M87)S92!T:&4@<F5S<&]N<V4@86YD(&=E="!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240N("HO"B`@("`@("`@;&ES="@D<F5S<&]N<V4L("1I9"D@/2!E>'!L
M;V1E*"<])RP@)')E<W!O;G-E*3L*"B`@("`@("`@+RH@5$]$3SH@9&\@=V4@
M;F5E9"!T;R!C:&5C:R!T:&4@;&5N9W1H(&]F('1H92!I9"!S=')I;F<_("HO
M"@H@("`@("`@(')E='5R;B`D:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&5S(&$@9&ES=')I8G5T:6]N(&QI<W0@9G)O;2!T:&4@9V%T97=A>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&=A=&5W87D@
M240@9F]R('1H92!L:7-T('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1&5L971E*"1I9"D*
M("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@
M*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&1I<W1R:6)U=&EO;BYP
M:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/41%3$54141)4U1,25-4
M)F1I<W1I9#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E
M*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@
M("`@("`@("`@("`@("`@("`@("`@)&ED*3L*("`@("`@("`D<F5S<&]N<V4@
M/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E
M<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!R97-P;VYS
M92X@*B\*("`@("`@("!I9B`H)')E<W!O;G-E(#T]("=!45--4RU/2R<I('L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H
M(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(BDI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@82!D:7-T
M<FEB=71I;VX@;&ES="!O;B!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I9"`@("`@("!4:&4@9V%T97=A>2!)1"!F;W(@=&AE
M(&QI<W0@=&\@=7!D871E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M("`@5&AE(&%R8FET<F%R>2!N86UE(&]F('1H92!L:7-T+B!)9B!D:69F97)E
M;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&9R;VT@=&AE(&]R
M:6=I;F%L(&YA;64@=&AA="!T:&4@;&ES="!W87,@8W)E871E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YD97(L('1H92!L:7-T('=I;&P@
M8F4@<F5N86UE9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YU;6)E<G,@(%1H
M92!N97<@;&ES="!O9B!N=6UB97)S(&EN('1H92!L:7-T+B!)9B!L969T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E;7!T>2P@=&AE(')E<W5L
M="!W:6QL(&)E('1H92!S86UE(&%S(&-A;&QI;F<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!L:7-T4F5N86UE*"D@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&ES=%5P9&%T92@D:60L("1N86UE+"`D;G5M8F5R<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A;&P@:70N("HO
M"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1D:7-T<FEB=71I;VXN<&AP
M/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U54$1!5$5,25-43D%-129D
M:7-T:60])7,F;F%M93TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L
M96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G
M72DL"B`@("`@("`@("`@("`@("`@("`@("`@)&ED+`H@("`@("`@("`@("`@
M("`@("`@("`@('5R;&5N8V]D92@D;F%M92DI.PH*("`@("`@("`O*B!#:&5C
M:R!I9B!T:&4@;&ES="!N=6UB97)S(&YE960@=7!D871I;F<N("HO"B`@("`@
M("`@:68@*"%E;7!T>2@D;G5M8F5R<RDI('L*("`@("`@("`@("`@)'5R;"`N
M/2`G)FYU;6)E<G,])R`N(&EM<&QO9&4H)RPG+"`D;G5M8F5R<RD["B`@("`@
M("`@?0H*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R
M;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!#:&5C:R!R97-P;VYS92X@*B\*("`@("`@("!I9B`H)')E
M<W!O;G-E(#T]("=!45--4RU/2R<I('L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(BDI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;F%M97,@82!D:7-T<FEB=71I;VX@;&ES="!O;B!T:&4@
M9V%T97=A>2X@1&]E<R!N;W1H:6YG(&]T:&5R('1H86X*("`@("`J(&-A;&QI
M;F<@=&AE(&QI<W15<&1A=&4H*2!F=6YC=&EO;B!W:71H(&IU<W0@=&AE("1I
M9"!A;F0@)&YA;64*("`@("`J('9A<FEA8FQE<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I9"`@("!4:&4@9V%T97=A>2!)1"!F;W(@=&AE(&QI
M<W0@=&\@=7!D871E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&YE=R!A<F)I=')A<GD@;F%M92!F;W(@=&AE(&QI<W0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(%!%05(@17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%)E;F%M
M92@D:60L("1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&ES
M=%5P9&%T92@D:60L("1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($9E
M=&-H97,@82!L:7-T:6YG(&]F(&%V86EL86)L92!D:7-T<FEB=71I;VX@;&ES
M=',@;VX@=&AE('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!!;B!A<G)A>2!O9B!L:7-T<R!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J("`@("`@("`@("`@("`@($9O<FUA="!O9B!T
M:&4@<F5T=7)N960@;&ES=',@:7,@9F]R(&5X86UP;&4Z/&-O9&4^"B`@("`@
M*B`@("`@("`@("`@("`@("`@("!A<G)A>2@\=6YI<75E:60^(#T^(&%R<F%Y
M*"=N86UE)R`@(#T^(#QN86UE/BDL"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`\=6YI<75E:60^(#T^(&%R<F%Y*"=N86UE)R`@(#T^(#QN86UE
M/BDI.PH@("`@("H@/"]C;V1E/@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,
M:7-T<R@I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A
M;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1D:7-T<FEB
M=71I;VXN<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U'151#3TU0
M04-43$E35"<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T
M:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@
M('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI.PH@("`@
M("`@("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@("`@("`@("\J
M($-H96-K(&EF('1H97)E('=A<R!A;B!E<G)O<B!R97-P;VYS92X@*B\*("`@
M("`@("!I9B`H<W5B<W1R*"1R97-P;VYS92P@,"P@,C(I("$]("=!45--4RU$
M25-44DE"551)3TY,25-4)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$5R<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,B*2D["B`@("`@("`@?0H*("`@("`@("`O
M*B!087)S92!T:&4@<F5S<&]N<V4@86YD(&-O;G-T<G5C="!T:&4@87)R87DN
M("HO"B`@("`@("`@;&ES="@D<F5S<&]N<V4L("1L:7-T<U]S='(I(#T@97AP
M;&]D92@G+"<L("1R97-P;VYS92P@,BD["@H@("`@("`@("\J($-H96-K('1H
M870@=&AE(&9U;&P@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',@:&%S(&)E
M96X@<F5C96EV960N("HO"B`@("`@("`@)&QE;F=T:"`]('-U8G-T<B@D<F5S
M<&]N<V4L(#(R*3L*("`@("`@("!I9B`H<W1R;&5N*"1L:7-T<U]S='(I("$]
M("1L96YG=&@I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RXB*2D["B`@("`@("`@?0H@("`@("`@("1L:7-T
M<U]L:6YE<R`](&5X<&QO9&4H(EQN(BP@)&QI<W1S7W-T<BD["B`@("`@("`@
M)&QI<W1S(#T@87)R87DH*3L*("`@("`@("`O*B!,;V]P('1H<F]U9V@@;&EN
M97,@86YD('!I8VL@;W5T('1H92!F:65L9',L(&UA:V4@<W5R92!T:&%T('1H
M92`B(@H@("`@("`@("`J(&%R92!N;W0@:6YC;'5D960@:6X@=&AE('9A;'5E
M<RP@<V\@9V5T('1H92!L:6YE(&QE<W,@,2!C:&%R(&]N(&5A8V@*("`@("`@
M("`@*B!E;F0@86YD('-P;&ET(&9O<B`B+"(N("HO"B`@("`@("`@9F]R96%C
M:"`H)&QI<W1S7VQI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@(&QI<W0H
M)&ED+"`D;F%M92P@)&-O=6YT*2`](&5X<&QO9&4H)R(L(B<L('-U8G-T<B@D
M;&EN92P@,2P@+3$I*3L*("`@("`@("`@("`@)&QI<W1S6R1I9%T@/2!A<G)A
M>2@G;F%M92<@(#T^("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C;W5N="<@/3X@)&-O=6YT*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D;&ES=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:&5S
M(&$@<W!E8VEF:6,@9&ES=')I8G5T:6]N(&QI<W0@9G)O;2!T:&4@9V%T97=A
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4:&4@240@;V8@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T('1O(&9E=&-H+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($%N(&%R<F%Y(&]F(&YU;6)E<G,@:6X@=&AE(&QI<W0@
M;VX@<W5C8V5S<R!O<B!014%2($5R<F]R"B`@("`@*B`@("`@("`@("`@("`@
M("!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,:7-T*"1I
M9"D*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I
M="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&1I<W1R:6)U=&EO
M;BYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/4=%5$Y534)%4E-7
M251(240F9&ES=&ED/25S)RP*("`@("`@("`@("`@("`@("`@("`@("!U<FQE
M;F-O9&4H)'1H:7,M/E]P87)A;7-;)W5S97(G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==
M*2P*("`@("`@("`@("`@("`@("`@("`@("`D:60I.PH@("`@("`@("1R97-P
M;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&EF
M('1H97)E('=A<R!A;B!E<G)O<B!R97-P;VYS92X@*B\*("`@("`@("!I9B`H
M<W5B<W1R*"1R97-P;VYS92P@,"P@,C(I("$]("=!45--4RU$25-44DE"551)
M3TY,25-4)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5R<F]R
M*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(I*3L*("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H
M92!R97-P;VYS92!A;F0@8V]N<W1R=6-T('1H92!A<G)A>2X@*B\*("`@("`@
M("!L:7-T*"1R97-P;VYS92P@)&QI<W1?<W1R*2`](&5X<&QO9&4H)RPG+"`D
M<F5S<&]N<V4L(#(I.PH*("`@("`@("`O*B!#:&5C:R!T:&%T('1H92!F=6QL
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S(&AA<R!B965N(')E8V5I=F5D
M+B`J+PH@("`@("`@("1L96YG=&@@/2!S=6)S='(H)')E<W!O;G-E+"`R,BD[
M"B`@("`@("`@:68@*'-T<FQE;B@D;&ES=%]S='(I("$]("1L96YG=&@I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(I*3L*("`@
M("`@("!]"B`@("`@("`@)&QI<W1?<W1R(#T@=')I;2@D;&ES=%]S='(I.PH@
M("`@("`@(&QI<W0H)&-O=6YT+"`D;G5M8F5R<RD@/2!E>'!L;V1E*"<B+"(G
M+"`D;&ES=%]S='(I.PH*("`@("`@("`O*B!43T1/.B!!;GET:&EN9R!U<V5F
M=6P@=&AA="!C86X@8F4@9&]N92!W:71H('1H92!C;W5N="!O9B!N=6UB97)S
M(&%T"B`@("`@("`@("H@=&AE('-T87)T/R`J+PH@("`@("`@("1C;W5N="`]
M('-U8G-T<B@D8V]U;G0L(#$I.PH*("`@("`@("`O*B!%>'!L;V1E('1H92!L
M:7-T(&]F(&YU;6)E<G,@:6YT;R!A;B!A<G)A>2!A;F0@<F5T=7)N+B`J+PH@
M("`@("`@("1N=6UB97)S(#T@<W5B<W1R*"1N=6UB97)S+"`P+"`M,2D["B`@
M("`@("`@<F5T=7)N(&5X<&QO9&4H)RPG+"`D;G5M8F5R<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!)9&5N=&EF:65S('1H:7,@9V%T97=A>2!D<FEV97(@
M86YD(')E='5R;G,@82!B<FEE9B!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!D<FEV97(@:6YF;RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T26YF;R@I"B`@("!["B`@("`@("`@)&EN9F];
M)VYA;64G72`](%\H(G-M<S)E;6%I;"!V:6$@2%144"(I.PH@("`@("`@("1I
M;F9O6R=D97-C)UT@/2!?*")4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB*3L*"B`@
M("`@("`@<F5T=7)N("1I;F9O.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@<F5Q=6ER960@<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y
M(&1R:79E<BX@5&AE('-E='1A8FQE"B`@("`@*B!P87)A;65T97)S(&9O<B!T
M:&ES(&=A=&5W87D@87)E.CQP<F4^"B`@("`@*B`@("T@=7-E<B`@("`@("`@
M("`@("T@5&AE('5S97)N86UE(&9O<B!A=71H96YT:6-A=&EO;B!O;B!T:&4@
M9V%T97=A>3L*("`@("`J("`@+2!P87-S=V]R9"`@("`@("`@+2!4:&4@<&%S
M<W=O<F0@9F]R(&%U=&AE;G1I8V%T:6]N(&]N('1H92!G871E=V%Y.PH@("`@
M("H@("`M('-S;"`@("`@("`@("`@("`M(%=H971H97(@;W(@;F]T('1O('5S
M92!34TP@9F]R(&-O;6UU;FEC871I;VX@=VET:`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('1H92!G871E=V%Y+@H@("`@("H@("`M(&1E;&EV97)Y
M7W)E<&]R="`M($$@55),(&9O<B!A('-C<FEP="!W:&EC:"!W;W5L9"!A8V-E
M<'0@9&5L:79E<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R97!O
M<G0@9G)O;2!T:&4@9V%T97=A>2X*("`@("`J(#PO<')E/@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F(')E<75I<F5D('!A<F%M971E
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M<R@I"B`@("!["B`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@)'!A<F%M<ULG=7-E
M<B==("`@("`](&%R<F%Y*"=L86)E;"<@/3X@7R@B57-E<FYA;64B*2P@)W1Y
M<&4G(#T^("=T97AT)RD["B`@("`@("`@)'!A<F%M<ULG<&%S<W=O<F0G72`]
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B4&%S<W=O<F0B*2P@)W1Y<&4G(#T^("=T
M97AT)RD["B`@("`@("`@)'!A<F%M<ULG<W-L)UT@("`@("`](&%R<F%Y*"=L
M86)E;"<@("`@/3X@7R@B57-E(%-33"(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G='EP92<@("`@(#T^("=B;V]L96%N)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]
M/B!F86QS92D["B`@("`@("`@)'!A<F%M<ULG9&5L:79E<GE?<F5P;W)T)UT@
M/2!A<G)A>2@G;&%B96PG("`@(#T^(%\H(E523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R="(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`@("`]/B`G=&5X="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5Q=6ER960G(#T^(&9A;'-E*3L*"@H@("`@("`@(')E='5R;B`D<&%R86US
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R
M<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L="!F;W(@<V5N9&EN9R!M97-S
M86=E<PH@("`@("H@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<B!A;F0@9&ES
M<&QA>65D('=H96X@<V5N9&EN9R!M97-S86=E<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!P87)A;65T97)S('1H870@8V%N(&)E
M('-E="!A<R!D969A=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A
M=6QT4V5N9%!A<F%M<R@I"B`@("!["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y
M*"D["B`@("`@("`@)'!A<F%M<ULG9G)O;2==(#T@87)R87DH"B`@("`@("`@
M("`@("=L86)E;"<@/3X@7R@B4V]U<F-E(&%D9')E<W,B*2P*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=T97AT)RD["@H@("`@("`@("1P87)A;7-;)V1E;&EV
M7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^(%\H(D1E
M;&EV97)Y('1I;64B*2P*("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*
M("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH87)R87DH)VYO=R<@/3X@
M7R@B:6UM961I871E(BDL("=U<V5R)R`]/B!?*")U<V5R('-E;&5C="(I*2DI
M.PH*("`@("`@("`D='EP97,@/2!A<G)A>2@G4TU37U1%6%0G(#T^("=335-?
M5$585"<L("=335-?1DQ!4T@G(#T^("=335-?1DQ!4T@G*3L*("`@("`@("`D
M<&%R86US6R=M<V=?='EP92==(#T@87)R87DH"B`@("`@("`@("`@("=L86)E
M;"<@/3X@7R@B365S<V%G92!T>7!E(BDL"B`@("`@("`@("`@("=T>7!E)R`]
M/B`G;75L=&EE;G5M)RP*("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH
M)'1Y<&5S*2D["@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!F;W(@<V5N9&EN
M9R!M97-S86=E<R!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R+`H@("`@("H@
M9&ES<&QA>65D('=H96X@<V5N9&EN9R!M97-S86=E<RX@5&AE<V4@87)E(&9I
M;'1E<F5D(&]U="!U<VEN9R!T:&4*("`@("`J(&1E9F%U;'0@=F%L=65S('-E
M="!U<"!W:&5N(&-R96%T:6YG('1H92!G871E=V%Y+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%R<F%Y(&]F(')E<75I<F5D('!A<F%M971E<G,N
M"B`@("`@*B!`=&]D;R`@5V]U;&0@8F4@;FEC92!T;R!U<V4@82!T:6UE+V1A
M=&4@<V5T=7`@<F%T:&5R('1H86X@;6EN=71E<R!F<F]M"B`@("`@*B`@("`@
M("`@;F]W(&9O<B!T:&4@9&5L:79E<GD@=&EM92X@57!L;V%D(&9I96QD(&9O
M<B!R:6YG=&]N97,O;&]G;W,_"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E
M;F1087)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'!A
M<F%M<ULG9G)O;2==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=F<F]M)UT@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("=L86)E;"<@/3X@7R@B4V]U<F-E
M(&%D9')E<W,B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1P87)A;7-;)V1E;&EV7W1I;64G
M72`]/2`G=7-E<B<I('L*("`@("`@("`@("`@)'!A<F%M<ULG9&5L:79?=&EM
M92==(#T@87)R87DH"B`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(D1E
M;&EV97)Y('1I;64B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G:6YT
M)RP*("`@("`@("`@("`@("`@("=D97-C)R`]/B!?*")686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N
M="@D<&%R86US6R=M<V=?='EP92==*2`^(#$I('L*("`@("`@("`@("`@)'!A
M<F%M<ULG;7-G7W1Y<&4G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQA
M8F5L)R`]/B!?*")-97-S86=E('1Y<&4B*2P*("`@("`@("`@("`@("`@("=T
M>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A
M<G)A>2@D<&%R86US6R=M<V=?='EP92==*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!A<F%M<ULG;7-G7W1Y<&4G72`]("1P87)A;7-;)VUS
M9U]T>7!E)UU;,%T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<F%M
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S=')I;F<@<F5P
M<F5S96YT871I;VX@;V8@86X@97)R;W(@8V]D92X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D97)R;W(@(%1H92!E<G)O<B!C;V1E('1O(&QO;VL@
M=7`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@($%N(&5X:7-T:6YG
M(&5R<F]R('1E>'0@=&\@=7-E('1O(')A:7-E(&$*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4B!%<G)O<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!!('1E>'1U86P@;65S<V%G92!C;W)R97-P;VYD:6YG('1O
M('1H92!E<G)O<B!C;V1E(&]R(&$*("`@("`J("`@("`@("`@("`@("`@(%!%
M05(@17)R;W(@:68@<&%S<V5D(&%N(&5X:7-T:6YG(&5R<F]R('1E>'0N"B`@
M("`@*@H@("`@("H@0'1O9&\@($-H96-K('=H:6-H(&]F('1H97-E(&%R92!A
M8W1U86QL>2!R97%U:7)E9"!A;F0@=')I;2!D;W=N('1H90H@("`@("H@("`@
M("`@(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5R<F]R*"1E<G)O
M<BP@)&5R<F]R7W1E>'0@/2`G)RD*("`@('L*("`@("`@("`D97)R;W(@/2!T
M<FEM*"1E<G)O<BD["@H@("`@("`@("\J($%N(&%R<F%Y(&]F(&5R<F]R(&-O
M9&5S(')E='5R;F5D(&)Y('1H92!G871E=V%Y+B`J+PH@("`@("`@("1E<G)O
M<G,@/2!A<G)A>2@*("`@("`@("`@("`@)T%14TU3+4Y/05542$1%5$%)3%,G
M("`@("`@("`]/B!?*").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="XB*2P*("`@("`@("`@("`@)T%14TU3+4%55$A%4E)/4B<@("`@("`@("`@
M("`]/B!?*"));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(I
M+`H@("`@("`@("`@("`G05%335,M3D]-4T<G("`@("`@("`@("`@("`@(#T^
M(%\H(DYO(&UE<W-A9V4@<W5P<&QI960N(BDL"B`@("`@("`@("`@("=!45--
M4RU.3T1%4U0G("`@("`@("`@("`@("`@/3X@7R@B3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N(BDL"B`@("`@("`@("`@("=!45--4RU.3T-2141)5"<@("`@
M("`@("`@("`@/3X@7R@B26YS=69F:6-I96YT(&-R961I="XB*2P*("`@("`@
M("`@("`@)T%14TU3+4Y/3D%-15-54%!,245$)R`@("`@("`]/B!?*").;R!N
M86UE('-P96-I9FEE9"XB*2P*("`@("`@("`@("`@)T%14TU3+4Y/3E5-0D52
M4U504$Q)140G("`@("`]/B!?*").;R!N=6UB97(@<W!E8VEF:65D+B(I+`H@
M("`@("`@("`@("`G05%335,M041$4D534T)/3TM%4E)/4B<@("`@(#T^(%\H
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(I+`H@("`@("`@("`@("`G05%335,M0T].5$%#5$E$15)23U(G("`@("`@
M(#T^(%\H(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92XB*2P*("`@("`@("`@("`@)T%14TU3+4-/3E1!0U154$1!5$5%4E)/4B<@
M("`]/B!?*")4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A
M8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB*2P*("`@("`@
M("`@("`@)T%14TU3+41)4U1)1$524D]2)R`@("`@("`@("`]/B!?*")4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N(BDL
M"B`@("`@("`@("`@("=!45--4RU.3T1)4U1,25-44U504$Q)140G("`@/3X@
M7R@B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(I
M+`H@("`@("`@("`@("`G05%335,M24Y3549&24-)14Y40U)%1$E44R<@(#T^
M(%\H(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(BDL"B`@("`@("`@("`@("=!45--4RU.3TY534)%4DQ)
M4U1355!03$E%1"<@/3X@7R@B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB*2P*("`@("`@("`@("`@
M)T%14TU3+41)4U1,25-455!$051%15)23U(G("`]/B!?*")4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+B(I*3L*"B`@("`@("`@:68@*&5M<'1Y*"1E
M<G)O<E]T97AT*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R<ULD97)R
M;W)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H)&5R<F]R7W1E>'0L("1E<G)O<G-;)&5R
M<F]R72DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1O('1H
M92!H='1P(&-A;&P@=7-I;F<@82!U<FP@<&%S<V5D('1O('1H92!F=6YC=&EO
M;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!U<FP@=&\@8V%L;"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5S<&]N<V4@;VX@<W5C8V5S
M<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C86QL55),*"1U<FPI"B`@("!["B`@("`@("`@)&]P=&EO;G-;)VUE
M=&AO9"==(#T@)U!/4U0G.PH@("`@("`@("1O<'1I;VYS6R=T:6UE;W5T)UT@
M/2`U.PH@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@=')U
M93L*"B`@("`@("`@)'5R;"`]("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<W-L
M)UTI(#\@)VAT='`Z+R\G(#H@)VAT='!S.B\O)RD@+B`D=&AI<RT^7V)A<V5?
M=7)L("X@)'5R;#L*"B`@("`@("`@:68@*"%`:6YC;'5D95]O;F-E("=(5%10
M+U)E<75E<W0N<&AP)RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(BDI.PH@("`@("`@('T*("`@("`@("`D:'1T<"`]("9N97<@2%144%]297%U
M97-T*"1U<FPL("1O<'1I;VYS*3L*("`@("`@("!`)&AT='`M/G-E;F1297%U
M97-T*"D["B`@("`@("`@:68@*"1H='1P+3YG971297-P;VYS94-O9&4H*2`A
M/2`R,#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")#;W5L9"!N;W0@;W!E;B`E<RXB*2P@)'5R;"DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1H='1P+3YG971297-P;VYS94)O9'DH
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'``````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(Q,S``
M,3`U,34T,S$P-C$`,#(R-S8P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!.971?4TU37W9O9&%F;VYE
M:71A;'E?<VUT<"!#;&%S<R!I;7!L96UE;G1S('1H92!33510($%022!F;W(@
M86-C97-S:6YG('1H90H@*B!6;V1A9F]N92!)=&%L>2!335,@9V%T97=A>2X@
M57-E(&]F('1H:7,@9V%T97=A>2!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M"B`J('=I=&@@5F]D869O;F4@271A;'D@*'=W=RXQ.3`N:70I+@H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%T=&5O(%IA;6)E;&QI(#QM
M;7IA;6)E0&AO=&UA:6PN8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<"QV(#$N,3$N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@
M*@H@*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M($!A=71H;W(@36%T=&5O(%IA;6)E;&QI(#QM;7IA;6)E0&AO=&UA:6PN8V]M
M/@H@*B!`<&%C:V%G92!.971?4TU3"B`J+PIC;&%S<R!.971?4TU37W9O9&%F
M;VYE:71A;'E?<VUT<"!E>'1E;F1S($YE=%]335,@>PH*("`@("\J*@H@("`@
M("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV
M97(@8V%N(')E<&]R="!W:&EC:"!O<&5R871I;VYS"B`@("`@*B!I="!S=7!P
M;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X@4&]S<VEB;&4@=F%L=65S(&%R
M93H\<')E/@H@("`@("H@("!A=71H("`@("`@("`M(%1H92!G871E=V%Y(')E
M<75I<F4@875T:&5N=&EC871I;VX@8F5F;W)E('-E;F1I;F<["B`@("`@*B`@
M(&)A=&-H("`@("`@("T@0F%T8V@@<V5N9&EN9R!I<R!S=7!P;W)T960["B`@
M("`@*B`@(&UU;'1I("`@("`@("T@4V5N9&EN9R!O9B!M97-S86=E<R!T;R!M
M=6QT:7!L92!R96-I<&EE;G1S(&ES('-U<'!O<G1E9#L*("`@("`J("`@<F5C
M96EV92`@("`@+2!7:&5T:&5R('1H:7,@9')I=F5R(&ES(&-A<&%B;&4@;V8@
M<F5C96EV:6YG(%--4SL*("`@("`J("`@8W)E9&ET("`@("`@+2!)<R!U<V4@
M;V8@=&AE(&=A=&5W87D@8F%S960@;VX@8W)E9&ET<SL*("`@("`J("`@861D
M<F5S<V)O;VL@+2!!<F4@9V%T97=A>2!A9&1R97-S8F]O:W,@<W5P<&]R=&5D
M.PH@("`@("H@("!L:7-T<R`@("`@("`M($=A=&5W87D@<W5P<&]R="!F;W(@
M9&ES=')I8G5T:6]N(&QI<W1S+@H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`]
M(&%R<F%Y*"=A=71H)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=B871C:"<@("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=M=6QT:2<@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96-E:79E)R`@
M("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C
M<F5D:70G("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=A9&1R97-S8F]O:R<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=L:7-T<R<@("`@("`@/3X@9F%L<V4I.PH*("`@
M("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!D;V5S('1H92!A8W1U86P@<V5N
M9&EN9R!O9B!T:&4@;65S<V%G92X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@(%1H
M92!A<G)A>2!C;VYT86EN:6YG('1H92!M97-S86=E(&%N9"!I=',@<V5N9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&\@("`@("!4:&4@9&5S=&EN871I;VX@<W1R
M:6YG+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y('=I
M=&@@=&AE('-U8V-E<W,@<W1A='5S(&%N9"!A9&1I=&EO;F%L"B`@("`@*B`@
M("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-E;F0H)B1M97-S86=E+"`D=&\I"B`@("!["B`@("`@("`@:68@*"%`
M:6YC;'5D95]O;F-E("=-86EL+G!H<"<I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"XB*2D["B`@("`@("`@?0H@("`@("`@("1M86EL97(@/2!-
M86EL.CIF86-T;W)Y*"=M86EL)RD["@H@("`@("`@("\J(%-I;F-E('1H:7,@
M;VYL>2!W;W)K<R!F;W(@271A;&EA;B!N=6UB97)S+"!T:&ES(&ES(&AA<F1C
M;V1E9"X@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+UXN*C\\/RA<*S\S
M.2D_*%QD>S$P?2D^/R\G+"`D=&\L("1M871C:&5S*2D@>PH@("`@("`@("`@
M("`D:&5A9&5R<ULG1G)O;2==(#T@)'1H:7,M/E]P87)A;7-;)W5S97(G73L*
M("`@("`@("`@("`@)'1O(#T@)&UA=&-H97-;,ET@+B`G0'-M<RYV;V1A9F]N
M92YI="<["B`@("`@("`@("`@("1R97-U;'0@/2`D;6%I;&5R+3YS96YD*"1T
M;RP@)&AE861E<G,L("1M97-S86=E6R=T97AT)UTI.PH@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@87)R87DH,"P@)')E<W5L="T^9V5T365S<V%G92@I*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!A
M<G)A>2@Q+"!N=6QL*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@P+"!?*")9;W4@;F5E9"!T;R!P
M<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(BDI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($ED96YT:69I97,@=&AI<R!G871E=V%Y
M(&1R:79E<B!A;F0@<F5T=7)N<R!A(&)R:65F(&1E<V-R:7!T:6]N+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F(&1R:79E<B!I;F9O
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);F9O*"D*("`@('L*("`@("`@
M("`D:6YF;ULG;F%M92==(#T@7R@B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M*3L*("`@("`@("`D:6YF;ULG9&5S8R==(#T@7R@B5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB*3L*"B`@("`@("`@<F5T
M=7)N("1I;F9O.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<F5Q=6ER960@<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&1R:79E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E
M9"!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;7,H
M*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P
M87)A;7-;)W5S97(G72`@("`@("`](&%R<F%Y*"=L86)E;"<@(#T^(%\H(E5S
M97)N86UE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`@/3X@)W1E>'0G*3L*"B`@("`@("`@<F5T=7)N("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T
M97)S('1H870@8V%N(&)E('-E="!A<R!D969A=6QT(&9O<B!S96YD:6YG(&UE
M<W-A9V5S"B`@("`@*B!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!D
M:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A9V5S+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%R<F%Y(&]F('!A<F%M971E<G,@=&AA="!C86X@
M8F4@<V5T(&%S(&1E9F%U;'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E
M9F%U;'1396YD4&%R86US*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E
M<G,@9F]R('-E;F1I;F<@;65S<V%G97,@=7-I;F<@=&AI<R!G871E=V%Y(&1R
M:79E<BP*("`@("`J(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N
M(%1H97-E(&%R92!F:6QT97)E9"!O=70@=7-I;F<@=&AE"B`@("`@*B!D969A
M=6QT('9A;'5E<R!S970@=7`@=VAE;B!C<F5A=&EN9R!T:&4@9V%T97=A>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E
M9"!P87)A;65T97)S+@H@("`@("H@0'1O9&\@(%=O=6QD(&)E(&YI8V4@=&\@
M=7-E(&$@=&EM92]D871E('-E='5P(')A=&AE<B!T:&%N(&UI;G5T97,@9G)O
M;0H@("`@("H@("`@("`@(&YO=R!F;W(@=&AE(&1E;&EV97)Y('1I;64N(%5P
M;&]A9"!F:65L9"!F;W(@<FEN9W1O;F5S+VQO9V]S/PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971396YD4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R;W(@
M8V]D92!T;R!L;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@
M("!!;B!E>&ES=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R86ES92!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(@17)R;W(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@8V]R
M<F5S<&]N9&EN9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@("`@*B`@("`@
M("`@("`@("`@("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN9R!E
M<G)O<B!T97AT+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C:R!W:&EC:"!O
M9B!T:&5S92!A<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R:6T@9&]W;B!T
M:&4*("`@("`J("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971%<G)O<B@D97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@("!["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'``````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,S$Q,C<`,3`U,34T,S$P-C$`,#(R,C(V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!.971?4TU37V-L:6-K871E;&Q?:'1T<"!#;&%S<R!I;7!L96UE
M;G1S('1H92!(5%10($%022!F;W(@86-C97-S:6YG('1H90H@*B!#;&EC:V%T
M96QL("AW=W<N8VQI8VMA=&5L;"YC;VTI(%--4R!G871E=V%Y+@H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP+'8@,2XQ,RXQ,"XY(#(P,#8O
M,#@O,#<@,#`Z-#(Z,S`@8VAU8VL@17AP("0*("H*("H@0&%U=&AO<B!-87)K
M;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!.971?4TU3
M"B`J+PIC;&%S<R!.971?4TU37V-L:6-K871E;&Q?:'1T<"!E>'1E;F1S($YE
M=%]335,@>PH*("`@('9A<B`D7W-E<W-I;VY?:60@/2!N=6QL.PH@("`@=F%R
M("1?8F%S95]U<FP@/2`G:'1T<#HO+V%P:2YC;&EC:V%T96QL+F-O;2]H='1P
M+R<["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L
M('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H(&]P97)A=&EO
M;G,*("`@("`J(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+B!0
M;W-S:6)L92!V86QU97,@87)E.CQP<F4^"B`@("`@*B`@(&%U=&@@("`@("`@
M("T@5&AE(&=A=&5W87D@<F5Q=6ER92!A=71H96YT:6-A=&EO;B!B969O<F4@
M<V5N9&EN9SL*("`@("`J("`@8F%T8V@@("`@("`@+2!"871C:"!S96YD:6YG
M(&ES('-U<'!O<G1E9#L*("`@("`J("`@;75L=&D@("`@("`@+2!396YD:6YG
M(&]F(&UE<W-A9V5S('1O(&UU;'1I<&QE(')E8VEP:65N=',@:7,@<W5P<&]R
M=&5D.PH@("`@("H@("!R96-E:79E("`@("`M(%=H971H97(@=&AI<R!D<FEV
M97(@:7,@8V%P86)L92!O9B!R96-E:79I;F<@4TU3.PH@("`@("H@("!C<F5D
M:70@("`@("`M($ES('5S92!O9B!T:&4@9V%T97=A>2!B87-E9"!O;B!C<F5D
M:71S.PH@("`@("H@("!A9&1R97-S8F]O:R`M($%R92!G871E=V%Y(&%D9')E
M<W-B;V]K<R!S=7!P;W)T960["B`@("`@*B`@(&QI<W1S("`@("`@("T@1V%T
M97=A>2!S=7!P;W)T(&9O<B!D:7-T<FEB=71I;VX@;&ES=',N"B`@("`@*B`\
M+W!R93X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%U=&@G("`@("`@("`]/B!T<G5E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F%T8V@G("`@("`@
M(#T^(#$P,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUU;'1I
M)R`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5C96EV92<@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8W)E9&ET)R`@("`@(#T^('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A9&1R97-S8F]O:R<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T<R<@("`@("`@/3X@
M9F%L<V4I.PH*("`@("\J*@H@("`@("H@075T:&5N=&EC871E(&%T('1H92!G
M871E=V%Y(&%N9"!S970@82!S97-S:6]N(&ED(&EF('-U8V-E<W-F=6PN($-A
M8VAI;F<*("`@("`J(&ES('5S960@=&\@;6EN:6UI<V4@=&AE(&AT='`@8V%L
M;',@9F]R('-U8G-E<75E;G0@;65S<V%G97,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@I"B`@("!["B`@("`@("`@
M+RH@5V4@:&%V92!A;')E861Y(&%U=&AE;G1I8V%T960@<V\@<F5T=7)N('1R
M=64N("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W-E<W-I;VY?:60I
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4V5T('5P('1H92!H='1P(&%U=&AE;G1I8V%T:6]N('5R;"X@*B\*
M("`@("`@("`D=7)L(#T@<W!R:6YT9B@G875T:#]U<V5R/25S)G!A<W-W;W)D
M/25S)F%P:5]I9#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC
M;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@
M("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%P:5]I
M9"==*3L*"B`@("`@("`@+RH@1&\@=&AE($A45%`@875T:&5N=&EC871I;VX@
M86YD(&=E="!T:&4@<F5S<&]N<V4N("HO"B`@("`@("`@)')E<W!O;G-E(#T@
M3F5T7U--4U]C;&EC:V%T96QL7VAT='`Z.E]C86QL55),*"1U<FPI.PH@("`@
M("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B*2P@)')E<W!O;G-E+3YG971-97-S
M86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@("\J(%-P;&ET('5P('1H92!R
M97-P;VYS92X@*B\*("`@("`@("`D<F5S<&]N<V4@/2!E>'!L;V1E*"<Z)RP@
M)')E<W!O;G-E*3L*("`@("`@("!I9B`H)')E<W!O;G-E6S!=(#T]("=/2R<I
M('L*("`@("`@("`@("`@)'1H:7,M/E]S97-S:6]N7VED(#T@=')I;2@D<F5S
M<&]N<V5;,5TI.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5R<F]R*"1R
M97-P;VYS95LQ72P@7R@B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N
M(&1O97,@=&AE(&%C='5A;"!S96YD:6YG(&]F('1H92!M97-S86=E+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D;65S<V%G92`@5&AE(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&UE
M<W-A9V4@86YD(&ET<R!S96YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@('!A<F%M971E<G,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;R`@("`@
M(%1H92!D97-T:6YA=&EO;B!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@06X@87)R87D@=VET:"!T:&4@<W5C8V5S<R!S=&%T=7,@86YD
M(&%D9&ET:6]N86P*("`@("`J("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5N9"@F)&UE<W-A9V4L("1T;RD*
M("`@('L*("`@("`@("`O*B!3970@=7`@=&AE(&AT='`@<V5N9&EN9R!U<FPN
M("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W-E;F1M<V<_<V5S<VEO;E]I
M9#TE<R9T97AT/25S)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E<W-I;VY?:60L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E
M*"1M97-S86=E6R=T97AT)UTI*3L*"B`@("`@("`@)')E<5]F96%T(#T@,#L*
M("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=F
M<F]M)UTI*2!["B`@("`@("`@("`@("\J($EF('-O=7)C92!F<F]M(&ES('-E
M="P@<F5Q=6ER92!I="!F;W(@=')A;G-I="!G871E=V%Y<R!A;F0@87!P96YD
M"B`@("`@("`@("`@("`@('1O('5R;"X@*B\*("`@("`@("`@("`@)')E<5]F
M96%T(#TK(#$V.PH@("`@("`@("`@("`D=7)L("X]("<F9G)O;3TG("X@=7)L
M96YC;V1E*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=F<F]M)UTI.PH@("`@
M("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M
M<R==6R=M<V=?='EP92==*2`F)@H@("`@("`@("`@("`D;65S<V%G95LG<V5N
M9%]P87)A;7,G75LG;7-G7W1Y<&4G72`]/2`G4TU37T9,05-()RD@>PH@("`@
M("`@("`@("`O*B!)9B!M97-S86=E('1Y<&4@:7,@9FQA<V@L(')E<75I<F4@
M:70@9F]R('1R86YS:70@9V%T97=A>7,N("HO"B`@("`@("`@("`@("1R97%?
M9F5A="`]*R`U,3(["B`@("`@("`@("`@("1U<FP@+CT@)R9M<V=?='EP93TG
M("X@)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;)VUS9U]T>7!E)UT["B`@("`@
M("`@?0H@("`@("`@(&EF("@A96UP='DH)')E<5]F96%T*2D@>PH@("`@("`@
M("`@("`O*B!)9B!F96%T=7)E<R!H879E(&)E96X@<F5Q=6ER960L(&%D9"!T
M;R!U<FPN("HO"B`@("`@("`@("`@("1U<FP@+CT@)R9R97%?9F5A=#TG("X@
M)')E<5]F96%T.PH@("`@("`@('T*"B`@("`@("`@+RH@07!P96YD('1H92!R
M96-I<&EE;G1S(&]F('1H:7,@;65S<V%G92!A;F0@8V%L;"!T:&4@=7)L+B`J
M+PH@("`@("`@(&9O<F5A8V@@*"1T;R!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>+BH_/#]<*S\H7&1[-RQ]*2@^
M?"0I+R<L("1V86PL("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'1O
M6R1K97E=(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`O*B!&25A-13H@4VEL96YT;'D@9')O<"!B860@<F5C
M:7!I96YT<RX@5&AI<R!S:&]U;&0@8F4@;&]G9V5D"B`@("`@("`@("`@("`@
M("`@*B!A;F0O;W(@<F5P;W)T960N("HO"B`@("`@("`@("`@("`@("!U;G-E
M="@D=&];)&ME>5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M("1T;R`](&EM<&QO9&4H)RPG+"`D=&\I.PH@("`@("`@("1U<FP@+CT@)R9T
M;STG("X@)'1O.PH@("`@("`@("1R97-P;VYS92`]('1R:6TH)'1H:7,M/E]C
M86QL55),*"1U<FPI*3L*"B`@("`@("`@+RH@56=L>2!P87)S:6YG(&]F('1H
M92!R97-P;VYS92P@8G5T('1H870G<R!H;W<@:70@8V]M97,@8F%C:RX@*B\*
M("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<;B(L("1R97-P;VYS92D["B`@
M("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*"B`@("`@("`@:68@*&-O=6YT
M*"1L:6YE<RD@/B`Q*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A
M<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G
M5&\Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@)')E8VEP:65N="`]('1R
M:6TH)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@("1O=71C;VUE(#T@97AP
M;&]D92@G.B<L("1P87)T<ULP72D["B`@("`@("`@("`@("`@("`D<F5S<&]N
M<V5;)')E8VEP:65N=%T@/2!A<G)A>2@H)&]U=&-O;65;,%T@/3T@)TE$)R`_
M(#$@.B`P*2P@)&]U=&-O;65;,5TI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@4VEN9VQE(')E8VEP:65N="X@*B\*
M("`@("`@("`@("`@)&]U=&-O;64@/2!E>'!L;V1E*"<Z)RP@)&QI;F5S6S!=
M*3L*("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A<G)A>2@H)&]U=&-O
M;65;,%T@/3T@)TE$)R`_(#$@.B`P*2P@)&]U=&-O;65;,5TI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@8W)E9&ET(&)A;&%N8V4@;VX@
M=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8W)E9&ET(&)A;&%N
M8V4@879A:6QA8FQE(&]N('1H92!G871E=V%Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9V5T0F%L86YC92@I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H
M92!U<FP@86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H
M)V=E=&)A;&%N8V4_<V5S<VEO;E]I9#TE<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S97-S:6]N7VED*3L*("`@("`@("`D<F5S<&]N<V4@
M/2!T<FEM*"1T:&ES+3Y?8V%L;%523"@D=7)L*2D["@H@("`@("`@("\J(%1R
M>2!S<&QI='1I;F<@=7`@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1L:6YE
M<R`](&5X<&QO9&4H)STG+"`D<F5S<&]N<V4I.PH*("`@("`@("`O*B!3<&QI
M="!U<"!T:&4@<F5S<&]N<V4N("HO"B`@("`@("`@)')E<W!O;G-E(#T@97AP
M;&]D92@G.B<L("1R97-P;VYS92D["B`@("`@("`@:68@*"1R97-P;VYS95LP
M72`]/2`G0W)E9&ET)RD@>PH@("`@("`@("`@("!R971U<FX@=')I;2@D<F5S
M<&]N<V5;,5TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E6S%=+"!?*")#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,B*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@261E;G1I9FEE<R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!R
M971U<FYS(&$@8G)I968@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@07)R87D@;V8@9')I=F5R(&EN9F\N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$EN9F\H*0H@("`@>PH@("`@("`@("1I;F9O6R=N86UE
M)UT@/2!?*")#;&EC:V%T96QL('9I82!(5%10(BD["B`@("`@("`@)&EN9F];
M)V1E<V,G72`](%\H(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(BD["@H@("`@
M("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@9F]R('1H:7,@9V%T97=A>2!D
M<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@
M<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@
M("`@("`D<&%R86US6R=U<V5R)UT@("`@(#T@87)R87DH)VQA8F5L)R`]/B!?
M*")5<V5R;F%M92(I+"`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("`D<&%R
M86US6R=P87-S=V]R9"==(#T@87)R87DH)VQA8F5L)R`]/B!?*")087-S=V]R
M9"(I+"`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("`D<&%R86US6R=A<&E?
M:60G72`@(#T@87)R87DH)VQA8F5L)R`]/B!?*")!4$D@240B*2P@)W1Y<&4G
M(#T^("=T97AT)RD["@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!T:&%T(&-A
M;B!B92!S970@87,@9&5F875L="!F;W(@<V5N9&EN9R!M97-S86=E<PH@("`@
M("H@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<B!A;F0@9&ES<&QA>65D('=H
M96X@<V5N9&EN9R!M97-S86=E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!<G)A>2!O9B!P87)A;65T97)S('1H870@8V%N(&)E('-E="!A<R!D
M969A=6QT+@H@("`@("H@0'1O9&\@(%-E="!U<"!B871C:"!F:65L9',O<&%R
M86US+"!W;W5L9"!B92!N:6-E('1O(&AA=F4@<FEN9W1O;F4O;&]G;PH@("`@
M("H@("`@("`@('-U<'!O<G0@=&]O+"!Q=65U92!C:&]I8V4L('5N:6-O9&4@
M8VAO:6-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT4V5N9%!A
M<F%M<R@I"B`@("!["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@
M("`@)'!A<F%M<ULG9G)O;2==(#T@87)R87DH"B`@("`@("`@("`@("=L86)E
M;"<@/3X@7R@B4V]U<F-E(&%D9')E<W,B*2P*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=T97AT)RD["@H@("`@("`@("1P87)A;7-;)V1E;&EV7W1I;64G72`]
M(&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^(%\H(D1E;&EV97)Y('1I
M;64B*2P*("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@
M("`@)W!A<F%M<R<@/3X@87)R87DH87)R87DH)VYO=R<@/3X@7R@B:6UM961I
M871E(BDL("=U<V5R)R`]/B!?*")U<V5R('-E;&5C="(I*2DI.PH*("`@("`@
M("`D='EP97,@/2!A<G)A>2@G4TU37U1%6%0G(#T^("=335-?5$585"<L("=3
M35-?1DQ!4T@G(#T^("=335-?1DQ!4T@G*3L*("`@("`@("`D<&%R86US6R=M
M<V=?='EP92==(#T@87)R87DH"B`@("`@("`@("`@("=L86)E;"<@/3X@7R@B
M365S<V%G92!T>7!E(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G;75L=&EE
M;G5M)RP*("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH)'1Y<&5S*2D[
M"@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!F;W(@<V5N9&EN9R!M97-S86=E
M<R!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R+`H@("`@("H@9&ES<&QA>65D
M('=H96X@<V5N9&EN9R!M97-S86=E<RX@5&AE<V4@87)E(&9I;'1E<F5D(&]U
M="!U<VEN9R!T:&4*("`@("`J(&1E9F%U;'0@=F%L=65S('-E="!F;W(@=&AE
M(&=A=&5W87DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@
M;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J($!T;V1O("!7;W5L9"!B
M92!N:6-E('1O('5S92!A('1I;64O9&%T92!S971U<"!R871H97(@=&AA;B!M
M:6YU=&5S(&9R;VT*("`@("`J("`@("`@("!N;W<@9F]R('1H92!D96QI=F5R
M>2!T:6UE+B!5<&QO860@9FEE;&0@9F]R(')I;F=T;VYE<R]L;V=O<S\*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V5N9%!A<F%M<R@D<&%R86US*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=F<F]M)UTI*2!["B`@("`@
M("`@("`@("1P87)A;7-;)V9R;VTG72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)VQA8F5L)R`]/B!?*")3;W5R8V4@861D<F5S<R(I+`H@("`@("`@("`@
M("`@("`@)W1Y<&4G(#T^("=T97AT)RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'!A<F%M<ULG9&5L:79?=&EM92==(#T]("=U<V5R)RD@>PH@("`@("`@
M("`@("`D<&%R86US6R=D96QI=E]T:6UE)UT@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("=L86)E;"<@/3X@7R@B1&5L:79E<GD@=&EM92(I+`H@("`@("`@
M("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^(%\H(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7-;)VUS9U]T>7!E)UTI
M(#X@,2D@>PH@("`@("`@("`@("`D<&%R86US6R=M<V=?='EP92==(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(DUE<W-A9V4@='EP
M92(I+`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@
M("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"1P87)A;7-;)VUS9U]T>7!E
M)UTI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R86US6R=M
M<V=?='EP92==(#T@)'!A<F%M<ULG;7-G7W1Y<&4G75LP73L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!A;B!E<G)O
M<B!C;V1E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1E<G)O<B`@
M5&AE(&5R<F]R(&-O9&4@=&\@;&]O:R!U<"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@("`@06X@97AI<W1I;F<@97)R;W(@=&5X="!T;R!U<V4@=&\@
M<F%I<V4@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!014%2($5R
M<F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@=&5X='5A;"!M
M97-S86=E(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&5R<F]R(&-O9&4@;W(@80H@
M("`@("H@("`@("`@("`@("`@("`@4$5!4B!%<G)O<B!I9B!P87-S960@86X@
M97AI<W1I;F<@97)R;W(@=&5X="X*("`@("`J"B`@("`@*B!`=&]D;R`@0VAE
M8VL@=VAI8V@@;V8@=&AE<V4@87)E(&%C='5A;&QY(')E<75I<F5D(&%N9"!T
M<FEM(&1O=VX@=&AE"B`@("`@*B`@("`@("`@;&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T17)R;W(H)&5R<F]R+"`D97)R;W)?=&5X="`]("<G*0H@
M("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!G970@;VYL>2!T:&4@;G5M
M8F5R(&%T('1H92!S=&%R="!O9B!A;B!E<G)O<BX@*B\*("`@("`@("!L:7-T
M*"1E<G)O<BD@/2!E>'!L;V1E*"<L)RP@)&5R<F]R*3L*("`@("`@("`D97)R
M;W(@/2!T<FEM*"1E<G)O<BD["@H@("`@("`@("\J($%N(&%R<F%Y(&]F(&5R
M<F]R(&-O9&5S(')E='5R;F5D(&)Y('1H92!G871E=V%Y+B`J+PH@("`@("`@
M("1E<G)O<G,@/2!A<G)A>2@G,#`Q)R`]/B!?*")!=71H96YT:6-A=&EO;B!F
M86EL960B*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S`P,B<@/3X@7R@B
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@)S`P,R<@/3X@7R@B4V5S<VEO;B!)1"!E>'!I<F5D+B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G,#`T)R`]/B!?*")!8V-O=6YT
M(&9R;WIE;BXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S`P-2<@/3X@
M7R@B36ES<VEN9R!S97-S:6]N($E$+B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G,#`W)R`]/B!?*"))4"!L;V-K9&]W;B!V:6]L871I;VXN(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("<Q,#$G(#T^(%\H(DEN=F%L:60@;W(@
M;6ES<VEN9R!P87)A;65T97)S+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G,3`R)R`]/B!?*"));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3`S)R`]/B!?*")5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("<Q,#0G(#T^(%\H(E5N:VYO=VX@8VQI;7-G:60@*$-L
M:65N="!-97-S86=E($E$*2XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)S$P-2<@/3X@7R@B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G,3`V)R`]/B!?*"));G9A;&ED('-O
M=7)C92!A9&1R97-S+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3`W
M)R`]/B!?*")%;7!T>2!M97-S86=E+B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G,3`X)R`]/B!?*"));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3`Y)R`]/B!?*")-:7-S:6YG
M(&UE<W-A9V4@240N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,3`G
M(#T^(%\H(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)S$Q,2<@/3X@7R@B26YV86QI9"!P<F]T;V-O;"XB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$Q,B<@/3X@7R@B26YV86QI
M9"!M<V=?='EP92XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$Q,R<@
M/3X@7R@B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("<Q,30G(#T^(%\H(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("<Q,34G(#T^(%\H(DUE<W-A9V4@97AP:7)E9"XB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)S$Q-B<@/3X@7R@B26YV86QI9"!U;FEC;V1E
M(&1A=&$N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<R,#$G(#T^(%\H
M(DEN=F%L:60@8F%T8V@@240N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("<R,#(G(#T^(%\H(DYO(&)A=&-H('1E;7!L871E+B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G,S`Q)R`]/B!?*").;R!C<F5D:70@;&5F="XB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)S,P,B<@/3X@7R@B36%X(&%L;&]W
M960@8W)E9&ET+B(I*3L*"B`@("`@("`@:68@*&5M<'1Y*"1E<G)O<E]T97AT
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R<ULD97)R;W)=.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H)&5R<F]R7W1E>'0L("1E<G)O<G-;)&5R<F]R72DI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1O('1H92!H='1P(&-A
M;&P@=7-I;F<@82!U<FP@<&%S<V5D('1O('1H92!F=6YC=&EO;BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<FP@(%1H92!U<FP@=&\@8V%L;"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@<F5S<&]N<V4@;VX@<W5C8V5S<R!O<B!014%2
M($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C86QL
M55),*"1U<FPI"B`@("!["B`@("`@("`@)&]P=&EO;G-;)VUE=&AO9"==(#T@
M)T=%5"<["B`@("`@("`@)&]P=&EO;G-;)W1I;65O=70G72`](#4["B`@("`@
M("`@)&]P=&EO;G-;)V%L;&]W4F5D:7)E8W1S)UT@/2!T<G5E.PH*("`@("`@
M("!I9B`H(4!I;F-L=61E7V]N8V4@)TA45%`O4F5Q=65S="YP:'`G*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DUI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB*2D["B`@("`@("`@?0H@("`@
M("`@("1H='1P(#T@)FYE=R!(5%107U)E<75E<W0H)'1H:7,M/E]B87-E7W5R
M;"`N("1U<FPL("1O<'1I;VYS*3L*("`@("`@("!`)&AT='`M/G-E;F1297%U
M97-T*"D["B`@("`@("`@:68@*"1H='1P+3YG971297-P;VYS94-O9&4H*2`A
M/2`R,#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")#;W5L9"!N;W0@;W!E;B`E<RXB*2P@)'5R;"DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1H='1P+3YG971297-P;VYS94)O9'DH
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'``````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(V-#(`,3`U,34T,S$P-C$`
M,#(Q-30P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!'96YE<FEC(&4M;6%I;"!B87-E9"!335,@9')I
M=F5R"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@5V5B4W!R;V-K971S+"!,
M3$,*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J(%1H:7,@9')I=F5R(&EN=&5R9F%C97,@
M=VET:"!T:&4@96UA:6PM=&\M<VUS(&=A=&5W87ES('!R;W9I9&5D(&)Y(&UA
M;GD*("H@8V%R<FEE<G,L('!A<G1I8W5L87)L>2!T:&]S92!B87-E9"!I;B!T
M:&4@52Y3+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP+'8@,2XX+C(N-"`R,#`V+S`W+S$S(#`X.C4W.C0U
M(&IA;B!%>'`@)`H@*@H@*B!`8V%T96=O<GD@("!.971W;W)K:6YG"B`J($!P
M86-K86=E("`@($YE=%]335,*("H@0&%U=&AO<B`@("`@26%N($5U<F4@/&EE
M=7)E0'!H<"YN970^"B`J($!S:6YC92`@("`@($AO<F1E(#,N,0H@*B!`<VEN
M8V4@("`@("!.971?4TU3(#`N,"XR"B`J+PIC;&%S<R!.971?4TU37V=E;F5R
M:6-?<VUT<"!E>'1E;F1S($YE=%]335,@>PH*("`@("\J*@H@("`@("H@0V%P
M86)I;&ET:65S(&]F('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@*
M("`@("`@("`G875T:"<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=B871C
M:"<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VUU;'1I)R`@("`@("`]/B!F
M86QS92P*("`@("`@("`G<F5C96EV92<@("`@(#T^(&9A;'-E+`H@("`@("`@
M("=C<F5D:70G("`@("`@/3X@9F%L<V4L"B`@("`@("`@)V%D9')E<W-B;V]K
M)R`]/B!F86QS92P*("`@("`@("`G;&ES=',G("`@("`@(#T^(&9A;'-E"B`@
M("`I.PH*("`@("\J*@H@("`@("H@1')I=F5R('!A<F%M971E<G,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@*("`@("`@
M("`G8V%R<FEE<B<@("`@(#T^(&YU;&PL"B`@("`@("`@)VUA:6Q"86-K96YD
M)R`]/B`G;6%I;"<L"B`@("`@("`@)VUA:6Q087)A;7,G("`]/B!A<G)A>2@I
M+`H@("`@("`@("=M86EL2&5A9&5R<R<@/3X@87)R87DH*0H@("`@*3L*"B`@
M("`O*BH*("`@("`J($-A<G)I97(@96UA:6P@;6%P+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?8V%R<FEE<G,@/2!A<G)A>2@*("`@("`@("`O*B!5
M+E,N(&-A<G)I97)S+B`J+PH@("`@("`@("=A='0G("`@("`@("`@(#T^("<E
M<T!M;6]D92YC;VTG+`H@("`@("`@("=C:6YG=6QA<B<@("`@(#T^("<E<T!M
M;6]D92YC;VTG+`H@("`@("`@("=V97)I>F]N)R`@("`@(#T^("<E<T!V=&5X
M="YC;VTG+`H@("`@("`@("=B;V]S="<@("`@("`@(#T^("<E<T!M>6)O;W-T
M;6]B:6QE+F-O;2<L"B`@("`@("`@)V-E;&QU;&%R;VYE)R`@/3X@)R5S0&UY
M8V5L;&]N92YN970G+`H@("`@("`@("=C:6YC>6)E;&PG("`@(#T^("<E<T!G
M;V-B=RYC;VTG+`H@("`@("`@("=S<')I;G0G("`@("`@(#T^("<E<T!M97-S
M86=I;F<N<W!R:6YT<&-S+F-O;2<L"B`@("`@("`@)W1M;V)I;&5?=7,G("`@
M/3X@)R5S0'1M;VUA:6PN8V]M)RP*("`@("`@("`G<W5N8V]M)R`@("`@("`]
M/B`G)7-`=&US+G-U;F-O;2YC;VTG+`H@("`@("`@("=A:7)C96PG("`@("`@
M(#T^("<E<T!A:7)S;7,N8V]M)RP*("`@("`@("`G86ER=&5L)R`@("`@("`]
M/B`G)7-`86ER=&5L;6%I;"YC;VTG+`H@("`@("`@("=B<&QM;V)I;&4G("`@
M(#T^("<E<T!B<&QM;V)I;&4N8V]M)RP*("`@("`@("`G8F5L;&UO8FEL:71Y
M)R`]/B`G)7-`='AT+F)E;&QM;V)I;&ET>2YC82<L"B`@("`@("`@)V)L=65G
M<F%S<R<@("`@/3X@)R5S0'-M<RYB;'5E8V5L;"YC;VTG+`H@("`@("`@("=C
M96QL9F]R8V4G("`@(#T^("<E<T!C96QF;W)C92YC;VTG+`H@("`@("`@("=C
M96QL=6QA<F]N92<@(#T^("<E<T!M>6-E;&QO;F4N;F5T)RP*("`@("`@("`O
M*B!'97)M86X@8V%R<FEE<G,N("HO"B`@("`@("`@)V5P;'5S)R`@("`@("`]
M/B`G)7-`<VUS;6%I;"YE<&QU<RYD92<L"B`@("`@("`@)W1M;V)I;&5?9&4G
M("`]/B`G)7-`="UM;V)I;&4M<VUS+F1E)RP*("`@("`@("`G=F]D869O;F5?
M9&4G(#T^("<E<T!V;V1A9F]N92US;7,N9&4G+`H@("`@*3L*"B`@("`O*BH*
M("`@("`J($ED96YT:69I97,@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@1')I=F5R(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$EN9F\H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@
M("`@("`@("`@)VYA;64G(#T^(%\H(D5M86EL+71O+5--4R!'871E=V%Y(BDL
M"B`@("`@("`@("`@("=D97-C)R`]/B!?*")%36%I;"UT;RU335,@9V%T97=A
M>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R
M=FEC92XB*0H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(')E<75I<F5D('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("!R971U
M<FX@87)R87DH"B`@("`@("`@("`@("=C87)R:65R)R`@("`@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")#87)R:65R(BDL("=T>7!E)R`]/B`G=&5X="<I+`H@
M("`@("`@("`@("`G;6%I;$)A8VME;F0G(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B4$5!4CHZ36%I;"!B86-K96YD(BDL("=T>7!E)R`]/B`G=&5X="<I"B`@
M("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F1S('1H92!M97-S
M86=E+@H@("`@("H*("`@("`J(%EO=2!M87D@86QS;R!S<&5C:69Y('1H92!C
M87)R:65R('=I=&@@=&AE("=C87)R:65R)R!K97D@;V8@=&AE(&UE<W-A9V4*
M("`@("`J('1O(&%V;VED(&-R96%T:6YG(&$@;F5W(&EN<W1A;F-E(&9O<B!E
M86-H(&-A<G)I97(L(&]R(&9I9&1L:6YG('=I=&@@=&AE"B`@("`@*B!P87)A
M;65T97)S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@365S<V%G92!T;R!S96YD
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@("`@("!$97-T:6YA=&EO;B!P
M:&]N92!N=6UB97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@=VET:"!T:&4@<W5C8V5S<R!S=&%T=7,@86YD(&%D9&ET:6]N86P*
M("`@("`J("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5N9"@F)&UE<W-A9V4L("1T;RD*("`@('L*("`@("`@
M("`D<F5S<&]N<V4@/2!A<G)A>2@I.PH@("`@("`@("1D97-T96UA:6P@/2`D
M=&AI<RT^7V=E=$1E<W0H)'1O*3L*("`@("`@("!R97%U:7)E7V]N8V4@)TUA
M:6PN<&AP)SL*("`@("`@("`D;2`]($UA:6PZ.F9A8W1O<GDH)'1H:7,M/E]P
M87)A;7-;)VUA:6Q"86-K96YD)UTL("1T:&ES+3Y?<&%R86US6R=M86EL4&%R
M86US)UTI.PH*("`@("`@("!I9B`H:7-S970H)&UE<W-A9V5;)V-A<G)I97(G
M72DI('L*("`@("`@("`@("`@)&1E<W0@/2`D=&AI<RT^7V=E=$1E<W0H)'1O
M+"`D;65S<V%G95LG8V%R<FEE<B==*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D9&5S="`]("1T:&ES+3Y?9V5T1&5S="@D=&\I.PH@("`@("`@
M('T*"B`@("`@("`@)')E<R`])B`D;2T^<V5N9"@D9&5S="P@)'1H:7,M/E]P
M87)A;7-;)VUA:6Q(96%D97)S)UTL("1M97-S86=E6R=T97AT)UTI.PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@("1R
M97-P;VYS95LD=&]=(#T@87)R87DH,"P@)')E<RT^9V5T365S<V%G92@I*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S<&]N<V5;)'1O72`]
M(&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M97-P;VYS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&5S=&EN
M871I;VX@92UM86EL(&%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&AO;F4@(%!H;VYE(&YU;6)E<B!T;R!S96YD('1O+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!$97-T:6YA=&EO;B!A9&1R97-S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T1&5S="@D<&AO;F4L("1C87)R:65R
M(#T@;G5L;"D*("`@('L*("`@("`@("`D8V%R<FEE<B`](&ES7VYU;&PH)&-A
M<G)I97(I(#\@)'1H:7,M/E]P87)A;7-;)V-A<G)I97(G72`Z("1C87)R:65R
M.PH@("`@("`@(')E='5R;B!S<')I;G1F*"1T:&ES+3Y?8V%R<FEE<G-;)&-A
M<G)I97)=+`H@("`@("`@("`@("`@("`@("`@("`@('!R96=?<F5P;&%C92@G
M+UM>,"TY72\G+"`G)RP@)'!H;VYE*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!A9&1R97-S('1E;7!L871E(&9O<B!A(&-A<G)I97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%R<FEE<B`@0V%R<FEE
M<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($%D9')E<W,@
M=&5M<&QA=&4@;W(@9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%D
M9')E<W-496UP;&%T92@D8V%R<FEE<BD*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?8V%R<FEE<G-;)&-A<G)I97)=*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI
M<RT^7V-A<G)I97)S6R1C87)R:65R73L*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9',@82!C87)R:65R('1O('1H92!L:7-T+@H@("`@("H*("`@("`J($%D
M9')E<W,@=&5M<&QA=&5S(&YE960@=&\@8F4@:6X@=&AE(&9O<FT@;V8@86X@
M96UA:6P@861D<F5S<RP@=VET:"!A"B`@("`@*B`G)7,G(')E<')E<V5N=&EN
M9R!T:&4@<&QA8V4@=VAE<F4@=&AE(&1E<W1I;F%T:6]N('!H;VYE(&YU;6)E
M<B!G;V5S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($-A
M<G)I97(@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&%D9'(@($%D9')E
M<W,@=&5M<&QA=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-A<G)I97(H
M)&YA;64L("1A9&1R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V%R<FEE<G-;
M)&YA;65=(#T@)&%D9'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@;&ES="!O9B!P87)A;65T97)S('-P96-I9FEC(&9O<B!T:&ES(&1R:79E
M<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y($1E9F%U;'0@<V5N9&EN
M9R!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT
M4V5N9%!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O
M4TU3+W=I;E]H='1P+G!H<```````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C(S,3<`,3`U,34T,S$P-C$`,#(P-S$U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!.971?
M4TU37W=I;E]H='1P($-L87-S(&EM<&QE;65N=',@=&AE($A45%`@05!)(&9O
M<B!A8V-E<W-I;F<@=&AE(%=)3@H@*B`H=W=W+G=I;G!L8RYC;VTI(%--4R!G
M871E=V%Y+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`L=B`Q+CDN,BXR
M(#(P,#8O,#$O,#$@,C$Z,C@Z,CD@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@3F5T
M7U--4PH@*B\*8VQA<W,@3F5T7U--4U]W:6Y?:'1T<"!E>'1E;F1S($YE=%]3
M35,@>PH*("`@('9A<B`D7V)A<V5?=7)L(#T@)V=A=&5W87DS+F=O,FUO8FEL
M92YN970Z,3`P,S`O9V%T97=A>2]V,R]G871E=V%Y+F%S<'@G.PH*("`@("\J
M*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H
M92!D<FEV97(@8V%N(')E<&]R="!W:&EC:"!O<&5R871I;VYS"B`@("`@*B!I
M="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X@4&]S<VEB;&4@=F%L
M=65S(&%R93H\<')E/@H@("`@("H@("!A=71H("`@("`@("`M(%1H92!G871E
M=V%Y(')E<75I<F5S(&%U=&AE;G1I8V%T:6]N(&)E9F]R92!S96YD:6YG.PH@
M("`@("H@("!B871C:"`@("`@("`M($)A=&-H('-E;F1I;F<@:7,@<W5P<&]R
M=&5D.PH@("`@("H@("!M=6QT:2`@("`@("`M(%-E;F1I;F<@;V8@;65S<V%G
M97,@=&\@;75L=&EP;&4@<F5C:7!I96YT<R!I<R!S=7!P;W)T960["B`@("`@
M*B`@(')E8V5I=F4@("`@("T@5VAE=&AE<B!T:&ES(&1R:79E<B!I<R!C87!A
M8FQE(&]F(')E8V5I=FEN9R!335,["B`@("`@*B`@(&-R961I="`@("`@("T@
M27,@=7-E(&]F('1H92!G871E=V%Y(&)A<V5D(&]N(&-R961I=',["B`@("`@
M*B`@(&%D9')E<W-B;V]K("T@07)E(&=A=&5W87D@861D<F5S<V)O;VMS('-U
M<'!O<G1E9#L*("`@("`J("`@;&ES=',@("`@("`@+2!'871E=V%Y('-U<'!O
M<G0@9F]R(&1I<W1R:6)U=&EO;B!L:7-T<RX*("`@("`J(#PO<')E/@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL
M:71I97,@/2!A<G)A>2@G875T:"<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G8F%T8V@G("`@("`@(#T^(#$P,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUU;'1I)R`@("`@("`]
M/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5C96EV
M92<@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8W)E9&ET)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G861D<F5S<V)O;VLG(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;&ES=',G("`@("`@(#T^(&9A;'-E*3L*
M"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E<R!T:&4@86-T=6%L
M('-E;F1I;F<@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E
M("!4:&4@87)R87D@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!A;F0@:71S('-E
M;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@5&AE(&1E<W1I;F%T:6]N
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!W:71H('1H92!S=6-C97-S('-T871U<R!A;F0@861D:71I;VYA;`H@("`@
M("H@("`@("`@("`@("`@("`@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S96YD*"8D;65S<V%G92P@)'1O*0H@("`@>PH@("`@("`@("\J
M(%-T87)T('1H92!834PN("HO"B`@("`@("`@)'AM;"`]("<\4TU334534T%'
M13X\5$585#XG("X@)&UE<W-A9V5;)W1E>'0G72`N("<\+U1%6%0^)SL*"B`@
M("`@("`@+RH@0VAE8VL@:68@<V]U<F-E(&9R;VT@:7,@<V5T+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;)V9R;VTG
M72DI('L*("`@("`@("`@("`@)'AM;"`N/2`G/%-/55)#15]!1$12/B<@+B`D
M;65S<V%G95LG<V5N9%]P87)A;7,G75LG9G)O;2==("X@)SPO4T]54D-%7T%$
M1%(^)SL*("`@("`@("!]"@H@("`@("`@("\J($QO;W`@=&AR;W5G:"!R96-I
M<&EE;G1S(&%N9"!D;R!S;VUE(&UI;FEM86P@=F%L:61I='D@8VAE8VMI;F<N
M("HO"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T;RDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)'1O(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>+BH_/#\H7"L_7&1[-RQ]*2@^?"0I+R<L
M("1V86PL("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("1T;ULD
M:V5Y72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`O*B!)9B!A(')E8VEP:65N="!I<R!I;G9A
M;&ED('-T;W`@86QL(&9U<G1H97(@<V5N9&EN9RX@*B\*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@87)R87DH,"P@<W!R:6YT9BA?*"));G9A;&ED(')E
M8VEP:65N=#H@7"(E<UPB(BDL("1V86PI*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1O(#T@:6UP;&]D92@G/"]$
M15-424Y!5$E/3E]!1$12/CQ$15-424Y!5$E/3E]!1$12/B<L("1T;RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>
M+BH_/#\H7"L_7&1[-RQ]*2@^?"0I+R<L("1T;RP@)&UA=&-H97,I*2!["B`@
M("`@("`@("`@("`@("`D=&\@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@P+"!S<')I
M;G1F*%\H(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B*2P@)'1O*2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'AM;"`N/2`G/$1%4U1)
M3D%424].7T%$1%(^)R`N("1T;R`N("<\+T1%4U1)3D%424].7T%$1%(^)SL*
M"B`@("`@("`@+RH@5$]$3SH@4VAO=6QD('=E(&AA=F4@<V]M971H:6YG(&UO
M<F4@:6YT96QL:6=E;G0_($-O=6QD(&%C='5A;&QY"B`@("`@("`@("H@8F4@
M<&%R="!O9B!S96YD('!A<F%M971E<G,N("HO"B`@("`@("`@)'AM;"`N/2`G
M/%1204Y304-424].240^)R`N('1I;64H*2`N("<\+U1204Y304-424].240^
M)SL*"B`@("`@("`@+RH@5$]$3SH@061D('-O;64@97AT<F$@=&%G<RP@:G5S
M="!T86-K960@;VX@9F]R(&YO=RX@*B\*("`@("`@("`D>&UL("X]("<\5%E0
M14E$/C(\+U194$5)1#X\4T525DE#14E$/C$\+U-%4E9)0T5)1#X\+U--4TU%
M4U-!1T4^)SL*"B`@("`@("`@+RH@4V5N9"!T:&ES(&UE<W-A9V4N("HO"B`@
M("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]P;W-T*"1X;6PI.PH@("`@("`@
M(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH,"P@)')E<W!O;G-E+3YG971-97-S86=E*"DI
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E+"!C
M:&5C:R!F;W(@;F5W(&QI;F5S(&EN(&-A<V4@;V8@;75L=&EP;&4*("`@("`@
M("`@*B!R96-I<&EE;G1S+B`J+PH@("`@("`@("1L:6YE<R`](&5X<&QO9&4H
M(EQN(BP@)')E<W!O;G-E*3L*("`@("`@("`D<F5S<&]N<V4@/2!A<G)A>2@I
M.PH*("`@("`@("!I9B`H8V]U;G0H)&QI;F5S*2`^(#$I('L*("`@("`@("`@
M("`@+RH@375L=&EP;&4@<F5C:7!I96YT<RX@*B\*("`@("`@("`@("`@9F]R
M96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`D<&%R
M=',@/2!E>'!L;V1E*"=4;SHG+"`D;&EN92D["B`@("`@("`@("`@("`@("`D
M<F5C:7!I96YT(#T@=')I;2@D<&%R='-;,5TI.PH@("`@("`@("`@("`@("`@
M:68@*"1L:6YE<ULP72`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E<W!O;G-E6R1R96-I<&EE;G1=(#T@87)R87DH,2P@;G5L;"D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1R97-P;VYS95LD<F5C:7!I96YT72`](&%R<F%Y*#`L("1L:6YE<ULP72D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O*B!3:6YG;&4@<F5C:7!I96YT+B`J+PH@("`@
M("`@("`@("!I9B`H)&QI;F5S6S!=(#T]("=!45--4RU/2R<I('L*("`@("`@
M("`@("`@("`@("1R97-P;VYS95LD=&]=(#T@87)R87DH,2P@;G5L;"D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V5;
M)'1O72`](&%R<F%Y*#`L("1L:6YE<ULP72D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!)9&5N=&EF:65S('1H:7,@9V%T97=A>2!D<FEV97(@86YD
M(')E='5R;G,@82!B<FEE9B!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!D<FEV97(@:6YF;RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T26YF;R@I"B`@("!["B`@("`@("`@)&EN9F];)VYA
M;64G72`](%\H(E=)3B!V:6$@2%144"(I.PH@("`@("`@("1I;F9O6R=D97-C
M)UT@/2!?*")4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB*3L*"B`@("`@("`@<F5T=7)N("1I;F9O
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F5Q=6ER960@
M<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&1R:79E<BX@5&AE('-E='1A
M8FQE"B`@("`@*B!P87)A;65T97)S(&9O<B!T:&ES(&=A=&5W87D@87)E.@H@
M("`@("H@("`M('5S97(@("`@("`@("`@("`M(%1H92!U<V5R;F%M92!F;W(@
M875T:&5N=&EC871I;VX@;VX@=&AE(&=A=&5W87D["B`@("`@*B`@("T@<&%S
M<W=O<F0@("`@("`@("T@5&AE('!A<W-W;W)D(&9O<B!A=71H96YT:6-A=&EO
M;B!O;B!T:&4@9V%T97=A>3L*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T97)S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971087)A;7,H*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@I.PH@("`@("`@("1P87)A;7-;)W5S97(G72`@("`@/2!A<G)A>2@G
M;&%B96PG(#T^(%\H(E5S97)N86UE(BDL("=T>7!E)R`]/B`G=&5X="<I.PH@
M("`@("`@("1P87)A;7-;)W!A<W-W;W)D)UT@/2!A<G)A>2@G;&%B96PG(#T^
M(%\H(E!A<W-W;W)D(BDL("=T>7!E)R`]/B`G=&5X="<I.PH*("`@("`@("!R
M971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('!A<F%M971E<G,@=&AA="!C86X@8F4@<V5T(&%S(&1E9F%U;'0@9F]R
M('-E;F1I;F<@;65S<V%G97,*("`@("`J('5S:6YG('1H:7,@9V%T97=A>2!D
M<FEV97(@86YD(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<&%R86UE=&5R
M<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1&5F875L=%-E;F1087)A;7,H*0H@("`@>PH@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P87)A;7-;)V9R;VTG72`](&%R
M<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S
M(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I.PH*("`@("`@("`D
M<&%R86US6R=C;W-T7VED)UT@/2!A<G)A>2@*("`@("`@("`@("`@)VQA8F5L
M)R`]/B!?*")#;W-T($E$(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G:6YT
M)RD["@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!F;W(@<V5N9&EN9R!M97-S
M86=E<R!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R+`H@("`@("H@9&ES<&QA
M>65D('=H96X@<V5N9&EN9R!M97-S86=E<RX@5&AE<V4@87)E(&9I;'1E<F5D
M(&]U="!U<VEN9R!T:&4*("`@("`J(&1E9F%U;'0@=F%L=65S('-E="!U<"!W
M:&5N(&-R96%T:6YG('1H92!G871E=V%Y+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%R<F%Y(&]F(')E<75I<F5D('!A<F%M971E<G,N"B`@("`@
M*B!`=&]D;R`@5V]U;&0@8F4@;FEC92!T;R!U<V4@82!T:6UE+V1A=&4@<V5T
M=7`@<F%T:&5R('1H86X@;6EN=71E<R!F<F]M"B`@("`@*B`@("`@("`@;F]W
M(&9O<B!T:&4@9&5L:79E<GD@=&EM92X@57!L;V%D(&9I96QD(&9O<B!R:6YG
M=&]N97,O;&]G;W,_"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E;F1087)A
M;7,H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG
M9G)O;2==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=F<F]M)UT@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("=L86)E;"<@/3X@7R@B4V]U<F-E(&%D9')E
M<W,B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)V-O<W1?:60G72DI
M('L*("`@("`@("`@("`@)'!A<F%M<ULG9&5L:79?=&EM92==(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(D-O<W0@240B*2P*("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G:6YT)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@86X@97)R;W(@8V]D
M92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D97)R;W(@(%1H92!E
M<G)O<B!C;V1E('1O(&QO;VL@=7`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("`@($%N(&5X:7-T:6YG(&5R<F]R('1E>'0@=&\@=7-E('1O(')A:7-E
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@4$5!4B!%<G)O<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!('1E>'1U86P@;65S<V%G
M92!C;W)R97-P;VYD:6YG('1O('1H92!E<G)O<B!C;V1E(&]R(&$*("`@("`J
M("`@("`@("`@("`@("`@(%!%05(@17)R;W(@:68@<&%S<V5D(&%N(&5X:7-T
M:6YG(&5R<F]R('1E>'0N"B`@("`@*@H@("`@("H@0'1O9&\@($-H96-K('=H
M:6-H(&]F('1H97-E(&%R92!A8W1U86QL>2!R97%U:7)E9"!A;F0@=')I;2!D
M;W=N('1H90H@("`@("H@("`@("`@(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$5R<F]R*"1E<G)O<BP@)&5R<F]R7W1E>'0@/2`G)RD*("`@('L*
M("`@("`@("`D97)R;W(@/2!T<FEM*"1E<G)O<BD["@H@("`@("`@("\J($%N
M(&%R<F%Y(&]F(&5R<F]R(&-O9&5S(')E='5R;F5D(&)Y('1H92!G871E=V%Y
M+B`J+PH@("`@("`@("1E<G)O<G,@/2!A<G)A>2@*("`@("`@("`@("`@)T%1
M4TU3+4Y/05542$1%5$%)3%,G("`@("`@("`]/B!?*").;R!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0@<V5N="XB*2P*("`@("`@("`@("`@)T%14TU3+41)
M4U1,25-455!$051%15)23U(G("`]/B!?*")4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(I*3L*"B`@("`@("`@:68@*&5M<'1Y*"1E<G)O<E]T97AT
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R<ULD97)R;W)=.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H)&5R<F]R7W1E>'0L("1E<G)O<G-;)&5R<F]R72DI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1O('1H92!H='1P(&-A
M;&P@=7-I;F<@82!U<FP@<&%S<V5D('1O('1H92!F=6YC=&EO;BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1X;6P@(%1H92!834P@:6YF;W)M871I;VX@<&%S<V5D('1O('1H
M92!G871E=V%Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R
M97-P;VYS92!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W!O<W0H)'AM;"D*("`@('L*("`@("`@
M("`D;W!T:6]N<ULG;65T:&]D)UT@/2`G4$]35"<["B`@("`@("`@)&]P=&EO
M;G-;)W1I;65O=70G72`](#4["B`@("`@("`@)&]P=&EO;G-;)V%L;&]W4F5D
M:7)E8W1S)UT@/2!T<G5E.PH*("`@("`@("`O*B!7<F%P('1H92!X;6P@=VET
M:"!T:&4@<W1A;F1A<F0@=&%G<RX@*B\*("`@("`@("`D>&UL(#T@)SP_>&UL
M('9E<G-I;VX](C$N,"(@<W1A;F1A;&]N93TB;F\B/SX\(41/0U194$4@5TE.
M7T1%3$E615)97S)?4TU3(%-94U1%32`B=VEN8F]U;F1?;65S<V%G97-?=C$N
M9'1D(CX\5TE.7T1%3$E615)97S)?4TU3/B<@+B`D>&UL("X@)SPO5TE.7T1%
M3$E615)97S)?4TU3/B<["@H@("`@("`@(&EF("@A0&EN8VQU9&5?;VYC92`G
M2%144"]297%U97-T+G!H<"<I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+B(I*3L*("`@("`@("!]"B`@("`@("`@)&AT='`@/2`F;F5W($A45%!?
M4F5Q=65S="@D=&AI<RT^7V)A<V5?=7)L+"`D;W!T:6]N<RD["@H@("`@("`@
M("\J($%D9"!T:&4@875T:&5N=&EC871I;VX@=F%L=65S('1O(%!/4U0N("HO
M"B`@("`@("`@)&AT='`M/F%D9%!O<W1$871A*"=5<V5R)RP@)'1H:7,M/E]P
M87)A;7-;)W5S97(G72D["B`@("`@("`@)&AT='`M/F%D9%!O<W1$871A*"=0
M87-S=V]R9"<L("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*3L*"B`@("`@
M("`@+RH@061D('1H92!834P@86YD('-E;F0@=&AE(')E<75E<W0N("HO"B`@
M("`@("`@)&AT='`M/F%D9%!O<W1$871A*"=724Y?6$U,)RP@)'AM;"D["B`@
M("`@("`@0"1H='1P+3YS96YD4F5Q=65S="@I.PH@("`@("`@(&EF("@D:'1T
M<"T^9V5T4F5S<&]N<V5#;V1E*"D@(3T@,C`P*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P
M96X@)7,N(BDL("1T:&ES+3Y?8F%S95]U<FPI*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q
M,#8Q`#`Q-C0U-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U3
M4"]!=71H+P``````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-C$`,#$W,S4U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TYE="])35-0+T%U=&@O:6UT97-T+G!H<```````````````
M```````````````````````````````````````````````P,3`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C8R-0`Q,#4Q-30S,3`V,0`P,C$T,#0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!.971?24U34%]!=71H7VEM=&5S="!C;&%S<R!F;W(@
M24U34"!A=71H96YT:6-A=&EO;BX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=U<V5R;F%M92<@("`@("`@(%5S97)N86UE('1O(&QO
M9V]N('1O($E-4U`@<V5R=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@("`@("`@
M(%!A<W-W;W)D(&9O<B!C=7)R96YT('5S97(N"B`J("`@)W-E<G9E<B<@("`@
M("`@("`@5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G
M<&]R="<@("`@("`@("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N
M"B`J("`@)W-O8VME="<@("`@("`@("`@5&AE(&YA;65D('-O8VME="!T;R!U
M<V4@9F]R(&-O;FYE8W1I;VX*("H@("`G8V]M;6%N9"<@("`@("`@("!0871H
M('1O('1H92!I;71E<W0@8V]M;6%N9"!O;B!L;V-A;&AO<W0*("H@("`G875T
M:%]M96-H86YI<VTG("!!=71H96YT:6-A=&EO;B!M971H;V0@=&\@=7-E('=I
M=&@@:6UT97-T/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O075T:"]I;71E<W0N<&AP+'8@,2XQ,BXR+C0@,C`P-B\P,2\P
M,2`R,3HR.#HR."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P
M-B`@("`@($QI86T@2&]E:V5N9V$@/&QI86UR0'5M:6-H+F5D=3X*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!,:6%M($AO
M96ME;F=A(#QL:6%M<D!U;6EC:"YE9'4^"B`J($!A=71H;W(@($UI8VAA96P@
M4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@3F5T
M7TE-4U`*("HO"F-L87-S($YE=%])35-07T%U=&A?:6UT97-T(&5X=&5N9',@
M3F5T7TE-4U!?075T:"!["@H@("`@+RHJ"B`@("`@*B!0<FEV871E(&%U=&AE
M;G1I8V%T:6]N(&9U;F-T:6]N+B`@4')O=FED97,@86-T=6%L"B`@("`@*B!A
M=71H96YT:6-A=&EO;B!C;V1E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H@0'!A<F%M("!M:7AE9"`@)'!A<F%M<R!(87-H(&]F($E-
M4U`@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!.
M971?24U34"!O8FIE8W0@8V]N;F5C=&5D('1O('-E<G9E<B!I9B!S=6-C97-S
M9G5L+`H@("`@("H@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7V%U=&AE;G1I8V%T92@D<&%R
M86US*0H@("`@>PH@("`@("`@("1I;7-P(#T@)DYE=%])35-0.CIS:6YG;&5T
M;VXH)VYO;F4G+"`D<&%R86US*3L*("`@("`@("`D8V]M;6%N9"`]("<G.PH@
M("`@("`@("1E<G)O<E]R971U<FX@/2`G)SL*"B`@("`@("`@:68@*'-T<G1O
M;&]W97(H)'!A<F%M<ULG875T:%]M96-H86YI<VTG72D@/3T@)V=S<V%P:2<@
M)B8*("`@("`@("`@("`@:7-S970H)%]315)615);)TM20C5#0TY!344G72DI
M('L*("`@("`@("`@("`@("`@("1C;VUM86YD("X]("=+4D(U0T-.04U%/2<@
M+B`D7U-%4E9%4ELG2U)"-4-#3D%-12==.PH@("`@("`@('T*"B`@("`@("`@
M)&-O;6UA;F0@+CT@)R`G("`@("X@)'!A<F%M<ULG8V]M;6%N9"==+@H@("`@
M("`@("`@("`@("`@("`@("<@+6T@)R`N("1P87)A;7-;)V%U=&A?;65C:&%N
M:7-M)UT@+@H@("`@("`@("`@("`@("`@("`@("<@+74@)R`N(&5S8V%P97-H
M96QL87)G*"1P87)A;7-;)W5S97)N86UE)UTI("X*("`@("`@("`@("`@("`@
M("`@("`G("UA("<@+B!E<V-A<&5S:&5L;&%R9R@D<&%R86US6R=U<V5R;F%M
M92==*2`N"B`@("`@("`@("`@("`@("`@("`@)R`M=R`G("X@97-C87!E<VAE
M;&QA<F<H)'!A<F%M<ULG<&%S<W=O<F0G72DN"B`@("`@("`@("`@("`@("`@
M("`@)R`M<"`G("X@)'!A<F%M<ULG<&]R="==("X*("`@("`@("`@("`@("`@
M("`@("`G("U8("<@+B`D<&%R86US6R=S;V-K970G72`N"B`@("`@("`@("`@
M("`@("`@("`@)R`G("`@("X@)'!A<F%M<ULG<V5R=F5R)UT["@H@("`@("`@
M("1C;VYN7V%T=&5M<'1S(#T@,#L*("`@("`@("!W:&EL92`H)&-O;FY?871T
M96UP=',K*R`\(#0I('L*("`@("`@("`@("`@)&%T=&5M<'1S(#T@,#L*("`@
M("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D<&%R86US6R=S;V-K970G72DI
M('L*("`@("`@("`@("`@("`@(&5X96,H)&-O;6UA;F0@+B`G(#X@+V1E=B]N
M=6QL(#(^)C$G*3L*("`@("`@("`@("`@("`@('-L965P*#$I.PH@("`@("`@
M("`@("`@("`@=VAI;&4@*"%F:6QE7V5X:7-T<R@D<&%R86US6R=S;V-K970G
M72DI('L*("`@("`@("`@("`@("`@("`@("!U<VQE97`H,C`P,#`P*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&%T=&5M<'1S*RL@/B`U*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1E<G)O<E]R971U<FX@/2`G.B!.;R!S;V-K
M970@869T97(@,3`@<V5C;VYD<R!O9B!T<GEI;F<A)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&9P(#T@0&9S;V-K;W!E;B@D<&%R86US6R=S;V-K970G72P@,"P@)&5R<F]R
M7VYU;6)E<BP@)&5R<F]R7W-T<FEN9RP@,S`I.PH@("`@("`@("`@("`D97)R
M;W)?<F5T=7)N(#T@)&5R<F]R7W-T<FEN9SL*("`@("`@("`@("`@:68@*"1F
M<"D@8G)E86L["B`@("`@("`@("`@('5N;&EN:R@D<&%R86US6R=S;V-K970G
M72D["@H@("`@("`@('T*("`@("`@("`O+T9A:6QU<F4_"B`@("`@("`@:68@
M*"%E;7!T>2@D97)R;W)?<F5T=7)N*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&EM<W`M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T;R!)35-0(&AO<W0@9F%I
M;&5D+B<@+B`G.B`G("X@)&5R<F]R7W)E='5R;BP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"B`@("`@("`@+R]3=6-C97-S"B`@("`@("`@)&EM
M<W`M/E]S=')E86T@/2`D9G`["B`@("`@("`@<F5T=7)N("1I;7-P.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1F]R8V4@82!L;V=O=70@8V]M;6%N9"!T;R!T
M:&4@:6US<"!S=')E86TN"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M;V=O=70H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6US<"T^;&]G;W5T*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D<FEV97(@='EP
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1Y<&4@;V8@
M=&AI<R!)35-07T%U=&@@9')I=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971$<FEV97)4>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)VEM=&5S="<[
M"B`@("!]"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B].970O24U34"]!=71H+V-R86U?;60U+G!H<```````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<R,#(`,3`U,34T,S$P-C$`,#(Q-34S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@3F5T7TE-4U!?075T:%]C<F%M7VUD-2!C;&%S<R!F
M;W(@24U34"!A=71H96YT:6-A=&EO;BX*("H*("H@4F5Q=6ER960@<&%R86UE
M=&5R<SH\<')E/@H@*B`@("=U<V5R;F%M92<@(%5S97)N86UE('1O(&QO9V]N
M('1O($E-4U`@<V5R=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@(%!A<W-W;W)D
M(&9O<B!C=7)R96YT('5S97(N"B`J("`@)W-E<G9E<B<@("`@5&AE(&AO<W1N
M86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G<&]R="<@("`@("!4:&4@
M<&]R="!O9B!T:&4@24U34"!S97)V97(N/"]P<F4^"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"]C<F%M7VUD-2YP:'`L=B`Q
M+C8N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(X(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA
M96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@
M3F5T7TE-4U`*("HO"F-L87-S($YE=%])35-07T%U=&A?8W)A;5]M9#4@97AT
M96YD<R!.971?24U34%]!=71H('L*"B`@("`O*BH*("`@("`J(%!R:79A=&4@
M875T:&5N=&EC871I;VX@9G5N8W1I;VXN("!0<F]V:61E<R!A8W1U86P*("`@
M("`J(&%U=&AE;G1I8V%T:6]N(&-O9&4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&UI>&5D("1P87)A;7,@2&%S:"!O
M9B!)35-0('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!.971?24U34"!O8FIE8W0@8V]N;F5C=&5D('1O('-E<G9E<B!I9B!S=6-C
M97-S9G5L+`H@("`@("H@("`@("`@("`@("`@("!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?875T:&5N=&EC871E*"1P
M87)A;7,I"B`@("!["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L
M971O;B@G;F]N92<L("1P87)A;7,I.PH@("`@("`@("1R97-U;'0@/2`D:6US
M<"T^:6YI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`D=7-E<DED(#T@)'!A<F%M<ULG=7-E<FYA;64G73L*("`@
M("`@("`D8W)E9&5N=&EA;',@/2`D<&%R86US6R=P87-S=V]R9"==.PH@("`@
M("`@("1R97-U;'0@/2`D:6US<"T^:6US<%-E;F0H)T%55$A%3E1)0T%412!#
M4D%-+4U$-2<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`O*B!'970@<F5S<&]N<V4@86YD(&1E8V]D92!I="X@3F]T
M92!T:&%T('=E(')E;6]V92!T:&4@,7-T(#(*("`@("`@("`@*B!C:&%R86-T
M97)S(&9R;VT@=&AE(')E<W!O;G-E('1O(&=E="!R:60@;V8@=&AE("<K)PH@
M("`@("`@("`J(&-O;G1I;G5A=&EO;B!C:&%R86-T97(@86YD('1H92!S<&%C
M92!T:&%T(&ES('-E;G0@87,@<&%R=`H@("`@("`@("`J(&]F('1H92!#4D%-
M+4U$-2!R97-P;VYS92`H870@;&5A<W0@;VX@8WER=7,M:6US<&0I+B`J+PH@
M("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D:6US<"T^:6US<%)E8V5I=F4H
M*3L*("`@("`@("!I9B`H:7-?82@D<V5R=F5R7W)E<W!O;G-E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<V5R=F5R7W)E<W!O;G-E
M.PH@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`](&)A<V4V
M-%]D96-O9&4H=')I;2AS=6)S='(H)'-E<G9E<E]R97-P;VYS92P@,BDI*3L*
M"B`@("`@("`@+RH@0G5I;&0@86YD(&)A<V4V-"!E;F-O9&4@=&AE(')E<W!O
M;G-E('1O('1H92!C:&%L;&%N9V4N("HO"B`@("`@("`@)')E<W!O;G-E7W1O
M7W-E;F0@/2`D=7-E<DED("X@)R`G("X@)'1H:7,M/E]H;6%C*"1C<F5D96YT
M:6%L<RP@)'-E<G9E<E]R97-P;VYS92D["B`@("`@("`@)&-O;6UA;F1?<W1R
M:6YG(#T@8F%S938T7V5N8V]D92@D<F5S<&]N<V5?=&]?<V5N9"D["@H@("`@
M("`@("\J(%-E;F0@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1R97-U;'0@
M/2`D:6US<"T^:6US<%-E;F0H)&-O;6UA;F1?<W1R:6YG+"!F86QS92D["B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R97-U;'0@(3T@
M)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)&EM<W`M/FEM<W!%<G)O<B@G
M3&]G:6X@=&\@24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D:6US
M<#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!21D,@,C$P-"!(
M34%#(&EM<&QE;65N=&%T:6]N+B!%;&EM:6YA=&5S('1H92!R96QI86YC92!O
M;B!M:&%S:"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M($!P87)A;2`@<W1R:6YG("`D:V5Y("`@(%1H92!(34%#(&ME>2X*("`@("`J
M($!P87)A;2`@<W1R:6YG("`D9&%T82`@(%1H92!D871A('1O(&AA<V@@=VET
M:"!T:&4@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M340U($A-04,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H;6%C*"1K97DL("1D
M871A*0H@("`@>PH@("`@("`@("\J($)Y=&4@;&5N9W1H(&9O<B!M9#4N("HO
M"B`@("`@("`@)&(@/2`V-#L*"B`@("`@("`@:68@*'-T<FQE;B@D:V5Y*2`^
M("1B*2!["B`@("`@("`@("`@("1K97D@/2!P86-K*"=(*B<L(&UD-2@D:V5Y
M*2D["B`@("`@("`@?0H*("`@("`@("`D:V5Y(#T@<W1R7W!A9"@D:V5Y+"`D
M8BP@8VAR*#!X,#`I*3L*("`@("`@("`D:7!A9"`]('-T<E]P860H)R<L("1B
M+"!C:'(H,'@S-BDI.PH@("`@("`@("1O<&%D(#T@<W1R7W!A9"@G)RP@)&(L
M(&-H<B@P>#5C*2D["B`@("`@("`@)&M?:7!A9"`]("1K97D@7B`D:7!A9#L*
M("`@("`@("`D:U]O<&%D(#T@)&ME>2!>("1O<&%D.PH@("`@("`@(')E='5R
M;B!M9#4H)&M?;W!A9"`N('!A8VLH)T@J)RP@;60U*"1K7VEP860@+B`D9&%T
M82DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($9O<F-E(&$@;&]G;W5T(&-O
M;6UA;F0@=&\@=&AE(&EM<W`@<W1R96%M+@H@("`@("H*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*("`@("`@("`D=&AI<RT^7VEM<W`M
M/FQO9V]U="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D
M<FEV97(@='EP90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG('1H92!T
M>7!E(&]F('1H:7,@24U34%]!=71H(&1R:79E<@H@("`@("HO"B`@("`@9G5N
M8W1I;VX@9V5T1')I=F5R5'EP92@I"B`@("`@>PH@("`@("`@("!R971U<FX@
M)V-R86U?;60U)SL*("`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H+W!L
M86EN=&5X="YP:'``````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<T,C$`
M,3`U,34T,S$P-C$`,#(R,#<W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@3F5T7TE-4U!?075T
M:%]P;&%I;G1E>'0@8VQA<W,@9F]R($E-4U`@875T:&5N=&EC871I;VXN"B`J
M"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G=7-E<FYA;64G
M("!5<V5R;F%M92!T;R!L;V=O;B!T;R!)35-0('-E<G9E<B!A<RX*("H@("`G
M<&%S<W=O<F0G("!087-S=V]R9"!F;W(@8W5R<F5N="!U<V5R+@H@*B`@("=S
M97)V97(G("`@(%1H92!H;W-T;F%M92!O9B!T:&4@24U34"!S97)V97(N"B`J
M("`@)W!O<G0G("`@("`@5&AE('!O<G0@;V8@=&AE($E-4U`@<V5R=F5R+CPO
M<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])35-0+T%U
M=&@O<&QA:6YT97AT+G!H<"QV(#$N-RXQ,"XQ,2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA
M96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO
M<F1E+F]R9SX*("H@0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE=%])
M35-07T%U=&A?<&QA:6YT97AT(&5X=&5N9',@3F5T7TE-4U!?075T:"!["@H@
M("`@+RHJ"B`@("`@*B!0<FEV871E(&%U=&AE;G1I8V%T:6]N(&9U;F-T:6]N
M+B`@4')O=FED97,@86-T=6%L"B`@("`@*B!A=71H96YT:6-A=&EO;B!C;V1E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M
M("!M:7AE9"`@)'!A<F%M<R!(87-H(&]F($E-4U`@<&%R86UE=&5R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!.971?24U34"!O8FIE8W0@8V]N
M;F5C=&5D('1O('-E<G9E<B!I9B!S=6-C97-S9G5L+`H@("`@("H@("`@("`@
M("`@("`@("`@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F7V%U=&AE;G1I8V%T92@D<&%R86US*0H@("`@>PH@("`@("`@
M("1I;7-P(#T@)DYE=%])35-0.CIS:6YG;&5T;VXH)VYO;F4G+"`D<&%R86US
M*3L*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/FEN:70H*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@("1U<V5R260@
M/2`D<&%R86US6R=U<V5R;F%M92==.PH@("`@("`@("`D8W)E9&5N=&EA;',@
M/2`D<&%R86US6R=P87-S=V]R9"==.PH*("`@("`@("`O*B!3=&%R="!T:&4@
M8V]M;6%N9"X@*B\*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/FEM<W!396YD
M*"=,3T=)3B`G+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J(%5S97)N86UE(&%S(&$@>WT_
M("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%
M4D%,+"`D=7-E<DED*2D@>PH@("`@("`@("`@("`D8FE5<V5R(#T@<W!R:6YT
M9B@G>R5D?2<L('-T<FQE;B@D=7-E<DED*2D["B`@("`@("`@("`@("1R97-U
M;'0@/2`D:6US<"T^:6US<%-E;F0H)&)I57-E<BP@9F%L<V4L('1R=64I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6US<"T^:6US<%)E8V5I=F4H*2DI
M('L*"B`@("`@("`@("`@("`@("!R971U<FX@)&EM<W`M/FEM<W!%<G)O<B@G
M1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N
M(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D
M:6US<"T^:6US<%-E;F0H)'5S97))9"`N("<@)RP@9F%L<V4L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M+RH@1&]N)W0@=V%N="!T;R!L;V<@=&AE('!A<W-W;W)D(2`J+PH@("`@("`@
M("1L;V=686QU92`]("1I;7-P+3YL;V=%;F%B;&5D.PH@("`@("`@("1I;7-P
M+3YL;V=%;F%B;&5D(#T@9F%L<V4["@H@("`@("`@("\J(%!A<W,@87,@>WT_
M("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%
M4D%,+"`D8W)E9&5N=&EA;',I*2!["B`@("`@("`@("`@("1B:5!A<W,@/2!S
M<')I;G1F*"=[)61])RP@<W1R;&5N*"1C<F5D96YT:6%L<RDI.PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)&EM<W`M/FEM<W!396YD*"1B:5!A<W,L(&9A;'-E
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<
M*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EM<W`M/FEM<W!2
M96-E:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&EM<W`M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N
M=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D:6US<"T^:6US<%-E;F0H)&-R961E;G1I86QS+"!F86QS92P@
M=')U92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E<W1O<F4@=&AE(&QO9V=I;F<@8F]O;&5A;BX@*B\*("`@
M("`@("`D:6US<"T^;&]G16YA8FQE9"`]("1L;V=686QU93L*"B`@("`@("`@
M)'-E<G9E<E]R97-P;VYS92`]("1I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@
M("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'-E<G9E<E]R97-P;VYS92`A/2`G3TLG*2![
M"B`@("`@("`@("`@(')E='5R;B`D:6US<"T^:6US<$5R<F]R*"=,;V=I;B!T
M;R!)35-0(&AO<W0@9F%I;&5D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&EM<W`["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&;W)C92!A(&QO9V]U="!C;VUM86YD('1O('1H92!I;7-P('-T
M<F5A;2X*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9V]U="@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I;7-P+3YL;V=O=70H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@9')I=F5R('1Y<&4*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@='EP92!O9B!T:&ES($E-4U!?075T
M:"!D<FEV97(*("`@("`J+PH@("`@(&9U;F-T:6]N(&=E=$1R:79E<E1Y<&4H
M*0H@("`@('L*("`@("`@("`@<F5T=7)N("=P;&%I;G1E>'0G.PH@("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B].970O24U34"]";V]K+G!H<```````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`Q-3(P,S4`,3`U,34T,S$P-C$`,#(P,#8R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TYE="])35-0+T%U=&@N<&AP)SL*"B\J*@H@*B!3=')I;F<@
M;V8@<W5P<&]R=&5D($%#3"!R:6=H=',N"B`J+PID969I;F4H)TE-4U!?04-,
M7U))1TA44R<L("=L<G=C9&$G*3L*"B\J*@H@*B!.971?24U34%]";V]K($-L
M87-S("T@<')O=FED97,@87!I(&9O<B!D96%L:6YG('=I=&@@24U34`H@*B!A
M9&1R97-S(&)O;VMS+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^
M"B`J("`@)W5S97)N86UE)R`@("`@57-E<FYA;64@=&\@;&]G;VX@=&\@24U3
M4"!S97)V97(@87,N"B`J("`@)W!A<W-W;W)D)R`@("`@4&%S<W=O<F0@9F]R
M(&-U<G)E;G0@=7-E<BX*("H@("`G875T:%]M971H;V0G("!4:&4@875T:&5N
M=&EC871I;VX@;65T:&]D('1O('5S92!T;R!L;V=I;BX*("H@("`G<V5R=F5R
M)R`@("`@("!4:&4@:&]S=&YA;64@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@
M("=P;W)T)R`@("`@("`@(%1H92!P;W)T(&]F('1H92!)35-0('-E<G9E<BX\
M+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]"
M;V]K+G!H<"QV(#$N,38N,BXR,B`R,#`V+S`Q+S`Q(#(Q.C(X.C(X(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4G5B:6YS
M:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*
M("H@0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE=%])35-07T)O;VL@
M>PH*("`@("\J*@H@("`@("H@4V]R="!O<F1E<BX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'-O<G0@/2`G87-C96YD)SL*
M"B`@("`O*BH*("`@("`J($YE=%])35-0(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`=F%R($YE=%])35-0"B`@("`@*B\*("`@('9A<B`D7VEM<W`["@H@("`@
M+RHJ"B`@("`@*B!087)A;65T97(@;&ES="X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<SL*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US($AA<V@@8V]N=&%I;FEN9R!)35-0('!A<F%M971E
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%])35-07T)O;VLH)'!A<F%M
M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L:7IA=&EO;B!F=6YC=&EO;B!T
M;R!B92!C86QL960@869T97(@;V)J96-T(&ES(')E='5R;F5D+@H@("`@("H@
M5&AI<R!A;&QO=W,@97)R;W)S('1O(&]C8W5R(&%N9"!N;W0@8G)E86L@=&AE
M('-C<FEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I;FET*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?:6US<"DI('L*("`@("`@("`@("`@)&%U=&@@/2`F3F5T7TE-4U!?075T
M:#HZ<VEN9VQE=&]N*"1T:&ES+3Y?<&%R86US6R=A=71H7VUE=&AO9"==*3L*
M("`@("`@("`@("`@)'1H:7,M/E]I;7-P(#T@)&%U=&@M/F%U=&AE;G1I8V%T
M92@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M82@D=&AI<RT^7VEM<W`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/E]I;7-P+3YW<FET951O3&]G*"=.971?24U34%]";V]K(&EN:71I86QI>F5D
M+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@
M8V]N=&%I;FEN9R!T:&4@;F%M97,@;V8@86QL('1H92!A9&1R97-S(&)O;VMS
M"B`@("`@*B!A=F%I;&%B;&4@=&\@=&AE(&QO9V=E9"!I;B!U<V5R+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@07)R87D@;V8@861D<F5S<R!B;V]K
M(&YA;65S(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$%D9')E<W-";V]K3&ES="@I"B`@("!["B`@("`@("`@)&-O;6UA;F1?<W1R
M:6YG(#T@)T%$1%)%4U-"3T]+("HG.PH*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]S=')I;F<I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T
M;R!)35-0(&AO<W0@9F%I;&5D+B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!)=&5R871E('1H<F]U9V@@=&AE(')E<W!O;G-E
M(&%N9"!P;W!U;&%T92!A;B!A<G)A>2!O9@H@("`@("`@("`J(&%D9')E<W,@
M8F]O:R!N86UE<RX@*B\*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@(&EF("AI<U]A*"1S
M97)V97)?<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1S97)V97)?<F5S<&]N<V4["B`@("`@("`@?0H@("`@("`@("1A
M8F]O:W,@/2!A<G)A>2@I.PH*("`@("`@("!W:&EL92`H<')E9U]M871C:"@B
M+UY<*B!!1$1215-30D]/2R\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@
M("`@("`@("`O*B!)9B!T:&ES(&ES(&%N($%$1%)%4U-"3T]+(')E<W!O;G-E
M+"!T:&5N('1H:7,@=VEL;"!E>'!L;V1E(&%S('-O.@H@("`@("`@("`@("`@
M*B!;,%T@86YD(%LQ72!C86X@8F4@9&ES8V%R9&5D"B`@("`@("`@("`@("`J
M(%LR72`](&%T=')I8G5T97,*("`@("`@("`@("`@("H@6S-=(#T@9&5L:6UI
M=&5R"B`@("`@("`@("`@("`J(%LT72`](&%D9')E<W,@8F]O:R!N86UE"B`@
M("`@("`@("`@("`J+PH*("`@("`@("`@("`@+RH@1FER<W0L(&-H96-K(&9O
M<B!A('M]("HO"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3T-4
M151?0T]53E0L("1S97)V97)?<F5S<&]N<V4L("1T96UP07)R87DI*2!["B`@
M("`@("`@("`@("`@("`D86)O;VMS6UT@/2`D=&AI<RT^7VEM<W`M/G)E8V5I
M=F53=')I;F=,:71E<F%L*"1T96UP07)R87E;,ETI.PH@("`@("`@("`@("`@
M("`@+RH@1V5T('1H92!#4DQ&(&%T(&5N9"!O9B!!1$1215-30D]/2R!R97-P
M;VYS90H@("`@("`@("`@("`@("`@("H@=&AA="!T:&4@>WT@9&]E<R!N;W0@
M:6YC;'5D92X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^<F5C
M96EV95-T<FEN9TQI=&5R86PH,BD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<@)RP@)'-E<G9E<E]R
M97-P;VYS92D["B`@("`@("`@("`@("`@("`D;G5M4&%R=',@/2!C;W5N="@D
M<&%R=',I.PH@("`@("`@("`@("`@("`@)&YA;64@/2`D<&%R='-;-%T["B`@
M("`@("`@("`@("`@("`D9FER<W1#:&%R(#T@<W5B<W1R*"1N86UE+"`P+"`Q
M*3L*("`@("`@("`@("`@("`@(&EF("@D9FER<W1#:&%R(#T](EPB(BD@>PH@
M("`@("`@("`@("`@("`@("`@("1N86UE(#T@;'1R:6TH)&YA;64L(")<(B(I
M.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`U.R`D:2`\("1N=6U0
M87)T<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`N
M/2`G("<@+B`D<&%R='-;)&E=.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;&%S=$-H87(@/2!S=6)S='(H)'!A<G1S6R1I72P@<W1R;&5N*"1P87)T<ULD
M:5TI("T@,2P@,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;&%S
M=$-H87(@/3T@(EPB(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2!R=')I;2@D;F%M92P@(EPB(BD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1A8F]O:W-;72`]("1N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-E<G9E<E]R
M97-P;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E
M9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],
M;V<H)T%$1%)%4U-"3T]+(&-O;6UA;F0@3TLN)RP@7U]&24Q%7U\L(%]?3$E.
M15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],
M3T=?24Y&3RD["B`@("`@("`@<F5T=7)N("1A8F]O:W,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&YA
M;65S('1H870@;6%T8V@@)'-E87)C:`H@("`@("H@8W)I=&5R82!I;B!T:&4@
M861D<F5S<R!B;V]K(&YA;65D("1A8F]O:RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8F]O:R`@061D<F5S<R!B;V]K(&YA;64@=&\@<V5A<F-H
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S96%R8V@@(%-E87)C:"!C<FET97)I
M82!I;B!T:&4@9F]R;2!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M)V9I96QD3F%M92<@/3X@)W-E87)C:%1E<FTG("AM87D@:6YC;'5D92`J('=I
M;&0@8V%R9"DN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!!<G)A>2!O
M9B!N86UE<R!O9B!T:&4@96YT<FEE<R!T:&%T(&UA=&-H(&]R(%!%05)?17)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E87)C:"@D86)O;VLL("1S96%R
M8V@I"B`@("!["B`@("`@("`@+R])9B!N;R!F:65L9"`]/B!V86QU92!P86ER
M<RP@87-S=6UE('=E(&%R92!S96%R8VAI;F<@;F%M92X*("`@("`@("`D8W)I
M=&5R:6$@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-?87)R87DH)'-E87)C
M:"DI('L*("`@("`@("`@("`@)&-R:71E<FEA6R=N86UE)UT@/2`D<V5A<F-H
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C<FET97)I82`]("1S
M96%R8V@["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@G4T5!4D-(041$4D534R`G+"!T<G5E+"!F86QS92D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("\O($1O('=E(&YE960@=&\@<V5N9"!T:&4@86)O;VL@;F%M92!A<R![?2`_
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,
M+"`D86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[
M)61](BP@<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US
M<%)E8V5I=F4H*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O
M7EPK+R(L("1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E
M9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R
M=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+U-T87)T('!A<G-I;F<@=&AE('-E87)C:"!A
M<G)A>2X*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N
M9"@B)&%B;V]K(BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&-R
M:71E<FEA*3L*("`@("`@("`D8W5R<F5N="`](#$["B`@("`@("`@9F]R96%C
M:"`H)&-R:71E<FEA(&%S("1S96%R8VA?9FEE;&0@/3X@)'-E87)C:"D@>PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B
M("1S96%R8VA?9FEE;&0@(BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O($AO=R!A8F]U="!T:&4@<V5A<F-H('1E<FT@87,@82![?2X*("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,
M+"`D<V5A<F-H*2D@>PH@("`@("`@("`@("`@("`@)&)I4V5A<F-H(#T@<W!R
M:6YT9B@B>R5D?2(L('-T<FQE;B@D<V5A<F-H*2D["@H@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I4V5A<F-H
M+"!F86QS92P@=')U92D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O
M7EPK+R(L("1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP
M96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0
M('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1S96%R8V@L(&9A;'-E+"`D8W5R<F5N="`]/2`D
M8V]U;G0I.PH@("`@("`@("`@("`@("`@)&-U<G)E;G0K*SL*("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O
M($]N;'D@<V5N9"!T:&4@0W),9B!I9B!T:&ES(&ES('1H92!L87-T(&9I96QD
M+W-E87)C:"!A=&]M+@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)R(G("X@)'-E87)C:"`N("<B)RP@9F%L<V4L
M("1C=7)R96YT(#T]("1C;W5N="D["B`@("`@("`@("`@("`@("`D8W5R<F5N
M="LK.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!'970@=&AE(')E<W!O;G-E+@H@("`@("`@("1S97)V97)?
M<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@
M("`@)&%B;V]K3F%M97,@/2!!<G)A>2@I.PH*("`@("`@("!W:&EL92`H<')E
M9U]M871C:"@B+UY<*B!314%20TA!1$1215-3+R(L("1S97)V97)?<F5S<&]N
M<V4I*2!["B`@("`@("`@("`@("1C:&]P<&5D7W)E<W!O;G-E(#T*("`@("`@
M("`@("`@("`@('!R96=?<F5P;&%C92@B+UY<*B!314%20TA!1$1215-3+R(L
M("<G+"`D<V5R=F5R7W)E<W!O;G-E*3L*"B`@("`@("`@("`@("\O($=E="!R
M:60@;V8@86YY(&QI;F=E<FEN9R!Q=6]T97,N"B`@("`@("`@("`@("1C:&]P
M<&5D7W)E<W!O;G-E(#T@<')E9U]R97!L86-E*"(O7"(O(BP@)R<L("1C:&]P
M<&5D7W)E<W!O;G-E*3L*"B`@("`@("`@("`@("\O(%)E;6]V92!A;GD@;&EN
M9V5R:6YG('=H:71E('-P86-E(&EN(&9R;VYT(&]N;'DN"B`@("`@("`@("`@
M("1T96UP(#T@;'1R:6TH)&-H;W!P961?<F5S<&]N<V4I.PH*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H(B\H>RDH6S`M.5U[,2Q]*2A<?20I+R(L("1T
M96UP+"`D=&5M<$%R<F%Y*2D@>PH@("`@("`@("`@("`@("`@)&1A=&%3:7IE
M(#T@)'1E;7!!<G)A>5LR73L*("`@("`@("`@("`@("`@("1T96UP(#T@)'1H
M:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@D9&%T85-I>F4I.PH*
M("`@("`@("`@("`@("`@("\J($=E="!T:&4@0U),1B!S:6YC92![?2!D;V5S
M(&YO="!I;F-L=61E(&ET+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@R*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&%B;V]K3F%M97-;72`]("1T96UP.PH*("`@("`@("`@
M("`@+R\@1V5T('1H92!N97AT(')E<W!O;G-E(&QI;F4@9G)O;2!T:&4@<V5R
M=F5R+@H@("`@("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I
M;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@('T*"B`@("`@("`@+R\@4VAO
M=6QD(&-H96-K(&9O<B!/2R!O<B!"040@:&5R92!J=7-T('1O(&)E(&-E<G1A
M:6XN"B`@("`@("`@<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@
M("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T
M86YD('EO=7(@<F5Q=65S="XG("X@("(Z("1C;VUM86YD7W1E>'0B+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R
M(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG("X@(CH@(B`N
M("1T:&ES+3Y?:6US<"T^;&%S=%)A=T5R<F]R+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("\J(%1H:7,@86QL;W=S(&9O<B!N;R!R
M97-U;'1S("HO"B`@("`@("`@:68@*&-O=6YT*"1A8F]O:TYA;65S*2`\(#$I
M('L*("`@("`@("`@("`@<F5T=7)N("1A8F]O:TYA;65S.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=314%20TA!1$12
M15-3(&-O;6UA;F0@3TLG+"!?7T9)3$5?7RP@7U],24Y%7U\L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TE.1D\I.PH*("`@
M("`@("`O+R!$971E<FUI;F4@=&AE('-O<G0@9&ER96-T:6]N(&%N9"!P97)F
M;W)M('1H92!S;W)T+@H@("`@("`@('-W:71C:"`H)'1H:7,M/G-O<G0I('L*
M("`@("`@("!C87-E("=A<V-E;F0G.@H@("`@("`@("`@("!S;W)T*"1A8F]O
M:TYA;65S*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V1E
M<V-E;F0G.@H@("`@("`@("`@("!R<V]R="@D86)O;VM.86UE<RD["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A8F]O
M:TYA;65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<W-O
M8VEA=&EV92!A<G)A>2!O9B!A('-I;F=L92!A9&1R97-S(&)O;VL@96YT<GDN
M"B`@("`@*B!.;W1E('1H870@=&AE<F4@=VEL;"!A;'=A>7,@8F4@82`G;F%M
M92<@9FEE;&0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VL@
M("`@("`@3F%M92!O9B!T:&4@861D<F5S<R!B;V]K('1O('-E87)C:"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&5N=')Y3F%M92`@)VYA;64G(&%T=')I8G5T
M92!O9B!T:&4@96YT<GD@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D($%R<F%Y(&-O;G1A:6YI;F<@96YT<GD@;W(@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E("\@;F\@;6%T8V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$5N=')Y*"1A8F]O:RP@)&5N=')Y3F%M92D*("`@('L*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G1D540TA!1$1215-3
M("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U53
M15],251%4D%,+"`D86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S
M<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L
M<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O
M7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E
M8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@
M<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H(B1A8F]O:R`B+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H<')E9U]M
M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1E;G1R>4YA;64I*2!["B`@
M("`@("`@("`@("1B:4YA;64@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1E
M;G1R>4YA;64I*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"1B:4YA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU
M871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1E;G1R>4YA;64L(&9A;'-E
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B7"(D96YT<GE.86UE7"(B
M+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R
M7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@
M("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*("`@("`@("!C87-E
M("="040G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U
M<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@8V%S
M92`G3D\G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)TYO(&5N=')Y(&EN('1H:7,@861D<F5S<R!B;V]K(&UA=&-H97,@
M>6]U<B!Q=65R>2XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1V5T('1H92!D871A(&EN(&%N(&%S<V]C:6%T:79E(&%R
M<F%Y+@H@("`@("`@("1E;G1R>2`]("1T:&ES+3Y?<&%R<V5&971C:$%D9')E
M<W-297-P;VYS92@D<V5R=F5R7W)E<W!O;G-E*3L*"B`@("`@("`@+R]'970@
M=&AE(&YE>'0@<V5R=F5R(')E<W!O;G-E("TM('1H:7,@*G-H;W5L9"H@8F4@
M=&AE($]+(')E<W!O;G-E+@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D
M=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@(&EF("@D<V5R
M=F5R7W)E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@+R\@56YE>'!E
M8W1E9"!R97-P;VYS92!T:')O=R!E<G)O<B!B=70@<W1I;&P@8V]N=&EN=64@
M;VXN"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@
M;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E
M<G9E<BXG+%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H)T9%5$-(041$4D534R!C;VUP
M;&5T960@3TLG+"!?7T9)3$5?7RP@7U],24Y%7U\L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!014%27TQ/1U])3D9/*3L*("`@("`@("!R
M971U<FX@)&5N=')Y.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A
M(&YE=R!A9&1R97-S(&)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D86)O;VM.86UE($953$Q9(%%504Q)1DE%1"!N86UE('-U8V@@)VID;V4N
M8VQI96YT<R<@971C+BXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!4
M<G5E(&]N('-U8V-E<W,@+R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-R96%T94%D9')E<W-";V]K*"1A8F]O:TYA;64I
M"B`@("!["B`@("`@("`@)&-O;6UA;F1?=&5X="`]("=#4D5!5$5!1$1215-3
M0D]/2R`G.PH*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%
M7TQ)5$5204PL("1A8F]O:TYA;64I*2!["B`@("`@("`@("`@("1B:4)O;VL@
M/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O:TYA;64I*3L*"B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM
M86YD7W1E>'0@+B`D8FE";V]K+"!T<G5E+"!T<G5E*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O
M<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T
M:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&%B;V]K3F%M
M92P@9F%L<V4L('1R=64I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)&-O;6UA;F1?=&5X="`N("1A8F]O:TYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1R=64L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R
M97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@
M("!I9B`H:7-?82@D<V5R=F5R7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@
M('T*"B`@("`@("`@<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@
M("`@8V%S92`G3TLG.@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E
M5&],;V<H)T-214%414%$1%)%4U-"3T]+(&-O;7!L971E9"!/2R<L(%]?1DE,
M15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],
M24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U<FX@=')U
M93L*"B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@("`O+R!#;W5L9"!N
M;W0@8W)E871E(&%B;V]K+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F
M;W)M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@
M("`@("!C87-E("="040G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R
M<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("\O(%-O;65T:&EN9R!U;F5X
M<&5C=&5D+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@
M9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@86X@861D<F5S<R!B
M;V]K(&-O;7!L971E;'DA"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M86)O;VM.86UE($YA;64@;V8@861D<F5S<R!B;V]K('1O(&1E;&5T92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<R`O(%!%
M05)?17)R;W(@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE
M=&5!9&1R97-S0F]O:R@D86)O;VM.86UE*0H@("`@>PH@("`@("`@("1C;VUM
M86YD7W1E>'0@/2`G1$5,151%041$4D534T)/3TL@)SL*"B`@("`@("`@+R\@
M0VAE8VL@;F5E9"!F;W(@>WTN"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U3
M4%]-55-47U5315],251%4D%,+"`D86)O;VM.86UE*2D@>PH@("`@("`@("`@
M("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VM.86UE
M*2D["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@D8V]M;6%N9%]T97AT("X@)&)I0F]O:RP@=')U92P@=')U92D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I
M=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@
M8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&%B;V]K3F%M92P@9F%L<V4L('1R=64I.PH@("`@("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM86YD7W1E>'0@+B`D
M86)O;VM.86UE+"!T<G5E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E
M*"D["B`@("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS
M93L*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS
M92D@>PH@("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YW<FET951O3&]G*"=$14Q%5$5!1$1215-30D]/2R!C;VUP;&5T960@
M3TLG+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["@H@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@
M+R\@0V]U;&0@;F]T($1%3$5412!A8F]O:RX*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B
M;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*"B`@("`@("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED
M(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`O+R!3;VUE
M=&AI;F<@=6YE>'!E8W1E9"X*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+"!?7T9)3$5?7RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&%N
M(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M8F]O:T]L9$YA;64@3VQD(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M8F]O:TYE=TYA;64@3F5W(&%D9')E<W,@8F]O:R!N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@5')U92`O(%!%05)?17)R;W(*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5N86UE061D<F5S<T)O;VLH)&%B;V]K3VQD3F%M92P@
M)&%B;V]K3F5W3F%M92D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]I;7-P+3YI;7-P4V5N9"@G4D5.04U%041$4D534T)/3TL@)RP@=')U92P@
M9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL
M("1A8F]O:T]L9$YA;64I*2!["B`@("`@("`@("`@("1B:4]L9$YA;64@/2!S
M<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O:T]L9$YA;64I*3L*"B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4]L
M9$YA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?
M:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VM/;&1.86UE("(L
M(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?
M3$E415)!3"P@)&%B;V]K3F5W3F%M92DI('L*("`@("`@("`@("`@)&)I3F5W
M3F%M92`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K3F5W3F%M92DI
M.PH*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E
M;F0H)&)I3F5W3F%M92P@9F%L<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@?0H*("`@("`@
M("`O+R!#4DQ&('-I;F-E(&QA<W0@<&%R="X*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D86)O;VM.97=.86UE+"!F86QS92P@
M=')U92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("\O($=E="!S97)V97(@<F5S<&]N<V4N"B`@("`@("`@)'-E<G9E
M<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@
M("`@("`@<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@("`@8V%S
M92`G3D\G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@
M<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!C87-E
M("="040G.@H@("`@("`@("`@("`O+R!3>6YT87@@<')O8FQE;2X*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U3
M4"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG*3L*
M"B`@("`@("`@8V%S92`G3TLG.@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M
M/G=R:71E5&],;V<H(D%D9')E<W,@8F]O:R`D86)O;VM/;&1.86UE('-U8V-E
M<W-F=6QL>0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-H86YG960@=&\@)&%B;V]K3F5W3F%M92(L(%]?1DE,15]?+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!014%2
M7TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A;B!A9&1R97-S(&)O
M;VL@96YT<GD@=&\@86X@861D<F5S<R!B;V]K+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&%B;V]K("`@("!.86UE(&]F(&%D9')E<W,@8F]O:R!T
M;R!A9&0@96YT<GD@=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&5N=')Y26YF
M;R`@061D<F5S<R!B;V]K(&5N=')Y(&EN9F]R;6%T:6]N("T*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&5R92!-55-4(&)E(&$@9FEE;&0@
M)VYA;64G(&-O;G1A:6YI;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@96YT<GD@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D(%1R=64@;VX@<W5C8V5S<R`O(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D16YT<GDH)&%B;V]K+"`D96YT<GE)
M;F9O*0H@("`@>PH@("`@("`@("1C;VUM86YD7W1E>'0@/2`G)SL*"B`@("`@
M("`@:68@*&=E=%1Y<&4H)&5N=')Y26YF;RD@(3T@)V%R<F%Y)RD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H24U34%]"
M041?05)'54U%3E0L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*
M("`@("`@("`O+R!,;V-K('1H92!E;G1R>2!I9B!I="!A;')E861Y(&5X:7-T
M<RX*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/FQO8VM%;G1R>2@D86)O;VLL
M("1E;G1R>4EN9F];)VYA;64G72D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!396YD*"=35$]214%$1%)%4U,@)RP@=')U92P@9F%L<V4I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!4
M86ME(&-A<F4@;V8@=&AE(&YA;64N"B`@("`@("`@)&5N=')Y3F%M92`]("1E
M;G1R>4EN9F];)VYA;64G73L*"B`@("`@("`@+R\@>WT@9F]R(&)O;VL@;F%M
M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$52
M04PL("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H
M(GLE9'TB+"!S=')L96XH)&%B;V]K*2D["@H@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE";V]K+"!F86QS92P@=')U
M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E
M*"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*"B`@("`@("`@+R\@1&\@=V4@
M;F5E9"![?2!F;W(@96YT<GD@;F%M92!A<R!W96QL/PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&5N=')Y3F%M92DI
M('L*("`@("`@("`@("`@)&)I;F%M92`]('-P<FEN=&8H(GLE9'TB+"!S=')L
M96XH)&5N=')Y3F%M92DI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!396YD*"1B:6YA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@)'1H
M:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1E;G1R>4YA;64L(&9A;'-E+"!F86QS92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@B7"(D96YT<GE.86UE7"(@(BP@9F%L<V4L(&9A;'-E*3L*("`@("`@
M("!]"@H@("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V86QU92D@/2!E86-H
M*"1E;G1R>4EN9F\I*2!["B`@("`@("`@("`@("\O($1O(&YO="!S96YT('1H
M92!K97D@;F%M92`G;F%M92<N"B`@("`@("`@("`@(&EF("@D:V5Y("$]("=N
M86UE)RD@>PH@("`@("`@("`@("`@("`@+R\@4')O=&5C="!F<F]M(&5X=')A
M;F5O=7,@=VAI=&4@<W!A8V4*("`@("`@("`@("`@("`@("1V86QU92`]('1R
M:6TH)'9A;'5E*3L*"B`@("`@("`@("`@("`@("`O+R!&;W(@<V]M92!R96%S
M;VXL('1A8G,@<V5E;2!T;R!B<F5A:R!T:&ES+@H@("`@("`@("`@("`@("`@
M)'9A;'5E(#T@<')E9U]R97!L86-E*"(O7'0O(BP@(EQN7'(B+"`D=F%L=64I
M.PH*("`@("`@("`@("`@("`@("\O($-H96-K('1O('-E92!I9B!W92!N965D
M('M]"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?
M55-%7TQ)5$5204PL("1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("`D
M8V]M;6%N9%]T97AT("X]("1K97D@+B!S<')I;G1F*"(@>R5D?2(L('-T<FQE
M;B@D=F%L=64I*3L*"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@D8V]M;6%N9%]T97AT+"!F86QS92P@=')U92D["B`@("`@
M("`@("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@("`@("`@("`@("`D8V]M;6%N
M9%]T97AT(#T@)R<[("\O0VQE87(@=&AE(&-O;6UA;F1?=&5X="!B=69F97(*
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S97)V97)?
M<F5S<&]N<V4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E
M>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("`@("`O+R!396YD('1H92!S=')I;F<@;V8@;V-T
M971S(&%N9"!B92!S=7)E($Y/5"!T;PH@("`@("`@("`@("`@("`@("`@("\O
M(&5N9"!W:71H($-23$8N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@D=F%L=64L(&9A;'-E+"!F86QS92D["@H@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!)9B!W
M92!A<F4@:&5R92P@=&AE;B!W92!D;R!N;W0@;F5E9"!T;R!S96YD(&$*("`@
M("`@("`@("`@("`@("`@("`O+R![?2X*("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@/2`B7"(B("X@)'9A;'5E("X@(EPB(CL*("`@("`@("`@("`@("`@
M("`@("`D8V]M;6%N9%]T97AT("X]("1K97D@+B`G("<@+B`D=F%L=64@+B`G
M("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O(%-E;F0@86YY=&AI;F<@=&AA="!I<R!L969T(&]F('1H
M92!C;VUM86YD+@H@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&-O
M;6UA;F1?=&5X="P@9F%L<V4L('1R=64I.PH@("`@("`@("1S97)V97)?<F5S
M<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@
M('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A<V4@)TY/
M)SH*("`@("`@("`@("`@+R]3;W)R>2XN+F-A;FYO="!D;R!I="X*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E
M<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G0D%$)SH*("`@("`@
M("`@("`@+R]3;W)R>2XN+F1I9"!N;W0@=6YD97)S=&%N9"!Y;W4*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U3
M4"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+"!?
M7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<V5R
M=F5R7W)E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@+R\@0WER=7,M
M24U34"!S97)V97(@<V5N9',@82!&151#2$%$1%)%4U,@4F5S<&]N<V4@:&5R
M92X*("`@("`@("`@("`@+R\@1&\@;W1H97)S/R`@("`@5&AI<R!W87,@;F]T
M(&EN('1H92!21D,N"B`@("`@("`@("`@("1D=6UM>5]A<G)A>2`]"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<G-E1F5T8VA!9&1R97-S4F5S<&]N<V4H
M)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("`@
M("`@<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@("`@("`@(&-A
M<V4@)TY/)SH*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O<FT@
M>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N
M9&5R<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?
M*3L*("`@("`@("`@("`@8V%S92`G3TLG.@H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]I;7-P+3YW<FET951O3&]G*"=35$]214%$1%)%4U,@0V]M<&QE=&5D
M('-U8V-E<W-F=6QL>2XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&
M3RD["@H@("`@("`@("`@("`@("`@+R]W92!W97)E('-U8V-E<W-F=6PN+BYS
M;R!R96QE87-E('1H92!L;V-K(&]N('1H92!E;G1R>0H@("`@("`@("`@("`@
M("`@:68@*"$D=&AI<RT^=6YL;V-K16YT<GDH)&%B;V]K+"`D96YT<GE);F9O
M6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@+R]C;W5L9"!N;W0@
M<F5L96%S92!L;V-K"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6US<"T^:6US<$5R<F]R*"=4:&%T(&%D9')E<W,@8F]O:R!E;G1R>2!I
M<R!L;V-K960@;W(@<F5A9"!O;FQY(&9O<B!T:&4@8W5R<F5N="!U<V5R+B<L
M(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%N(&%B
M;V]K(&5N=')Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K
M("`@("!.86UE(&]F(&%D9')E<W,@8F]O:R!C;VYT86EN:6YG(&5N=')Y+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8F]O:T5N=')Y($YA;64@;V8@96YT<GD@
M=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@5')U92!O
M;B!S=6-C97-S("\@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!D96QE=&5%;G1R>2@D86)O;VLL("1B;V]K16YT<GDI"B`@
M("!["B`@("`@("`@+R\@4W1A<G0@=&AE(&-O;6UA;F0N"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)T1%3$5414%$1%)%4U,@
M)RP@=')U92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O+R!.965D('M](&9O<B!B;V]K(&YA;64_"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D
M86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61]
M(BP@<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@D8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H
M)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO
M;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1A8F]O:R`B+"!F86QS92P@9F%L<V4I
M.PH*("`@("`@("`O+TAO=R!B;W5T(&9O<B!T:&4@96YT<GD@;F%M93\*("`@
M("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1B
M;V]K16YT<GDI*2!["B`@("`@("`@("`@("1B:45N=')Y(#T@<W!R:6YT9B@B
M>R5D?2(L('-T<FQE;B@D8F]O:T5N=')Y*2D["@H@("`@("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1B:45N=')Y+"!F86QS92P@=')U92D["@H@
M("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H
M*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N
M=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1B;V]K16YT<GD@/2`D=&AI<RT^7VEM<W`M/G%U
M;W1E4W!A8V5D4W1R:6YG*"1B;V]K16YT<GDI.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8F]O:T5N=')Y+"!F86QS92P@
M=')U92D["B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@<W=I=&-H("@D<V5R=F5R7W)E
M<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@("`O+U-O
M<G)Y+BYC86YN;W0@9&\@:70*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R
M9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!C87-E("="040G.@H@("`@("`@("`@("`O+T1O(&YO="!K;F]W('=H
M870@>6]U<B!T86QK:6YG(&%B;W5T"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@
M=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD[
M"B`@("`@("`@8V%S92`G3TLG.@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M
M/G=R:71E5&],;V<H)T1%3$5412!#;VUP;&5T960@<W5C8V5S<V9U;&QY+B<L
M(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!A8W%U:7)E(&$@<V5M87!H;W)E(&]N('1H92!A9&1R97-S(&)O
M;VL@96YT<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VL@
M("`@($%D9')E<W,@8F]O:R!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG("1B
M;V]K16YT<GD@3F%M92!O9B!E;G1R>2!T;R!L;V-K"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!T<G5E(&]R(&%R<F%Y(&]N('-U8V-E<W,@86YD(%!%
M05)?17)R;W(@;VX@9F%I;'5R90H@("`@("H@("`@("`@("`@("`@("`H<V5R
M=F5R(&1E<&5N9&EN9RD*("`@("`J+PH@("`@9G5N8W1I;VX@;&]C:T5N=')Y
M*"1A8F]O:RP@)&)O;VM%;G1R>2D*("`@('L*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G3$]#2R!!1$1215-30D]/2R`G+"!T
M<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\O($1O('=E(&YE960@82!S=')I;F<@;&ET97)A;#\*
M("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL
M("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H(GLE
M9'TB+"!S=')L96XH)&%B;V]K*2D["@H@("`@("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@
M("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R
M*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I
M;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1A8F]O:R`B+"!F86QS92P@9F%L<V4I
M.PH*("`@("`@("`O+R!7:&%T(&%B;W5T('1H92!E;G1R>2!N86UE/PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&)O
M;VM%;G1R>2DI('L*("`@("`@("`@("`@)&)I16YT<GD@/2!S<')I;G1F*")[
M)61](BP@<W1R;&5N*"1B;V]K16YT<GDI*3L*"B`@("`@("`@("`@("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)&)I16YT<GDL(&9A;'-E+"!T<G5E*3L*"B`@
M("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT
M:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)O;VM%;G1R>2P@9F%L<V4L('1R=64I
M.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8F]O:T5N=')Y(#T@
M)'1H:7,M/E]I;7-P+3YQ=6]T95-P86-E9%-T<FEN9R@D8F]O:T5N=')Y*3L*
M("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&)O;VM%;G1R
M>2(L(&9A;'-E+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("1S97)V97)?
M<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@
M("`@(&1O('L*"B`@("`@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS
M92D@>PH*("`@("`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&%T(&%D9')E<W,@
M8F]O:R!E;G1R>2!I<R!L;V-K960@;W(@<F5A9"!O;FQY(&9O<B!T:&4@8W5R
M<F5N="!U<V5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD
M97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+T-H96-K('1O('-E92!I
M9B!T:&ES(&ES(&$@1D540TA!1$1215-3(')E<V]N<V4*("`@("`@("`@("`@
M)&1U;6UY(#T@)'1H:7,M/E]P87)S949E=&-H061D<F5S<U)E<W!O;G-E*"1S
M97)V97)?<F5S<&]N<V4I.PH*("`@("`@("`@("`@:68@*"1D=6UM>2D@>PH@
M("`@("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@("`@?0H*("`@("`@("!]('=H
M:6QE("@D<V5R=F5R7W)E<W!O;G-E("$]("=/2R<I.PH*("`@("`@("`D=&AI
M<RT^7VEM<W`M/G=R:71E5&],;V<H(DQ/0TL@041$4D534T)/3TL@;VX@)&%B
M;V]K("1B;V]K16YT<GD@3TLB+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH*
M("`@("`@("`O+R!2971U<FX@96ET:&5R('1R=64@;W(@=&AE($9%5$-(041$
M4D534R!R97-P;VYS92!I9B!I="!E>&ES=',N"B`@("`@("`@:68@*"$D9'5M
M;7DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1D=6UM>3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5;FQO8VMS(&$@<')E=FEO=7-L>2!L;V-K960@
M861D<F5S<R!B;V]K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B
M;V]K("`@("!.86UE(&]F(&%D9')E<W,@8F]O:R!C;VYT86EN:6YG(&QO8VME
M9"!E;G1R>2X*("`@("`J($!P87)A;2!S=')I;F<@)&)O;VM%;G1R>2!.86UE
M(&]F(&5N=')Y('1O('5N;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!U;FQO8VM%;G1R>2@D86)O;VLL("1B;V]K
M16YT<GDI"B`@("!["B`@("`@("`@+R\@4W1A<G0@<V5N9&EN9R!C;VUM86YD
M+@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=5
M3DQ/0TL@041$4D534T)/3TL@)RP@=')U92P@9F%L<V4I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R![?2!F;W(@
M8F]O:R!N86UE/PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]5
M4T5?3$E415)!3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@
M<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I
M.PH*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E
M:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD
M(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1A8F]O:R`B+"!F
M86QS92P@9F%L<V4I.PH*("`@("`@("`O+TAO=R!B;W5T(&9O<B!E;G1R>2!N
M86UE/PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E4
M15)!3"P@)&)O;VM%;G1R>2DI('L*("`@("`@("`@("`@)&)I16YT<GD]<W!R
M:6YT9B@B>R5D?2(L('-T<FQE;B@D8F]O:T5N=')Y*2D["B`@("`@("`@("`@
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I16YT<GDL(&9A;'-E+"!T<G5E
M*3L*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C
M96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N
M9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)O;VM%;G1R>2P@9F%L<V4L
M('1R=64I.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8F]O:T5N
M=')Y(#T@)'1H:7,M/E]I;7-P+3YQ=6]T95-P86-E9%-T<FEN9R@D8F]O:T5N
M=')Y*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&)O
M;VM%;G1R>2(L(&9A;'-E+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("1R
M97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@
M("`@<W=I=&-H("@D<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U3
M4"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE
M($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G3TLG.@H@
M("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H(E5.3$]#2R!!
M1$1215-30D]/2R!O;B`D86)O;VL@)&)O;VM%;G1R>2!/2R(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8V-E<W,@0V]N=')O
M;"!,:7-T("A!0TPI("!-971H;V1S+@H@("`@("H*("`@("`J(%1H92!F;VQL
M;W=I;F<@8VAA<F%C=&5R<R!A<F4@<F5C;V=N:7IE9"!!0TP@8VAA<F%C=&5R
M<SH@;')W8V1A"B`@("`@*B!L("T@(FQO;VMU<"(@("AS964@=&AE(&YA;64@
M86YD(&5X:7-T96YC92!O9B!T:&4@861D<F5S<R!B;V]K*0H@("`@("H@<B`M
M(")R96%D(B`@("`H<V5A<F-H(&%N9"!R971R:65V92!A9&1R97-S97,@9G)O
M;2!A9&1R97-S(&)O;VLI"B`@("`@*B!W("T@(G=R:71E(B`@("AC<F5A=&4O
M961I="!N97<@861D<F5S<R!B;V]K(&5N=')I97,@+2!N;W0@9&5L971E*0H@
M("`@("H@8R`M(")C<F5A=&4B("`H8W)E871E(&YE=R!A9&1R97-S(&)O;VMS
M('5N9&5R('1H92!C=7)R96YT(&%D9')E<W,@8F]O:RD*("`@("`J(&0@+2`B
M9&5L971E(B`@*&1E;&5T92!E;G1R:65S(&]R(&5N=&ER92!B;V]K*0H@("`@
M("H@82`M(")A9&UI;B(@("`H<V5T($%#3"!L:7-T<R!F;W(@=&AI<R!A9&1R
M97-S(&)O;VL@+2!U<W5A;&QY(&]N;'D*("`@("`J("`@("`@("`@("`@("`@
M86QL;W=E9"!F;W(@=&AE(&]W;F5R(&]F('1H92!A9&1R97-S(&)O;VLI"B`@
M("`@*@H@("`@("H@97AA;7!L97,Z"B`@("`@*B`@(FQR(B!W;W5L9"!B92!R
M96%D(&]N;'D@9F]R('1H870@=7-E<@H@("`@("H@(")L<G<B('=O=6QD(&)E
M(')E860O=W)I=&4*("`@("`J+PH*("`@("\J*@H@("`@("H@4V5T<R!A;B!!
M8V-E<W,@0V]N=')O;"!,:7-T(&9O<B!A;B!A8F]O:RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A8F]O:R!.86UE(&]F(&%D9')E<W,@8F]O:RX*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT($YA;64@;V8@=7-E<B!F;W(@
M=&AI<R!A8VPN"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8VP@("!A8VP@9F]R
M('1H:7,@=7-E<B]B;V]K+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M5')U92!O;B!S=6-C97-S("\@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971!0TPH)&%B;V]K+"`D:61E;G0L("1A8VPI
M"B`@("!["B`@("`@("`@+R\@5F5R:69Y('1H870@)&%C;"!L;V]K<R!G;V]D
M+@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O6UXB("X@24U34%]!0TQ?4DE'
M2%13("X@(ETO(BP@)&%C;"DI('L*("`@("`@("`@("`@+R]E<G)O<BXN+F%C
M;"!L:7-T(&-O;G1A:6YE9"!U;G)E8V]G:6YZ960@;W!T:6]N<PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H24U34%]"041?
M05)'54U%3E0L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`O+R!"96=I;B!S96YD:6YG(&-O;6UA;F0N"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)U-%5$%#3"!!1$1215-30D]/
M2R`G+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O
M;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@
M<W1R;&5N*"1A8F]O:RDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF
M("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@
M;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S
M<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*"B`@
M("`@("`@+R\@>WT@9F]R(&ED96YT/PH@("`@("`@(&EF("AP<F5G7VUA=&-H
M*$E-4U!?35535%]54T5?3$E415)!3"P@)&ED96YT*2D@>PH@("`@("`@("`@
M("`D8FE)9&5N="`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&ED96YT*2D[
M"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I261E;G0L
M(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B
M+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP
M96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0
M('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@
M('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*"(D:61E;G0@(BP@9F%L<V4L(&9A;'-E*3L*"B`@("`@("`@+R\@3F]W(&9I
M;FES:"!U<"!W:71H('1H92!A8W1U86P@04-,+@H@("`@("`@("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)&%C;"P@9F%L<V4L('1R=64I.PH@("`@("`@("1R
M97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@
M("`@<W=I=&-H("@D<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z"B`@
M("`@("`@("`@("\O($-O=6QD(&YO="!S970@04-,+@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R(&ES
M('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG+%]?1DE,15]?+"!?
M7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@("\O
M($)A9"!S>6YT87@N"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N
M9"!Y;W5R(')E<75E<W0N)RQ?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@
M("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^=W)I=&54
M;TQO9R@B04-,('-E="!F;W(@)&ED96YT(&]N("1A8F]O:R(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`O+R!$;R!N;W0@:VYO
M=R!W:'D@=V4@=V]U;&0@;6%K92!I="!D;W=N(&AE<F4N"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E
M:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F5S(&%N(&%D9')E<W,@8F]O:R=S($%#3"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8F]O:R!.86UE(&]F(&%D9')E<W,@
M8F]O:R!T;R!R971R:65V92!A8VP@9F]R+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@87)R87D@8V]N=&%I;FEN9R!A8VP@9F]R(&5V97)Y('5S97(@
M=VET:"!A8V-E<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@861D
M<F5S<R!B;V]K(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T04-,*"1A8F]O:RD*("`@('L*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G1T5404-,($%$1%)%4U-"
M3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@+R\@>WT@9F]R(&)O;VL@;F%M93\*("`@
M("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1A
M8F]O:RDI('L*("`@("`@("`@("`@)&)I3F%M92`]('-P<FEN=&8H(GLE9'TB
M+"!S=')L96XH)&%B;V]K*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)&)I3F%M92P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I
M9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R
M97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]I;7-P+3YI;7-P4V5N9"@D86)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@("`@
M("`@+R\@1V5T(')E<W5L=',N"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M
M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!S=VET8V@@*"1R97-P
M;VYS92D@>PH@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R\@0V]U
M;&0@;F]T(&-O;7!L971E/PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F
M;W)M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@
M("`@("!C87-E("="040G.@H@("`@("`@("`@("`O+R!$;R!N;W0@:VYO=R!W
M:&%T('EO=2!S86ED(0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A
M;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!)9B!W92!A<F4@:&5R92P@=V4@;F5E9"!T;R!R
M96-E:79E('1H92`J($%#3"!297-P;VYS97,N"B`@("`@("`@9&\@>PH@("`@
M("`@("`@("`O*B!'970@86X@87)R87D@;V8@<F5S<&]N<V5S+@H@("`@("`@
M("`@("`@*B!4:&4@6S-=(&5L96UE;G0@<VAO=6QD(&)E('1H92!A9&1R97-S
M(&)O;VL@;F%M90H@("`@("`@("`@("`@*B!;-%T@86YD(%LU72!W:6QL(&)E
M('5S97(O9W)O=7`@;F%M92!A;F0@<&5R;6ES<VEO;G,@*B\*"B`@("`@("`@
M("`@("\O=&AE(&)O;VL@;F%M92!M:6=H="!B92!A(&QI=&5R86P*("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H24U34%]/0U1%5%]#3U5.5"P@)')E<W!O
M;G-E+"`D=&5M<$%R<F%Y*2D@>PH@("`@("`@("`@("`@("`@)&1A=&$@/2`D
M=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I;F=,:71E<F%L*"1T96UP07)R87E;
M,ETI.PH@("`@("`@("`@("`@("`@+R]'970@=&AE(')E<W0*("`@("`@("`@
M("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D
M92@G("<L("1R97-P;VYS92D["@H@("`@("`@("`@("`O+R!0=7-H('1H92!A
M<G)A>2!I9B!B;V]K('=A<R!A(&QI=&5R86P*("`@("`@("`@("`@:68@*"1D
M871A*2!["B`@("`@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1P87)T<RP@
M)R`G+"`G("<L("<@)RP@)R`G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`O+R!!9&1R97-S(&)O;VL@;F%M92!Q=6]T960_"B`@("`@("`@("`@("1N
M=6U087)T<R`](&-O=6YT*"1P87)T<RD["B`@("`@("`@("`@("1N86UE(#T@
M)'!A<G1S6S-=.PH@("`@("`@("`@("`D9FER<W1!0TQ)9'@@/2`T.PH@("`@
M("`@("`@("`D9FER<W1#:&%R(#T@<W5B<W1R*"1N86UE+"`P+"`Q*3L*("`@
M("`@("`@("`@:68@*"1F:7)S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#0[("1I(#P@)&YU;5!A<G1S.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@<W5B<W1R*"1P87)T<ULD
M:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M(#$L(#$I.PH@("`@("`@("`@("`@
M("`@("`@("1F:7)S=$%#3$ED>"LK.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D;&%S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H)&D@/2`D9FER
M<W1!0TQ)9'@[("1I(#P@8V]U;G0H)'!A<G1S*3L@)&D@*ST@,BD@>PH@("`@
M("`@("`@("`@("`@)')E<W5L='-;)'!A<G1S6R1I75T@/2`D<&%R='-;)&DK
M,5T["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-P;VYS92`]("1T
M:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@?2!W:&EL92`H
M<')E9U]M871C:"@B+UY<*B!!0TP@041$4D534T)/3TLO(BP@)')E<W!O;G-E
M*2D["@H@("`@("`@("\O($AO<&5F=6QL>2!W92!C86X@<F5C96EV92!A;B!/
M2R!R97-P;VYS92!H97)E"B`@("`@("`@:68@*"1R97-P;VYS92`A/2`G3TLG
M*2!["B`@("`@("`@("`@("\O(%-O;64@=V5I<F0@<')O8FQE;0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@
M<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R
M+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]I;7-P+3YW<FET951O3&]G*")'151!0TP@;VX@)&%B;V]K(&-O;7!L
M971E9"XB+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@(')E='5R
M;B`D<F5S=6QT<SL*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%N
M($%#3"!E;G1R>2!F;W(@86X@861D<F5S<R!B;V]K+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%B;V]K($YA;64@;V8@=&AE(&%D9')E<W,@8F]O
M:RX*("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT($YA;64@;V8@96YT<GD@
M=&\@<F5M;W9E(&%C;"!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!T<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&5L971E04-,*"1A8F]O:RP@)&ED96YT*0H@
M("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*"=$14Q%5$5!0TP@041$4D534T)/3TL@)RP@=')U92P@9F%L<V4I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!$
M;R!W92!N965D(&QI=&5R86P@9F]R(&%D9')E<W,@8F]O:R!N86UE/PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B
M;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L
M('-T<FQE;B@D86)O;VLI*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED
M(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E
M<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K("(L(&9A;'-E+"!F86QS92D["@H@
M("`@("`@("\O($QI=&5R86P@9F]R(&ED96YT(&YA;64_"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D:61E;G0I*2![
M"B`@("`@("`@("`@("1B:4ED96YT(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE
M;B@D:61E;G0I*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N
M9"@D8FE)9&5N="P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*"%P
M<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@
M<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS
M92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@D:61E;G0L(&9A;'-E+"!T<G5E*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*")<(B1I9&5N=%PB
M(BP@9F%L<V4L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T(')E
M<W5L=',N"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@<W=I=&-H("@D<V5R=F5R7W)E
M<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N
M86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D
M:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H
M:7,M/E]I;7-P+3YW<FET951O3&]G*")$14Q%5$5$($%#3"!F;W(@)&ED96YT
M(&]N("1A8F]O:R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO
M="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V
M97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A;B!!0TP@<W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(')I9VAT<R!F;W(@=&AE(&-U<G)E;G0@=7-E<@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%B;V]K($YA;64@;V8@861D<F5S<R!B;V]K('1O
M(')E=')I979E(&%C;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(&%C
M;"!O9B!C=7)R96YT('5S97(@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!M>5)I9VAT<R@D86)O;VLI"B`@("!["B`@
M("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@G35E224=(5%,@041$4D534T)/3TL@)RP@=')U92P@
M9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL
M("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H(GLE
M9'TB+"!S=')L96XH)&%B;V]K*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH*("`@("`@("`@
M("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H
M)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO
M;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H)&%B;V]K+"!F86QS92P@=')U92D["B`@
M("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E
M8V5I=F4H*3L*"B`@("`@("`@<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2![
M"B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P
M97)F;W)M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*
M("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N
M9&5R<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"H@35E2
M24=(5%,@041$4D534T)/3TLO(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@
M;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E
M<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M("\O('M](&9O<B!T:&4@86)O;VL@;F%M93\*("`@("`@("!I9B`H<')E9U]M
M871C:"A)35-07T]#5$547T-/54Y4+"`D<V5R=F5R7W)E<W!O;G-E+"`D=&5M
M<$%R<F%Y*2D@>PH@("`@("`@("`@("`D9&%T82`]("1T:&ES+3Y?:6US<"T^
M<F5C96EV95-T<FEN9TQI=&5R86PH)'1E;7!!<G)A>5LR72D["B`@("`@("`@
M("`@("\O($=E="!T:&4@<F5S="X*("`@("`@("`@("`@)'-E<G9E<E]R97-P
M;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!]
M"@H@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R`G+"`D<V5R=F5R7W)E<W!O
M;G-E*3L*"B`@("`@("`@+R\@4'5S:"!T:&4@87)R87D@:68@=V4@:&%D(&$@
M>WT*("`@("`@("!I9B`H)&1A=&$I('L*("`@("`@("`@("`@87)R87E?=6YS
M:&EF="@D<&%R=',L("<@)RP@)R`G+"`G("<L("<@)RD["B`@("`@("`@?0H*
M("`@("`@("`O+R!1=6]T960@861D<F5S<R!B;V]K(&YA;64_"B`@("`@("`@
M)&YU;5!A<G1S(#T@8V]U;G0H)'!A<G1S*3L*("`@("`@("`D;F%M92`]("1P
M87)T<ULS73L*("`@("`@("`D9FER<W1!0TQ)9'@@/2`T.PH@("`@("`@("1F
M:7)S=$-H87(@/2!S=6)S='(H)&YA;64L(#`L(#$I.PH@("`@("`@(&EF("@D
M9FER<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@9F]R("@D:2`](#0[
M("1I(#P@)&YU;5!A<G1S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D;&%S
M=$-H87(@/2!S=6)S='(H)'!A<G1S6R1I72P@<W1R;&5N*"1P87)T<ULD:5TI
M("T@,2P@,2D["B`@("`@("`@("`@("`@("`D9FER<W1!0TQ)9'@K*SL*("`@
M("`@("`@("`@("`@(&EF("@D;&%S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D86-L(#T@)'!A<G1S6R1F:7)S
M=$%#3$ED>%T["B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?
M:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@:68@*"1S97)V97)?<F5S
M<&]N<V4@(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@
M<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M=W)I=&54;TQO9R@B35E224=(5%,@;VX@)&%B;V]K(&-O;7!L971E9"XB+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@(')E='5R
M;B`D86-L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE(&QO9R!I;F9O<FUA=&EO;B!I;B!T:&4@3F5T7TE-4U`@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2`@87)R87D@($QO9R!P87)A;65T97)S+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$QO9V=E<B@D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VEM<W`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/G-E=$QO9V=E<B@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(I*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!087)S97,@82!)35-0(&9E=&-H861D<F5S<R!R
M97-P;VYS92!T97AT('-T<FEN9R!I;G1O"B`@("`@*B!K97DM=F%L=64@<&%I
M<G,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A
M;2`@<W1R:6YG("`D<V5R=F5R7W)E<W!O;G-E(%1H92!R87<@9F5T8VAA9&1R
M97-S(')E<W!O;G-E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@("!!
M9&1R97-S(&)O;VL@96YT<GD@:6YF;W)M871I;VX@87,@:V5Y/3YV86QU92!P
M86ER<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E1F5T8VA!9&1R97-S
M4F5S<&]N<V4H)'-E<G9E<E]R97-P;VYS92D*("`@('L*("`@("`@("`D86)O
M;VL@/2`G)SL*"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPJ($9%5$-(
M041$4D534R`O(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=;15)23U)=($1I9"!N;W0@<F5C
M96EV92!A($9%5$-(041$4D534R!R97-P;VYS92!F<F]M('-E<G9E<BXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH*("`@("`@("`@("`@)'1H:7,M
M/E]I;7-P+3YE>&ET0V]D92`]("=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!.3U1%4PH@("`@
M("`@("`J(%!A<G-E(&]U="!T:&4@<V5R=F5R(')E<W!O;G-E('-T<FEN9PH@
M("`@("`@("`J"B`@("`@("`@("H@069T97(@8VAO<&EN9R!O9F8@=&AE('-E
M<G9E<B!C;VUM86YD(')E<W!O;G-E('1A9W,@86YD"B`@("`@("`@("H@97AP
M;&]D92@I)VEN9R!T:&4@<V5R=F5R7W)E<W!O;G-E('-T<FEN9PH@("`@("`@
M("`J('1H92`D<&%R=',@87)R87D@8V]N=&%I;G,@=&AE(&-H=6YK<R!O9B!T
M:&4@<V5R=F5R(')E='5R;F5D(&1A=&$N"B`@("`@("`@("H*("`@("`@("`@
M*B!4:&4@<')E9&EF:6YE9"`G;F%M92<@9FEE;&0@<W1A<G1S(&EN("1P87)T
M<ULQ72X*("`@("`@("`@*B!4:&4@<V5R=F5R('-H;W5L9"!R971U<FX@86YY
M('-I;F=L92!I=&5M(&]F(&1A=&$*("`@("`@("`@*B!T:&%T(&-O;G1A:6YS
M('-P86-E<R!W:71H:6X@:70@87,@82!D;W5B;&4@<75O=&5D('-T<FEN9RX*
M("`@("`@("`@*B!3;R!W92!C86X@:6YT97)P<F5T('1H92!E>&ES=&5N8V4@
M;V8@82!D;W5B;&4@<75O=&4@870@=&AE(&)E9VEN;FEN9PH@("`@("`@("`J
M(&]F(&$@8VAU;FL@=&\@;65A;B!T:&%T('1H92!N97AT(&-H=6YK*',I(&%R
M92!P87)T(&]F"B`@("`@("`@("H@=&AE('-A;64@=F%L=64N("!!(&1O=6)L
M92!Q=6]T92!A="!T:&4@96YD(&]F(&$@8VAU;FL@<VEG;FEF:65S('1H90H@
M("`@("`@("`J(&5N9"!O9B!T:&%T('9A;'5E(&%N9"!T:&4@8VAU;FL@9F]L
M;&]W:6YG('1H870@8V%N(&)E(&EN=&5R<')E=&5D"B`@("`@("`@("H@87,@
M82!K97D@;F%M92X*("`@("`@("`@*@H@("`@("`@("`J(%=E(&%L<V\@;F5E
M9"!T;R!W871C:"!F;W(@=&AE('-E<G9E<B!R971U<FYI;F<@82![?2!R97-P
M;VYS92!F;W(@=&AE"B`@("`@("`@("H@=F%L=64@;V8@=&AE(&ME>2!A<R!W
M96QL+B`J+PH*("`@("`@("`O+R!787,@=&AE(&%D9')E<W,@8F]O:R!N86UE
M(&$@('M]/PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O*%Y<*B!&151#2$%$
M1%)%4U,@*2A[*2A;,"TY77LQ+'TI*%Q])"DO(BP*("`@("`@("`@("`@("`@
M("`@("`@("`D<V5R=F5R7W)E<W!O;G-E+"`D=&5M<$%R<F%Y*2D@>PH@("`@
M("`@("`@("`D86)O;VL@/2`D=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I;F=,
M:71E<F%L*"1T96UP07)R87E;,UTI.PH@("`@("`@("`@("`D8VAO<'!E9%]R
M97-P;VYS92`]('1R:6TH)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!486ME(&]F9B!T:&4@
M<W1U9F8@9G)O;2!T:&4@8F5G:6YN:6YG(&]F('1H92!R97-P;VYS90H@("`@
M("`@("`@("`D8VAO<'!E9%]R97-P;VYS92`]('1R:6TH<')E9U]R97!L86-E
M*"(O7EPJ($9%5$-(041$4D534R`O(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP@)'-E<G9E<E]R97-P
M;VYS92DI.PH@("`@("`@('T*"B`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G
M("<L("1C:&]P<&5D7W)E<W!O;G-E*3L*("`@("`@("`O*B!)9B!A9&1R97,@
M8F]O:R!W87,@<V5N="!A<R!A('M]('1H96X@=V4@;75S="`G<'5S:"<@82!B
M;&%N:PH@("`@("`@("`J('9A;'5E('1O('1H92!S=&%R="!O9B!T:&ES(&%R
M<F%Y('-O('1H92!R97-T(&]F('1H92!R;W5T:6YE"B`@("`@("`@("H@=VEL
M;"!W;W)K('=I=&@@=&AE(&-O<G)E8W0@:6YD97AE<RX@*B\*("`@("`@("`@
M:68@*"%E;7!T>2@D86)O;VLI*2!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI
M9G0H)'!A<G1S+"`G("<I.PH@("`@("`@('T*"B`@("`@("`@+R\@5V%S('1H
M92!A9&1R97-S(&)O;VL@;F%M92!Q=6]T960_"B`@("`@("`@)&YU;4]F4&%R
M=',@/2!C;W5N="@D<&%R=',I.PH@("`@("`@("1N86UE(#T@)'!A<G1S6S!=
M.PH@("`@("`@("1F:7)S=$YA;65)9'@@/2`Q.PH@("`@("`@("1F:7)S=$-H
M87(@/2!S=6)S='(H)&YA;64L(#`L(#$I.PH@("`@("`@(&EF("@D9FER<W1#
M:&%R(#T](EPB(BD@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"`D
M;G5M3V9087)T<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&QA<W1#:&%R
M(#T@<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M(#$L
M(#$I.PH@("`@("`@("`@("`@("`@)&9I<G-T3F%M94ED>"LK.PH@("`@("`@
M("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`B7"(B*2!["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\O($YO=R!S=&%R="!W;W)K:6YG(&]N
M('1H92!E;G1R>2!N86UE"B`@("`@("`@)&YA;64@/2`D<&%R='-;)&9I<G-T
M3F%M94ED>%T["B`@("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92PP
M+#$I.PH*("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=&AE(&9I<G-T(&-H
M87(@;V8@=&AE(&YA;64@<W1R:6YG(&ES(&$@9&]U8FQE('%U;W1E"B`@("`@
M("`@+R\@<V\@=V4@:VYO=R!I9B!W92!H879E('1O(&5X=')A8W0@;6]R92!O
M9B!T:&4@;F%M92X*("`@("`@("!I9B`H)&9I<G-T0VAA<B`]/2`B7"(B*2![
M"B`@("`@("`@("`@("1N86UE(#T@;'1R:6TH)&YA;64L(")<(B(I.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@)&9I<G-T3F%M94ED>"`K(#$[("1I(#P@)&YU
M;4]F4&%R=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1N86UE("X]("`G
M("<@+B`D<&%R='-;)&E=.PH@("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@
M<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M(#$L,2D[
M"B`@("`@("`@("`@("`@("!I9B`H)&QA<W1#:&%R(#T](")<(B(I('L*("`@
M("`@("`@("`@("`@("`@("`D;F%M92`](')T<FEM*"1N86UE+"`B7"(B*3L*
M("`@("`@("`@("`@("`@("`@("`D;F5X=$ME>2`]("1I("L@,3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@>WT*("`@("`@("!](&5L
M<V5I9B`H<')E9U]M871C:"@G+UQ[*%QD*RE<?2\G+"`D;F%M92P@)&UA=&-H
M97,I*2!["B`@("`@("`@("`@("1N86UE(#T@)'1H:7,M/E]I;7-P+3YR96-E
M:79E4W1R:6YG3&ET97)A;"@D;6%T8VAE<ULQ72D["B`@("`@("`@("`@("1R
M97-P;VYS93TD=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@
M("`@("1P87)T<R`](&5X<&QO9&4H)R`G+"`D<F5S<&]N<V4I.PH@("`@("`@
M("`@("`D;G5M3V9087)T<R`](&-O=6YT*"1P87)T<RD["B`@("`@("`@("`@
M("1N97AT2V5Y(#T@,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!)9B!O;FQY(&]N92!C:'5N:R!F;W(@)VYA;64G('1H96X@=V4@:G5S="!H
M879E('1O('!O:6YT"B`@("`@("`@("`@("\O('1O('1H92!N97AT(&-H=6YK
M(&EN('1H92!A<G)A>2XN+G=H:6-H('=I;&P@:&]P969U;&QY"B`@("`@("`@
M("`@("\O(&)E("<R)PH@("`@("`@("`@("`D;F5X=$ME>2`]("1F:7)S=$YA
M;65)9'@@*R`Q.PH@("`@("`@('T*"B`@("`@("`@)&QA<W1#:&%R(#T@)R<[
M"B`@("`@("`@)&5N=')Y6R=N86UE)UT@/2`D;F%M93L*"B`@("`@("`@+R\@
M4W1A<G0@<&%R<VEN9R!T:&4@<F5S="!O9B!T:&4@<F5S<&]N<V4N"B`@("`@
M("`@9F]R("@D:2`]("1N97AT2V5Y.R`D:2`\("1N=6U/9E!A<G1S.R`D:2`K
M/2`R*2!["B`@("`@("`@("`@("1K97D@/2`D<&%R='-;)&E=.PH@("`@("`@
M("`@("`O*B!#:&5C:R!F;W(@>WT@*B\*("`@("`@("`@("`@:68@*$!P<F5G
M7VUA=&-H*$E-4U!?3T-4151?0T]53E0L("1P87)T<ULD:2LQ72P@)'1E;7!!
M<G)A>2DI('L*("`@("`@("`@("`@("`@("1S97)V97)?9&%T82`]("1T:&ES
M+3Y?:6US<"T^<F5C96EV95-T<FEN9TQI=&5R86PH)'1E;7!!<G)A>5LR72D[
M"B`@("`@("`@("`@("`@("`D96YT<GE;)&ME>5T@/2`D<V5R=F5R7V1A=&$[
M"@H@("`@("`@("`@("`@("`@+RH@4F5A9"!A;GD@<F5M86EN:6YG(&1A=&$@
M9G)O;2!T:&4@<W1R96%M(&%N9"!R97-E=`H@("`@("`@("`@("`@("`@("H@
M=&AE(&-O=6YT97(@=F%R:6%B;&5S('-O('1H92!L;V]P('=I;&P@8V]N=&EN
M=64*("`@("`@("`@("`@("`@("`J(&-O<G)E8W1L>2X@3F]T92!W92!S970@
M)&D@('1O("TR(&)E8V%U<V4@:70@=VEL;`H@("`@("`@("`@("`@("`@("H@
M8F4@:6YC<F5M96YT960@8GD@,B!B969O<F4@=&AE(&QO;W`@=VEL;"!R=6X@
M86=A:6X@*B\*("`@("`@("`@("`@("`@("1P87)T<R`]("1T:&ES+3Y?:6US
M<"T^9V5T4V5R=F5R4F5S<&]N<V5#:'5N:W,H*3L*("`@("`@("`@("`@("`@
M("1I(#T@+3(["B`@("`@("`@("`@("`@("`D;G5M3V9087)T<R`](&-O=6YT
M*"1P87)T<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`O+R!.;W0@82!S=')I;F<@;&ET97)A;"!R97-P;VYS90H@("`@("`@("`@
M("`@("`@0"1E;G1R>5LD:V5Y72`]("1P87)T<ULD:2`K(#%=.PH@("`@("`@
M("`@("`@("`@("\O($-H96-K('1O('-E92!I9B!T:&4@=F%L=64@<W1A<G1E
M9"!W:71H(&$@9&]U8FQE"B`@("`@("`@("`@("`@("`@+R\@<75O=&4N("!7
M92!A;'-O(&YE960@=&\@8VAE8VL@:68@=&AE(&QA<W0@8VAA<B!I<R!A"B`@
M("`@("`@("`@("`@("`@+R\@<75O=&4@=&\@;6%K92!S=7)E('=E(%)%04Q,
M62!H879E('1O(&-H96-K('1H92!N97AT"B`@("`@("`@("`@("`@("`@+R\@
M96QE;65N=',@9F]R(&$@8VQO<VEN9R!Q=6]T92X*("`@("`@("`@("`@("`@
M(&EF("@H0'-U8G-T<B@D<&%R='-;)&D@*R`Q72P@,"P@,2D@/3T@)R(G*2`F
M)@H@("`@("`@("`@("`@("`@("`@("AS=6)S='(H)'!A<G1S6R1I("L@,5TL
M"B`@("`@("`@("`@("`@("`@("`@('-T<FQE;B@D<&%R='-;)&D@*R`Q72D@
M+2`Q+"`Q*2`A/2`G(B<I*2!["@H@("`@("`@("`@("`@("`@("`@(&1O('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&YE>'1%;&5M96YT(#T@)'!A<G1S
M6R1I*S)=.PH*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V%S('1H:7,@
M96QE;65N="!T:&4@;&%S="!O;F4_"B`@("`@("`@("`@("`@("`@("`@("`@
M("1L87-T0VAA<B`]('-U8G-T<B@D;F5X=$5L96UE;G0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')L96XH)&YE>'1%
M;&5M96YT*2`M(#$L(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT
M<GE;)&ME>5T@+CT@)R`G("X@)&YE>'1%;&5M96YT.PH*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@3D]7+"!W92!C86X@8VAE8VL@=&AE(&QA<W1#:&%R
M+@H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&QA<W1#:&%R(#T]("<B
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1O;F4@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O($-H96-K('1O('-E92!I9B!T:&4@;F5X="!E;&5M96YT(&ES
M('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@;&%S="!O;F4N
M($EF('-O+"!T:&4@9&\@;&]O<"!W:6QL('1E<FUI;F%T92X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D;VYE(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;&%S=$-H87(@/2!S=6)S='(H)'!A<G1S6R1I
M*S-=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<FQE;B@D<&%R='-;)&DK,UTI("T@,2PQ*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]('=H:6QE("@D;&%S=$-H87(@
M(3T@)R(G*3L*"B`@("`@("`@("`@("`@("`@("`@+R\@1&\@=V4@;F5E9"!T
M;R!A9&0@=&AE(&9I;F%L(&5L96UE;G0L(&]R('=E<F4*("`@("`@("`@("`@
M("`@("`@("`O+R!T:&5R92!O;FQY('1W;R!T;W1A;#\*("`@("`@("`@("`@
M("`@("`@("!I9B`H(21D;VYE*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1N97AT16QE;65N="`]("1P87)T<ULD:2LR73L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N=')Y6R1K97E=("X]("<@)R`N("1N97AT16QE;65N=#L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\O(%)E;6]V92!T:&4@<75O
M=&5S('-E;G0@8F%C:R!T;R!U<R!F<F]M('1H92!S97)V97(N"B`@("`@("`@
M("`@("`@("`@("`@:68@*'-U8G-T<B@D96YT<GE;)&ME>5TL(#`L(#$I(#T]
M("<B)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)&ME>5T@
M/2!S=6)S='(H)&5N=')Y6R1K97E=+"`Q+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1E;G1R>5LD:V5Y
M72D@+2`R*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@(&EF("AS=6)S='(H)&5N=')Y6R1K97E=+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W1R;&5N*"1E;G1R>5LD:V5Y72D@+2`Q+"`Q
M*2`]/2`G(B<I('L*"B`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5LD
M:V5Y72`]('-U8G-T<B@D96YT<GE;)&ME>5TL(#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')L96XH)&5N=')Y
M6R1K97E=*2`M(#(I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@)&5N=')Y.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U3
M4"]5=&EL<RYP:'``````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3`V,3$`,3`U,34T,S$P-C$`,#(P,C8Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!.971?24U3
M4%]5=&EL<SHZ"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-
M4U`O571I;',N<&AP+'8@,2XS+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HR."!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%)U
M8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO
M<F<^"B`J($!P86-K86=E($YE=%])35-0"B`J+PIC;&%S<R!.971?24U34%]5
M=&EL<R!["@H@("`@+RHJ"B`@("`@*B!5=&EL:71Y(&9U;F-T:6]N('1O(')E
M=')I979E('1H92!N86UE<R!O9B!A;&P@=&AE(&%D9')E<W,@8F]O:W,*("`@
M("`J('1H870@=&AE('5S97(@:&%S(&%C8V5S<R!T;RP@86QO;F<@=VET:"!T
M:&4@86-L(&9O<B!T:&]S90H@("`@("H@8F]O:W,N("!&;W(@:6YF;W)M871I
M;VX@86)O=70@=&AE("1S97)V97));F9O(&%R<F%Y('-E90H@("`@("H@='5R
M8F$O8V]N9FEG+W-O=7)C97,N<&AP(&%S('1H:7,@:7,@=&AE(&-F9U-O=7)C
M97-;72!E;G1R>2!F;W(*("`@("`J('1H92!A9&1R97-S(&)O;VMS+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<V5R=F5R26YF;R`@26YF;W)M871I
M;VX@86)O=70@=&AE('-E<G9E<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A;F0@=&AE(&-U<G)E;G0@=7-E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!);F9O<FUA=&EO;B!A8F]U="!A;&P@=&AE(&%D9')E
M<W,@8F]O:W,@;W(@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T06QL0F]O:W,H)'-E<G9E<DEN9F\I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=.970O24U34"YP:'`G.PH@("`@("`@("1F;W5N9$1E9F%U;'0@
M/2!F86QS93L*("`@("`@("`D<F5S=6QT<R`](&%R<F%Y*"D["B`@("`@("`@
M)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O;B@G0F]O:R<L("1S97)V97))
M;F9O6R=P87)A;7,G72D["B`@("`@("`@)')E<W5L="`]("1I;7-P+3YI;FET
M*"D["@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("`D8F]O:W,@/2`D:6US<"T^9V5T061D<F5S<T)O;VM,:7-T*"D["B`@
M("`@("`@:68@*&ES7V$H)&)O;VMS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8F]O:W,["B`@("`@("`@?0H*("`@("`@("`D8D-O
M=6YT(#T@8V]U;G0H)&)O;VMS*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D8D-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1N97=";V]K(#T@)'-E
M<G9E<DEN9F\["B`@("`@("`@("`@(&EF("@D8F]O:W-;)&E=("$]("1S97)V
M97));F9O6R=P87)A;7,G75LG=7-E<FYA;64G72D@>PH@("`@("`@("`@("`@
M("`@)&YE=T)O;VM;)W1I=&QE)UT@/2`G24U34%\G("X@)&)O;VMS6R1I73L*
M("`@("`@("`@("`@("`@("1N97=";V]K6R=P87)A;7,G75LG;F%M92==(#T@
M)&)O;VMS6R1I73L*("`@("`@("`@("`@("`@("1N97=";V]K6R=P87)A;7,G
M75LG:7-?<F]O="==(#T@9F%L<V4["B`@("`@("`@("`@("`@("`D;F5W0F]O
M:ULG<&%R86US)UU;)VUY7W)I9VAT<R==(#T@)&EM<W`M/FUY4FEG:'1S*"1B
M;V]K<ULD:5TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&9O=6YD1&5F875L="`]('1R=64["B`@("`@("`@("`@("`@("`D;F5W
M0F]O:ULG<&%R86US)UU;)VUY7W)I9VAT<R==(#T@)&EM<W`M/FUY4FEG:'1S
M*"1B;V]K<ULD:5TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U
M;'1S6UT@/2`D;F5W0F]O:SL*("`@("`@("!]"B`@("`@("`@+RH@268@=&AE
M<F4@:7,@;F\@9&5F875L="!A9&1R97-S(&)O;VL@*&YA;65D('5S97)N86UE
M*2!T:&5N('=E('-H;W5L9"!C<F5A=&4@;VYE+B`J+PH@("`@("`@(&EF("@A
M)&9O=6YD1&5F875L="D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)&EM<W`M
M/F-R96%T94%D9')E<W-";V]K*"1S97)V97));F9O6R=P87)A;7,G75LG=7-E
M<FYA;64G72D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=,;V=I;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SH@1&5F875L="!A
M9&1R97-S(&)O;VL@:7,@;6ES<VEN9R!A;F0@8V]U;&0@;F]T(&)E(&-R96%T
M960N)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R97-U;'1S.PH@("`@?0H*("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC
M=&EO;B!T;R!M86ME(&ET(&5A<VEE<B!F;W(@8VQI96YT(&%P<&QI8V%T:6]N
M<R!T;R!D96QE=&4*("`@("`J(&%D9')E<W,@8F]O:W,@=VET:&]U="!H879I
M;F<@=&\@8W)E871E(&EM<W`@9')I=F5R<RX@(%1H92`D<V]U<F-E(&%R<F%Y
M"B`@("`@*B!I<R!A(&AO<F1E+W1U<F)A('-T>6QE("1C9F=3;W5R8V5S(&5N
M=')Y(&9O<B!T:&4@861D<F5S<R!B;V]K(&)E:6YG"B`@("`@*B!D96QE=&5D
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<V]U<F-E("!);F9O<FUA
M=&EO;B!A8F]U="!T:&4@861D<F5S<R!B;V]K(&)E:6YG(&1E;&5T960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&5L971E0F]O:R@D<V]U<F-E*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC
M92`G3F5T+TE-4U`N<&AP)SL*("`@("`@("`D:6US<"`]("9.971?24U34#HZ
M<VEN9VQE=&]N*"=";V]K)RP@)'-O=7)C95LG<&%R86US)UTI.PH@("`@("`@
M("1R97-U;'0@/2`D:6US<"T^:6YI="@I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2`D:6US<"T^9&5L
M971E061D<F5S<T)O;VLH)'-O=7)C95LG<&%R86US)UU;)VYA;64G72D["B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5=&EL:71Y(&9U;F-T
M:6]N('1O(&AE;'`@8VQI96YT<R!C<F5A=&4@;F5W(&%D9')E<W,@8F]O:W,@
M=VET:&]U="!H879I;F<*("`@("`J('1O(&-R96%T92!A;B!I;7-P(&1R:79E
M<B!I;G-T86YC92!F:7)S="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'-O=7)C92`@("!);F9O<FUA=&EO;B!A8F]U="!T:&4@=7-E<B=S(&1E9F%U
M;'0@24U34`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@861D<F5S
M<R!B;V]K+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W3F%M92`@5&AE(&YA
M;64@;V8@=&AE(&YE=R!A9&1R97-S(&)O;VLN("!.;W1E('1H870@=&AI<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@:7,@875T;VUA=&EC86QL
M>2!Q=6%L:69I960@=VET:"!T:&4@=7-E<B=S(&YA;64*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('-O('-H;W5L9"!N;W0@8F4@<&%S<V5D(&%S
M(&$@9G5L;'D@<75A;&EF:65D($E-4U`*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&%D9')E<W,@8F]O:R!N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@('1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@("!F=6YC=&EO;B!C<F5A=&5";V]K*"1S
M;W5R8V4L("1N97=.86UE*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M3F5T+TE-4U`N<&AP)SL*("`@("`@("`D:6US<"`]("9.971?24U34#HZ<VEN
M9VQE=&]N*"=";V]K)RP@)'-O=7)C95LG<&%R86US)UTI.PH@("`@("`@("1R
M97-U;'0@/2`D:6US<"T^:6YI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H@("`@("`@("1N86UE(#T@)'-O=7)C95LG<&%R86US
M)UU;)W5S97)N86UE)UT@+B`G+B<@+B`D;F5W3F%M93L*("`@("`@("`D<F5S
M=6QT(#T@)&EM<W`M/F-R96%T94%D9')E<W-";V]K*"1N86UE*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+T]P=&EO;G,N
M<&AP````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-34V,@`Q
M,#4Q-30S,3`V,0`P,C`V,C8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3F5T+TE-4U`O
M075T:"YP:'`G.PH*+RHJ"B`J($YE=%])35-07T]P=&EO;G,@0VQA<W,@+2!P
M<F]V:61E<R!A;B!I;G1E<F9A8V4@=&\@24U34"!S97)V97(M8F%S960*("H@
M;W!T:6]N<R!S=&]R86=E+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP
M<F4^"B`J("`@)W5S97)N86UE)R`@("`@57-E<FYA;64@=&\@;&]G;VX@=&\@
M24U34"!S97)V97(@87,N"B`J("`@)W!A<W-W;W)D)R`@("`@4&%S<W=O<F0@
M9F]R(&-U<G)E;G0@=7-E<BX*("H@("`G875T:%]M971H;V0G("!4:&4@875T
M:&5N=&EC871I;VX@;65T:&]D('1O('5S92!T;R!L;V=I;BX*("H@("`G<V5R
M=F5R)R`@("`@("!4:&4@:&]S=&YA;64@;V8@=&AE($E-4U`@<V5R=F5R+@H@
M*B`@("=P;W)T)R`@("`@("`@(%1H92!P;W)T(&]F('1H92!)35-0('-E<G9E
M<BX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]/<'1I;VYS+G!H<"QV(#$N,RXR+C$V(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!2
M=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N
M;W)G/@H@*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?
M3W!T:6]N<R!["@H@("`@+RHJ"B`@("`@*B!.971?24U34"!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'9A<B!.971?24U34`H@("`@("HO"B`@("!V87(@)%]I
M;7-P.PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R(&QI<W0N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B!F=6YC=&EO;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@2&%S:"!C;VYT86EN:6YG($E-
M4U`@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@3F5T7TE-4U!?
M3W!T:6]N<R@D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI>F%T
M:6]N(&9U;F-T:6]N('1O(&)E(&-A;&QE9"!A9G1E<B!O8FIE8W0@:7,@<F5T
M=7)N960N"B`@("`@*B!4:&ES(&%L;&]W<R!E<G)O<G,@=&\@;V-C=7(@86YD
M(&YO="!B<F5A:R!T:&4@<V-R:7!T+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]I;7-P*2D@>PH@("`@("`@("`@("`D875T:"`]
M("9.971?24U34%]!=71H.CIS:6YG;&5T;VXH)'1H:7,M/E]P87)A;7-;)V%U
M=&A?;65T:&]D)UTI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`@/2`D875T
M:"T^875T:&5N=&EC871E*"1T:&ES+3Y?<&%R86US*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6US<"P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H)TYE=%])35-07T]P
M=&EO;G,@:6YI=&EA;&EZ960N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M=6YC=&EO;B!S96YD<R!A($=%5"!C;VUM86YD('1O($E-4U`@<V5R=F5R(&%N
M9"!R971R:65V97,@=F%L=65S+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R
M:6YG("1O<'1I;VY.86UE($YA;64@;V8@;W!T:6]N('1O(')E=')I979E+B!!
M8V-E<'1S("<J)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87,@=VEL9"!C87)D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($%S
M<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@;W!T:6]N/3YV86QU92!P86ER
M<R!O<@H@("`@("H@("`@("`@("`@("`@("`@4$5!4E]%<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T*"1O<'1I;VY.86UE*0H@("`@>PH@("`@("`@
M("1O<'1I;VYS(#T@87)R87DH*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]I;7-P+3YI;7-P4V5N9"@B1T54("1O<'1I;VY.86UE(BP@=')U92P@=')U
M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E
M:79E*"D["B`@("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P
M;VYS93L*("`@("`@("!]"@H@("`@("`@('=H:6QE("AP<F5G7VUA=&-H*"(O
M7EPJ($]05$E/3B\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@
M("`O*B!&:7)S="P@8VAE8VL@9F]R(&$@>WTN("HO"B`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*$E-4U!?3T-4151?0T]53E0L("1S97)V97)?<F5S<&]N
M<V4L("1T96UP07)R87DI*2!["B`@("`@("`@("`@("`@("`D=&5M<"`](&5X
M<&QO9&4H)R`G+"`D<V5R=F5R7W)E<W!O;G-E*3L*("`@("`@("`@("`@("`@
M("1O<'1I;VYS6R1T96UP6S)=72`]("1T:&ES+3Y?:6US<"T^<F5C96EV95-T
M<FEN9TQI=&5R86PH)'1E;7!!<G)A>5LR72D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&5M<"`](&5X<&QO9&4H)R`G+"`D<V5R
M=F5R7W)E<W!O;G-E*3L*("`@("`@("`@("`@("`@("1O<'1I;VYS6R1T96UP
M6S)=72`]('1R:6TH)'1E;7!;,UTI.PH@("`@("`@("`@("`@("`@)&D@/2`S
M.PH@("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@(B(["B`@("`@("`@("`@
M("`@("`D;F5X=$5L96UE;G0@/2!T<FEM*"1T96UP6S-=*3L*"B`@("`@("`@
M("`@("`@("`O*B!787,@=&AE('9A;'5E('%U;W1E9"!A;F0@<W!A8V5D/R`J
M+PH@("`@("`@("`@("`@("`@:68@*"AS=6)S='(H)&YE>'1%;&5M96YT+#`L
M,2D@/3T@)R(G*2`F)@H@("`@("`@("`@("`@("`@("`@("AS=6)S='(H)&YE
M>'1%;&5M96YT+'-T<FQE;B@D;F5X=$5L96UE;G0I("T@,2P@,2D@(3T@)R(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(&1O('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&YE>'1%;&5M96YT(#T@)'1E;7!;)&DK,5T["B`@("`@("`@
M("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D;F5X=$5L96UE
M;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')L96XH)&YE>'1%;&5M96YT*2`M(#$L(#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;W!T:6]N<ULD=&5M<%LR75T@+CT@)R`G("X@)&YE>'1%
M;&5M96YT.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&QA<W1#:&%R
M(#T]("<B)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1O;F4@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1O;F4@/2!F86QS93L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D=&5M
M<%LD:2LR72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')L96XH)'1E;7!;)&DK,ETI("T@,2P@,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@('T@=VAI;&4@*"1L87-T
M0VAA<B`A/2`G(B<I.PH*("`@("`@("`@("`@("`@("`@("!I9B`H(21D;VYE
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N97AT16QE;65N="`]("1T
M96UP6R1I*S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<ULD
M=&5M<%LR75T@+CT@)R`G("X@)&YE>'1%;&5M96YT.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4F5C96EV92@I.PH@("`@("`@("`@("!I9B`H:7-?82@D<V5R=F5R7W)E<W!O
M;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'-E<G9E<E]R97-P;VYS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"1S97)V97)?<F5S<&]N<V4@(3T@)T]+)RD@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@
M<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R
M+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]I;7-P+3YW<FET951O3&]G*"='150@8V]M;6%N9"!/2RXG+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U
M<FX@)&]P=&EO;G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!S
M971S(&%N(&]P=&EO;B!V86QU92!O;B!T:&4@24U34"!S97)V97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N3F%M92`@3F%M92!O9B!O
M<'1I;VX@=&\@<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N5F%L
M=64@5F%L=64@=&\@87-S:6=N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@5')U92!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M970H)&]P=&EO;DYA;64L("1O<'1I;VY686QU92D*("`@('L*("`@("`@("`O
M*B!396YD('1H92!B96=I;FYI;F<@;V8@=&AE(&-O;6UA;F0N("HO"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(E-%5"`D;W!T
M:6]N3F%M92`B+"!T<G5E+"!F86QS92D["@H@("`@("`@("\J(%-E;F0@)&]P
M=&EO;E9A;'5E(&%S(&$@;&ET97)A;"![?3\@*B\*("`@("`@("!I9B`H<')E
M9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1O<'1I;VY686QU92DI
M('L*("`@("`@("`@("`@)&)I5F%L=64@/2!S<')I;G1F*")[)61](BP@<W1R
M;&5N*"1O<'1I;VY686QU92DI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE686QU92P@9F%L<V4L('1R=64I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E
M:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD
M(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@3F]W('-E;F0@=&AE(')E<W0@;V8@=&AE(&-O;6UA;F0N
M("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&]P=&EO;E9A;'5E+"!F86QS92P@=')U92D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@(&EF("AI
M<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4["B`@("`@("`@?2!E;'-E
M:68@*"1S97)V97)?<F5S<&]N<V4@(3T@)T]+)RD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!O<'1I;VX@8V]U
M;&0@;F]T(&)E('-E="!O;B!T:&4@24U34"!S97)V97(N)RP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US<"T^
M=W)I=&54;TQO9R@G4T54(&-O;6UA;F0@3TLN)RP@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!L;V<@:6YF;W)M871I;VX@
M:6X@=&AE($YE=%])35-0(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@5&AE(&QO9R!P87)A;65T97)S+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!014%27T5R<F]R
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$QO9V=E<B@D
M<&%R86US*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VEM<W`I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/G-E=$QO9V=E
M<B@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0(&QO9R!C;W5L
M9"!N;W0@8F4@:6YI=&EA;&EZ960N)RD["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(&QO9V]U="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I;7-P
M+3YL;V=O=70H*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TYE="])35-0+T%U=&@N<&AP````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3`U-P`Q,#4Q-30S,3`V,0`P,C`P
M-C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G3F5T+TE-4U`N<&AP)SL*"B\J*@H@*B!4
M:&4@3F5T7TE-4U!?075T:"!C;&%S<R!A8G-T<F%C="!C;&%S<R!F;W(@24U3
M4"!A=71H96YT:6-A=&EO;BX*("H*("H@4F5Q=6ER960@4&%R86UE=&5R<SH\
M<')E/@H@*B`@("=U<V5R;F%M92<@(%5S97)N86UE('1O(&QO9V]N('1O($E-
M4U`@<V5R=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@(%!A<W-W;W)D(&9O<B!C
M=7)R96YT('5S97(N"B`J("`@)W-E<G9E<B<@("`@5&AE(&AO<W1N86UE(&]F
M('1H92!)35-0('-E<G9E<BX*("H@("`G<&]R="<@("`@("!4:&4@<&]R="!O
M9B!T:&4@24U34"!S97)V97(N/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`L=B`Q+C@N,3`N,3$@,C`P-B\P
M,2\P,2`R,3HR.#HR-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM
M<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K86=E($YE=%])35-0"B`J+PIC
M;&%S<R!.971?24U34%]!=71H('L*("`@("\J*@H@("`@("H@0VQA<W,@=F%R
M:6%B;&4@=&\@:&]L9"!T:&4@<F5S=6QT:6YG($YE=%])35-0(&]B:F5C=`H@
M("`@("H*("`@("`J($!V87(@3F5T7TE-4U`*("`@("`J+PH@("`@=F%R("1?
M:6US<#L*"B`@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!L;V=I;B!T;R!)
M35-0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@("`@("`@(%!A<F%M971E<G,@9F]R($YE=%])35-0"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;&]G:6X@("`@("`@(%-H;W5L9"!W92!R96UA:6X@;&]G
M9V5D(&EN(&%F=&5R(&%U=&@_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@("`@("`@("`@("`@("!2971U<FYS(&$@3F5T7TE-4U`@;V)J96-T(&-O
M;FYE8W1E9"!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@24U34"!S97)V97(@:68@;&]G:6X@:7,@=')U92!A;F0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W5C8V5S<V9U;"X@(%)E
M='5R;G,@8F]O;&5A;B!T<G5E(&EF"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-U8V-E<W-F=6P@86YD(&QO9VEN(&ES(&9A;'-E+B!2
M971U<FYS"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F%U
M=&AE;G1I8V%T92@D<&%R86US+"`D;&]G:6X@/2!T<G5E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:6US<"`]("8D=&AI<RT^7V%U=&AE;G1I8V%T92@D<&%R
M86US*3L*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]I;7-P+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(21L;V=I;BD@>PH@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FQO9V]U="@I.PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0<FEV871E(&%U=&AE;G1I8V%T:6]N(&9U
M;F-T:6]N+B!0<F]V:61E<R!A8W1U86P@875T:&5N=&EC871I;VX*("`@("`J
M(&-O9&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@(&%R<F%Y("`@)'!A<F%M<R`@("`@(%!A<F%M971E<G,@9F]R($YE
M=%])35-07T%U=&@@9')I=F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@("`@("`@("`@("`@("`@4F5T=7)N<R!.971?24U34"!O8FIE8W0@8V]N
M;F5C=&5D('1O('-E<G9E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B!S=6-C97-S9G5L+"!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A=71H
M96YT:6-A=&4H)'!A<F%M<RD*("`@('L*"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!T>7!E(&]F('1H:7,@9')I=F5R+@H@("`@("H*("`@
M("`J($!A8G-T<F%C=`H@("`@("H@0')E='5R;B!S=')I;F<@5'EP92!O9B!)
M35-07T%U=&@@9')I=F5R(&EN<W1A;F-E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$1R:79E<E1Y<&4H*0H@("`@>PH*("`@('T*"B`@("`O*BH*("`@("`J
M($9O<F-E(&$@;&]G;W5T(&9R;VT@=&AE('5N9&5R;'EI;F<@24U34"!S=')E
M86TN"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V=O=70H*0H@("`@
M>PH*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(&-O;F-R971E($YE=%])35-07T%U=&@@:6YS=&%N8V4@8F%S960@;VX@)&1R
M:79E<@H@("`@("H@375S="!B92!C86QL960@87,@)DYE=%])35-07T%U=&@Z
M.F9A8W1O<GDH*0H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("1D<FEV
M97(@5'EP92!O9B!.971?24U34%]!=71H('-U8F-L87-S('1O(')E='5R;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8W)E871E9"!.971?
M24U34%]!=71H('-U8F-L87-S(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(I"B`@("!["B`@("`@("`@)&1R
M:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H96UP='DH
M)&1R:79E<BD@?'P@*'-T<F-M<"@D9')I=F5R+"`G;F]N92<I(#T](#`I*2![
M"B`@("`@("`@("`@("1A=71H(#T@)FYE=R!)35-07T%U=&@H*3L*("`@("`@
M("`@("`@<F5T=7)N("1A=71H.PH@("`@("`@('T*"B`@("`@("`@:68@*&9I
M;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]!=71H+R<@+B`D9')I
M=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+T%U=&@O)R`N("1D<FEV97(@+B`G+G!H<"<[
M"B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G3F5T7TE-4U!?075T:%\G
M("X@)&1R:79E<CL*"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I
M*2!["B`@("`@("`@("`@("1A=71H(#T@)FYE=R`D8VQA<W,H*3L*("`@("`@
M("`@("`@<F5T=7)N("1A=71H.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(BDL("1C;&%S
M<RDI+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($YE
M=%])35-07T%U=&@@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J
M(%=I;&P@;VYL>2!C<F5A=&4@82!N97<@;V)J96-T(&EF(&]N92!W:71H('1H
M92!S86UE('!A<F%M971E<G,@86QR96%D>0H@("`@("H@9&]E<R!N;W0@97AI
M<W0N"B`@("`@*B!-=7-T(&)E(&-A;&QE9"!L:6ME.B`D=F%R(#T@)DYE=%])
M35-07T%U=&@Z.G-I;F=L971O;B@G9')I=F5R7W1Y<&4G*3L*("`@("`J"B`@
M("`@*B!`<&%R86T@('-T<FEN9R`D9')I=F5R(%1Y<&4@;V8@24U34%]!=71H
M('-U8F-L87-S('1O(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="!2969E<F5N8V4@=&\@24U34%]!=71H('-U8F-L87-S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(I"B`@("!["B`@("`@
M("`@<W1A=&EC("1I;G-T86YC97,["B`@("`@("`@+RH@0VAE8VL@9F]R(&%N
M>2!I;71E<W0@9')I=F5R(&EN<W1A;F-E<R!A;F0@:VEL;"!T:&5M+@H@("`@
M("`@("`@($]T:&5R=VES92P@=&AE('-O8VME="!W:6QL(&AA;F<@8F5T=V5E
M;B!R97%U97-T<R!F<F]M"B`@("`@("`@("`@<V5P97)A=&4@9')I=F5R<R`H
M86X@075T:"!R97%U97-T(&%N9"!A;B!/<'1I;VYS(')E<75E<W0I+BHO"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1I;G-T86YC97,@87,@)&]B:BD@>PH@("`@("`@("`@("`@
M("`@:68@*"1O8FHM/F=E=$1R:79E<E1Y<&4H*2`]/2`G:6UT97-T)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1O8FHM/FQO9V]U="@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`]
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R
M:6%L:7IE*&%R<F%Y*"1D<FEV97(I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC
M97-;)'-I9VYA='5R95T@/2`F3F5T7TE-4U!?075T:#HZ9F%C=&]R>2@D9')I
M=F5R*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B].970O4TU3+G!H<```````````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C4R,30`,3`U,34T,S$P
M-C$`,#$W,#8P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@H@
M*B!.971?4TU3($-L87-S"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R
M:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<"QV(#$N,3`N,3`N
M,3`@,C`P-B\P,2\P,2`R,3HR.#HR."!J86X@17AP("0*("H*("H@0&%U=&AO
M<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@
M3F5T7U--4PH@*B\*8VQA<W,@3F5T7U--4R!["@H@("`@+RHJ"B`@("`@*B!!
M(&AA<V@@8V]N=&%I;FEN9R!A;GD@<&%R86UE=&5R<R!F;W(@=&AE(&-U<G)E
M;G0@9V%T97=A>2!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@('9A<B`D
M7V%U=&@@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E
M<G,@;F5E9&5D(&9O<B!T:&ES(&=A=&5W87D@9')I=F5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!.971?4TU3*"1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!L:7-T(&]F(&%V86EL86)L92!G871E=V%Y(&1R
M:79E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M;V8@879A:6QA8FQE(&1R:79E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$1R:79E<G,H*0H@("`@>PH@("`@("`@('-T871I8R`D9')I=F5R<R`](&%R
M<F%Y*"D["B`@("`@("`@:68@*"%E;7!T>2@D9')I=F5R<RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1D<FEV97)S.PH@("`@("`@('T*"B`@("`@("`@)&1R
M:79E<G,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&1R:79E<E]D:7(@/2!O
M<&5N9&ER*&1I<FYA;64H7U]&24Q%7U\I("X@)R]335,O)RDI('L*("`@("`@
M("`@("`@=VAI;&4@*&9A;'-E("$]/2`H)&9I;&4@/2!R96%D9&ER*"1D<FEV
M97)?9&ER*2DI('L*("`@("`@("`@("`@("`@("\J($AI9&4@9&]T(&9I;&5S
M(&%N9"!N;VX@+G!H<"!F:6QE<RX@*B\*("`@("`@("`@("`@("`@(&EF("AS
M=6)S='(H)&9I;&4L(#`L(#$I("$]("<N)R`F)B!S=6)S='(H)&9I;&4L("TT
M*2`]/2`G+G!H<"<I('L*("`@("`@("`@("`@("`@("`@("`D9')I=F5R(#T@
M<W5B<W1R*"1F:6QE+"`P+"`M-"D["B`@("`@("`@("`@("`@("`@("`@)&1R
M:79E<E]I;F9O(#T@3F5T7U--4SHZ9V5T1V%T97=A>4EN9F\H)&1R:79E<BD[
M"B`@("`@("`@("`@("`@("`@("`@)&1R:79E<G-;)&1R:79E<ET@/2`D9')I
M=F5R7VEN9F];)VYA;64G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!C;&]S961I<B@D9')I=F5R7V1I<BD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&1R:79E<G,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&]N(&$@9V%T97=A>2P@<W5C
M:"!A<R!N86UE(&%N9"!A(&)R:65F(&1E<V-R:7!T:6]N+`H@("`@("H@9G)O
M;2!T:&4@9')I=F5R('-U8F-L87-S(&=E=$EN9F\H*2!F=6YC=&EO;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!E>'1R82!I
M;F9O<FUA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1V%T97=A>4EN
M9F\H)&=A=&5W87DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;F9O(#T@87)R
M87DH*3L*("`@("`@("!I9B`H:7-S970H)&EN9F];)&=A=&5W87E=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&EN9F];)&=A=&5W87E=.PH@("`@("`@('T*
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=.970O4TU3+R<@+B`D9V%T97=A>2`N
M("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G3F5T7U--4U\G("X@)&=A=&5W
M87D["B`@("`@("`@)&EN9F];)&=A=&5W87E=(#T@8V%L;%]U<V5R7V9U;F,H
M87)R87DH)&-L87-S+"`G9V5T26YF;R<I*3L*"B`@("`@("`@<F5T=7)N("1I
M;F9O6R1G871E=V%Y73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M<&%R86UE=&5R<R!F;W(@82!G871E=V%Y(&9R;VT@=&AE(&1R:79E<B!S=6)C
M;&%S<R!G971087)A;7,H*0H@("`@("H@9G5N8W1I;VXN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE(&=A=&5W87D@9')I
M=F5R(&9O<B!W:&EC:"!T;R!R971U<FX@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y(&]F(&5X=')A(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971'871E=V%Y4&%R86US*"1G871E=V%Y*0H@("`@>PH@("`@
M("`@('-T871I8R`D<&%R86US(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-S
M970H)'!A<F%M<ULD9V%T97=A>5TI*2!["B`@("`@("`@("`@(')E='5R;B`D
M<&%R86US6R1G871E=V%Y73L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?
M;VYC92`G3F5T+U--4R\G("X@)&=A=&5W87D@+B`G+G!H<"<["B`@("`@("`@
M)&-L87-S(#T@)TYE=%]335-?)R`N("1G871E=V%Y.PH@("`@("`@("1P87)A
M;7-;)&=A=&5W87E=(#T@8V%L;%]U<V5R7V9U;F,H87)R87DH)&-L87-S+"`G
M9V5T4&%R86US)RDI.PH*("`@("`@("!R971U<FX@)'!A<F%M<ULD9V%T97=A
M>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('-E;F0@<&%R86UE
M=&5R<R!F;W(@82!G871E=V%Y(&9R;VT@=&AE(&1R:79E<B!S=6)C;&%S<PH@
M("`@("H@9V5T1&5F875L=%-E;F1087)A;7,H*69U;F-T:6]N+B!4:&5S92!A
M<F4@<&%R86UE=&5R<R!W:&EC:"!A<F4@879A:6QA8FQE"B`@("`@*B!T;R!T
M:&4@=7-E<B!D=7)I;F<@<V5N9&EN9RP@<W5C:"!A<R!S971T:6YG(&$@=&EM
M92!F;W(@9&5L:79E<GDL(&]R('1Y<&4*("`@("`J(&]F(%--4R`H;F]R;6%L
M('1E>'0@;W(@9FQA<V@I+"!O<B!S;W5R8V4@861D<F5S<RP@971C+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@(%1H92!N86UE(&]F('1H92!G871E
M=V%Y(&1R:79E<B!F;W(@=VAI8V@@=&\@<F5T=7)N('1H90H@("`@("H@("`@
M("`@("`@("`@("`@<V5N9"!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%V86EL86)L92!S96YD('!A<F%M
M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1396YD4&%R
M86US*"1G871E=V%Y*0H@("`@>PH@("`@("`@('-T871I8R`D<&%R86US(#T@
M87)R87DH*3L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULD9V%T97=A>5TI
M*2!["B`@("`@("`@("`@(')E='5R;B`D<&%R86US6R1G871E=V%Y73L*("`@
M("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G3F5T+U--4R\G("X@)&=A
M=&5W87D@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)TYE=%]335-?)R`N
M("1G871E=V%Y.PH@("`@("`@("1P87)A;7-;)&=A=&5W87E=(#T@8V%L;%]U
M<V5R7V9U;F,H87)R87DH)&-L87-S+"`G9V5T1&5F875L=%-E;F1087)A;7,G
M*2D["@H@("`@("`@(')E='5R;B`D<&%R86US6R1G871E=V%Y73L*("`@('T*
M"B`@("`O*BH*("`@("`J(%%U97)Y('1H92!C=7)R96YT($=A=&5W87D@;V)J
M96-T('1O(&9I;F0@;W5T(&EF(&ET('-U<'!O<G1S('1H92!G:79E;@H@("`@
M("H@8V%P86)I;&ET>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M87!A8FEL:71Y("!4:&4@8V%P86)I;&ET>2!T;R!T97-T(&9O<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P
M86)I;&ET>2!I<R!S=7!P;W)T960@;W(@86YY(&]T:&5R"B`@("`@*B`@("`@
M("`@("`@("`@("!V86QU92!T:&%T('1H92!C87!A8FEL:71Y('=I<VAE<R!T
M;R!R97!O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH
M)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M8V%P86)I;&ET:65S6R1C87!A8FEL:71Y72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YC87!A8FEL:71I97-;)&-A<&%B:6QI='E=.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!=71H96YT:6-A=&5S(&%G86EN<W0@=&AE(&=A=&5W87D@:68@<F5Q=6ER
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@875T:&5N=&EC871E*"D*("`@('L*("`@("`@("`O*B!$;R!A=71H
M96YT:6-A=&EO;B!F;W(@=&AI<R!G871E=V%Y(&EF(&1R:79E<B!R97%U:7)E
M<R!I="X@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH)V%U
M=&@G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%U=&@@/2`D=&AI<RT^7V%U
M=&AE;G1I8V%T92@I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]A=71H
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E;F1S(&$@;65S<V%G92!T;R!O;F4@;W(@;6]R92!R96-I
M<&EE;G1S+B!(86YD<R!O9F8@=&AE(&%C='5A;"!S96YD:6YG"B`@("`@*B!T
M;R!T:&4@9V%T97=A>2!D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1M97-S86=E("!4:&4@;65S<V%G92!T;R!B92!S96YT+"!W:&EC:"!I
M<R!C;VUP;W-E9"!O9CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M/'!R93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I9"`@("T@
M02!U;FEQ=64@240@9F]R('1H92!M97-S86=E.PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('1O("`@+2!!;B!A<G)A>2!O9B!R96-I<&EE;G1S
M.PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1E>'0@+2!4:&4@
M=&5X="!O9B!T:&4@;65S<V%G93L*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@/"]P<F4^"B`@("`@*@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F0H)B1M97-S86=E*0H@("`@>PH@
M("`@("`@("\J($%U=&AE;G1I8V%T92X@*B\*("`@("`@("!I9B`H:7-?82@D
M=&AI<RT^875T:&5N=&EC871E*"DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?875T:#L*("`@("`@("!]"@H@("`@("`@
M("\J($UA:V4@<W5R92!T:&4@<F5C:7!I96YT<R!A<F4@:6X@86X@87)R87DN
M("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;65S<V%G95LG=&\G72DI('L*
M("`@("`@("`@("`@)&UE<W-A9V5;)W1O)UT@/2!A<G)A>2@D;65S<V%G95LG
M=&\G72D["B`@("`@("`@?0H*("`@("`@("`O*B!!<G)A>2!T;R!S=&]R92!E
M86-H('-E;F0N("HO"B`@("`@("`@)'-E;F1S(#T@87)R87DH*3L*"B`@("`@
M("`@+RH@268@9V%T97=A>2!S=7!P;W)T<R!B871C:"!S96YD:6YG+"!P<F5F
M97)E;F-E(&ES(&=I=F5N('1O('1H:7,*("`@("`@("`@*B!M971H;V0N("HO
M"B`@("`@("`@:68@*"1M87A?<&5R7V)A=&-H(#T@)'1H:7,M/FAA<T-A<&%B
M:6QI='DH)V)A=&-H)RDI('L*("`@("`@("`@("`@+RH@4W!L:70@=7`@=&AE
M(')E8VEP:65N=',@:6X@=&AE(&UA>"!R96-I<&EE;G1S('!E<B!B871C:"!A
M<PH@("`@("`@("`@("`@*B!S=7!P;W)T960@8GD@9V%T97=A>2X@*B\*("`@
M("`@("`@("`@)&E-87@@/2!C;W5N="@D;65S<V%G95LG=&\G72D["B`@("`@
M("`@("`@("1B871C:&5S(#T@8V5I;"@D:4UA>"`O("1M87A?<&5R7V)A=&-H
M*3L*"B`@("`@("`@("`@("\J($QO;W`@=&AR;W5G:"!T:&4@8F%T8VAE<R!A
M;F0@8V]M<&]S92!M97-S86=E<R!T;R!B92!S96YT+B`J+PH@("`@("`@("`@
M("!F;W(@*"1B(#T@,#L@)&(@/"`D8F%T8VAE<SL@)&(K*RD@>PH@("`@("`@
M("`@("`@("`@)')E8VEP:65N=',@/2!A<G)A>5]S;&EC92@D;65S<V%G95LG
M=&\G72P@*"1B("H@)&UA>%]P97)?8F%T8V@I+"`D;6%X7W!E<E]B871C:"D[
M"B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7W-E;F0H)&UE
M<W-A9V4L("1R96-I<&EE;G1S*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1R96-I<&EE;G1S(&%S("1R96-I<&EE;G0I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)')E<W!O;G-E6R1R96-I<&EE;G1=6S!=(#T](#$I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+RH@365S<V%G92!W87,@<V5N="P@<W1O
M<F4@<F5M;W1E(&ED+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5M
M;W1E7VED(#T@)')E<W!O;G-E6R1R96-I<&EE;G1=6S%=.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D97)R;W(@/2!N=6QL.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("\J($UE<W-A
M9V4@9F%I;&5D+"!S=&]R92!E<G)O<B!C;V1E+B`J+PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5M;W1E7VED(#T@;G5L;#L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5R<F]R(#T@)')E<W!O;G-E6R1R96-I<&EE;G1=6S%=.PH@
M("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@+RH@
M4W1O<F4@=&AE('-E;F1S+B`J+PH@("`@("`@("`@("`@("`@("`@("1S96YD
M<UM=(#T@87)R87DH)VUE<W-A9V5?:60G(#T^("1M97-S86=E6R=I9"==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]T95]I
M9"<@(#T^("1R96UO=&5?:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5C:7!I96YT)R`@/3X@)')E8VEP:65N="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=E<G)O<B<@("`@("`]
M/B`D97)R;W(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@3F\@8F%T8V@@<V5N9&EN
M9R!A=F%I;&%B;&4L(&IU<W0@;&]O<"!T:')O=6=H(&%L;"!R96-I<&EE;G1S
M"B`@("`@("`@("`@("`J(&%N9"!S96YD(&$@;65S<V%G92!F;W(@96%C:"!O
M;F4N("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1M97-S86=E6R=T;R==(&%S
M("1R96-I<&EE;G0I('L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1T
M:&ES+3Y?<V5N9"@D;65S<V%G92P@)')E8VEP:65N="D["B`@("`@("`@("`@
M("`@("!I9B`H)')E<W!O;G-E6S!=(#T](#$I('L*("`@("`@("`@("`@("`@
M("`@("`O*B!-97-S86=E('=A<R!S96YT+"!S=&]R92!R96UO=&4@:60@:68@
M86YY+B`J+PH@("`@("`@("`@("`@("`@("`@("1R96UO=&5?:60@/2`H:7-S
M970H)')E<W!O;G-E6S%=*2`_("1R97-P;VYS95LQ72`Z(&YU;&PI.PH@("`@
M("`@("`@("`@("`@("`@("1E<G)O<B`](&YU;&P["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($UE<W-A9V4@9F%I
M;&5D+"!S=&]R92!E<G)O<B!C;V1E+B`J+PH@("`@("`@("`@("`@("`@("`@
M("1R96UO=&5?:60@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@("1E<G)O
M<B`]("1R97-P;VYS95LQ73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`O*B!3=&]R92!T:&4@<V5N9',N("HO"B`@("`@("`@("`@("`@
M("`D<V5N9'-;72`](&%R<F%Y*"=M97-S86=E7VED)R`]/B`D;65S<V%G95LG
M:60G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]T
M95]I9"<@(#T^("1R96UO=&5?:60L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=R96-I<&EE;G0G("`]/B`D<F5C:7!I96YT+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G97)R;W(G("`@("`@/3X@)&5R
M<F]R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1S96YD<SL*("`@('T*"B`@("`O*BH*("`@("`J($EF('1H92!C=7)R96YT
M(&1R:79E<B!H87,@82!C<F5D:70@8V%P86)I;&ET>2P@<75E<FEE<R!T:&4@
M9V%T97=A>2!F;W(*("`@("`J(&$@8W)E9&ET(&)A;&%N8V4@86YD(')E='5R
M;G,@=&AE('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5F%L=64@:6YD:6-A=&EN9R!A=F%I;&%B;&4@8W)E9&ET(&]R(&YU;&P@:68@
M;F]T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G1E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0F%L86YC92@I"B`@("!["B`@("`@("`@+RH@
M075T:&5N=&EC871E+B`J+PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3YA=71H
M96YT:6-A=&4H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]A=71H.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@
M8F%L86YC92X@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH
M)V-R961I="<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$)A
M;&%N8V4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T
M<R!T;R!R971U<FX@82!C;VYC<F5T92!'871E=V%Y(&EN<W1A;F-E(&)A<V5D
M(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!'871E=V%Y('-U8F-L87-S('1O
M(')E='5R;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@5&AI<R!I
M<R!B87-E9"!O;B!T:&4@9V%T97=A>2!D<FEV97(@*"1D<FEV97(I+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!4:&4@8V]D92!I<R!D>6YA;6EC
M86QL>2!I;F-L=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO
M;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N
M('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@
M("`J($!R971U<FX@3F5T7U--4R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E
M=&4@1V%T97=A>2!I;G-T86YC92!O<B!F86QS92!O;@H@("`@("H@("`@("`@
M("`@("`@("`@("!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A
M8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:6YC;'5D95]O;F-E("=.970O4TU3+R<@+B`D9')I=F5R("X@)RYP:'`G
M.PH@("`@("`@("1C;&%S<R`]("=.971?4TU37R<@+B`D9')I=F5R.PH@("`@
M("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D
M<VUS(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'-M<R`](%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB*2P@)&1R:79E
M<BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S;7,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@
M=&\@82!C;VYC<F5T92!.971?4TU3(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@
M*B`D9')I=F5R+@H@("`@("H*("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@
M82!N97<@:6YS=&%N8V4@:68@;F\@3F5T7U--4R!I;G-T86YC92!W:71H('1H
M92!S86UE"B`@("`@*B!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@
M("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D
M=F%R(#T@)DYE=%]335,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!.971?
M4TU3('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@5&AE(&ES(&)A<V5D(&]N('1H92!G871E=V%Y(&1R:79E<B`H
M)&1R:79E<BDN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%1H92!C
M;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D
M:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG
M:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8W)E
M871E9"!C;VYC<F5T92!.971?4TU3(&EN<W1A;F-E+"!O<B!F86QS92!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN
M<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@
M("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D
M<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N
M871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=
M(#T@)DYE=%]335,Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O3F5T+TE-4U`N<&AP````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,U,30W`#$P-3$U-#,Q,#8Q`#`Q-S$W-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M:6YC;'5D95]O;F-E("=,;V<N<&AP)SL*"B\O($-O;G-T86YT($1E9FEN:71I
M;VYS"F1E9FEN92@G24U34%]/0U1%5%]#3U5.5"<L("(O*'LI*%LP+3E=>S$L
M?2DH7'TD*2\B*3L*9&5F:6YE*"=)35-07TU54U1?55-%7TQ)5$5204PG+"`B
M+UM<5UTO:2(I.PH*+RHJ"B`J(%1H92!.971?24U34"!C;&%S<R!P<F]V:61E
M<R!A(&-O;6UO;B!I;G1E<F9A8V4@=&\@86X@24U34"!S97)V97(@+@H@*@H@
M*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W-E<G9E<B<@($AO
M<W1N86UE(&]F($E-4U`@<V5R=F5R+@H@*B`@("=P;W)T)R`@("!0;W)T(&]F
M($E-4U`@<V5R=F5R+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].
M971?24U34"])35-0+G!H<"QV(#$N,3,N,3`N,3D@,C`P-B\P,B\Q,"`P-#HU
M.#HR-B!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS
M:T!H;W)D92YO<F<^"B`J($!P86-K86=E($YE=%])35-0"B`J+PIC;&%S<R!.
M971?24U34"!["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!N
M86UE+TE0(&%D9')E<W,@;V8@24U34"!H;W-T+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:6US<%]S97)V97(@("`@("`@
M("`@("`@("`@/2`G;&]C86QH;W-T)SL*"B`@("`O*BH*("`@("`J(%-T<FEN
M9R!C;VYT86EN:6YG('!O<G0@9F]R($E-4U`@<V5R=F5R+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:6US<%]P;W)T("`@
M("`@("`@("`@("`@("`@/2`G-#`V)SL*"B`@("`O*BH*("`@("`J($)O;VQE
M86X@=&\@<V5T(&EF('=E('-H;W5L9"!W<FET92!T;R!A(&QO9RP@:68@;VYE
M(&ES('-E="!U<"X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1L;V=%;F%B;&5D("`@("`@("`@("`@("`@("`]('1R=64[
M"@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8G5F9F5R(&-O;G1A:6YI;F<@=&AE
M(&QA<W0@<F%W($Y/(&]R($)!1"!R97-P;VYS92!F<F]M('1H90H@("`@("H@
M<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D;&%S=%)A=T5R<F]R("`@("`@("`@("`@("`]("<G.PH*("`@("\O
M(%!R:79A=&4@1&5C;&%R871I;VYS"B`@("!V87(@)%]C;VUM86YD4')E9FEX
M("`@("`@("`@("`@(#T@)T$G.PH@("`@=F%R("1?8V]M;6%N9$-O=6YT("`@
M("`@("`@("`@("`](#$["B`@("!V87(@)%]T86<@("`@("`@("`@("`@("`@
M("`@("`@(#T@)R<["B`@("!V87(@)%]S=')E86T@("`@("`@("`@("`@("`@
M("`@(#T@;G5L;#L*("`@('9A<B`D7VQA<W1#;VUM86YD5&%G("`@("`@("`@
M("`@/2`G=6YD969I;F5D)SL*("`@('9A<B`D7VQO9V=E<B`@("`@("`@("`@
M("`@("`@("`@/2!N=6QL.PH@("`@=F%R("1?;&]G4V5T("`@("`@("`@("`@
M("`@("`@("`](&YU;&P["B`@("!V87(@)%]L;V=,979E;"`@("`@("`@("`@
M("`@("`@(#T@4$5!4E],3T=?24Y&3SL*("`@('9A<B`D7VQO9T)U9F9E<B`@
M("`@("`@("`@("`@("`@(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US($AA<V@@8V]N=&%I;FEN9R!S97)V97(@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@3F5T7TE-4U`H)'!A<F%M<RD*("`@('L*
M("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M<RD@)B8@(65M<'1Y*"1P87)A
M;7-;)W-E<G9E<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^:6US<%]S97)V
M97(@/2`D<&%R86US6R=S97)V97(G73L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]A<G)A>2@D<&%R86US*2`F)B`A96UP='DH)'!A<F%M<ULG<&]R="==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^:6US<%]P;W)T(#T@)'!A<F%M<ULG
M<&]R="==.PH@("`@("`@('T*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET
M:6%L:7IA=&EO;B!F=6YC=&EO;B!T;R!B92!C86QL960@869T97(@;V)J96-T
M(&ES(')E='5R;F5D+B`@5&AI<PH@("`@("H@86QL;W=S(&5R<F]R<R!T;R!O
M8V-U<B!A;F0@;F]T(&)R96%K('1H92!S8W)I<'0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(%!%05)?17)R;W(@;VX@
M8V]N;F5C=&EO;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET
M*"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/FEM<W!/<&5N*"D[
M"@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YW<FET951O3&]G*"=);FET:6%L:7II;F<@3F5T7TE-4U`@;V)J
M96-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("!014%27TQ/1U])3D9/*3L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($QO9W,@;W5T(&]F('1H92!S97)V97(@
M86YD(&-L;W-E<R!T:&4@24U34"!S=')E86T*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&]G;W5T*"D*("`@('L*("`@("`@("`D=&AI<RT^=W)I=&54;TQO9R@G
M0VQO<VEN9R!)35-0($-O;FYE8W1I;VXN)RP@7U]&24Q%7U\L(%]?3$E.15]?
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TE.1D\I.PH@
M("`@("`@("1C;VUM86YD7W-T<FEN9R`]("=,3T=/550G.PH@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^:6US<%-E;F0H)&-O;6UA;F1?<W1R:6YG*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(&9C;&]S92@D=&AI<RT^7W-T<F5A;2D["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9C
M;&]S92@D=&AI<RT^7W-T<F5A;2D["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(')A=R!C87!A8FEL:71Y(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')A=R!C87!A8FEL:71Y
M(')E<W!O;G-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C87!A8FEL:71Y*"D*
M("`@('L*("`@("`@("`D8V]M;6%N9%]S=')I;F<@/2`G0T%004))3$E462<[
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YI;7-P4V5N9"@D8V]M;6%N9%]S
M=')I;F<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3YI
M;7-P4F5C96EV92@I.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B+UY<
M*B!#05!!0DE,2519+R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@
M("`@("`@("`D8V%P86)I;&ET>2`]('!R96=?<F5P;&%C92@B+UY<*B!#05!!
M0DE,2519+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G)RP@)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("`@("`@
M("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3YI;7-P4F5C96EV92@I.R`O
M+T]+"@H@("`@("`@("`@("`@("`@:68@*"$D<V5R=F5R7W)E<W!O;G-E(#T]
M("=/2R<I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=W)I=&54;TQO9R@G0T%004))3$E462!C;VUP;&5T960@3TLG+"!?7T9)
M3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1C87!A8FEL:71Y.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@;W!E;B!A;B!)35-0('-O8VME="!W:71H('1H92!S97)V97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@:6US
M<$]P96XH*0H@("`@>PH@("`@("`@("1F<"`]($!F<V]C:V]P96XH)'1H:7,M
M/FEM<W!?<V5R=F5R+"`D=&AI<RT^:6US<%]P;W)T*3L*("`@("`@("!I9B`H
M(21F<"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G
M0V]N;F5C=&EO;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<L(%]?1DE,15]?+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?<W1R96%M(#T@)&9P.PH@("`@
M("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^:6US<%)E8V5I=F4H*3L*
M("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"H@3TLO(BP@)'-E<G9E<E]R
M97-P;VYS92DI('L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@
M=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O('-E;F0@82!C
M;VUM86YD('1O('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&-O;6UA;F1497AT(%1E>'0@=&\@<V5N9"!T;R!T:&4@<V5R=F5R
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN8VQU9&5486<@($1E=&5R;6EN
M97,@:68@8V]M;6%N9"!T86<@:7,@<')E<&5N9&5D+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@("1S96YD0U),1B`@($1E=&5R;6EN97,@:68@0U),1B!I<R!A
M<'!E;F1E9"X*("`@("`J($!R971U<FX@;6EX960@("!4<G5E(&]N('-U8V-E
M<W,@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I;7-P4V5N9"@D8V]M;6%N9%1E>'0L("1I;F-L=61E5&%G/71R=64L("1S
M96YD0U),1CUT<G5E*0H@("`@>PH@("`@("`@("1C;VUM86YD7W1E>'0@/2`G
M)SL*"B`@("`@("`@:68@*"$D=&AI<RT^7W-T<F5A;2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T;R!)35-0
M(&AO<W0@9F%I;&5D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&EN8VQU9&5486<I('L*("`@("`@("`@("`@)'1H
M:7,M/E]T86<@/2`D=&AI<RT^7V=E=$YE>'1#;VUM86YD5&%G*"D["B`@("`@
M("`@("`@("1C;VUM86YD7W1E>'0@/2`B)'1H:7,M/E]T86<@(CL*("`@("`@
M("!]"@H@("`@("`@("1C;VUM86YD7W1E>'0@+CT@)&-O;6UA;F1497AT.PH*
M("`@("`@("!I9B`H)'-E;F1#4DQ&*2!["B`@("`@("`@("`@("1C;VUM86YD
M7W1E>'0@+CT@(EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G=R
M:71E5&],;V<H)U1O.B`G("X@)&-O;6UA;F1?=&5X="P@7U]&24Q%7U\L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@:68@*"%F<'5T<R@D=&AI<RT^7W-T<F5A;2P@)&-O
M;6UA;F1?=&5X="DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P
M17)R;W(H)T-O;FYE8W1I;VX@=&\@24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E8V5I=F5S(&$@<VEN9VQE($-23$8@=&5R;6EN871E9"!S97)V97(@<F5S
M<&]N<V4@<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`G3D\G
M+"`G0D%$)RP@)T]+)RP@<F%W(')E<W!O;G-E(&]R(%!%05)?17)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&EM<W!296-E:79E*"D*("`@('L*("`@("`@
M("!I9B`H(21T:&ES+3Y?<W1R96%M*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^:6US<$5R<F]R*"=#;VYN96-T:6]N('1O($E-4U`@:&]S="!F86EL
M960N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@
M)')E<W5L="`](&9G971S*"1T:&ES+3Y?<W1R96%M+"`U,3(I.PH@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@
M("`@("`@)&UE=&$@/2!S=')E86U?9V5T7VUE=&%?9&%T82@D=&AI<RT^7W-T
M<F5A;2D["B`@("`@("`@:68@*"1M971A6R=T:6UE9%]O=70G72D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T
M;R!)35-0(&AO<W0@9F%I;&5D+B<@+B`G.B!#;VYN96-T:6]N('1I;65D(&]U
M="$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R
M97-P;VYS92`]('1R:6TH)')E<W5L="D["B`@("`@("`@)'1H:7,M/G=R:71E
M5&],;V<H)T9R;VTZ("<@+B`D<V5R=F5R7W)E<W!O;G-E+"!?7T9)3$5?7RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`O*B!087)S92!O=70@=&AE(')E<W!O;G-E.@H@
M("`@("`@("`J($9I<G-T(&UA:V4@<W5R92!T:&%T('1H:7,@:7,@;F]T(&9O
M<B!A('!R979I;W5S(&-O;6UA;F0N"B`@("`@("`@("H@268@:70@:7,L(&ET
M(&UE86YS('=E(&1I9"!N;W0@<F5A9"!A;&P@=&AE('-E<G9E<B!R97-P;VYS
M97,@9G)O;0H@("`@("`@("`J('1H92!L87-T(&-O;6UA;F0N+BYR96%D('1H
M96T@;F]W+"!B=70@=&AR;W<@86X@97)R;W(N("HO"B`@("`@("`@=VAI;&4@
M*'!R96=?;6%T8V@H(B]>(B`N("1T:&ES+3Y?;&%S=$-O;6UA;F1486<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`N(B\B+"`D<V5R=F5R7W)E<W!O;G-E
M*2D@>PH@("`@("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T*("`@("`@("`@
M("`@("`@('1R:6TH9F=E=',H)'1H:7,M/E]S=')E86TL(#4Q,BDI.PH@("`@
M("`@("`@("`D=&AI<RT^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE
M(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG("X@(CH@)'-E
M<G9E<E]R97-P;VYS92(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1C=7)R
M96YT5&%G(#T@)'1H:7,M/E]T86<["B`@("`@("`@:68@*'!R96=?;6%T8V@H
M(B]>(B`N("1C=7)R96YT5&%G("X@(B!.3R\B+"`D<V5R=F5R7W)E<W!O;G-E
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&%S=%)A=T5R<F]R(#T@)'-E<G9E
M<E]R97-P;VYS93L*("`@("`@("`@("`@<F5T=7)N("=.3R<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H<')E9U]M871C:"@B+UXB("X@)&-U<G)E;G1486<@
M+B`B($)!1"\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E
M<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("`D=&AI<RT^;&%S=%)A=T5R<F]R(#T@)'-E<G9E<E]R97-P
M;VYS93L*("`@("`@("`@("`@<F5T=7)N("="040G.PH@("`@("`@('T*"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H(B]>(B`N("1C=7)R96YT5&%G("X@(B!/
M2R\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@("!R971U<FX@
M)T]+)SL*("`@("`@("!]"@H@("`@("`@("\J($EF(&ET('=A<R!N;W0@82`G
M3D\G+"`G0D%$)R!O<B`G3TLG(')E<W!O;G-E+`H@("`@("`@("`J('1H96X@
M:70G<R!U<"!T;R!T:&4@8V%L;&EN9R!F=6YC=&EO;B!T;R!D96-I9&4*("`@
M("`@("`@*B!W:&%T('1O(&1O('=I=&@@:70N("HO"B`@("`@("`@<F5T=7)N
M("1S97)V97)?<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R
M:65V97,@0U),1B!T97)M:6YA=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&%N
M9"!S<&QI=',@:70@:6YT;PH@("`@("H@86X@87)R87D@9&5L:6UI=&5D(&)Y
M(&$@/'-P86-E/BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y(')E<W5L
M="!F<F]M(&5X<&QO9&4H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5R
M=F5R4F5S<&]N<V5#:'5N:W,H*0H@("`@>PH@("`@("`@("1S97)V97)?<F5S
M<&]N<V4@/0H@("`@("`@("`@("!T<FEM*&9G971S*"1T:&ES+3Y?<W1R96%M
M+"`U,3(I*3L*("`@("`@("`D8VAU;FMS(#T@97AP;&]D92@G("<L("1S97)V
M97)?<F5S<&]N<V4I.PH@("`@("`@(')E='5R;B`D8VAU;FMS.PH@("`@?0H*
M("`@("\J"B`@("`@*B!296-E:79E<R!F:7AE9"!N=6UB97(@;V8@8GET97,@
M9G)O;2!)35-0('-O8VME="X@57-E9"!W:&5N"B`@("`@*B!S97)V97(@<F5T
M=7)N<R!A('-T<FEN9R!L:71E<F%L+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1L96YG=&@@($YU;6)E<B!O9B!B>71E<R!T;R!R96%D(&9R;VT@
M<V]C:V5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!497AT(&]F
M('-T<FEN9R!L:71E<F%L+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96-E:79E
M4W1R:6YG3&ET97)A;"@D;&5N9W1H*0H@("`@>PH@("`@("`@("1T96UP(#T@
M=')I;2AF<F5A9"@D=&AI<RT^7W-T<F5A;2P@)&QE;F=T:"DI.PH@("`@("`@
M("1T:&ES+3YW<FET951O3&]G*"=&<F]M>WTZ("<@+B`D=&5M<"P@7U]&24Q%
M7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@)'1E;7`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!);F-R96UE;G1S('1H92!)35-0(&-O;6UA;F0@=&%G('1O
M:V5N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0')E
M='5R;B!S=')I;F<@3F5X="!C;VUM86YD('1A9RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V=E=$YE>'1#;VUM86YD5&%G*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7VQA<W1#;VUM86YD5&%G(#T@)'1H:7,M/E]T86<@/R`D=&AI<RT^7W1A
M9R`Z("=U;F1E9FEN960G.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;6UA
M;F10<F5F:7@@+B!S<')I;G1F*"<E,#1D)RP@)'1H:7,M/E]C;VUM86YD0V]U
M;G0K*RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF(&$@
M<W1R:6YG(&YE961S('1O(&)E('%U;W1E9"!B969O<F4@<V5N9&EN9R!T;R!T
M:&4@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN
M9R`@4W1R:6YG('1O(&)E('1E<W1E9"X*("`@("`J($!R971U<FX@<W1R:6YG
M($]R:6=I;F%L('-T<FEN9R!Q=6]T960@:68@;F5E9&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!Q=6]T95-P86-E9%-T<FEN9R@D<W1R:6YG*0H@("`@>PH@
M("`@("`@(&EF("AS=')P;W,H)'-T<FEN9RP@)R`G*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N("<B)R`N("1S=')I;F<@+B`G(B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F%I<V5S(&%N($E-4U`@97)R
M;W(N("!"87-I8V%L;'DL(&]N;'D@=W)I=&5S"B`@("`@*B!E<G)O<B!O=70@
M=&\@=&AE(&AO<F1E(&QO9V9I;&4@86YD(')E='5R;G,@4$5!4E]%<G)O<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5R<B`@("!%:71H97(@4$5!
M4E]%<G)O<B!O8FIE8W0@;W(@=&5X="!T;R!W<FET92!T;R!L;V<N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F:6QE("`@1FEL92!N86UE('=H97)E(&5R<F]R
M(&]C8W5R960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EN92`@3&EN92!N
M=6UB97(@=VAE<F4@97)R;W(@;V-C=7)E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@:6US<$5R<F]R*"1E<G(@/2`G)RP@)&9I;&4]7U]&24Q%7U\L("1L:6YE
M/5]?3$E.15]?*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)&QO9U]T97AT(#T@)&5R<BT^9V5T
M365S<V%G92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L;V=?
M=&5X="`]("1E<G(["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^=W)I=&54
M;TQO9R@D;&]G7W1E>'0L("1F:6QE+"`D;&EN92P@4$5!4E],3T=?15)2*3L*
M("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G(I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E<R!A(&UE<W-A9V4@=&\@=&AE
M($E-4U`@;&]G9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M97-S86=E("!497AT('1O('=R:71E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<FET951O3&]G*"1M97-S86=E+"`D9FEL92`](%]?1DE,15]?+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D;&EN92`](%]?3$E.15]?+"`D<')I;W)I='D@
M/2!014%27TQ/1U])3D9/*0H@("`@>PH@("`@("`@(&EF("@H)'1H:7,M/FQO
M9T5N86)L960I("8F("@D=&AI<RT^7VQO9U-E="DI('L*("`@("`@("`@("`@
M:68@*"1P<FEO<FET>2`^("1T:&ES+3Y?;&]G3&5V96PI('L*("`@("`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&QO
M9TUE<W-A9V4@/2`G6VEM<W!=("<@+B`D;65S<V%G92`N("<@6V]N(&QI;F4@
M)R`N("1L:6YE("X@)R!O9B`B)R`N("1F:6QE("X@)R)=)SL*("`@("`@("`@
M("`@)'1H:7,M/E]L;V=G97(M/FQO9R@D;&]G365S<V%G92P@)'!R:6]R:71Y
M*3L*("`@("`@("!](&5L<V5I9B`H*"$D=&AI<RT^7VQO9U-E="D@)B8@*"1T
M:&ES+3YL;V=%;F%B;&5D*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO9T)U
M9F9E<EM=(#T@87)R87DH)VUE<W-A9V4G("`]/B`D;65S<V%G92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P<FEO<FET>2<@
M/3X@)'!R:6]R:71Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V9I;&4G("`@("`]/B`D9FEL92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=L:6YE)R`@("`@/3X@)&QI;F4*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!,
M;V<@;V)J96-T(&)A<V5D(&]N("1P87)A;7,*("`@("`J"B`@("`@*B!`<&%R
M86T@(&%R<F%Y("`D<&%R86US($QO9R!O8FIE8W0@<&%R86UE=&5R<RX*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$QO9V=E
M<B@D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&]G3&5V96P@/2`D
M<&%R86US6R=P<FEO<FET>2==.PH@("`@("`@("1L;V=G97(@/2`F3&]G.CIS
M:6YG;&5T;VXH)'!A<F%M<ULG='EP92==+"`D<&%R86US6R=N86UE)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R=I9&5N
M="==+"`D<&%R86US6R=P87)A;7,G72D["B`@("`@("`@)'1H:7,M/E]L;V=3
M970@/2!T<G5E.PH*("`@("`@("!I9B`H:7-?82@D;&]G9V5R+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YL;V=%;F%B;&5D(#T@9F%L
M<V4["B`@("`@("`@("`@(')E='5R;B`D;&]G9V5R.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R(#T@)B1L;V=G97(["B`@
M("`@("`@("`@("1T:&ES+3YL;V=%;F%B;&5D(#T@=')U93L*("`@("`@("`@
M("`@)'1H:7,M/E]W<FET94QO9T)U9F9E<B@I.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET
M97,@;W5T(&-O;G1E;G1S(&]F("1?;&]G0G5F9F5R('1O(&QO9R!F:6QE+B`@
M06QL;W=S(&UE<W-A9V5S"B`@("`@*B!T;R!B92!L;V=G960@9'5R:6YG(&EN
M:71I86QI>F%T:6]N(&]F(&]B:F5C="!B969O<F4@3&]G(&]B:F5C="!I<PH@
M("`@("H@:6YS=&%N=&EA=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?=W)I=&5,;V="=69F97(H*0H@
M("`@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?
M;&]G0G5F9F5R*3L@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^=W)I=&54
M;TQO9R@D=&AI<RT^7VQO9T)U9F9E<ELD:5U;)VUE<W-A9V4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V="=69F97);)&E=
M6R=F:6QE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;&]G0G5F9F5R6R1I75LG;&EN92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VQO9T)U9F9E<ELD:5U;)W!R:6]R:71Y)UTI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(&-R96%T92!A($YE=%])35-0(&]B:F5C="!B87-E9"!O;B`D9')I=F5R+@H@
M("`@("H@375S="!B92!C86QL960@87,@)&EM<W`@/2`F3F5T7TE-4U`Z.F9A
M8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@*@H@("`@("H@0'!A<F%M
M("!S=')I;F<@)&1R:79E<B!4>7!E(&]F($YE=%])35-0(&]B:F5C="!T;R!R
M971U<FXN"B`@("`@*B!`<&%R86T@(&UI>&5D("`D<&%R86US("!!;GD@<&%R
M86UE=&5R<R!N965D960@8GD@=&AE($YE=%])35-0(&]B:F5C="X*("`@("`J
M($!R971U<FX@;6EX960@(%1H92!R97%U97-T960@3F5T7TE-4U`@;V)J96-T
M(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD*("`@('L*("`@("`@("`D
M9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["B`@("`@("`@:68@*&5M<'1Y
M*"1D<FEV97(I('Q\("1D<FEV97(@/3T@)VYO;F4G*2!["B`@("`@("`@("`@
M("1I;7-P(#T@)FYE=R!.971?24U34"@D<&%R86US*3L*("`@("`@("`@("`@
M<F5T=7)N("1I;7-P.PH@("`@("`@('T*"B`@("`@("`@:6YC;'5D95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R])35-0+R<@+B`D9')I=F5R("X@)RYP
M:'`G.PH@("`@("`@("1C;&%S<R`]("=.971?24U34%\G("X@)&1R:79E<CL*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)&EM<W`@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("`@("`@
M<F5T=7)N("1I;7-P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(BDL("1C;&%S<RDI+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A($YE=%])35-0(&]B:F5C="!B
M87-E9"!O;B`D9')I=F5R+B`@3VYL>0H@("`@("H@8W)E871E<R!A(&YE=R!O
M8FIE8W0@:68@;VYE('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!A;')E861Y
M"B`@("`@*B!D;V5S;B=T(&5X:7-T+@H@("`@("H@375S="!B92!C86QL960@
M87,@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O;B@D9')I=F5R+"`D<&%R
M86US*3L*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D9')I=F5R(%1Y
M<&4@;V8@3F5T7TE-4U`@;V)J96-T('1O(')E='5R;BX*("`@("`J($!P87)A
M;2`@;6EX960@("1P87)A;7,@06YY('!A<F%M971E<G,@;F5E9&5D(&)Y('1H
M92!.971?24U34"!O8FIE8W0N"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2969E
M<F5N8V4@=&\@=&AE($YE=%])35-0(&]B:F5C="!O<B!014%27T5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R
M:79E<BP@)'!A<F%M<RD*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E
M<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@
M("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US
M*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=
M*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DYE
M=%])35-0.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]B87-E+G!H
M<```````````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#,T-C0`,3`U,34T,S$P-C$`,#$V-C`U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!(;W)D92!B
M87-E(&EN8VQU<VEO;B!F:6QE+@H@*@H@*B!4:&ES(&9I;&4@8G)I;F=S(&EN
M(&%L;"!O9B!T:&4@9&5P96YD96YC:65S('1H870@2&]R9&4*("H@9G)A;65W
M;W)K+6QE=F5L('-C<FEP=',@=VEL;"!N965D+"!A;F0@<V5T<R!U<"!O8FIE
M8W1S('1H870@86QL"B`J('-C<FEP=',@=7-E+@H@*@H@*B!.;W1E.B!4:&ES
M(&)A<V4@9FEL92!D;V5S(%]N;W1?(&-H96-K(&%U=&AE;G1I8V%T:6]N+"!S
M;R!A<R!T;PH@*B!A=F]I9"!A;B!I;F9I;FET92!L;V]P(&]N('1H92!(;W)D
M92!L;V=I;B!P86=E+B!9;W4G;&P@;F5E9"!T;R!D;PH@*B!I="!Y;W5R<V5L
M9B!I;B!F<F%M97=O<FLM;&5V96P@<&%G97,N"B`J"B`J("1(;W)D93H@:&]R
M9&4O;&EB+V)A<V4N<&AP+'8@,2XT,"XQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ
M,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*
M"B\O($-H96-K(&9O<B!A('!R:6]R(&1E9FEN:71I;VX@;V8@2$]21$5?0D%3
M12`H<&5R:&%P<R!B>2!A;@HO+R!A=71O7W!R97!E;F1?9FEL92!D969I;FET
M:6]N(&9O<B!S:71E(&-U<W1O;6EZ871I;VXI+@II9B`H(61E9FEN960H)TA/
M4D1%7T)!4T4G*2D@>PH@("`@0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B<I.PI]"@HO+R!,;V%D('1H92!(;W)D92!&
M<F%M97=O<FL@8V]R92P@86YD('-E="!U<"!I;F-L=7-I;VX@<&%T:',N"G)E
M<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*+R\@
M4F5G:7-T<GDN"B1S97-S:6]N7V-O;G1R;VP@/2!5=&EL.CIN;VY);G!U=%9A
M<B@G<V5S<VEO;E]C;VYT<F]L)RD["FEF("@D<V5S<VEO;E]C;VYT<F]L(#T]
M("=N;VYE)RD@>PH@("`@)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T
M;VXH2$]21$5?4T534TE/3E].3TY%*3L*?2!E;'-E:68@*"1S97-S:6]N7V-O
M;G1R;VP@/3T@)W)E861O;FQY)RD@>PH@("`@)')E9VES=')Y(#T@)E)E9VES
M=')Y.CIS:6YG;&5T;VXH2$]21$5?4T534TE/3E]214%$3TY,62D["GT@96QS
M92!["B`@("`D<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I.PI]
M"FEF("AI<U]A*"@D<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"=H;W)D
M92<L("%D969I;F5D*"=!551(7TA!3D1,15(G*2DI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("!I9B`H)'!U<VAE9"T^9V5T0V]D92@I(#T]("=P97)M:7-S:6]N
M7V1E;FEE9"<I('L*("`@("`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL
M=7)E4F5D:7)E8W0H*3L*("`@('T*("`@($AO<F1E.CIF871A;"@D<'5S:&5D
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*?0HD8V]N9B`]("8D1TQ/
M0D%,4ULG8V]N9B==.PI`9&5F:6YE*"=(3U)$15]414U03$%415,G+"`D<F5G
M:7-T<GDM/F=E="@G=&5M<&QA=&5S)RDI.PH*+R\@3F]T:69I8V%T:6]N(%-Y
M<W1E;2X*)&YO=&EF:6-A=&EO;B`]("9.;W1I9FEC871I;VXZ.G-I;F=L971O
M;B@I.PHD;F]T:69I8V%T:6]N+3YA='1A8V@H)W-T871U<R<I.PH*+RH@4V5T
M('5P('1H92!M96YU+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP
M)SL*)&UE;G4@/2`F;F5W($UE;G4H*3L*"B\O($-O;7!R97-S(&]U='!U=`I(
M;W)D93HZ8V]M<')E<W-/=71P=70H*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5S="YP:'``````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4T
M-S,R`#$P-3$U-#,Q,#8Q`#`Q-C8Q-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+RHJ"B`J($1E9FEN92!(3U)$
M15]"05-%+"!I9B!I="!I<R!N;W0@86QR96%D>2!S970L(&%N9"!I;F-L=61E
M('1H92!M86EN"B`J($AO<F1E(&QI8G)A<GDL('-I;F-E('=E(')E<75I<F4@
M:70@9F]R('1H:7,@<&%C:V%G92!T;R!F=6YC=&EO;BX*("HO"FEF("@A9&5F
M:6YE9"@G2$]21$5?0D%312<I*2!["B`@("!D969I;F4H)TA/4D1%7T)!4T4G
M+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*?0IR97%U:7)E7V]N8V4@
M2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B\J*@H@*B!3970@=&AE
M('!A=&@@=&\@=&AE('1E;7!L871E<R!N965D960@9F]R('1E<W1I;F<@;W5T
M<'5T+@H@*B\*9&5F:6YE*"=415-47U1%35!,051%4R<L($A/4D1%7T)!4T4@
M+B`G+W1E;7!L871E<R]T97-T+R<I.PH*+RH@268@9V5T=&5X="!I<R!N;W0@
M;&]A9&5D+"!D969I;F4@82!D=6UM>2!?*"D@9G5N8W1I;VX@<V\@=&AA=`H@
M*B!I;F-L=61I;F<@86YY(&9I;&4@=VET:"!G971T97AT('-T<FEN9W,@=V]N
M)W0@8V%U<V4@82!F871A;"!E<G)O<BP*("H@8V%U<VEN9R!T97-T+G!H<"!T
M;R!R971U<FX@82!B;&%N:R!P86=E+B`J+PII9B`H(69U;F-T:6]N7V5X:7-T
M<R@G7R<I*2!["B`@("!F=6YC=&EO;B!?*"1S*2![(')E='5R;B`D<SL@?0I]
M"@HO*BH*("H@5&AE($AO<F1E7U1E<W0Z.B!C;&%S<R!P<F]V:61E<R!F=6YC
M=&EO;G,@=7-E9"!I;B!T:&4@=&5S="!S8W)I<'1S"B`J('5S960@:6X@=&AE
M('9A<FEO=7,@87!P;&EC871I;VYS("AT97-T+G!H<"DN"B`J"B`J("1(;W)D
M93H@:&]R9&4O;&EB+U1E<W0N<&AP+'8@,2XS,2XT+C$Y(#(P,#8O,#,O,C@@
M,3(Z,S$Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($)R96YT($HN($YO<F1Q=6ES="`\8FIN
M0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO<F1E
M+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?5&5S=`H@*B\*8VQA<W,@2&]R9&5?5&5S="!["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!T:&%T(&AO;&1S('1H92!L:7-T(&]F($AO
M<F1E(&%P<&QI8V%T:6]N<RX*("`@("`J("A,;V%D960@9G)O;2!C;VYF:6<O
M<F5G:7-T<GDN<&AP*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1A<'!L:6-A=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@0V%C:&5D(')E<W5L=',@;V8@9V5T07!P;&EC871I;VYS*"DN"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!O
M=71P=70@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(%!(4"!V97)S
M:6]N(&]F('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P:'!V97(["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&5S="@I"B`@
M("!["B`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I
M9R]R96=I<W1R>2YP:'`G.PH@("`@("`@(&MS;W)T*"1T:&ES+3YA<'!L:6-A
M=&EO;G,I.PH*("`@("`@("`O*B!3=&]R92!T:&4@4$A0('9E<G-I;VX@:6YF
M;W)M871I;VXN("HO"B`@("`@("`@)'1H:7,M/E]P:'!V97(@/2`D=&AI<RT^
M<W!L:7102%!697)S:6]N*'!H<'9E<G-I;VXH*2D["@H@("`@("`@("\J(%=E
M('=A;G0@=&\@8F4@87,@=F5R8F]S92!A<R!P;W-S:6)L92!H97)E+B`J+PH@
M("`@("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@("`@("\J(%-E
M="!C:&%R86-T97(@96YC;V1I;F<N("HO"B`@("`@("`@:&5A9&5R*"=#;VYT
M96YT+71Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E=#UU=&8M."<I.PH@("`@("`@
M(&AE861E<B@G5F%R>3H@06-C97!T+4QA;F=U86=E)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!087)S92!02%`@=F5R<VEO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1V97)S:6]N("!!(%!(4"US='EL92!V97)S:6]N('-T
M<FEN9R`H6"Y8+E@I+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@5&AE
M('!A<G-E9"!S=')I;F<N"B`@("`@*B`@("`@("`@("`@("`@($ME>7,Z("=M
M86IO<B<L("=M:6YO<B<L("=S=6)M:6YO<B<L("=C;&%S<R<*("`@("`J+PH@
M("`@9G5N8W1I;VX@<W!L:7102%!697)S:6]N*"1V97)S:6]N*0H@("`@>PH@
M("`@("`@("\J($9I<G-T('!I8VL@;V9F(&UA:F]R('9E<G-I;VXL(&%N9"!L
M;W=E<BUC87-E('1H92!R97-T+B`J+PH@("`@("`@(&EF("@H<W1R;&5N*"1V
M97)S:6]N*2`^/2`S*2`F)B`H)'9E<G-I;VY;,5T@/3T@)RXG*2D@>PH@("`@
M("`@("`@("`D<&AP=F5R6R=M86IO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`P
M+"`S*3L*("`@("`@("`@("`@)'9E<G-I;VX@/2!S=6)S='(H<W1R=&]L;W=E
M<B@D=F5R<VEO;BDL(#,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1P:'!V97);)VUA:F]R)UT@/2`D=F5R<VEO;CL*("`@("`@("`@("`@)'!H
M<'9E<ELG8VQA<W,G72`]("=U;FMN;W=N)SL*("`@("`@("`@("`@<F5T=7)N
M("1P:'!V97(["B`@("`@("`@?0H*("`@("`@("!I9B`H)'9E<G-I;VY;,%T@
M/3T@)RXG*2!["B`@("`@("`@("`@("1V97)S:6]N(#T@<W5B<W1R*"1V97)S
M:6]N+"`Q*3L*("`@("`@("!]"@H@("`@("`@("\J($YE>'0L(&1E=&5R;6EN
M92!I9B!T:&ES(&ES(#0N,&(@;W(@-"XP<F,[(&EF('-O+"!T:&5R92!I<R!N
M;PH@("`@("`@("`@(&UI;F]R+"!T:&4@<F5S="!I<R!T:&4@<W5B;6EN;W(L
M(&%N9"!C;&%S<R!I<R!S970@=&\@8F5T82X@*B\*("`@("`@("`D<R`]('-T
M<G-P;B@D=F5R<VEO;BP@)S`Q,C,T-38W.#DG*3L*("`@("`@("!I9B`H)',@
M/3T@,"D@>PH@("`@("`@("`@("`D<&AP=F5R6R=S=6)M:6YO<B==(#T@)'9E
M<G-I;VX["B`@("`@("`@("`@("1P:'!V97);)V-L87-S)UT@/2`G8F5T82<[
M"B`@("`@("`@("`@(')E='5R;B`D<&AP=F5R.PH@("`@("`@('T*"B`@("`@
M("`@+RH@3W1H97)W:7-E+"!T:&ES(&ES(&YO;BUB971A.R`@=&AE(&YU;65R
M:6,@<&%R="!I<R!T:&4@;6EN;W(L"B`@("`@("`@("`@=&AE(')E<W0@:7,@
M96ET:&5R(&$@8VQA<W-I9FEC871I;VX@*&1E=BP@8W9S*2!O<B!A('-U8FUI
M;F]R"B`@("`@("`@("`@=F5R<VEO;B`H<F,\>#XL('!L/'@^*2X@*B\*("`@
M("`@("`D<&AP=F5R6R=M:6YO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`P+"`D
M<RD["B`@("`@("`@:68@*"AS=')L96XH)'9E<G-I;VXI(#X@)',I("8F"B`@
M("`@("`@("`@("@H)'9E<G-I;VY;)'-=(#T]("<N)RD@?'P@*"1V97)S:6]N
M6R1S72`]/2`G+2<I*2D@>PH@("`@("`@("`@("`D<RLK.PH@("`@("`@('T*
M("`@("`@("`D<&AP=F5R6R=S=6)M:6YO<B==(#T@<W5B<W1R*"1V97)S:6]N
M+"`D<RD["B`@("`@("`@:68@*"@D<&AP=F5R6R=S=6)M:6YO<B==(#T]("=C
M=G,G*2!\?`H@("`@("`@("`@("`H)'!H<'9E<ELG<W5B;6EN;W(G72`]/2`G
M9&5V)RD@?'P*("`@("`@("`@("`@*'-U8G-T<B@D<&AP=F5R6R=S=6)M:6YO
M<B==+"`P+"`R*2`]/2`G<F,G*2D@>PH@("`@("`@("`@("!U;G-E="@D<&AP
M=F5R6R=S=6)M:6YO<B==*3L*("`@("`@("`@("`@)'!H<'9E<ELG8VQA<W,G
M72`]("=D978G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A
M)'!H<'9E<ELG<W5B;6EN;W(G72D@>PH@("`@("`@("`@("`@("`@=6YS970H
M)'!H<'9E<ELG<W5B;6EN;W(G72D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'!H<'9E<ELG8VQA<W,G72`]("=R96QE87-E)SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<&AP=F5R.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VL@=&AE(&QI<W0@;V8@4$A0(&UO9'5L97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1M;V1L:7-T("!4:&4@;6]D=6QE(&QI<W0N"B`@("`@
M*B`\<')E/@H@("`@("H@2T59.B`@(&UO9'5L92!N86UE"B`@("`@*B!604Q5
M13H@16ET:&5R('1H92!D97-C<FEP=&EO;B!O<B!A;B!A<G)A>2!W:71H('1H
M92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@("`@("`G9&5S8W)I<"<@
M("TM("!-;V1U;&4@1&5S8W)I<'1I;VX*("`@("`J("`@("`@("`G97)R;W(G
M("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@("`@("`@)W!H<'9E<B<@
M("`M+2`@5&AE(%!(4"!V97)S:6]N(&%B;W9E('=H:6-H('1O(&1O('1H92!T
M97-T"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE($A434P@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!P:'!-
M;V1U;&5#:&5C:R@D;6]D;&ES="D*("`@('L*("`@("`@("`D;W5T<'5T(#T@
M)R<["B`@("`@("`@)&]U='!U=%]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@
M(&9O<F5A8V@@*"1M;V1L:7-T(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("`D97)R;W)?;7-G(#T@)&UO9%]T97-T(#T@)'-T871U<U]O=70@/2`D
M9F%T86P@/2!N=6QL.PH@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH*
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@("`@
M("`@("`D9&5S8W)I<"`]("1V86Q;)V1E<V-R:7`G73L*("`@("`@("`@("`@
M("`@("1F871A;"`]("%E;7!T>2@D=F%L6R=F871A;"==*3L*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D=F%L6R=P:'!V97(G72D@)B8*("`@("`@("`@
M("`@("`@("`@("`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)'9A
M;%LG<&AP=F5R)UTI(#T]("TQ*2D@>PH@("`@("`@("`@("`@("`@("`@("1M
M;V1?=&5S="`]('1R=64["B`@("`@("`@("`@("`@("`@("`@)'-T871U<U]O
M=70@/2`G3B]!)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D=F%L6R=E<G)O<B==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1E<G)O<E]M<V<@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1E
M<V-R:7`@/2`D=F%L.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M:7-?;G5L;"@D<W1A='5S7V]U="DI('L*("`@("`@("`@("`@("`@("1M;V1?
M=&5S="`](&5X=&5N<VEO;E]L;V%D960H)&ME>2D["B`@("`@("`@("`@("`@
M("`D<W1A='5S7V]U="`]("1T:&ES+3Y?<W1A='5S*"1M;V1?=&5S="P@)&9A
M=&%L*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&5N=')Y6UT@/2`D
M9&5S8W)I<#L*("`@("`@("`@("`@)&5N=')Y6UT@/2`D<W1A='5S7V]U=#L*
M"B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D97)R;W)?;7-G*2`F)B`A)&UO
M9%]T97-T*2!["B`@("`@("`@("`@("`@("`D96YT<GE;72`]("1E<G)O<E]M
M<V<["B`@("`@("`@("`@("`@("!I9B`H(21F871A;"D@>PH@("`@("`@("`@
M("`@("`@("`@("1E;G1R>5M=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U
M='!U=$QI;F4H)&5N=')Y*3L*"B`@("`@("`@("`@(&EF("@D9F%T86P@)B8@
M(21M;V1?=&5S="D@>PH@("`@("`@("`@("`@("`@96-H;R`D;W5T<'5T.PH@
M("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@=&AE(&QI<W0@;V8@4$A0('-E='1I;F=S+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D;6]D;&ES="`@5&AE('-E='1I;F=S(&QI<W0N
M"B`@("`@*B`\8V]D93X*("`@("`J($M%63H@("!S971T:6YG(&YA;64*("`@
M("`J(%9!3%5%.B!!;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE
M<SH*("`@("`J("`@("`@("`G97)R;W(G("`@("TM("!%<G)O<B!-97-S86=E
M"B`@("`@*B`@("`@("`@)W-E='1I;F<G("`M+2`@0F]O;&5A;B`M('-H;W5L
M9"!T:&4@<V5T=&EN9R!B92!O;B!O<B!O9F8*("`@("`J(#PO8V]D93X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@;W5T<'5T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P:'!3971T:6YG0VAE8VLH)'-E='1I;F=S
M7VQI<W0I"B`@("!["B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("!F
M;W)E86-H("@D<V5T=&EN9W-?;&ES="!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@)')E<W5L
M="`]("AI;FE?9V5T*"1K97DI(#T]("1V86Q;)W-E='1I;F<G72D["@H@("`@
M("`@("`@("`D96YT<GE;72`]("1K97D@+B`G("<@+B`H*"1V86Q;)W-E='1I
M;F<G72`]/3T@=')U92D@/R`G96YA8FQE9"<@.B`G9&ES86)L960G*3L*("`@
M("`@("`@("`@)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<R@D<F5S=6QT*3L*
M"B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@
M)&5N=')Y6UT@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@;&ES="!O9B!014%2(&UO9'5L97,N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P96%R7VQI<W0@(%1H92!0
M14%2(&UO9'5L92!L:7-T+@H@("`@("H@/'!R93X*("`@("`J($M%63H@("!0
M14%2(&-L87-S(&YA;64*("`@("`J(%9!3%5%.B!!;B!A<G)A>2!W:71H('1H
M92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@("`@("`G9&5P96YD<R<@
M("`M+2`@5&AI<R!M;V1U;&4@9&5P96YD<R!O;B!A;F]T:&5R(&UO9'5L90H@
M("`@("H@("`@("`@("=E<G)O<B<@("`@("TM("!%<G)O<B!-97-S86=E"B`@
M("`@*B`@("`@("`@)V9U;F-T:6]N)R`@+2T@(%)E9F5R96YC92!T;R!F=6YC
M=&EO;B!T;R!R=6X@:68@;6]D=6QE(&ES(&9O=6YD"B`@("`@*B`@("`@("`@
M)W!A=&@G("`@("`@+2T@(%1H92!P871H('1O('1H92!014%2(&UO9'5L90H@
M("`@("H@("`@("`@("=R97%U:7)E9"<@("TM("!)<R!T:&ES(%!%05(@;6]D
M=6QE(')E<75I<F5D/R`H8F]O;&5A;BD*("`@("`J(#PO<')E/@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%!%05)-;V1U;&5#:&5C:R@D<&5A<E]L:7-T*0H@
M("`@>PH@("`@("`@("1O=71P=70@/2`G)SL*"B`@("`@("`@+RH@5'5R;B!T
M<F%C:VEN9R!O9B!E<G)O<G,@;VXN("HO"B`@("`@("`@:6YI7W-E="@G=')A
M8VM?97)R;W)S)RP@,2D["@H@("`@("`@("\J(%!R:6YT('1H92!I;F-L=61E
M7W!A=&@N("HO"B`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI
M;F4H87)R87DH(CQS=')O;F<^4$5!4B!396%R8V@@4&%T:"`H4$A0)W,@:6YC
M;'5D95]P871H*3PO<W1R;VYG/B(L("<F;F)S<#L\='0^)R`N(&EN:5]G970H
M)VEN8VQU9&5?<&%T:"<I("X@)SPO='0^)RDI.PH*("`@("`@("`O*B!#:&5C
M:R!F;W(@4$5!4B!I;B!G96YE<F%L+B`J+PH@("`@("`@('L*("`@("`@("`@
M("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@)&5N=')Y6UT@/2`G
M4$5!4B<["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*
M("`@("`@("`@("`@)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<R@A:7-S970H
M)'!H<%]E<G)O<FUS9RDI.PH@("`@("`@("`@("!I9B`H:7-S970H)'!H<%]E
M<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)T-H96-K
M('EO=7(@4$A0(&EN8VQU9&5?<&%T:"!S971T:6YG('1O(&UA:V4@<W5R92!I
M="!H87,@=&AE(%!%05(@;&EB<F%R>2!D:7)E8W1O<GDN)SL*("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*"1E;G1R>2D[
M"B`@("`@("`@("`@("`@("!I;FE?<F5S=&]R92@G=')A8VM?97)R;W)S)RD[
M"B`@("`@("`@("`@("`@("!R971U<FX@)&]U='!U=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D
M96YT<GDI.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(&$@<F5C
M96YT(%!%05(@=F5R<VEO;BX@*B\*("`@("`@("`D96YT<GD@/2!A<G)A>2@I
M.PH@("`@("`@("1N97=P96%R(#T@)'1H:7,M/FES4F5C96YT4$5!4B@I.PH@
M("`@("`@("1E;G1R>5M=(#T@)U)E8V5N="!014%2)SL*("`@("`@("`D96YT
M<GE;72`]("1T:&ES+3Y?<W1A='5S*"1N97=P96%R*3L*("`@("`@("!I9B`H
M(21N97=P96%R*2!["B`@("`@("`@("`@("1E;G1R>5M=(#T@)U1H:7,@=F5R
M<VEO;B!O9B!014%2(&ES(&YO="!R96-E;G0@96YO=6=H+B!3964@=&AE(#QA
M(&AR968](FAT='`Z+R]W=W<N:&]R9&4N;W)G+W!E87(O(CY(;W)D92!014%2
M('!A9V4\+V$^(&9O<B!D971A:6QS+B<["B`@("`@("`@?0H@("`@("`@("1O
M=71P=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*"1E;G1R>2D["@H@("`@("`@
M("\J($=O('1H<F]U9V@@;6]D=6QE(&QI<W0N("HO"B`@("`@("`@)'-U8V-E
M961E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'!E87)?;&ES="!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH
M*3L*"B`@("`@("`@("`@("\J($EF('1H:7,@;6]D=6QE(&1E<&5N9',@;VX@
M86YO=&AE<B!M;V1U;&4@=&AA="!W90H@("`@("`@("`@("`@*B!H879E;B=T
M('-U8V-E<V9U;&QY(&9O=6YD+"!F86EL('1H92!T97-T+B`J+PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1V86Q;)V1E<&5N9',G72D@)B8@96UP='DH)'-U
M8V-E961E9%LD=F%L6R=D97!E;F1S)UU=*2D@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`](&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)')E<W5L="`]($!I;F-L=61E7V]N8V4@)'9A;%LG<&%T:"==
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E<G)O<E]M<V<@/2`D=F%L
M6R=E<G)O<B==.PH@("`@("`@("`@("!I9B`H)')E<W5L="`F)B!I<W-E="@D
M=F%L6R=F=6YC=&EO;B==*2D@>PH@("`@("`@("`@("`@("`@)&9U;F-?;W5T
M<'5T(#T@8V%L;%]U<V5R7V9U;F,H)'9A;%LG9G5N8W1I;VXG72D["B`@("`@
M("`@("`@("`@("!I9B`H)&9U;F-?;W5T<'5T*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E<W5L="`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("1E
M<G)O<E]M<V<@/2`D9G5N8U]O=71P=70["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&5N=')Y6UT@/2`D:V5Y.PH@("`@
M("`@("`@("`D96YT<GE;72`]("1T:&ES+3Y?<W1A='5S*"1R97-U;'0L("%E
M;7!T>2@D=F%L6R=R97%U:7)E9"==*2D["@H@("`@("`@("`@("!I9B`H)')E
M<W5L="D@>PH@("`@("`@("`@("`@("`@)'-U8V-E961E9%LD:V5Y72`]('1R
M=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1V86Q;)W)E<75I<F5D)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&5R<F]R7VUS9R`N/2`G(%1(25,@25,@02!215%525)%1"!-3T153$4A
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1E;G1R>5M=
M(#T@)&5R<F]R7VUS9SL*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L
M6R=R97%U:7)E9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R>5M=
M(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%)E<W1O<F4@<')E=FEO=7,@=F%L=64@
M;V8@)W1R86-K7V5R<F]R<R<N("HO"B`@("`@("`@:6YI7W)E<W1O<F4H)W1R
M86-K7V5R<F]R<R<I.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K('1H92!L:7-T(&]F(')E<75I<F5D(&9I
M;&5S"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:6QE7VQI<W0@(%1H
M92!F:6QE(&QI<W0N"B`@("`@*B`\<')E/@H@("`@("H@2T59.B`@(&9I;&4@
M<&%T:`H@("`@("H@5D%,544Z(%1H92!E<G)O<B!M97-S86=E('1O('5S92`H
M;G5L;"!T;R!U<V4@9&5F875L="!M97-S86=E*0H@("`@("H@/"]P<F4^"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]U='!U="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q=6ER961&:6QE0VAE8VLH)&9I;&5?
M;&ES="D*("`@('L*("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@(&9O
M<F5A8V@@*"1F:6QE7VQI<W0@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("1E;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("1R97-U;'0@/2!F
M:6QE7V5X:7-T<R@G+B\G("X@)&ME>2D["@H@("`@("`@("`@("`D96YT<GE;
M72`]("1K97D["B`@("`@("`@("`@("1E;G1R>5M=(#T@)'1H:7,M/E]S=&%T
M=7,H)')E<W5L="D["@H@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1E;G1R>5M=(#T@)U1H92!F:6QE(#QC;V1E/B<@+B`D:V5Y("X@
M)SPO8V]D93X@87!P96%R<R!T;R!B92!M:7-S:6YG+B!9;W4@<')O8F%B;'D@
M:G5S="!F;W)G;W0@=&\@8V]P>2`\8V]D93XG("X@)&ME>2`N("<N9&ES=#PO
M8V]D93X@;W9E<BX@5VAI;&4@>6]U(&1O('1H870L('1A:V4@82!L;V]K(&%T
M('1H92!S971T:6YG<R!A;F0@;6%K92!S=7)E('1H97D@87)E(&%P<')O<')I
M871E(&9O<B!Y;W5R('-I=&4N)SL*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D=F%L.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;W5T<'5T
M("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M:7-P;&%Y<R!A;B!E<G)O<B!S8W)E96X@=VET:"!A(&QI<W0@;V8@86QL(&-O
M;F9I9W5R871I;VX@9FEL97,@=&AA=`H@("`@("H@87)E(&UI<W-I;F<L('1O
M9V5T:&5R('=I=&@@82!D97-C<FEP=&EO;B!W:&%T('1H97D@9&\@86YD(&AO
M=R!T:&5Y(&%R90H@("`@("H@8W)E871E9"X@268@82!F:6QE(&-A;B!B92!A
M=71O;6%T:6-A;&QY(&-R96%T960@9G)O;2!T:&4@9&5F875L=',L('1H96X*
M("`@("`J('=E(&1O('1H870@:6YS=&5A9"!A;F0@9&]N)W0@9&ES<&QA>2!A
M;B!E<G)O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@
M("`@(%1H92!A<'!L:6-A=&EO;B!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A<'!"87-E("`@(%1H92!P871H('1O('1H92!A<'!L:6-A=&EO;@H@("`@
M("H@0'!A<F%M(&%R<F%Y("`D9FEL97,@("`@("!!;B!A<G)A>2!W:71H('1H
M92`B<W1A;F1A<F0B(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9FEL97,@=&AA="!S:&]U;&0@8F4@8VAE8VME9"X@
M0W5R<F5N=&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-U
M<'!O<G1E9#H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!C
M;VYF+G!H<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`M('!R
M969S+G!H<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`M(&UI
M;65?9')I=F5R<RYP:'`*("`@("`J($!P87)A;2!A<G)A>2`D861D:71I;VYA
M;"`@06X@87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!M;W)E(&9I;&5S
M("AA<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!K97ES*2!A
M;F0@97)R;W(@;65S<V%G92`H87,@=F%L=65S*2!I9B!T:&5Y"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&1O;B=T(&5X:7-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;VYF:6=&:6QE<TUI<W-I;F<H)&%P<"P@)&%P<$)A
M<V4L("1F:6QE<RP@)&%D9&ET:6]N86P@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@("\J(%1R>2!T;R!L;V%D(&$@8F%S:6,@9G)A;65W;W)K(&EF('=E)W)E
M('1E<W1I;F<@86X@87!P(&]T:&5R('1H86X*("`@("`@("`@*B!T:&4@2&]R
M9&4@8F%S92!F:6QE<RX@*B\*("`@("`@("!I9B`H)&%P<"`A/2`G2&]R9&4G
M*2!["B`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==(#T@)E)E9VES
M=')Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/G!U<VA!<'`H)VAO<F1E)RP@9F%L<V4I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D9FEL97,I*2!["B`@("`@("`@("`@("1F
M:6QE<R`](&%R<F%Y*"1F:6QE<RD["B`@("`@("`@?0H@("`@("`@("1F:6QE
M<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@87)R87E?:V5Y<R@D861D:71I;VYA
M;"DI.PH*("`@("`@("`O*B!4<GD@=&\@875T;RUC<F5A=&4@;6ES<VEN9R`N
M9&ES="!F:6QE<RX@*B\*("`@("`@("`D:6YD:6-E<R`](&%R<F%Y7VME>7,H
M)&9I;&5S*3L*("`@("`@("!F;W)E86-H("@D:6YD:6-E<R!A<R`D:6YD97@I
M('L*("`@("`@("`@("`@:68@*&ES7W)E861A8FQE*"1A<'!"87-E("X@)R]C
M;VYF:6<O)R`N("1F:6QE<ULD:6YD97A=*2D@>PH@("`@("`@("`@("`@("`@
M=6YS970H)&9I;&5S6R1I;F1E>%TI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D87!P0F%S92`N("<O
M8V]N9FEG+R<@+B`D9FEL97-;)&EN9&5X72`N("<N9&ES="<I("8F"B`@("`@
M("`@("`@("`@("`@("`@0&-O<'DH)&%P<$)A<V4@+B`G+V-O;F9I9R\G("X@
M)&9I;&5S6R1I;F1E>%T@+B`G+F1I<W0G+"`D87!P0F%S92`N("<O8V]N9FEG
M+R<@+B`D9FEL97-;)&EN9&5X72DI('L*("`@("`@("`@("`@("`@("`@("!U
M;G-E="@D9FEL97-;)&EN9&5X72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!I9B!W92!H
M879E(&YO(&UI<W-I;F<@9FEL97,@;&5F="X@*B\*("`@("`@("!I9B`H(6-O
M=6YT*"1F:6QE<RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@)&1E<V-R:7!T:6]N<R`](&%R<F%Y7VUE<F=E*&%R<F%Y*`H@
M("`@("`@("`@("`G8V]N9BYP:'`G(#T^('-P<FEN=&8H)U1H:7,@:7,@=&AE
M(&UA:6X@)7,@8V]N9FEG=7)A=&EO;B!F:6QE+B`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=)="!C;VYT86EN<R!P871H<R!A;F0@
M;W!T:6]N<R!F;W(@=&AE("5S("<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W-C<FEP=',N(%EO=2!N965D('1O(&QO9VEN(&%S(&%N
M("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%D;6EN
M:7-T<F%T;W(@86YD(&-R96%T92!T:&4@9FEL92!W:71H("<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1H92!W96(@9G)O;G1E;F0@
M=6YD97(@(D%D;6EN:7-T<F%T:6]N(#T^("<@+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U-E='5P(BXG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&%P<"P@)&%P<"P@)&%P<$)A<V4@+B`G+V-O
M;F9I9R<I+`H@("`@("`@("`@("`G<')E9G,N<&AP)R`]/B!S<')I;G1F*"=4
M:&ES(&9I;&4@8V]N=')O;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<B`E<RP@
M86YD(&%L<V\@8V]N=')O;',@=VAI8V@@<')E9F5R96YC97,@)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)S(&-A;B!A;'1E
M<BXG+"`D87!P*2P*("`@("`@("`@("`@)VUI;65?9')I=F5R<RYP:'`G(#T^
M('-P<FEN=&8H)U1H:7,@9FEL92!C;VYT<F]L<R!L;V-A;"!-24U%("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9')I
M=F5R<R!F;W(@)7,L('-P96-I9FEC86QL>2!W:&%T("<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:VEN9',@;V8@9FEL
M97,@87)E('9I97=A8FQE(&%N9"]O<B`G("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1O=VYL;V%D86)L92XG+"`D87!P
M*2P*("`@("`@("`@("`@)V)A8VME;F1S+G!H<"<@/3X@<W!R:6YT9B@G5&AI
M<R!F:6QE(&-O;G1R;VQS('=H870@8F%C:V5N9',@87)E("<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A=F%I;&%B;&4@9G)O
M;2`E<RXG+"`D87!P*2P*("`@("`@("`@("`@)W-O=7)C97,N<&AP)R`]/B!S
M<')I;G1F*"=4:&ES(&9I;&4@9&5F:6YE<R!T:&4@;&ES="!O9B!A=F%I;&%B
M;&4@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<V]U<F-E<R!F;W(@)7,N)RP@)&%P<"D*("`@("`@("`I+"`D861D:71I;VYA
M;"D["@H@("`@("`@("\J($EF('=E(&MN;W<@=&AE('5S97(@:7,@86X@861M
M:6XL(&=I=F4@=&AE;2!A(&1I<F5C="!L:6YK('1O"B`@("`@("`@("H@9V5N
M97)A=&4@8V]N9BYP:'`N($EN('1H92!F=71U<F4L('-H;W5L9"!W92!T<GD@
M9V5N97)A=&EN9PH@("`@("`@("`J(&$@8F%S:6,@8V]N9BYP:'`@875T;VUA
M9VEC86QL>2!H97)E/R`J+PH@("`@("`@(&EF("A!=71H.CII<T%D;6EN*"DI
M('L*("`@("`@("`@("`@)'-E='5P7W5R;"`]($AO<F1E.CIL:6YK*$AO<F1E
M.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H
M;W)D92<I("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R]A9&UI;B]S971U<"]C;VYF:6<N<&AP/V%P<#TG("X@
M4W1R:6YG.CIL;W=E<B@D87!P*2DI("X*("`@("`@("`@("`@("`@("=#;VYF
M:6=U<F%T:6]N(%=E8B!);G1E<F9A8V4G("X@)SPO83XG.PH@("`@("`@("`@
M("`D9&5S8W)I<'1I;VYS6R=C;VYF+G!H<"==(#T*("`@("`@("`@("`@("`@
M('-P<FEN=&8H)U1H:7,@:7,@=&AE(&UA:6X@)7,@8V]N9FEG=7)A=&EO;B!F
M:6QE+B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@)T=E;F5R871E(&ET
M(&)Y(&=O:6YG('1O('1H92`E<RXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`D87!P+"`D<V5T=7!?=7)L*3L*("`@("`@("!]"@H@("`@("`@("1T:71L
M92`]('-P<FEN=&8H)R5S(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D)RP@
M)&%P<"D["B`@("`@("`@)&AE861E<B`]('-P<FEN=&8H)U-O;64@;V8@)7-<
M)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@;6ES<VEN9R!O<B!U;G)E861A
M8FQE)RP@)&%P<"D["B`@("`@("`@)&9O;W1E<B`]('-P<FEN=&8H)T-R96%T
M92!T:&5S92!F:6QE<R!F<F]M('1H96ER("YD:7-T('9E<G-I;VYS(&EN("5S
M(&%N9"!C:&%N9V4@=&AE;2!A8V-O<F1I;F<@=&\@>6]U<B!N965D<RXG+"`D
M87!P0F%S92`N("<O8V]N9FEG)RD["@H@("`@("`@(&5C:&\@/#P\($A%041%
M4@H\:'1M;#X*/&AE860^/'1I=&QE/B1T:71L93PO=&ET;&4^/"]H96%D/@H\
M8F]D>2!S='EL93TB8F%C:V=R;W5N9"UC;VQO<CH@=VAI=&4[(&-O;&]R.B!B
M;&%C:SLB/@H\:#$^)&AE861E<CPO:#$^"DA%041%4CL*"B`@("`@("`@9F]R
M96%C:"`H)&9I;&5S(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("AE;7!T
M>2@D9&5S8W)I<'1I;VYS6R1F:6QE72DI('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D97-C<FEP=&EO
M;B`]("1D97-C<FEP=&EO;G-;)&9I;&5=.PH@("`@("`@("`@("!E8VAO(#P\
M/"!&24Q%"B`@("`\:#,^)&9I;&4\+V@S/CQP/B1D97-C<FEP=&EO;CPO<#X*
M1DE,13L*("`@("`@("!]"@H@("`@("`@(&5C:&\@/#P\($9/3U1%4@H*/&@R
M/B1F;V]T97(\+V@R/@H\+V)O9'D^"CPO:'1M;#X*1D]/5$52.PH@("`@("`@
M(&5X:70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@;&ES="!O
M9B!R97%U:7)E9"!(;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1A<'!?;&ES="`@5&AE(&%P<&QI8V%T:6]N(&QI<W0N
M"B`@("`@*B`\<')E/@H@("`@("H@2T59.B`@(&%P<&QI8V%T:6]N(&YA;64*
M("`@("`J(%9!3%5%.B!!;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@96YT
M<FEE<SH*("`@("`J("`@("`@("`G97)R;W(G("`@("TM("!%<G)O<B!-97-S
M86=E"B`@("`@*B`@("`@("`@)W9E<G-I;VXG("`M+2`@5&AE(&UI;FEM=6T@
M=F5R<VEO;B!R97%U:7)E9`H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]U='!U="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5Q=6ER961!<'!#:&5C:R@D87!P7VQI<W0I"B`@("!["B`@
M("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`D87!P<R`]("1T:&ES+3YA
M<'!L:6-A=&EO;DQI<W0H*3L*"B`@("`@("`@9F]R96%C:"`H)&%P<%]L:7-T
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D96YT<GD@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`D96YT<GE;72`]("1K97D["@H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1A<'!S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@
M)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<RAF86QS92D["B`@("`@("`@("`@
M("`@("`D96YT<GE;72`]("1V86Q;)V5R<F]R)UT["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O*B!3=')I<"`G+6-V<R<@86YD($@S
M("AV97(I(&9R;VT@=F5R<VEO;B!S=')I;F<N("HO"B`@("`@("`@("`@("`@
M("`D87!P=F5R(#T@<W1R7W)E<&QA8V4H)RUC=G,G+"`G)RP@)&%P<'-;)&ME
M>5TM/G9E<G-I;VXI.PH@("`@("`@("`@("`@("`@)&%P<'9E<B`]('!R96=?
M<F5P;&%C92@G+T@S(%PH*"XJ*5PI+R<L("<D,2<L("1A<'!V97(I.PH@("`@
M("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F%L6R=V97)S:6]N
M)UTL("1A<'!V97(I(#T]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&5N
M=')Y6UT@/2`D=&AI<RT^7W-T871U<RAF86QS92D@+B`G("A(879E('9E<G-I
M;VXZ("<@+B`D87!P<ULD:V5Y72T^=F5R<VEO;B`N("<[($YE960@=F5R<VEO
M;CH@)R`N("1V86Q;)W9E<G-I;VXG72`N("<I)SL*("`@("`@("`@("`@("`@
M("`@("`D96YT<GE;72`]("1V86Q;)V5R<F]R)UT["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)'1H
M:7,M/E]S=&%T=7,H=')U92D@+B`G("A697)S:6]N.B`G("X@)&%P<'-;)&ME
M>5TM/G9E<G-I;VX@+B`G*2<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI
M;F4H)&5N=')Y*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T
M.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AI<R!A("=R96-E;G0G('9E
M<G-I;VX@;V8@4$5!4C\*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@
M5')U92!I9B!A(')E8V5N="!V97)S:6]N(&]F(%!%05(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES4F5C96YT4$5!4B@I"B`@("!["B`@("`@("`@0&EN8VQU
M9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("1P96%R7VUE=&AO9',@/2!G
M971?8VQA<W-?;65T:&]D<R@G4$5!4B<I.PH@("`@("`@(')E='5R;B`H:7-?
M87)R87DH)'!E87)?;65T:&]D<RD@)B8*("`@("`@("`@("`@("`@("AI;E]A
M<G)A>2@G<F5G:7-T97)S:'5T9&]W;F9U;F,G+"`D<&5A<E]M971H;V1S*2!\
M?`H@("`@("`@("`@("`@("`@(&EN7V%R<F%Y*"=R96=I<W1E<E-H=71D;W=N
M1G5N8R<L("1P96%R7VUE=&AO9',I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!/8G1A:6X@:6YF;W)M871I;VX@;VX@=&AE(%!(4"!V97)S:6]N+@H@("`@
M("H*("`@("`J($!R971U<FX@;V)J96-T('-T9$-L87-S("!43T1/"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!H<%9E<G-I;VY);F9O<FUA=&EO;B@I"B`@
M("!["B`@("`@("`@)&]U='!U="`]("9N97<@<W1D0VQA<W,["B`@("`@("`@
M)'5R;"`]('5R;&5N8V]D92@D7U-%4E9%4ELG4$A07U-%3$8G72D["B`@("`@
M("`@)'9E<G-?8VAE8VL@/2!T<G5E.PH*("`@("`@("`D=&5S='-C<FEP="`]
M("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO<F1E)UU;)W=E8G)O;W0G72`N("<O
M=&5S="YP:'`G.PH@("`@("`@("1O=71P=70M/G!H<&EN9F\@/2`D=&5S='-C
M<FEP="`N("<_;6]D93UP:'!I;F9O)G5R;#TG("X@)'5R;#L*("`@("`@("`D
M;W5T<'5T+3YE>'1E;G-I;VYS(#T@)'1E<W1S8W)I<'0@+B`G/VUO9&4]97AT
M96YS:6]N<R9U<FP])R`N("1U<FP["B`@("`@("`@)&]U='!U="T^=F5R<VEO
M;B`]('!H<'9E<G-I;VXH*3L*("`@("`@("`D;W5T<'5T+3YM86IO<B`]("1T
M:&ES+3Y?<&AP=F5R6R=M86IO<B==.PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!H<'9E<ELG;6EN;W(G72DI('L*("`@("`@("`@("`@)&]U='!U="T^
M;6EN;W(@/2`D=&AI<RT^7W!H<'9E<ELG;6EN;W(G73L*("`@("`@("!]"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&AP=F5R6R=S=6)M:6YO<B==*2D@
M>PH@("`@("`@("`@("`D;W5T<'5T+3YS=6)M:6YO<B`]("1T:&ES+3Y?<&AP
M=F5R6R=S=6)M:6YO<B==.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T+3YC
M;&%S<R`]("1T:&ES+3Y?<&AP=F5R6R=C;&%S<R==.PH*("`@("`@("`D;W5T
M<'5T+3YS=&%T=7-?8V]L;W(@/2`G<F5D)SL*("`@("`@("!I9B`H)&]U='!U
M="T^;6%J;W(@/"`G-"XS)RD@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%T
M=7,@/2`G5&AI<R!V97)S:6]N(&]F(%!(4"!I<R!N;W0@<W5P<&]R=&5D+B!9
M;W4@;F5E9"!T;R!U<&=R861E('1O(&$@;6]R92!R96-E;G0@=F5R<VEO;BXG
M.PH@("`@("`@("`@("`D=F5R<U]C:&5C:R`](&9A;'-E.PH@("`@("`@('T@
M96QS96EF("@H)&]U='!U="T^;6%J;W(@/3T@)S0N,R<I('Q\"B`@("`@("`@
M("`@("`@("`@("@D;W5T<'5T+3YM86IO<B`]/2`G-"XT)RD@?'P*("`@("`@
M("`@("`@("`@("`@*"1O=71P=70M/FUA:F]R(#T]("<U+C`G*2!\?`H@("`@
M("`@("`@("`@("`@("`H)&]U='!U="T^;6%J;W(@/3T@)S4N,2<I*2!["B`@
M("`@("`@("`@("1O=71P=70M/G-T871U<R`]("=9;W4@87)E(')U;FYI;F<@
M82!S=7!P;W)T960@=F5R<VEO;B!O9B!02%`N)SL*("`@("`@("`@("`@)&]U
M='!U="T^<W1A='5S7V-O;&]R(#T@)V=R965N)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%T=7,@/2`G5V]W+"!A(&UY<W1I
M8V%L('9E<G-I;VX@;V8@4$A0(&9R;VT@=&AE(&9U='5R92X@3&5T(#QA(&AR
M968](FUA:6QT;SID979`;&ES=',N:&]R9&4N;W)G(CYD979`;&ES=',N:&]R
M9&4N;W)G/"]A/B!K;F]W('=H870@=F5R<VEO;B!Y;W4@:&%V92!S;R!W92!C
M86X@9FEX('1H:7,@<V-R:7!T+B<["B`@("`@("`@("`@("1O=71P=70M/G-T
M871U<U]C;VQO<B`]("=O<F%N9V4G.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"$D=F5R<U]C:&5C:RD@>PH@("`@("`@("`@("`D;W5T<'5T+3YV97)S:6]N
M7V-H96-K(#T@)TAO<F1E(')E<75I<F5S(%!(4"`T+C,N,"!O<B!G<F5A=&5R
M+B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@87!P;&EC871I;VX@;&ES="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!,:7-T(&]F('-T9$-L87-S(&]B
M:F5C=',N"B`@("`@*B`@("`@("`@("`@("`@("!+15DZ(&%P<&QI8V%T:6]N
M(&YA;64*("`@("`J("`@("`@("`@("`@("`@($5,14U%3E0@)W9E<G-I;VXG
M.B!697)S:6]N(&]F(&%P<&QI8V%T:6]N"B`@("`@*B`@("`@("`@("`@("`@
M("!%3$5-14Y4("=T97-T)SH@5&AE(&QO8V%T:6]N(&]F('1H92!T97-T('-C
M<FEP="`H:68@86YY*0H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO
M;DQI<W0H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]A<'!O
M=71P=70I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%P<&]U='!U
M=#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YA<'!L:6-A
M=&EO;G,@87,@)&UO9"`]/B`D9&5T*2!["B`@("`@("`@("`@(&EF("@H)&1E
M=%LG<W1A='5S)UT@(3T@)VAE861I;F<G*2`F)@H@("`@("`@("`@("`@("`@
M*"1D971;)W-T871U<R==("$]("=B;&]C:R<I("8F"B`@("`@("`@("`@("`@
M("!I<U]R96%D86)L92@D9&5T6R=F:6QE<F]O="==("X@)R]L:6(O=F5R<VEO
M;BYP:'`G*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1D971;
M)V9I;&5R;V]T)UT@+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@("`@("`@("`@
M("`@("`D=F5R<VEO;E]C;VYS=&%N="`](%-T<FEN9SHZ=7!P97(H)&UO9"D@
M+B`G7U9%4E-)3TXG.PH@("`@("`@("`@("`@("`@:68@*&1E9FEN960H)'9E
M<G-I;VY?8V]N<W1A;G0I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A<'!O=71P=71;)&UO9%T@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?87!P;W5T<'5T6R1M;V1=+3YV97)S:6]N(#T@
M8V]N<W1A;G0H)'9E<G-I;VY?8V]N<W1A;G0I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@H)&UO9"`A/2`G:&]R9&4G*2`F)@H@("`@("`@("`@("`@("`@
M("`@("`@("!`:7-?<F5A9&%B;&4H)&1E=%LG9FEL97)O;W0G72`N("<O=&5S
M="YP:'`G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%P
M<&]U='!U=%LD;6]D72T^=&5S="`]("1D971;)W=E8G)O;W0G72`N("<O=&5S
M="YP:'`G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?87!P;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T
M('1H92!R97-U;'1S(&]F(&$@<W1A='5S(&-H96-K+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1B;V]L("`@("`@5&AE(')E<W5L="!O9B!T:&4@<W1A='5S(&-H96-K+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)')E<75I<F5D("!7:&5T:&5R('1H92!C
M:&5C:V5D(&ET96T@:7,@<F5Q=6ER960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!(5$U,(&]F('1H92!R97-U;'0@;V8@=&AE('-T871U
M<R!C:&5C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-T871U<R@D8F]O;"P@
M)')E<75I<F5D(#T@=')U92D*("`@('L*("`@("`@("!I9B`H)&)O;VPI('L*
M("`@("`@("`@("`@<F5T=7)N("<\9F]N="!C;VQO<CTB9W)E96XB/CQS=')O
M;F<^665S/"]S=')O;F<^/"]F;VYT/B<["B`@("`@("`@?2!E;'-E:68@*"1R
M97%U:7)E9"D@>PH@("`@("`@("`@("!R971U<FX@)SQF;VYT(&-O;&]R/2)R
M960B/CQS=')O;F<^3F\\+W-T<F]N9SX\+V9O;G0^)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@)SQF;VYT(&-O;&]R/2)O<F%N9V4B
M/CQS=')O;F<^3F\\+W-T<F]N9SX\+V9O;G0^)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!);G1E<FYA;"!O=71P=70@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1E;G1R>2`@,R!E;&5M96YT(&%R<F%Y+@H@("`@("H@/'!R
M93X*("`@("`J(#%S="!V86QU93H@2&5A9&5R"B`@("`@*B`R;F0@=F%L=64Z
M(%1E<W0@4F5S=6QT"B`@("`@*B`S<F0@=F%L=64Z($5R<F]R(&UE<W-A9V4@
M*&EF('!R97-E;G0I"B`@("`@*B`T=&@@=F%L=64Z($5R<F]R(&QE=F5L("AI
M9B!P<F5S96YT*3H@,"`](&5R<F]R+"`Q(#T@=V%R;FEN9PH@("`@("H@/"]P
M<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($A434P@;W5T<'5T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;W5T<'5T3&EN92@D96YT<GDI"B`@
M("!["B`@("`@("`@)&]U='!U="`]("<\;&D^)R`N(&%R<F%Y7W-H:69T*"1E
M;G1R>2D@+B`G.B`G("X@87)R87E?<VAI9G0H)&5N=')Y*3L*("`@("`@("!I
M9B`H(65M<'1Y*"1E;G1R>2DI('L*("`@("`@("`@("`@)&US9R`](&%R<F%Y
M7W-H:69T*"1E;G1R>2D["B`@("`@("`@("`@("1O=71P=70@+CT@)SQB<B`O
M/CQF;VYT(&-O;&]R/2(G("X@*&5M<'1Y*"1E;G1R>2D@?'P@(6%R<F%Y7W-H
M:69T*"1E;G1R>2D@/R`G<F5D)R`Z("=O<F%N9V4G*2`N("<B/CQS=')O;F<^
M)R`N("1M<V<@+B`G/"]S=')O;F<^/"]F;VYT/B<@+B`B7&XB.PH@("`@("`@
M('T*("`@("`@("`D;W5T<'5T("X]("<\+VQI/B<@+B`B7&XB.PH*("`@("`@
M("!R971U<FX@)&]U='!U=#L*("`@('T*"GT*````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92YP:'``````````````````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q-34R,#(`,3`U,34T,S$P-C$`,#$V-S,R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@II
M;F-L=61E7V]N8V4@)TQO9RYP:'`G.PII;F-L=61E7V]N8V4@)TAO<F1E+U5T
M:6PN<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&4Z.B!C;&%S<R!P<F]V:61E<R!T
M:&4@9G5N8W1I;VYA;&ET>2!S:&%R960@8GD@86QL($AO<F1E"B`J(&%P<&QI
M8V%T:6]N<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP+'8@,2XT.#DN,BXU-"`R,#`V+S`W+S,Q(#`X.C0Y.C0W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T9R86UE=V]R:PH@*B\*8VQA
M<W,@2&]R9&4@>PH*("`@("\J*@H@("`@("H@3&]G<R!A(&UE<W-A9V4@=&\@
M=&AE(&=L;V)A;"!(;W)D92!L;V<@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&UE<W-A9V4@("`@($5I=&AE<B!A('-T<FEN9R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL
M92`@("`@("!7:&%T(&9I;&4@=V%S('1H92!L;V<@9G5N8W1I;VX@8V%L;&5D
M(&9R;VT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@*&4N9RX@
M7U]&24Q%7U\I/PH@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;F4@("`@("!7
M:&%T(&QI;F4@=V%S('1H92!L;V<@9G5N8W1I;VX@8V%L;&5D(&9R;VT*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@*&4N9RX@7U],24Y%7U\I
M/PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'!R:6]R:71Y("!4:&4@<')I;W)I
M='D@;V8@=&AE(&UE<W-A9V4N($]N92!O9CH*("`@("`J(#QP<F4^"B`@("`@
M*B!014%27TQ/1U]%34521PH@("`@("H@4$5!4E],3T=?04Q%4E0*("`@("`J
M(%!%05)?3$]'7T-2250*("`@("`J(%!%05)?3$]'7T524@H@("`@("H@4$5!
M4E],3T=?5T%23DE.1PH@("`@("H@4$5!4E],3T=?3D]424-%"B`@("`@*B!0
M14%27TQ/1U])3D9/"B`@("`@*B!014%27TQ/1U]$14)51PH@("`@("H@/"]P
M<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9TUE<W-A9V4H)&UE<W-A9V4L
M("1F:6QE+"`D;&EN92P@)'!R:6]R:71Y(#T@4$5!4E],3T=?24Y&3RD*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("@A)&-O;F9;
M)VQO9R==6R=E;F%B;&5D)UTI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1P<FEO<FET>2`^("1C;VYF6R=L;V<G75LG
M<')I;W)I='DG72D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*
M("`@("`@("`D;&]G9V5R(#T@)DAO<F1E.CIG971,;V=G97(H*3L*("`@("`@
M("!I9B`H(6ES7V$H)&QO9V=E<BP@)TQO9R<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=!;B!E<G)O<B!H87,@;V-C
M=7)R960N($9U<G1H97)M;W)E+"!(;W)D92!E;F-O=6YT97)E9"!A;B!E<G)O
M<B!A='1E;7!T:6YG('1O(&QO9R!T:&ES(&5R<F]R+B!0;&5A<V4@8VAE8VL@
M>6]U<B!(;W)D92!L;V=G:6YG(&-O;F9I9W5R871I;VX@:6X@:&]R9&4O8V]N
M9FEG+V-O;F8N<&AP+B<I+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1M97-S86=E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1U<V5R:6YF;R`]("1M97-S86=E+3YG
M9715<V5R26YF;R@I.PH@("`@("`@("`@("`D;65S<V%G92`]("1M97-S86=E
M+3YG971-97-S86=E*"D["B`@("`@("`@("`@(&EF("@A96UP='DH)'5S97)I
M;F9O*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1U<V5R:6YF
M;RDI('L*("`@("`@("`@("`@("`@("`@("`D=7-E<FEN9F\@/2!`:6UP;&]D
M92@G+"`G+"`D=7-E<FEN9F\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@+CT@)SH@)R`N("1U<V5R:6YF;SL*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("AI<U]C86QL86)L92AA<G)A>2@D
M;65S<V%G92P@)V=E=$UE<W-A9V4G*2DI('L*("`@("`@("`@("`@)&UE<W-A
M9V4@/2`D;65S<V%G92T^9V5T365S<V%G92@I.PH@("`@("`@('T*"B`@("`@
M("`@)&%P<"`](&ES<V5T*"1'3$]"04Q36R=R96=I<W1R>2==*2`_("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG971!<'`H*2`Z("=H;W)D92<["B`@("`@("`@
M)&UE<W-A9V4@/2`G6R<@+B`D87!P("X@)UT@)R`N("1M97-S86=E("X@)R!;
M;VX@;&EN92`G("X@)&QI;F4@+B`G(&]F("(G("X@)&9I;&4@+B`G(ETG.PH*
M("`@("`@("`O*B!-86ME('-U<F4@=&\@;&]G(&EN('1H92!S>7-T96TG<R!L
M;V-A;&4N("HO"B`@("`@("`@)&QO8V%L92`]('-E=&QO8V%L92A,0U]424U%
M+"`P*3L*("`@("`@("!S971L;V-A;&4H3$-?5$E-12P@)T,G*3L*"B`@("`@
M("`@)&QO9V=E<BT^;&]G*"1M97-S86=E+"`D<')I;W)I='DI.PH*("`@("`@
M("`O*B!297-T;W)E(&]R:6=I;F%L(&QO8V%L92X@*B\*("`@("`@("!S971L
M;V-A;&4H3$-?5$E-12P@)&QO8V%L92D["@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T3&]G
M9V5R*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF
M("AE;7!T>2@D8V]N9ELG;&]G)UU;)V5N86)L960G72DI('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<W1A=&EC("1L
M;V=C:&5C:SL*("`@("`@("!I9B`H(6ES<V5T*"1L;V=C:&5C:RDI('L*("`@
M("`@("`@("`@+R\@5')Y('1O(&UA:V4@<W5R92!T:&%T('=E(&-A;B!L;V<@
M;65S<V%G97,@<V]M96AO=RX*("`@("`@("`@("`@:68@*&5M<'1Y*"1C;VYF
M6R=L;V<G72D@?'P*("`@("`@("`@("`@("`@(&5M<'1Y*"1C;VYF6R=L;V<G
M75LG='EP92==*2!\?`H@("`@("`@("`@("`@("`@96UP='DH)&-O;F9;)VQO
M9R==6R=N86UE)UTI('Q\"B`@("`@("`@("`@("`@("!E;7!T>2@D8V]N9ELG
M;&]G)UU;)VED96YT)UTI('Q\"B`@("`@("`@("`@("`@("`A:7-S970H)&-O
M;F9;)VQO9R==6R=P87)A;7,G72DI('L*("`@("`@("`@("`@("`@($AO<F1E
M.CIF871A;"A014%2.CIR86ES945R<F]R*"=(;W)D92!I<R!N;W0@8V]R<F5C
M=&QY(&-O;F9I9W5R960@=&\@;&]G(&5R<F]R(&UE<W-A9V5S+B!9;W4@;75S
M="!C;VYF:6=U<F4@870@;&5A<W0@82!T97AT(&9I;&4@;&]G(&EN(&AO<F1E
M+V-O;F9I9R]C;VYF+G!H<"XG*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS
M92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QO9V-H96-K(#T@=')U
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&]G9V5R(#T@)DQO9SHZ
M<VEN9VQE=&]N*"1C;VYF6R=L;V<G75LG='EP92==+"`D8V]N9ELG;&]G)UU;
M)VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]N9ELG;&]G)UU;)VED96YT)UTL("1C;VYF6R=L;V<G75LG<&%R
M86US)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S=')O>7,@86YY(&5X
M:7-T:6YG('-E<W-I;VX@;VX@;&]G:6X@86YD(&UA:V4@<W5R92!T;R!U<V4@
M82!N97<*("`@("`J('-E<W-I;VX@240L('1O(&%V;VED('-E<W-I;VX@9FEX
M871I;VX@:7-S=65S+B!3:&]U;&0@8F4@8V%L;&5D(&)E9F]R90H@("`@("H@
M8VAE8VMI;F<@82!L;V=I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0VQE
M86Y397-S:6]N*"D*("`@('L*("`@("`@("`O+R!-86ME('-U<F4@=&\@9F]R
M8V4@82!C;VUP;&5T96QY(&YE=R!S97-S:6]N($E$(&%N9"!C;&5A<@H@("`@
M("`@("\O(&%L;"!S97-S:6]N(&1A=&$N"B`@("`@("`@:68@*'9E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C,N,R<I("$]/2`M,2D@>PH@("`@
M("`@("`@("!S97-S:6]N7W)E9V5N97)A=&5?:60H*3L*("`@("`@("`@("`@
M<V5S<VEO;E]U;G-E="@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M($!S97-S:6]N7V1E<W1R;WDH*3L*("`@("`@("`@("`@:68@*%5T:6PZ.F5X
M=&5N<VEO;D5X:7-T<R@G<&]S:7@G*2D@>PH@("`@("`@("`@("`@("`@)&YE
M=U]S97-S:6]N7VED(#T@;60U*&UI8W)O=&EM92@I("X@<&]S:7A?9V5T<&ED
M*"DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YE
M=U]S97-S:6]N7VED(#T@;60U*'5N:7%I9"AM=%]R86YD*"DL('1R=64I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!S97-S:6]N7VED*"1N97=?<V5S
M<VEO;E]I9"D["@H@("`@("`@("`@("`O+R!297-T87)T('1H92!S97-S:6]N
M+"!I;F-L=61I;F<@<V5T=&EN9R!U<"!T:&4@<V5S<VEO;@H@("`@("`@("`@
M("`O+R!H86YD;&5R+@H@("`@("`@("`@("!(;W)D93HZ<V5T=7!397-S:6]N
M2&%N9&QE<B@I.PH@("`@("`@("`@("!`<V5S<VEO;E]S=&%R="@I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4F5S970@8V]O:VEE('1I;65O=71S+"!I9B!N
M96-E<W-A<GDN("HO"B`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N
M9B==6R=S97-S:6]N)UU;)W1I;65O=70G72DI('L*("`@("`@("`@("`@)&%P
M<"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H*3L*("`@("`@("`@
M("`@:68@*%-E8W)E=#HZ8VQE87)+97DH)&%P<"DI('L*("`@("`@("`@("`@
M("`@(%-E8W)E=#HZ<V5T2V5Y*"1A<'`I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(%-E8W)E=#HZ<V5T2V5Y*"=A=71H)RD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@06)O<G1S('=I=&@@82!F871A;"!E<G)O<BP@
M9&ES<&QA>6EN9R!D96)U9R!I;F9O<FUA=&EO;B!T;R!T:&4@=7-E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)&5R<F]R("`@02!014%27T5R<F]R
M(&]B:F5C="!W:71H(&1E8G5G(&EN9F]R;6%T:6]N(&]R(&%N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@97)R;W(@;65S<V%G92X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1F:6QE("!4:&4@9FEL92!I;B!W:&EC:"!T:&4@97)R
M;W(@;V-C=7)E9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YE("!4:&4@
M;&EN92!O;B!W:&EC:"!T:&4@97)R;W(@;V-C=7)E9"X*("`@("`J($!P87)A
M;2!B;V]L96%N("1L;V<@("!,;V<@=&AI<R!M97-S86=E('9I82!(;W)D93HZ
M;&]G365S<V%G92@I/PH@("`@("HO"B`@("!F=6YC=&EO;B!F871A;"@D97)R
M;W(L("1F:6QE+"`D;&EN92P@)&QO9R`]('1R=64I"B`@("!["B`@("`@("`@
M0&EN8VQU9&5?;VYC92`G2&]R9&4O075T:"YP:'`G.PH@("`@("`@($!I;F-L
M=61E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*("`@("`@("`D861M:6X@/2!C
M;&%S<U]E>&ES=',H)T%U=&@G*2`F)B!!=71H.CII<T%D;6EN*"D["B`@("`@
M("`@)&-L:2`](&-L87-S7V5X:7-T<R@G2&]R9&5?0TQ))RD@)B8@2&]R9&5?
M0TQ).CIR=6YN:6YG1G)O;4-,22@I.PH*("`@("`@("`D97)R;W)T97AT(#T@
M)SQH,3XG("X@7R@B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B*2`N("<\
M+V@Q/B<["B`@("`@("`@:68@*&ES7V$H)&5R<F]R+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1I;F9O(#T@87)R87E?;65R9V4H87)R87DH)V9I
M;&4G(#T^("=C;VYF+G!H<"<L("=V87)I86)L92<@/3X@)R1C;VYF)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&5R<F]R+3YG
M9715<V5R26YF;R@I*2D["@H@("`@("`@("`@("!S=VET8V@@*"1E<G)O<BT^
M9V5T0V]D92@I*2!["B`@("`@("`@("`@(&-A<V4@2$]21$5?15)23U)?1%))
M5D527T-/3D9)1U]-25-324Y'.@H@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!S<')I;G1F*%\H(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB*2P@)&EN9F];)VYA;64G72D@+B`G/&)R("\^)R`N
M"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M9FEL97)O;W0G*2`N("<O8V]N9FEG+R<@+B`D:6YF;ULG9FEL92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@B)7-;)R5S)UU;)W!A
M<F%M<R==(BP@)&EN9F];)W9A<FEA8FQE)UTL("1I;F9O6R=D<FEV97(G72DI
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E($A/
M4D1%7T524D]27T12259%4E]#3TY&24<Z"B`@("`@("`@("`@("`@("`D;65S
M<V%G92`]('-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB*2P@)&EN9F];)V9I96QD)UTL("1I
M;F9O6R=N86UE)UTI("X@)SQB<B`O/B<@+@H@("`@("`@("`@("`@("`@("`@
M('-P<FEN=&8H7R@B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G*2`N("<O8V]N9FEG+R<@
M+B`D:6YF;ULG9FEL92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W!R:6YT9B@B)7-;)R5S)UU;)W!A<F%M<R==6R<E<R==(BP@)&EN9F];)W9A
M<FEA8FQE)UTL("1I;F9O6R=D<FEV97(G72P@)&EN9F];)V9I96QD)UTI*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@("1M97-S86=E(#T@)&5R<F]R+3YG971-97-S86=E
M*"D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&5R<F]R=&5X="`N/2`G/&@S/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1M97-S86=E*2`N("<\+V@S/B<["B`@("`@("`@?2!E;'-E:68@*&ES
M7V]B:F5C="@D97)R;W(I("8F(&UE=&AO9%]E>&ES=',H)&5R<F]R+"`G9V5T
M365S<V%G92<I*2!["B`@("`@("`@("`@("1E<G)O<G1E>'0@+CT@)SQH,SXG
M("X@:'1M;'-P96-I86QC:&%R<R@D97)R;W(M/F=E=$UE<W-A9V4H*2D@+B`G
M/"]H,SXG.PH@("`@("`@('T@96QS96EF("AI<U]S=')I;F<H)&5R<F]R*2D@
M>PH@("`@("`@("`@("`D97)R;W)T97AT("X]("<\:#,^)R`N(&AT;6QS<&5C
M:6%L8VAA<G,H)&5R<F]R*2`N("<\+V@S/B<["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&%D;6EN*2!["B`@("`@("`@("`@("1E<G)O<G1E>'0@+CT@)SQP
M/CQC;V1E/B<@+B!S<')I;G1F*%\H(EML:6YE("5S(&]F("5S72(I+"`D;&EN
M92P@)&9I;&4I("X@)SPO8V]D93X\+W`^)SL*("`@("`@("`@("`@:68@*&ES
M7V]B:F5C="@D97)R;W(I*2!["B`@("`@("`@("`@("`@("`D97)R;W)T97AT
M("X]("<\:#,^)R`N(%\H(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3HB*2`N("<\+V@S/B<["B`@("`@("`@("`@("`@("`D97)R;W)T97AT
M("X]("<\<#X\<')E/B<@+B!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F)U9F9E
M<D]U='!U="@G=F%R7V1U;7`G+"`D97)R;W(I*2`N("<\+W!R93X\+W`^)SL*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D;&]G*2!["B`@("`@
M("`@("`@("1E<G)O<G1E>'0@+CT@)SQH,SXG("X@7R@B1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB*2`N("<\+V@S
M/B<["B`@("`@("`@?0H*("`@("`@("`O+R!,;V<@=&AE(&5R<F]R('9I82!(
M;W)D93HZ;&]G365S<V%G92@I(&EF(')E<75E<W1E9"X*("`@("`@("!I9B`H
M)&QO9RD@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D97)R;W(L
M("1F:6QE+"`D;&EN92P@4$5!4E],3T=?14U%4D<I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1C;&DI('L*("`@("`@("`@("`@96-H;R!S=')I<%]T86=S
M*'-T<E]R97!L86-E*&%R<F%Y*"<\8G(@+SXG+"`G/'`^)RP@)SPO<#XG+"`G
M/&@Q/B<L("<\+V@Q/B<L("<\:#,^)RP@)SPO:#,^)RDL(")<;B(L("1E<G)O
M<G1E>'0I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO(#P\
M/"!(5$U,"CQH=&UL/@H\:&5A9#X\=&ET;&4^2&]R9&4@.CH@1F%T86P@17)R
M;W(\+W1I=&QE/CPO:&5A9#X*/&)O9'D@<W1Y;&4](F)A8VMG<F]U;F0Z(V9F
M9CL@8V]L;W(Z(S`P,"(^)&5R<F]R=&5X=#PO8F]D>3X*/"]H=&UL/@I(5$U,
M.PH@("`@("`@('T*("`@("`@("!E>&ET.PH@("`@?0H*("`@("\J*@H@("`@
M("H@061D<R!T:&4@:F%V87-C<FEP="!C;V1E('1O('1H92!O=71P=70@*&EF
M(&]U='!U="!H87,@86QR96%D>2!S=&%R=&5D*0H@("`@("H@;W(@=&\@=&AE
M(&QI<W0@;V8@<V-R:7!T(&9I;&5S('1O(&EN8VQU9&4@=FEA(&EN8VQU9&53
M8W)I<'1&:6QE<R@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I
M;&4@("`@(%1H92!F=6QL(&IA=F%S8W)I<'0@9FEL92!N86UE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D87!P("`@("`@5&AE(&%P<&QI8V%T:6]N(&YA;64N
M($1E9F%U;'1S('1O('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!A<'!L:6-A=&EO;BX*("`@("`J($!P87)A;2!B;V]L96%N
M("1D:7)E8W0@($EN8VQU9&4@=&AE(&9I;&4@9&ER96-T;'D@=VET:&]U="!P
M87-S:6YG(&ET"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T:')O
M=6=H(&IA=F%S8W)I<'0N<&AP/PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&13
M8W)I<'1&:6QE*"1F:6QE+"`D87!P(#T@;G5L;"P@)&1I<F5C="`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@<W1A
M=&EC("1I;F-L=61E9"`](&%R<F%Y*"D["@H@("`@("`@(&EF("AE;7!T>2@D
M87!P*2D@>PH@("`@("`@("`@("`D87!P(#T@)')E9VES=')Y+3YG971!<'`H
M*3L*("`@("`@("!]"@H@("`@("`@("\O(%-K:7`@86YY(&IS(&9I;&5S('1H
M870@:&%V92!S:6YC92!B965N(&1E<')E8V%T960N"B`@("`@("`@)&EG;F]R
M961?9FEL97,@/2!A<G)A>2@G:&]R9&4G(#T^(&%R<F%Y*"=T;V]L=&EP+FIS
M)R`]/B`Q*2D["B`@("`@("`@:68@*"%E;7!T>2@D:6=N;W)E9%]F:6QE<ULD
M87!P75LD9FEL95TI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"@H@("`@("`@("\O($1O;B=T(&EN8VQU9&4@<V-R:7!T<R!M=6QT:7!L92!T
M:6UE<RX*("`@("`@("!I9B`H(65M<'1Y*"1I;F-L=61E9%LD87!P75LD9FEL
M95TI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@
M)&EN8VQU9&5D6R1A<'!=6R1F:6QE72`]('1R=64["@H@("`@("`@("\O($5X
M<&QI8VET;'D@8VAE8VL@9F]R(&$@;F]N+5!(4"!V97)S:6]N(&]F('1H92!S
M8W)I<'0N"B`@("`@("`@:68@*"$D9&ER96-T("8F(&9I;&5?97AI<W1S*"1F
M:6QE>S!](#T]("<O)R`_("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A
M<'`I("X@)&9I;&4@.B`D<F5G:7-T<GDM/F=E="@G:G-F<R<L("1A<'`I("X@
M)R\G("X@)&9I;&4I*2!["B`@("`@("`@("`@("1D:7)E8W0@/2!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@+R\@268@:&5A9&5R<R!H879E(&%L<F5A9'D@
M8F5E;B!S96YT+"!W92!N965D('1O(&]U='!U="!A"B`@("`@("`@+R\@/'-C
M<FEP=#X@=&%G(&1I<F5C=&QY+@H@("`@("`@(&EF("AO8E]G971?;&5N9W1H
M*"D@?'P@:&5A9&5R<U]S96YT*"DI('L*("`@("`@("`@("`@:68@*"1D:7)E
M8W0I('L*("`@("`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1F:6QE
M>S!](#T]("<O)R`_("1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)&%P<"D@
M+B`D9FEL92`Z("1R96=I<W1R>2T^9V5T*"=J<W5R:2<L("1A<'`I("X@)R\G
M("X@)&9I;&4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'5R;"`]($AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G
M+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:F%V87-C<FEP="YP:'`G*3L*("`@
M("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@
M87)R87DH)V9I;&4G(#T^("1F:6QE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G87!P)R`@/3X@)&%P
M<"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@)SQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](B<@+B`D=7)L("X@)R(^/"]S
M8W)I<'0^)R`N(")<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M9VQO8F%L("1?:&]R9&5?<V-R:7!T7V9I;&5S.PH@("`@("`@("`@("`D7VAO
M<F1E7W-C<FEP=%]F:6QE<ULD87!P75M=(#T@87)R87DH)&9I;&4L("1D:7)E
M8W0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EN8VQU9&5S
M(&IA=F%S8W)I<'0@9FEL97,@=&AA="!W97)E(&YE961E9"!B969O<F4@86YY
M(&AE861E<G,@=V5R92!S96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;F-L
M=61E4V-R:7!T1FEL97,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7VAO<F1E
M7W-C<FEP=%]F:6QE<RP@)')E9VES=')Y.PH*("`@("`@("`O*B!)9B!T:&5R
M92!I<R!N;R!J879A<V-R:7!T(&%V86EL86)L92P@=&AE<F4G<R!N;R!P;VEN
M="!I;B!I;F-L=61I;F<*("`@("`@("`@*B!T:&4@<F5S="!O9B!T:&4@9FEL
M97,N("HO"B`@("`@("`@:68@*"$D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&
M96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@+RH@061D(&=E;F5R86P@54D@:G,@;&EB<F%R
M>2X@*B\*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G:&]R9&4N:G,G
M+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S
M97(G72T^:&%S475I<FLH)W=I;F1O=V5D7V-O;G1R;VQS)RDI('L*("`@("`@
M("`@("`@+RH@1FEX97,@9F]R($E%('1H870@8V%N)W0@96%S:6QY(&)E(&1O
M;F4@=VET:&]U="!B<F]W<V5R"B`@("`@("`@("`@("`J(&1E=&5C=&EO;BX@
M*B\*("`@("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAO<F1E+FEE
M+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1?:&]R9&5?<V-R:7!T7V9I;&5S*2D@>PH@("`@("`@("`@("`D
M8F%S95]U<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T
M)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VIA=F%S8W)I<'0N<&AP)RD["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1?:&]R9&5?<V-R:7!T7V9I;&5S(&%S("1A
M<'`@/3X@)&9I;&5S*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL
M97,@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1F:6QE6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=7)L(#T@
M)&9I;&5;,%U[,'T@/3T@)R\G(#\@)')E9VES=')Y+3YG970H)W=E8G)O;W0G
M+"`D87!P*2`N("1F:6QE6S!=(#H@)')E9VES=')Y+3YG970H)VIS=7)I)RP@
M)&%P<"D@+B`G+R<@+B`D9FEL95LP73L*("`@("`@("`@("`@("`@("`@("`@
M("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB
M)R`N($AO<F1E.CIU<FPH)'5R;"D@+B`B7"(^/"]S8W)I<'0^7&XB.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&)A<V5?=7)L+"!A<G)A
M>2@G9FEL92<@/3X@)&9I;&5;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M87!P)R`@/3X@)&%P<"DI.PH@("`@("`@("`@("`@("`@("`@("`@("!E8VAO
M("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2(G("X@)'5R
M;"`N(")<(CX\+W-C<FEP=#Y<;B(["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@26YC;'5D97,@:F%V87-C<FEP="!F:6QE<R!T
M:&%T('=E<F4@;F5E9&5D(&)E9F]R92!A;GD@:&5A9&5R<R!W97)E('-E;G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN;&EN95-C<FEP=$9I;&5S*"D*("`@
M('L*("`@("`@("!G;&]B86P@)%]H;W)D95]S8W)I<'1?9FEL97,L("1R96=I
M<W1R>3L*"B`@("`@("`@:68@*"%E;7!T>2@D7VAO<F1E7W-C<FEP=%]F:6QE
M<RDI('L*("`@("`@("`@("`@)&IS5W)A<'!E<B`]("1R96=I<W1R>2T^9V5T
M*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]J879A<V-R:7!T
M+G!H<"<["B`@("`@("`@("`@(&9O<F5A8V@@*"1?:&]R9&5?<V-R:7!T7V9I
M;&5S(&%S("1A<'`@/3X@)&9I;&5S*2!["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1F:6QE6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!`<F5A9&9I;&4H)&9I;&5;,%U[,'T@/3T@)R\G(#\@)')E9VES=')Y+3YG
M970H)V9I;&5R;V]T)RP@)&%P<"D@+B`D9FEL95LP72`Z("1R96=I<W1R>2T^
M9V5T*"=J<V9S)RP@)&%P<"D@+B`G+R<@+B`D9FEL95LP72D["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I;&4@/2`D9FEL95LP73L*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q
M=6ER92`D:G-7<F%P<&5R.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($-H96-K<R!I9B!L:6YK('-H;W5L9"!B92!S:&]W;B!A
M;F0@<F5T=7)N('1H92!N97-C97-S87)Y(&-O9&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)'1Y<&4@("`@("!4>7!E(&]F(&QI;FL@=&\@9&ES
M<&QA>0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&%P<"`@("`@("!4:&4@;F%M
M92!O9B!T:&4@8W5R<F5N="!(;W)D92!A<'!L:6-A=&EO;BX*("`@("`J($!P
M87)A;2!B;V]L96%N("1O=F5R<FED92`@3W9E<G)I9&4@2&]R9&4@<V5T=&EN
M9W,_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5F97)R97(@($EN8VQU9&4@
M=&AE(&-U<G)E;G0@<&%G92!A<R!T:&4@<F5F97)R97(@*'5R;#TI/PH@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!T;R!C<F5A=&4@
M=&AE(&QI;FLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<G9I8V5,:6YK
M*"1T>7!E+"`D87!P+"`D;W9E<G)I9&4@/2!F86QS92P@)')E9F5R<F5R(#T@
M=')U92D*("`@('L*("`@("`@("!I9B`H(4AO<F1E.CIS:&]W4V5R=FEC92@D
M='EP92D@)B8@(21O=F5R<FED92D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@
M("`@8V%S92`G:&5L<"<Z"B`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O
M=W-E<B==+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@
M("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D
M92<L('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1U<FP@/2!(
M;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G
M+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:&5L<"\G+"!T<G5E*3L*("`@("`@
M("`@("`@<F5T=7)N(%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;6]D=6QE
M)RP@)&%P<"D["@H@("`@("`@(&-A<V4@)W!R;V)L96TG.@H@("`@("`@("`@
M("!R971U<FX@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!R;V)L96TN<&AP
M/W)E='5R;E]U<FP])R`N('5R;&5N8V]D92A(;W)D93HZ<V5L9E5R;"AT<G5E
M+"!T<G5E+"!T<G5E*2DI.PH*("`@("`@("!C87-E("=L;V=O=70G.@H@("`@
M("`@("`@("!R971U<FX@2&]R9&4Z.G5R;"A!=71H.CIA9&1,;V=O=71087)A
M;65T97)S*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N("<O;&]G:6XN<&AP)RP@05542%]214%33TY?3$]'3U54*2D[
M"@H@("`@("`@(&-A<V4@)VQO9VEN)SH*("`@("`@("`@("`@<F5T=7)N($%U
M=&@Z.F=E=$QO9VEN4V-R965N*"<G+"`D<F5F97)R97(@/R!(;W)D93HZ<V5L
M9E5R;"AT<G5E*2`Z(&YU;&PI.PH*("`@("`@("!C87-E("=O<'1I;VYS)SH*
M("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("`@("!I9B`H*"1C
M;VYF6R=P<F5F<R==6R=D<FEV97(G72`A/2`G)RD@)B8@*"1C;VYF6R=P<F5F
M<R==6R=D<FEV97(G72`A/2`G;F]N92<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W
M96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!R969S+G!H<#]A<'`]
M)R`N("1A<'`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE('1Y<&4@;V8@;&EN
M:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE
M(&QI;FL@:7,@=&\@8F4@<VAO=VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H
M;W=397)V:6-E*"1T>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*
M"B`@("`@("`@:68@*&5M<'1Y*"1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)'1Y
M<&5=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!S=VET8V@@*"1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)'1Y<&5=
M*2!["B`@("`@("`@8V%S92`G86QL)SH*("`@("`@("`@("`@<F5T=7)N('1R
M=64["@H@("`@("`@(&-A<V4@)VYE=F5R)SH*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH*("`@("`@("!C87-E("=A=71H96YT:6-A=&5D)SH*("`@("`@
M("`@("`@<F5T=7)N("AB;V]L*4%U=&@Z.F=E=$%U=&@H*3L*"B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1R:79E<B!P87)A
M;65T97)S(&9O<B!T:&4@<W!E8VEF:65D(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1B86-K96YD("!4:&4@8F%C:V5N9"!S>7-T96T@
M*&4N9RX@)W!R969S)RP@)V-A=&5G;W)I97,G+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`G8V]N=&%C=',G*2!B96EN9R!U<V5D+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!4:&4@=7-E9"!C;VYF:6=U<F%T:6]N
M(&%R<F%Y('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;F9;)&)A8VME;F1=+B!)9B!A;B!A<G)A>2!G971S('!A<W-E9"P@:70@
M=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!B92`D8V]N9ELD
M:V5Y,5U;)&ME>3)=+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@("!4
M:&4@='EP92!O9B!D<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@5&AE(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1')I=F5R0V]N9FEG*"1B86-K96YD+"`D='EP92`]("=S<6PG
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&,@/2!N
M=6QL.PH@("`@("`@(&EF("AI<U]A<G)A>2@D8F%C:V5N9"DI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@
M("`@("`D8R`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1C;VYF+"`D8F%C
M:V5N9"D["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF6R1B86-K96YD
M72DI('L*("`@("`@("`@("`@)&,@/2`D8V]N9ELD8F%C:V5N9%T["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D8RD@)B8@:7-S970H)&-;)W!A
M<F%M<R==*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&-O;F9;)'1Y<&5=
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7VUE<F=E*"1C;VYF
M6R1T>7!E72P@)&-;)W!A<F%M<R==*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D8ULG<&%R86US)UT["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!I<W-E="@D8V]N9ELD
M='EP95TI(#\@)&-O;F9;)'1Y<&5=(#H@87)R87DH*3L*("`@('T*"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!61E,@9')I=F5R('!A<F%M971E<G,@
M9F]R('1H92!S<&5C:69I960@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@5D93('-Y<W1E;2!N86UE("AE+F<N("=I
M;6%G97,G+"`G9&]C=6UE;G1S)RD*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(&)E:6YG('5S960N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M02!H87-H('=I=&@@=&AE(%9&4R!P87)A;65T97)S.R!T:&4@5D93(&1R:79E
M<B!I;B`G='EP92<*("`@("`J("`@("`@("`@("`@("`@(&%N9"!T:&4@8V]N
M;F5C=&EO;B!P87)A;65T97)S(&EN("=P87)A;7,G+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G97161E-#;VYF:6<H)&YA;64I"B`@("!["B`@("`@("`@9VQO
M8F%L("1C;VYF.PH*("`@("`@("!I9B`H(6ES<V5T*"1C;VYF6R1N86UE75LG
M='EP92==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB*2D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&-O;F9;)&YA;65=6R=T>7!E)UT@/3T@
M)VAO<F1E)RD@>PH@("`@("`@("`@("`D=F9S(#T@)&-O;F9;)W9F<R==.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V9G,@/2`D8V]N9ELD;F%M
M95T["B`@("`@("`@?0H*("`@("`@("!I9B`H)'9F<ULG='EP92==(#T]("=S
M<6PG*2!["B`@("`@("`@("`@("1V9G-;)W!A<F%M<R==(#T@2&]R9&4Z.F=E
M=$1R:79E<D-O;F9I9R@D;F%M92P@)W-Q;"<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1V9G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@
M:68@86QL(&YE8V5S<V%R>2!P87)A;65T97)S(&9O<B!A(&1R:79E<B!C;VYF
M:6=U<F%T:6]N"B`@("`@*B!A<F4@<V5T(&%N9"!T:')O=W,@82!F871A;"!E
M<G)O<B!W:71H(&$@9&5T86EL960@97AP;&%I;F%T:6]N"B`@("`@*B!H;W<@
M=&\@9FEX('1H:7,L(&EF('-O;65T:&EN9R!I<R!M:7-S:6YG+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!4:&4@8V]N9FEG=7)A
M=&EO;B!A<G)A>2!W:71H(&%L;"!P87)A;65T97)S+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9')I=F5R("`@(%1H92!K97D@;F%M92`H:6X@=&AE(&-O;F9I
M9W5R871I;VX@87)R87DI(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE(&1R:79E<BX*("`@("`J($!P87)A;2!A<G)A>2`D9FEE;&1S
M("`@("!!;B!A<G)A>2!W:71H(&UA;F1A=&]R>2!P87)A;65T97(@;F%M97,@
M9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!D<FEV
M97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@5&AE(&-L96%R
M('1E>'0@;F%M92!O9B!T:&4@9')I=F5R+B!)9B!N;W0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!S<&5C:69I960L('1H92!A<'!L:6-A=&EO
M;B!N86UE('=I;&P@8F4@=7-E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I
M;&4@("`@("!4:&4@8V]N9FEG=7)A=&EO;B!F:6QE('1H870@<VAO=6QD(&-O
M;G1A:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&5S92!S
M971T:6YG<RX*("`@("`J($!P87)A;2!S=')I;F<@)'9A<FEA8FQE("!4:&4@
M;F%M92!O9B!T:&4@8V]N9FEG=7)A=&EO;B!V87)I86)L92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@87-S97)T1')I=F5R0V]N9FEG*"1P87)A;7,L("1D<FEV
M97(L("1F:65L9',L("1N86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9FEL92`]("=C;VYF+G!H<"<L("1V87)I86)L92`]
M("<D8V]N9B<I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@
M("`@("`@+R\@1&]N)W0@9V5N97)A=&4@82!F871A;"!E<G)O<B!I9B!W92!F
M86EL(&1U<FEN9R!O<B!B969O<F4*("`@("`@("`O+R!296=I<W1R>2!I;G-T
M86YT:6%T:6]N+@H@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@
M("`@("`@("`D;F%M92`](&ES<V5T*"1R96=I<W1R>2D@/R`D<F5G:7-T<GDM
M/F=E=$%P<"@I(#H@)UMU;FMN;W=N72<["B`@("`@("`@?0H@("`@("`@("1F
M:6QE<F]O="`](&ES<V5T*"1R96=I<W1R>2D@/R`D<F5G:7-T<GDM/F=E="@G
M9FEL97)O;W0G*2`Z("<G.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A
M;7,I('Q\("%C;W5N="@D<&%R86US*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@*("`@("`@("`@("`@("`@('-P<FEN
M=&8H7R@B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+B(I+"`D;F%M92D@+B`B7&Y<;B(@+@H@("`@("`@("`@("`@("`@
M<W!R:6YT9BA?*")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+B(I+`H@("`@("`@("`@("`@("`@("`@("1F:6QE<F]O="`N
M("<O8V]N9FEG+R<@+B`D9FEL92P*("`@("`@("`@("`@("`@("`@("!S<')I
M;G1F*"(E<ULG)7,G75LG<&%R86US)UTB+"`D=F%R:6%B;&4L("1D<FEV97(I
M*2DL"B`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A<R`D9FEE;&0I('L*
M("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R1F:65L9%TI*2!["B`@
M("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@*
M("`@("`@("`@("`@("`@("`@("!S<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(BDL("1F:65L
M9"P@)&YA;64I("X@(EQN7&XB("X*("`@("`@("`@("`@("`@("`@("!S<')I
M;G1F*%\H(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN
M9RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5R;V]T("X@)R]C
M;VYF:6<O)R`N("1F:6QE+`H@("`@("`@("`@("`@("`@("`@("`@("!S<')I
M;G1F*"(E<ULG)7,G75LG<&%R86US)UU;)R5S)UTB+"`D=F%R:6%B;&4L("1D
M<FEV97(L("1F:65L9"DI*2P*("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-E<W-I;VXM:60M:69I960@=F5R
M<VEO;B!O9B`D=7)I+@H@("`@("H@268@82!F=6QL(%523"!I<R!R97%U97-T
M960L(&%L;"!P87)A;65T97(@<V5P87)A=&]R<R!G970@8V]N=F5R=&5D('1O
M"B`@("`@*B`B)B(L(&]T:&5R=VES92!T;R`B)F%M<#LB+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5R:2`@("`@("`@("`@("`@5&AE(%5222!T
M;R!B92!M;V1I9FEE9"X*("`@("`J($!P87)A;2!B;V]L96%N("1F=6QL("`@
M("`@("`@("`@1V5N97)A=&4@82!F=6QL("AH='1P.B\O<V5R=F5R+W!A=&@O
M*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!54DPN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D87!P96YD7W-E<W-I;VX@(#`@/2!O
M;FQY(&EF(&YE961E9"P@,2`](&%L=V%Y<RP@+3$@/0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!N979E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(%523"!W:71H('1H92!S97-S:6]N(&ED
M(&%P<&5N9&5D("AI9B!N965D960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!U
M<FPH)'5R:2P@)&9U;&P@/2!F86QS92P@)&%P<&5N9%]S97-S:6]N(#T@,"P@
M)&9O<F-E7W-S;"`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D9F]R8V5?
M<W-L*2!["B`@("`@("`@("`@("1F=6QL(#T@=')U93L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D9G5L;"D@>PH@("`@("`@("`@("!G;&]B86P@)&-O;F8L
M("1R96=I<W1R>2P@)&)R;W=S97(["@H@("`@("`@("`@("`O*B!3=&]R92!C
M;VYN96-T:6]N('!A<F%M971E<G,@:6X@;&]C86P@=F%R:6%B;&5S+B`J+PH@
M("`@("`@("`@("`D<V5R=F5R7VYA;64@/2`D8V]N9ELG<V5R=F5R)UU;)VYA
M;64G73L*("`@("`@("`@("`@)'-E<G9E<E]P;W)T(#T@)&-O;F9;)W-E<G9E
M<B==6R=P;W)T)UT["@H@("`@("`@("`@("`D<')O=&]C;VP@/2`G:'1T<"<[
M"B`@("`@("`@("`@(&EF("@D8V]N9ELG=7-E7W-S;"==(#T](#$I('L*("`@
M("`@("`@("`@("`@("1P<F]T;V-O;"`]("=H='1P<R<["B`@("`@("`@("`@
M('T@96QS96EF("@D8V]N9ELG=7-E7W-S;"==(#T](#(@)B8*("`@("`@("`@
M("`@("`@("`@("`@("1B<F]W<V5R+3YU<VEN9U-33$-O;FYE8W1I;VXH*2D@
M>PH@("`@("`@("`@("`@("`@)'!R;W1O8V]L(#T@)VAT='!S)SL*("`@("`@
M("`@("`@?2!E;'-E:68@*"1C;VYF6R=U<V5?<W-L)UT@/3T@,RD@>PH@("`@
M("`@("`@("`@("`@)'-E<G9E<E]P;W)T(#T@)R<["B`@("`@("`@("`@("`@
M("!I9B`H)&9O<F-E7W-S;"D@>PH@("`@("`@("`@("`@("`@("`@("1P<F]T
M;V-O;"`]("=H='1P<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($EF('5S:6YG(&YO;BUS=&%N9&%R9"!P;W)T
M<RP@861D('1H92!P;W)T('1O('1H92!54DPN("HO"B`@("`@("`@("`@(&EF
M("@A96UP='DH)'-E<G9E<E]P;W)T*2`F)@H@("`@("`@("`@("`@("`@*"@H
M)'!R;W1O8V]L(#T]("=H='1P)RD@)B8@*"1S97)V97)?<&]R="`A/2`X,"DI
M('Q\"B`@("`@("`@("`@("`@("`@*"@D<')O=&]C;VP@/3T@)VAT='!S)RD@
M)B8@*"1S97)V97)?<&]R="`A/2`T-#,I*2DI('L*("`@("`@("`@("`@("`@
M("1S97)V97)?;F%M92`N/2`G.B<@+B`D<V5R=F5R7W!O<G0["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J(%-T;W)E('1H92!W96)R;V]T(&EN(&$@
M;&]C86P@=F%R:6%B;&4N("HO"B`@("`@("`@("`@("1W96)R;V]T(#T@)')E
M9VES=')Y+3YG970H)W=E8G)O;W0G*3L*"B`@("`@("`@("`@("1U<FP@/2`D
M<')O=&]C;VP@+B`G.B\O)R`N("1S97)V97)?;F%M93L*("`@("`@("`@("`@
M:68@*'-U8G-T<B@D=7)I+"`P+"`Q*2`A/2`G+R<I('L*("`@("`@("`@("`@
M("`@(&EF("AS=6)S='(H)'=E8G)O;W0L("TQ*2`]/2`G+R<I('L*("`@("`@
M("`@("`@("`@("`@("`D=7)L("X]("1W96)R;V]T("X@)'5R:3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5R;"`N
M/2`D=V5B<F]O="`N("<O)R`N("1U<FD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=7)L("X]("1U
M<FD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=7)L(#T@)'5R:3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D
M1TQ/0D%,4ULG8V]N9B==6R=S97-S:6]N)UU;)W5S95]O;FQY7V-O;VMI97,G
M72D@)B8*("`@("`@("`@("`@*"@D87!P96YD7W-E<W-I;VX@/3T@,2D@?'P*
M("`@("`@("`@("`@("@H)&%P<&5N9%]S97-S:6]N(#T](#`I("8F"B`@("`@
M("`@("`@("`@(6ES<V5T*"1?0T]/2TE%6W-E<W-I;VY?;F%M92@I72DI*2D@
M>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL
M('-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED*"DI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1F=6QL*2!["B`@("`@("`@("`@("\J(%=E(&YE960@=&\@
M<G5N('1H92!R97!L86-E('1W:6-E+"!B96-A=7-E('=E(&]N;'D@8V%T8V@@
M979E<GD*("`@("`@("`@("`@("H@<V5C;VYD(&UA=&-H+B`J+PH@("`@("`@
M("`@("!R971U<FX@<')E9U]R97!L86-E*&%R<F%Y*"<O*#T_+BH_*29A;7`[
M*"XJ/STI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R\H/3\N*C\I)F%M<#LH+BH_/2DO)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R0Q)B0R)RP@)'5R;"D["B`@("`@("`@?2!E;'-E
M:68@*'!R96=?;6%T8V@H)R\]+BHF86UP.RXJ/2\G+"`D=7)L*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@:'1M;&5N=&ET:65S*"1U<FPI.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S97-S:6]N+6ED+6EF:65D
M('9E<G-I;VX@;V8@)'5R:2P@=7-I;F<@=&AE(&-U<G)E;G0*("`@("`J(&%P
M<&QI8V%T:6]N)W,@=V5B<F]O="!S971T:6YG+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5R:2`@("`@("`@("`@("`@5&AE(%5222!T;R!B92!M
M;V1I9FEE9"X*("`@("`J($!P87)A;2!B;V]L96%N("1F=6QL("`@("`@("`@
M("`@1V5N97)A=&4@82!F=6QL("AH='1P.B\O<V5R=F5R+W!A=&@O*0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!54DPN"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D87!P96YD7W-E<W-I;VX@(#`@/2!O;FQY(&EF
M(&YE961E9"P@,2`](&%L=V%Y<RP@+3$@/0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N979E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('5R;"!W:71H('1H92!S97-S:6]N(&ED(&%P<&5N
M9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO;E5R;"@D=7)I
M+"`D9G5L;"`](&9A;'-E+"`D87!P96YD7W-E<W-I;VX@/2`P*0H@("`@>PH@
M("`@("`@(&EF("@D9G5L;"D@>PH@("`@("`@("`@("!R971U<FX@2&]R9&4Z
M.G5R;"@D=7)I+"`D9G5L;"P@)&%P<&5N9%]S97-S:6]N*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AS=6)S='(H)'5R:2P@,"P@,2D@(3T@)R\G*2!["B`@
M("`@("`@("`@("1W96)R;V]T(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G=V5B<F]O="<I.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1W96)R;V]T
M+"`M,2D@(3T@)R\G*2!["B`@("`@("`@("`@("`@("`D=V5B<F]O="`N/2`G
M+R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'5R:2`]("1W96)R;V]T
M("X@)'5R:3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!(;W)D93HZ=7)L
M*"1U<FDL("1F=6QL+"`D87!P96YD7W-E<W-I;VXI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;B!E>'1E<FYA;"!L:6YK('!A<W-E9"!T:')O
M=6=H('1H92!D97)E9F5R<F5R('1O('-T<FEP('-E<W-I;VX*("`@("`J($E$
M<R!F<F]M('1H92!R969E<G)E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<FP@("!4:&4@97AT97)N86P@55),('1O(&QI;FL@=&\N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D=&%G("!)9B!T<G5E+"!A(&-O;7!L971E(#QA
M/B!T86<@:7,@<F5T=7)N960L(&]N;'D@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!U<FP@;W1H97)W:7-E+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@8V]R<F5C="!L:6YK('1O('1H92!D97)E9F5R<F5R
M('-C<FEP="X*("`@("`J+PH@("`@9G5N8W1I;VX@97AT97)N86Q5<FPH)'5R
M;"P@)'1A9R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7T-/
M3TM)15MS97-S:6]N7VYA;64H*5TI*2!["B`@("`@("`@("`@("1E>'0@/2`D
M=7)L.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E>'0@/2!(;W)D
M93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<O<V5R
M=FEC97,O9V\N<&AP)RP@=')U92P@+3$I.PH*("`@("`@("`@("`@+RH@5V4@
M;75S="!M86ME('-U<F4@=&AE<F4@87)E(&YO("9A;7`G<R!I;B!T:&4@55),
M+B`J+PH@("`@("`@("`@("`D=7)L(#T@<')E9U]R97!L86-E*&%R<F%Y*"<O
M*#T_+BH_*29A;7`[*"XJ/STI+R<L("<O*#T_+BH_*29A;7`[*"XJ/STI+R<I
M+"`G)#$F)#(G+"`D=7)L*3L*("`@("`@("`@("`@)&5X="`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D97AT+"`G=7)L)RP@)'5R;"D["B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&%G*2!["B`@("`@("`@("`@("1E>'0@/2!(;W)D93HZ;&EN
M:R@D97AT+"`D=7)L+"`G)RP@)U]B;&%N:R<I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!54DP@=&\@8F4@=7-E9"!F;W(@9&]W;FQO861I;F<L('1H870@=&%K97,@
M:6YT;R!A8V-O=6YT(&%N>0H@("`@("H@<W!E8VEA;"!B<F]W<V5R('%U:7)K
M<R`H:2YE+B!)12=S(&)R;VME;B!F:6QE;F%M92!H86YD;&EN9RDN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE;F%M
M92!O9B!T:&4@9&]W;FQO860@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("`@("!!;GD@861D:71I;VYA;"!P87)A;65T97)S(&YE961E9"X*
M("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("!4:&4@55),('1O(&%L
M=&5R+B!)9B!N;VYE('!A<W-E9"!I;BP@=VEL;"!U<V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@9FEL92`G=FEE=RYP:'`G(&QO8V%T
M960@:6X@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!M;V1U;&4G<R!B87-E(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&1O=VYL;V%D(%523"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&]W;FQO8615<FPH)&9I;&5N86UE+"`D<&%R86US(#T@87)R
M87DH*2P@)'5R;"`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1B<F]W
M<V5R.PH*("`@("`@("`D:&]R9&5?=7)L(#T@9F%L<V4["@H@("`@("`@(&EF
M("AI<U]N=6QL*"1U<FPI*2!["B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["B`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R
M9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@
M)R]S97)V:6-E<R]D;W=N;&]A9"\G*2P@)VUO9'5L92<L("1R96=I<W1R>2T^
M9V5T07!P*"DI.PH@("`@("`@("`@("`D:&]R9&5?=7)L(#T@=')U93L*("`@
M("`@("!]"@H@("`@("`@("\J($%D9"!P87)A;65T97)S+B`J+PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1P87)A;7,I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@=V4@87)E('5S:6YG('1H92!D969A=6QT($AO<F1E
M(&1O=VYL;V%D(&QI;FLL(&%D9"!T:&4*("`@("`@("`@*B!F:6QE;F%M92!T
M;R!T:&4@96YD(&]F('1H92!54DPN($%L=&AO=6=H(&YO="!N96-E<W-A<GD@
M9F]R"B`@("`@("`@("H@;6%N>2!B<F]W<V5R<RP@=&AI<R!S:&]U;&0@86QL
M;W<@979E<GD@8G)O=W-E<B!T;R!D;W=N;&]A9`H@("`@("`@("`J(&-O<G)E
M8W1L>2X@*B\*("`@("`@("!I9B`H)&AO<F1E7W5R;"D@>PH@("`@("`@("`@
M("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=F;B<L("<O)R`N
M(')A=W5R;&5N8V]D92@D9FEL96YA;64I*3L*("`@("`@("!](&5L<V5I9B`H
M)&)R;W=S97(M/FAA<U%U:7)K*"=B<F5A:U]D:7-P;W-I=&EO;E]F:6QE;F%M
M92<I*2!["B`@("`@("`@("`@("\J(%-O;64@8G)O=W-E<G,@=VEL;"!O;FQY
M(&]B=&%I;B!T:&4@9FEL96YA;64@8V]R<F5C=&QY"B`@("`@("`@("`@("`J
M(&EF('1H92!E>'1E;G-I;VX@:7,@=&AE(&QA<W0@87)G=6UE;G0@:6X@=&AE
M('%U97)Y"B`@("`@("`@("`@("`J('-T<FEN9R!A;F0@<F5S="!O9B!T:&4@
M9FEL96YA;64@87!P96%R<R!I;B!T:&4*("`@("`@("`@("`@("H@4$%42%])
M3D9/(&5L96UE;G0N("HO"B`@("`@("`@("`@("1F:6QE;F%M92`](')A=W5R
M;&5N8V]D92@D9FEL96YA;64I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!W
M96)S97)V97(@240N("HO"B`@("`@("`@("`@("1S97)V97(@/2!(;W)D93HZ
M=V5B4V5R=F5R240H*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@;F%M92!A
M;F0@97AT96YS:6]N(&]F('1H92!F:6QE+B`@07!A8VAE(#(@9&]E<PH@("`@
M("`@("`@("`@*B!.3U0@<W5P<&]R="!0051(7TE.1D\@:6YF;W)M871I;VX@
M8F5I;F<@<&%S<V5D('1O('1H90H@("`@("`@("`@("`@*B!02%`@;6]D=6QE
M(&)Y(&1E9F%U;'0L('-O(&1I<V%B;&4@=&AA=`H@("`@("`@("`@("`@*B!F
M=6YC=&EO;F%L:71Y+B`J+PH@("`@("`@("`@("!I9B`H*"1S97)V97(@(3T@
M)V%P86-H93(G*2D@>PH@("`@("`@("`@("`@("`@:68@*"@D<&]S(#T@<W1R
M<G!O<R@D9FEL96YA;64L("<N)RDI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2`G+R<@+B!P<F5G7W)E<&QA8V4H)R]<+B\G+"`G)3)%)RP@<W5B
M<W1R*"1F:6QE;F%M92P@,"P@)'!O<RDI.PH@("`@("`@("`@("`@("`@("`@
M("1E>'0@/2!S=6)S='(H)&9I;&5N86UE+"`D<&]S*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G+R<@
M+B`D9FEL96YA;64["B`@("`@("`@("`@("`@("`@("`@)&5X="`]("<G.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($5N=&5R('1H
M92!0051(7TE.1D\@:6YF;W)M871I;VXN("HO"B`@("`@("`@("`@("`@("!I
M9B`H*"1P;W,@/2!S=')P;W,H)'5R;"P@)S\G*2DI('L*("`@("`@("`@("`@
M("`@("`@("`D=7)L(#T@<W5B<W1R*"1U<FPL(#`L("1P;W,I("X@)&YA;64@
M+B!S=6)S='(H)'5R;"P@)'!O<RD["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1U<FP@+CT@)&YA;64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($%P<&5N
M9"!T:&4@97AT96YS:6]N+"!I9B!I="!E>&ES=',N("HO"B`@("`@("`@("`@
M(&EF("@H)'-E<G9E<B`]/2`G87!A8VAE,B<I('Q\("%E;7!T>2@D97AT*2D@
M>PH@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M=7)L+"`G9FY?97AT)RP@)R\G("X@)&9I;&5N86UE*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&%N(&%N8VAO<B!T86<@=VET:"!T:&4@<F5L
M979A;G0@<&%R86UE=&5R<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5R;"`@("`@("`@5&AE(&9U;&P@55),('1O(&)E(&QI;FME9"!T;RX*("`@
M("`J($!P87)A;2!S=')I;F<@)'1I=&QE("`@("`@5&AE(&QI;FL@=&ET;&4O
M9&5S8W)I<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@("`@
M(%1H92!#4U,@8VQA<W,@;V8@=&AE(&QI;FLN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T87)G970@("`@(%1H92!W:6YD;W<@=&%R9V5T('1O('!O:6YT('1O
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VYC;&EC:R`@("!*879A4V-R:7!T
M(&%C=&EO;B!F;W(@=&AE("=O;F-L:6-K)R!E=F5N="X*("`@("`J($!P87)A
M;2!S=')I;F<@)'1I=&QE,B`@("`@5&AE(&QI;FL@=&ET;&4@*'1O;VQT:7`I
M("AD97!R96-A=&5D("T@:G5S=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!U<V4@)'1I=&QE*2X*("`@("`J($!P87)A;2!S=')I;F<@)&%C
M8V5S<VME>2`@5&AE(&%C8V5S<R!K97D@=&\@=7-E+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1A='1R:6)U=&5S("!!;GD@;W1H97(@;F%M92]V86QU92!P86ER
M<R!T;R!A9&0@=&\@=&AE(#QA/@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T86<N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D97-C87!E("`@
M(%=H971H97(@=&\@97-C87!E('-P96-I86P@8VAA<F%C=&5R<R!I;B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=&ET;&4@871T<FEB
M=71E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"`\
M82!H<F5F/B!T86<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;FLH)'5R;"P@
M)'1I=&QE(#T@)R<L("1C;&%S<R`]("<G+"`D=&%R9V5T(#T@)R<L("1O;F-L
M:6-K(#T@)R<L"B`@("`@("`@("`@("`@("`@("1T:71L93(@/2`G)RP@)&%C
M8V5S<VME>2`]("<G+"`D871T<FEB=71E<R`](&%R<F%Y*"DL"B`@("`@("`@
M("`@("`@("`@("1E<V-A<&4@/2!T<G5E*0H@("`@>PH@("`@("`@('-T871I
M8R`D8VAA<G-E=#L*("`@("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T*2D@>PH@
M("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&ET;&4R*2D@>PH@("`@("`@
M("`@("`D=&ET;&4@/2`D=&ET;&4R.PH@("`@("`@('T*"B`@("`@("`@)')E
M="`]("(\82!H<F5F/5PB)'5R;%PB(CL*("`@("`@("!I9B`H(65M<'1Y*"1O
M;F-L:6-K*2D@>PH@("`@("`@("`@("`D<F5T("X]("(@;VYC;&EC:SU<(B1O
M;F-L:6-K7"(B.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1C;&%S
M<RDI('L*("`@("`@("`@("`@)')E="`N/2`B(&-L87-S/5PB)&-L87-S7"(B
M.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1T87)G970I*2!["B`@
M("`@("`@("`@("1R970@+CT@(B!T87)G970]7"(D=&%R9V5T7"(B.PH@("`@
M("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1T:71L92DI('L*("`@("`@("`@
M("`@:68@*"1E<V-A<&4I('L*("`@("`@("`@("`@("`@("1T:71L92`](&YL
M,F)R*$!H=&UL<W!E8VEA;&-H87)S*$!H=&UL<W!E8VEA;&-H87)S*"1T:71L
M92P@14Y47U%53U1%4RP@)&-H87)S970I+"!%3E1?455/5$53+"`D8VAA<G-E
M="DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R970@+CT@)R!T:71L
M93TB)R`N("1T:71L92`N("<B)SL*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D86-C97-S:V5Y*2D@>PH@("`@("`@("`@("`D<F5T("X]("<@86-C
M97-S:V5Y/2(G("X@:'1M;'-P96-I86QC:&%R<R@D86-C97-S:V5Y*2`N("<B
M)SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S
M("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D<F5T("X]("<@)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I("X@)STB)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H)'9A;'5E*2`N("<B)SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`B)')E=#XB.PH@("`@?0H*("`@("\J*@H@("`@("H@57-E<R!$3TT@5&]O
M;'1I<',@=&\@9&ES<&QA>2!T:&4@)W1I=&QE)R!A='1R:6)U=&4@9F]R"B`@
M("`@*B!(;W)D93HZ;&EN:R@I(&-A;&QS+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'5R;"`@("`@("`@5&AE(&9U;&P@55),('1O(&)E(&QI;FME
M9"!T;PH@("`@("H@0'!A<F%M('-T<FEN9R`D<W1A='5S("`@("!4:&4@2F%V
M85-C<FEP="!M;W5S92UO=F5R('-T<FEN9PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D8VQA<W,@("`@("!4:&4@0U-3(&-L87-S(&]F('1H92!L:6YK"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T87)G970@("`@(%1H92!W:6YD;W<@=&%R9V5T
M('1O('!O:6YT('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VYC;&EC:R`@
M("!*879A4V-R:7!T(&%C=&EO;B!F;W(@=&AE("=O;F-L:6-K)R!E=F5N="X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE("`@("`@5&AE(&QI;FL@=&ET
M;&4@*'1O;VQT:7`I+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-C97-S:V5Y
M("!4:&4@86-C97-S(&ME>2!T;R!U<V4N"B`@("`@*B!`<&%R86T@87)R87D@
M("1A='1R:6)U=&5S($%N>2!O=&AE<B!N86UE+W9A;'5E('!A:7)S('1O(&%D
M9"!T;R!T:&4@/&$^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1A9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@
M/&$@:')E9CX@=&%G+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YK5&]O;'1I
M<"@D=7)L+"`D<W1A='5S(#T@)R<L("1C;&%S<R`]("<G+"`D=&%R9V5T(#T@
M)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D;VYC;&EC:R`]("<G+"`D
M=&ET;&4@/2`G)RP@)&%C8V5S<VME>2`]("<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M('-T871I8R`D8VAA<G-E=#L*("`@("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T
M*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&ET;&4I*2!["B`@
M("`@("`@("`@("1T:71L92`]("<F;'0[<')E)F=T.R<@+B!P<F5G7W)E<&QA
M8V4H87)R87DH)R]<;B\G+"`G+R@H/SPA/&)R*5QS>S$L?2@_/"%<+SXI*2]E
M;2<L("<O/&)R(%PO/CQB<B!<+SXO)RP@)R\\8G(@7"\^+R<I+"!A<G)A>2@G
M)RP@)W-T<E]R97!E870H(B9N8G-P.R(L('-T<FQE;B@B)#$B*2DG+"`G)FQT
M.V)R("\F9W0[("9L=#MB<B`O)F=T.R<L("<F;'0[8G(@+R9G=#LG*2P@;FPR
M8G(H0&AT;6QS<&5C:6%L8VAA<G,H0&AT;6QS<&5C:6%L8VAA<G,H)'1I=&QE
M+"!%3E1?455/5$53+"`D8VAA<G-E="DL($5.5%]154]415,L("1C:&%R<V5T
M*2DI("X@)R9L=#LO<')E)F=T.R<["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!(;W)D93HZ;&EN:R@D=7)L+"`D=&ET;&4L("1C;&%S<RP@)'1A<F=E="P@
M)&]N8VQI8VLL(&YU;&PL("1A8V-E<W-K97DL("1A='1R:6)U=&5S+"!F86QS
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%N8VAO<B!S
M97%U96YC92!W:71H('1H92!R96QE=F%N="!P87)A;65T97)S(&9O<B!A('=I
M9&=E=`H@("`@("H@=VET:"!A8V-E<W-K97D@86YD('1E>'0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=7)L("`@("`@5&AE(&9U;&P@55),('1O(&)E(&QI;FME9"!T;RX*
M("`@("`J($!P87)A;2!S=')I;F<@("1T:71L92`@("!4:&4@;&EN:R!T:71L
M92]D97-C<FEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@("1C;&%S<R`@
M("!4:&4@0U-3(&-L87-S(&]F('1H92!L:6YK"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=&%R9V5T("`@5&AE('=I;F1O=R!T87)G970@=&\@<&]I;G0@=&\N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;VYC;&EC:R`@2F%V85-C<FEP="!A
M8W1I;VX@9F]R('1H92`G;VYC;&EC:R<@979E;G0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D=&ET;&4R("`@5&AE(&QI;FL@=&ET;&4@*'1O;VQT:7`I("AD
M97!R96-A=&5D("T@:G5S="!U<V4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&ET;&4I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YO8VAE
M8VL@($1O;B=T(&-H96-K(&EF('1H92!A8V-E<W,@:V5Y(&%L<F5A9'D@:&%S
M(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!U<V5D+B!$
M969A=6QT<R!T;R!F86QS92`H/2!C:&5C:RDN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!F=6QL(#QA(&AR968^5&ET;&4\+V$^('-E<75E
M;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W:61G970H)'5R;"P@)'1I=&QE
M(#T@)R<L("1C;&%S<R`]("=W:61G970G+"`D=&%R9V5T(#T@)R<L"B`@("`@
M("`@("`@("`@("`@("`@)&]N8VQI8VL@/2`G)RP@)'1I=&QE,B`]("<G+"`D
M;F]C:&5C:R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1I
M=&QE,BDI('L*("`@("`@("`@("`@)'1I=&QE(#T@)'1I=&QE,CL*("`@("`@
M("!]"@H@("`@("`@("1A:R`]($AO<F1E.CIG971!8V-E<W-+97DH)'1I=&QE
M+"`D;F]C:&5C:RD["@H@("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@D=7)L
M+"`G)RP@)&-L87-S+"`D=&%R9V5T+"`D;VYC;&EC:RP@)R<L("1A:RD@+B!(
M;W)D93HZ:&EG:&QI9VAT06-C97-S2V5Y*"1T:71L92P@)&%K*2`N("<\+V$^
M)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S97-S:6]N+6ED
M+6EF:65D('9E<G-I;VX@;V8@)%-#4DE05%].04U%(')E<W`N("102%!?4T5,
M1BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V-R:7!T7W!A<F%M
M<R!);F-L=61E('-C<FEP="!P87)A;65T97)S(&QI:V4@455%4EE?4U1224Y'
M(&%N9"!0051(7TE.1D\_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;F]C86-H
M92`@("`@("!);F-L=61E(&$@;F]C86-H92!P87)A;65T97(@:6X@=&AE(%52
M3#\*("`@("`J($!P87)A;2!B;V]L96%N("1F=6QL("`@("`@("`@(%)E='5R
M;B!A(&9U;&P@55),/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5Q=65S=&5D(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5L9E5R
M;"@D<V-R:7!T7W!A<F%M<R`](&9A;'-E+"`D;F]C86-H92`]('1R=64L("1F
M=6QL(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("1F;W)C95]S<VP@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H<W5B<W1R*'!H<%]S87!I7VYA
M;64H*2P@,"P@,RD@/3T@)V-G:2<I('L*("`@("`@("`@("`@+R\@5VAE;B!U
M<VEN9R!#1TD@4$A0+"!30U))4%1?3D%-12!M87D@8V]N=&%I;B!T:&4@<&%T
M:"!T;PH@("`@("`@("`@("`O+R!T:&4@4$A0(&)I;F%R>2!I;G-T96%D(&]F
M('1H92!S8W)I<'0@8F5I;F<@<G5N.R!U<V4*("`@("`@("`@("`@+R\@4$A0
M7U-%3$8@:6YS=&5A9"X*("`@("`@("`@("`@)'5R;"`]("1?4T525D526R=0
M2%!?4T5,1B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1U<FP@
M/2!I<W-E="@D7U-%4E9%4ELG4T-225!47TY!344G72D@/PH@("`@("`@("`@
M("`@("`@)%]315)615);)U-#4DE05%].04U%)UT@.@H@("`@("`@("`@("`@
M("`@)%]315)615);)U!(4%]314Q&)UT["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'-C<FEP=%]P87)A;7,I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M7U-%4E9%4ELG4$%42%])3D9/)UTI*2!["B`@("`@("`@("`@("`@("`D=7)L
M("X]("1?4T525D526R=0051(7TE.1D\G73L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1?4T525D526R=1545265]35%))3D<G72DI
M('L*("`@("`@("`@("`@("`@("1U<FP@+CT@)S\G("X@)%]315)615);)U%5
M15)97U-44DE.1R==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D=7)L(#T@2&]R9&4Z.G5R;"@D=7)L+"`D9G5L;"P@,"P@)&9O<F-E7W-S
M;"D["@H@("`@("`@(&EF("@D;F]C86-H92D@>PH@("`@("`@("`@("!R971U
M<FX@571I;#HZ;F]C86-H955R;"@D=7)L*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@8V]R<F5C=&QY+7!A=&AE9"!L:6YK
M('1O(&%N(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-R
M8R`@(%1H92!I;6%G92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86QT
M("`@5&5X="!D97-C<FEB:6YG('1H92!I;6%G92X*("`@("`J($!P87)A;2!M
M:7AE9"`@)&%T='(@($%N>2!A9&1I=&EO;F%L(&%T=')I8G5T97,@9F]R('1H
M92!I;6%G92!T86<N($-A;B!B90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@82!P<F4M8G5I;'0@<W1R:6YG(&]R(&%N(&%R<F%Y(&]F(&ME>2]V86QU
M92!P86ER<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@=&AA="!W:6QL
M(&)E(&%S<V5M8FQE9"!A;F0@:'1M;"UE;F-O9&5D+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&ER("`@5&AE(')O;W0@9W)A<&AI8W,@9&ER96-T;W)Y+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"!I;6%G92!T
M86<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM9R@D<W)C+"`D86QT(#T@)R<L
M("1A='1R(#T@)R<L("1D:7(@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I
M8R`D8VAA<G-E=#L*("`@("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T*2D@>PH@
M("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M(&EM86=E<RP@<VEM<&QY(')E='5R;B!T:&4@04Q4('1E>'0N("HO"B`@("`@
M("`@:68@*"$D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=I;6%G
M97,G*2D@>PH@("`@("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H
M)&%L="P@14Y47T-/35!!5"P@)&-H87)S970I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@268@;F\@9&ER96-T;W)Y(&AA<R!B965N('-P96-I9FEE9"P@9V5T
M(&ET(&9R;VT@=&AE(')E9VES=')Y+B`J+PH@("`@("`@(&EF("@D9&ER(#T]
M/2!N=6QL*2!["B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@
M("`@("`@("1D:7(@/2`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"D["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!A(&1I<F5C=&]R>2!H87,@8F5E;B!P<F]V
M:61E9"P@<')E<&5N9"!I="!T;R!T:&4@:6UA9V4@<V]U<F-E+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)&1I<BDI('L*("`@("`@("`@("`@)'-R8R`]("1D
M:7(@+B`G+R<@+B`D<W)C.PH@("`@("`@('T*"B`@("`@("`@+RH@0G5I;&0@
M86QL(&]F('1H92!T86<@871T<FEB=71E<RX@*B\*("`@("`@("`D871T<FEB
M=71E<R`](&%R<F%Y*"=S<F,G(#T^("1S<F,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G86QT)R`]/B`D86QT*3L*("`@("`@("!I9B`H:7-?87)R
M87DH)&%T='(I*2!["B`@("`@("`@("`@("1A='1R:6)U=&5S(#T@87)R87E?
M;65R9V4H)&%T=')I8G5T97,L("1A='1R*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1A='1R:6)U=&5S6R=T:71L92==*2D@>PH@("`@("`@("`@
M("`D871T<FEB=71E<ULG=&ET;&4G72`]("<G.PH@("`@("`@('T*"B`@("`@
M("`@)&EM9R`]("<\:6UG)SL*("`@("`@("!F;W)E86-H("@D871T<FEB=71E
M<R!A<R`D871T<FEB=71E(#T^("1V86QU92D@>PH@("`@("`@("`@("`D:6UG
M("X]("<@)R`N("1A='1R:6)U=&4@+B`G/2(G("X@*"1A='1R:6)U=&4@/3T@
M)W-R8R<@/R`D=F%L=64@.B!`:'1M;'-P96-I86QC:&%R<R@D=F%L=64L($5.
M5%]#3TU0050L("1C:&%R<V5T*2D@+B`G(B<["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!T:&4@=7-E<B!S=7!P;&EE9"!A('!R92UB=6EL="!S=')I;F<@
M;V8@871T<FEB=71E<RP@861D('1H870N("HO"B`@("`@("`@:68@*&ES7W-T
M<FEN9R@D871T<BD@)B8@(65M<'1Y*"1A='1R*2D@>PH@("`@("`@("`@("`D
M:6UG("X]("<@)R`N("1A='1R.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T
M=7)N('1H92!C;&]S960@:6UA9V4@=&%G+B`J+PH@("`@("`@(')E='5R;B`D
M:6UG("X@)R`O/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S
M('1H92!L;V-A=&EO;B!O9B!T:&4@<WES=&5M('1E;7!O<F%R>2!D:7)E8W1O
M<GDN($EF(&$@<W!E8VEF:6,*("`@("`J('-E='1I;F<@8V%N;F]T(&)E(&9O
M=6YD+"!I="!D969A=6QT<R!T;R`O=&UP+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!!(&1I<F5C=&]R>2!N86UE('1H870@8V%N(&)E('5S960@
M9F]R('1E;7`@9FEL97,N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N
M<R!F86QS92!I9B!O;F4@8V]U;&0@;F]T(&)E(&9O=6YD+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971496UP1&ER*"D*("`@('L*("`@("`@("!G;&]B86P@
M)&-O;F8["@H@("`@("`@("\J($EF(&]N92!H87,@8F5E;B!S<&5C:69I8V%L
M;'D@<V5T+"!T:&5N('5S92!T:&%T("HO"B`@("`@("`@:68@*"%E;7!T>2@D
M8V]N9ELG=&UP9&ER)UTI*2!["B`@("`@("`@("`@("1T;7`@/2`D8V]N9ELG
M=&UP9&ER)UT["B`@("`@("`@?0H*("`@("`@("`O*B!.97AT+"!T<GD@571I
M;#HZ9V5T5&5M<$1I<B@I+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@
M>PH@("`@("`@("`@("`D=&UP(#T@571I;#HZ9V5T5&5M<$1I<B@I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@:70@:7,@<W1I;&P@96UP='DL('=E(&AA
M=F4@9F%I;&5D+"!S;R!R971U<FX@9F%L<V4["B`@("`@("`@("H@;W1H97)W
M:7-E(')E='5R;B!T:&4@9&ER96-T;W)Y(&1E=&5R;6EN960N("HO"B`@("`@
M("`@<F5T=7)N(&5M<'1Y*"1T;7`I(#\@9F%L<V4@.B`D=&UP.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A('1E;7!O<F%R>2!F:6QE;F%M92!F
M;W(@=&AE(&QI9F5T:6UE(&]F('1H92!S8W)I<'0L(&%N9`H@("`@("H@*&]P
M=&EO;F%L;'DI(')E9VES=&5R<R!I="!T;R!B92!D96QE=&5D(&%T(')E<75E
M<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E
M9FEX("`@4')E9FEX('1O(&UA:V4@=&AE('1E;7!O<F%R>2!N86UE(&UO<F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(')E8V]G;FEZ86)L92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@($1E;&5T92!T:&4@9FEL
M92!A="!T:&4@96YD(&]F('1H92!R97%U97-T/PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&ER("`@("`@1&ER96-T;W)Y('1O(&-R96%T92!T:&4@=&5M<&]R
M87)Y(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V5C=7)E("!)
M9B!D96QE=&EN9R!F:6QE+"!S:&]U;&0@=V4@<V5C=7)E;'D@9&5L971E('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9FEL93\*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%)E='5R;G,@=&AE(&9U;&P@<&%T
M:"UN86UE('1O('1H92!T96UP;W)A<GD@9FEL92!O<@H@("`@("H@("`@("`@
M("`@("`@("`@("!F86QS92!I9B!A('1E;7!O<F%R>2!F:6QE(&-O=6QD(&YO
M="!B92!C<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971496UP1FEL
M92@D<')E9FEX(#T@)TAO<F1E)RP@)&1E;&5T92`]('1R=64L("1D:7(@/2`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1S96-U<F4@/2!F86QS92D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)&1I<BD@?'P@(6ES7V1I<B@D9&ER
M*2D@>PH@("`@("`@("`@("`D9&ER(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!5=&EL.CIG971496UP1FEL92@D
M<')E9FEX+"`D9&5L971E+"`D9&ER+"`D<V5C=7)E*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-T87)T<R!O=71P=70@8V]M<')E<W-I;VXL(&EF(')E<75E
M<W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<')E<W-/=71P=70H*0H@
M("`@>PH@("`@("`@('-T871I8R`D<W1A<G1E9#L*"B`@("`@("`@:68@*&ES
M<V5T*"1S=&%R=&5D*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("`O*B!#;VUP<F5S<R!O=71P=70@:68@<F5Q=65S=&5D(&%N
M9"!P;W-S:6)L92X@*B\*("`@("`@("!I9B`H)$=,3T)!3%-;)V-O;F8G75LG
M8V]M<')E<W-?<&%G97,G72`F)@H@("`@("`@("`@("`A)$=,3T)!3%-;)V)R
M;W=S97(G72T^:&%S475I<FLH)V)U9V=Y7V-O;7!R97-S:6]N)RD@)B8*("`@
M("`@("`@("`@(2AB;V]L*6EN:5]G970H)WIL:6(N;W5T<'5T7V-O;7!R97-S
M:6]N)RD@)B8*("`@("`@("`@("`@(2AB;V]L*6EN:5]G970H)WIE;F1?86-C
M96QE<F%T;W(N8V]M<')E<W-?86QL)RD@)B8*("`@("`@("`@("`@:6YI7V=E
M="@G;W5T<'5T7VAA;F1L97(G*2`A/2`G;V)?9WIH86YD;&5R)RD@>PH@("`@
M("`@("`@("!I9B`H;V)?9V5T7VQE=F5L*"DI('L*("`@("`@("`@("`@("`@
M(&]B7V5N9%]C;&5A;B@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]B
M7W-T87)T*"=O8E]G>FAA;F1L97(G*3L*("`@("`@("!]"@H@("`@("`@("1S
M=&%R=&5D(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@:68@;W5T<'5T(&-O;7!R97-S:6]N(&-A;B!B92!U<V5D+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!O=71P=70@8V]M<')E
M<W-I;VX@8V%N(&)E('5S960L(&9A;'-E(&EF(&YO="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86QL;W=/=71P=71#;VUP<F5S<VEO;B@I"B`@("!["B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]"<F]W<V5R+G!H<"<["B`@("`@("`@
M)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["@H@("`@("`@("\J
M(%1U<FX@;V9F(&-O;7!R97-S:6]N(&9O<B!B=6=G>2!B<F]W<V5R<RX@*B\*
M("`@("`@("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=B=6=G>5]C;VUP<F5S
M<VEO;B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`H:6YI7V=E="@G>FQI8BYO=71P=71?8V]M<')E
M<W-I;VXG*2`]/2`G)R`F)@H@("`@("`@("`@("`@("`@:6YI7V=E="@G>F5N
M9%]A8V-E;&5R871O<BYC;VUP<F5S<U]A;&PG*2`]/2`G)R`F)@H@("`@("`@
M("`@("`@("`@:6YI7V=E="@G;W5T<'5T7VAA;F1L97(G*2`A/2`G;V)?9WIH
M86YD;&5R)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!7
M96(@<V5R=F5R(&)E:6YG('5S960N"B`@("`@*B!02%`@<W1R:6YG(&QI<W0@
M8G5I;'0@9G)O;2!T:&4@4$A0("=C;VYF:6=U<F4G('-C<FEP="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!W96(@<V5R=F5R(&ED96YT:69I
M8V%T:6]N('-T<FEN9RX*("`@("`J(#QP<F4^"B`@("`@*B`G86]L<V5R=F5R
M)R`]($%/3"!397)V97(*("`@("`J("=A<&%C:&4Q)R`@(#T@07!A8VAE(#$N
M>`H@("`@("H@)V%P86-H93(G("`@/2!!<&%C:&4@,BYX"B`@("`@*B`G8V%U
M9&EU;2<@("`]($-A=61I=6T*("`@("`J("=C9VDG("`@("`@(#T@56YK;F]W
M;B!S97)V97(@+2!02%`@8G5I;'0@87,@0T=)('!R;V=R86T*("`@("`J("=C
M;&DG("`@("`@(#T@0V]M;6%N9"!,:6YE($EN=&5R9F%C92!B=6EL9`H@("`@
M("H@)V5M8F5D)R`@("`@/2!%;6)E9&1E9"!02%`*("`@("`J("=I<V%P:2<@
M("`@(#T@6F5U<R!)4T%020H@("`@("H@)VUI;'1E<B<@("`@/2!-:6QT97(*
M("`@("`J("=N<V%P:2<@("`@(#T@3E-!4$D*("`@("`J("=P:'1T<&0G("`@
M(#T@4$A45%!$"B`@("`@*B`G<&DS=V5B)R`@("`](%!I,U=E8@H@("`@("H@
M)W)O>&5N)R`@("`@/2!2;WAE;B]0:6ME"B`@("`@*B`G<V5R=FQE="<@("`]
M(%-E<G9L970*("`@("`J("=T:'1T<&0G("`@(#T@=&AT='!D"B`@("`@*B`G
M='5X)R`@("`@("`](%1U>`H@("`@("H@)W=E8FIA;65S)R`@/2!796)J86UE
M<PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N('=E8E-E<G9E
M<DE$*"D*("`@('L*("`@("`@("`D<V5R=F5R(#T@<&AP7W-A<&E?;F%M92@I
M.PH*("`@("`@("!I9B`H)'-E<G9E<B`]/2`G87!A8VAE)RD@>PH@("`@("`@
M("`@("!R971U<FX@)V%P86-H93$G.PH@("`@("`@('T@96QS96EF("@H)'-E
M<G9E<B`]/2`G87!A8VAE,F9I;'1E<B<I('Q\"B`@("`@("`@("`@("`@("`@
M("@D<V5R=F5R(#T]("=A<&%C:&4R:&%N9&QE<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`G87!A8VAE,B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1S97)V97(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@/&QI;FL^('1A9W,@9F]R('1H92!#4U,@<W1Y
M;&5S:&5E=',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D
M87!P("!4:&4@2&]R9&4@87!P;&EC871I;VXH<RDN"B`@("`@*B!`<&%R86T@
M;6EX960@)'1H96UE("`@("`@(%1H92!T:&5M92!T;R!U<V4[('-P96-I9GD@
M86X@96UP='D@=F%L=64@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T<FEE=F4@=&AE('1H96UE(&9R;VT@=7-E<B!P<F5F97)E;F-E
M<RP@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E
M(&9O<B!N;R!T:&5M92X*("`@("`J($!P87)A;2!B;V]L96%N("1I;FAE<FET
M("`@26YH97)I="!(;W)D92UW:61E($-34S\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@/&QI;FL^('1A9W,@9F]R($-34R!S='EL97-H965T<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<W1Y;&5S:&5E=$QI;FLH)&%P<',@/2!N
M=6QL+"`D=&AE;64@/2`G)RP@)&EN:&5R:70@/2!T<G5E*0H@("`@>PH@("`@
M("`@(&EF("@D=&AE;64@/3T]("<G("8F(&ES<V5T*"1'3$]"04Q36R=P<F5F
M<R==*2D@>PH@("`@("`@("`@("`D=&AE;64@/2`D1TQ/0D%,4ULG<')E9G,G
M72T^9V5T5F%L=64H)W1H96UE)RD["B`@("`@("`@?0H*("`@("`@("`D<G1L
M(#T@:7-S970H)$=,3T)!3%-;)VYL<R==6R=R=&PG75LD1TQ/0D%,4ULG;&%N
M9W5A9V4G75TI.PH@("`@("`@("1C<W,@/2!A<G)A>2@I.PH*("`@("`@("`D
M=&AE;65S7V9S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&AE;65S
M9G,G+"`G:&]R9&4G*3L*("`@("`@("!I9B`H)&EN:&5R:70I('L*("`@("`@
M("`@("`@)'1H96UE<U]U<FD@/2!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I
M<W1R>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D92<I+"!F86QS92P@+3$I
M.PH@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O<V-R965N
M+F-S<R<["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H96UE*2`F)@H@("`@
M("`@("`@("`@("`@9FEL95]E>&ES=',H)'1H96UE<U]F<R`N("<O)R`N("1T
M:&5M92`N("<O<V-R965N+F-S<R<I*2!["B`@("`@("`@("`@("`@("`D8W-S
M6UT@/2`D=&AE;65S7W5R:2`N("<O)R`N("1T:&5M92`N("<O<V-R965N+F-S
M<R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D<G1L*2!["B`@
M("`@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O<G1L+F-S
M<R<["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&5M92D@)B8*("`@
M("`@("`@("`@("`@("`@("!F:6QE7V5X:7-T<R@D=&AE;65S7V9S("X@)R\G
M("X@)'1H96UE("X@)R]R=&PN8W-S)RDI('L*("`@("`@("`@("`@("`@("`@
M("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O)R`N("1T:&5M92`N("<O<G1L
M+F-S<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@A96UP='DH)&%P<',I*2!["B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)&%P<',I*2!["B`@("`@("`@("`@("`@("`D87!P
M<R`](&%R<F%Y*"1A<'!S*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M9F]R96%C:"`H)&%P<',@87,@)&%P<"D@>PH@("`@("`@("`@("`@("`@:68@
M*"1I;FAE<FET("8F("1A<'`@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1T:&5M97-?9G,@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=T:&5M97-F<R<L("1A<'`I.PH@("`@("`@("`@("`@("`@)'1H96UE<U]U
M<FD@/2!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1H
M96UE<W5R:2<L("1A<'`I+"!F86QS92P@+3$I.PH@("`@("`@("`@("`@("`@
M:68@*&9I;&5?97AI<W1S*"1T:&5M97-?9G,@+B`G+W-C<F5E;BYC<W,G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@
M)R]S8W)E96XN8W-S)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)'1H96UE*2`F)@H@("`@("`@("`@("`@("`@("`@
M(&9I;&5?97AI<W1S*"1T:&5M97-?9G,@+B`G+R<@+B`D=&AE;64@+B`G+W-C
M<F5E;BYC<W,G*2D@>PH@("`@("`@("`@("`@("`@("`@("1C<W-;72`]("1T
M:&5M97-?=7)I("X@)R\G("X@)'1H96UE("X@)R]S8W)E96XN8W-S)SL*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)')T;"D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&AE;65S7V9S
M("X@)R]R=&PN8W-S)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-S
M<UM=(#T@)'1H96UE<U]U<FD@+B`G+W)T;"YC<W,G.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&5M
M92D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@9FEL95]E>&ES=',H)'1H
M96UE<U]F<R`N("<O)R`N("1T:&5M92`N("<O<G1L+F-S<R<I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@)R\G
M("X@)'1H96UE("X@)R]R=&PN8W-S)SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1H=&UL(#T@)R<["B`@("`@("`@9F]R96%C:"`H)&-S<R!A<R`D
M8W-S7VQI;FLI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQL:6YK(&AR968]
M(B<@+B`D8W-S7VQI;FL@+B`G(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E
M>'0O8W-S(B`O/B<@+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A
M9"!)12!03D<@=')A;G-P87)E;F-Y(&-O9&4@:68@;F5E9&5D+B`J+PH@("`@
M("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-1=6ER:R@G<&YG7W1R
M86YS<&%R96YC>2<I("8F"B`@("`@("`@("`@("1'3$]"04Q36R=P<F5F<R==
M+3YG971686QU92@G86QP:&%?9FEL=&5R)RDI('L*("`@("`@("`@("`@)'5R
M;"`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G:G-U
M<FDG+"`G:&]R9&4G*2`N("<O86QP:&%);6%G94QO861E<BYP:'`G+"!T<G5E
M+"`M,2D["B`@("`@("`@("`@("1H=&UL("X]("<\<W1Y;&4@='EP93TB=&5X
M="]C<W,B/B!I;6<@>R!B96AA=FEO<CH@=7)L*"(G("X@)'5R;"`N("<B*3L@
M?2`\+W-T>6QE/B<["B`@("`@("`@?0H*("`@("`@("`O*B!,;V%D(&)R;W=S
M97(@<W!E8VEF:6,@<W1Y;&5S:&5E=',@:68@;F5E9&5D+B`J+PH@("`@("`@
M(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YI<T)R;W=S97(H)VUS:64G*2`F
M)B`D1TQ/0D%,4ULG8G)O=W-E<B==+3YG971-86IO<B@I(#P@-RD@>PH@("`@
M("`@("`@("`D:'1M;"`N/2`G/&QI;FL@:')E9CTB)R`N("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D92<I("X@)R]I939?
M;W)?;&5S<RYC<W,B(')E;#TB<W1Y;&5S:&5E="(@='EP93TB=&5X="]C<W,B
M("\^)R`N(")<;B(["B`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E
M<B==+3YG9710;&%T9F]R;2@I(#T]("=M86,G*2!["B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/&QI;FL@:')E9CTB)R`N("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D92<I("X@)R]I935M86,N8W-S
M(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@+B`B7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D1TQ/0D%,
M4ULG8G)O=W-E<B==+3YI<T)R;W=S97(H)V]P97)A)RDI('L*("`@("`@("`@
M("`@)&AT;6P@+CT@)SQL:6YK(&AR968](B<@+B`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=T:&5M97-U<FDG+"`G:&]R9&4G*2`N("<O;W!E<F$N8W-S
M(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@+B`B7&XB
M.PH@("`@("`@('T*("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^
M:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8*("`@("`@("`@("`@)$=,3T)!3%-;
M)V)R;W=S97(G72T^9V5T36%J;W(H*2`^/2`U("8F"B`@("`@("`@("`@('!R
M96=?;6%T8V@H)R]R=CHH+BHI7"DO)RP@)$=,3T)!3%-;)V)R;W=S97(G72T^
M9V5T06=E;G13=')I;F<H*2P@)')E=FES:6]N*2`F)@H@("`@("`@("`@("`D
M<F5V:7-I;VY;,5T@/#T@,2XT*2!["B`@("`@("`@("`@("1H=&UL("X]("<\
M;&EN:R!H<F5F/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&AE
M;65S=7)I)RP@)VAO<F1E)RD@+B`G+VUO>C$T+F-S<R(@<F5L/2)S='EL97-H
M965T(B!T>7!E/2)T97AT+V-S<R(@+SXG("X@(EQN(CL*("`@("`@("!]"B`@
M("`@("`@:68@*'-T<G!O<RAS=')T;VQO=V5R*"1'3$]"04Q36R=B<F]W<V5R
M)UTM/F=E=$%G96YT4W1R:6YG*"DI+"`G<V%F87)I)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1H=&UL("X]("<\;&EN:R!H<F5F/2(G("X@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G=&AE;65S=7)I)RP@)VAO<F1E)RD@+B`G
M+W-A9F%R:2YC<W,B(')E;#TB<W1Y;&5S:&5E="(@='EP93TB=&5X="]C<W,B
M("\^)R`N(")<;B(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@8W5S=&]M('-E<W-I;VX@
M:&%N9&QE<B!U<"P@:68@=&AE<F4@:7,@;VYE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971U<%-E<W-I;VY(86YD;&5R*"D*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8["@H@("`@("`@(&EN:5]S970H)W5R;%]R97=R:71E<BYT86=S
M)RP@,"D["B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG<V5S<VEO;B==6R=U
M<V5?;VYL>5]C;V]K:65S)UTI*2!["B`@("`@("`@("`@(&EN:5]S970H)W-E
M<W-I;VXN=7-E7V]N;'E?8V]O:VEE<R<L(#$I.PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTI("8F"B`@("`@("`@
M("`@("`@("!S=')P;W,H)&-O;F9;)W-E<G9E<B==6R=N86UE)UTL("<N)RD@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4V5S<VEO;B!C;V]K:65S('=I;&P@;F]T('=O<FL@=VET:&]U="!A($91
M1$X@86YD('=I=&@@82!N;VXM96UP='D@8V]O:VEE(&1O;6%I;BXG+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@('-E<W-I;VY?<V5T7V-O;VMI95]P87)A
M;7,H)&-O;F9;)W-E<W-I;VXG75LG=&EM96]U="==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)V-O;VMI92==6R=P871H)UTL
M("1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTL("1C;VYF6R=U<V5?<W-L)UT@
M/3T@,2`_(#$@.B`P*3L*("`@("`@("!S97-S:6]N7V-A8VAE7VQI;6ET97(H
M)&-O;F9;)W-E<W-I;VXG75LG8V%C:&5?;&EM:71E<B==*3L*("`@("`@("!S
M97-S:6]N7VYA;64H=7)L96YC;V1E*"1C;VYF6R=S97-S:6]N)UU;)VYA;64G
M72DI.PH*("`@("`@("`D='EP92`]("%E;7!T>2@D8V]N9ELG<V5S<VEO;FAA
M;F1L97(G75LG='EP92==*2`_("1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T
M>7!E)UT@.B`G;F]N92<["@H@("`@("`@(&EF("@D='EP92`]/2`G97AT97)N
M86PG*2!["B`@("`@("`@("`@("1C86QL<R`]("1C;VYF6R=S97-S:6]N:&%N
M9&QE<B==6R=P87)A;7,G73L*("`@("`@("`@("`@<V5S<VEO;E]S971?<V%V
M95]H86YD;&5R*"1C86QL<ULG;W!E;B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-A;&QS6R=C;&]S92==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QS6R=R96%D)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%L;'-;)W=R
M:71E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V%L;'-;)V1E<W1R;WDG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C86QL<ULG9V,G72D["B`@("`@("`@?2!E;'-E:68@*"1T
M>7!E("$]("=N;VYE)RD@>PH@("`@("`@("`@("!G;&]B86P@)%]S97-S:6]N
M7VAA;F1L97(["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S
M<VEO;DAA;F1L97(N<&AP)SL*("`@("`@("`@("`@)%]S97-S:6]N7VAA;F1L
M97(@/2`F4V5S<VEO;DAA;F1L97(Z.G-I;F=L971O;B@D8V]N9ELG<V5S<VEO
M;FAA;F1L97(G75LG='EP92==*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M7W-E<W-I;VY?:&%N9&QE<BD@)B8*("`@("`@("`@("`@("`@("%I<U]A*"1?
M<V5S<VEO;E]H86YD;&5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!I;FE?<V5T*"=S97-S:6]N+G-A=F5?:&%N9&QE<B<L("=U<V5R)RD[
M"B`@("`@("`@("`@("`@("!S97-S:6]N7W-E=%]S879E7VAA;F1L97(H87)R
M87DH)B1?<V5S<VEO;E]H86YD;&5R+"`G;W!E;B<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?
M:&%N9&QE<BP@)V-L;W-E)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)B1?<V5S<VEO;E]H86YD;&5R+"`G<F5A
M9"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"8D7W-E<W-I;VY?:&%N9&QE<BP@)W=R:71E)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)B1?<V5S
M<VEO;E]H86YD;&5R+"`G9&5S=')O>2<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?:&%N9&QE
M<BP@)V=C)RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H)TAO<F1E(&ES('5N
M86)L92!T;R!C;W)R96-T;'D@<W1A<G0@=&AE(&-U<W1O;2!S97-S:6]N(&AA
M;F1L97(N)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A;B!U;BUU<V5D(&%C8V5S<R!K97D@9G)O;2!T:&4@;&%B96P@9VEV96XN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@(%1H92!L
M86)E;"!T;R!C:&]O<V4@86X@86-C97-S(&ME>2!F<F]M+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&YO8VAE8VL@($1O;B=T(&-H96-K(&EF('1H92!A8V-E
M<W,@:V5Y(&%L<F5A9'D@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!U<V5D/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!!('-I;F=L92!L;W=E<B!C87-E(&-H87)A8W1E<B!A8V-E<W,@:V5Y(&]R
M(&5M<'1Y"B`@("`@*B`@("`@("`@("`@("`@("`@<W1R:6YG(&EF(&YO;F4@
M8V%N(&)E(&9O=6YD"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%C8V5S<TME
M>2@D;&%B96PL("1N;V-H96-K(#T@9F%L<V4L("1S:'5T9&]W;B`](&9A;'-E
M*0H@("`@>PH@("`@("`@("\J(%1H92!A8V-E<W,@:V5Y<R!A;')E861Y('5S
M960@:6X@=&AI<R!P86=E("HO"B`@("`@("`@<W1A=&EC("1?=7-E9"`](&%R
M<F%Y*"D["@H@("`@("`@("\J(%1H92!L86)E;',@86QR96%D>2!U<V5D(&EN
M('1H:7,@<&%G92`J+PH@("`@("`@('-T871I8R`D7VQA8F5L<R`](&%R<F%Y
M*"D["@H@("`@("`@("\J(%-H=71D;W=N(&-A;&P@9F]R('1R86YS;&%T;W)S
M/R`J+PH@("`@("`@(&EF("@D<VAU=&1O=VXI('L*("`@("`@("`@("`@:68@
M*"%C;W5N="@D7VQA8F5L<RDI('L*("`@("`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V-R:7!T(#T@8F%S96YA;64H
M)%]315)615);)U!(4%]314Q&)UTI.PH@("`@("`@("`@("`D;&%B96QS(#T@
M87)R87E?:V5Y<R@D7VQA8F5L<RD["B`@("`@("`@("`@('-O<G0H)&QA8F5L
M<RD["B`@("`@("`@("`@("1U<V5D(#T@87)R87E?:V5Y<R@D7W5S960I.PH@
M("`@("`@("`@("!S;W)T*"1U<V5D*3L*("`@("`@("`@("`@)')E;6%I;FEN
M9R`]('-T<E]R97!L86-E*"1U<V5D+"!A<G)A>2@I+"`G86)C9&5F9VAI:FML
M;6YO<'%R<W1U=G=X>7HG*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)T%C8V5S<R!K97D@:6YF;W)M871I;VX@9F]R("<@+B`D<V-R:7!T+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G57-E9"!L86)E;',Z("<@+B!I;7!L;V1E*"<L)RP@)&QA8F5L<RDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=5<V5D(&ME>7,Z("<@+B!I;7!L;V1E*"<G+"`D=7-E9"DL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=&<F5E(&ME>7,Z("<@+B`D<F5M86EN:6YG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@
M("`O*B!5<V4@86-C97-S(&ME>7,@870@86QL/R`J+PH@("`@("`@('-T871I
M8R`D;F]T<W5P<&]R=&5D.PH@("`@("`@(&EF("@A:7-S970H)&YO='-U<'!O
M<G1E9"DI('L*("`@("`@("`@("`@)&YO='-U<'!O<G1E9"`]("$D1TQ/0D%,
M4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=A8V-E<W-K97DG*2!\?`H@("`@
M("`@("`@("`@("`@(21'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G=VED
M9V5T7V%C8V5S<VME>2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1N;W1S
M=7!P;W)T960@?'P@(7!R96=?;6%T8V@H)R]?*%M!+5IA+7I=*2\G+"`D;&%B
M96PL("1M871C:"DI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M('T*("`@("`@("`D:V5Y(#T@)&UA=&-H6S%=.PH*("`@("`@("`O*B!(87,@
M=&AI<R!K97D@86QR96%D>2!B965N('5S960_("HO"B`@("`@("`@:68@*&ES
M<V5T*"1?=7-E9%MS=')T;VQO=V5R*"1K97DI72D@)B8*("`@("`@("`@("`@
M(2@D;F]C:&5C:R`F)B!I<W-E="@D7VQA8F5L<ULD;&%B96Q=*2DI('L*("`@
M("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@4V%V
M92!K97D@86YD(&QA8F5L+B`J+PH@("`@("`@("1?=7-E9%MS=')T;VQO=V5R
M*"1K97DI72`]('1R=64["B`@("`@("`@)%]L86)E;'-;)&QA8F5L72`]('1R
M=64["@H@("`@("`@(')E='5R;B`D:V5Y.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4W1R:7!S(&%N(&%C8V5S<R!K97D@9G)O;2!A(&QA8F5L+@H@("`@("H@
M1F]R(&UU;'1I8GET92!C:&%R<V5T('-T<FEN9W,@=&AE(&%C8V5S<R!K97D@
M9V5T<R!R96UO=F5D(&-O;7!L971E;'DL"B`@("`@*B!O=&AE<G=I<V4@;VYL
M>2!T:&4@=6YD97)S8V]R92!G971S(')E;6]V960N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!L86)E;"!C;VYT86EN:6YG(&%N
M(&%C8V5S<R!K97DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!L86)E;"!W:71H('1H92!A8V-E<W,@:V5Y(&)E:6YG('-T<FEP<&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S=')I<$%C8V5S<TME>2@D;&%B96PI"B`@
M("!["B`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I
M9R]N;',N<&AP)SL*("`@("`@("`D;75L=&EB>71E(#T@:7-S970H)$=,3T)!
M3%-;)VYL<R==6R=M=6QT:6)Y=&4G75M.3%,Z.F=E=$-H87)S970H=')U92E=
M*3L*"B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+U\H6T$M6F$M>ETI
M+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;75L=&EB>71E("8F
M('!R96=?;6%T8V@H)R];7'@X,"U<>&9F72\G+"`D;&%B96PI(#\@)R<@.B`G
M7#$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA8F5L*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($AI9VAL:6=H=',@86X@86-C97-S(&ME>2!I
M;B!A(&QA8F5L+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L
M("`@("`@5&AE(&QA8F5L('1O('1O(&AI9VAL:6=H="!T:&4@86-C97-S(&ME
M>2!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5S<TME>2`@5&AE(&%C
M8V5S<R!K97D@=&\@:&EG:&QI9VAT+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@2%1-3"!V97)S:6]N(&]F('1H92!L86)E;"!W:71H('1H
M92!A8V-E<W,@:V5Y"B`@("`@*B`@("`@("`@("`@("`@("`@:&EG:&QI9VAT
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AI9VAL:6=H=$%C8V5S<TME>2@D
M;&%B96PL("1A8V-E<W-+97DI"B`@("!["B`@("`@("`@)'-T<FEP<&5D7VQA
M8F5L(#T@2&]R9&4Z.G-T<FEP06-C97-S:V5Y*"1L86)E;"D["@H@("`@("`@
M(&EF("AE;7!T>2@D86-C97-S2V5Y*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'-T<FEP<&5D7VQA8F5L.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1'3$]"04Q36R=N;',G75LG;75L=&EB>71E)UU;3DQ3.CIG971#:&%R<V5T
M*'1R=64I72DI('L*("`@("`@("`@("`@<F5T=7)N("1S=')I<'!E9%]L86)E
M;"`N("<H)R`N("<\<W!A;B!C;&%S<STB86-C97-S2V5Y(CXG("X*("`@("`@
M("`@("`@("`@('-T<G1O=7!P97(H)&%C8V5S<TME>2D@+B`G/"]S<&%N/B<@
M+B`G*2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('-T
M<E]R97!L86-E*"=?)R`N("1A8V-E<W-+97DL("<\<W!A;B!C;&%S<STB86-C
M97-S2V5Y(CXG("X@)&%C8V5S<TME>2`N("<\+W-P86X^)RP@)&QA8F5L*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!A
M<'!R;W!R:6%T92`B86-C97-S:V5Y(B!A;F0@(G1I=&QE(B!A='1R:6)U=&5S
M(&9O<B!A;B!(5$U,"B`@("`@*B!T86<@86YD('1H92!G:79E;B!L86)E;"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("`@5&AE('1I
M=&QE(&]F(&%N($A434P@96QE;65N=`H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&YO8VAE8VL@($1O;B=T(&-H96-K(&EF('1H92!A8V-E<W,@:V5Y(&%L<F5A
M9'D@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!U
M<V5D/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&ET;&4L
M(&%N9"!I9B!A<'!R;W!R:6%T92P@=&AE(&%C8V5S<VME>2!A='1R:6)U=&5S
M"B`@("`@*B`@("`@("`@("`@("`@("`@9F]R('1H92!E;&5M96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971!8V-E<W-+97E!;F14:71L92@D;&%B96PL
M("1N;V-H96-K(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&%K(#T@2&]R9&4Z
M.F=E=$%C8V5S<TME>2@D;&%B96PL("1N;V-H96-K*3L*("`@("`@("`D871T
M<FEB=71E<R`]("=T:71L93TB)R`N($AO<F1E.CIS=')I<$%C8V5S<TME>2@D
M;&%B96PI.PH@("`@("`@(&EF("@A96UP='DH)&%K*2D@>PH@("`@("`@("`@
M("`D871T<FEB=71E<R`N/2!S<')I;G1F*%\H(B`H06-C97-S:V5Y("5S*2(I
M+"`D86LI.PH@("`@("`@("`@("`D871T<FEB=71E<R`N/2`G(B!A8V-E<W-K
M97D](B<@+B`D86L["B`@("`@("`@?0H@("`@("`@("1A='1R:6)U=&5S("X]
M("<B)SL*("`@("`@("!R971U<FX@)&%T=')I8G5T97,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@;&%B96P@96QE;65N="!I;F-L=61I;F<@
M86X@86-C97-S(&ME>2!F;W(@=7-A9V4@:6X@8V]N:G5C=&EO;@H@("`@("H@
M=VET:"!A(&9O<FT@9FEE;&0N(%5S97(@<')E9F5R96YC97,@<F5G87)D:6YG
M(&%C8V5S<R!K97ES(&%R92!R97-P96-T960N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9F]R("`@(%1H92!F;W)M(&9I96QD)W,@:60@871T<FEB
M=71E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!L86)E;"!T
M97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86L@("`@(%1H92!A8V-E<W,@
M:V5Y('1O('5S92X@268@;G5L;"!A(&YE=R!A8V-E<W,@:V5Y"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!G96YE<F%T960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!H=&UL(&-O9&4@9F]R('1H
M92!L86)E;"!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!L86)E;"@D
M9F]R+"`D;&%B96PL("1A:R`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L
M("1P<F5F<SL*"B`@("`@("`@:68@*&ES7VYU;&PH)&%K*2D@>PH@("`@("`@
M("`@("`D86L@/2!(;W)D93HZ9V5T06-C97-S:V5Y*"1L86)E;"P@,2D["B`@
M("`@("`@?0H@("`@("`@("1L86)E;"`]($AO<F1E.CIH:6=H;&EG:'1!8V-E
M<W-+97DH)&QA8F5L+"`D86LI.PH*("`@("`@("!R971U<FX@<W!R:6YT9B@G
M/&QA8F5L(&9O<CTB)7,B)7,^)7,\+VQA8F5L/B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<BP*("`@("`@("`@("`@("`@("`@("`@("`A96UP='DH
M)&%K*2`_("<@86-C97-S:V5Y/2(G("X@)&%K("X@)R(G(#H@)R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)&QA8F5L*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E9&ER96-T<R!T;R!T:&4@;6%I;B!(;W)D92!L;V=I;B!P86=E(&]N
M(&%U=&AE;G1I8V%T:6]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH@("`@("`@(&EF("A(
M;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@("`@("`@("`@)&-L
M:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D8VQI
M+3YF871A;"A?*")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(I*3L*("`@
M("`@("!]"@H@("`@("`@("1U<FP@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+VQO9VEN+G!H<"<["B`@("`@
M("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!A<G)A>2@G=7)L
M)R`]/B!(;W)D93HZ<V5L9E5R;"AT<G5E*2P@)VYO<VED96)A<B<@/3X@,2DL
M(&YU;&PL(&9A;'-E*3L*("`@("`@("`D=7)L(#T@075T:#HZ861D3&]G;W5T
M4&%R86UE=&5R<R@D=7)L*3L*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G
M("X@2&]R9&4Z.G5R;"@D=7)L+"!T<G5E*2D["B`@("`@("`@97AI=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%!R;W9I9&5S(&$@<W1A;F1A<F1I<V5D(&9U
M;F-T:6]N('1O(&-A;&P@82!(;W)D92!H;V]K+"!C:&5C:VEN9R!W:&5T:&5R
M"B`@("`@*B!A(&AO;VL@8V]N9FEG(&9I;&4@97AI<W1S(&%N9"!W:&5T:&5R
M('1H92!F=6YC=&EO;B!I='-E;&8@97AI<W1S+B!)9@H@("`@("H@=&AE<V4@
M='=O(&-O;F1I=&EO;G,@87)E(&YO="!S871I<V9I960@:70@=VEL;"!R971U
M<FX@=&AE('-P96-I9FEE9`H@("`@("H@=F%L=64@*&)Y(&1E9F%U;'0@82!0
M14%2(&5R<F]R*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H;V]K
M("!4:&4@9G5N8W1I;VX@=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A>2`@
M)&%R9W,@($%N(&%R<F%Y(&]F(&%N>2!A<F=U;65N=',@=&\@<&%S<R!T;R!T
M:&4@:&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@9G5N8W1I;VXN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("!)9B!S<&5C:69I960@;&]O
M:R!F;W(@:&]O:W,@:6X@=&AE(&-O;F9I9R!D:7)E8W1O<GD*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@(&]F('1H:7,@87!P+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1E<G)O<B`@5VAA="!T;R!R971U<FX@:68@)&%P<"]C;VYF:6<O
M:&]O:W,N<&AP(&]R("1H;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!D;V5S(&YO="!E>&ES="X@268@=&AI<R!I<R!T:&4@<W1R:6YG("=014%2
M7T5R<F]R)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@82!014%2(&5R
M<F]R(&]B:F5C="!I<R!R971U<FYE9"!I;G-T96%D+"!D971A:6QI;F<*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@('1H92!F86EL=7)E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@<F5S=6QT<R!O9B!T
M:&4@:&]O:R!O<B!014%2(&5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-A;&Q(;V]K*"1H;V]K+"`D87)G<R`](&%R<F%Y*"DL("1A
M<'`@/2`G:&]R9&4G+"`D97)R;W(@/2`G4$5!4E]%<G)O<B<I"B`@("!["B`@
M("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!S=&%T:6,@)&AO;VMS
M7VQO861E9#L*"B`@("`@("`@:68@*"%I<W-E="@D:&]O:W-?;&]A9&5D*2D@
M>PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)')E9VES=')Y+3YG970H
M)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R]H;V]K<RYP:'`G*2D@>PH@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1R96=I<W1R>2T^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@
M("`@("`@("`@("1H;V]K<U]L;V%D960@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&AO;VMS7VQO861E9"`](&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D:&]O:W-?
M;&]A9&5D("8F(&9U;F-T:6]N7V5X:7-T<R@D:&]O:RDI('L*("`@("`@("`@
M("`@<F5T=7)N(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1H;V]K+"`D87)G<RD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?<W1R:6YG*"1E<G)O<BD@)B8@
M<W1R8VUP*"1E<G)O<BP@)U!%05)?17)R;W(G*2`]/2`P*2!["B`@("`@("`@
M("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G2&]O:R`E
M<R!I;B!A<'!L:6-A=&EO;B`E<R!N;W0@8V%L;&5D+B<L("1H;V]K+"`D87!P
M*2D["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1E<G)O<BP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VX@9F]R('1H92!C=7)R
M96YT('5S97(N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@($$@<&5R;6ES
M<VEO;BP@8W5R<F5N=&QY(&]N;'D@)VUA>%]B;&]C:W,G+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!V86QU92!O9B!T:&4@<W!E8VEF:65D
M('!E<FUI<W-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I
M;VXH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@9VQO8F%L("1P97)M<SL*
M"B`@("`@("`@:68@*"$D<&5R;7,M/F5X:7-T<R@G:&]R9&4Z)R`N("1P97)M
M:7-S:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1A;&QO=V5D(#T@)'!E<FUS+3YG971097)M:7-S:6]N<R@G
M:&]R9&4Z)R`N("1P97)M:7-S:6]N*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)&%L;&]W960I*2!["B`@("`@("`@("`@('-W:71C:"`H)'!E<FUI<W-I;VXI
M('L*("`@("`@("`@("`@8V%S92`G;6%X7V)L;V-K<R<Z"B`@("`@("`@("`@
M("`@("`D86QL;W=E9"`](&%R<F%Y7W)E9'5C92@D86QL;W=E9"P@8W)E871E
M7V9U;F-T:6]N*"<D82P@)&(G+"`G<F5T=7)N(&UA>"@D82P@)&(I.R<I+"`P
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&%L;&]W960["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]P<F5F<RYP:'``````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3$T,S``,3`U,34T,S$P-C$`,#$W,#`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+VQI8B]P<F5F<RYP:'`L=B`Q+C$Y+C0N,3`@,C`P
M-B\P,2\P,2`R,3HR.3HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y
M.3DM,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!H86YD;&5?<VAO
M=W-U;6UA<GES96QE8W0H)'5P9&%T960I"GL*("`@(&=L;V)A;"`D<')E9G,[
M"@H@("`@)'-H;W=?<W5M;6%R:65S(#T@571I;#HZ9V5T1F]R;41A=&$H)W-H
M;W=?<W5M;6%R:65S)RD["B`@("!I9B`H(6ES7VYU;&PH)'-H;W=?<W5M;6%R
M:65S*2D@>PH@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)W-H;W=?<W5M;6%R
M:65S)RP@)'-H;W=?<W5M;6%R:65S*3L*("`@("`@("`D=7!D871E9"`]('1R
M=64["B`@("!]"@H@("`@<F5T=7)N("1U<&1A=&5D.PI]"@IF=6YC=&EO;B!H
M86YD;&5?=&AE;65S96QE8W0H)'5P9&%T960I"GL*("`@(&=L;V)A;"`D<')E
M9G,["@H@("`@)'1H96UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W1H96UE)RD[
M"B`@("!I9B`H(6ES7VYU;&PH)'1H96UE*2D@>PH@("`@("`@("1P<F5F<RT^
M<V5T5F%L=64H)W1H96UE)RP@)'1H96UE*3L*("`@("`@("`D=7!D871E9"`]
M('1R=64["B`@("!]"@H@("`@<F5T=7)N("1U<&1A=&5D.PI]"@IF=6YC=&EO
M;B!H86YD;&5?8V%T96=O<GEM86YA9V5M96YT*"1U<&1A=&5D*0I["B`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`G
M.PH@("`@)&--86YA9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H
M*3L*"B`@("`O*B!!;'=A>7,@<V%V92!C;VQO<G,@;V8@86QL(&-A=&5G;W)I
M97,N("HO"B`@("`D8V]L;W)S(#T@87)R87DH*3L*("`@("1C871E9V]R:65S
M(#T@)&--86YA9V5R+3YG970H*3L*("`@(&9O<F5A8V@@*"1C871E9V]R:65S
M(&%S("1C871E9V]R>2D@>PH@("`@("`@(&EF("@D8V]L;W(@/2!5=&EL.CIG
M971&;W)M1&%T82@G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H)&-A=&5G;W)Y
M*2DI('L*("`@("`@("`@("`@)&-O;&]R<ULD8V%T96=O<GE=(#T@)&-O;&]R
M.PH@("`@("`@('T*("`@('T*("`@(&EF("@D8V]L;W(@/2!5=&EL.CIG971&
M;W)M1&%T82@G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H)U]D969A=6QT7R<I
M*2D@>PH@("`@("`@("1C;VQO<G-;)U]D969A=6QT7R==(#T@)&-O;&]R.PH@
M("`@?0H@("`@:68@*"1C;VQO<B`](%5T:6PZ.F=E=$9O<FU$871A*"=C;VQO
M<E\G("X@8F%S938T7V5N8V]D92@G7W5N9FEL961?)RDI*2!["B`@("`@("`@
M)&-O;&]R<ULG7W5N9FEL961?)UT@/2`D8V]L;W(["B`@("!]"B`@("`D8TUA
M;F%G97(M/G-E=$-O;&]R<R@D8V]L;W)S*3L*"B`@("`D86-T:6]N(#T@571I
M;#HZ9V5T1F]R;41A=&$H)V-!8W1I;VXG*3L*("`@("1C871E9V]R>2`](%5T
M:6PZ.F=E=$9O<FU$871A*"=C871E9V]R>2<I.PH*("`@('-W:71C:"`H)&%C
M=&EO;BD@>PH@("`@8V%S92`G861D)SH*("`@("`@("`D8TUA;F%G97(M/F%D
M9"@D8V%T96=O<GDI.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)W)E;6]V
M92<Z"B`@("`@("`@)&--86YA9V5R+3YR96UO=F4H)&-A=&5G;W)Y*3L*("`@
M("`@("!B<F5A:SL*"B`@("!D969A=6QT.@H@("`@("`@("\J(%-A=F4@8G5T
M=&]N+B`J+PH@("`@("`@("1U<&1A=&5D(#T@=')U93L*("`@('T*"B`@("!R
M971U<FX@)'5P9&%T960["GT*"B\J*@H@*B!$;R!A;GET:&EN9R!T:&%T('=E
M(&YE960@=&\@9&\@87,@82!R97-U;'0@;V8@8V5R=&%I;B!P<F5F97)E;F-E
M<PH@*B!C:&%N9VEN9RX*("HO"F9U;F-T:6]N('!R969S7V-A;&QB86-K*"D*
M>PH@("`@9VQO8F%L("1P<F5F<RP@)')E9VES=')Y+"`D;F]T:69I8V%T:6]N
M+"`D;FQS.PH*("`@(&EF("@D<')E9G,M/FES1&ER='DH)VQA;F=U86=E)RD@
M?'P*("`@("`@("`D<')E9G,M/FES1&ER='DH)W-H;W=?<VED96)A<B<I*2![
M"B`@("`@("`@:68@*"1P<F5F<RT^:7-$:7)T>2@G;&%N9W5A9V4G*2D@>PH@
M("`@("`@("`@("!.3%,Z.G-E=$QA;F<H)'!R969S+3YG971686QU92@G;&%N
M9W5A9V4G*2D["B`@("`@("`@("`@($Y,4SHZ<V5T5&5X=&1O;6%I;B@D<F5G
M:7-T<GDM/F=E=$%P<"@I+"`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G*2`N
M("<O;&]C86QE)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("!3
M=')I;F<Z.G-E=$1E9F%U;'1#:&%R<V5T*$Y,4SHZ9V5T0VAA<G-E="@I*3L*
M("`@("`@("!]"@H@("`@("`@("1U<FP@/2`D<F5G:7-T<GDM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I.PH@("`@("`@(&EF("AS=6)S='(H)'5R;"P@+3$I
M("$]("<O)RD@>PH@("`@("`@("`@("`D=7)L("X]("<O)SL*("`@("`@("!]
M"B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L("X@)VEN
M9&5X+G!H<"<L("=U<FPG+"!(;W)D93HZ<V5L9E5R;"AT<G5E*2D["B`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E;G0N9G)A
M;65S*2!W:6YD;W<N<&%R96YT+F9R86UE<RYL;V-A=&EO;B`](%PG)R`N(&%D
M9'-L87-H97,H2&]R9&4Z.G5R;"@D=7)L+"!T<G5E*2D@+B`G7"<[)RP@)VIA
M=F%S8W)I<'0G*3L*("`@('T*"B`@("!I9B`H)'!R969S+3YI<T1I<G1Y*"=S
M:61E8F%R7W=I9'1H)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*"=I9B`H=VEN9&]W+G!A<F5N="`F)B!W:6YD;W<N<&%R96YT+F1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*%PG:&9<)RD@)B8@=VEN9&]W+G!A<F5N="YH;W)D
M95]M96YU("8F('=I;F1O=RYP87)E;G0N:&]R9&5?;65N=2YE>'!A;F1E9%-I
M9&5B87(N<VAO=VXH*2D@=VEN9&]W+G!A<F5N="YD;V-U;65N="YG971%;&5M
M96YT0GE)9"A<)VAF7"<I+F-O;',@/2!W:6YD;W<N<&%R96YT+FAO<F1E7VUE
M;G4N<G1L(#\@7"<J+"<@+B`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R7W=I
M9'1H)RD@+B`G7"<@.B!<)R<@+B`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R
M7W=I9'1H)RD@+B`G+"I<)SLG+"`G:F%V87-C<FEP="<I.PH@("`@?0H*("`@
M(&EF("@D<')E9G,M/FES1&ER='DH)W1H96UE)RD@?'P*("`@("`@("`D<')E
M9G,M/FES1&ER='DH)VUE;G5?=FEE=R<I('Q\"B`@("`@("`@)'!R969S+3YI
M<T1I<G1Y*"=M96YU7W)E9G)E<VA?=&EM92<I*2!["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E;G0N9G)A;65S+FAO<F1E
M7VUE;G4I('=I;F1O=RYP87)E;G0N9G)A;65S+FAO<F1E7VUE;G4N;&]C871I
M;VXN<F5L;V%D*"D[)RP@)VIA=F%S8W)I<'0G*3L*("`@('T*?0H*+RH@07-S
M:6=N('9A<FEA8FQE<R!F;W(@<V5L96-T(&QI<W1S+B`J+PII9B`H(21P<F5F
M<RT^:7-,;V-K960H)W1I;65Z;VYE)RDI('L*("`@("1T:6UE>F]N95]O<'1I
M;VYS(#T@)'1Z.PH@("`@87)R87E?=6YS:&EF="@D=&EM97IO;F5?;W!T:6]N
M<RP@7R@B1&5F875L="(I*3L*?0II9B`H(21P<F5F<RT^:7-,;V-K960H)VEN
M:71I86Q?87!P;&EC871I;VXG*2D@>PH@("`@9VQO8F%L("1P97)M<SL*"B`@
M("`D:6YI=&EA;%]A<'!L:6-A=&EO;E]O<'1I;VYS(#T@87)R87DH*3L*("`@
M("1A<'!S(#T@)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G86-T:79E)RDI
M.PH@("`@9F]R96%C:"`H)&%P<',@87,@)&$I('L*("`@("`@("!I9B`H9FEL
M95]E>&ES=',H)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&$I*2`F)@H@
M("`@("`@("`@("`H*"1P97)M<RT^97AI<W1S*"1A*2`F)B`H)'!E<FUS+3YH
M87-097)M:7-S:6]N*"1A+"!!=71H.CIG971!=71H*"DL(%!%4DU37U)%040I
M('Q\($%U=&@Z.FES061M:6XH*2DI('Q\"B`@("`@("`@("`@("`A)'!E<FUS
M+3YE>&ES=',H)&$I*2D@>PH@("`@("`@("`@("`D:6YI=&EA;%]A<'!L:6-A
M=&EO;E]O<'1I;VYS6R1A72`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&$I
M.PH@("`@("`@('T*("`@('T*("`@(&%S;W)T*"1I;FET:6%L7V%P<&QI8V%T
M:6]N7V]P=&EO;G,I.PI]"FEF("@A)'!R969S+3YI<TQO8VME9"@G=&AE;64G
M*2D@>PH@("`@)'1H96UE7V]P=&EO;G,@/2!A<G)A>2@I.PH@("`@)'1H96UE
M7V)A<V4@/2`D<F5G:7-T<GDM/F=E="@G=&AE;65S9G,G+"`G:&]R9&4G*3L*
M("`@("1D:"`]($!O<&5N9&ER*"1T:&5M95]B87-E*3L*("`@(&EF("@A)&1H
M*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@B5&AE;64@9&ER96-T
M;W)Y(&-A;B=T(&)E(&]P96YE9"(L("=H;W)D92YE<G)O<B<I.PH@("`@?2!E
M;'-E('L*("`@("`@("!W:&EL92`H*"1D:7(@/2!R96%D9&ER*"1D:"DI("$]
M/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H)&1I<B`]/2`G+B<@?'P@)&1I
M<B`]/2`G+BXG('Q\("$@:7-?9&ER*"1T:&5M95]B87-E+B<O)RXD9&ER*2D@
M>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1T:&5M95]N86UE(#T@;G5L;#L*("`@("`@("`@("`@0&EN
M8VQU9&4@)'1H96UE7V)A<V4@+B`G+R<@+B`D9&ER("X@)R]I;F9O+G!H<"<[
M"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H96UE7VYA;64I*2!["B`@("`@
M("`@("`@("`@("`D=&AE;65?;W!T:6]N<ULD9&ER72`]("1T:&5M95]N86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&%S;W)T*"1T
M:&5M95]O<'1I;VYS*3L*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O4WEN8TU,+G!H<```````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#0Q-C<R`#$P-3$U-#,Q,#8Q`#`Q-S`T,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N9"YP:'`G.PII;F-L=61E
M7V]N8V4@)U-Y;F--3"]#;VUM86YD+U-T871U<RYP:'`G.PII;F-L=61E7V]N
M8V4@)U-Y;F--3"]#;VUM86YD+T%L97)T+G!H<"<["FEN8VQU9&5?;VYC92`G
M4WEN8TU,+T-O;6UA;F0O4WEN8RYP:'`G.PII;F-L=61E7V]N8V4@)U-Y;F--
M3"]#;VUM86YD+T9I;F%L+G!H<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+U-Y
M;F,N<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO0F%C:V5N9"YP:'`G.PH*
M+RHJ"B`J(%1H92!3>6YC34Q?4WEN8TAD<B!A;F0@4WEN8TU,7U-Y;F-";V1Y
M(&-L87-S97,@<')O=FED97,*("H@82!3>6YC2&1R(&%N9"!3>6YC0F]D>2!I
M;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX*("H@
M,2XQ(#4N,BXR(&%N9"`U+C(N,RX@($UO<W0@;V8@=&AE('=O<FL@:7,@<&%S
M<V5D(&]N('1O"B`J(%-Y;F--3%]#;VUM86YD7T%L97)T(&%N9"!3>6YC34Q?
M0V]M;6%N9%]3>6YC+@H@*@H@*B!4:&5R92!A<F4@='=O(&=L;V)A;"!O8FIE
M8W1S('1H870@87)E('5S960@8GD@4WEN8TU,.@H@*B`Q*2`D7U-%4U-)3TY;
M)U-Y;F--3"YS=&%T92==.@H@*B`@("!S97-S:6]N(&]B:F5C="!U<V5D('1O
M(&UA:6YT86EN('1H92!S=&%T92!B971W965N('1H92!I;F1I=FED=6%L"B`J
M("`@(%-Y;F--3"!M97-S86=E<RX*("H*("H@,BD@)$=,3T)!3%-;)V)A8VME
M;F0G70H@*B`@("!"86-K96YD('1O(&AA;F1L92!T:&4@8V]M;75N:6-A=&EO
M;B!W:71H('1H92!D871A<W1O<F4N($-U<G)E;G1L>2!T:&4*("H@("`@:&]R
M9&4@8F%C:V5N9"!I<R!T:&4@;VYL>2!B86-K96YD('!R;W9I9&5D+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+G!H<"QV(#$N,C$N
M,3`N,3`@,C`P-B\P,2\P,2`R,3HR.#HS-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI
M9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YT:&]N>2!-
M:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0&%U=&AO<B`@2V%R<W1E
M;B!&;W5R;6]N="`\9F]U<FUO;G1`9VUX+F1E/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]N
M=&5N=$AA;F1L97(@>PH*("`@("\J*@H@("`@("H@3W5T<'5T($-O;G1E;G1(
M86YD;&5R('5S960@=&\@;W5T<'5T(%A-3"!E=F5N=',N"B`@("`@*@H@("`@
M("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1?;W5T<'5T.PH*("`@
M("\J*@H@("`@("H@4W1A8VL@9F]R(&AO;&1I;F<@=&AE('AM;"!E;&5M96YT
M<R!D=7)I;F<@8W)E871I;VX@;V8@=&AE(&]B:F5C="!F<F]M"B`@("`@*B!T
M:&4@>&UL(&5V96YT(&9L;W<N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]3=&%C:R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C:&%R<SL*"B`@
M("!F=6YC=&EO;B!S971/=71P=70H)B1O=71P=70I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]O=71P=70@/2`F)&]U='!U=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*
M("`@("`@("`D=&AI<RT^7U-T86-K6UT@/2`D96QE;65N=#L*("`@('T*"B`@
M("!F=6YC=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H87)S*2D@>PH@("`@("`@("`@
M("!U;G-E="@D=&AI<RT^7V-H87)S*3L*("`@("`@("!]"@H@("`@("`@(&%R
M<F%Y7W!O<"@D=&AI<RT^7U-T86-K*3L*("`@('T*"B`@("!F=6YC=&EO;B!C
M:&%R86-T97)S*"1S='(I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?8VAA<G,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8VAA<G,@/2`D=&AI
M<RT^7V-H87)S("X@)'-T<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-H87)S(#T@)'-T<CL*("`@("`@("!]"B`@("!]"@I]"@H*
M+RHJ"B`J($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O
M8V]L+"!V97)S:6]N(#$N,2`U+C(N,@H@*@H@*B!`<&%C:V%G92!3>6YC34P*
M("HO"F-L87-S(%-Y;F--3%]3>6YC34Q(9'(@97AT96YD<R!3>6YC34Q?0V]N
M=&5N=$AA;F1L97(@>PH*("`@("\J*@H@("`@("H@1&5F:6YE9"!I;B!3>6YC
M34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N,2XY
M+B!5<V5R(&YA;64N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?;&]C3F%M93L*"B`@("`O*BH*("`@("`J($1E9FEN960@
M:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N
M,2`U+C$N,3@*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]S97-S:6]N240["@H@("`@+RHJ"B`@("`@*B!$969I;F5D(&EN
M(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO;B`Q+C$N
M("!-=7-T(&)E(#$N,"`H,"D*("`@("`J(&]R(#$N,2`H,2DN"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=F5R<VEO;CL*
M"B`@("`O*BH*("`@("`J($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T
M:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N,2`U+C$N,3(*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]M<V=)1#L*"B`@("`O
M*BH*("`@("`J($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R
M;W1O8V]L+"!V97)S:6]N(#$N,2`U+C$N,3`*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T87)G97154DD["@H@("`@+RHJ
M"B`@("`@*B!$969I;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T
M;V-O;"P@=F5R<VEO;B`Q+C$@-2XQ+C$P+"`U+C$N,C`*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S;W5R8V554DD["@H@
M("`@=F%R("1?8W)E9$1A=&$["@H@("`@=F%R("1?8W)E9$9O<FUA=#L*"B`@
M("!V87(@)%]C<F5D5'EP93L*"B`@("!V87(@)%]M87A-<V=3:7IE.PH*("`@
M(&9U;F-T:6]N(&=E=%-T871E1G)O;5-E<W-I;VXH)'-O=7)C955222P@)&QO
M8TYA;64L("1S97-S:6]N240I"B`@("!["B`@("`@("`@)$=,3T)!3%-;)V)A
M8VME;F0G72`]("9N97<@4WEN8TU,7T)A8VME;F1?2&]R9&4H*3L*"B`@("`@
M("`@+R\@4F5L;V%D('1H92!(;W)D92!397-S:6]N2&%N9&QE<B!I9B!N96-E
M<W-A<GDN"B`@("`@("`@2&]R9&4Z.G-E='5P4V5S<VEO;DAA;F1L97(H*3L*
M"B`@("`@("`@+R\@4WEN8TU,('!R;W1O8V]L(&1O97,@;F]T(')E<75I<F4@
M=&AE(&-L:65N="!T;R!S96YD('1H90H@("`@("`@("\O('5S97)N86UE(&]N
M(&%N>2!M97-S86=E<R!B=70@=&AE(&9I<G-T+B`@4V\@=6YF;W)T=6YA=&5L
M>0H@("`@("`@("\O('=E(&-A;B=T('5S92!I="!T;R!M86ME(&$@=6YI<75E
M('-E<W-I;VX@:60N"B`@("`@("`@<V5S<VEO;E]I9"@G<WEN8VUL)R`N('!R
M96=?<F5P;&%C92@G+UM>82UZ02U:,"TY72\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L("1S;W5R8V554DD@+B`D
M<V5S<VEO;DE$*2D["B`@("`@("`@<V5S<VEO;E]S=&%R="@I.PH*("`@("`@
M("`O+R!)="!W;W5L9"!S965M(&UU;'1I<WEN8R!D;V5S(&YO="!S96YD('1H
M92!U<V5R(&YA;64@;VYC92!I=`H@("`@("`@("\O(&AA<R!B965N(&%U=&AO
M<FEZ960N($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@<V5S<VEO;B!I9"X*
M("`@("`@("!S97-S:6]N7VED*"=S>6YC;6PG("X@<')E9U]R97!L86-E*"<O
M6UYA+7I!+5HP+3E=+R<L("<G+"`D<V]U<F-E55))("X@)'-E<W-I;VY)1"DI
M.PH@("`@("`@($!S97-S:6]N7W-T87)T*"D["@H@("`@("`@(&EF("@A:7-S
M970H)%]315-324].6R=3>6YC34PN<W1A=&4G72DI('L*("`@("`@("`@("`@
M+R\@0W)E871E(&$@;F5W('-T871E(&EF(&]N92!D;V5S(&YO="!A;')E861Y
M(&5X:7-T+@H@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-
M97-S86=E*"=.97<@<V5S<VEO;B!C<F5A=&5D.B`G"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("X@<V5S<VEO;E]I9"@I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@("`@("1?4T534TE/3ELG4WEN8TU,+G-T871E
M)UT@/2`F;F5W(%-Y;F--3%]3=&%T92@D<V]U<F-E55))+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&QO8TYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5S<VEO;DE$*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL
M;V=-97-S86=E*"=%>&ES=&EN9R!S97-S:6]N(&-O;G1I;G5E9#H@)PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N('-E<W-I;VY?:60H*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)%]315-324].6R=3>6YC34PN<W1A=&4G73L*("`@('T*"B`@("!F=6YC=&EO
M;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*
M("`@("`@("!P87)E;G0Z.G-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@
M)&%T=')S*3L*("`@('T*"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT*"1U<FDL
M("1E;&5M96YT*0H@("`@>PH@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M
M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("\O(#PO
M4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@+R\@1FEN9"!T:&4@<W1A
M=&4N"B`@("`@("`@("`@("1S=&%T92`]("1T:&ES+3YG9713=&%T949R;VU3
M97-S:6]N*"1T:&ES+3Y?<V]U<F-E55))+"`D=&AI<RT^7VQO8TYA;64L("1T
M:&ES+3Y?<V5S<VEO;DE$*3L*"B`@("`@("`@("`@("1S=&%T92T^<V5T5F5R
M<VEO;B@D=&AI<RT^7W9E<G-I;VXI.PH@("`@("`@("`@("`D<W1A=&4M/G-E
M=$US9TE$*"1T:&ES+3Y?;7-G240I.PH@("`@("`@("`@("`D<W1A=&4M/G-E
M=%1A<F=E=%5222@D=&AI<RT^7W1A<F=E=%5222D["B`@("`@("`@("`@("1S
M=&%T92T^<V5T4&%S<W=O<F0H)'1H:7,M/E]C<F5D1&%T82D["B`@("`@("`@
M("`@("1S=&%T92T^<V5T5T)834PH:7-?82@D=&AI<RT^7V]U='!U="P@)UA-
M3%]70EA-3%]%;F-O9&5R)RDI.PH*("`@("`@("`@("`@+R\@4W1O<F4@;&]G
M:6X@;F%M92!I;B!S=&%T92!I9B!N;W0@86QR96%D>2!S970*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1S=&%T92T^7VQO8TYA;64I("8F("%E;7!T>2@D=&AI
M<RT^7VQO8TYA;64I*2!["B`@("`@("`@("`@("`@("`D<W1A=&4M/G-E=$QO
M8TYA;64H)'1H:7,M/E]L;V-.86UE*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;6%X37-G4VEZ92DI('L*("`@("`@
M("`@("`@("`@("1S=&%T92T^<V5T36%X37-G4VEZ92@D=&AI<RT^7VUA>$US
M9U-I>F4I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<W1R(#T@)V%U
M=&AO<FEZ960])R`N("1S=&%T92T^:7-!=71H;W)I>F5D*"D@+@H@("`@("`@
M("`@("`@("`@)R!V97)S:6]N/2<@+B`D<W1A=&4M/F=E=%9E<G-I;VXH*2`N
M"B`@("`@("`@("`@("`@("`G(&US9VED/2<@+B`D<W1A=&4M/F=E=$US9TE$
M*"D@+@H@("`@("`@("`@("`@("`@)R!S;W5R8V4])R`N("1S=&%T92T^9V5T
M4V]U<F-E55))*"D@+@H@("`@("`@("`@("`@("`@)R!T87)G970])R`N("1S
M=&%T92T^9V5T5&%R9V5T55))*"D@+@H@("`@("`@("`@("`@("`@)R!U<V5R
M/2<@+B`D<W1A=&4M/F=E=$QO8TYA;64H*2`N"B`@("`@("`@("`@("`@("`G
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I("X*("`@("`@("`@("`@
M("`@("<@=V)X;6P])R`N("1S=&%T92T^:7-70EA-3"@I"@H@("`@("`@("`@
M("`@("`@.PH*("`@("`@("`@("`@)%]315-324].6R=3>6YC34PN<W1A=&4G
M72`]("1S=&%T93L*"B`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM
M/FQO9TUE<W-A9V4H)'-T<BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["@H@("`@("`@("`@("`O+R!';W0@=&AE('-T871E.R!N;W<@
M=W)I=&4@;W5R(%-Y;F-(9'(@:&5A9&5R+@H@("`@("`@("`@("`D=&AI<RT^
M;W5T<'5T4WEN8TAD<B@D=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N
M="`]/2`G5F5R4')O=&\G*2!["B`@("`@("`@("`@("`@("`O+R`\+U9E<E!R
M;W1O/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@(&EF("AT
M<FEM*"1T:&ES+3Y?8VAA<G,I(#T]("=3>6YC34PO,2XQ)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=F5R<VEO;B`](#$["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F5R
M<VEO;B`](#`["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M96EF("@D96QE;65N="`]/2`G4V5S<VEO;DE$)RD@>PH@("`@("`@("`@("`@
M("`@+R\@/"]397-S:6]N240^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S97-S:6]N240@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)TUS9TE$
M)RD@>PH@("`@("`@("`@("`@("`@+R\@/"]-<V=)1#X\+U-Y;F-(9'(^/"]3
M>6YC34P^"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUS9TE$(#T@:6YT=F%L
M*'1R:6TH)'1H:7,M/E]C:&%R<RDI.PH@("`@("`@("`@("!](&5L<V5I9B`H
M)&5L96UE;G0@/3T@)T-R960G*2!["B`@("`@("`@("`@("`@("`O+R`\+T-R
M960^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C<F5D1&%T82`](&)A<V4V-%]D96-O9&4H)'1H:7,M/E]C<F5D1&%T82D[
M"@H@("`@("`@("`@("`@("`@)'1M<"`](&5X<&QO9&4H)SHG+"`D=&AI<RT^
M7V-R961$871A*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]C3F%M92`]
M("1T;7!;,%T["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-R961$871A(#T@
M)'1M<%LQ73L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3
M>6YC34PZ(')E8V5I=F5D(&-R961E;G1I86QS(&9O<B!U<V5R/2<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D
M=&AI<RT^7VQO8TYA;64@+"`G8W)E9#TG"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/E]C<F5D1&%T
M82P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(#,Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G3&]C55)))RD@>PH@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U-O=7)C
M92<I('L*("`@("`@("`@("`@("`@("`@("`O+R`\+TQO8U5223X\+U-O=7)C
M93X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S;W5R8V554DD@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U1A<F=E
M="<I('L*("`@("`@("`@("`@("`@("`@("`O+R`\+TQO8U5223X\+U1A<F=E
M=#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]T87)G97154DD@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@
M)TQO8TYA;64G*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C
M:ULQ72`]/2`G4V]U<F-E)RD@>PH@("`@("`@("`@("`@("`@("`@("\O(#PO
M3&]C3F%M93X\+U-O=7)C93X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]L;V-.86UE(#T@=')I;2@D=&AI<RT^7V-H
M87)S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@
M*"1E;&5M96YT(#T]("=$871A)RD@>PH@("`@("`@("`@("`@("`@("`@("\O
M(#PO1&%T83X\+T-R960^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)T-R960G*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C<F5D1&%T82`]('1R:6TH)'1H:7,M
M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M96EF("@D96QE;65N="`]/2`G36%X37-G4VEZ92<I('L*("`@("`@("`@("`@
M("`@("\O(#PO36%X37-G4VEZ93X\+TUE=&$^/"]3>6YC2&1R/CPO4WEN8TU,
M/@H@("`@("`@("`@("`@("`@)'1H:7,M/E]M87A-<V=3:7IE(#T@:6YT=F%L
M*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7U-T86-K6S%=(#T]("=#<F5D)RD@>PH@("`@("`@("`@("`@("`@:68@*"1E
M;&5M96YT(#T]("=&;W)M870G*2!["B`@("`@("`@("`@("`@("`@("`@+R\@
M/"]&;W)M870^/"]-971A/CPO0W)E9#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C<F5D1F]R;6%T(#T@=')I;2@D
M=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D96QE
M;65N="`]/2`G5'EP92<I('L*("`@("`@("`@("`@("`@("`@("`O+R`\+U1Y
M<&4^/"]-971A/CPO0W)E9#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C<F5D5'EP92`]('1R:6TH)'1H:7,M/E]C
M:&%R<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L
M96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&]U
M='!U=%-Y;F-(9'(H)B1O=71P=70I"B`@("!["B`@("`@("`@)&%T=')S(#T@
M87)R87DH*3L*"B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,
M+G-T871E)UT["@H@("`@("`@("1U<FD@/2`D<W1A=&4M/F=E=%5222@I.PH@
M("`@("`@("1U<FE-971A(#T@)'-T871E+3YG97154DE-971A*"D["@H@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G4WEN8TAD<B<L("1A
M='1R<RD["@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G
M5F5R1%1$)RP@)&%T=')S*3L*("`@("`@("`D8VAA<G,@/2`H)'1H:7,M/E]V
M97)S:6]N(#T](#$I(#\@)S$N,2<@.B`G,2XP)SL*("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D=7)I+"`G5F5R1%1$)RD["@H@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D=7)I+"`G5F5R4')O=&\G+"`D871T<G,I.PH@("`@("`@("1C
M:&%R<R`]("@D=&AI<RT^7W9E<G-I;VX@/3T@,2D@/R`G4WEN8TU,+S$N,2<@
M.B`G4WEN8TU,+S$N,"<["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D
M8VAA<G,I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)U9E
M<E!R;W1O)RD["@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I
M+"`G4V5S<VEO;DE$)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R
M86-T97)S*"1T:&ES+3Y?<V5S<VEO;DE$*3L*("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1U<FDL("=397-S:6]N240G*3L*"B`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1U<FDL("=-<V=)1"<L("1A='1R<RD["B`@("`@
M("`@)&]U='!U="T^8VAA<F%C=&5R<R@D=&AI<RT^7VUS9TE$*3L*("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=-<V=)1"<I.PH*("`@("`@
M("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)U1A<F=E="<L("1A='1R
M<RD["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=,;V-5
M4DDG+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'1H
M:7,M/E]S;W5R8V554DDI.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'5R:2P@)TQO8U5222<I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D=7)I+"`G3&]C3F%M92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^
M8VAA<F%C=&5R<R@D<W1A=&4M/F=E=$QO8TYA;64H*2D["B`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D=7)I+"`G3&]C3F%M92<I.PH@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)U1A<F=E="<I.PH*("`@("`@("`D
M;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)U-O=7)C92<L("1A='1R<RD[
M"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=,;V-54DDG
M+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'1H:7,M
M/E]T87)G97154DDI.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R
M:2P@)TQO8U5222<I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R
M:2P@)U-O=7)C92<I.PH*("`@("`@("`O*@H@("`@("`@($1O(&YO="!S96YD
M(%)E<W!54DD@16QE;65N="X@270G<R!O<'1I;VYA;"!A;F0@;6%Y(&)E(&UI
M<VQE861I;F<Z"B`@("`@("`@)'1H:7,M/E]T87)G97154DD@:7,@9&%T82!F
M<F]M('1H92!C;&EE;G0@86YD(&YO="!G=6%R86YT965D('1O(&)E"B`@("`@
M("`@=&AE(&-O<G)E8W0@55),(&9O<B!A8V-E<W,N($QE="!T:&4@8VQI96YT
M(&IU<W0@<W1A>2!W:71H('1H92!S86UE"B`@("`@("`@55),(&ET(&AA<R!U
M<V5D(&9O<B!T:&4@<')E=FEO=7,@<F5Q=65S="AS*2X*("`@("`@("`J+PH@
M("`@("`@("\O)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=297-P55))
M)RP@)&%T=')S*3L*("`@("`@("`O+R1O=71P=70M/F-H87)A8W1E<G,H)'1H
M:7,M/E]T87)G97154DDI.PH@("`@("`@("\O)&]U='!U="T^96YD16QE;65N
M="@D=7)I+"`G4F5S<%5222<I.PH*("`@("`@("`O*@H@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D=7)I+"`G365T82<L("1A='1R<RD["@H@("`@
M("`@("\O($1U;6UY($UA>"!-<W%3:7IE+"!T:&ES(&ES(&IU<W0@<'5T(&EN
M('1O(&UA:V4@=&AE('!A8VME=`H@("`@("`@("\O('=O<FLL(&ET(&ES(&YO
M="!A(')E86P@=F%L=64N"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1U<FE-971A+"`G36%X37-G4VEZ92<L("1A='1R<RD["B`@("`@("`@)&-H
M87)S(#T@)S4P,#`P)SL*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C
M:&%R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D=7)I365T82P@
M)TUA>$US9U-I>F4G*3L*"B`@("`@("`@+R\@1'5M;7D@36%X3V)J4VEZ92P@
M=&AI<R!I<R!J=7-T('!U="!I;B!T;R!M86ME('1H92!P86-K970*("`@("`@
M("`O+R!W;W)K+"!I="!I<R!N;W0@82!R96%L('9A;'5E+@H@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D=7)I365T82P@)TUA>$]B:E-I>F4G+"`D
M871T<G,I.PH@("`@("`@("1C:&%R<R`]("<T,#`P,#`P)SL*("`@("`@("`D
M;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@)&]U='!U="T^
M96YD16QE;65N="@D=7)I365T82P@)TUA>$]B:E-I>F4G*3L*"B`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G365T82<I.PH@("`@("`@("HO
M"@H@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)U-Y;F-(9'(G
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G9713;W5R8V554DDH*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W-O=7)C955223L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971,;V-.86UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]L;V-.86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-E<W-I;VY)
M1"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5S<VEO;DE$.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=%9E<G-I;VXH*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W9E<G-I;VX["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T37-G240H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUS9TE$
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1A<F=E=%5222@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=&%R9V5T55)).PH@("`@?0H*("`@(&9U
M;F-T:6]N(&]P87%U92@D;RD*("`@('L*("`@('T*"GT*"B\J*@H@*B!$969I
M;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO
M;B`Q+C$@-2XR+C,*("H*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3
M>6YC34Q?4WEN8TU,0F]D>2!E>'1E;F1S(%-Y;F--3%]#;VYT96YT2&%N9&QE
M<B!["@H@("`@=F%R("1?8W5R<F5N=$-M9$E$(#T@,3L*"B`@("!V87(@)%]C
M=7)R96YT0V]M;6%N9#L*"B`@("!V87(@)%]A8W1I;VY#;VUM86YD<R`](&9A
M;'-E.PH*("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N
M="P@)&%T=')S*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M96YT
M*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH*("`@("`@("!S=VET8V@@*&-O
M=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@
M("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*"B`@
M("`@("`@("`@("1T:&ES+3Y?86-T:6]N0V]M;6%N9',@/2!F86QS93L@+R\@
M<V\@9F%R+"!W92!H879E(&YO="!S965N(&-O;6UA;F1S('1H870@<F5Q=6ER
M92!A8W1I;VX@9G)O;2!O=7(@<VED90H*("`@("`@("`@("`@+R\@/%-Y;F--
M3#X\4WEN8T)O9'D^"B`@("`@("`@("`@("1U<FD@/2`D<W1A=&4M/F=E=%52
M22@I.PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="T^<W1A<G1%;&5M96YT
M*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH*("`@("`@("`@("`@+R\@4FEG
M:'0@;W5R('-T871U<R!A8F]U="!T:&4@:&5A9&5R+@H@("`@("`@("`@("`D
M<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H*"1S=&%T92T^
M:7-!=71H;W)I>F5D*"DI(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%)%4U!/3E-%7T%55$A%3E1)0T%424].
M7T%#0T505$5$(#H@4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4RP@)U-Y
M;F-(9'(G*3L*("`@("`@("`@("`@)'-T871U<RT^<V5T4V]U<F-E4F5F*"1S
M=&%T92T^9V5T4V]U<F-E55))*"DI.PH@("`@("`@("`@("`D<W1A='5S+3YS
M971487)G9712968H)'-T871E+3YG971487)G97154DDH*2D["B`@("`@("`@
M("`@("1S=&%T=7,M/G-E=$-M9%)E9B@P*3L*"B`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=$-M9$E$(#T@)'-T871U<RT^;W5T<'5T*"1T:&ES+3Y?8W5R
M<F5N=$-M9$E$+"`D=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("\O(#Q3>6YC34P^/%-Y
M;F-";V1Y/CQ;0V]M;6%N9%T^"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=$-O;6UA;F0@/2!3>6YC34Q?0V]M;6%N9#HZ9F%C=&]R>2@D96QE;65N="D[
M"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0M/G-T87)T16QE
M;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*3L*"B`@("`@("`@("`@(&EF
M("@D96QE;65N="`A/2`G4W1A='5S)R`F)B`D96QE;65N="`A/2`G36%P)R`F
M)B`D96QE;65N="`A/2`G1FEN86PG*2!["B`@("`@("`@("`@("`@("`O+R!7
M92=V92!G;W0@=&\@9&\@<V]M971H:6YG(2!4:&ES(&-A;B=T(&)E('1H92!L
M87-T"B`@("`@("`@("`@("`@("`O+R!P86-K970N"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%C=&EO;D-O;6UA;F1S(#T@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@+R\@/%-Y;F--3#X\4WEN8T)O9'D^/$-O;6UA;F0^/"XN+CX*("`@
M("`@("`@("`@)'1H:7,M/E]C=7)R96YT0V]M;6%N9"T^<W1A<G1%;&5M96YT
M*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I
M+"`D96QE;65N="D*("`@('L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES
M+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`O+R`\
M+U-Y;F-";V1Y/CPO4WEN8TU,/@H@("`@("`@("`@("`D<W1A=&4@/2`F)%]3
M15-324].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@("`@(&EF("@D<W1A
M=&4M/FAA<U!E;F1I;F=%;&5M96YT<R@I*2!["B`@("`@("`@("`@("`@("`O
M*B!S=&EL;"!S;VUE=&AI;F<@=&\@9&\Z(&1O;B=T(&-L;W-E('-E<W-I;VX@
M*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N0V]M;6%N9',@/2!T
M<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=$-M9$E$(#T@4WEN8TU,7T-O;6UA;F1?1FEN86PZ.F]U='!U=$9I;F%L*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R96YT0VUD240L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*"B`@("`@
M("`@("`@(&EF("@A)'1H:7,M/E]A8W1I;VY#;VUM86YD<RD@>PH@("`@("`@
M("`@("`@("`@+R\@5&AI<R!P86-K970@9&ED(&YO="!C;VYT86EN(&%N>2!R
M96%L(&%C=&EO;G,L(&IU<W0*("`@("`@("`@("`@("`@("\O('-T871U<R!A
M;F0@;6%P+B!4:&ES(&UE86YS('=E)W)E(&1O;F4N(%1H92!S97-S:6]N"B`@
M("`@("`@("`@("`@("`O+R!C86X@8F4@8VQO<V5D(&%N9"!T:&4@86YC:&]R
M<R!S879E9"!F;W(@=&AE(&YE>'0*("`@("`@("`@("`@("`@("\O('-Y;F,N
M"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S
M86=E*"=S>6YC)R`N('-E<W-I;VY?:60H*2`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@8V]M<&QE=&5D('-U
M8V-E<W-F=6QL>2$G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R!3=&]R:6YG($-L:65N="U44R`G("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-T871E+3Y?8VQI96YT06YC:&]R3F5X="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@("`@("1'3$]"04Q3
M6R=B86-K96YD)UTM/G=R:71E4WEN8U-U;6UA<GDH"B`@("`@("`@("`@("`@
M("`@("`@)'-T871E+3YG9713>6YC261E;G1I9FEE<B@I+`H@("`@("`@("`@
M("`@("`@("`@("1S=&%T92T^7V-L:65N=$%N8VAO<DYE>'0L"B`@("`@("`@
M("`@("`@("`@("`@)'-T871E+3Y?<V5R=F5R06YC:&]R3F5X="D["B`@("`@
M("`@("`@("`@("`D;&]G(#T@)'-T871E+3YG971,;V<H*3L*("`@("`@("`@
M("`@("`@("1S(#T@)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D;&]G
M(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@)',@+CT@(B`D
M:STD=B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D1TQ/
M0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S86=E*"=3=6UM87)Y.B<@+B`D<RP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*"B`@("`@("`@
M("`@("`@("`O+R!397-S:6]N(&-A;B!B92!C;&]S960@:&5R92X*("`@("`@
M("`@("`@("`@('-E<W-I;VY?=6YS970H*3L*("`@("`@("`@("`@("`@('-E
M<W-I;VY?9&5S=')O>2@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@G4WEN
M8TU,.B!R971U<FX@;65S<V%G92!C;VUP;&5T960G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`O
M+R`\+UM#;VUM86YD73X\+U-Y;F-";V1Y/CPO4WEN8TU,/@H@("`@("`@("`@
M("`D=&AI<RT^7V-U<G)E;G1#;VUM86YD+3YE;F1%;&5M96YT*"1U<FDL("1E
M;&5M96YT*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-M9$E$(#T@
M)'1H:7,M/E]C=7)R96YT0V]M;6%N9"T^;W5T<'5T*"1T:&ES+3Y?8W5R<F5N
M=$-M9$E$+"`D=&AI<RT^7V]U='!U="D["@H@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7V-U<G)E;G1#;VUM86YD*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("\O(#PO+BXN/CPO6T-O;6UA
M;F1=/CPO4WEN8T)O9'D^/"]3>6YC34P^"B`@("`@("`@("`@("1T:&ES+3Y?
M8W5R<F5N=$-O;6UA;F0M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ
M96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I
M;VX@8VAA<F%C=&5R<R@D<W1R*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V-U<G)E;G1#;VUM86YD*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-U<G)E;G1#;VUM86YD+3YC:&%R86-T97)S*"1S='(I.PH@("`@("`@('T*
M("`@('T*"GT*````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+RYH=&%C8V5S<P``````````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`Q-@`Q,#4Q-30S,3`V
M,0`P,38W-#8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1&5N>2!F<F]M(&%L;`H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]V97)S:6]N+G!H<```````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P-3(`,3`U,34T,S$P-C$`,#$W,S0V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M(&1E9FEN92@G2$]21$5?5D524TE/3B<L("<S+C$N,R<I(#\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O8V]R
M92YP:'``````````````````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S,S(V`#$P-3$U-#,Q,#8Q`#`Q-C8R,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@2&]R
M9&4@07!P;&EC871I;VX@1G)A;65W;W)K(&-O<F4@<V5R=FEC97,@9FEL92X*
M("H*("H@5&AI<R!F:6QE('-E=',@=7`@86YY(&YE8V5S<V%R>2!I;F-L=61E
M('!A=&@@=F%R:6%B;&5S(&%N9"!I;F-L=61E<PH@*B!T:&4@;6EN:6UU;2!R
M97%U:7)E9"!(;W)D92!L:6)R87)I97,N"B`J"B`J("1(;W)D93H@:&]R9&4O
M;&EB+V-O<F4N<&AP+'8@,2XR-BXV+C<@,C`P-B\P,2\P-R`Q-CHT,#HR."!C
M:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO
M*B!4=7)N(%!(4"!S='5F9B!O9F8@=&AA="!C86X@<F5A;&QY('-C<F5W('1H
M:6YG<R!U<"X@*B\*:6YI7W-E="@G;6%G:6-?<75O=&5S7W-Y8F%S92<L(#`I
M.PII;FE?<V5T*"=M86=I8U]Q=6]T97-?<G5N=&EM92<L(#`I.PH*+RH@56YS
M970@86QL('9A<FEA8FQE<R!P;W!U;&%T960@=&AR;W5G:"!R96=I<W1E<E]G
M;&]B86QS+B`J+PII9B`H:6YI7V=E="@G<F5G:7-T97)?9VQO8F%L<R<I*2![
M"B`@("!F;W)E86-H("AA<G)A>5]K97ES*"1?1T54*2!A<R`D:V5Y*2!["B`@
M("`@("`@=6YS970H)"1K97DI.PH@("`@?0H@("`@9F]R96%C:"`H87)R87E?
M:V5Y<R@D7U!/4U0I(&%S("1K97DI('L*("`@("`@("!U;G-E="@D)&ME>2D[
M"B`@("!]"B`@("!F;W)E86-H("AA<G)A>5]K97ES*"1?0T]/2TE%*2!A<R`D
M:V5Y*2!["B`@("`@("`@=6YS970H)"1K97DI.PH@("`@?0H@("`@9F]R96%C
M:"`H87)R87E?:V5Y<R@D7T5.5BD@87,@)&ME>2D@>PH@("`@("`@('5N<V5T
M*"0D:V5Y*3L*("`@('T*("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)%]315)6
M15(I(&%S("1K97DI('L*("`@("`@("!U;G-E="@D)&ME>2D["B`@("!]"GT*
M"B\J($EF('1H92!(;W)D92!&<F%M97=O<FL@<&%C:V%G97,@87)E(&YO="!I
M;G-T86QL960@:6X@4$A0)W,@9VQO8F%L"B`J(&EN8VQU9&5?<&%T:"P@>6]U
M(&UU<W0@861D(&%N(&EN:5]S970H*2!C86QL(&AE<F4@=&\@861D('1H96ER
M(&QO8V%T:6]N('1O"B`J('1H92!I;F-L=61E7W!A=&@N("HO"FEN:5]S970H
M)VEN8VQU9&5?<&%T:"<L(&1I<FYA;64H7U]&24Q%7U\I("X@4$%42%]315!!
M4D%43U(@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D["@HO*B!014%2(&)A
M<V4@8VQA<W,N("HO"FEN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH*+RH@2&]R
M9&4@8V]R92!C;&%S<V5S+B`J+PII;F-L=61E7V]N8V4@)TAO<F1E+G!H<"<[
M"FEN8VQU9&5?;VYC92`G2&]R9&4O4F5G:7-T<GDN<&AP)SL*:6YC;'5D95]O
M;F-E("=(;W)D92]3=')I;F<N<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92].
M3%,N<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92].;W1I9FEC871I;VXN<&AP
M)SL*:6YC;'5D95]O;F-E("=(;W)D92]!=71H+G!H<"<["FEN8VQU9&5?;VYC
M92`G2&]R9&4O0G)O=W-E<BYP:'`G.PII;F-L=61E7V]N8V4@)TAO<F1E+U!E
M<FUS+G!H<"<["@HO*B!"<F]W<V5R(&1E=&5C=&EO;B!O8FIE8W0N("HO"FEF
M("AC;&%S<U]E>&ES=',H)T)R;W=S97(G*2D@>PH@("`@)&)R;W=S97(@/2`F
M0G)O=W-E<CHZ<VEN9VQE=&]N*"D["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4RYP:'``
M````````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`V-C8W-@`Q,#4Q-30S,3`V,0`P,38S-#<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G
M4$5!4BYP:'`G.PIR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*9&5F:6YE*"=6
M1E-?455/5$%?34544DE#7T)95$4G+"`Q*3L*9&5F:6YE*"=61E-?455/5$%?
M34544DE#7TM")RP@,BD["F1E9FEN92@G5D937U%53U1!7TU%5%))0U]-0B<L
M(#,I.PID969I;F4H)U9&4U]154]405]-151224-?1T(G+"`T*3L*"B\J*@H@
M*B!61E,@05!)(&9O<B!A8G-T<F%C=&5D(&9I;&4@<W1O<F%G92!A;F0@86-C
M97-S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+G!H<"QV(#$N
M-CDN-"XQ-B`R,#`V+S`X+S`W(#`P.C,P.C$T(&-H=6-K($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@
M*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@5D93"B`J
M($!S:6YC92`@($AO<F1E(#(N,@H@*B\*8VQA<W,@5D93('L*"B`@("`O*BH*
M("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P
M87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@3&ES="!O9B!A9&1I
M=&EO;F%L(&-R961E;G1I86QS(')E<75I<F5D(&9O<B!T:&ES(%9&4R!B86-K
M96YD("AE>&%M<&QE.@H@("`@("H@1F]R($944"P@=V4@;F5E9"!A('5S97)N
M86UE(&%N9"!P87-S=V]R9"!T;R!L;V<@:6X@=&\@=&AE('-E<G9E<B!W:71H
M*2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7V-R961E;G1I86QS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($QI<W0@
M;V8@<&5R;6ES<VEO;G,@86YD(&EF('1H97D@8V%N(&)E(&-H86YG960@:6X@
M=&AI<R!61E,@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W!E<FUI<W-I;VYS(#T@87)R87DH"B`@("`@("`@
M)V]W;F5R)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@
M9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@("`@("`@)V=R;W5P)R`]
M/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E
M>&5C=71E)R`]/B!F86QS92DL"B`@("`@("`@)V%L;"<@("`]/B!A<G)A>2@G
M<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]
M/B!F86QS92DI.PH*("`@("\J*@H@("`@("H@02!014%2($QO9R!O8FIE8W0N
M($EF('!R97-E;G0L('=I;&P@8F4@=7-E9"!T;R!L;V<@97)R;W)S(&%N9`H@
M("`@("H@:6YF;W)M871I;VYA;"!M97-S86=E<R!A8F]U="!61E,@86-T:79I
M='DN"B`@("`@*@H@("`@("H@0'9A<B!,;V<*("`@("`J+PH@("`@=F%R("1?
M;&]G9V5R(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!L;V<@;&5V96P@
M=&\@=7-E("T@;65S<V%G97,@=VET:"!A(&AI9VAE<B!L;V<@;&5V96P@=&AA
M;B!C;VYF:6=U<F5D"B`@("`@*B!H97)E('=I;&P@;F]T(&)E(&QO9V=E9"X@
M1&5F875L=',@=&\@;VYL>2!L;V=G:6YG(&5R<F]R<R!O<B!H:6=H97(N"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VQO
M9TQE=F5L(#T@4$5!4E],3T=?15)2.PH*("`@("\J*@H@("`@("H@5&AE(&-U
M<G)E;G0@<VEZ92P@:6X@8GET97,L(&]F('1H92!61E,@:71E;2X*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?=F9S4VEZ
M92`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI
M;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!61E,H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1P87)A;7-;)W5S97(G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG
M=7-E<B==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<&%R
M86US6R=V9G-?<75O=&%L:6UI="==*2D@>PH@("`@("`@("`@("`D<&%R86US
M6R=V9G-?<75O=&%L:6UI="==(#T@+3$["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D<&%R86US6R=V9G-?<75O=&%R;V]T)UTI*2!["B`@("`@("`@
M("`@("1P87)A;7-;)W9F<U]Q=6]T87)O;W0G72`]("<O)SL*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VAE8VMS('1H92!C<F5D96YT:6%L<R!T:&%T('=E(&AA
M=F4@8GD@8V%L;&EN9R!?8V]N;F5C="@I+"!T;R!S964@:68*("`@("`J('1H
M97)E(&ES(&$@=F%L:60@;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&1E<V-R:6)I;F<@
M=&AE('!R;V)L96T@:68@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!C<F5D
M96YT:6%L<R!A<F4@:6YV86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE
M8VM#<F5D96YT:6%L<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8V]N;F5C="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!C;VYF:6=U
M<F%T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@<&%R86UE=&5R
M(&YA;65S(&%S(&ME>7,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%!A<F%M
M<R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULD;F%M95T@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!C;VYF:6=U<F%T:6]N('!A<F%M971E
M<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('!A
M<F%M971E<B!T;R!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE('!A<F%M971E<B!V86QU92!O<B!N=6QL(&EF(&ET(&1O97-N)W0@
M97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1N86UE*0H@
M("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W!A<F%M<ULD;F%M
M95TI(#\@)'1H:7,M/E]P87)A;7-;)&YA;65=(#H@;G5L;#L*("`@('T*"B`@
M("`O*BH*("`@("`J($QO9W,@82!M97-S86=E(&EF(&$@4$5!4B!,;V<@;V)J
M96-T(&ES(&%V86EL86)L92P@86YD('1H92!M97-S86=E)W,*("`@("`J('!R
M:6]R:71Y(&ES(&QO=V5R('1H86X@;W(@97%U86P@=&\@=&AE(&-O;F9I9W5R
M960@;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@("1M
M97-S86=E("`@5&AE(&UE<W-A9V4@=&\@8F4@;&]G9V5D+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'!R:6]R:71Y("!4:&4@;65S<V%G92=S('!R:6]R:71Y
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET
M>2`](%!%05)?3$]'7T524BD*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;&]G9V5R*2!\?"`D<')I;W)I='D@/B`D=&AI<RT^7VQO9TQE=F5L
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]A*"1M97-S86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1U<V5R:6YF;R`]("1M97-S86=E+3YG9715<V5R26YF;R@I.PH@("`@("`@
M("`@("`D;65S<V%G92`]("1M97-S86=E+3YG971-97-S86=E*"D["B`@("`@
M("`@("`@(&EF("@D=7-E<FEN9F\I('L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=7-E<FEN9F\I*2!["B`@("`@("`@("`@("`@("`@("`@)'5S
M97)I;F9O(#T@:6UP;&]D92@G+"`G+"`D=7-E<FEN9F\I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&UE<W-A9V4@+CT@)SH@)R`N("1U
M<V5R:6YF;SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M36%K92!S=7)E('1O(&QO9R!I;B!T:&4@<WES=&5M)W,@;&]C86QE+B`J+PH@
M("`@("`@("1L;V-A;&4@/2!S971L;V-A;&4H3$-?5$E-12P@,"D["B`@("`@
M("`@<V5T;&]C86QE*$Q#7U1)344L("=#)RD["@H@("`@("`@("1T:&ES+3Y?
M;&]G9V5R+3YL;V<H)&UE<W-A9V4L("1P<FEO<FET>2D["@H@("`@("`@("\J
M(%)E<W1O<F4@;W)I9VEN86P@;&]C86QE+B`J+PH@("`@("`@('-E=&QO8V%L
M92A,0U]424U%+"`D;&]C86QE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M=',@=&AE(%!%05(@3&]G(&]B:F5C="!U<V5D('1O(&QO9R!I;F9O<FUA=&EO
M;F%L(&]R(&5R<F]R(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!P87)A;2!,
M;V<@)B1L;V=G97(@(%1H92!,;V<@;V)J96-T('1O('5S92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D;&]G9V5R+"`D;&]G3&5V96P@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;&]G9V5R+"`G3&]G)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]L;V=G97(@/2`F)&QO9V=E<CL*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&QO9TQE=F5L*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO9TQE
M=F5L(#T@)&QO9TQE=F5L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E<R!T:&4@<VEZ92!O9B!A(&9I;&4@9G)O;2!T:&4@5D93
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R
M:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@5&AE(&9I;&4@
M<VEZ92X*("`@("`J+PH@("`@9G5N8W1I;VX@<VEZ92@D<&%T:"P@)&YA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T
M('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!S:7IE(&]F(&$@9F]L9&5R"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!P871H('1O('1H92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE('-I>F4@;V8@=&AE(&9O;&1E<BP@:6X@8GET
M97,L(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]L9&5R4VEZ92@D
M<&%T:"`](&YU;&PL("1N86UE(#T@;G5L;"D*("`@('L*("`@("`@("`D<VEZ
M92`](#`["B`@("`@("`@)')O;W0@/2`H*"%I<U]N=6QL*"1P871H*2D@/R`D
M<&%T:"`N("<O)R`Z("<G*2`N("1N86UE.PH@("`@("`@("1O8FIE8W1?;&ES
M="`]("1T:&ES+3YL:7-T1F]L9&5R*"1R;V]T+"!N=6QL+"!T<G5E+"!F86QS
M92P@=')U92D["B`@("`@("`@9F]R96%C:"`H)&]B:F5C=%]L:7-T(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'9A;%LG<W5B
M9&ER<R==*2D@>PH@("`@("`@("`@("`@("`@)'-I>F4@*ST@)'1H:7,M/F=E
M=$9O;&1E<E-I>F4H)')O;W0L("1K97DI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&9I;&5S:7IE(#T@)'1H:7,M/G-I>F4H)')O
M;W0L("1K97DI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&9I;&5S:7IE
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1F:6QE<VEZ93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1S:7IE("L]("1F:6QE<VEZ93L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T<FEE=F5S(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@
M0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E860H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@<&%R="!O9B!A(&9I
M;&4@9G)O;2!T:&4@5D93+B!087)T:6-U;&%R;'D@=7-E9G5L('=H96X*("`@
M("`J(')E861I;F<@;&%R9V4@9FEL97,@=VAI8V@@=V]U;&0@97AC965D('1H
M92!02%`@;65M;W)Y(&QI;6ET<R!I9B!T:&5Y"B`@("`@*B!W97)E('-T;W)E
M9"!I;B!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%T:"`@("`@("!4:&4@<&%T:&YA
M;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;F%M92`@
M("`@("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D;V9F<V5T("`@("!4:&4@;V9F<V5T(&]F('1H92!P87)T+B`H
M5&AE(&YE=R!O9F9S970@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8F4@<W1O<F5D(&EN(&AE<F4I+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&QE;F=T:"`@("`@5&AE(&QE;F=T:"!O9B!T:&4@<&%R="X@268@
M=&AE(&QE;F=T:"`]("TQ+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE('=H;VQE('!A<G0@869T97(@=&AE(&]F9G-E="!I<R!R971R
M:65V960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!M
M;W)E(&)Y=&5S(&%R92!G:79E;B!A<R!E>&ES=',@869T97(@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G:79E;B!O9F9S970N($]N
M;'D@=&AE(&%V86EL86)L92!B>71E<R!A<F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E860N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<F5M86EN:6YG("!4:&4@8GET97,@=&AA="!A<F4@;&5F="P@869T97(@=&AE
M('!A<G0@=&AA=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:7,@<F5T<FEE=F5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H
M92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861">71E4F%N
M9V4H)'!A=&@L("1N86UE+"`F)&]F9G-E="P@)&QE;F=T:"`]("TQ+"`F)')E
M;6%I;FEN9RD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-T;W)E<R!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@
M("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R
M87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)E('-T;W)E9"X*("`@("`J($!P87)A
M;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D
M:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA;64L("1T
M;7!&:6QE+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93
M(&9R;VT@<F%W(&1A=&$N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H
M('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A("`@("`@("`@5&AE(&9I;&4@9&%T82X*("`@("`J
M($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R
M96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L
M("1N86UE+"`D9&%T82P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D
M+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($UO=F5S(&$@9FEL92!T:')O
M=6=H('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H
M92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&YA;64@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D97-T("!4:&4@9&5S=&EN871I;VX@9FEL92!N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&UO=F4H)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O<&EE<R!A(&9I;&4@=&AR;W5G
M:"!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@
M;W)I9VEN86P@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!N86UE(&]F('1H92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&5S="`@5&AE(&YA;64@;V8@=&AE(&1E<W1I;F%T:6]N(&1I<F5C
M=&]R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;W!Y*"1P871H+"`D;F%M92P@)&1E<W0I"B`@
M("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U
M<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@
M9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@
M9&5L971E('1H92!F:6QE(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@9FEL96YA;64@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T
M949I;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5N86UE<R!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1O;&1P871H("!4:&4@;VQD('!A=&@@=&\@=&AE(&9I;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1O;&1N86UE("!4:&4@;VQD(&9I;&5N86UE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T:"`@5&AE(&YE=R!P871H(&]F('1H
M92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE
M=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H)&]L9'!A=&@L("1O;&1N
M86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EF(&$@9VEV96X@9FEL92!O<B!F
M;VQD97(@97AI<W1S(&EN(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('1H92!F;VQD97(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL92!O<B!F;VQD97(@;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@:70@
M97AI<W1S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5X:7-T<R@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&QI<W0@/2`D
M=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"D["B`@("`@("`@:68@*&ES7V$H)&QI
M<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!I<W-E="@D
M;&ES=%LD;F%M95TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-R96%T97,@82!F;VQD97(@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@<&%R96YT(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!N86UE(&]F('1H92!N97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T
M949O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!=71O;6%T:6-A;&QY(&-R96%T97,@86YY(&YE8V5S
M<V%R>2!P87)E;G0@9&ER96-T;W)I97,@:6X@=&AE('-P96-I9FEE9`H@("`@
M("H@)'!A=&@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE(%9&4R!P871H('1O(&%U=&]C<F5A=&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%U=&]C<F5A=&50871H*"1P871H*0H@("`@>PH@("`@("`@("1D:7)S
M(#T@97AP;&]D92@G+R<L("1P871H*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)&1I<G,I*2!["B`@("`@("`@("`@("1C=7(@/2`G+R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1D:7)S(&%S("1D:7(I('L*("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&1I<BDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(21T
M:&ES+3YI<T9O;&1E<B@D8W5R+"`D9&ER*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T949O;&1E<B@D8W5R+"`D
M9&ER*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1C=7(@(3T@)R\G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C=7(@
M+CT@)R\G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D8W5R("X]("1D:7(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&$@9VEV96X@:71E;2!I<R!A(&9O
M;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@
M<&%R96YT(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!I=&5M(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF(&ET(&ES(&$@9F]L9&5R+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES1F]L9&5R*"1P871H+"`D;F%M92D*("`@('L*
M("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H
M+"!N=6QL+"!T<G5E+"!T<G5E*3L*("`@("`@("!R971U<FX@:7-S970H)&9O
M;&1E<DQI<W1;)&YA;65=*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T
M97,@82!F;VQD97(@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@
M(%1H92!P87)E;G0@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@("`@("`@5&AE(&YA;64@;V8@=&AE(&9O;&1E<B!T;R!D96QE=&4N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E("!&;W)C92!A(')E8W5R
M<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1F]L9&5R*"1P871H+"`D
M;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5C=7)S:79E;'D@<F5M;W9E(&%L;"!F:6QE
M<R!A;F0@<W5B9F]L9&5R<R!F<F]M('1H92!G:79E;@H@("`@("H@9F]L9&5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H
M(&]F('1H92!F;VQD97(@=&\@96UP='DN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@96UP='E&;VQD
M97(H)'!A=&@I"B`@("!["B`@("`@("`@+R\@1V5T(&%N9"!D96QE=&4@=&AE
M('-U8F9O;&1E<G,N"B`@("`@("`@)&QI<W0@/2`D=&AI<RT^;&ES=$9O;&1E
M<B@D<&%T:"P@;G5L;"P@=')U92P@=')U92D["B`@("`@("`@:68@*&ES7V$H
M)&QI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L
M:7-T.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D9F]L
M9&5R*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9&5L971E1F]L
M9&5R*"1P871H+"`D9F]L9&5R6R=N86UE)UTL('1R=64I.PH@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`O+R!/;FQY(&9I;&5S(&%R92!L969T+"!G970@86YD(&1E
M;&5T92!T:&5M+@H@("`@("`@("1L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H
M)'!A=&@I.PH@("`@("`@(&EF("AI<U]A*"1L:7-T+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("!]"B`@("`@
M("`@9F]R96%C:"`H)&QI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YD96QE=&5&:6QE*"1P871H+"`D9FEL95LG;F%M92==
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&9I;&4@;&ES="!O9B!T:&4@9&ER
M96-T;W)Y('!A<W-E9"!I;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@("`@
M("H@0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("`@4W1R:6YG+VAA<V@@=&\@
M9FEL=&5R(&9I;&4O9&ER;F%M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N
M("1D;W1F:6QE<R`@(%-H;W<@9&]T9FEL97,_"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D9&ER;VYL>2`@("!3:&]W(&]N;'D@9&ER96-T;W)I97,_"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E("!2971U<FX@86QL(&1I<F5C
M=&]R>2!L979E;',@<F5C=7)S:79E;'D_"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R*"1P
M871H+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1I<F]N;'D@/2!F86QS92P@)')E8W5R<VEV
M92`](&9A;'-E*0H@("`@>PH@("`@("`@("1L:7-T(#T@)'1H:7,M/E]L:7-T
M1F]L9&5R*"1P871H+"`D9FEL=&5R+"`D9&]T9FEL97,L("1D:7)O;FQY*3L*
M("`@("`@("!I9B`H(21R96-U<G-I=F4@?'P@:7-?82@D;&ES="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@
M?0H*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D;F%M92`]/B`D=F%L=65S
M*2!["B`@("`@("`@("`@(&EF("@D=F%L=65S6R=T>7!E)UT@/3T@)RHJ9&ER
M)RD@>PH@("`@("`@("`@("`@("`@)&QI<W1;)&YA;65=6R=S=6)D:7)S)UT@
M/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"`N("<O)R`N("1N86UE+"`D9FEL
M=&5R+"`D9&]T9FEL97,L("1D:7)O;FQY+"`D<F5C=7)S:79E*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A;B!U;G-O<G1E9"!F:6QE
M(&QI<W0@;V8@=&AE('-P96-I9FEE9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A
M<F%M(&UI>&5D("1F:6QT97(@("`@("!3=')I;F<O:&%S:"!T;R!F:6QT97(@
M9FEL92]D:7)N86UE(&]N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I
M;&5S("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I
M<F]N;'D@("!3:&]W(&]N;'D@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES=$9O
M;&1E<B@D<&%T:"P@)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A;'-E*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S
M=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@8W5R<F5N="!W;W)K:6YG(&1I<F5C=&]R>2!O9B!T:&4@5D93(&)A8VME
M;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C=7)R96YT
M('=O<FMI;F<@9&ER96-T;W)Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#
M=7)R96YT1&ER96-T;W)Y*"D*("`@('L*("`@("`@("!R971U<FX@)R<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@;W(@;F]T(&$@
M9FEL96YA;64@;6%T8VAE<R!A;GD@9FEL=&5R(&5L96UE;G0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1F:6QT97(@("`@(%-T<FEN9R]H87-H('1O(&)U:6QD('1H92!R96=U
M;&%R(&5X<')E<W-I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!F<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%-T<FEN
M9R!C;VYT86EN:6YG('1H92!F:6QE;F%M92!T;R!M871C:"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@;6%T8V@L(&9A;'-E(&]N
M(&YO(&UA=&-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9FEL=&5R36%T8V@H
M)&9I;'1E<BP@)&9I;&5N86UE*0H@("`@>PH@("`@("`@("1N86UE9FEL=&5R
M(#T@;G5L;#L*"B`@("`@("`@+R\@0G5I;&0@82!R96=E>'`@8F%S960@;VX@
M)&9I;'1E<BX*("`@("`@("!I9B`H)&9I;'1E<B`A/3T@;G5L;"D@>PH@("`@
M("`@("`@("`D;F%M969I;'1E<B`]("<O)SL*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1F:6QT97(I*2!["B`@("`@("`@("`@("`@("`D;VYC92`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9I;'1E<B!A<R`D:71E
M;2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D;VYC92`A/3T@=')U92D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F%M969I;'1E<B`N/2`G*"<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O;F-E(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;F%M969I;'1E<B`N/2`G?"@G.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D;F%M969I;'1E<B`N/2`D:71E;2`N("<I
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1N86UE9FEL=&5R("X]("<H)R`N("1F:6QT97(@+B`G
M*2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YA;65F:6QT97(@+CT@
M)R\G.PH@("`@("`@('T*"B`@("`@("`@)&UA=&-H(#T@9F%L<V4["B`@("`@
M("`@:68@*"1N86UE9FEL=&5R("$]/2!N=6QL*2!["B`@("`@("`@("`@("1M
M871C:"`]('!R96=?;6%T8V@H)&YA;65F:6QT97(L("1F:6QE;F%M92D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&UA=&-H.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VAA;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@:71E;2!O;B!T
M:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@(%1H92!P87)E;G0@9F]L9&5R
M(&]F('1H92!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@
M("`@5&AE(&YA;64@;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!T;R!S970N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VAA;F=E4&5R;6ES<VEO;G,H)'!A=&@L("1N86UE+"`D<&5R;6ES<VEO
M;BD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").
M;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!S;W)T960@;&ES="!O9B!F;VQD97)S(&EN('1H92!S<&5C:69I960@
M9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T
M:&4@9&ER96-T;W)Y('1O(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R
M86T@;6EX960@)&9I;'1E<B`@("`@("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT
M97(@8F%S960@;VX@9F]L9&5R;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1D;W1F;VQD97)S("!);F-L=61E(&1O=&9O;&1E<G,_"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@1F]L9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI<W1&;VQD97)S*"1P871H(#T@)R<L("1F:6QT97(@/2!N=6QL
M+"`D9&]T9F]L9&5R<R`]('1R=64I"B`@("!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L:7-T(&]F(&%D9&ET:6]N86P@
M8W)E9&5N=&EA;',@<F5Q=6ER960L(&EF(&%N>2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!#<F5D96YT:6%L(&QI<W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%)E<75I<F5D0W)E9&5N=&EA;',H*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>5]D:69F*"1T:&ES+3Y?8W)E9&5N=&EA;',L(&%R<F%Y
M7VME>7,H)'1H:7,M/E]P87)A;7,I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@86X@87)R87D@<W!E8VEF>6EN9R!W:&%T('!E<FUI<W-I;VYS
M(&%R92!C:&%N9V5A8FQE(&9O<B!T:&ES"B`@("`@*B!61E,@:6UP;&5M96YT
M871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@0VAA;F=E86)L
M92!P97)M:7-I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-;V1I9FEA
M8FQE4&5R;6ES<VEO;G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!E<FUI<W-I;VYS.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@
M82!S=')I;F<@=&\@86QL(&QO=V5R8V%S92!C:&%R86-T97)S(&EG;F]R:6YG
M('1H92!C=7)R96YT"B`@("`@*B!L;V-A;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<W1R:6YG("!4:&4@<W1R:6YG('1O(&)E(&QO=V5R8V%S
M960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN9R!W
M:71H(&QO=V5R8V%S92!C:&%R86-T97)S"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-T<G1O;&]W97(H)'-T<FEN9RD*("`@('L*("`@("`@("`D;&%N9W5A9V4@
M/2!S971L;V-A;&4H3$-?0U194$4L(#`I.PH@("`@("`@('-E=&QO8V%L92A,
M0U]#5%E012P@)V5N)RD["B`@("`@("`@)'-T<FEN9R`]('-T<G1O;&]W97(H
M)'-T<FEN9RD["B`@("`@("`@<V5T;&]C86QE*$Q#7T-465!%+"`D;&%N9W5A
M9V4I.PH@("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C=&5R("AN;W0@8GET92D@;&5N9W1H
M(&]F(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T
M<FEN9R`@(%1H92!S=')I;F<@=&\@<F5T=7)N('1H92!L96YG=&@@;V8N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U
M<V4@=VAE;B!C86QC=6QA=&EN9R!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('-T<FEN9R=S(&QE;F=T:"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('-T<FEN9R=S(&QE;F=T:"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<W1R;&5N*"1S=')I;F<L("1C:&%R<V5T(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H97AT96YS:6]N7VQO861E9"@G;6)S=')I;F<G*2D@
M>PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@("`@("1C:&%R<V5T(#T@)TE33RTX.#4Y+3$G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1R970@/2!`;6)?<W1R;&5N*"1S=')I;F<L("1C
M:&%R<V5T*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<F5T*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N('-T<FQE;B@D<W1R:6YG*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-I>F4@;V8@=&AE(%9&4R!I=&5M
M+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@(%1H92!S:7IE+"!I;B!B>71E<RP@;V8@=&AE
M(%9&4R!I=&5M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G97161E-3:7IE*"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W9F<U-I>F4I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?=F9S4VEZ92`]("1T:&ES+3YG971&;VQD
M97)3:7IE*"1T:&ES+3Y?<&%R86US6R=V9G-?<75O=&%R;V]T)UTI.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]V9G-3:7IE.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@5D93('%U;W1A(&QI;6ET+@H@("`@
M("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<75O=&$@("!4:&4@;&EM:70@=&\@87!P;'DN"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;65T<FEC("!4:&4@;65T<FEC('1O(&UU;'1I
M<&QY('1H92!Q=6]T82!I;G1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9711
M=6]T82@D<75O=&$L("1M971R:6,@/2!61E-?455/5$%?34544DE#7T)95$4I
M"B`@("!["B`@("`@("`@<W=I=&-H("@D;65T<FEC*2!["B`@("`@("`@8V%S
M92!61E-?455/5$%?34544DE#7TM".@H@("`@("`@("`@("`D<75O=&$@*CT@
M<&]W*#(L(#$P*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M5D937U%53U1!7TU%5%))0U]-0CH*("`@("`@("`@("`@)'%U;W1A("H]('!O
M=R@R+"`R,"D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9&
M4U]154]405]-151224-?1T(Z"B`@("`@("`@("`@("1Q=6]T82`J/2!P;W<H
M,BP@,S`I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=V9G-?<75O=&%L:6UI="==(#T@)'%U;W1A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@5D93('%U;W1A(')O;W0N
M"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1I<B`@5&AE(')O;W0@9&ER96-T;W)Y(&9O<B!T
M:&4@<75O=&$@9&5T97)M:6YA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T475O=&%2;V]T*"1D:7(I"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W9F<U]Q=6]T87)O;W0G72`]("1D:7(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@<75O=&$@:6YF;W)M871I;VX@*'5S960O86QL;V-A=&5D*2P@
M:6X@8GET97,N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($%N(&%S<V]C:6%T:79E(&%R<F%Y
M+@H@("`@("H@("`@("`@("`@("`@("`@)VQI;6ET)R`]($UA>&EM=6T@<75O
M=&$@86QL;W=E9`H@("`@("H@("`@("`@("`@("`@("`@)W5S86=E)R`]($-U
M<G)E;G1L>2!U<V5D('!O<G1I;VX@;V8@<75O=&$@*&EN(&)Y=&5S*0H@("`@
M("H@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U;W1A*"D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T86QI;6ET
M)UTI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(DYO('%U;W1A('-E="XB*2D["B`@("`@("`@?0H*("`@("`@("`D=7-A9V4@
M/2`D=&AI<RT^9V5T5D934VEZ92@I.PH@("`@("`@(&EF("AI<U]A*"1U<V%G
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'5S86=E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M=7-A9V4G(#T^("1U<V%G92P@)VQI;6ET)R`]/B`D=&AI<RT^7W!A<F%M<ULG
M=F9S7W%U;W1A;&EM:70G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1&5T97)M:6YE<R!T:&4@;&]C871I;VX@;V8@=&AE('-Y<W1E;2!T
M96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@9&ER96-T
M;W)Y(&YA;64@=VAI8V@@8V%N(&)E('5S960@9F]R('1E;7`@9FEL97,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!I9B!O;F4@8V]U
M;&0@;F]T(&)E(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5&5M
M<$1I<B@I"B`@("!["B`@("`@("`@)'1M<%]L;V-A=&EO;G,@/2!A<G)A>2@G
M+W1M<"<L("<O=F%R+W1M<"<L("=C.EQ7551E;7`G+"`G8SI<=&5M<"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8SI<=VEN9&]W<UQT96UP
M)RP@)V,Z7'=I;FYT7'1E;7`G*3L*"B`@("`@("`@+RH@5')Y(%!(4"=S('5P
M;&]A9%]T;7!?9&ER(&1I<F5C=&EV92X@*B\*("`@("`@("`D=&UP(#T@:6YI
M7V=E="@G=7!L;V%D7W1M<%]D:7(G*3L*"B`@("`@("`@+RH@3W1H97)W:7-E
M+"!T<GD@=&\@9&5T97)M:6YE('1H92!435!$25(@96YV:7)O;FUE;G0@=F%R
M:6%B;&4N("HO"B`@("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@
M("`@("1T;7`@/2!G971E;G8H)U1-4$1)4B<I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@268@=V4@<W1I;&P@8V%N;F]T(&1E=&5R;6EN92!A('9A;'5E+"!T
M:&5N(&-Y8VQE('1H<F]U9V@@82!L:7-T(&]F"B`@("`@("`@("H@<')E<V5T
M('!O<W-I8FEL:71I97,N("HO"B`@("`@("`@=VAI;&4@*&5M<'1Y*"1T;7`I
M("8F('-I>F5O9B@D=&UP7VQO8V%T:6]N<RDI('L*("`@("`@("`@("`@)'1M
M<%]C:&5C:R`](&%R<F%Y7W-H:69T*"1T;7!?;&]C871I;VYS*3L*("`@("`@
M("`@("`@:68@*$!I<U]D:7(H)'1M<%]C:&5C:RDI('L*("`@("`@("`@("`@
M("`@("1T;7`@/2`D=&UP7V-H96-K.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!I="!I<R!S=&EL;"!E;7!T>2P@=V4@:&%V92!F
M86EL960L('-O(')E='5R;B!F86QS93L@;W1H97)W:7-E"B`@("`@("`@("H@
M<F5T=7)N('1H92!D:7)E8W1O<GD@9&5T97)M:6YE9"X@*B\*("`@("`@("!R
M971U<FX@96UP='DH)'1M<"D@/R!F86QS92`Z("1T;7`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#<F5A=&5S(&$@=&5M<&]R87)Y(&9I;&4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@(%)E='5R;G,@=&AE(&9U;&P@<&%T:"UN86UE('1O('1H92!T
M96UP;W)A<GD@9FEL92!O<@H@("`@("H@("`@("`@("`@("`@("`@("!F86QS
M92!I9B!A('1E;7!O<F%R>2!F:6QE(&-O=6QD(&YO="!B92!C<F5A=&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5&5M<$9I;&4H*0H@("`@>PH@("`@
M("`@("1T;7!?9&ER(#T@)'1H:7,M/E]G971496UP1&ER*"D["B`@("`@("`@
M:68@*&5M<'1Y*"1T;7!?9&ER*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D=&UP7V9I;&4@/2!T96UP;F%M*"1T
M;7!?9&ER+"`G=F9S)RD["@H@("`@("`@("\J($EF('1H92!F:6QE('=A<R!C
M<F5A=&5D+"!T:&5N(')E9VES=&5R(&ET(&9O<B!D96QE=&EO;B!A;F0*("`@
M("`@("`@*B!R971U<FXN("HO"B`@("`@("`@:68@*&5M<'1Y*"1T;7!?9FEL
M92DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D=&UP7V9I;&4["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!Q=6]T82!W:&5N('!R
M97!A<FEN9R!T;R!W<FET92!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@("!%
M:71H97(@)W-T<FEN9R<@;W(@)V9I;&4G+B`@268@)W-T<FEN9R<L("1D871A
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE(&1A=&$@=&\@
M8F4@=W)I='1E;BX@($EF("=F:6QE)RP@)&1A=&$@:7,@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@9FEL96YA;64@8V]N=&%I;FEN9R!T:&4@
M9&%T82!T;R!B92!W<FET=&5N+@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A
M=&$@($5I=&AE<B!T:&4@9&%T82!O<B!T:&4@9FEL96YA;64@=&\@=&AE(&1A
M=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4$5!4E]%<G)O<B!O
M;B!E<G)O<BP@=')U92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8VAE8VM1=6]T85=R:71E*"1M;V1E+"`F)&1A=&$I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?<&%R86US6R=V9G-?<75O=&%L:6UI="==("$]("TQ
M*2!["B`@("`@("`@("`@(&EF("@D;6]D92`]/2`G9FEL92<I('L*("`@("`@
M("`@("`@("`@("1F:6QE<VEZ92`]($!F:6QE<VEZ92@D9&%T82D["B`@("`@
M("`@("`@("`@("!I9B`H)&9I;&5S:7IE(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(BDI.PH@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D9FEL97-I>F4@/2!S=')L96XH)&1A=&$I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1V9G-S:7IE(#T@)'1H:7,M/F=E=%9&4U-I>F4H
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'9F<W-I>F4L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=F9S<VEZ93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H*"1V9G-S:7IE("L@)&9I;&5S:7IE
M*2`^("1T:&ES+3Y?<&%R86US6R=V9G-?<75O=&%L:6UI="==*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(BDI
M.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]V9G-3:7IE("$]/2`P
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W9F<U-I>F4@*ST@)&9I;&5S
M:7IE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@<75O=&$@
M=VAE;B!P<F5P87)I;F<@=&\@9&5L971E(&1A=&$N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@5&AE('!A=&@@=&AE(&9I;&4@:7,@;&]C871E9"!I;BX*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!014%27T5R<F]R(&]N(&5R<F]R+"!T<G5E
M(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:U%U;W1A
M1&5L971E*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H*"1T:&ES
M+3Y?<&%R86US6R=V9G-?<75O=&%L:6UI="==("$]("TQ*2`F)@H@("`@("`@
M("`@("`A96UP='DH)'1H:7,M/E]V9G-3:7IE*2D@>PH@("`@("`@("`@("`D
M9FEL97-I>F4@/2`D=&AI<RT^<VEZ92@D<&%T:"P@)&YA;64I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D9FEL97-I>F4L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AS:7IE*"D@9F%I;&5D*2XB*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]V9G-3:7IE("T]("1F:6QE
M<VEZ93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@
M5D93(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9&
M4R!S=6)C;&%S<R!T;R!R971U<FXN(%1H:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1D
M<FEV97(I+B!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;V1E
M(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O
M;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C
M;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@
M("`@("H*("`@("`J($!R971U<FX@5D93("!4:&4@;F5W;'D@8W)E871E9"!C
M;VYC<F5T92!61E,@:6YS=&%N8V4L(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@
M("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EN8VQU9&5?;VYC92`G5D93+R<@+B`D9')I=F5R("X@)RYP:'`G
M.PH@("`@("`@("1C;&%S<R`]("=61E-?)R`N("1D<FEV97(["B`@("`@("`@
M:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1V9G,@
M/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=F9S(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(I+"`D8VQA<W,I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F9S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@
M8V]N8W)E=&4@5D93(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R
M+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO(%9&
M4R!I;G-T86YC92!W:71H('1H90H@("`@("H@<V%M92!P87)A;65T97)S(&-U
M<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@
M=7-E9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F:6QE(&)A8VME;F1S("AA;F0L
M('1H=7,L"B`@("`@*B!M=6QT:7!L92!61E,@:6YS=&%N8V5S*2!A<F4@<F5Q
M=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O
M:V5D(&%S.B`D=F%R(#T@)E9&4SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@
M5D93('-U8F-L87-S('1O(')E='5R;BX@5&AI<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E<B`H
M)&1R:79E<BDN(%1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O
M9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@
M8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!61E,@(%1H92!C;VYC<F5T92!61E,@
M<F5F97)E;F-E+"!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@
M("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I
M;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA
M='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@
M("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)E9&4SHZ9F%C
M=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]A
M<&DN<&AP````````````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-3(W-S4`,3`U,34T,S$P-C$`,#$V-#4U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!(
M;W)D92!E>'1E<FYA;"!!4$D@:6YT97)F86-E+@H@*@H@*B!4:&ES(&9I;&4@
M9&5F:6YE<R!(;W)D92=S(&5X=&5R;F%L($%022!I;G1E<F9A8V4N($]T:&5R
M"B`J(&%P<&QI8V%T:6]N<R!C86X@:6YT97)A8W0@=VET:"!(;W)D92!T:')O
M=6=H('1H:7,@05!)+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]A<&DN<&AP
M+'8@,2XT,RXR+C4@,C`P-B\P-2\P-"`Q,SHR-SHR."!J86X@17AP("0*("H*
M("H@0'!A8VMA9V4@2&]R9&4*("HO"@HO*B!#;VUP;&5X('1Y<&5S+B`J+PHD
M7W1Y<&5S(#T@87)R87DH"B`@("`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<@
M/3X@87)R87DH87)R87DH)VET96TG(#T^("=S=')I;F<G*2DL"B`@("`G:&%S
M:$ET96TG(#T^(&%R<F%Y*"=K97DG(#T^("=S=')I;F<G+"`G=F%L=64G(#T^
M("=S=')I;F<G*2P*("`@("=H87-H)R`]/B!A<G)A>2AA<G)A>2@G:71E;2<@
M/3X@)WMU<FXZ:&]R9&5]:&%S:$ET96TG*2DL"B`@("`G:&%S:$AA<VA)=&5M
M)R`]/B!A<G)A>2@G:V5Y)R`]/B`G<W1R:6YG)RP@)W9A;'5E)R`]/B`G>W5R
M;CIH;W)D97UH87-H)RDL"B`@("`G:&%S:$AA<V@G(#T^(&%R<F%Y*&%R<F%Y
M*"=I=&5M)R`]/B`G>W5R;CIH;W)D97UH87-H2&%S:$ET96TG*2DI.PH*+RH@
M3&ES=&EN9W,N("HO"B1?<V5R=FEC97-;)W!E<FUS)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E
M?7-T<FEN9T%R<F%Y)RD["@HD7W-E<G9I8V5S6R=A9&UI;E]L:7-T)UT@/2!A
M<G)A>2AT<G5E*3L*"B1?<V5R=FEC97-;)VQI<W1!<'!S)UT@/2!A<G)A>2@*
M("`@("=A<F=S)R`]/B!A<G)A>2@G9FEL=&5R)R`]/B`G>W5R;CIH;W)D97US
M=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN
M9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG;&ES=$%027,G72`](&%R<F%Y*`H@
M("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R
M9&5]<W1R:6YG07)R87DG"BD["@HO*B!";&]C:W,N("HO"B1?<V5R=FEC97-;
M)V)L;V-K5&ET;&4G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=A
M<'`G(#T^("=S=')I;F<G+"`G;F%M92<@/3X@)W-T<FEN9R<L("=P87)A;7,G
M(#T^("=[=7)N.FAO<F1E?6AA<V@G*2P*("`@("=T>7!E)R`]/B`G<W1R:6YG
M)PHI.PH*)%]S97)V:6-E<ULG8FQO8VM#;VYT96YT)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@G87!P)R`]/B`G<W1R:6YG)RP@)VYA;64G(#T^
M("=S=')I;F<G+"`G<&%R86US)R`]/B`G>W5R;CIH;W)D97UH87-H)RDL"B`@
M("`G='EP92<@/3X@)W-T<FEN9R<**3L*"B1?<V5R=FEC97-;)V)L;V-K<R==
M(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH*2P*("`@("=T>7!E)R`]
M/B`G>W5R;CIH;W)D97UH87-H)PHI.PH*+RH@57-E<B!D871A+B`J+PHD7W-E
M<G9I8V5S6R=G9710<F5F97)E;F-E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G87!P)R`]/B`G<W1R:6YG)RP@)W!R968G(#T^("=S=')I;F<G
M*2P*("`@("=T>7!E)R`]/B`G<W1R:6YG)PHI.PH*)%]S97)V:6-E<ULG<V5T
M4')E9F5R96YC92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)V%P
M<"<@/3X@)W-T<FEN9R<L("=P<F5F)R`]/B`G<W1R:6YG)RP@)W9A;'5E)R`]
M/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E
M<G9I8V5S6R=R96UO=F55<V5R1&%T82==(#T@87)R87DH"B`@("`G87)G<R<@
M/3X@87)R87DH)W5S97(G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G
M8F]O;&5A;B<**3L*"B\J($=R;W5P<RX@*B\*)%]S97)V:6-E<ULG861D1W)O
M=7`G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G
M<W1R:6YG)RP@)W!A<F5N="<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^
M("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E1W)O=7`G72`](&%R
M<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RDL
M"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HO+R1?<V5R=FEC97-;)V=E
M=$=R;W5P<R==.R`_/S\*"B1?<V5R=FEC97-;)V%D9%5S97)4;T=R;W5P)UT@
M/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G;F%M92<@/3X@)W-T<FEN
M9R<L("=U<V5R)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O;VQE
M86XG"BD["@HD7W-E<G9I8V5S6R=A9&15<V5R<U1O1W)O=7`G72`](&%R<F%Y
M*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RP@)W5S
M97)S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G
M(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E57-E<D9R;VU'
M<F]U<"==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)VYA;64G(#T^
M("=S=')I;F<G+"`G=7-E<B<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^
M("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E57-E<G-&<F]M1W)O
M=7`G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G
M<W1R:6YG)RP@)W5S97)S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I
M+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG;&ES
M=%5S97)S3V9'<F]U<"==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH
M)VYA;64G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D
M97US=')I;F=!<G)A>2<**3L*"B\J(%-H87)E<RX@*B\*)%]S97)V:6-E<ULG
M861D4VAA<F4G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R
M95)O;W0G(#T^("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@
M)W-H87)E5&ET;&4G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S=')I
M;F<G*2P*("`@("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;
M)W)E;6]V95-H87)E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G
M<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN
M9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG
M;&ES=%-H87)E<T]F3W=N97(G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R
M<F%Y*"=S:&%R95)O;W0G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S
M=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<**3L*"B1?<V5R=FEC97-;)V%D9%5S97)097)M:7-S:6]N<R==(#T@87)R
M87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN
M9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S
M=')I;F<G+"`G<&5R;6ES<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R
M<F%Y)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S
M6R=A9&1'<F]U<%!E<FUI<W-I;VYS)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@
M/3X@)W-T<FEN9R<L("=G<F]U<$YA;64G(#T^("=S=')I;F<G+"`G<&5R;6ES
M<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP
M92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S6R=S9715<V5R4&5R;6ES
M<VEO;G,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O
M;W0G(#T^("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)W5S
M97).86UE)R`]/B`G<W1R:6YG)RP@)W!E<FUI<W-I;VYS)R`]/B`G>W5R;CIH
M;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI
M.PH*)%]S97)V:6-E<ULG<V5T1W)O=7!097)M:7-S:6]N<R==(#T@87)R87DH
M"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L
M("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G9W)O=7!.86UE)R`]/B`G<W1R
M:6YG)RP@)W!E<FUI<W-I;VYS)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG
M<F5M;W9E57-E<E!E<FUI<W-I;VYS)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@
M/3X@)W-T<FEN9R<L("=U<V5R3F%M92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y
M<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E1W)O=7!0
M97)M:7-S:6]N<R==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H
M87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G
M+"`G9W)O=7!.86UE)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O
M;VQE86XG"BD["@HD7W-E<G9I8V5S6R=L:7-T57-E<E!E<FUI<W-I;VYS)UT@
M/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G
M<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<L("=U<V5R3F%M92<@
M/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN
M9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG;&ES=$=R;W5P4&5R;6ES<VEO;G,G
M72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^
M("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)V=R;W5P3F%M
M92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T
M<FEN9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG;&ES=%5S97)S3V93:&%R92==
M(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@
M)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G<&5R;6ES<VEO
M;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP92<@
M/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG"BD["@HD7W-E<G9I8V5S6R=L
M:7-T1W)O=7!S3V93:&%R92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R
M87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S
M=')I;F<G+"`G<&5R;6ES<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R
M<F%Y)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG
M"BD["@H*+RH@3&ES=&EN9W,N("HO"F9U;F-T:6]N(%]H;W)D95]P97)M<R@I
M"GL*("`@("1P97)M<R`](&%R<F%Y*"D["@H@("`@)'!E<FUS6R=T<F5E)UU;
M)VAO<F1E)UU;)VUA>%]B;&]C:W,G72`](&9A;'-E.PH@("`@)'!E<FUS6R=T
M:71L92==6R=H;W)D93IM87A?8FQO8VMS)UT@/2!?*")-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS(BD["B`@("`D<&5R;7-;)W1Y<&4G75LG:&]R
M9&4Z;6%X7V)L;V-K<R==(#T@)VEN="<["@H@("`@<F5T=7)N("1P97)M<SL*
M?0H*9G5N8W1I;VX@7VAO<F1E7V%D;6EN7VQI<W0H*0I["B`@("!R971U<FX@
M87)R87DH)V-O;F9I9W5R871I;VXG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO<V5T=7`O
M)RP*("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E]3971U<"(I
M+`H@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)V-O;F9I9RYP;F<G
M*2P*("`@("`@("`@("`@("`@("`G=7-E<G,G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO
M=7-E<BYP:'`G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B
M7U5S97)S(BDL"B`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G=7-E
M<BYP;F<G*2P*("`@("`@("`@("`@("`@("`G9W)O=7!S)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE
M+V%D;6EN+V=R;W5P<RYP:'`G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M
M92<@/3X@7R@B7T=R;W5P<R(I+`H@("`@("`@("`@("`@("`@("`@("`G:6-O
M;B<@/3X@)V=R;W5P+G!N9R<I+`H@("`@("`@("`@("`@("`@("=P97)M<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P
M<&QI8V%T:6]N)2]A9&UI;B]P97)M<R]I;F1E>"YP:'`G+`H@("`@("`@("`@
M("`@("`@("`@("`G;F%M92<@/3X@7R@B7U!E<FUI<W-I;VYS(BDL"B`@("`@
M("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G<&5R;7,N<&YG)RDL"B`@("`@
M("`@("`@("`@("`@)V1A=&%T<F5E)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN+V1A=&%T
M<F5E+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")?
M1&%T851R964B*2P*("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=D
M871A=')E92YP;F<G*2P*("`@("`@("`@("`@("`@("`G<V5S<VEO;G,G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L
M:6-A=&EO;B4O861M:6XO<V5S<VEO;G,N<&AP)RP*("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G(#T^(%\H(E-E<W-I;VYS(BDL"B`@("`@("`@("`@("`@
M("`@("`@("=I8V]N)R`]/B`G=7-E<BYP;F<G*2P*("`@("`@("`@("`@("`@
M("`G<&AP<VAE;&PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G
M;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO<&AP<VAE;&PN<&AP)RP*
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E!?2%`@4VAE;&PB
M*2P*("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=M:6UE+W!H<"YP
M;F<G*2P*("`@("`@("`@("`@("`@("`G<W%L<VAE;&PG(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O
M861M:6XO<W%L<VAE;&PN<&AP)RP*("`@("`@("`@("`@("`@("`@("`@)VYA
M;64G(#T^(%\H(E-?44P@4VAE;&PB*2P*("`@("`@("`@("`@("`@("`@("`@
M)VEC;VXG(#T^("=S<6PN<&YG)RDL"B`@("`@("`@("`@("`@("`@)V-M9'-H
M96QL)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^
M("<E87!P;&EC871I;VXE+V%D;6EN+V-M9'-H96QL+G!H<"<L"B`@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")?0TQ)(BDL"B`@("`@("`@("`@
M("`@("`@("`@("=I8V]N)R`]/B`G<VAE;&PN<&YG)RDL"B`@("`@("`@("`@
M("`@("`@*3L*?0H*9G5N8W1I;VX@7VAO<F1E7VQI<W1!<'!S*"1F:6QT97(@
M/2!N=6QL*0I["B`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI
M<W1!<'!S*"1F:6QT97(I.PI]"@IF=6YC=&EO;B!?:&]R9&5?;&ES=$%027,H
M*0I["B`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!4$ES
M*"D["GT*"B\J($)L;V-K<RX@*B\*9G5N8W1I;VX@)E]H;W)D95]B;&]C:R@D
M87!P+"`D;F%M92P@)'!A<F%M<R`](&%R<F%Y*"DI"GL*("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:RYP:'`G
M.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H
M<"<["@H@("`@)')E<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@D87!P*3L*
M("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@)')E<W5L="`]($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K
M*"1A<'`L("1N86UE+"`D<&%R86US*3L*("`@("`@("`D<F5G:7-T<GDM/G!O
M<$%P<"@D87!P*3L*("`@('T*("`@(')E='5R;B`D<F5S=6QT.PI]"@IF=6YC
M=&EO;B!?:&]R9&5?8FQO8VM4:71L92@D87!P+"`D;F%M92P@)'!A<F%M<R`]
M(&%R<F%Y*"DI"GL*("`@("1B;&]C:R`]("9?:&]R9&5?8FQO8VLH)&%P<"P@
M)&YA;64L("1P87)A;7,I.PH@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1B;&]C:RT^9V5T365S<V%G92@I
M.PH@("`@?0H@("`@<F5T=7)N("1B;&]C:RT^9V5T5&ET;&4H*3L*?0H*9G5N
M8W1I;VX@7VAO<F1E7V)L;V-K0V]N=&5N="@D87!P+"`D;F%M92P@)'!A<F%M
M<R`](&%R<F%Y*"DI"GL*("`@("1B;&]C:R`]("9?:&]R9&5?8FQO8VLH)&%P
M<"P@)&YA;64L("1P87)A;7,I.PH@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1B;&]C:RT^9V5T365S<V%G
M92@I.PH@("`@?0H@("`@<F5T=7)N("1B;&]C:RT^9V5T0V]N=&5N="@I.PI]
M"@IF=6YC=&EO;B!?:&]R9&5?8FQO8VMS*"D*>PH@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<["B`@("`D8V]L;&5C=&EO
M;B`]("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T;VXH*3L*("`@
M(&EF("AI<U]A*"1C;VQL96-T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@<F5T=7)N("1C;VQL96-T:6]N.PH@("`@?2!E;'-E('L*("`@("`@("!R
M971U<FX@)&-O;&QE8W1I;VXM/F=E=$)L;V-K<TQI<W0H*3L*("`@('T*?0H*
M+RH@57-E<B!D871A+B`J+PIF=6YC=&EO;B!?:&]R9&5?9V5T4')E9F5R96YC
M92@D87!P+"`D<')E9BD*>PH@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQO
M8610<F5F<R@D87!P*3L*("`@(')E='5R;B`D1TQ/0D%,4ULG<')E9G,G72T^
M9V5T5F%L=64H)'!R968I.PI]"@IF=6YC=&EO;B!?:&]R9&5?<V5T4')E9F5R
M96YC92@D87!P+"`D<')E9BP@)'9A;'5E*0I["B`@("`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^;&]A9%!R969S*"1A<'`I.PH@("`@<F5T=7)N("1'3$]"04Q3
M6R=P<F5F<R==+3YS971686QU92@D<')E9BP@)'9A;'5E*3L*?0H*9G5N8W1I
M;VX@7VAO<F1E7W)E;6]V955S97)$871A*"1U<V5R*0I["B`@("!G;&]B86P@
M)&-O;F8["@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<RYP:'`G.PH@
M("`@)'!R969S(#T@)E!R969S.CIS:6YG;&5T;VXH)&-O;F9;)W!R969S)UU;
M)V1R:79E<B==+"!N=6QL+"`D=7-E<BD["B`@("!I9B`H:7-?82@D<F5S=6QT
M(#T@)'!R969S+3YC;&5A<B@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"GT*"B\J($=R;W5P<RX@*B\*"B\J*@H@
M*B!!9&1S(&$@9W)O=7`@=&\@=&AE(&=R;W5P<R!S>7-T96TN"B`J"B`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A
M<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9W)O=7`G<R!P87)E;G0G<R!N86UE
M+@H@*B\*9G5N8W1I;VX@7VAO<F1E7V%D9$=R;W5P*"1N86UE+"`D<&%R96YT
M(#T@;G5L;"D*>PH@("`@:68@*&5M<'1Y*"1P87)E;G0I*2!["B`@("`@("`@
M)'!A<F5N="`]($1!5$%44D5%7U)/3U0["B`@("!]"@H@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ
M<VEN9VQE=&]N*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M
M/FYE=T=R;W5P*"1N86UE+"`D<&%R96YT*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@<F5T=7)N("1G<F]U
M<',M/F%D9$=R;W5P*"1G<F]U<"D["GT*"B\J*@H@*B!296UO=F5S(&$@9W)O
M=7`@9G)O;2!T:&4@9W)O=7!S('-Y<W1E;2X*("H*("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&=R;W5P)W,@;F%M92X*("HO"F9U;F-T:6]N(%]H;W)D
M95]R96UO=F5'<F]U<"@D;F%M92D*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N
M*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P
M*"1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D9W)O
M=7`["B`@("!]"@H@("`@<F5T=7)N("1G<F]U<',M/G)E;6]V94=R;W5P*"1G
M<F]U<"P@=')U92D["GT*"B\J*@H@*B!!9&1S(&$@=7-E<B!T;R!A(&=R;W5P
M+@H@*@H@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9W)O=7`G<R!N86UE
M+@H@*B!`<&%R86T@<W1R:6YG("1U<V5R("!4:&4@=7-E<B!T;R!A9&0N"B`J
M+PIF=6YC=&EO;B!?:&]R9&5?861D57-E<E1O1W)O=7`H)&YA;64L("1U<V5R
M*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D
M9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D
M9W)O=7`@/2`F)&=R;W5P<RT^9V5T1W)O=7`H)&YA;64I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@<F5T=7)N("1G<F]U<#L*("`@('T*"B`@("!R971U
M<FX@)&=R;W5P+3YA9&15<V5R*"1U<V5R*3L*?0H*+RHJ"B`J($%D9',@;75L
M=&EP;&4@=7-E<G,@=&\@82!G<F]U<"X*("H*("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y("1U<V5R
M<R`@5&AE('5S97)S('1O(&%D9"X*("HO"F9U;F-T:6]N(%]H;W)D95]A9&15
M<V5R<U1O1W)O=7`H)&YA;64L("1U<V5R<RD*>PH@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN
M9VQE=&]N*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E
M=$=R;W5P*"1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R
M;B`D9W)O=7`["B`@("!]"@H@("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R
M*2!["B`@("`@("`@)&=R;W5P+3YA9&15<V5R*"1U<V5R+"!F86QS92D["B`@
M("!]"@H@("`@<F5T=7)N("1G<F]U<"T^<V%V92@I.PI]"@HO*BH*("H@4F5M
M;W9E<R!A('5S97(@9G)O;2!A(&=R;W5P+@H@*@H@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@9W)O=7`G<R!N86UE+@H@*B!`<&%R86T@<W1R:6YG("1U
M<V5R("!4:&4@=7-E<B!T;R!A9&0N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M
M;W9E57-E<D9R;VU'<F]U<"@D;F%M92P@)'5S97(I"GL*("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z
M.G-I;F=L971O;B@I.PH*("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S
M+3YG971'<F]U<"@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R
M971U<FX@)&=R;W5P.PH@("`@?0H*("`@(')E='5R;B`D9W)O=7`M/G)E;6]V
M955S97(H)'5S97(I.PI]"@HO*BH*("H@4F5M;W9E<R!M=6QT:7!L92!U<V5R
M<R!F<F]M(&$@9W)O=7`N"B`J"B`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!G<F]U<"=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D=7-E<G,@(%1H92!U
M<V5R<R!T;R!A9&0N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E57-E<G-&
M<F]M1W)O=7`H)&YA;64L("1U<V5R<RD*>PH@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE
M=&]N*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R
M;W5P*"1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D
M9W)O=7`["B`@("!]"@H@("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*2![
M"B`@("`@("`@)&=R;W5P+3YR96UO=F55<V5R*"1U<V5R+"!F86QS92D["B`@
M("!]"@H@("`@<F5T=7)N("1G<F]U<"T^<V%V92@I.PI]"@HO*BH*("H@4F5T
M=7)N<R!A(&QI<W0@;V8@=7-E<G,@=&AA="!A<F4@<&%R="!O9B!T:&ES(&=R
M;W5P("AA;F0@;VYL>2!T:&ES(&=R;W5P*0H@*@H@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@=7-E<B!L:7-T+@H@*B\*9G5N8W1I;VX@7VAO<F1E7VQI<W15<V5R
M<T]F1W)O=7`H)&YA;64I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O
M=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH*
M("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D;F%M
M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&=R;W5P.PH@
M("`@?0H*("`@(')E='5R;B`D9W)O=7`M/FQI<W15<V5R<R@I.PI]"@HO*B!3
M:&%R97,N("HO"@HO*BH*("H@061D<R!A('-H87)E('1O('1H92!S:&%R97,@
M<WES=&5M+@H@*@H@*B!`<&%R86T@<W1R:6YG("1S:&%R95)O;W0@("!4:&4@
M;F%M92!O9B!T:&4@<VAA<F4@<F]O="P@92YG+B!T:&4*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87!P;&EC871I;VX@=&AA="!T:&4@<VAA<F4@
M8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T<FEN9R`D<VAA<F5.86UE("`@5&AE
M('-H87)E)W,@;F%M92X*("H@0'!A<F%M('-T<FEN9R`D<VAA<F54:71L92`@
M5&AE('-H87)E)W,@:'5M86X@<F5A9&%B;&4@=&ET;&4N"B`J($!P87)A;2!S
M=')I;F<@)'5S97).86UE("`@(%1H92!S:&%R92=S(&]W;F5R+@H@*B\*9G5N
M8W1I;VX@7VAO<F1E7V%D9%-H87)E*"1S:&%R95)O;W0L("1S:&%R94YA;64L
M("1S:&%R951I=&QE+"`D=7-E<DYA;64I"GL*("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z
M.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@
M/2`F)'-H87)E<RT^;F5W4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H@("`@)'-H87)E
M+3YS970H)V]W;F5R)RP@)'5S97).86UE*3L*("`@("1S:&%R92T^<V5T*"=N
M86UE)RP@)'-H87)E5&ET;&4I.PH*("`@(')E='5R;B`D<VAA<F5S+3YA9&13
M:&%R92@D<VAA<F4I.PI]"@HO*BH*("H@4F5M;W9E<R!A('-H87)E(&9R;VT@
M=&AE('-H87)E<R!S>7-T96T@<&5R;6%N96YT;'DN"B`J"B`J($!P87)A;2!S
M=')I;F<@)'-H87)E4F]O="`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L
M(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P;&EC
M871I;VX@=&AA="!T:&4@<VAA<F4@8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T
M<FEN9R`D<VAA<F5.86UE("!4:&4@<VAA<F4G<R!N86UE+@H@*B\*9G5N8W1I
M;VX@7VAO<F1E7W)E;6]V95-H87)E*"1S:&%R95)O;W0L("1S:&%R94YA;64I
M"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S
M:&%R97,@/2`F2&]R9&5?4VAA<F4Z.G-I;F=L971O;B@D<VAA<F52;V]T*3L*
M"B`@("!I9B`H:7-?82@D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H
M87)E3F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H
M87)E.PH@("`@?0H*("`@(')E='5R;B`D<VAA<F5S+3YR96UO=F53:&%R92@D
M<VAA<F4I.PI]"@HO*BH*("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A;&P@<VAA
M<F5S('1H870@)'5S97).86UE(&ES('1H92!O=VYE<B!O9BX*("H*("H@0'!A
M<F%M('-T<FEN9R`D<VAA<F52;V]T("!4:&4@;F%M92!O9B!T:&4@<VAA<F4@
M<F]O="P@92YG+B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R
M86T@<W1R:6YG("1U<V5R3F%M92`@(%1H92!S:&%R92=S(&]W;F5R+@H@*@H@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!S:&%R97,N"B`J+PIF=6YC
M=&EO;B!?:&]R9&5?;&ES=%-H87)E<T]F3W=N97(H)'-H87)E4F]O="P@)'5S
M97).86UE*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<[
M"B`@("`D<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E
M4F]O="D["@H@("`@)'-H87)E7VQI<W0@/2`F)'-H87)E<RT^;&ES=%-H87)E
M<R@D=7-E<DYA;64L(%!%4DU37U-(3U<L("1U<V5R3F%M92D["B`@("`D;7ES
M:&%R97,@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)'-H87)E7VQI<W0@87,@
M)'-H87)E*2!["B`@("`@("`@)&UY<VAA<F5S6UT@/2`D<VAA<F4M/F=E=$YA
M;64H*3L*("`@('T*"B`@("!R971U<FX@)&UY<VAA<F5S.PI]"@HO*BH*("H@
M1VEV97,@82!U<V5R(&-E<G1A:6X@<')I=FEL96=E<R!F;W(@82!S:&%R92X*
M("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE(&YA;64@;V8@
M=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H87)E(&)E;&]N9W,@
M=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@(%1H92!S:&%R92=S
M(&YA;64N"B`J($!P87)A;2!S=')I;F<@)'5S97).86UE("`@(%1H92!U<V5R
M)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y("1P97)M:7-S:6]N<R`@02!L:7-T
M(&]F('!E<FUI<W-I;VYS("AS:&]W+"!R96%D+"!E9&ET+"!D96QE=&4I+@H@
M*B\*9G5N8W1I;VX@7VAO<F1E7V%D9%5S97)097)M:7-S:6]N<R@D<VAA<F52
M;V]T+"`D<VAA<F5.86UE+"`D=7-E<DYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!E<FUI<W-I;VYS*0I["B`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO<F1E
M7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["@H@("`@:68@*&ES7V$H
M)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R94YA;64I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*"B`@
M("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@(&9O<F5A
M8V@@*"1P97)M:7-S:6]N<R!A<R`D<&5R;6ES<VEO;BD@>PH@("`@("`@("1P
M97)M:7-S:6]N(#T@4W1R:6YG.CIU<'!E<B@D<&5R;6ES<VEO;BD["B`@("`@
M("`@:68@*&1E9FEN960H)U!%4DU37R<@+B`D<&5R;6ES<VEO;BDI('L*("`@
M("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R3F%M92P@
M8V]N<W1A;G0H)U!%4DU37R<@+B`D<&5R;6ES<VEO;BDL(&9A;'-E*3L*("`@
M("`@("!]"B`@("!]"B`@("!R971U<FX@)'-H87)E+3YS971097)M:7-S:6]N
M*"1P97)M*3L*?0H*+RHJ"B`J($=I=F5S(&$@9W)O=7`@8V5R=&%I;B!P<FEV
M:6QE9V5S(&9O<B!A('-H87)E+@H@*@H@*B!`<&%R86T@<W1R:6YG("1S:&%R
M95)O;W0@("!4:&4@;F%M92!O9B!T:&4@<VAA<F4@<F]O="P@92YG+B!T:&4*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P;&EC871I;VX@=&AA
M="!T:&4@<VAA<F4@8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T<FEN9R`D<VAA
M<F5.86UE("`@5&AE('-H87)E)W,@;F%M92X*("H@0'!A<F%M('-T<FEN9R`D
M9W)O=7!.86UE("`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y
M("1P97)M:7-S:6]N<R`@02!L:7-T(&]F('!E<FUI<W-I;VYS("AS:&]W+"!R
M96%D+"!E9&ET+"!D96QE=&4I+@H@*B\*9G5N8W1I;VX@7VAO<F1E7V%D9$=R
M;W5P4&5R;6ES<VEO;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P
M3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E
M<FUI<W-I;VYS*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H
M<"<["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D
M<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D[
M"B`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H
M:7-?82@D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@
M?0H@("`@:68@*&ES7V$H)&=R;W5P260@/2`D9W)O=7!S+3YG971'<F]U<$ED
M*"1G<F]U<$YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N
M("1G<F]U<$ED.PH@("`@?0H*("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R
M;6ES<VEO;B@I.PH@("`@9F]R96%C:"`H)'!E<FUI<W-I;VYS(&%S("1P97)M
M:7-S:6]N*2!["B`@("`@("`@)'!E<FUI<W-I;VX@/2!3=')I;F<Z.G5P<&5R
M*"1P97)M:7-S:6]N*3L*("`@("`@("!I9B`H9&5F:6YE9"@G4$5235-?)R`N
M("1P97)M:7-S:6]N*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1W)O=7!0
M97)M:7-S:6]N*"1G<F]U<$ED+"!C;VYS=&%N="@G4$5235-?)R`N("1P97)M
M:7-S:6]N*2P@9F%L<V4I.PH@("`@("`@('T*("`@('T*("`@(')E='5R;B`D
M<VAA<F4M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PI]"@IF=6YC=&EO;B!?:&]R
M9&5?<V5T57-E<E!E<FUI<W-I;VYS*"1S:&%R95)O;W0L("1S:&%R94YA;64L
M("1U<V5R3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&5R;6ES<VEO;G,I"GL*?0H*9G5N8W1I;VX@7VAO<F1E7W-E=$=R;W5P
M4&5R;6ES<VEO;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FUI
M<W-I;VYS*0I["GT*"B\J*@H@*B!296UO=F5S(&$@=7-E<B!F<F]M(&$@<VAA
M<F4N"B`J"B`J($!P87)A;2!S=')I;F<@)'-H87)E4F]O="`@(%1H92!N86UE
M(&]F('1H92!S:&%R92!R;V]T+"!E+F<N('1H90H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO
M;F=S('1O+@H@*B!`<&%R86T@<W1R:6YG("1S:&%R94YA;64@("!4:&4@<VAA
M<F4G<R!N86UE+@H@*B!`<&%R86T@<W1R:6YG("1U<V5R3F%M92`@("!4:&4@
M=7-E<B=S(&YA;64N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E57-E<E!E
M<FUI<W-I;VYS*"1S:&%R95)O;W0L("1S:&%R94YA;64L("1U<V5R3F%M92D*
M>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H
M87)E<R`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*
M("`@(&EF("AI<U]A*"1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA
M<F5.86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA
M<F4["B`@("!]"@H@("`@<F5T=7)N("1S:&%R92T^<F5M;W9E57-E<B@D=7-E
M<DYA;64I.PI]"@HO*BH*("H@4F5M;W9E<R!A(&=R;W5P(&9R;VT@82!S:&%R
M92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE(&YA;64@
M;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H87)E(&)E;&]N
M9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@(%1H92!S:&%R
M92=S(&YA;64N"B`J($!P87)A;2!S=')I;F<@)&=R;W5P3F%M92`@(%1H92!G
M<F]U<"=S(&YA;64N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E1W)O=7!0
M97)M:7-S:6]N<R@D<VAA<F52;V]T+"`D<VAA<F5.86UE+"`D9W)O=7!.86UE
M*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D<VAA<F5S(#T@
M)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["B`@("`D9W)O
M=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D<VAA
M<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H@("`@:68@
M*&ES7V$H)&=R;W5P260@/2`D9W)O=7!S+3YG971'<F]U<$ED*"1G<F]U<$YA
M;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1G<F]U<$ED
M.PH@("`@?0H*("`@(')E='5R;B`D<VAA<F4M/G)E;6]V94=R;W5P*"1G<F]U
M<$ED*3L*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@;V8@86QL('5S97(@
M<&5R;6ES<VEO;G,@;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D
M<VAA<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@
M=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N
M('1H870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@
M)'-H87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!S=')I
M;F<@)'5S97).86UE("`@(%1H92!U<V5R)W,@;F%M92X*("H*("H@0')E='5R
M;B!A<G)A>2`@06QL('5S97(@<&5R;6ES<VEO;G,@9F]R('1H:7,@<VAA<F4N
M"B`J+PIF=6YC=&EO;B!?:&]R9&5?;&ES=%5S97)097)M:7-S:6]N<R@D<VAA
M<F52;V]T+"`D<VAA<F5.86UE+"`D=7-E<DYA;64I"GL*("`@("1P97)M7VUA
M<"`](&%R<F%Y*%!%4DU37U-(3U<@/3X@)W-H;W<G+`H@("`@("`@("`@("`@
M("`@("`@("`@4$5235-?4D5!1"`]/B`G<F5A9"<L"B`@("`@("`@("`@("`@
M("`@("`@("!015)-4U]%1$E4(#T^("=E9&ET)RP*("`@("`@("`@("`@("`@
M("`@("`@(%!%4DU37T1%3$5412`]/B`G9&5L971E)RD["@H@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D
M95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A
M*"1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@
M("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@("`D<&5R
M;6ES<VEO;G,@/2`D<&5R;2T^9V5T57-E<E!E<FUI<W-I;VYS*"D["B`@("!I
M9B`H96UP='DH)'!E<FUI<W-I;VYS6R1U<V5R3F%M95TI*2!["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@)'5S97)?<&5R;6ES<VEO;G,@
M/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H87)R87E?:V5Y<RA097)M<SHZ:6YT
M96=E<E1O07)R87DH)'!E<FUI<W-I;VYS6R1U<V5R3F%M95TI*2!A<R`D<&5R
M;6ES<VEO;BD@>PH@("`@("`@("1U<V5R7W!E<FUI<W-I;VYS6UT@/2`D<&5R
M;5]M87!;)'!E<FUI<W-I;VY=.PH@("`@?0H*("`@(')E='5R;B`D=7-E<E]P
M97)M:7-S:6]N<SL*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@;V8@86QL
M(&=R;W5P('!E<FUI<W-I;VYS(&]N(&$@<VAA<F4N"B`J"B`J($!P87)A;2!S
M=')I;F<@)'-H87)E4F]O="`@(%1H92!N86UE(&]F('1H92!S:&%R92!R;V]T
M+"!E+F<N('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!L
M:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R86T@
M<W1R:6YG("1S:&%R94YA;64@("!4:&4@<VAA<F4G<R!N86UE+@H@*B!`<&%R
M86T@<W1R:6YG("1G<F]U<$YA;64@("!4:&4@9W)O=7`G<R!N86UE+@H@*@H@
M*B!`<F5T=7)N(&%R<F%Y("!!;&P@9W)O=7`@<&5R;6ES<VEO;G,@9F]R('1H
M:7,@<VAA<F4N"B`J+PIF=6YC=&EO;B!?:&]R9&5?;&ES=$=R;W5P4&5R;6ES
M<VEO;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M92D*>PH@
M("`@)'!E<FU?;6%P(#T@87)R87DH4$5235-?4TA/5R`]/B`G<VAO=R<L"B`@
M("`@("`@("`@("`@("`@("`@("!015)-4U]214%$(#T^("=R96%D)RP*("`@
M("`@("`@("`@("`@("`@("`@(%!%4DU37T5$250@/3X@)V5D:70G+`H@("`@
M("`@("`@("`@("`@("`@("`@4$5235-?1$5,151%(#T^("=D96QE=&4G*3L*
M"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("`D<VAA
M<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["@H@
M("`@:68@*&ES7V$H)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R
M94YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1S:&%R
M93L*("`@('T*"B`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH
M*3L*("`@("1P97)M:7-S:6]N<R`]("1P97)M+3YG971'<F]U<%!E<FUI<W-I
M;VYS*"D["B`@("!I9B`H96UP='DH)'!E<FUI<W-I;VYS6R1G<F]U<$YA;65=
M*2D@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("1G<F]U
M<%]P97)M:7-S:6]N<R`](&%R<F%Y*"D["B`@("!F;W)E86-H("AA<G)A>5]K
M97ES*%!E<FUS.CII;G1E9V5R5&]!<G)A>2@D<&5R;6ES<VEO;G-;)&=R;W5P
M3F%M95TI*2!A<R`D<&5R;6ES<VEO;BD@>PH@("`@("`@("1G<F]U<%]P97)M
M:7-S:6]N<UM=(#T@)'!E<FU?;6%P6R1P97)M:7-S:6]N73L*("`@('T*"B`@
M("!R971U<FX@)&=R;W5P7W!E<FUI<W-I;VYS.PI]"@HO*BH*("H@4F5T=7)N
M<R!A(&QI<W0@;V8@=7-E<G,@=VAI8V@@:&%V92!H879E(&-E<G1A:6X@<&5R
M;6ES<VEO;G,@;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA
M<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H
M870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H
M87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D
M<&5R;6ES<VEO;G,@($$@;&ES="!O9B!P97)M:7-S:6]N<R`H<VAO=RP@<F5A
M9"P@961I="P@9&5L971E*2X*("H*("H@0')E='5R;B!A<G)A>2`@3&ES="!O
M9B!U<V5R<R!W:71H('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N"B`J+PIF
M=6YC=&EO;B!?:&]R9&5?;&ES=%5S97)S3V93:&%R92@D<VAA<F52;V]T+"`D
M<VAA<F5.86UE+"`D<&5R;6ES<VEO;G,I"GL*("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z
M.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@
M/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*("`@("1P97)M
M(#T@,#L*("`@(&9O<F5A8V@@*"1P97)M:7-S:6]N<R!A<R`D<&5R;6ES<VEO
M;BD@>PH@("`@("`@("1P97)M:7-S:6]N(#T@4W1R:6YG.CIU<'!E<B@D<&5R
M;6ES<VEO;BD["B`@("`@("`@:68@*&1E9FEN960H)U!%4DU37R<@+B`D<&5R
M;6ES<VEO;BDI('L*("`@("`@("`@("`@)'!E<FT@)CT@8V]N<W1A;G0H)U!%
M4DU37R<@+B`D<&5R;6ES<VEO;BD["B`@("`@("`@?0H@("`@?0H*("`@(')E
M='5R;B`D<VAA<F4M/FQI<W15<V5R<R@D<&5R;2D["GT*"B\J*@H@*B!2971U
M<FYS(&$@;&ES="!O9B!G<F]U<',@=VAI8V@@:&%V92!H879E(&-E<G1A:6X@
M<&5R;6ES<VEO;G,@;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D
M<VAA<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@
M=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N
M('1H870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@
M)'-H87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!A<G)A
M>2`D<&5R;6ES<VEO;G,@($$@;&ES="!O9B!P97)M:7-S:6]N<R`H<VAO=RP@
M<F5A9"P@961I="P@9&5L971E*2X*("H*("H@0')E='5R;B!A<G)A>2`@3&ES
M="!O9B!G<F]U<',@=VET:"!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VYS+@H@
M*B\*9G5N8W1I;VX@7VAO<F1E7VQI<W1'<F]U<'-/9E-H87)E*"1S:&%R95)O
M;W0L("1S:&%R94YA;64L("1P97)M:7-S:6]N<RD*>PH@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D95]3
M:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A*"1S
M:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@("`@
M)'!E<FT@/2`P.PH@("`@9F]R96%C:"`H)'!E<FUI<W-I;VYS(&%S("1P97)M
M:7-S:6]N*2!["B`@("`@("`@)'!E<FUI<W-I;VX@/2!3=')I;F<Z.G5P<&5R
M*"1P97)M:7-S:6]N*3L*("`@("`@("!I9B`H9&5F:6YE9"@G4$5235-?)R`N
M("1P97)M:7-S:6]N*2D@>PH@("`@("`@("`@("`D<&5R;2`F/2!C;VYS=&%N
M="@G4$5235-?)R`N("1P97)M:7-S:6]N*3L*("`@("`@("!]"B`@("!]"@H@
M("`@<F5T=7)N("1S:&%R92T^;&ES=$=R;W5P<R@D<&5R;2D["GT*````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O````````````````````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#8R`#`Q-38U,``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]K;5]+2"\`````````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#$V-C0P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+VMM7TM(+TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,0`P
M,C`T,C4`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:VU?2T@O3$-?
M34534T%'15,O:&]R9&4N;6\`````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3$Q
M-S4S`#$P-3$U-#,Q,#8Q`#`R,C`W,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````$0"```<````/!(```4#``!<
M)````````'`P```.````<3````\```"`,```"````)`P```+````F3````P`
M``"E,```&````+(P```;````RS````P```#G,```!0```/0P```%````^C``
M``8`````,0``#`````<Q```.````%#$```X````C,0``"````#(Q```)````
M.S$```@```!%,0``$P```$XQ```#````8C$```@```!F,0``!P```&\Q```,
M````=S$```X```"$,0``"P```),Q```'````GS$```<```"G,0``!0```*\Q
M```%````M3$```,```"[,0``%P```+\Q```.````US$```<```#F,0``!@``
M`.XQ```(````]3$```H```#^,0``$P````DR```+````'3(```4````I,@``
M%0```"\R```)````13(```<```!/,@``!0```%<R```*````73(```8```!H
M,@``"0```&\R```'````>3(``!4```"!,@``"@```)<R```*````HC(``!``
M``"M,@``!P```+XR```'````QC(```H```#.,@``"````-DR```'````XC(`
M``<```#J,@``!@```/(R```%````^3(```<```#_,@``!@````<S```(````
M#C,```0````7,P``!P```!PS```)````)#,```8````N,P``!P```#4S```6
M````/3,```0```!4,P``"````%DS```&````8C,```T```!I,P``!@```'<S
M```>````?C,``!$```"=,P``"````*\S```,````N#,```<```#%,P```P``
M`,TS```(````T3,```@```#:,P``"````.,S```&````[#,```8```#S,P``
M"@```/HS```'````!30```<````--```#@```!4T```&````)#0``!@````K
M-```!````$0T```&````230```4```!0-```!0```%8T```0````7#0```4`
M``!M-```"P```',T```,````?S0``!<```",-```"````*0T```%````K30`
M``<```"S-```!P```+LT```+````PS0```<```#/-```!P```-<T```)````
MWS0```D```#I-```"@```/,T```5````_C0``!D````4-0``!0```"XU```2
M````-#4```@```!'-0``"````%`U```,````634```0```!F-0``"@```&LU
M```'````=C4```8```!^-0``!P```(4U```$````C34```P```"2-0``#0``
M`)\U```H````K34```,```#6-0``!@```-HU```1````X34``!<```#S-0``
M#@````LV```"````&C8```4````=-@``!````",V```#````*#8```@````L
M-@``#P```#4V```'````138```8```!--@``#0```%0V```*````8C8```<`
M``!M-@``"P```'4V```+````@38```D```"--@``"````)<V```(````H#8`
M`!(```"I-@``'P```+PV```(````W#8```P```#E-@``!@```/(V```'````
M^38```0````!-P``"0````8W```%````$#<```L````6-P``!0```"(W```-
M````*#<``!L````V-P``"0```%(W```1````7#<```<```!N-P``!0```'8W
M```'````?#<```@```"$-P``!@```(TW```0````E#<``!````"E-P``#P``
M`+8W```/````QC<```P```#6-P``!P```.,W```&````ZS<```@```#R-P``
M&P```/LW```-````%S@```,````E.```"````"DX```$````,C@```0````W
M.```"0```#PX```'````1C@```<```!..```!````%8X```%````6S@```H`
M``!A.```!0```&PX```&````<C@```8```!Y.```#0```(`X```0````CC@`
M`!L```"?.```!````+LX```)````P#@```4```#*.```!@```-`X```'````
MUS@```<```#?.```!0```.<X```)````[3@```H```#W.```#@````(Y```"
M````$3D```D````4.0``!@```!XY```2````)3D```D````X.0``!P```$(Y
M```&````2CD```H```!1.0``!````%PY```)````83D```8```!K.0``#0``
M`'(Y```&````@#D```0```"'.0``!0```(PY```&````DCD```<```"9.0``
M(0```*$Y```&````PSD```0```#*.0``!````,\Y```=````U#D```0```#R
M.0``#````/<Y```.````!#H```H````3.@``"````!XZ```)````)SH```<`
M```Q.@``"@```#DZ```'````1#H```H```!,.@``!@```%<Z```/````7CH`
M``4```!N.@``"0```'0Z```$````?CH```L```"#.@``#````(\Z```'````
MG#H```0```"D.@``!P```*DZ```&````L3H```8```"X.@``!@```+\Z```%
M````QCH```<```#,.@``!P```-0Z```%````W#H``!8```#B.@``!@```/DZ
M```$`````#L```0````%.P``!P````H[```*````$CL```4````=.P``"@``
M`",[```(````+CL```@````W.P``#P```$`[```&````4#L```H```!7.P``
M"````&([```@````:SL```8```",.P``!@```),[```'````FCL```0```"B
M.P``!P```*<[```%````KSL```<```"U.P``%@```+T[```-````U#L```0`
M``#B.P``!0```.<[```)````[3L```H```#W.P``"`````(\```&````"SP`
M``<````2/```!0```!H\```+````(#P```0````L/````P```#$\```*````
M-3P```(```!`/```!0```$,\```*````23P```0```!4/```!@```%D\```(
M````8#P```@```!I/```!````'(\```%````=SP```4```!]/```!@```(,\
M```0````BCP```H```";/```"@```*8\```)````L3P```,```"[/```!P``
M`+\\```'````QSP```<```#//```!@```-<\```&````WCP```8```#E/```
M"0```.P\```&````]CP```T```#]/```!@````L]```(````$CT```X````;
M/0``!P```"H]```*````,CT```<````]/0``"0```$4]```)````3ST```H`
M``!9/0``!P```&0]```)````;#T```<```!V/0``"@```'X]```'````B3T`
M``0```"1/0``!P```)8]```%````GCT```4```"D/0``"P```*H]```4````
MMCT```<```#+/0``!0```-,]```-````V3T``!$```#G/0``"P```/D]```,
M````!3X```0````2/@``"@```!<^```$````(CX```D````G/@``!0```#$^
M```'````-SX```4````_/@``!````$4^```"````2CX```0```!-/@``#@``
M`%(^```8````83X```8```!Z/@``!0```($^```(````ASX```8```"0/@``
M%````)<^```"````K#X```8```"O/@``!P```+8^```&````OCX```P```#%
M/@``!````-(^```4````USX``!````#L/@``!P```/T^```%````!3\```<`
M```+/P``"````!,_```%````'#\```8````B/P``$````"D_```(````.C\`
M``@```!#/P``"0```$P_```%````5C\```0```!</P``!@```&$_```'````
M:#\``"@```!P/P``"@```)D_```+````I#\``!0```"P/P``!````,4_```+
M````RC\```4```#6/P``"````-P_```&````Y3\```8```#L/P``"````/,_
M```(````_#\```<````%0```"`````U````*````%D````L````A0```!0``
M`"U````%````,T````4````Y0```!````#]````'````1$````T```!,0```
M!@```%I````'````84````8```!I0```!0```'!````'````=D```!$```!^
M0```!P```)!````%````F$````0```">0```!P```*-````+````JT````P`
M``"W0```!0```,1````#````RD```!(```#.0```!@```.%````#````Z$``
M``P```#L0```%0```/E````+````#T$``!D````;00``(````#5!```%````
M5D$```H```!<00``%0```&=!```,````?4$```0```"*00``#````(]!```&
M````G$$```X```"C00``#0```+)!```*````P$$```L```#+00``!P```-=!
M```)````WT$``!4```#I00``#0```/]!```(````#4(```,````60@``!0``
M`!I"```*````($(```0````K0@``!@```#!"```,````-T(```D```!$0@``
M"0```$Y"```$````6$(```@```!=0@``"````&9"```/````;T(```<```!_
M0@``#````(="```L````E$(```<```#!0@``!0```,E"```$````ST(```D`
M``#40@``"````-Y"```&````YT(```T```#N0@``!P```/Q"```&````!$,`
M``D````+0P``!P```!5#```%````'4,```<````C0P``"P```"M#```'````
M-T,```@````_0P``%@```$A#```)````7T,```8```!I0P``"P```'!#```4
M````?$,```4```"10P``$````)=#```0````J$,```8```"Y0P``"@```,!#
M```%````RT,``!````#10P``"P```.)#```$````[D,```D```#S0P``"```
M`/U#```O````!D0```0````V1```"P```#M$```%````1T0```(```!-1```
M!0```%!$```$````5D0```<```!;1```!0```&-$```#````:40``!,```!M
M1```!P```(%$```&````B40``!0```"01```#````*5$```8````LD0```8`
M``#+1````P```-)$```$````UD0```8```#;1```!P```.)$```)````ZD0`
M``<```#T1```#P```/Q$```4````#$4```X````A10``#0```#!%```D````
M/D4```4```!C10``!P```&E%```'````<44```8```!Y10``!@```(!%```'
M````AT4```0```"/10``$P```)1%```(````J$4```D```"Q10``"@```+M%
M```(````QD4```8```#/10``!P```-9%```(````WD4```D```#G10``!P``
M`/%%```/````^44```<````)1@``%````!%&```1````)D8```<````X1@``
M`P```$!&```(````1$8```8```!-1@``!P```%1&```-````7$8```X```!J
M1@``!0```'E&```&````?T8```@```"&1@``#````(]&```*````G$8```(`
M``"G1@``!````*I&```&````KT8```4```"V1@```P```+Q&```)````P$8`
M``H```#*1@``!0```-5&```&````VT8```@```#B1@``"````.M&```1````
M]$8``!D````&1P``$0```"!'```8````,D<``!,```!+1P``'````%]'```1
M````?$<```\```".1P```@```)Y'```1````H4<``!(```"S1P``%P```,9'
M```"````WD<```0```#A1P``$0```.9'```&````^$<``!@```#_1P``$P``
M`!A(```"````+$@```P````O2```$0```#Q(```-````3D@```<```!<2```
M!0```&1(```E`0``:D@``"T```"020``10```+Y)```;````!$H``"$````@
M2@``'@```$)*```]````84H``&H```"?2@``$@````I+```%````'4L``!4`
M```C2P``"0```#E+```5````0TL``#(```!92P``,@```(Q+```3````OTL`
M``H```#32P``$@```-Y+```P````\4L``!(````B3```-@```#5,```;````
M;$P``"T```"(3```*@```+9,```G````X4P``!@````)30``'@```")-```P
M````04T``!(```!R30``&````(5-``!"````GDT``"@```#A30``&`````I.
M```;````(TX``!X````_3@``)P```%Y.```^````ADX``!@```#%3@``#```
M`-Y.```D````ZTX``!X````03P``$@```"]/```2````0D\``!L```!53P``
M#````'%/```>````?D\``!4```"=3P``@0```+-/```M````-5```"H```!C
M4```-@```(Y0```8````Q5```!(```#>4```)````/%0```8````%E$``!L`
M```O40``'@```$M1```5````:E$``!(```"`40``&````)-1```2````K%$`
M`!L```"_40``"0```-M1```2````Y5$``"0```#X40``#````!U2```/````
M*E(``$T````Z4@``&P```(A2```;````I%(```D```#`4@``'@```,I2```8
M````Z5(``%@````"4P``/````%M3```>````F%,``"H```"W4P``&````.)3
M```#````^U,``!@```#_4P``%0```!A4```8````+E0``!(```!'5```$@``
M`%I4```2````;50``!4```"`5```,````)94```>````QU0``!(```#F5```
M40```/E4```)````2U4``"0```!550``#````'I5```)````AU4``"T```"1
M50``#P```+]5```A````SU4``!X```#Q50``*@```!!6```8````.U8```D`
M``!45@``(0```%Y6```S````@%8``"0```"T5@``'@```-E6```;````^%8`
M`!X````45P``&````#-7```8````3%<``$(```!E5P``40```*A7```5````
M^E<``$H````06```"````%M8```,````9%@``!4```!Q6```#P```(=8```>
M````EU@``!(```"V6```$@```,E8```5````W%@```\```#R6```/`````)9
M``!"````/UD``+D```""60``#````#Q:```2````25H``"$```!<6@``+0``
M`'Y:```M````K%H```(```#:6@``&P```-U:```G````^5H```P````A6P``
M#````"Y;```Q````.UL``!@```!M6P``#````(9;```>````DUL``!X```"R
M6P``&````-%;```>````ZEL``!@````)7```!@```")<```;````*5P``!@`
M``!%7```/````%Y<``!1````FUP```\```#M7```+0```/U<```2````*UT`
M`!L````^70``&P```%I=```;````=ET``!@```"270``)P```*M=```2````
MTUT``#````#F70``:````!=>```J````@%X``#````"K7@``&````-Q>```/
M````]5X``!@````%7P``&````!Y?```2````-U\``"\```!*7P``-0```'I?
M```I````L%\``#D```#:7P``)````!1@```>````.6```!(```!88```*@``
M`&M@``!"````EF```"$```#98```$@```/M@```2````#F$``!L````A80``
M#P```#UA```A````36$```\```!O80``&P```']A```2````FV$```\```"N
M80``+0```+YA```D````[&$```P````18@``$@```!YB```W````,6(``#,`
M``!I8@``1@```)UB```&````Y&(``!L```#K8@``%0````=C```8````'6,`
M`!L````V8P``'@```%)C```2````<6,``"0```"$8P``&````*EC```>````
MPF,```8```#A8P``,P```.AC```/````'&0``!P````L9```%0```$ED```>
M````7V0```\```!^9```)P```(YD```2````MF0``"$```#)9```$@```.MD
M```A````_F0``!L````@90``!````#QE```,````064``!4```!.90``$@``
M`&1E``!-````=V4``!(```#%90``#P```-AE```/````Z&4``%$```#X90``
M&````$IF```J````8V8``!(```".9@``)P```*%F```>````R68``!(```#H
M9@``%0```/MF```A````$6<``!@````S9P``(0```$QG```2````;F<``$(`
M``"!9P``#P```,1G```>````U&<``!4```#S9P``%0````EH```D````'V@`
M`!L```!$:```&````&!H```2````>6@``!X```",:```&````*MH```/````
MQ&@``!4```#4:```%0```.IH```,`````&D```\````-:0``(````!UI```;
M````/FD``!(```!::0``$@```&UI```G````@&D``"<```"H:0``$@```-!I
M```D````XVD``#,````(:@``&````#QJ```;````56H``!@```!Q:@``)```
M`(IJ```,````KVH``'4```"\:@``&````#)K```2````2VL```\```!>:P``
M#P```&YK```2````?FL``!(```"1:P``&P```*1K``!/````P&L``"$````0
M;```"0```#)L```)````/&P``!L```!&;```)````&)L```2````AVP```D`
M``":;```"0```*1L```)````KFP``"0```"X;```+0```-UL```)````"VT`
M`!X````5;0```@```#1M```2````-VT``"H```!*;0``%0```'5M```5````
MBVT``!@```"A;0``&````+IM```/````TVT``!4```#C;0``#````/EM```;
M````!FX``!(````B;@``&P```#5N```;````46X``!@```!M;@``#````(9N
M```2````DVX``!(```"F;@``"0```+EN```A````PVX``!@```#E;@``$@``
M`/YN```7````$6\```\````I;P``%0```#EO```5````3V\``!X```!E;P``
M(````(1O```5````I6\``!L```"[;P``%0```-=O```Y````[6\``#8````G
M<```-@```%YP```P````E7```!L```#&<```$@```.)P```D````]7```!X`
M```:<0``#P```#EQ```5````27$```P```!?<0``%0```&QQ```8````@G$`
M`"T```";<0``$@```,EQ```)````W'$``"<```#F<0``)`````YR```G````
M,W(``#8```!;<@``%0```))R```J````J'(``!4```#3<@``)````.ER```5
M````#G,``"$````D<P``"0```$9S```)````4',```8```!:<P``#P```&%S
M```A````<7,``$4```"3<P``$@```-ES```/````[',``!@```#\<P``"0``
M`!5T```G````'W0``!4```!'=```#P```%UT```,````;70``!L```!Z=```
M-@```)9T```/````S70``$4```#==```0@```"-U```5````9G4``!(```!\
M=0``$@```(]U```>````HG4```\```#!=0``&````-%U```J````ZG4``"$`
M```5=@``)P```#=V```L````7W8``!L```",=@``#P```*AV```2````N'8`
M``\```#+=@``9@```-MV```2````0G<``!(```!5=P``/````&AW```2````
MI7<``!L```"X=P``&````-1W```;````[7<``!(````)>```$@```!QX```D
M````+W@``!(```!4>```)````&=X```2````C'@``"<```"?>```&P```,=X
M```,````XW@``!(```#P>```#`````-Y```)````$'D``"H````:>0``00``
M`$5Y```G````AWD``"<```"O>0``$@```-=Y```G````ZGD``!4````2>@``
M,````"AZ```A````67H``!(```![>@``$@```(YZ```5````H7H``"T```"W
M>@``+0```.5Z```:````$WL```P````N>P``+0```#M[```8````:7L```,`
M``"">P``'@```(9[```L````I7L``"$```#2>P``1````/1[``!-````.7P`
M`!(```"'?```(0```)I\```5````O'P``#,```#2?```)`````9]```Q````
M*WT``!4```!=?0``+0```'-]```S````H7T``"<```#5?0``(0```/U]```>
M````'WX```\````^?@``1````$Y^```A````DWX```P```"U?@``#P```,)^
M```/````TGX``!4```#B?@``$@```/A^```2````"W\``!X````>?P``&```
M`#U_```;````5G\```P```!R?P``&P```']_```;````FW\``"0```"W?P``
M%0```-Q_```V````\G\``(`````I@```$@```*J````8````O8```"H```#6
M@```&P````&!```>````'8$``!@````\@0``(0```%6!```;````=X$``!L`
M``"3@0``+0```*^!```2````W8$``!(```#P@0``$@````."```D````%H(`
M`!(````[@@``&P```$Z"``!'````:H(``"0```"R@@``%0```->"```2````
M[8(``$8`````@P``#P```$>#```_````5X,``%$```"7@P``%0```.F#```M
M````_X,``!@````MA```)````$:$```>````:X0``!(```"*A```&````)V$
M```&````MH0``)$```"]A```&P```$^%``!+````:X4``!@```"WA0``!@``
M`-"%```8````UX4``!(```#PA0``&P````.&```5````'X8```\````UA@``
M1````$6&```8````BH8```\```"CA@``'````+.&```D````T(8``#(```#U
MA@``&P```"B'```#````1(<```0```!(AP``'@```$V'```;````;(<``#,`
M``"(AP``)P```+R'```=````Y(<``"$````"B```,````"2(```G````58@`
M`%H```!]B```#````-B(```>````Y8@``"$````$B0``-@```":)```;````
M78D``"0```!YB0``&P```)Z)``!%````NHD``"T`````B@``,@```"Z*```M
M````88H``!4```"/B@``#P```*6*```A````M8H```P```#7B@``)P```.2*
M```,````#(L``$(````9BP``#````%R+``!&````:8L``#X```"PBP``$@``
M`.^+```)`````HP``"$````,C```)````"Z,```D````4XP``#\```!XC```
M+0```+B,```/````YHP``!````#VC```*@````>-``!+````,HT``%$```!^
MC0```@```-"-```$````TXT``"$```#8C0``#P```/J-```3````"HX``"H`
M```>C@``)````$F.```&````;HX``!@```!UC@``(0```(Z.```,````L(X`
M`%0```"]C@``40```!*/``!.````9(\``&,```"SCP``5````!>0``!@````
M;)```$L```#-D```0@```!F1```"````7)$``$@```!?D0``-P```*B1``!%
M````X)$```@````FD@``#P```"^2``!%````/Y(``!(```"%D@``5P```)B2
M```Y````\)(```(````JDP``*@```"V3```Y````6),``#````"2DP``(0``
M`,.3```%````Y9,```$```!&````\P$``+@`````````,P$```$!``#^````
M'0(``-8!````````*0$```4"``#2`0```````"8`````````LP````````!,
M````NP```-@```"3````LP$```T"````````5`$``.8```"1````Q@```#("
M``#%`````````%$```!2`0``'0$`````````````10```/L```#B`0``"`(`
M`",````E`@```````*<```"#`0``F0```.<!```6`@``/P(``,,!```#`0``
MI`$```````#?`0``L````,````!9````#@(``#$!`````````````-4```#'
M````CP$``$`!````````Z@$``)8```!6````````````````````&@(``)(`
M``!T`0``T0```((```#O````@````"T```":`0``Y0$``,D````R`0``'0``
M``````#3````*`(``'<```#U`0``^@```*L```#Y`0````````````!U`0``
M`````.P!``#*`````````-4!``"Q`0``/`$``(@````O`0``H@```&8!```7
M`@``)@$```````!&`0````````````#K````+0$````````W`@``````````
M````````[P$```````"6`0````````````#3`0``T`$``/(`````````CP``
M```````*`@``:@$``#@!```D````#@````````"Z`0``HP`````````^````
M>0$``````````````````.X`````````20$``+4`````````,P```-\`````
M````G@````````#P`0``;P```%`!``#C````G@$````````(````;0$``(@!
M````````````````````````BP$``/@`````````O@```!L"````````<```
M`&$```!@````"P(``(<````)````FP``````````````=@```!X"``"]`0``
M`P```!`"````````;P$``.@!```J````+P````````"L````6`$```````!U
M````*`$```\```!V`0``<@```)\```#1`0``:0```+(```#_````[0$``*,!
M``#$````#`````````!$`0``H0$`````````````30```$(`````````A```
M`#4"````````P0``````````````M````.$!````````'P```*`!````````
MOP$``#`"````````B@```*H```#9`0```````"P"``!4````'@$``$,!``"X
M`0```````````````````````+L!````````D@$``"<`````````[0```)<`
M``"F````8`$``*0````[`0``]P```#0```";`0``X`$``#T"````````9P``
M`#D``````````````)@!```3`0``S`$``*X`````````9````*\```"E````
MPP```+D!``"B`0``Y``````````Z`@```````(P```!3`0``A0$``$H```!Q
M````.````&$!``!:`````````$<````S`@``2@$```````#L`````````!P!
M```5`@``-`(```0````P`0``-`$```````#Q````K0```+P!``#:````````
M``````````````````````#&`0``%P```$P!``"F`0``E0```*L!```I````
M2P$``"$"``!]`0``2````&T```!$`@```````($!``!T````YP````L!```,
M`0``/````&P!````````-0````$"```D`0``30$```````#:`0``'P$``*``
M```:`````````/<!```V`0``F@```````````````P(```````!"`0``@0``
M``D!``!B`0``_@$``,@!```D`@```````-P!``#E`````````#H!````````
M-@(``%P!```B````;@````````"-````4````,0!``#B`````````"P!```6
M````<P$``)@`````````@P```$4!```[````:P```*H!``!``@``P`$``*P!
M```G`0``50$``"4!```F`@````````H```#\`0`````````````'`0``@`$`
M`%L!````````^@$```````#-`````````'P```!$`````````.````"<````
M]`$``!D```!?````7@$``-(```#I`0``C`$``+H```!X`````````$X`````
M`````````(X!``#S````"P```!4!``#9````2P```)D!```7`0``R@$``+<`
M``"H`0```````'<!```K`@``D````%T```!<````&0$``"D"```G`@``````
M`!(`````````DP$``(<!``#R`0``.P(``&L!``#\``````````````""`0``
M!@(`````````````!@```!D"`````````````%L````1`@```````%\!``!>
M````.0(```4!```L````Z0```,L```!3`````````)4!```2`0``_P$```\!
M``#N`0````(```````"M`0``,@```#4!``#/````T````!P"```Y`0``6@$`
M```````C`0``S@$``$X!``#X`0``0@(``/$!``!#`@````````````!S````
M```````````N````8@``````````````"@$```````#;````]0```.$```#T
M````>0````````#Y```````````````"`0``5P$``*X!```"````P@$``*<!
M``#H`````````)$!``"&````J0```#T!```3`@``S@````````"4````(`$`
M`!,````C`@``&`$```````#C`0``/P$``'@!``"^`0``````````````````
M`````,$!``"-`0```````-0!``#>`0``ZP$```0"````````G0$``,P```")
M````!P(``!0```!5````M@$``*\!```8`@``9`$```````!E`````````#``
M``!9`0``L@$``"$`````````UP````4`````````40$``%(````Z````+@$`
M``````"?`0``%`(``+$````K````I0$``'X`````````8P$`````````````
MQP$``,L!```?`@``R0$```````#>````?`$``.8!``!#````M`$```````#]
M`0```````!$`````````MP$``&<!``"U`0```````(8!```M`@```````%T!
M``!R`0``BP```/`````&`0``/`(```````#8`0````````````"]````Q0$`
M`-0```#[`0``00(```````#J````J````*$```!'`0``B0$``"````!(`0``
M``````````#6`````````&X!``"_````90$````````J`@``,0(``$````"0
M`0``"0(``,\!````````*```````````````/P```-T```#V````(`(``%<`
M``!Q`0``:0$``"(!``"$`0`````````````2`@``EP$``*D!``!^`0``-P``
M`$$`````````<`$````````;````$`$``````````0``(@(``"\"``!!`0``
M_0```(X````A`0``$0$``+D```!H`0``.`(```@!``#=`0``O````&P```!]
M````#0$``!0!```>```````````````:`0``VP$``$D```!Z`0``/@$`````
M```5````&````"4````'````>P$````````]````:@```'H```"=````````
M`,@`````````5@$``!``````````8P````T````J`0``*P$```("````````
M?P$``"X"````````,0``````````````>P``````````````B@$``-<!``#"
M````#P(``)0!```W`0``%@$```````#<``````````````#-`0``6````'\`
M```^`@``3P```+`!```$`0``A0```$\!````````#@$``!L!``"V````-@``
M```````,`@``:````)P!``#D`0```````!P```#V`0````````````!F````
M`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN
M`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`E9"`E<R!A;F0@)7,`)7,@
M2T(`)7,@34(`)7,Z("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R
M-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`06)O=70N+BX`06-C
M;W5N="!);F9O<FUA=&EO;@!!9&0`061D('5S97(`061D<F5S<P!!9&1R97-S
M($)O;VL`061M:6YI<W1R871I;VX`069G:&%N:7-T86X`06QB86YI80!!;&=E
M<FEA`$%L:6%S`$%L:6=N`$%L;`!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!
M;65R:6-A;B!386UO80!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;G1A<F-T
M:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!R:6P`07)A
M8FEC("A7:6YD;W=S+3$R-38I`$%R9V5N=&EN80!!<FUE;FEA`$%R=6)A`$%T
M=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9`!!>F5R8F%I:F%N`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#
M;VQO<@!"86AA;6%S`$)A:')A:6X`0F%N9VQA9&5S:`!"87)B861O<P!"96QA
M<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H
M9&%Y`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<G,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V
M970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0U)#`$-A;&5N9&%R`$-A;6)O9&EA`$-A;65R;V]N`$-A;F%D80!#
M86YC96P`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%Y;6%N($ES;&%N
M9',`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#:&%D`$-H86YG
M90!#:&EL90!#:&EN80!#:')I<W1M87,@27-L86YD`$-L96%R`$-L96%R(%%U
M97)Y`$-L;W-E(%=I;F1O=P!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQO
M;6)I80!#;VQO<@!#;VUM86YD`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O
M<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF
M:7)M($5M86EL($%D9')E<W,`0V]N9FER;2!N97<@96UA:6P@861D<F5S<P!#
M;VYG;P!#;VYN96-T:6]N(&9A:6QE9"X`0V]N=&%C=',`0V]N=&EN=64`0V]O
M:R!)<VQA;F1S`$-O<'D`0V]S=&$@4FEC80!#;W5N=')Y`$-R96%T90!#<F]A
M=&EA`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0WEP<G5S`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Z96-H
M(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&4`1&%Y`$1E8V5M8F5R`$1E8W)E87-E
M($EN9&5N=`!$969A=6QT`$1E;&5T90!$96QE=&4@8V]L=6UN`$1E;&5T92!R
M;W<`1&5N;6%R:P!$97-C<FEP=&EO;@!$979E;&]P;65N=`!$:7)E8W1O<GD`
M1&II8F]U=&D`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA
M=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1'EN86UI8R!-86EL
M`$4M36%I;`!%8W5A9&]R`$5D:70`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A
M9&]R`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M;W1I8V]N<P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5S=&]N:6$`171H:6]P:6$`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&5C=71E`$5X<&%N9`!%>'!O;F5N=`!&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&87@`1F5B
M<G5A<GD`1FEJ:0!&:6QE`$9I;&4@3F%M90!&:6QT97)S`$9I;FQA;F0`1FQI
M<`!&;&]A=`!&;VYT($-O;&]R`$9O<FUS`$9R86UE<P!&<F%N8V4`1G)E;F-H
M($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<P!&<F]M`$9U;&P@3F%M90!'86)O;@!'86UB:6$`1V5O<F=I80!'
M97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I
M;VYS`$=O`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R
M965N;&%N9`!'<F5N861A`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M
M86QA`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$AA:71I`$AE
M861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<P!(96EG:'0`2&5L<`!(:6=H`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO
M;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AU;F=A<GD`25`@061D<F5S<P!)8V5L
M86YD`$EC;VYS($]N;'D`26UA9V5S`$EN8W)E87-E($EN9&5N=`!);F1I80!)
M;F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@5&%B;&4`26YT96=E
M<@!)<F%Q`$ER96QA;F0`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M
M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F]R
M9&%N`$IU;'D`2G5N90!*=7-T:69Y`$MA>F%K:'-T86X`2V5N>6$`2V5Y($QE
M;F=T:`!+97D@5'EP90!+:7)I8F%T:0!+;W)E86X@*$550RU+4BD`2W5W86ET
M`$MY<F=Y>G-T86X`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,`3&%T=FEA`$QA>6]U=`!,96)A;F]N`$QE9G0`3&5S;W1H;P!,
M979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS
M=&5I;@!,:6YK`$QI;FMS`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%T:6]N
M`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO=F4`3&]W`$QU
M>&5M8F]U<F<`34T`36%C86\`36%D86=A<V-A<@!-86EL`$UA;&%W:0!-86QA
M>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA<F-H`$UA<F=I;@!-87)S:&%L
M;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%U<FET86YI80!-875R:71I=7,`36%Y
M`$UA>6]T=&4`365M8F5R<P!-97-S86=E`$UE=&AO9`!-97AI8V\`36ED9&QE
M`$UI;64@5'EP90!-:7)R;W(`36ES8V5L;&%N96]U<P!-;VYA8V\`36]N9V]L
M:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO<F]C8V\`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=7``36]Z86UB:7%U90!->6%N;6%R`$YA;64`3F%M:6)I80!.
M875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($UE<W-A9V4@=&\@)7,`
M3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=W,`3F5W<V=R;W5P<P!.97AT
M`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F]N90!.
M;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y
M`$YO=&5S`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!/
M2P!/8FIE8W0`3V-T;V)E<@!/9F9I8V4`3VQD('!A<W-W;W)D`$]M86X`3W!E
M;B!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]T
M:&5R`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%N86UA`%!A<'5A($YE=R!'
M=6EN96$`4&%R86=U87D`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W1E`%!A=&@`
M4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VYS`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`4&AO;F4`4&ET8V%I<FX`4&EX
M96QS`%!O;&%N9`!0;W)T=6=A;`!0<F5S<W5R90!0<F5V:65W`%!R;VIE8W1S
M`%!U8FQI8R!+97D`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475O=&$`4F5A
M9`!2969R97-H`%)E9G)E<V@@<F%T93H`4F5L;V%D`%)E;6%R:W,`4F5M;W9E
M`%)E<V5T`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2:6=H
M=`!2;VQE`%)O;6%N:6$`4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=W,Z
M`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%-32`!386EN="!(96QE
M;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92!/<'1I;VYS`%-E87)C:`!396%R8V@@
M16YG:6YE<P!396QE8W0@82!D871E`%-E;&5C="!A;&P`4V5L96-T(&YO;F4`
M4V5N96=A;`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA
M;"!.=6UB97(`4V5S<VEO;G,`4V5T`%-E='5P`%-E>6-H96QL97,`4VAO=P!3
M:')I;FL`4VEE<G)A($QE;VYE`%-I9VYA='5R90!3:6YG87!O<F4`4VEZ90!3
M;&]V86MI80!3;&]V96YI80!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;W5T
M:"!!9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`4W!A8VEN9P!3<&%I;@!3<&%M`%-R:2!,86YK80!3=&%N9&%R
M9`!3=&%T=7,`4W1R:6ME=&AR;W5G:`!3=6)J96-T`%-U8FUI=`!3=6)S8W)I
M<'0`4W5C8V5S<P!3=61A;@!3=6UM87)Y`%-U<&5R<V-R:7!T`%-U<'!O<G0`
M4W5R:6YA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E
M9&5N`%-W:71Z97)L86YD`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%1A8FQE`%1A
M8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%J:6MI
M<W1A;@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7!E<F%T=7)E`%1E>'0`
M5&5X="!/;FQY`%1H86EL86YD`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T`%1I;64`5&EM92!F;W)M870`5&ET;&4`
M5&\`5&]D87D`5&]G;P!4;VME;&%U`%1O;F=A`%1O<`!4<FEN:61A9"!A;F0@
M5&]B86=O`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U
M<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%52
M3`!54DPZ`%5G86YD80!5:W)A:6YE`%5N9&5R;&EN90!5;F9I;&5D`%5N:6-O
M9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O
M;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<P!5;FET<P!5;FMN;W=N`%5N;F%M960`57!D871E`%5P;&]A9`!5
M<G5G=6%Y`%5S97(`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R;F%M90!5<V5R
M;F%M93H`57IB96MI<W1A;@!686QI9&ET>0!686QU97,`5F%N=6%T=0!687)I
M86)L90!696YE>G5E;&$`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5FEE=R`E
M<P!6:7)G:6X@27-L86YD<RP@52Y3+@!786QL:7,@86YD($9U='5N80!787)N
M:6YG`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E<W1E<FX@4V%H87)A`%=I9'1H`%=I9'1H.@!7:7-H;&ES=`!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!960!965E9`%EE87)L>0!996UE;@!997,`66]U
M<B!.86UE`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%],;V<@
M;W5T`&%D9')E<W-E92!U;FMN;W=N`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4`8V%N;F]T(&]P96X@:6YP=70`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES
M<VEN9P!D871A(&9O<FUA="!E<G)O<@!E;G1R>2!N;W0@9F]U;F0`:&@`:&]S
M="!N86UE('5N:VYO=VX`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O
M9G1W87)E(&5R<F]R`&UM`&YA;64`<&5R;6ES<VEO;B!D96YI960`<&EX96QS
M`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!S97)V:6-E('5N879A:6QA8FQE
M`'-S`'-Y<W1E;2!E<G)O<@!T96UP;W)A<GD@9F%I;'5R90!U;FMN;W=N(&5R
M<F]R`'5N;F%M960`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!)35`*4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#0M,3(M,#@@,3`Z,C@K,#$P,`I03RU2979I
M<VEO;BU$871E.B`R,#`U+3`V+3$U(#$Q.C4S*S`W,#`*3&%S="U4<F%N<VQA
M=&]R.B!,96%N9R!#:'5M<V]B96X@/'-O8F5N0&MH;65R;W,N:6YF;SX*3&%N
M9W5A9V4M5&5A;3H@2VAM97(@/'-U<'!O<G1`:VAM97)O<RYI;F9O/@I-24U%
M+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]=71F+3@*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E
M<R#AGI#AGY+AGH3AGX/B@(OAGH#AGI/AGY+AGIOAGH3B@(OAGI'AGX4I`"`H
MX9Z"X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%X9Z[X9Z%XH"+X9Z5X9^2X9Z;X9Z\
MX9Z<XH"+X9Z`X9ZVX9Z/X9^+("5S*0`@*.&>D.&?DN&>A.&?@^*`B^&>D^&?
M@>&?ARD`("CAGI#AGY+AGH3AGX/B@(OAGI_AGY+AGJ+AGX+AGH`I`"`HX9Z8
MX9^2X9Z?X9ZWX9Z;X9Z8X9^)X9ZWX9Z)*0`B)7,B(.&>F.&>M^&>D^*`B^&>
MF.&?@N&>D^*`B^&>A^&>MN*`B^&>D.&>C^*`B^&>H>&>ON&>F<*@X9^4`"(E
M<R(@X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3XH"+X9Z'X9ZVXH"+X9Z'X9Z8X9^2
MX9Z:X9Z^X9Z?XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2X9Z:X9Z\X9Z<XH"+
MX9ZAX9Z^X9Z9PJ#AGY0`)60@)7,@X9Z3X9ZWX9Z$("5S`"5S($M"`"5S(.&>
MF.&?@>&>@.&>MN&>E.&?@P`E<R#AGY8@)7,`+2T@X9Z'X9^2X9Z:X9Z^X9Z?
M("TM`.&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F2#AGZ'AGZ(@X9Z8
MX9^)X9^$X9Z$`.&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F2#AGZ+A
MGZ0@X9Z8X9^)X9^$X9Z$`.&?HN&?I"#AGICAGXGAGX3AGH0`/.&>F.&>N^&>
MDP#AGJ+AGX;AGI;AGKCB@(LN+BX`X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+
MX9ZBX9^&X9Z6X9ZXX9Z"X9Z.X9Z3X9ZX`.&>E.&>D^&?DN&>D.&?@N&>F`#A
MGI3AGI/AGY+AGI#AGX+AGICB@(OB@(OB@(OAGJ+AGY+AGI/AGH#B@(OAGI3A
MGY+AGIKAGKX`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3`.&>G^&?@.&>
MG.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DP#AGH#AGK;A
MGIKB@(OAGH+AGY+AGIKAGI3AGXOB@(OAGH+AGY+AGIKAGH0`X9ZBX9ZVX9Z@
MX9^2X9Z"X9ZVX9Z3X9ZXX9Z?X9^2X9Z0X9ZVX9Z3`.&>HN&>MN&>F^&?B^&>
ME.&>MN&>D^&>N`#AGJ+AGK;AGIOAGXOAGJ#AGY+AGI_AGX'AGIKAGK@`X9Z(
MX9^2X9Z8X9^$X9^'XH"+X9Z`X9^2X9Z;X9^"X9Z$X9Z`X9^2X9Z;X9ZVX9Z9
M`.&>C^&>F.&?DN&>FN&>N>&>F`#AGI'AGK;AGX;AGH3B@(OAGJ+AGI_AGXL`
MX9Z4X9^2X9Z*X9Z\X9Z:XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3
MXH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;`.&>G^&>MN&>F.&>O.&>HN&>MB#AGJ+A
MGK;AGICAGX'AGIKAGK?AGH``X9ZBX9Z$X9^+X9Z*X9Z\X9Z:X9^)X9ZV`.&>
MHN&>A.&?B^&>H.&?DN&>@N&?A.&>H>&>M@#AGJ+AGH3AGXOAGJ#AGY+AGI_A
MGXKAGKCAGJ'AGK8`X9Z7X9ZVX9Z"XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4
MX9Z\X9Z$`.&>HN&>A.&?B^&>D>&>N.&>H.&?DN&>@N&>MB#AGI/AGK?AGH0@
MX9Z4X9ZVX9Z4X9^*X9Z[X9Z9X9Z*X9ZV`.&>@.&>F.&?DN&>F.&>G.&>M^&>
MDN&>N`#AGICAGX'AGI_AGK8`X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+("A7:6YD
M;W=S+3$R-38I`.&>HN&>MN&>H.&?DN&>G^&>A.&?B^&>D>&>N.&>DP#AGJ+A
MGK;AGICAGX'AGI/AGK@`X9ZBX9ZVX9Z:X9Z\X9Z4X9ZV`.&>@N&>N^&>CN&>
MF^&>@.&?DN&>@>&>CN&?B`#AGI_AGKCAGJ#AGK8`X9ZBX9Z\X9Z?X9^2X9Z/
MX9^2X9Z:X9ZVX9Z;X9ZX`.&>HN&>O.&>D>&?DN&>FN&>N.&>GP#AGH#AGK;A
MGIKB@(OAGI7AGY+AGI'AGX#AGH3B@(OAGI7AGY+AGI'AGK;AGH_AGXOB@(OA
MGI?AGK;AGI;B@(OAGH_AGY+AGIKAGKGAGICB@(OAGH_AGY+AGIKAGKSAGISB
M@(OAGI3AGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGID`X9ZBX9ZVX9Z@X9^2
MX9Z?X9^*X9^"X9Z:X9Z4X9^"X9Z@X9^2X9Z?X9Z$X9^+`.&>E>&?DN&>D>&?
M@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F0#AGI;AGH[AGXSB@(OA
MGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGID`X9Z4
MX9ZVX9Z@X9ZVX9Z8X9^)X9ZVX9Z?`.&>E.&>MN&>FN&?B>&?@N&>DP#AGI3A
MGH3AGXOAGH#AGY+AGIOAGK;AGHKAGX'AGI_AGY+AGJ``X9Z4X9ZVX9Z:X9Z4
MX9ZVX9Z*X9Z\X9Z?`.&>E.&?@>&>H>&>MN&>FN&>N^&>G^&?DN&>GP#AGI3A
MGX+AGIOB@(OAGJ#AGY+AGI_AGXKAGK?AGH``X9Z4X9^!X9Z;X9ZXX9Z@X9^2
MX9Z?`.&>E.&?@>&>CN&>MN&?AN&>A`#AGI3AGXKAGX'AGIKAGICAGKSAGHKA
MGK8`X9Z4X9^*X9Z\X9Z/X9ZVX9Z3`.&>D.&?DN&>A.&?@^&>@.&?AN&>CN&>
MON&>CP#AGHKAGK?AGH\`X9Z4X9Z\X9Z;X9ZXX9Z<X9ZX`.&>@.&>D^&?DN&>
MF^&?@N&>A.*`B^&>A>&?AN&>CN&>MN&?A@#AGI_AGXKAGKOAGI@`X9Z?X9^*
MX9Z[X9Z8XH"+`.&>E.&>O.&>G^&?DN&>D^&?BN&>N"#AGI/AGK?AGH0@X9Z@
MX9ZZX9Z@X9^2X9Z?X9^*X9^!X9Z@X9^2X9Z"X9^$X9Z<X9ZXX9Z.X9ZV`.&>
MD>&>MN&?AN&>A.*`B^&>EN&>N.&>FN*`BP#AGI3AGKOAGH_AGI_AGY+AGISA
MGK;AGH[AGK8`X9Z4X9ZVX9Z/`.&>@.&?A.&?A^*`B^&>E.&?BN&>O.&>G.&?
MB>&?@@#AGI3AGY+AGIKAGX'AGI_AGXKAGKCAGIL`X9ZBX9ZVX9Z.X9ZVX9Z%
MX9Z`X9^2X9Z:XH"+X9Z?X9Z8X9Z[X9Z1X9^2X9Z:XH"+X9ZEX9Z.X9^2X9Z,
MX9ZV(.&>HN&>A.&?B^&>@N&?DN&>F^&?@>&>GP#AGI3AGY+AGIKAGXKAGKOA
MGIGAGH[AGX'B@(OAGHKAGK;AGIKAGXKAGKOAGIGAGI_AGK;AGJ'AGK;AGI@`
MX9Z4X9^*X9Z[X9Z;X9Z@X9^2X9Z"X9ZVX9Z:X9ZX`.&>E.&?BN&>O.&>FN&>
M@N&>N.&>CN&>MN&>H.&?DN&>G.&>MN&>G^&>O`#AGI3AGXKAGKSAGIKAGKOA
MGI/AGHSAGK@`0U)#`.&>E.&?DN&>FN&>C^&>M^&>D>&>M^&>DP#AGH#AGICA
MGY+AGI;AGKOAGH?AGK8`X9Z`X9ZVX9Z8X9^)X9ZVX9Z:X9Z\X9Z3`.&>@.&>
MMN&>CN&>MN&>BN&>M@#AGI3AGX3AGX?AGI3AGH3AGXL`X9Z`X9ZVX9Z4X9Z<
MX9^"X9Z:`.&>A>&?AN&>CN&>A.&>A^&>ON&>A`#AGISAGH_AGY+AGI#AGKOB
M@(OAGHKAGKGAGH#B@(OAGH?AGHGAGY+AGH?AGKSAGI,`X9Z`X9^$X9^'XH"+
MX9Z`X9^#X9Z8X9^)X9ZVX9Z3`.&>@.&>CN&?DN&>C^&>MN&>FP#AGI_AGK;A
MGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGJ#AGY+AGISAGY+A
MGIKAGK?AGH#B@(OAGH#AGH[AGY+AGHKAGK;AGIL`X9Z&X9ZVX9Z*`.&>E>&?
MDN&>F^&>MN&>G^&?B^*`B^&>E.&?DN&>C^&>O.&>F@#AGHCAGKCAGIOAGK@`
MX9Z%X9ZWX9Z3`.&>@.&?A.&?A^*`B^&>@N&?DN&>FN&>N.&>G^&?DN&>C^&>
MF.&?B>&>MN&>GP#AGH?AGICAGY+AGIKAGX<`X9Z'X9Z8X9^2X9Z:X9^'XH"+
MX9Z?X9^&X9Z.X9Z]X9Z:`.&>E.&>M^&>D>*`B^&>E.&>A.&?DN&>HN&>O>&>
MA0#AGH#AGX3AGX?B@(OAGH#AGKSAGH#AGKP@*.&>@^&>N.&>F^&>N.&>A"D`
MX9Z`X9Z\X9ZAX9Z[X9^&X9Z4X9^*X9ZX`.&>EN&>CN&?C`#AGI;AGK;AGH#A
MGY+AGIGB@(OAGI3AGHGAGY+AGH?AGK8`X9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZX
MXH"+XH"+X9ZBX9Z2X9ZWX9Z4X9^2X9Z4X9ZVX9Z9`.&>B.&?DN&>F.&?A.&?
MA^*`B^&>DN&>F.&?DN&>F.&>C^&>M@#AGH#AGKOAGX;AGICAGXGAGKSAGIKA
MGXGAGKSAGI\`X9Z`X9^2X9Z:X9Z[X9Z8X9Z@X9^*X9Z[X9Z3`.&>@.&>N^&?
MAN&>EN&?DN&>F>&>O.&>D>&?D.&>F@#AGIOAGH#AGY+AGH'AGH'AGH[AGY+A
MGHP`X9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,`.&>HN&?A^&>HN&>MN&>A.*`
MB^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?
M@N&>FP#AGJ+AGX?AGJ+AGK;AGH3B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIOB@(OAGI#AGY+AGICAGK@`X9Z`
MX9Z[X9Z$X9Z@X9^2X9Z"X9^$`.&>@.&>MN&>FN*`B^&>C^&>E^&?DN&>A^&>
MMN&>E.&?B^*`B^&>E.&>MN&>D^*`B^&>E.&>FN&>MN&>A^&?D.&>F>*`B\*@
MX9^4`$-O;G1A8W1S`.&>E.&>D^&?DN&>CP#AGH#AGX3AGX?B@(OAGH#AGKSA
MGH``X9Z%X9Z8X9^2X9Z;X9Z$`.&>@.&>O.&>G^&?DN&>C^&>MN&>FN&>N.&>
M@.&>M@#AGI3AGY+AGIKAGI'AGX'AGI\`X9Z4X9Z$X9^2X9Z`X9Z^X9Z/`.&>
M@.&?DN&>FN&>O.&>HN&>MN&>CP#AGH+AGKOAGIGAGI3AGK8`X9Z6X9^!X9Z;
MXH"+X9Z<X9^!X9Z;X9ZVXH"+X9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2X9Z4X9Z3
MX9^2X9Z3`.&>FN&>A>&>D^&>MN&>E.&?D.&>D>&?DN&>F.*`B^&>E.&>A>&?
MDN&>A>&>N^&>E.&?DN&>E.&>D^&?DN&>D^*`BP#AGI3AGY+AGH_AGKSAGIKB
M@(OAGI?AGK;AGIKAGH#AGK?AGH7AGY+AGH7B@(OAGHKAGX+AGIOB@(OAGH_A
MGY+AGIKAGKSAGISB@(OAGIKAGH_AGXOB@(OAGH_AGK;AGICB@(OAGI3AGX;A
MGH[AGH0@X9ZBX9ZVX9Z?X9^2X9Z:X9^0X9Z9XH"+X9Z;X9Z^XH"+X9Z`X9ZV
MX9Z:XH"+X9Z%X9Z\X9Z;XH"+X9Z1X9^%XH"+("5S(.&?E`#AGH#AGK;AGH_A
MGXL`X9Z?X9^*X9ZXX9Z6X9Z:X9^-`.&>G^&?BN&>N.&>FN&>N.&>F^&>N.&>
M@"`H2T])."U2*0#B@(OB@(OAGI_AGXKAGKCAGIKAGKCAGIOAGKCAGH`@*%=I
M;F1O=W,M,3(U,2D`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.XH"+X9Z:X9Z*X9^2X9Z+
MXH"+X9Z&X9^!X9Z``$1$`.&>FN&>MN&>F^&?B^*`B^&>D.&?DN&>A.&?@P#A
MGH#AGK;AGIOB@(OB@(OAGI3AGIKAGK?AGH7AGX'AGY+AGH;AGI$`X9Z0X9^2
MX9Z$X9^#`.&>DN&?DN&>D^&>O`#AGI3AGI/AGY+AGI#AGID@X9Z%X9Z\X9Z;
MXH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+`.&>F^&?AN&>D^&>MN&?AN&>BN&>
MON&>F`#AGIOAGKOAGI3B@(L`X9Z;X9Z[X9Z4XH"+X9Z'X9Z]X9Z:XH"+X9Z(
MX9Z:`.&>F^&>N^&>E.*`B^&>A^&>O>&>FN&>BN&?@>&>@`#AGHKAGK;AGH[A
MGKKAGICAGXGAGK;AGH``X9Z`X9ZVX9Z:X9Z6X9ZWX9Z6X9Z.X9^,X9Z3X9ZV
M`.*`B^&>HN&>E^&>M^&>G.&>C.&?DN&>C0#AGI#AGH\`X9Z@X9^2X9Z?X9^*
MX9ZXX9Z4X9Z\X9Z1X9ZX`.&>BN&>O.&>F.&>N.&>D^&>N.&>@.&>M@#AGI_A
MGK;AGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OAGHKAGKSAGICAGKCAGI/A
MGKCAGH#AGX+AGI,`X9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z"X9Z.X9Z3
MX9ZXPJ`_(.&>G^&>O.&>F.*`B^&>A>&>N^&?A^&>B.&?DN&>F.&?A.&?A\*@
MX9^4`.&>D>&>MN&>B>&>F>&>@`#AGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OA
MGI#AGK;AGICAGISAGI/AGY+AGH\`X9ZBX9^*X9ZXX9Z8X9^"X9Z;`.&>HN&?
M@>&>@.&?DN&>G.&>MN&>C.&?D.&>F@#AGH#AGX+B@(OAGI_AGICAGY+AGIKA
MGKWAGIL`X9Z`X9ZVX9Z:XH"+X9ZBX9Z4X9^+X9Z:X9^&`.&>HN&?@>&>H.&?
MDN&>G^&?BN&>N.&>E`#AGJ+AGX+AGIOAGI_AGK;AGIOAGXOAGISAGXGAGK;A
MGHSAGY#AGIH`X9ZBX9^*X9ZXX9Z8X9^"X9Z;`.&>HN&>MN&>G^&>F>&>BN&?
MDN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>FP#AGJ+AGK;AGI_AGIGA
MGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIOB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGH_AGX+B@(OAGHKAGKSAGH7AGH+AGY+AGI/AGK;"H.&?
ME`#AGI_AGHGAGY+AGHGAGK;B@(OAGJ+AGK;AGIKAGICAGY+AGICAGH[AGXT`
MX9Z@X9^2X9Z"X9ZXX9Z.X9^!XH"+X9ZBX9^!X9Z`X9^2X9Z<X9ZVX9Z1X9^0
MX9Z:`.&>HN&?@>&>FN&>N.&>D>&?DN&>FN&>M@#AGH#AGX;AGJ#AGKOAGI\`
MX9ZBX9^!X9Z?X9^2X9Z/X9Z\X9Z3X9ZX`.&>HN&?@>&>C^&?DN&>F>&>O.&>
MEN&>N`#AGJ+AGKKAGIKAGXGAGKOAGI0`X9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;
MX9^+XH"+(.&?H>&?I2#AGI/AGK;AGI'AGK@`X9Z:X9^`X9Z$XH"+X9Z:X9ZV
MX9Z;X9^+XH"+(.&?H^&?H"#AGISAGK?AGI/AGK;AGI'AGK@`X9Z:X9^`X9Z$
MXH"+X9Z:X9ZVX9Z;X9^+(.&?I2#AGI/AGK;AGI'AGK@`X9Z:X9^`X9Z$XH"+
MX9Z:X9ZVX9Z;X9^+XH"+X9Z`X9Z3X9^2X9Z;X9^'XH"+X9Z8X9^)X9^$X9Z$
M`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^&>D^&>MN&>D>&>N`#AGI3AGY+A
MGIKAGH_AGK?AGI3AGH_AGY+AGH_AGK<`X9Z4X9Z3X9^2X9Z;X9ZVX9Z9`.&>
MHN&?BN&>M^&>A>&>G^&?DN&>E.&>O.&>CN&>A.&?B^&>G^&?@N&>FP#AGH#A
MGX3AGX?B@(OAGJ#AGY+AGISAGXGAGH#AGJ'AGH3AGXL@*.&>F.&?B>&>MN&>
MF^&?B^&>G.&>N.&>CN&>MBD`X9Z`X9^$X9^'X9Z@X9^2X9Z<X9ZVX9ZBX9^!
MX9Z:X9Z\`.&>D>&>O.&>FN&>G^&>MN&>F@#AGH#AGKOAGICAGY+AGI?AGX@`
MX9Z@X9^2X9Z<X9ZXX9Z@X9^2X9Z?X9^*X9ZX`.&>K^&>@.&>G^&>MN&>F@#A
MGHCAGY+AGICAGX3AGX?B@(OAGJ_AGH#AGI_AGK;AGIH`X9Z/X9Z8X9^2X9Z:
MX9Z$`.&>H.&?DN&>G.&>MN&?AN&>A.&>H>&>A.&?BP#AGH_AGY+AGIKAGJ'A
MGI3AGXL`X9Z1X9Z?X9Z7X9ZVX9Z"`.&>EN&>CN&?C.*`B^&>EN&>N^&>F.&?
MDN&>EN*`B^&>HN&>@.&?DN&>G^&>F@#AGI_AGX;AGH[AGKOAGX;B@(OB@(OA
MGI3AGX+AGI3AGI3AGI$`X9Z?X9^*X9Z[X9Z8`.&>E.&>MN&>FN&>MN&?AN&>
MA`#AGJ#AGY+AGH+AGKSAGJ+AGXKAGKCAGIGAGXGAGK;AGH[AGK8@X9Z4X9ZV
MX9Z:X9ZVX9^&X9Z$`.&>E.&?B>&>O.&>F^&>N.&>D^&?@>&>G^&?BN&>N.*`
MB^&>E.&>MN&>FN&>MN&?AN&>A`#AGJ+AGK;AGH[AGH7AGH#AGY+AGIKB@(OA
MGH'AGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0@X9Z4X9ZVX9Z:X9ZVX9^&X9Z$
M`.&>EN&>N`#AGHCAGY+AGICAGX3AGX?B@(OAGI;AGX'AGHD`X9Z@X9^2X9Z"
MX9ZVX9Z4X9Z[X9Z$`.&>H.&?DN&>@.&>MN&?AN&>E.&?BN&>N`#AGJ#AGY+A
MGI_AGH#AGJ#AGY+AGI_AGXKAGK@`X9ZBX9ZVX9Z;X9^2X9Z;X9ZZX9Z8X9^)
MX9Z$X9^+`.&>H.&?DN&>@.&>MN&>CN&>M@#AGJ#AGY+AGH+AGKCAGI3AGY+A
MGIKAGK;AGIOAGXOAGH_AGK8`X9Z3X9ZVX9Z8X9Z!X9^2X9Z;X9Z]X9Z3`.&>
MA^&>F.&?DN&>FN&>ON&>G^*`B^&>G^&>@.&>FP#AGI'AGX4`X9Z8X9ZVX9Z/
MX9^2X9Z:X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z4X9^2X9Z:X9Z5X9^!X9^'`.&>
M@.&?DN&>FN&>M^&>@`#AGH#AGY+AGIKAGK?AGH`@*$E33RTX.#4Y+3<I`.&>
M@N&?DN&>FN&>N.&>H>&>A.&?BP#AGJ#AGY+AGH+AGY+AGIKAGKCAGH[AGK;A
MGHKAGK8`X9Z`X9^2X9Z:X9Z[X9Z8`.&>H.&?DN&>@N&>O.&>HN&>MN&>BN&>
MNN&>F^&>O.&>E.&?B>&?@0#AGJ#AGY+AGH+AGK;AGX;AGI@`X9Z@X9^2X9Z"
MX9ZVX9Z/X9^!X9Z8X9^)X9ZVX9ZAX9ZV`.&>H.&?DN&>@N&>N.&>CN&?@0#A
MGJ#AGY+AGH+AGKCAGH[AGX'AGI3AGXKAGKCAGI_AGX4`X9Z@X9^2X9Z"X9ZX
MX9Z9X9^)X9ZVX9Z.X9ZV`$A434P`X9Z@X9^#X9Z1X9ZX`.&>E.&>B^&>F.&>
M@.&>D.&>MN*`BP#AGI3AGHOAGICAGH#AGI#AGK8`X9Z`X9^$X9^'XH"+X9Z@
MX9^*X9Z^X9Z*(.&>D^&>M^&>A"#AGH#AGX3AGX?B@(OAGICAGXGAGK;AGH#A
MGHKAGKSAGH[AGK;AGIOAGXL`X9Z`X9Z8X9^2X9Z6X9Z?X9^+`.&>A^&?AN&>
MD^&>O>&>F0#AGH'AGY+AGI;AGI_AGXL`X9Z@X9Z\X9Z;X9ZXX9Z?X9^*X9ZX
M("CAGIKAGHKAGY+AGHOB@(OAGH#AGY+AGIKAGKOAGH3B@(OAGISAGXGAGK;A
MGI'AGKCAGH#AGH3AGXLI`.&>@N&?@>&>H.&>D>&?AN&>EN&?D.&>F@#AGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGI7AGY+AGI'AGX<`X9Z0X9Z/
MX9Z5X9^2X9Z1X9^'`.&>D>&>O.&>FN&>G^&?D.&>EN&?DN&>D>*`B^&>E>&?
MDN&>D>&?AP#AGJ#AGKOAGH3AGHSAGKSAGIKAGXGAGK;AGI_AGXL`X9Z@X9Z[
MX9Z$X9Z`X9Z[X9Z$`.&>H.&>N^&>A.&>@N&?DN&>FN&>N`#AGJ+AGK;AGI_A
MGIGAGHKAGY+AGHOAGK;AGI/B@(L@25``X9ZBX9^*X9ZXX9Z?X9^2X9Z;X9Z$
MX9^+`.&>C^&?@N*`B^&>FN&>O.&>E.&>C^&?AN&>CN&>MN&>A`#AGIKAGKSA
MGI3AGI?AGK;AGI8`X9Z4X9Z$X9^2X9Z`X9Z^X9Z3XH"+X9Z`X9ZVX9Z:XH"+
MX9Z%X9Z\X9Z;XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+`.&>I>&>CN&?DN&>
MC.&>M@#AGJ7AGH[AGY+AGHSAGKSAGI/AGX'AGI_AGXKAGK@`X9Z6X9^0X9Z/
MX9^,X9Z8X9ZVX9Z3`.&>EN&?D.&>C^&?C.&>F.&>MN&>DP#AGI3AGHGAGY+A
MGH7AGKSAGIOB@(OAGH_AGK;AGIKAGK;AGH0`X9Z%X9^&X9Z3X9Z]X9Z3XH"+
MX9Z"X9Z/X9^+`.&>HN&?BN&>N.&>FN&?B>&>MN&>@.&?BP#AGJ+AGX#AGIKA
MGJ'AGH3AGXL`X9ZBX9^*X9ZXX9Z?X9^2X9Z:X9ZVX9ZBX9^"X9Z;`.&>HN&?
MDN&>D^&>@.*`B^&>A>&?@>&>B0#AGI'AGY+AGIKAGX'AGH\`X9ZBX9^*X9ZX
MX9Z/X9ZVX9Z;X9ZX`.&>A>&>MN&>F.&?B>&?@^&>@.&>M@#AGICAGH#AGIKA
MGK8`X9Z'X9Z4X9^)X9Z[X9Z3`.*`B^&>A^&>E.&?B>&>N^&>DR`H25-/+3(P
M,C(M2E`I`.&>H.&?DN&>G^&?BN&>@.&>BN&>MN&>D^&>N`#AGH#AGH#AGY+A
MGH#AGHKAGK8`X9Z8X9ZWX9Z0X9Z[X9Z3X9ZV`.&>C^&>F.&?DN&>FN&>N>&>
MF.*`B^&>G^&>A.*`B^&>@>&>MN&>A`#AGH#AGK;AGJ#AGY+AGI_AGK;AGH#A
MGXOAGI_AGY+AGH_AGH3AGXL`X9Z`X9^"X9Z3X9Z9X9^)X9ZV`.&>E.&?DN&>
MFN&>G.&?@N&>A.*`B^&>@.&>O.&>D^&>G^&?A`#AGI3AGY+AGIKAGI?AGX'A
MGI'B@(OAGH+AGY+AGIKAGK;AGI3AGXOB@(OAGH7AGKOAGH4`X9Z"X9ZWX9Z:
MX9ZWX9Z4X9ZVX9Z1X9ZX`.*`B^&>@.&>O.&>FN&?B>&?@2`H155#+4M2*0#A
MGH+AGKOAGIGB@(OAGISAGXGAGX+AGH\`X9Z"X9^`X9Z:X9Z@X9^2X9Z"X9ZX
MX9Z?X9^2X9Z/X9Z$X9^+`.&>E^&>MN&>G^&>M@#AGI_AGK;AGI+AGK;AGIKA
MGH[AGIKAGHKAGY+AGHOB@(OAGI3AGY+AGIKAGH?AGK;AGI+AGK?AGI3AGH_A
MGX'AGIGAGY+AGIGB@(OAGI3AGY+AGIKAGH?AGK;AGICAGK;AGI/AGK?AGH_B
M@(OAGJ'AGK;AGIP`X9ZAX9ZVX9Z/X9Z<X9ZXX9Z9X9^)X9ZV`.&>E.&?DN&>
MF^&>A.&?B^*`BP#AGIOAGKCAGI3AGH3AGXL`X9Z&X9^2X9Z<X9^!X9Z$`.&>
MH>&?@>&>G^&>O.&>C^&>O`#AGH#AGICAGY+AGIKAGK?AGH\`X9Z;X9ZXX9Z4
MX9^!X9Z:X9ZXX9Z9X9^)X9ZV`.&>A>&>MN&>F.&?B>&>MN&>HN&?BN&>M^&>
MFN&>N.&>F>&?B>&>MN*`B^&>HN&>MN&>FN&?B>&>MN&>E.&?BR#AGIOAGKCA
MGI3AGXKAGK@`X9Z;X9ZWX9Z%X9Z1X9^!X9Z3X9Z?X9^2X9Z/X9^"X9Z3`.&>
MC^&?AN&>C@#AGH_AGX;AGHX`X9Z;X9ZXX9Z1X9Z[X9Z9X9ZBX9ZVX9Z3X9ZX
M`.&>@.&?AN&>EN&>N^&>A.*`B^&>E>&?DN&>D>&>N^&>@"XN+@#AGI'AGKCA
MGH_AGK;AGX;AGH0`X9Z%X9Z\X9Z;`.&>A>&?@>&>B0#AGH7AGKSAGIL`X9Z7
MX9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z%X9Z\X9Z;`.&>G^&?@>&>A>&>
M@.&?DN&>C^&>N.*`B^&>G^&?DN&>FN&>H>&>MN&>B>&?BP#AGI'AGK;AGI0`
MX9Z;X9Z[X9Z%X9Z@X9^2X9Z?X9^&X9Z4X9Z]X9Z:`$U-`.&>F.&?B>&>MN&>
M@.&>MN&>G`#AGICAGXGAGK;AGHKAGK;AGJ#AGY+AGH#AGK;AGI_AGY+AGH#A
MGK;AGIH`X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:`.&>F.&?B>&>MN&>H>&>MN&>
MG.&?@P#AGICAGXGAGK;AGJ'AGX'AGI_AGXKAGK@`X9Z8X9^)X9ZVX9Z;X9^+
MX9Z,X9ZXX9Z<`.&>F.&?B>&>MN&>F^&>N`#AGICAGXGAGK;AGIOAGXOAGH_A
MGK8`X9Z8X9ZXX9Z3X9ZV`.&>FN&>N>&>F.*`B^&>D>&?AN&>EN&?D.&>F@#A
MGH#AGX3AGX<@36%R<VAA;&P`X9Z8X9^)X9ZVX9Z:X9Z1X9ZXX9Z3X9ZXX9Z"
M`.&>F.&?B>&>O.&>FN&>N.&>C^&>MN&>D^&>N`#AGICAGXGAGKSAGIKAGKCA
MGI'AGKOAGI\`X9ZGX9Z?X9Z7X9ZV`.&>F.&?@^&>HN&>O.&>C^&?@0#AGI_A
MGICAGK;AGH?AGK?AGH``X9Z?X9ZVX9Z:`.&>G.&>M^&>DN&>N.&>G^&>MN&>
MG^&?DN&>FN&?DN&>CP#AGICAGXGAGK?AGH7AGI_AGXKAGK?AGH``X9Z`X9Z.
MX9^2X9Z/X9ZVX9Z;`.&>E.&?DN&>FN&>E^&?@>&>D2!-:6UE`.&>AN&?DN&>
MF^&>N^&?AP#AGI7AGY+AGI_AGX'AGH3AGY?B@(L`X9Z8X9^)X9Z\X9Z.X9ZV
MX9Z`X9Z\`.&>F.&?B>&>N^&>A.&>H.&?DN&>@N&?A.&>F^&>N`#AGH'AGX(@
MX9Z3X9ZWX9Z$(.&>AN&?DN&>D^&>MN&?A@#AGIKAGK;AGIOAGXOB@(OAGH'A
MGX(`X9Z8X9^)X9Z[X9Z$X9Z?X9^!X9Z:X9^)X9ZV`.&>F.&?B>&>MN&>FN&?
MB>&>N^&>@`#AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGH7AGKOA
MGX?B@(OAGH#AGY+AGIKAGX3AGI@`X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1
MX9ZXXH"+X9Z1X9^%XH"+X9Z&X9^2X9Z<X9^!X9Z$`.&>E>&?DN&>F^&>MN&>
MG^&?B^*`B^&>D>&>N.*`B^&>D>&?A>*`B^&>G^&?DN&>C^&>MN&?A@#AGI7A
MGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGJ'AGK[AGH3B@(OAGIOAGKX`
MX9Z%X9Z[X9^'XH"+X9Z`X9^2X9Z:X9^$X9Z8`.&>H>&>ON&>A.*`B^&>F^&>
MO@#AGICAGXGAGKSAGJ#AGY+AGI_AGK;AGX;AGI3AGXKAGK?AGH``X9Z8X9ZX
MX9Z9X9^)X9ZVX9Z3X9^+X9Z8X9^)X9ZV`.&>B.&?DN&>F.&?A.&?AP#AGH[A
MGK;AGICAGKCAGI3AGXKAGK@`X9Z.X9Z\X9Z:X9Z[`.&>D^&?@>&>E.&?B>&>
MMN&>F^&?BP#B@(OAGJ#AGKOAGIOAGY+AGIOAGH3AGXL`X9ZBX9Z$X9^+X9Z1
MX9ZXX9Z9X9^-XH"+X9Z@X9Z\X9Z;X9^2X9Z;X9Z$X9^+`.&>E.&>CN&?DN&>
MC^&>MN&>B0#AGH#AGKOAGX8`X9Z3X9Z\X9Z<X9^"X9Z;X9Z`X9ZVX9Z;X9^!
MX9Z*X9Z\X9Z3X9ZX`.&>G^&>MN&>FN*`B^&>D.&?DN&>F.&>N.*`B^&>D>&?
MA2`E<P#AGI/AGKSAGISAGX+AGIOAGJ#AGXKAGY+AGI_AGX'AGJ'AGH3AGXL`
MX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z0
MX9^2X9Z8X9ZX`.&>EN&?D.&>C^&?C.&>F.&>MN&>DP#AGISAGX'AGI'AGK?A
MGH#AGK;B@(OAGI;AGY#AGH_AGXSAGICAGK;AGI,`X9Z4X9Z3X9^2X9Z1X9ZV
MX9Z4X9^+`.&>D^&>N.&>@.&>MN&>FN&?B>&>MN&>H.&?DN&>@N&?D.&>F@#A
MGI/AGKCAGJ#AGY+AGI_AGX'AGIH`X9Z3X9ZXX9Z@X9^2X9Z?X9^!X9Z:X9ZX
MX9Z9X9^)X9ZV`.&>F>&>E.&?BP#AGI/AGKCAGIP`X9Z1X9^!`.&>@N&?DN&>
MF.&>MN&>DP#AGH#AGX3AGX?B@(OAGH[AGXGAGJ#AGY+AGISAGXGAGH``X9Z`
MX9^$X9^'XH"+X9Z8X9^)X9ZVX9Z:X9^`X9Z.X9ZVXH"+X9Z7X9ZVX9Z"XH"+
MX9Z!X9ZVX9Z$XH"+X9Z'X9Z^X9Z$`.&>D^&?D.&>FN&>G.&?@N&>GP#AGH7A
MGX;AGH[AGK;AGX8`X9Z<X9ZWX9Z%X9^2X9Z&X9ZWX9Z`X9ZV`.&>F^&?@>&>
M@0#AGH7AGX;AGI/AGKWAGI/B@(OAGH_AGKWAGJ+AGH#AGY+AGI_AGIH`X9Z9
MX9Z;X9^+X9Z6X9^2X9Z:X9Z8`.&>G.&>C^&?DN&>D.&>NP#AGH_AGKOAGIOA
MGK8`X9Z`X9ZVX9Z:X9ZWX9Z9X9ZVX9Z;X9^0X9Z9`.&>EN&>MN&>@.&?DN&>
MF>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>A>&>MN&>G^&?BP#AGJ+A
MGKSAGICAGX+AGI,`X9Z4X9Z^X9Z`XH"+XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+
MXH"+X9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z0X9^2X9Z8X9ZX`.&>E.&?DN&>
MFN&>EN&?D.&>D^&?DN&>DN*`B^&>E.&?DN&>FN&>C^&>M^&>E.&>C^&?DN&>
MC^&>M^&>@.&>MN&>F@#AGH?AGICAGY+AGIKAGK[AGI_B@(L`X9Z5X9^2X9Z?
MX9^!X9Z$X9^7`.&>A>&>D^&?DN&>F^&?A.&?AP#AGI3AGXGAGK;AGH+AGKCA
MGI_AGY+AGI#AGK;AGI,`X9Z4X9^)X9ZVX9ZAX9Z\`.&>E.&?B>&>MN&>CN&>
MMN&>F.&?B>&>M@#AGI3AGXGAGK;AGI;AGKSAGHGAGKSAGISAGJ#AGY+AGH+A
MGKCAGH[AGX$`X9Z4X9^)X9ZVX9Z:X9^)X9ZVX9Z@X9^2X9Z"X9ZVX9Z9`.&>
MEN&>MN&>@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?BP#AGI;AGK;A
MGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_AGXO"H.&?E@#AGI3AGK?A
MGI'AGI?AGY+AGH?AGK;AGI3AGXL`X9Z5X9^2X9Z;X9Z\X9Z<`.&>F.&>D^&>
MN^&>G^&?DN&>GP#AGI?AGK;AGH+AGIKAGID`X9Z2X9^2X9Z<X9Z^XH"+X9Z4
MX9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/X9ZWX9Z`X9ZVX9Z:XH"+X9Z/X9^&
MX9Z@X9^"X9Z1X9ZVX9^&(.&>EN&?@>&>F^*`B^&>A>&>O.&>FR`_`.&>G^&>
MM^&>D>&?DN&>DN&>MP#AGI_AGK?AGI'AGY+AGI+AGK<`X9Z6X9^0X9Z/X9^,
MX9Z8X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2X9Z;X9Z]
MX9Z3`.&>E.&?B>&?@>&>FN&?B>&>O`#AGJ#AGY+AGISAGKCAGIOAGKCAGI;A
MGKCAGI,`X9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1`.&>EN&>N.&>C^&>@>&>
MMN&>F>&>FN&>M^&>DP#AGI?AGKCAGH#AGI_AGX+AGIL`X9Z4X9^)X9Z\X9ZA
MX9Z\X9Z)`.&>EN&?D.&>FN&>D>&>N^&>F>&>H.&?DN&>@N&>MN&>F^&?BP#A
MGI_AGICAGY+AGI;AGK;AGI(`X9Z8X9Z^X9Z;XH"+X9Z'X9ZVXH"+XH"+XH"+
MX9Z8X9Z[X9Z3`.&>@N&>F.&?DN&>FN&?A.&>A`#AGH#AGKSAGI/AGI_AGX3B
M@(OAGI_AGK;AGI+AGK;AGIKAGH[AGX@`X9Z6X9^0X9Z:X9Z/X9Z\X9Z:X9ZX
MX9Z`X9Z\`.&>@.&>MN&>C^&>M@#AGI_AGX;AGH[AGKWAGIKB@(L`X9Z`X9Z\
MX9Z/X9ZV`.&>HN&>MN&>DP#AGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OA
MGI_AGY+AGIKAGI_AGXL`X9ZBX9Z/X9^2X9Z:X9ZVXH"+X9Z2X9^2X9Z<X9Z^
MXH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2X9Z:X9Z?X9^+PJ#AGY8`X9Z5X9^2X9Z1
MX9Z[X9Z`XH"+X9ZAX9Z^X9Z$XH"+X9Z<X9ZWX9Z)`.&>@.&?AN&>CN&>C^&?
MB^*`B^&>G^&>F.&?DN&>@N&>MN&>F^&?BP#AGIGAGH#B@(OAGH7AGX'AGHD`
MX9Z`X9^&X9Z.X9Z/X9^+XH"+X9ZAX9Z^X9Z$XH"+X9Z<X9ZWX9Z)`.&>F^&>
MD>&?DN&>DN*`B^&>E>&>FP#AGH_AGY+AGIKAGJ'AGI3AGXOB@(OAGI'AGX7B
M@(OAGH?AGICAGY+AGIKAGK[AGI\`X9Z:X9ZXX9ZBX9Z[X9Z9X9Z3X9ZXX9Z9
MX9^)X9Z[X9Z$`.*`B^&>G^&?DN&>C^&>MN&?A@#AGH_AGKWAGI/AGK;AGI'A
MGK@`X9Z:X9Z\X9Z8X9^)X9ZVX9Z3X9ZX`.&>E.&>A.&?DN&>G.&>M^&>F^*`
MB^&>D>&?A>*`B^&>AN&?DN&>G.&?@>&>A`#AGI3AGH3AGY+AGISAGK?AGIOB
M@(OAGI'AGX7B@(OAGI_AGY+AGHKAGK;AGX8`X9Z'X9Z]X9Z:XH"+X9Z*X9^!
MX9Z`PJ#AGY8`X9Z:X9Z/X9^+XH"+`.&>G^&>H.&>EN&?D.&>D^&?DN&>DN*`
MB^&>FN&>N^&>G^&?DN&>G^&?BN&>N`#AGIKAGISAGXGAGK;AGI/AGXOAGHKA
MGK8`4U-(`.&>G^&>A.&?B^*`B^&>H.&?@>&>H>&?@>&>CN&>M@#AGI_AGH3A
MGXOAGH/AGKCAGH\@X9Z3X9ZWX9Z$(.&>D^&?@>&>G.&>N.&>GP#AGI_AGH3A
MGXOAGIOAGKSAGI_AGXKAGKCAGIGAGXGAGK8`X9Z?X9Z$X9^+XH"+X9Z6X9^2
MX9Z9X9^"X9Z:(.&>D^&>M^&>A"#AGICAGKCAGH+AGKOAGIGAGJ+AGX'AGJ'A
MGKOAGH0`X9Z?X9Z$X9^+X9Z<X9ZVX9^&X9Z$X9Z?X9Z$X9^+(.&>D^&>M^&>
MA"#B@(OAGJ#AGY+AGH+AGY+AGIKAGKCAGH[AGK;AGHSAGKCAGI,`X9Z?X9ZV
MX9Z8X9Z\X9ZBX9ZV`.&>G^&>MN&>D^&?B^&>F.&?B>&>MN&>FN&>N.&>CN&>
MO`!386\@5&]M92!A;F0@4')I;F-I<&4`X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+
MXH"+X9Z4X9^*X9ZXX9Z?X9ZVX9ZBX9Z\X9Z,X9ZX`.&>FN&>@.&?DN&>G^&>
MMN*`B^*`B^&>D>&>N^&>@.*`B^*`BP#AGIKAGH#AGY+AGI_AGK;B@(OAGI'A
MGKOAGH#B@(L@X9Z'X9Z8X9^2X9Z:X9Z^X9Z?`.&>G^&?DN&>G.&?@N&>A.&>
MFN&>@`#AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI_AGY+AGISAGX+AGH3A
MGIKAGH``X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z`X9ZVX9Z;X9Z4X9Z:X9ZWX9Z%
MX9^2X9Z&X9^!X9Z1`.&>A^&?DN&>FN&>ON&>G^*`B^&>D>&>MN&?AN&>A.&>
MHN&>G^&?BP#AGH?AGY+AGIKAGK[AGI_B@(OAGH+AGY+AGICAGK;AGI,`X9Z?
MX9^!X9Z.X9^!X9Z@X9^2X9Z"X9ZVX9Z;X9^+`.&>@.&>B>&?DN&>B>&>M@#A
MGI_AGX+AGI3AGXKAGK@@X9Z3X9ZWX9Z$(.&>F.&?B>&>N^&>A.&>C^&?@>&>
MCN&?@>&>H.&?DN&>@.&?DN&>FN&>O`#AGIOAGX'AGH'B@(OAGI_AGICAGY+A
MGH+AGK;AGIOAGXL`X9Z?X9Z8X9^0X9Z9`.&>@.&?AN&>CN&>C^&?BP#AGHKA
MGX;AGJ'AGK[AGH0`X9Z?X9ZXX9Z?X9^2X9Z@X9^"X9Z;`.&>E.&>A.&?DN&>
MH.&>MN&>B0#AGI3AGH3AGY+AGIKAGKWAGHD`X9Z?X9^!X9Z:X9^)X9ZVX9ZA
MX9^!X9ZBX9Z\X9Z3`.&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>M@#AGI_AGKGA
MGH3AGY+AGJ#AGI3AGKOAGIKAGK@`X9Z1X9^&X9Z@X9^&`.&>G^&?DN&>F^&>
MO.&>G.&?B>&>MN&>@N&>N`#AGI_AGY+AGIOAGKSAGISAGXGAGK;AGI/AGK@`
MX9Z`X9^$X9^'XH"+X9Z?X9Z\X9ZAX9Z\X9Z8X9^)X9Z\X9Z3`.&>G^&>O.&>
MF.&?B>&>MN&>F^&>N`#AGJ+AGK;AGJ#AGY+AGIKAGK?AGH#B@(OB@(OAGH'A
MGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0`X9Z@X9^2X9Z?X9Z`X9Z@X9^2X9Z?
MX9^*X9ZXXH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(.&>D^&>M^&>
MA"#AGH#AGX3AGX?AGI_AGK;AGX;AGH3AGISAGK?AGH7B@(OAGH'AGK;AGH3B
M@(OAGH_AGY+AGI3AGKSAGH0`X9Z"X9Z8X9^2X9Z;X9ZVX9Z/`.&>HN&?@>&>
MG^&?B>&?DN&>E.&>MN&>B0#AGI_AGK;AGIKB@(OAGJ7AGH_B@(OAGI3AGK;A
MGI/B@(OAGH#AGK;AGIH`X9Z?X9^2X9Z:X9ZXX9Z;X9Z$X9^2X9Z`X9ZV`.&>
M@>&?DN&>D^&>MN&>C^*`B^&>@N&?AN&>FN&>O`#AGI_AGY+AGI#AGK;AGI/A
MGI?AGK;AGI8`X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z&X9Z\X9Z/`.&>
ME.&?DN&>FN&>DN&>MN&>D^*`B^&>E.&>D0#AGHKAGK;AGH#AGXOB@(OAGI_A
MGY+AGI/AGKX`X9ZBX9Z`X9^2X9Z?X9Z:XH"+X9Z/X9Z\X9Z%XH"+X9Z`X9^2
MX9Z:X9^$X9Z8`.&>A^&?A.&>@N&>A^&?D.&>F0#AGI_AGXKAGKSAGHKAGH3A
MGXL`X9Z?X9Z$X9^2X9Z!X9^!X9Z4`.&>HN&>@.&?DN&>G^&>FN*`B^&>C^&>
MO.&>A>*`B^&>F^&>O@#AGH+AGK;AGX;AGI'AGY+AGIH`X9Z?X9^*X9Z\X9Z:
MX9ZXX9Z.X9ZVX9Z8X9ZX`.&>G^&?DN&>G.&>MN&>F^&?B^&>E.&>MN&>CR#A
MGI/AGK?AGH0@X9Z@X9^2X9Z?X9Z$X9^+X9Z8X9^)X9ZVX9Z9X9^!X9Z3`.&>
MG^&?DN&>G.&>MN&>H.&?DN&>G^&?BN&>N.&>H>&>A.&?BP#AGI_AGXKAGKOA
MGIGAGJ+AGX+AGHH`X9Z?X9^2X9Z<X9^*X9ZXX9Z?`.&>G^&>MN&>DN&>MN&>
MFN&>CN&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>FN&?B>&>MN&>E.&?BR#AGI_A
MGXKAGKCAGIKAGK@`X9Z/X9ZVX9Z:X9ZVX9Z$`.&>F^&>@.&?DN&>@>&>CN&?
MB.*`B^&>G^&>F.&?DN&>E.&>C^&?DN&>C^&>M^*`B^&>C^&>MN&>FN&>MN&>
MA`#AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI_AGICAGY+AGI3AGH_AGY+AGH_A
MGK?B@(OAGIKAGI3AGI_AGXOB@(OB@(OAGH_AGK;AGIKAGK;AGH0`X9Z/X9^#
MX9Z<X9^)X9ZVX9Z3X9^+`.&>C^&>MN&>BN&>H.&?DN&>G^&?BN&>N.&>@N&>
MN.&>G^&?DN&>C^&>A.&?BP#AGI?AGK;AGIKAGH#AGK?AGH7AGY+AGH4`X9Z;
MX9^!X9Z!XH"+X9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1`.&>G^&>N.&>C^&>
MN^&>CN&?DN&>H.&>E^&>MN&>E@#AGJ+AGH_AGY+AGI#AGI3AGI$`X9Z/X9^"
MX9ZBX9Z/X9^2X9Z0X9Z4X9Z1`.&>D.&?@P#AGICAGK;AGI/B@(OAGH#AGX;A
MGJ#AGKOAGI_B@(OAGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZV
MX9Z:XH"+X9Z4X9Z$X9^2X9Z@X9ZVX9Z)XH"+X9Z5X9^2X9Z3X9^"X9Z`XH"+
MX9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'`.&>EN&?@>&>
MF^*`B^&>G.&?@>&>F^&>MN*`BP#AGI'AGY+AGIKAGH3AGXOB@(OAGI'AGY+A
MGIKAGK;AGIGB@(OB@(OB@(OB@(OAGI;AGX'AGIOB@(OB@(OAGISAGX'AGIOA
MGK;B@(L`X9Z%X9^&X9Z.X9Z$XH"+X9Z'X9Z^X9Z$`.&>D>&?A0#AGI#AGY+A
MGH3AGX/B@(OAGI/AGX'AGX<`X9Z/X9Z\X9Z@X9^2X9Z"X9^$`.&>C^&>O.&>
M@.&?@>&>H>&>MN&>HN&?BN&>O`#AGH_AGKOAGH3AGJ#AGY+AGH+AGX0`X9Z`
MX9^&X9Z6X9Z\X9Z;`.&>D>&?DN&>FN&>N.&>D^&>N.&>BN&>MN&>BB#AGI/A
MGK?AGH3B@(OB@(L@X9Z/X9Z\X9Z4X9ZVX9Z@X9^2X9Z"X9^$`.&>D>&>N^&>
MF>&>CN&?@>&>G^&?BN&>N`#AGI'AGKWAGIKAGH+AGK@`X9Z1X9Z]X9Z:X9Z"
MX9ZX("A)4T\M.#@U.2TY*0#AGI'AGKWAGH+AGICAGX'AGI/AGKCAGI_AGY+A
MGH_AGH3AGXL`X9Z`X9^$X9^'XH"+X9Z1X9Z]X9Z`(.&>D^&>M^&>A.*`BR#A
MGH#AGX/AGH#AGKSAGI\`X9Z1X9Z[X9Z9X9Z<X9^)X9ZVX9Z;X9Z[X9Z9`%52
M3`!54DPZ`.&>HN&?BN&>O.&>H.&?DN&>@N&>A.&?B^&>BN&>M@#AGJ+AGXKA
MGKOAGIGAGH#AGY+AGIKAGX+AGI,`X9Z"X9Z\X9Z?XH"+X9Z4X9Z3X9^2X9Z1
MX9ZVX9Z/X9^+XH"+X9Z`X9^2X9Z:X9^$X9Z8`.&>F.&>M^&>D^*`B^&>E.&>
MMN&>D^*`B^&>FN&?@.&>E.&>A>&?A@#AGIGAGKSAGI/AGKCAGH#AGKSAGHH@
M*%541BTX*0#AGJ+AGK;AGIKAGXGAGK;AGI3AGXOB@(OAGIKAGKWAGI@`X9Z%
MX9Z`X9^2X9Z:XH"+X9Z7X9Z6XH"+X9ZBX9Z$X9^+X9Z"X9^2X9Z;X9^!X9Z?
M`.&>G^&>H.&>FN&>BN&?DN&>B^&>HN&>MN&>F.&?@>&>FN&>M^&>@`#AGH#A
MGX3AGX?B@(OAGH;AGY+AGH3AGK;AGIGAGY?B@(OAGIKAGI3AGI_AGXOB@(OA
MGI_AGJ#AGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGICAGX'AGIKAGK?AGH``X9ZO
MX9Z`X9Z/X9ZV`.&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?BP#AGH+A
MGY+AGICAGK;AGI/B@(OAGHCAGY+AGICAGX3AGX<`X9Z2X9^2X9Z<X9Z^XH"+
MX9ZRX9^2X9Z9XH"+X9Z1X9ZVX9Z3X9^+XH"+X9Z?X9Z8X9^0X9Z9`.&>E>&?
MDN&>D>&>N^&>@.*`B^&>H>&>ON&>A`#AGJ+AGXKAGKOAGIGAGIKAGXGAGK;A
MGJ#AGY+AGH+AGK;AGID`X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^`.&>
M@.&>MN&>FN*`B^&>@N&?DN&>FN&>E.&?B^&>@N&?DN&>FN&>A.*`B^&>HN&?
MDN&>D^&>@.*`B^&>E.&?DN&>FN&>O@#AGHCAGY+AGICAGX3AGX?B@(OAGJ+A
MGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKX`X9Z(X9^2X9Z8X9^$X9^'XH"+X9ZB
MX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^PJ#AGY8`X9ZBX9^*X9Z\X9Z@X9^2
MX9Z?X9Z4X9^!X9Z"X9ZXX9Z?X9^2X9Z/X9Z$X9^+`.&>G^&>N^&>EN&>F^&>
ME^&>MN&>E@#AGH_AGICAGY+AGIOAGX,`X9Z<X9^)X9ZVX9Z3X9Z[X9Z9X9ZB
MX9ZVX9Z1X9Z[X9Z9`.&>HN&>D.&?@>&>F@#AGISAGX'AGH[AGX'AGJ#AGY+A
MGI_AGKOAGIGAGJ+AGX'AGJ'AGK8`X9Z`X9^&X9Z.X9^"`.&>@.&>MN&>FN*`
MB^&>C^&?DN&>FN&>O>&>C^*`B^&>EN&>M^&>D^&>M^&>C^&?DN&>F>*`B^&>
M@.&?AN&>CN&?@@#AGICAGK[AGIL@)7,`X9Z`X9^$X9^'XH"+X9Z<X9ZXX9Z'
MX9ZXX9Z3(.&>G^&>H.&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>F.&?@>&>FN&>
MM^&>@`#AGISAGXGAGK;AGIOAGKCAGI\@X9Z3X9ZWX9Z$(.&>H.&?DN&>G.&?
MBN&>O.*`B^&>D>&>N^&>F>&>CN&>M@#AGI;AGY+AGIKAGICAGK;AGI,`X9Z<
MX9ZWX9Z4`.&>C^&?AN&>E.&>D^&?B^&>E.&>CN&?DN&>C^&>MN&>B0#AGIKA
MGK;AGIOAGXOB@(OAGI_AGI3AGY+AGHKAGK;AGJ#AGXT`X9Z?X9Z\X9Z8XH"+
MX9Z?X9^2X9Z<X9ZVX9Z"X9Z8X9Z3X9^-`.&>G^&>O.&>F.*`B^&>G^&?DN&>
MG.&>MN&>@N&>F.&>D^&?C>*`B^&>F.&>@.*`B^&>@.&>MN&>D^&?BR`E<P#A
MGI_AGK;AGJ#AGK;AGIKAGXGAGK;B@(OAGH'AGK;AGH3B@(OAGIOAGK?AGH4`
MX9Z1X9Z1X9ZYX9Z$XH"+`.&>D>&>D>&>N>&>A"#AGY8`X9Z4X9Z)X9^2X9Z'
MX9ZXXH"+X9Z4X9^2X9Z:X9ZVX9Z0X9^2X9Z3X9ZV`.&>HN&>MN&>G^&>F>&>
MBN&?DN&>B^&>MN&>D^*`B^&>@.&>D^&?DN&>F^&?@N&>A.*`B^&>DN&?DN&>
MG.&>ON*`B^&>@.&>MN&>F@#AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OB
M@(OB@(OAGH#AGI/AGY+AGIOAGX+AGH3B@(OB@(OB@(OAGI+AGY+AGISAGK[A
MGH#AGK;AGIH`65D`65E960#AGI3AGY+AGIKAGH7AGK;AGX;AGH;AGY+AGI/A
MGK;AGX8`X9Z9X9^!X9Z8X9^"X9Z3`.&>E.&>MN&>D2_AGH7AGK;AGI\`X9Z(
MX9^2X9Z8X9^$X9^'XH"+X9Z:X9Z4X9Z?X9^+X9ZBX9^2X9Z3X9Z``.&>F>&>
MO.&>H.&?DN&>@N&?A.&>G^&?DN&>F^&>MN&>G.&>N`#AGI_AGX,`X9Z@X9^2
MX9Z?X9ZVX9^&X9Z4X9^*X9ZX`.&>H.&?DN&>G^&?BN&>N.&>F.&>E.&>MN&>
MG.&?B>&?@0!?3.&>A>&?@>&>B2``X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZV
MX9Z;X9^+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;XH"+X9Z?X9^&
MX9Z4X9Z[X9Z/X9^2X9Z:`.&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>E.&>
MA.&?DN&>@.&>ON&>C^*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>F^&>D>&?DN&>
MDN&>E>&>FP#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[AGH#B@(OA
MGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGI3AGHGAGY+AGH7AGKSAGIL`X9Z`
MX9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z^XH"+X9Z4
MX9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z6X9ZVX9Z`X9^2X9Z9X9Z4X9Z)X9^2
MX9Z'X9ZV`.&>@.&?AN&>H.&>N^&>G^*`B^&>@.&>MN&>FN*`B^&>@.&?AN&>
MCN&>C^&?B^*`B^&>FN&>A>&>D^&>MN&>G^&>F.&?DN&>EN&?D.&>D^&?DN&>
MD@#AGI3AGK;AGH_AGXOB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI3AGY+AGIKA
MGI;AGY#AGI/AGY+AGI+B@(OAGI_AGX;AGH'AGK;AGI/AGXOB@(OAGI3AGX;A
MGI7AGKOAGH\`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z1X9^2X9Z:X9Z$X9^+X9Z1
MX9^2X9Z:X9ZVX9Z9XH"+X9Z1X9ZWX9Z3X9^2X9Z3X9Z3X9^0X9Z9`.&>FN&>
M@.*`B^&>F.&>M^&>D^*`B^&>@^&>ON&>B>*`B^&>DN&>MN&>C^&>N^*`B^&>
ME.&>B>&?DN&>A>&>O.&>FP!H:`#AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;A
MGIOAGXOB@(OAGHCAGY+AGICAGX3AGX?B@(OAGICAGXGAGK;AGI_AGXKAGKCA
MGI,`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z4X9Z)X9^2X9Z%X9^!X9Z)+^&>E.&>
MB>&?DN&>A>&>O.&>FP#AGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGICAGY+AGICA
MGISAGK?AGI+AGKCB@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX4`X9Z8+N&>
MF"X`X9Z(X9^2X9Z8X9^$X9^'`.&>G^&>M^&>D>&?DN&>DN&>M^*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>BN&>M^&>G^&?@>&>D@#A
MGI?AGKCAGH#AGI_AGX+AGIL`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z6X9ZXXH"+
MX9Z%X9Z8X9^2X9Z$X9ZVX9Z9XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z6X9ZW
MX9Z2X9ZXX9Z`X9ZVX9Z:`.&>F.&>M^&>D^*`B^&>HN&>MN&>A>*`B^&>FN&>
M@.*`B^&>G^&?@>&>G.&>MN*`B^&>E.&>MN&>DP!S<P#AGH#AGX;AGJ#AGKOA
MGI_B@(OAGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI(`X9Z4X9Z:X9ZVX9Z'X9^0
MX9Z9XH"+X9Z4X9Z.X9^2X9Z*X9^$X9^'X9ZBX9ZVX9Z?X9Z3X9^2X9Z3`.&>
MF.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?B^*`B^&>@.&?AN&>H.&>N^&>
MGP#AGH+AGY+AGICAGK;AGI/B@(OAGHCAGY+AGICAGX3AGX<`=D-A<F0`````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O87)?4UDO````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8V-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]A<E]362],0U]-15-304=%4R\`````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P
M-C$`,#(P-#4Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V%R7U-9
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q-C0Q-``Q,#4Q-30S,3`V,0`P,C(Q,3(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````![````'````/0#``"G
M````S`<```````!H"@``"````&D*```%````<@H```@```!X"@``!P```($*
M```,````B0H``!\```"6"@``.0```+8*```I````\`H``!$````:"P``%@``
M`"P+```6````0PL```@```!:"P``"````&,+```5````;`L```H```"""P``
M#````(T+```&````F@L```<```"A"P``*0```*D+```"````TPL```4```#6
M"P``$````-P+```4````[0L``"\````"#```#P```#(,```F````0@P```4`
M``!I#```#0```&\,```%````?0P``!````"##```$````)0,```/````I0P`
M``L```"U#```#P```,$,```,````T0P```\```#>#```'@```.X,```A````
M#0T``"`````O#0```P```%`-```$````5`T```0```!9#0``#````%X-```*
M````:PT```4```!V#0``"@```'P-```/````APT``!(```"7#0``$````*H-
M```H````NPT```@```#D#0``$````.T-```&````_@T```<````%#@```@``
M``T.```$````$`X```\````5#@``"@```"4.```'````,`X```<````X#@``
M!````$`.```%````10X```(```!+#@``,P```$X.```S````@@X``#@```"V
M#@``,0```.\.```L````(0\```4```!.#P```@```%0/```'````5P\``!$`
M``!?#P``"````'$/```>````>@\```4```"9#P``*````)\/```I````R`\`
M`!,```#R#P``"P````80```1````$A````0````D$```#````"D0```:````
M-A```!<```!1$```%P```&D0```;````@1```!\```"=$```$P```+T0```0
M````T1```!<```#B$```!P```/H0```%`````A$```D````($0``(0```!(1
M```<````-!$```4```!1$0```P```%<1```O````6Q$``"````"+$0``)0``
M`*P1```@````TA$``"8```#S$0``#````!H2```,````)Q(```@````T$@``
M!P```#T2```&````11(```T```!,$@``"P```%H2```,````9A(```H```!S
M$@```@```'X2```&````@1(```,```"($@``10```(P2```P````TA(``!``
M```#$P``'P```!03```0````-!,```\```!%$P``!````%43```%````6A,`
M`&@!``!@$P``!P```,D4```,````T10```D```#>%```!P```.@4```+````
M\!0``!@```#\%```)@```!45```M````/!4``!````!J%0``'P```'L5```A
M````FQ4```L```"]%0``!0```,D5```5````SQ4```T```#E%0``#0```/,5
M```&`````18```8````(%@``*@````\6```+````.A8```0```!&%@``$```
M`$L6```+````7!8``!P```!H%@``#````(46```I````DA8``!$```"\%@``
M#0```,X6```#````W!8```L```#@%@``"P```.P6```*````^!8```<````#
M%P``"P````L7```(````%Q<``!`````@%P``'P```#$7```?````41<``!X`
M``!Q%P``!````)`7```(````E1<```<```">%P``#````*87```+````LQ<`
M``4```"_%P``"P```,47```/````T1<``!0```#A%P``$0```/87```E````
M"!@```4````N&```%0```#08```$````2A@```0```!/&```"P```%08```&
M````8!@```T```!G&```#0```'48```%````@Q@```8```")&```!0```)`8
M```%````EA@```(```"<&```)P```)\8```G````QQ@``"D```#O&```(```
M`!D9```<````.AD```<```!7&0``!0```%\9```&````91D```P```!L&0``
M"P```'D9```4````A1D```0```":&0``'````)\9```H````O!D```L```#E
M&0``#````/$9```1````_AD```4````0&@``#````!8:```5````(QH``!,`
M```Y&@``$0```$T:```4````7QH``!(```!T&@``&````(<:```,````H!H`
M``\```"M&@``"````+T:```'````QAH```8```#.&@``(P```-4:```;````
M^1H```4````5&P``#P```!L;```K````*QL``!T```!7&P``'P```'4;```N
M````E1L``"(```#$&P``$@```.<;```/````^AL```P````*'```!0```!<<
M```(````'1P```\````F'```#0```#8<```+````1!P```H```!0'```"```
M`%L<```&````9!P```,```!K'```)@```&\<```M````EAP```@```#$'```
M$0```,T<```/````WQP``!````#O'```!0`````=```%````!AT```$```!L
M````=````$<````)````,`````````!)`````````"D```!H````7````&4`
M``!B````)P```%<````$````+P````````!!````50```%X`````````0```
M`"L````````````````````V````:@```%D````Q````2@```$\```!2````
M``````````!"````&@````H`````````(````&8````W``````````````!3
M````9````&X````%````5@```$8```!W````&0````````!+````#P``````
M```;````5```````````````<P```&T````-`````````!\````3`````@``
M``````!O````0P`````````B````"P```'`````4````%@```&,````N````
M:0```&$````8````2````"P``````````````'D````&````8````'8````Z
M````>````%T````_````.P```$X```!Q````$0```$P````R````$@```%H`
M```.````,P```!T```!G`````````````````````````&L```!8````````
M````````````(P```!````!0```````````````U````'`````````!$````
M"```````````````.`````,`````````%P```'H````,````/````#X`````
M````*`````````!;````+0```"0```````````````````!-`````````"4`
M````````'@```$4````'````(0```%\````5````-````'4`````````>P``
M`#T```!1`````````'(````Y````)@```"H``````````#(T(&AO=7)S`$%-
M+U!-`$%D9"!P86ER`$%D9')E<W,`061D<F5S<R!";V]K`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%V86EL86)L92!F:65L
M9',Z`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N
M86UE+@!":7)T:&1A>0!#86QE;F1A<@!#86YC96P@4')O8FQE;2!297!O<G0`
M0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`0V]M:6-S`$-O;7!A;GD`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`
M1&5F875L="!)9&5N=&ET>0!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7-P
M;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M4TU"('-E<G9E<BX`1F%X`$AE;'``2&]M90!(;VUE($%D9')E<W,`2&]M92!0
M:&]N90!(;W)D90!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN`$QA;F=U86=E`$QI<W0@2&5L<"!4
M;W!I8W,`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L9',`
M365N=2!M;V1E.@!-97-S86=E`$UO;G1H;'D`3F%M90!.979E<@!.;P!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F]T97,`3TL`3W!T:6]N<P!/
M=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER`%)E
M='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE
M;2!297!O<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3=6-C97-S`%1A<VMS`%1E>'0@3VYL>0!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:71L90!54DP`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BX`56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57-E<B!/<'1I
M;VYS`%5S97)N86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EE
M<P!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF;W)M871I
M;VX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!2
M97!O<G1=`%ML:6YE("5S(&]F("5S70!N86UE`'9#87)D`%!R;VIE8W0M260M
M5F5R<VEO;CH@2$]21$4@=C(N,"XP"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP-"TS,"`Q
M,CHP,"LP,C`P"DQA<W0M5')A;G-L871O<CH@4&QA=&EN=6T@1&5V96QO<&UE
M;G0@5&5A;2`\9&5V=&5A;4!P;&%T:6YU;2US>2YN970^"DQA;F=U86=E+51E
M86TZ($%R86)I8R`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]H=&UL.R!C:&%R<V5T/4-0,3(U
M-@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`R-"#3Q]K)`.3E
MQ]''\"_A[>''\`##UMT@R^3'QNT`Q^':Y.;'Y`#/W<K1(-KDQ^;MY`#*XR#*
MS<_MSR#>[>/)(-OMT2#CWLCFX<D`RL/?[<\@Q^'8X<@@WLCA(,?AR,_!(,C:
MX^'MQ\H@Q^'5[<?DR;\`RN,@T=W6(,?ARLW>WB#CY"#'X>7F[<D@X^0@WLCA
M(,?AX\[/XR#1Q\_MYM,N`,?AS=[FX2#'X>/*YMW1R3H`W^'CR2#CT>;1(-O(
MT2#CWLCFX<D@*-_MT<CMT>;3*0#'T^,@Q^'CT\K.S^,@V\C1(./>R.;A("C?
M[='([='FTRD`[>;C(,?AX^WAQ\\`P\SDS\D`Q>';Q\$@Q^'(X<?;(-KD(./4
MW^')`,?AY<?*W2#'X<SFQ^$`Q=OAQ]X@Q^'DQ]W0R0#1T^;CQ\H`Q^'4T=_)
M`.''Q>/?Q^3MR2#AW<K-($UA:6YT96YA;F-E7U1A<VL@X>'(T>WCS"`E<P#M
MYN,@+2#1WN/MY`#MYN/M`,?ARLW>WB#'X<?=RM''UNT`U-'-(,?AX]3?X<D`
MRN,@S=W9(,?ARMW'U>WA(.'CS^W1(,?AY-G'XP#.[<?1Q\H@Q^':T=8`X<<@
MRL_.X2#CR,?4T<GP(,7A["#'X>/AW2!M86EN=&5N86YC92YP:'``Q^'(T>W/
M(,?AQ>'?RM'FY.T`X<?*YLS/(.3*Q\;,+@#.V,,`W^$@,34@S][MWLD`W^$@
M,S`@S][MWLD`W^$@-2#/WNW>R0#?X2#/SN;A`-_A(.35W2#3Q]K)`-_A(,_>
M[=[)`,/CR^')(-KA["#'X=[MXSH`X<?%X]_'Y.W)(.'AVLOFT2#:X>P@Q^'*
MW=;MX<?*+@#AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C($Q$05`N`.''Q>/?
MQ^3MR2#AX<7*U<?A(,C'X>/.S^,@4TU"+@#=Q]_3`,?AX]/'VL_)`,?AR,_'
M[<D`VN3FQ^0@Q^'CY-+A`.7'RMT@Q^'CY-+A`.7FT<_M`,/MWN;DQ\H@W=[8
M`,/MWN;DQ\H@X]H@Y-7FU0#'X<W>YN$@Q^'CT\KFT<_).B`E<P#'X<W>YN$@
MQ^'CT\KFT<_).@#'X>/.S^,@W^W1R.W1YM,@T=W6(,?ARLW>WB#CY"#'X>7F
M[<DN`,?AX=O)`-['QN/)(-KDQ^;MY"#'X>/3Q]K/R0#/SN;A`,[1YLP`U.71
M("T@T=[C[>0`Q^'(T>W/`./8Q\C>R2#'X<W>YN$`YM;:(,?AX]#?T<?*.@#1
MT\?AR0#4Y='MQ_``Q^''T^,`P\C/Q_``X<<`X<?*YLS/(./:X>;CQ\H@S>;A
M(,7:S\?/Q\H@Q^'<($944"!61E,N`.''RN;,SR#CVN'FX\?*(,WFX2#%VL_'
MS\?*(,?AW"!344P@5D93+@#AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#C
MX=W'RB!344P@5D93+@#AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB#?[='([='F
MTP#AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB!334(^`./AQ\W9Q\H`X^;'W=X`
MSNW'T<?*`./:X>;CQ\H@PL[1[`#?X>/)(,?AX]'FT0#*Y-WMT"#:X^'MQ\H@
MQ^'5[<?DR0#EQ\K=`,?AT<S'P2#*TN;MS^3'(./ASM4@Q^'CU-_AR2X`Q^'1
MS,?!(,K2YNW/Y,<@R,?3XR#'X>/3RL[/XR#FW^'CR2#'X=/1+@#4T<T@Q^'C
MU-_AR0#%TN')(,?AR^3'QNT`VN;/R2#%X>P@Q^'.[<?1Q\H`Q^'/YM$`S=W9
M(,?ASNW'T<?*`,?.RM$@Q^'=YL?5X2#AX<K'T>W..@#'SLK1(,KDT^W>(,?A
MRL?1[<XZ`,?.RM$@RN33[=X@Q^'FWLHZ`,7.RM$@S=[A[>0@X\KCQ\OA[>0N
M`,7.RM$@X=O*WR#'X>/=UN').@##T=/A(,K>T>W1Q_`@R./4W^')(,W5X<H`
MQ>7CX2#'X=7MQ^3)`,7/SL?1(,W1YMT@SL?5R0#*XR#(Y,S'S0#'X>/EX\?*
M`.35(-W>V`#MS,@@P^0@[=_FY"#ET,<@Q^'1WN,@P]_(T2#CY"#'X=7=T0#M
MS,@@P^0@RM_FY"#ET.4@Q^'>[>/)(-'>XRX`Q^'AWL@`VN3FQ^0@Q^'%Y,K1
MY.W*`.''(,7CW\?D[<D@X<K;[>W1(,?AT^/'S>W'RB#AX^'=(%9&4R`E<R\E
M<RX`X<<@Q>/?Q^3MR2#AX<7*U<?A(,CCSL_C(%-13"X`X<<@Q>/?Q^3MR2#A
MWM''P<D@X\SASR!V9G-R;V]T+@#AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3
MXR`@X^'=(,?AW"!61E,@)7,O)7,N`-OMT2#>Q\_1(-KA["#*T<SCR2#CT\KD
MSR#'X>;1SR#ET,<`RM''S-H@VN0@Q^'*V^WMT<?*`,[MQ]''RB#'X>/3RL[/
MXP#'T^,@Q^'CT\K.S^,`RN3([>4`P]/(YMKMQ_``P^7AQR#(W^,@Q>'L("5S
M`,/EX<<@YM/EX<<@)7,`VN3FQ^0@Q^':X^$`Y<?*W2#'X=KCX0#3Y,D@+2#7
MUP#3Y.;MQ_``Y-KC`.W,R"#4T<T@Q^'CU-_AR2#>R.$@Q]'3Q^$@RM[1[=''
M\"#(Y<<N`,?DRN7*(-7AQ\WMR2#'X<?*U<?A("5S+B#'X=',Q\$@Q=K'S\D@
MQ^'/SN;A+@#([<?DQ\K?.@#*XR#*S<_MRR#'X<[MQ]''R@!;RM[1[=$@Q^'C
MU-_AR5T`6\?AT]C1("5S(./D("5S70#'X<?3XP!V0V%R9```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8V%?
M15,O````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8R,0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]C85]%4R],0U]-15-304=%4R\`````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#(P-#`V
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V-A7T53+TQ#7TU%4U-!
M1T53+VAO<F1E+FUO````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,V,3(S,0`Q
M,#4Q-30S,3`V,0`P,C(P-#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````WA($E0````#&!@``'````$PV```="0``?&P`````
M``#PD```#@```/&0```/`````)$```T````0D0``"````!Z1```+````)Y$`
M``P````SD0``!````$"1```8````19$```P```!>D0``$0```&N1```E````
M?9$```\```"CD0``"P```+.1```.````OY$```4```#.D0``*````-21```(
M````_9$```H````&D@``%0```!&2```2````)Y(```L````ZD@``#@```$:2
M```*````59(```T```!@D@``+@```&Z2```.````G9(``!$```"LD@``#0``
M`+Z2```,````S)(```T```#9D@``!@```.>2```/````[I(``!@```#^D@``
M#````!>3```;````)),```X```!`DP``#@```$^3```(````7I,```D```!G
MDP``+@```'&3```:````H),``#(```"[DP``.````.Z3``!4````)Y0``%$`
M``!\E```6@```,Z4``!7````*94``#0```"!E0``"0```+:5```-````P)4`
M``<```#.E0``"@```-:5```/````X94```4```#QE0``!@```/>5```1````
M_I4```@````0E@``"0```!F6```)````(Y8``"4````ME@``(````%.6```0
M````=)8```\```"%E@``"@```)66```#````H)8```\```"DE@``%````+26
M```)````R98```T```#3E@``$@```.&6```/````])8```H````$EP``#P``
M``^7```(````'Y<``"0````HEP``%````$V7```6````8I<```@```!YEP``
M'P```(*7```9````HI<```<```"\EP``#````,27```L````T9<```X```#^
MEP```P````V8```+````$9@```<````=F```!P```"68```%````+9@```4`
M```SF```"@```#F8```#````1)@``!<```!(F```"@```&"8```/````:Y@`
M``X```![F```&````(J8```C````HY@```X```#'F```%````-:8```7````
MZY@``!<````#F0``%P```!N9```3````,YD```\```!'F0``#@```%>9```?
M````9ID``!T```"&F0``!P```*29```&````K)D```@```"SF0``#P```+R9
M```&````S)D```H```#3F0``$P```-Z9```+````\ID``!````#^F0``%0``
M``^:```5````)9H```<````[F@``$````$.:```%````5)H``!4```!:F@``
M$0```'":```,````@IH``#L```"/F@``"0```,N:```'````U9H``!0```#=
MF@```P```/*:```%````]IH``!````#\F@``"0````V;```3````%YL``#D`
M```KFP``$@```&6;```G````>)L``"P```"@FP``*@```,V;```E````^)L`
M``H````>G```!@```"F<```)````,)P```<````ZG```+P```$*<```W````
M<IP``"X```"JG```50```-F<```M````+YT``"T```!=G0``+0```(N=``!`
M````N9T``",```#ZG0``(P```!Z>```M````0IX``#,```!PG@``%0```*2>
M```9````NIX``"D```#4G@``)````/Z>```H````(Y\``!$```!,GP``"@``
M`%Z?```,````:9\```H```!VGP``$````(&?```6````DI\``!8```"IGP``
M!P```,"?```'````R)\``!0```#0GP``"@```.6?```(````\)\```@```#Y
MGP``!P````*@```'````"J````8````2H```!0```!F@```'````'Z````8`
M```GH```"````"Z@```I````-Z````X```!AH```"@```'"@```$````>Z``
M``<```"`H```"0```(B@```&````DJ```!$```"9H```!P```*N@```6````
MLZ````0```#*H```"````,^@```&````V*````T```#?H```!@```.V@```>
M````]*```!$````3H0``(@```"6A```6````2*$```@```!?H0``#0```&BA
M```,````=J$```<```"#H0```P```(NA```#````CZ$``!<```"3H0``$P``
M`*NA```=````OZ$```@```#=H0``!````.:A```(````ZZ$```@```#TH0``
M00```/VA```@````/Z(```8```!@H@``!@```&>B```5````;J(``!@```"$
MH@``(@```)VB```N````P*(``!T```#OH@``(0````VC``!4````+Z,``"D`
M``"$HP``"@```*ZC```'````N:,``!4```#!HP``#@```->C```*````YJ,`
M``\```#QHP``#0````&D```/````#Z0```T````?I```"0```"VD```4````
M-Z0```8```!,I```&````%.D```=````;*0``!,```"*I```$0```)ZD```4
M````L*0```0```#%I```!@```,JD``!4````T:0```0````FI0``#@```"NE
M```%````.J4```4```!`I0``&P```$:E```:````8J4``!$```!]I0``$0``
M`(^E```<````H:4``"H```"^I0``$````.FE```A````^J4```4````<I@``
M$P```"*F```2````-J8```H```!)I@``#P```%2F```-````9*8``!$```!R
MI@``$P```(2F```,````F*8```8```"EI@``#````*RF```&````N:8``!<`
M``#`I@``$````-BF```1````Z:8```@```#[I@``!0````2G```,````"J<`
M`!`````7IP``!0```"BG```-````+J<```8````\IP``!P```$.G```-````
M2Z<```<```!9IP``"P```&&G```'````;:<```<```!UIP``%````'VG```)
M````DJ<```H```"<IP``&0```*>G```=````P:<```P```#?IP``$````.RG
M```%````_:<``"4````#J```$@```"FH```3````/*@``"L```!0J```.P``
M`'RH```@````N*@``#8```#9J```"````!"I```,````&:D```8````FJ0``
M!````"VI```/````,JD```X```!"J0``"@```%&I```-````7*D``"$```!J
MJ0``'@```(RI```9````JZD``!X```#%J0``&P```.2I```F`````*H``!X`
M```GJ@``'````$:J```F````8ZH``#,```"*J@``)@```+ZJ```K````Y:H`
M`#@````1JP``+P```$JK```2````>JL``"D```"-JP``$@```+>K``"B````
MRJL``!8```!MK```(P```(2L```H````J*P``"D```#1K```*````/NL```?
M````)*T``"````!$K0``)0```&6M```H````BZT``#````"TK0``D@```.6M
M```A````>*X``!P```":K@``)@```+>N``!!````WJX```P````@KP``!P``
M`"VO```'````-:\```8````]KP``#0```$2O```0````4J\``!(```!CKP``
M$P```':O```2````BJ\```<```"=KP``!````*6O```0````JJ\```P```"[
MKP``#@```,BO```/````UZ\``!,```#GKP``#0```/NO```H````";````,`
M```RL```#0```#:P```&````1+```!$```!+L```%P```%VP```;````=;``
M``X```"1L````@```*"P```%````H[```!````"IL```!````+JP```-````
MO[````X```#-L````P```-RP```.````X+````@```#OL```#P```/BP```/
M````"+$```<````8L0``#0```""Q```0````+K$```L````_L0``!@```$NQ
M```,````4K$``!$```!?L0``&0```'&Q```+````B[$```T```"7L0``(@``
M`*6Q```*````R+$``!@```#3L0``&0```.RQ```6````!K(```T````=L@``
M!P```"NR```4````,[(```L```!(L@``(@```%2R```O````=[(```L```"G
ML@``"0```+.R```9````O;(```L```#7L@``%P```..R```7````^[(```D`
M```3LP``%@```!VS```/````-+,``!8```!$LP``#@```%NS```8````:K,`
M``@```"#LP``#0```(RS```F````FK,``$,```#!LP``"`````6T```2````
M#K0```@````AM```"P```"JT```O````-K0```X```!FM```!0```'6T```&
M````>[0```,```""M```!P```(:T```$````CK0```H```"3M```"@```)ZT
M```/````J;0``!````"YM```%P```,JT```1````XK0``!<```#TM```"0``
M``RU```%````%K4```L````<M0``"@```"BU```"````,[4```4````VM0``
M#0```#RU```;````2K4``!<```!FM0``"0```'ZU```.````B+4```T```"7
MM0``$@```*6U```X````N+4``"````#QM0``"````!*V```.````&[8``'L`
M```JM@``&````*:V```1````O[8```<```#1M@``!0```-FV```9````W[8`
M``<```#YM@``"`````&W```&````"K<```8````1MP``$````!BW```/````
M*;<``!`````YMP``#P```$JW```+````6K<```\```!FMP``#````':W```/
M````@[<```<```"3MP``!@```)NW```.````HK<```P```"QMP``*````+ZW
M```/````Y[<```@```#WMP``"`````"X```3````";@``!X````=N```(0``
M`#RX```@````7K@``!D```!_N```%P```)FX```E````L;@``!<```#7N```
M%@```.^X```$````!KD``!L````+N0``#0```">Y```,````-;D```,```!"
MN0``"````$:Y```*````3[D```P```!:N0``"P```&>Y```0````<[D```P`
M``"$N0``!````)&Y```3````EKD``!0```"JN0``#````+^Y```)````S+D`
M``X```#6N0``"P```.6Y```;````\;D```<````-N@``!P```!6Z```*````
M';H```T````HN@``"0```#:Z```$````0+H```4```!%N@```P```$NZ```8
M````3[H```H```!HN@``!````'.Z```F````>+H```X```"?N@``?````*ZZ
M```5````*[L```4```!!NP``!P```$>[```,````3[L```@```!<NP``"@``
M`&6[```&````<+L```@```!WNP```@```("[```&````@[L```8```"*NP``
M%````)&[```-````IKL``!````"TNP``&P```,6[```$````X;L```D```#F
MNP``$````/"[```)`````;P```D````+O```!0```!6\```:````&[P```@`
M```VO```!@```#^\```9````1KP```X```!@O```!P```&^\```'````=[P`
M``4```!_O```"0```(6\```*````C[P```(```":O```!@```)V\```-````
MI+P```D```"RO```!@```+R\```2````P[P```D```#6O```!P```."\```4
M````Z+P``!T```#]O```!@```!N]```*````(KT```0````MO0``"0```#*]
M```(````/+T``!$```!%O0``"0```%>]```&````8;T```T```!HO0``!@``
M`':]```$````?;T``#D```""O0``/0```+R]```Z````^KT``!X````UO@``
M!0```%2^```.````6KX```0```!IO@``!@```&Z^```A````=;X``!4```"7
MO@``!@```*V^```$````M+X``!$```"YO@``!@```,N^```*````TKX``"(`
M``#=O@``!`````"_```%````!;\``!T````+OP``!````"F_```,````+K\`
M``H````[OP``"````$:_```)````3[\```4```!9OP``.@```%^_```P````
MFK\``#4```#+OP``*0````'```!'````*\```#@```!SP```*0```*S````_
M````UL```"X````6P0``+0```$7!```?````<\$```\```"3P0``$@```*/!
M```+````ML$``"8```#"P0``*0```.G!```D````$\(``"8````XP@``"```
M`%_"```*````:,(```D```!SP@``!P```'W"```@````A<(``"````"FP@``
M)@```,?"```*````[L(``!D```#YP@``*0```!/#```6````/<,``!(```!4
MPP``!P```&?#```*````;\,```P```!ZPP``#P```(?#```0````E\,``$``
M``"HPP``<````.G#``!F````6L0```X```#!Q```"0```-#$```*````VL0`
M`!(```#EQ```$P```/C$```,````#,4```8````9Q0``#P```"#%```2````
M,,4``!````!#Q0``$0```%3%```<````9L4``",```"#Q0``:@```*?%```/
M````$L8```4````BQ@``$````"C&```)````.<8```0```!#Q@``"P```$C&
M```:````5,8``!0```!OQ@``#````(3&```,````D<8```\```">Q@``%0``
M`*[&```I````Q,8``"H```#NQ@``)@```!G'```G````0,<``"D```!HQP``
M*@```)+'```9````O<<``$(```#7QP``$0```!K(```2````+,@``!,````_
MR```%````%/(```/````:,@``!8```!XR```%P```(_(```0````I\@``!$`
M``"XR```-````,K(```3````_\@``!(````3R0``-0```";)```4````7,D`
M``<```!QR0``#````'G)```@````ALD``!0```"GR0``$0```+S)```7````
MSLD``!P```#FR0``$P````/*```4````%\H``!H````LR@``$0```$?*```:
M````6<H``!X```!TR@``&@```)/*```3````KLH``!4```#"R@``$0```-C*
M```4````ZLH``!<```#_R@``%0```!?+```)````+<L``!D````WRP``!```
M`%'+```'````5LL```L```!>RP``$0```&K+```&````?,L```8```"#RP``
M!@```(K+```%````D<L```<```"7RP``!P```)_+```%````I\L``!8```"M
MRP``!@```,3+```&````R\L```0```#2RP``!````-?+```'````W,L```X`
M``#DRP``#````//+```,`````,P```T````-S```"@```!O,```.````)LP`
M``4````US```*````#O,```.````9,P```P```!SS```#P```(#,```*````
MD,P```@```";S```"0```*3,```K````KLP```0```#:S```"````-_,```F
M````Z,P``!(````/S0``#P```"+-```&````,LT```H````YS0``!P```$3-
M```(````3,T``"````!5S0``"0```';-```,````@,T```T```"-S0``#@``
M`)O-```6````JLT``!$```#!S0``!@```-/-```#````VLT```8```#>S0``
M&0```.7-```'````_\T```0````'S@``"P````S.```+````&,X```<````D
MS@``!P```"S.```6````-,X```T```!+S@``#0```%G.```*````9\X``!``
M``!RS@``#P```(/.```1````D\X``!<```"ES@``"@```+W.```1````R,X`
M``@```#:S@``!````./.```/````Z,X``#H```#XS@``!0```#//```,````
M.<\``!X```!&SP``#@```&7/```0````=,\```L```"%SP``#````)'/```)
M````GL\```<```"HSP``"@```+#/```)````N\\```X```#%SP``$````-3/
M```:````Y<\```H`````T```"0````O0```*````%=````P````@T```#P``
M`"W0```(````/=````8```!&T```!P```$W0```+````5=```$<```!AT```
M#0```*G0```)````M]````0```#!T````P```,;0```3````RM```!,```#>
MT```$P```/+0```*````!M$```(````1T0``!````!31```E````&=$```,`
M```_T0``!0```$/1```J````2=$```H```!TT0``!0```'_1```$````A=$`
M``H```"*T0``#0```)71```&````H]$```@```"JT0``"````+/1```$````
MO-$```4```#!T0``:````,?1```)````,-(```P````ZT@``!0```$?2```&
M````3=(``!L```!4T@``+P```'#2```0````H-(```H```"QT@``#P```+S2
M```*````S-(```D```#7T@``$P```.'2```;````]=(``!@````1TP``%P``
M`"K3```.````0M,```,```!1TP``!P```%73```(````7=,```<```!FTP``
M"@```&[3```+````>=,```<```"%TP``40```(W3```0````W],```P```#P
MTP``#0```/W3```:````"]0``$H````FU```&0```''4```&````B]0```8`
M``"2U```!@```)G4```?````H-0```8```#`U```"0```,?4```8````T=0`
M`!<```#JU```!@````+5```-````"=4``"(````7U0``5P```#K5```3````
MDM4``",```"FU0``$P```,K5```"````WM4```L```#AU0``"````.W5```-
M````]M4```H````$U@``!P````_6```4````%]8```8````LU@``"````#/6
M```.````/-8```<```!+U@``"@```%/6```+````7M8```<```!JU@``#```
M`'+6```-````?]8```P```"-U@``"0```)K6```)````I-8```H```"NU@``
M!P```+G6```)````P=8```<```#+U@``"@```-/6```;````WM8``!(```#Z
MU@``"@````W7```)````&-<``!`````BUP``!P```#/7```2````.]<```0`
M``!.UP``!P```%/7```%````6]<```4```!AUP``"P```&?7```4````<]<`
M`!$```"(UP``&@```)K7```6````M=<``!0```#,UP``%P```.'7```8````
M^=<``!P````2V```&0```"_8```'````2=@```4```!1V```#0```%?8```,
M````9=@```@```!RV```%P```'O8```+````D]@``!,```"?V```!````+/8
M```*````N-@```0```##V```#0```,C8```,````UM@```4```#CV```"0``
M`.G8```%````\]@```<```#YV```!0````'9```$````!]D```(````,V0``
M.`````_9```L````2-D``!(```!UV0``*0```(C9```R````LMD```H```#E
MV0``+````/#9```N````'=H``#,```!,V@``,P```(#:```X````M-H```\`
M``#MV@``&````/W:```0````%ML```\````GVP``$P```#?;```5````2]L`
M`!0```!AVP``$@```';;```4````B=L``!4```">VP``+0```+3;```M````
MXML``#$````0W```+@```$+<```O````<=P``"P```"AW```8@```,[<```3
M````,=T```T```!%W0``"````%/=```(````7-T```P```!EW0``*P```'+=
M```A````GMT``!H```#`W0``"0```-O=``!%````Y=T``$$````KW@``!```
M`&W>```3````<MX``!0```"&W@``#@```)O>```3````JMX``!@```"^W@``
M!@```-?>```)````WMX```H```#HW@``#P```//>```0`````]\```<````4
MWP``#@```!S?```%````*]\``!L````QWP``"````$W?```&````5M\``!0`
M``!=WP``$0```'+?```.````A-\``#@```"3WP```@```,S?```&````S]\`
M``X```#6WP``!0```.7?```'````Z]\```X```#SWP``!@````+@```$````
M">```"D````.X```%P```#C@```?````4.```%P```!PX```%````,W@```^
M````XN```!\````AX0``$````$'A```'````4N$```X```!:X0``#````&GA
M```,````=N$``!,```"#X0``"@```)?A```=````HN$``!D```#`X0``!0``
M`-KA```1````X.$``!$```#RX0``)`````3B```5````*>(``!(````_X@``
M#@```%+B```9````8>(```@```![X@``"0```(3B```-````CN(```H```"<
MX@``!P```*?B```/````K^(```8```"_X@``"P```,;B```*````TN(```<`
M``#=X@``"````.7B```%````[N(``!\```#TX@``!@```!3C```0````&^,`
M``@````LXP``#0```#7C```(````0^,``!(```!,XP``+````%_C```:````
MC.,```D```"GXP``"@```+'C```5````O.,```4```#2XP``%````-CC```$
M````[>,``!````#RXP``!@````/D```'````"N0``!X````2Y```*````#'D
M```*````6N0``!$```!EY```&@```'?D```4````DN0```0```"GY```!```
M`*SD```+````L>0```4```"]Y```!@```,/D```(````RN0```8```#3Y```
M"@```-KD```;````Y>0``#0````!Y0``-````#;E```@````:^4``"D```",
MY0``(````+;E``!!````U^4``!H````9Y@``*````#3F```I````7>8``"(`
M``"'Y@``!@```*KF```(````L>8```4```"ZY@``"````,#F```9````R>8`
M`!D```#CY@``*@```/WF```C````*.<``"X```!,YP``-````'OG```(````
ML.<``!<```"YYP``"@```-'G```'````W.<``"$```#DYP``$`````;H```.
M````%^@```L````FZ```!P```#+H```3````.N@```@```!.Z```"P```%?H
M```*````8^@``!0```!NZ```#P```(/H```R````D^@```L```#&Z```!0``
M`-+H```%````V.@``!<```#>Z```#P```/;H```$````!ND```H````+Z0``
M"0```!;I```+````(.D```T````LZ0``#````#KI```.````1^D```4```!6
MZ0``!````%SI```-````8>D``#(```!OZ0``10```*+I```7````Z.D``!X`
M````Z@``%````!_J```%````-.H``!0````ZZ@``!P```$_J```.````5^H`
M`"D```!FZ@``!@```)#J```,````E^H```T```"DZ@``$0```++J```+````
MQ.H``#8```#0Z@``"@````?K```B````$NL```L````UZP``#P```$'K```R
M````4>L``"4```"$ZP``#@```*KK```%````N>L```X```"_ZP``$P```,[K
M```'````XNL``!$```#JZP``!P```/SK```4````!.P``!@````9[```!P``
M`#+L```%````.NP```P```!`[```#````$WL```2````6NP```0```!M[```
M!P```'+L```*````>NP```L```"%[```#````)'L```.````GNP```X```"M
M[```!0```+SL```%````PNP``"X```#([```)@```/?L```C````'NT```,`
M``!"[0``$@```$;M```&````6>T``!X```!@[0``&````'_M```E````F.T`
M``T```"^[0``"0```,SM```#````UNT```<```#:[0``"@```.+M```"````
M[>T```P```#P[0``%0```/WM```+````$^X``!D````?[@``(````#GN```2
M````6NX```4```!M[@``"@```'/N```5````?NX``!(```"4[@``#````*?N
M```$````M.X```<```"Y[@``#````,'N``!2````SNX``!<````A[P``$@``
M`#GO```'````3.\```8```!4[P``#@```%OO```,````:N\```T```!W[P``
M%0```(7O```2````F^\```\```"N[P``%````+[O```;````T^\``!````#O
M[P``:0````#P```:````:O```!<```"%\```)P```)WP```:````Q?```!<`
M``#@\```&P```/CP```9````%/$``!\````N\0``$P```$[Q```(````8O$`
M``<```!K\0``"````'/Q```)````?/$``!4```"&\0``#0```)SQ```C````
MJO$``!,```#.\0```P```.+Q``!&````YO$``#\````M\@``-P```&WR``!7
M````I?(```4```#]\@``'P````/S```O````(_,```H```!3\P``"````%[S
M```-````9_,``"T```!U\P``!````*/S``!/````J/,``"4```#X\P``'```
M`![T```+````._0``!\```!']```'0```&?T```E````A?0``"````"K]```
M)````,ST```@````\?0```L````2]0``!P```![U```-````)O4```P````T
M]0``%P```$'U```&````6?4``#D```!@]0``#````)KU```'````I_4```D`
M``"O]0``$P```+GU```)````S?4```0```#7]0``$````-SU```(````[?4`
M``@```#V]0``!````/_U```+````!/8```P````0]@``$@```!WV```1````
M,/8```P```!"]@``&@```$_V```/````:O8```<```!Z]@``#0```(+V```4
M````D/8```X```"E]@``#````+3V```;````P?8``"P```#=]@``$P````KW
M```<````'O<``"@````[]P``!@```&3W```'````:_<``!,```!S]P``!0``
M`(?W```$````C?<``!<```"2]P``"@```*KW```,````M?<```D```#"]P``
M!@```,SW```)````T_<```@```#=]P``"0```.;W```*````\/<``!$```#[
M]P``!@````WX```.````%/@```X````C^```#0```#+X```+````0/@``!T`
M``!,^```"P```&KX```"````=O@```<```!Y^```!@```('X```)````B/@`
M``<```"2^```.P```)KX```H````UO@``#0```#_^```%0```#3Y```%````
M2OD```<```!0^0``"````%CY```'````8?D```4```!I^0``!P```&_Y```.
M````=_D```D```"&^0``!@```)#Y```(````E_D```L```"@^0``!P```*SY
M```(````M/D```<```"]^0``%@```,7Y```)````W/D```8```#F^0``"P``
M`.WY```<````^?D``!0````6^@``!P```"OZ```1````,_H```@```!%^@``
M"````$[Z```0````5_H``!````!H^@``!@```'GZ```9````@/H```H```":
M^@``'````*7Z```'````POH```4```#*^@``$````-#Z```4````X?H```L`
M``#V^@``#0````+[```7````$/L```0````H^P``"0```"W[```*````-_L`
M``<```!"^P```@```$K[```.````3?L```@```!<^P``(P```&7[```X````
MB?L``#$```#"^P``)P```/3[``!D````'/P``!0```"!_```50```);\```X
M````[/P``$H````E_0``6P```'#]```H````S/T``#@```#U_0``*````"[^
M```L````5_X``!L```"$_@``/@```*#^``"I`0``W_X``",```")``$`%P``
M`*T``0!(````Q0`!`(4````.`0$`,````)0!`0!!````Q0$!`%L````'`@$`
M20```&,"`0`=````K0(!`!@```#+`@$`(0```.0"`0`?````!@,!`"L````F
M`P$`)P```%(#`0`=````>@,!`!$```"8`P$`,P```*H#`0`E````W@,!`"<`
M```$!`$`'P```"P$`0`P````3`0!`&D```!]!`$`/0```.<$`0!E````)04!
M`$T```"+!0$`+P```-D%`0`N````"08!`#`````X!@$`5````&D&`0!:````
MO@8!`$@````9!P$`2@```&('`0`R````K0<!`"\```#@!P$`+````!`(`0`M
M````/0@!`'$```!K"`$`;P```-T(`0"S````30D!`!<````!"@$`)0```!D*
M`0`R````/PH!`"D```!R"@$`/@```)P*`0`B````VPH!`%(```#^"@$`)0``
M`%$+`0`+````=PL!`+$```"#"P$`10```#4,`0`A````>PP!`#````"=#`$`
M)0```,X,`0`<````]`P!`#$````1#0$`!P```$,-`0`'````2PT!``0```!3
M#0$`#0```%@-`0`+````9@T!``X```!R#0$`"P```($-`0`%````C0T!`!``
M``"3#0$``@```*0-`0!9````IPT!``4````!#@$`$@````<.`0`$````&@X!
M``<````?#@$`"````"<.`0`%````,`X!``,````V#@$`$````#H.`0`,````
M2PX!`!,```!8#@$`#0```&P.`0`"````>@X!``<```!]#@$`!@```(4.`0`4
M````C`X!``P```"A#@$`&````*X.`0`&````QPX!`!(```#.#@$`#````.$.
M`0`#````[@X!`"H```#R#@$`!````!T/`0`&````(@\!``<````I#P$`'P``
M`#$/`0`U````40\!`"X```"'#P$`+P```+8/`0`7````Y@\!`"````#^#P$`
M&P```!\0`0`8````.Q`!`"0```!4$`$`'P```'D0`0`:````F1`!`"$```"T
M$`$`(````-80`0`:````]Q`!`#(````2$0$`+P```$41`0`K````=1$!`!\`
M``"A$0$`(P```,$1`0`?````Y1$!`!H````%$@$`(0```"`2`0`E````0A(!
M`"8```!H$@$`)0```(\2`0`D````M1(!`!@```#:$@$`'0```/,2`0`D````
M$1,!`!@````V$P$`(@```$\3`0`L````<A,!`"\```"?$P$`%0```,\3`0`E
M````Y1,!`#P````+%`$`'P```$@4`0`C````:!0!`!\```",%`$`(````*P4
M`0`:````S10!`!@```#H%`$`)@````$5`0`>````*!4!`"D```!'%0$`'@``
M`'$5`0`Q````D!4!``D```#"%0$`#````,P5`0`7````V14!`"\```#Q%0$`
M)````"$6`0`'````1A8!``\```!.%@$`%````%X6`0`.````<Q8!``T```""
M%@$`)````)`6`0`%````M18!``<```"[%@$`(@```,,6`0`E````YA8!`!H`
M```,%P$`'0```"<7`0`:````11<!``<```!@%P$`QP```&@7`0`+````,!@!
M`!4````\&`$`!@```%(8`0`)````61@!``L```!C&`$`%P```&\8`0`&````
MAQ@!`#,```".&`$`$P```,(8`0`3````UA@!``<```#J&`$`#P```/(8`0`'
M`````AD!`#(````*&0$`(0```#T9`0`3````7QD!``P```!S&0$`$0```(`9
M`0`R````DAD!``@```#%&0$`"0```,X9`0`*````V!D!`!0```#C&0$`"@``
M`/@9`0`=`````QH!``@````A&@$`'P```"H:`0`(````2AH!`!H```!3&@$`
M)P```&X:`0`&````EAH!`!4```"=&@$`!P```+,:`0`(````NQH!``D```#$
M&@$`/P```,X:`0`'````#AL!``\````6&P$`#@```"8;`0`0````-1L!``D`
M``!&&P$`"0```%`;`0`(````6AL!`!,```!C&P$`!P```'<;`0`9````?QL!
M``H```"9&P$`%P```*0;`0`4````O!L!``H```#1&P$`#````-P;`0`7````
MZ1L!``0````!'`$`*@````8<`0`1````,1P!``<```!#'`$``@```$L<`0`0
M````3AP!`!@```!?'`$`"P```'@<`0`#````A!P!``@```"('`$`!@```)$<
M`0`'````F!P!``T```"@'`$`"P```*X<`0`4````NAP!`!4```#/'`$`#@``
M`.4<`0`O````]!P!`"`````D'0$`'````$4=`0`,````8AT!`#$```!O'0$`
M!0```*$=`0`2````IQT!`#\```"Z'0$`$@```/H=`0`*````#1X!``8````8
M'@$`!````!\>`0`$````)!X!``H````I'@$`$P```#0>`0`%````2!X!``8`
M``!.'@$`!@```%4>`0`$````7!X!``P```!A'@$`"@```&X>`0`%````>1X!
M`!@```!_'@$`&0```)@>`0`?````LAX!`!T```#2'@$`$0```/`>`0`"````
M`A\!``0````%'P$`"@````H?`0`&````%1\!``4````<'P$``P```"(?`0`,
M````)A\!`$4````S'P$`&@```'D?`0`H````E!\!`%,```"]'P$`&0```!$@
M`0!R````*R`!`"````">(`$`-0```+\@`0`A````]2`!`$4````7(0$`,```
M`%TA`0`H````CB$!`"D```"W(0$`)@```.$A`0`E````""(!`"@````N(@$`
M*````%<B`0`B````@"(!`#````"C(@$`$@```-0B`0`3````YR(!`!````#[
M(@$`>0````PC`0`)````AB,!`',```"0(P$`?`````0D`0`K````@20!`%0`
M``"M)`$`%P````(E`0`6````&B4!``\````Q)0$`'P```$$E`0!`````824!
M`!\```"B)0$`'````,(E`0!1````WR4!`!0````Q)@$`"@```$8F`0`%````
M428!``8```!7)@$`"````%XF`0`%````9R8!`!(```!M)@$`$````(`F`0`3
M````D28!`!T```"E)@$`#P```,,F`0`/````TR8!``0```#C)@$`"0```.@F
M`0`+````\B8!``<```#^)@$`!0````8G`0`4````#"<!``<````A)P$`"```
M`"DG`0`/````,B<!``@```!")P$`#````$LG`0`/````6"<!``8```!H)P$`
M%````&\G`0`&````A"<!``P```"+)P$`"````)@G`0`$````H2<!``H```"F
M)P$`!P```+$G`0`$````N2<!`!D```"^)P$``@```-@G`0`"````VR<!``D`
M``#>)P$`!@```.@G`0`&````[R<!`"<```#V)P$``@```!XH`0`$````(2@!
M``\````F*`$`$P```#8H`0`'````2B@!``<```!2*`$`!@```%HH`0`&````
M82@!`!````!H*`$`$@```'DH`0`"````C"@!``8```"/*`$`"0```)8H`0`B
M````H"@!``<```##*`$`!P```,LH`0`+````TR@!``4```#?*`$``@```.4H
M`0`+````Z"@!`%T!``#T*`$`#````%(J`0`2````7RH!``P```!R*@$`!@``
M`'\J`0`&````ABH!``8```"-*@$``@```)0J`0`8````ERH!``H```"P*@$`
M$0```+LJ`0`L````S2H!`!8```#Z*@$`"0```!$K`0`4````&RL!``4````P
M*P$`*@```#8K`0`2````82L!``H```!T*P$`&P```'\K`0`/````FRL!``L`
M``"K*P$`$````+<K`0`)````R"L!`!(```#2*P$`,P```.4K`0`.````&2P!
M`!@````H+`$`#````$$L`0`3````3BP!`!<```!B+`$`!@```'HL`0`/````
M@2P!`!4```"1+`$`$0```*<L`0`;````N2P!`!(```#5+`$`$@```.@L`0`(
M````^RP!``D````$+0$`.@````XM`0`B````22T!`#D```!L+0$`0P```*8M
M`0!E````ZBT!`&(```!0+@$`:P```+,N`0!H````'R\!`#L```"(+P$`#@``
M`,0O`0`3````TR\!``T```#G+P$`#P```/4O`0`6````!3`!``4````<,`$`
M"0```"(P`0`3````+#`!``T```!`,`$`&0```$XP`0`7````:#`!`"\```"`
M,`$`*@```+`P`0`6````VS`!`!````#R,`$`$`````,Q`0`&````%#$!`!D`
M```;,0$`(@```#4Q`0`5````6#$!`!(```!N,0$`'0```($Q`0`5````GS$!
M`!,```"U,0$`%````,DQ`0`2````WC$!`#(```#Q,0$`(````"0R`0`D````
M13(!`!````!J,@$`(@```'LR`0`J````GC(!``8```#),@$`$@```-`R`0!`
M````XS(!``T````D,P$`!P```#(S`0`*````.C,!``<```!%,P$`!P```$TS
M`0`%````53,!``<```!;,P$`"@```&,S`0`$````;C,!`!P```!S,P$`#@``
M`)`S`0`1````GS,!`!,```"Q,P$`%0```,4S`0`Y````VS,!``L````5-`$`
M%0```"$T`0`<````-S0!`!P```!4-`$`'@```'$T`0`7````D#0!`!````"H
M-`$`#P```+DT`0`C````R30!`"$```#M-`$`!P````\U`0`&````%S4!``@`
M```>-0$`%0```"<U`0`(````/34!``D```!&-0$`$0```%`U`0`)````8C4!
M`!0```!L-0$`%@```($U`0`J````F#4!``<```##-0$`#P```,LU`0`%````
MVS4!`!0```#A-0$`#P```/8U`0`.````!C8!`"H````5-@$`"0```$`V`0`'
M````2C8!`!(```!2-@$``P```&4V`0`%````:38!`!(```!O-@$`#````((V
M`0`9````CS8!`$$```"I-@$`%0```.LV`0`K`````3<!`#0````M-P$`,@``
M`&(W`0`U````E3<!``@```#+-P$`!0```-0W`0`)````VC<!``<```#D-P$`
M-P```.PW`0`V````)#@!`#8```!;.`$`8P```)(X`0`U````]C@!`#4````L
M.0$`-0```&(Y`0!/````F#D!`"X```#H.0$`,0```!<Z`0`U````23H!`#L`
M``!_.@$`*````+LZ`0`K````Y#H!`"X````0.P$`/````#\[`0`\````?#L!
M`!(```"Y.P$`"P```,P[`0`,````V#L!``0```#E.P$`#@```.H[`0`@````
M^3L!`"$````:/`$`!P```#P\`0`'````1#P!`!0```!,/`$`"P```&$\`0`(
M````;3P!``H```!V/`$`"P```($\`0`'````C3P!``8```"5/`$`!0```)P\
M`0`(````HCP!``8```"K/`$`"@```+(\`0`Q````O3P!`!,```#O/`$`#0``
M``,]`0`'````$3T!``<````9/0$`"0```"$]`0`'````*ST!`!$````S/0$`
M"````$4]`0`4````3CT!``8```!C/0$`"````&H]`0`(````<ST!``X```!\
M/0$`!@```(L]`0`F````DCT!`!$```"Y/0$`)P```,L]`0`0````\ST!``@`
M```$/@$`#@````T^`0`,````'#X!``<````I/@$``P```#$^`0`#````-3X!
M`!L````Y/@$`%P```%4^`0`_````;3X!``D```"M/@$`!0```+<^`0`(````
MO3X!``<```#&/@$`:@```,X^`0`Q````.3\!``8```!K/P$`"@```'(_`0`B
M````?3\!`"````"@/P$`)P```,$_`0`T````Z3\!`"4````>0`$`*@```$1`
M`0!P````;T`!`#0```#@0`$`"````!5!`0`(````'D$!`!8````G00$`#```
M`#Y!`0`-````2T$!`!0```!900$`$P```&Y!`0`7````@D$!`!4```":00$`
M#0```+!!`0`4````OD$!``<```#300$`&````-M!`0`;````]$$!`!8````0
M0@$`%@```"="`0`:````/D(!``0```!90@$`!@```%Y"`0!V````94(!``0`
M``#<0@$`%````.%"`0`$````]D(!``0```#[0@$`&@````!#`0`8````&T,!
M`!0````T0P$`%````$E#`0`D````7D,!`#D```"#0P$`$0```+U#`0`M````
MST,!``@```#]0P$`(0````9$`0`4````*$0!`!`````]1`$`'0```$Y$`0`7
M````;$0!`!,```"$1`$`$P```)A$`0`1````K$0!``8```"^1`$`%0```,5$
M`0`)````VT0!`!@```#E1`$`%P```/Y$`0`.````%D4!``@````E10$`!0``
M`"Y%`0`1````-$4!`!$```!&10$`"0```%A%`0`6````8D4!``8```!Y10$`
M!0```(!%`0`'````AD4!``D```".10$`"````)A%`0`'````H44!``D```"I
M10$`%P```+-%`0`*````RT4!``H```#610$`&P```.%%`0`E````_44!``P`
M```C1@$`&````#!&`0`%````248!`"````!/1@$`)0```'!&`0`E````ED8!
M`#D```"\1@$`1@```/9&`0`U````/4<!`$4```!S1P$`"0```+E'`0`*````
MPT<!``8```#.1P$`!@```-5'`0`8````W$<!``\```#U1P$`"@````5(`0`-
M````$$@!`"@````>2`$`*````$=(`0`@````<$@!`"D```"12`$`(````+M(
M`0`Q````W$@!`"D````.20$`)@```#A)`0`S````7TD!`#X```"320$`,@``
M`-))`0`U````!4H!`$0````[2@$`/0```(!*`0`7````ODH!`#H```#62@$`
M&````!%+`0#,````*DL!`!\```#W2P$`,0```!=,`0`T````24P!`#8```!^
M3`$`-@```+5,`0`H````[$P!`"<````530$`,@```#U-`0`U````<$T!`$@`
M``"F30$`H````.]-`0`F````D$X!`"D```"W3@$`-@```.%.`0!C````&$\!
M``P```!\3P$`!````(E/`0`&````CD\!``4```"53P$`#P```)M/`0`2````
MJT\!`!$```"^3P$`%````-!/`0`>````Y4\!``<````$4`$`!`````Q0`0`/
M````$5`!``P````A4`$`$````"Y0`0`,````/U`!`!````!,4`$`#````%U0
M`0!*````:E`!``@```"U4`$`%````+Y0`0`%````TU`!`!(```#94`$`&```
M`.Q0`0`;````!5$!``\````A40$``@```#%1`0`*````-%$!`!4````_40$`
M!````%51`0`2````6E$!`!````!M40$``P```'Y1`0`0````@E$!``@```"3
M40$`$````)Q1`0`0````K5$!``T```"^40$`$P```,Q1`0`8````X%$!``L`
M``#Y40$`"`````52`0`-````#E(!``\````<4@$`&P```"Q2`0`/````2%(!
M`!````!84@$`*@```&E2`0`-````E%(!`"(```"B4@$`&@```,52`0`7````
MX%(!`!(```#X4@$`"0````M3`0`5````%5,!``H````K4P$`+P```#93`0`W
M````9E,!``\```">4P$`#@```*Y3`0`B````O5,!`!````#@4P$`$@```/%3
M`0`3````!%0!``D````85`$`*@```")4`0`8````350!`!@```!F5`$`%P``
M`']4`0`7````EU0!``@```"O5`$`#@```+A4`0`H````QU0!`%0```#P5`$`
M"````$55`0`4````3E4!``L```!C50$`#@```&]5`0`[````?E4!`!(```"Z
M50$`!P```,U5`0`1````U54!``,```#G50$`!P```.M5`0`%````\U4!``H`
M``#Y50$`"@````16`0`,````#U8!``X````<5@$`%````"M6`0`1````0%8!
M`!0```!25@$`"````&=6`0`&````<%8!``L```!W5@$`"@```(-6`0`(````
MCE8!`!$```"75@$`$@```*E6`0`K````O%8!`"$```#H5@$`"@````I7`0`2
M````%5<!`!(````H5P$`&@```#M7`0!%````5E<!`#4```"<5P$`$P```-)7
M`0`0````YE<!`)0```#W5P$`(@```(Q8`0`1````KU@!``<```#!6`$`!0``
M`,E8`0`P````SU@!``<`````60$`!P````A9`0`%````$%D!``8````660$`
M#@```!U9`0`-````+%D!``X````Z60$`#0```$E9`0`4````5UD!``\```!L
M60$`"@```'Q9`0`1````AUD!``<```"960$`"0```*%9`0`9````JUD!``X`
M``#%60$`+P```-19`0`1````!%H!``@````66@$`$P```!]:`0`B````,UH!
M`"D```!66@$`+0```(!:`0`L````KEH!`!T```#;6@$`'````/E:`0`K````
M%EL!`"````!"6P$`&P```&-;`0`$````?UL!`!D```"$6P$`"P```)Y;`0`4
M````JEL!``,```"_6P$`!@```,-;`0`+````REL!``P```#66P$`#0```.-;
M`0`2````\5L!``\````$7`$`!````!1<`0`;````&5P!`!P````U7`$`#P``
M`%)<`0`.````8EP!`!$```!Q7`$`$@```(-<`0`:````EEP!``<```"Q7`$`
M"0```+E<`0`.````PUP!``P```#27`$`"@```-]<`0`(````ZEP!``P```#S
M7`$`!0````!=`0`9````!ET!`!`````@70$`!@```#%=`0`M````.%T!``X`
M``!F70$`E@```'5=`0`;````#%X!``H````H7@$`!````#->`0`.````.%X!
M``4```!'7@$`!P```$U>`0`&````55X!``P```!<7@$``P```&E>`0`%````
M;5X!``8```!S7@$`%````'I>`0`0````CUX!`!(```"@7@$`'````+->`0`&
M````T%X!``<```#77@$`$P```-]>`0`+````\UX!``L```#_7@$`!0````M?
M`0`H````$5\!``<````Z7P$`!@```$)?`0`<````25\!``P```!F7P$`!P``
M`'-?`0`(````>U\!``4```"$7P$`"0```(I?`0`+````E%\!``8```"@7P$`
M!0```*=?`0`/````K5\!`!````"]7P$`!@```,Y?`0`1````U5\!``H```#G
M7P$`!P```/)?`0`/````^E\!`"P````*8`$`!0```#=@`0`)````/6`!``0`
M``!'8`$`"0```$Q@`0`(````5F`!`!<```!?8`$`$P```'=@`0`&````BV`!
M``T```"28`$`!@```*!@`0`$````IV`!`#D```"L8`$`.P```.9@`0`X````
M(F$!`",```!;80$`!0```']A`0`1````A6$!``<```"780$`"0```)]A`0`;
M````J6$!`!4```#%80$`!@```-MA`0`%````XF$!`!P```#H80$`$0````5B
M`0`)````%V(!`!T````A8@$``P```#]B`0`%````0V(!`"8```!)8@$`!0``
M`'!B`0`1````=F(!`!(```"(8@$`"````)MB`0`)````I&(!``4```"N8@$`
M0P```+1B`0!'````^&(!`$8```!`8P$`,0```(=C`0!$````N6,!`$0```#^
M8P$`+P```$-D`0!4````<V0!`#(```#(9`$`-@```/MD`0`M````,F4!`!$`
M``!@90$`%0```')E`0`,````B&4!`"X```"590$`(````,1E`0`>````Y64!
M`!T````$9@$`!P```")F`0`(````*F8!``H````S9@$`!P```#YF`0`F````
M1F8!`"D```!M9@$`0````)=F`0`)````V&8!`!\```#B9@$`+P````)G`0`9
M````,F<!`!<```!,9P$`"````&1G`0`,````;6<!``P```!Z9P$`#P```(=G
M`0`0````EV<!`$````"H9P$`D0```.EG`0!M````>V@!`"(```#I:`$`$```
M``QI`0`1````'6D!`!0````O:0$`%0```$1I`0`4````6FD!``<```!O:0$`
M$@```'=I`0`1````BFD!`!````"<:0$`%P```*UI`0`T````Q6D!`"H```#Z
M:0$`E@```"5J`0`3````O&H!``4```#0:@$`$P```-9J`0`)````ZFH!``H`
M``#T:@$`"@```/]J`0`:````"FL!`!L````E:P$`$P```$%K`0`2````56L!
M`!,```!H:P$`&@```'QK`0`L````EVL!`"T```#$:P$`*0```/)K`0`K````
M'&P!`"L```!(;`$`+````'1L`0`:````H6P!`(0```"\;`$`&@```$%M`0`;
M````7&T!`!H```!X;0$`&P```)-M`0`1````KVT!`!H```#!;0$`&P```-QM
M`0`7````^&T!`!@````0;@$`+P```"EN`0`8````66X!`!@```!R;@$`1```
M`(MN`0`3````T&X!``P```#D;@$`&````/%N`0`M````"F\!`!0````X;P$`
M(P```$UO`0`J````<6\!`"0```"<;P$`(0```,%O`0`E````XV\!`"X````)
M<`$`&0```#AP`0`T````4G`!`#L```"'<`$`)````,-P`0`L````Z'`!`"$`
M```5<0$`&````#=Q`0`?````4'$!`!\```!P<0$`(0```)!Q`0`)````LG$!
M`!L```"\<0$`!````-AQ`0`'````W7$!``L```#E<0$`$@```/%Q`0`&````
M!'(!``<````+<@$`!P```!-R`0`&````&W(!``<````B<@$`!0```"IR`0`$
M````,'(!`!4````U<@$`!@```$MR`0`(````4G(!``8```!;<@$`!````&)R
M`0`*````9W(!`!0```!R<@$`'````(=R`0`7````I'(!`!4```"\<@$`"@``
M`-)R`0`;````W7(!``4```#Y<@$`,````/]R`0`.````,',!`!`````_<P$`
M&P```%!S`0`3````;',!``T```"`<P$`#0```(YS`0`W````G',!``0```#4
M<P$`"````-ES`0`G````XG,!`!,````*=`$`#@```!YT`0`&````+70!``P`
M```T=`$`!@```$%T`0`&````2'0!`"4```!/=`$`#@```'5T`0`,````A'0!
M`!8```"1=`$`%````*AT`0`:````O70!`!$```#8=`$`!P```.IT`0`$````
M\G0!``<```#W=`$`*@```/]T`0`%````*G4!``@````P=0$`$@```#EU`0`4
M````3'4!``<```!A=0$`!P```&EU`0`%````<74!``T```!W=0$`#````(5U
M`0`+````DG4!`!H```">=0$`%P```+EU`0`,````T74!`!8```#>=0$`#```
M`/5U`0`2`````G8!``@````5=@$`!@```!YV`0`8````)78!`$0````^=@$`
M"````(-V`0`,````C'8!`"<```"9=@$`&@```,%V`0`9````W'8!`!(```#V
M=@$`#`````EW`0`)````%G<!``<````@=P$`"@```"AW`0`)````,W<!``X`
M```]=P$`$````$QW`0`F````77<!``P```"$=P$`"````)%W`0`3````FG<!
M``P```"N=P$`#0```+MW`0`(````R7<!`!````#2=P$`!````.-W`0`9````
MZ'<!`&8````">`$`%@```&EX`0`*````@'@!``0```"+>`$`!````)!X`0`9
M````E7@!`!H```"O>`$`&P```,IX`0`)````YG@!``(```#P>`$`!````/-X
M`0`I````^'@!``,````B>0$`!0```"9Y`0`H````+'D!``H```!5>0$`!0``
M`&!Y`0`1````9GD!`!<```!X>0$`&@```)!Y`0`&````JWD!``@```"R>0$`
M"````+MY`0`$````Q'D!``4```#)>0$`?0```,]Y`0`*````37H!``T```!8
M>@$`!````&9Z`0`%````:WH!`"D```!Q>@$`-P```)MZ`0`.````TWH!``D`
M``#B>@$`%@```.QZ`0`*`````WL!``<````.>P$`%````!9[`0`R````*WL!
M`"T```!>>P$`+````(Q[`0`/````N7L!``0```#)>P$`!P```,Y[`0`(````
MUGL!``<```#?>P$`#@```.=[`0`3````]GL!``@````*?`$`8P```!-\`0`1
M````=WP!`!$```")?`$`#@```)M\`0`A````JGP!`%D```#,?`$`*@```"9]
M`0`&````47T!``8```!8?0$`!0```%]]`0`>````97T!``8```"$?0$`"@``
M`(M]`0`M````EGT!`"P```#$?0$`!P```/%]`0`+````^7T!`"T````%?@$`
M40```#-^`0`C````A7X!`#4```"I?@$`(````-]^`0`#`````'\!``P````$
M?P$`!P```!%_`0`/````&7\!`!`````I?P$`!0```#I_`0`6````0'\!``8`
M``!7?P$`"````%Y_`0`)````9W\!``L```!Q?P$`"@```'U_`0`,````B'\!
M``8```"5?P$`&0```)Q_`0`9````MG\!`!H```#0?P$`#P```.M_`0`2````
M^W\!`!`````.@`$`#P```!^``0`/````+X`!``\````_@`$`"````$^``0`R
M````6(`!`!$```"+@`$`#0```)V``0`-````JX`!`!8```"Y@`$`!P```-"`
M`0`7````V(`!``,```#P@`$`!P```/2``0`%````_(`!``4````"@0$`#0``
M``B!`0`5````%H$!`!0````L@0$`(@```$&!`0`C````9($!`!P```"(@0$`
M'````*6!`0`@````PH$!`"0```#C@0$`'P````B"`0`%````*((!``,````N
M@@$`#@```#*"`0`.````08(!``H```!0@@$`&P```%N"`0`,````=X(!`!D`
M``"$@@$`"0```)Z"`0`2````J((!``<```"[@@$`$````,."`0`0````U((!
M``@```#E@@$`"0```.Z"`0`%````^((!``<```#^@@$``P````:#`0`$````
M"H,!``(````/@P$`1````!*#`0`U````5X,!`!L```"-@P$`+P```*F#`0`_
M````V8,!``T````9A`$`+@```">$`0`W````5H0!`$````".A`$`0````,^$
M`0!'````$(4!`!````!8A0$`(0```&F%`0`;````BX4!`!D```"GA0$`'0``
M`,&%`0`?````WX4!`!X```#_A0$`&P```!Z&`0`>````.H8!`",```!9A@$`
M/````'V&`0`\````NH8!`$````#WA@$`/P```#B'`0`^````>(<!`#L```"W
MAP$`;````/.'`0`8````8(@!`",```!YB`$`#````)V(`0`+````JH@!`!@`
M``"VB`$`/0```,^(`0`Q````#8D!`",````_B0$`#````&.)`0!0````<(D!
M`$<```#!B0$``P````F*`0`1````#8H!`!0````?B@$`#P```#2*`0`.````
M1(H!`!@```!3B@$`!P```&R*`0`*````=(H!``@```!_B@$`$@```(B*`0`/
M````FXH!``H```"KB@$`"@```+:*`0`%````P8H!`"<```#'B@$`"````.^*
M`0`&````^(H!`!,```#_B@$`$@```!.+`0`/````)HL!`%<````VBP$`!P``
M`(Z+`0`'````EHL!`!0```">BP$`!0```+.+`0`'````N8L!`!0```#!BP$`
M!P```-:+`0`$````WHL!`#\```#CBP$`&````".,`0`N````/(P!`((```!K
MC`$`&@```.Z,`0!+````"8T!`"<```!5C0$`$````'V-`0`'````CHT!``P`
M``"6C0$`#P```*.-`0`,````LXT!`!0```#`C0$`$@```-6-`0`>````Z(T!
M`!L````'C@$`!0```"..`0`0````*8X!`!<````ZC@$`)@```%*.`0`5````
M>8X!`!8```"/C@$`$````*:.`0`?````MXX!``@```#7C@$`%@```.".`0`0
M````]XX!``\````(CP$`$````!B/`0`8````*8\!``P```!"CP$`$@```$^/
M`0`7````8H\!``D```!ZCP$`"````(2/`0`%````C8\!`!D```"3CP$`!@``
M`*V/`0`1````M(\!``@```#&CP$`%0```,^/`0`+````Y8\!`!8```#QCP$`
M.@````B0`0`;````0Y`!``P```!?D`$`#0```&R0`0`B````>I`!``@```"=
MD`$`&@```*:0`0`$````P9`!``\```#&D`$`!````-:0`0`+````VY`!`",`
M``#GD`$`/P````N1`0`&````2Y$!``X```!2D0$`&0```&&1`0`/````>Y$!
M``0```"+D0$`%````)"1`0`)````I9$!``<```"OD0$`!0```+>1`0`(````
MO9$!``8```#&D0$`!@```,V1`0`4````U)$!`"P```#ID0$`+P```!:2`0`:
M````1I(!`"D```!AD@$`'P```(N2`0`\````JY(!`!H```#HD@$`(P````.3
M`0`M````)Y,!`"4```!5DP$`!P```'N3`0`(````@Y,!``D```",DP$`"```
M`):3`0`<````GY,!`!L```"\DP$`+````-B3`0`P````!90!`#@````VE`$`
M0````&^4`0`'````L)0!`!H```"XE`$`"0```-.4`0`4````W90!`#4```#R
ME`$`#P```"B5`0`4````.)4!``P```!-E0$`"````%J5`0`7````8Y4!``D`
M``![E0$`#@```(65`0`,````E)4!`!D```"AE0$`&@```+N5`0!`````UI4!
M``L````7E@$`!0```".6`0`(````*98!`!D````RE@$`$````$R6`0`%````
M798!`!0```!CE@$`$0```'B6`0`&````BI8!``L```"1E@$`"````)V6`0`.
M````II8!``<```"UE@$`!@```+V6`0`4````Q)8!`$,```#9E@$`:````!V7
M`0`<````AI<!`"@```"CEP$`)0```,R7`0`1````\I<!`!8````$F`$`"@``
M`!N8`0`0````)I@!`"D````WF`$`"````&&8`0`-````:I@!`!````!XF`$`
M%@```(F8`0`3````H)@!`$$```"TF`$`"P```/:8`0`A`````ID!`!$````D
MF0$`%0```#:9`0!!````3)D!`"4```".F0$`$````+29`0`(````Q9D!`!@`
M``#.F0$`&````.>9`0`)`````)H!``\````*F@$`!@```!J:`0`9````(9H!
M`"0````[F@$`!P```&":`0`%````:)H!``\```!NF@$`$@```'Z:`0`8````
MD9H!``8```"JF@$`!P```+&:`0`)````N9H!`!(```##F@$`$````-::`0`5
M````YYH!`!4```#]F@$`!@```!.;`0`&````&IL!`#,````AFP$`)P```%6;
M`0`D````?9L!``@```"BFP$`#P```*N;`0`&````NYL!`"(```#"FP$`&@``
M`.6;`0`G`````)P!``\````HG`$`%@```#B<`0`#````3YP!``0```!3G`$`
M%@```%B<`0`#````;YP!``P```!SG`$`&0```("<`0`+````FIP!`!@```"F
MG`$`'@```+^<`0`3````WIP!``4```#RG`$`"@```/B<`0`3`````YT!`!8`
M```7G0$`#@```"Z=`0`$````/9T!``<```!"G0$`$````$J=`0!;````6YT!
M`"$```"WG0$`$P```-F=`0`'````[9T!``4```#UG0$`#P```/N=`0`6````
M"YX!`!0````BG@$`)@```#>>`0`=````7IX!`!<```!\G@$`*````)2>`0`I
M````O9X!`!8```#GG@$`=````/Z>`0`F````<Y\!`"$```":GP$`+P```+R?
M`0`E````[)\!`"`````2H`$`)P```#.@`0`D````6Z`!`!X```"`H`$`'P``
M`)^@`0`*````OZ`!``<```#*H`$`"````-*@`0`(````VZ`!`!,```#DH`$`
M#P```/B@`0`^````"*$!`"4```!'H0$`"````&VA`0!/````=J$!`$````#&
MH0$`20````>B`0!W````4:(!``P```#)H@$`,P```-:B`0`V````"J,!``H`
M``!!HP$`!P```$RC`0`*````5*,!`#\```!?HP$`!@```)^C`0`^````IJ,!
M`#D```#EHP$`)@```!^D`0`4````1J0!`#D```!;I`$`*P```)6D`0`Q````
MP:0!`"<```#SI`$`+P```!NE`0`H````2Z4!`!$```!TI0$`!P```(:E`0`6
M````CJ4!`!,```"EI0$`%````+FE`0`&````SJ4!`#````#5I0$`#`````:F
M`0`0````$Z8!``D````DI@$`%@```"ZF`0`(````1:8!``0```!.I@$`$```
M`%.F`0`*````9*8!``D```!OI@$`!@```'FF`0`,````@*8!``T```"-I@$`
M'````)NF`0`9````N*8!``X```#2I@$`'P```.&F`0`,`````:<!``<````.
MIP$`$````!:G`0`I````)Z<!``\```!1IP$`"@```&&G`0`8````;*<!`"P`
M``"%IP$`#0```+*G`0`=````P*<!`#(```#>IP$`"0```!&H`0`'````&Z@!
M`!,````CJ`$`!P```#>H`0`-````/Z@!`"$```!-J`$`#@```&^H`0`/````
M?J@!``P```".J`$`!P```)NH`0`)````HZ@!``D```"MJ`$`"0```+>H`0`+
M````P:@!`!$```#-J`$`!0```-^H`0`7````Y:@!`!$```#]J`$`!@````^I
M`0`1````%JD!`!X````HJ0$`"P```$>I`0`#````4ZD!``@```!7J0$`!0``
M`&"I`0`(````9JD!``0```!OJ0$`3@```'2I`0`Q````PZD!`#\```#UJ0$`
M'0```#6J`0`%````4ZH!``4```!9J@$`#P```%^J`0`-````;ZH!``H```!]
MJ@$`#P```(BJ`0`=````F*H!`!$```"VJ@$`#0```,BJ`0`.````UJH!``H`
M``#EJ@$`"P```/"J`0`'````_*H!``8````$JP$`%`````NK`0`+````(*L!
M``8````LJP$`!@```#.K`0`G````.JL!`!8```!BJP$`"````'FK`0`1````
M@JL!``D```"4JP$`"0```)ZK`0`3````J*L!`!,```"\JP$`!@```-"K`0`<
M````UZL!``L```#TJP$`'`````"L`0`)````':P!``<````GK`$`$0```"^L
M`0`D````0:P!``L```!FK`$`#0```'*L`0`;````@*P!``0```"<K`$`"@``
M`*&L`0`1````K*P!``X```"^K`$``P```,VL`0`3````T:P!``D```#EK`$`
M(@```.^L`0`X````$JT!`#<```!+K0$`-@```(.M`0!A````NJT!`!D````<
MK@$`<P```#:N`0`]````JJX!`%````#HK@$`>@```#FO`0`M````M*\!`$0`
M``#BKP$`+@```">P`0`S````5K`!`!H```"*L`$`3````*6P`0#C`0``\K`!
M`"````#6L@$`&````/>R`0!"````$+,!`'@```!3LP$`.````,RS`0!`````
M!;0!`&H```!&M`$`60```+&T`0`A````"[4!`!0````MM0$`'P```$*U`0`<
M````8K4!`"H```!_M0$`(@```*JU`0`E````S;4!`!@```#SM0$`-P````RV
M`0`E````1+8!`"<```!JM@$`'@```)*V`0`O````L;8!`%X```#AM@$`00``
M`$"W`0!C````@K<!`%,```#FMP$`.@```#JX`0`X````=;@!`#8```"NN`$`
M;````.6X`0!Q````4KD!`%P```#$N0$`70```"&Z`0`\````?[H!`"<```"\
MN@$`)P```.2Z`0`S````#+L!`($```!`NP$`?@```,*[`0#6````0;P!`!D`
M```8O0$`+@```#*]`0`W````8;T!`"T```"9O0$`3P```,>]`0`F````%[X!
M`%T````^O@$`(P```)R^`0`+````P+X!`.4```#,O@$`3P```+*_`0`I````
M`L`!`#8````LP`$`*@```&/``0`A````CL`!`#P```"PP`$``P```.W``0`'
M````\<`!``0```#YP`$`$````/[``0`-````#\$!`!$````=P0$`#@```"_!
M`0`%````/L$!`"(```!$P0$``0```&?!`0!K````:<$!``0```#5P0$`%0``
M`-K!`0`$````\,$!``<```#UP0$`!````/W!`0`%`````L(!``@````(P@$`
M&0```!'"`0`+````*\(!`!$````WP@$`#@```$G"`0`#````6,(!``<```!<
MP@$`!P```&3"`0`1````;,(!``P```!^P@$`%````(O"`0`&````H,(!`!H`
M``"GP@$`"@```,+"`0`#````S<(!`#P```#1P@$`!`````[#`0`&````$\,!
M``<````:PP$`)P```"+#`0`^````2L,!`#0```")PP$`-0```+[#`0`;````
M],,!`"@````0Q`$`(````#G$`0`A````6L0!`"H```!\Q`$`)0```*?$`0`@
M````S<0!`"@```#NQ`$`)@```!?%`0`E````/L4!`#<```!DQ0$`-0```)S%
M`0`\````TL4!`"@````/Q@$`+````#C&`0`H````9<8!`",```".Q@$`*P``
M`++&`0`S````WL8!`"T````2QP$`,@```$#'`0`J````<\<!`"````">QP$`
M)0```+_'`0`P````Y<<!`"`````6R`$`)@```#?(`0!'````7L@!`$````"F
MR`$`'P```.?(`0`O````!\D!`$\````WR0$`+P```(?)`0`S````M\D!`#$`
M``#KR0$`,@```!W*`0`L````4,H!`"$```!]R@$`+0```)_*`0`H````S<H!
M`$T```#VR@$`,````$3+`0!#````=<L!``H```"YRP$`$0```,3+`0`6````
MULL!`#X```#MRP$`,````"S,`0`/````7<P!``\```!MS`$`%P```'W,`0`*
M````E<P!``P```"@S`$`*P```*W,`0`'````V<P!``H```#AS`$`.P```.S,
M`0`\````*,T!`"L```!ES0$`)P```)'-`0`<````N<T!``D```#6S0$`!0$`
M`.#-`0`1````YLX!`!@```#XS@$`"P```!'/`0`.````'<\!`!0````LSP$`
M*P```$'/`0`(````;<\!`$@```!VSP$`&@```+_/`0`;````VL\!``<```#V
MSP$`%@```/[/`0`-````%=`!`$0````CT`$`*````&C0`0`7````D=`!`!``
M``"IT`$`$@```+K0`0`U````S=`!``P````#T0$`#0```!#1`0`.````'M$!
M`!0````MT0$`"@```$+1`0`=````3=$!``@```!KT0$`+````'31`0`(````
MH=$!`!\```"JT0$`*0```,K1`0`&````]-$!`!\```#[T0$`!P```!O2`0`(
M````(](!``D````LT@$`10```#;2`0`&````?-(!`!,```"#T@$`$@```)?2
M`0`2````JM(!``D```"]T@$`"````,?2`0`'````T-(!`!,```#8T@$`#@``
M`.S2`0`B````^](!`!0````>TP$`&````#/3`0`<````3-,!``L```!ITP$`
M#0```'73`0`A````@],!``L```"ETP$`+0```+'3`0`/````W],!``0```#O
MTP$``P```/33`0`2````^-,!`"H````+U`$`"P```#;4`0`#````0M0!``@`
M``!&U`$`#````$_4`0`*````7-0!``\```!GU`$`#@```'?4`0`7````AM0!
M`!@```">U`$`$0```+?4`0`Z````R=0!`"`````$U0$`'P```"75`0`,````
M1=4!`#````!2U0$`!P```(/5`0`:````B]4!`$0```"FU0$`$P```.O5`0`0
M````_]4!``@````0U@$`!````!G6`0`$````'M8!`!,````CU@$`&P```#?6
M`0`%````4]8!``8```!9U@$`!P```&#6`0`%````:-8!`!(```!NU@$`$P``
M`('6`0`%````E=8!`!L```";U@$`&P```+?6`0`@````T]8!`"<```#TU@$`
M$0```!S7`0`"````+M<!``0````QUP$`#@```#;7`0`)````1=<!``4```!/
MUP$``@```%77`0`.````6-<!`#P```!GUP$`%0```*37`0`O````NM<!`$\`
M``#JUP$`&````#K8`0!Z````4]@!`!\```#.V`$`.P```.[8`0`B````*MD!
M`#D```!-V0$`,````(?9`0`T````N-D!`#<```#MV0$`-P```"7:`0`Q````
M7=H!`#@```"/V@$`+0```,C:`0`H````]MH!`$<````?VP$`'````&?;`0`:
M````A-L!`!0```"?VP$`?0```+3;`0`-````,MP!`((```!`W`$`@````,/<
M`0`V````1-T!`%@```![W0$`%````-3=`0`9````Z=T!``P````#W@$`(P``
M`!#>`0!%````--X!`"0```!ZW@$`)````)_>`0!M````Q-X!`!$````RWP$`
M"@```$3?`0`%````3]\!``8```!5WP$`"````%S?`0`%````9=\!`!,```!K
MWP$`%@```'_?`0`4````EM\!`!\```"KWP$`$````,O?`0`-````W-\!``0`
M``#JWP$`#P```._?`0`.````_]\!``8````.X`$`!@```!7@`0`;````'.`!
M`!$````XX`$`!0```$K@`0`5````4.`!``@```!FX`$`"0```&_@`0`4````
M>>`!``T```".X`$`&@```)S@`0`(````M^`!`!(```#`X`$`!@```-/@`0`%
M````VN`!``H```#@X`$`"P```.O@`0`%````]^`!`!L```#]X`$``@```!GA
M`0`"````'.$!``@````?X0$`"````"CA`0`'````,>$!`#D````YX0$`!```
M`'/A`0`#````>.$!`!,```!\X0$`&@```)#A`0`-````J^$!``L```"YX0$`
M!@```,7A`0`+````S.$!`!,```#8X0$`&0```.SA`0`"````!N(!``@````)
MX@$`$0```!+B`0`U````).(!``@```!:X@$`"0```&/B`0`4````;>(!``4`
M``""X@$`!````(CB`0`+````C>(!``$```"^!0``@`4``-L%``!*!0``-P8`
M``````#'!0``#@8```````!6`@``5P,```\%``"9`@``&`,``"L!````````
MIP$```````!:!0```````$L```"%!@``J@```'H"``!6!```E``````````X
M`@``'08``%X"```````````````````^````'P$``!\```#4!0``G04``$,&
M``#"`@```````",&``"+!@``8@0``/H"```)`P``;@4``"$&``!B`0``*P``
M`%L#``#Z!```4@,``)\&```3!@``0`(``.T#```^`P````````0"``!^`@``
MV@$``*,%``#*`@``+P```!L$``#I````+@,``*D```"N!```X@0``&P"````
M````SP4``)P```!W`P``5`8```````!-!0``G0$```````!=`@```@(``'``
M``"Z!```5P$``````````````````.\"``"&!`````````````"V`0``604`
M`)P%``"[!0```````&X#``"!`````````-,!```6````4`8``,L%```J!0``
M``````<&```]!@````````````#0!0``=0,``%<```"<`0``Q@4``(0$```M
M`P``PP0````````-!@``-@```&8&``#S```````````#``"6````````````
M``#Q`@``M0$``(,!`````````````'(#``!1!```)00``(<#``#R`0``.P(`
M`%@#``"<`@```````-0```"V!````````%$```#\`P``00$``"`"``!*!```
M2@8``,4%``!T`0``XP4```````">`@```````````````````````,4"````
M```````````````Z````_`$```````#\!````````+P`````````2@(``&@"
M``!)`0``R0,```````#Y`@``8`$``-D!```<`@``````````````````W@(`
M````````````UP(````````%!0``!`0``)<%``#J!```A@4``"P````%!@``
MZP0``&X$``"6!0``#0```(D&``#N`P``00(``!@"````````O04``-,$````
M````.0$``)\%``#1`P``;`8``,P!`````````````&$%``!+!0``5```````
M```>!0``$@4``$P$``````````````````!B`@``WP4``&8`````````%08`
M`$H```##!@``=`0````````D!0``-0,````````2`0``[P````````!Q!@``
M`````%4$````````-P4````````(`P``Y0,``+P&``!$!```R04``#8&```%
M````CP8``(<&``!8!```WP(``,$$``!U!```9`8```````!$!@``&@0`````
M``#(!```>0,``"4&```:`P``I`$``#(!````````%````"D"```*!@``5`,`
M`!@!````````_0(``,$"``#R`P``M@````````#F````:P0`````````````
M>P$````````P`@``9`0```````"&!@``:P,```````!E!@``^`0``(@!````
M````"P````````!E````%@0``,$&``!.!``````````````*`P``[@(``.T%
M``#%!```J@4``#8!``#T`0``O@$`````````````)P4``'H$```.!```'@$`
M`"\$``"5`P``_0```,<$``"Z`@``B0$``/T$``#8````6@,```(#``"(!0``
M``````````!G!0``(0$``"8````W`0```````"@%``#H!````````,X%``#+
M!```9P$``-@#``"0`P```````````````````````,0&```2`@``'0(``+(`
M````````9`,``)L`````````D`$``!H"``!G!`````````````"]`0``.P4`
M`!4%``#%`P``204``/X$``"S````$P4``$8#``#M`@``U0(``'0%````````
MCP4```````!S`@``*P,```````"[`0``A`$```````````````````````!)
M`P``$`,`````````````^P$``-X$``"H`0```````"X&````````@0,`````
M````````/`(``)D$``#,!0```````!`"``#+`P``=````(8`````````````
M``8&`````````````&(&````````H`4``'8!``"J`P``N`(````````\`P``
M,P(``*\"`````````````&$!``"9!0``D`4``"L$```#!0```````(H"``#N
M````*00``'D$``#)````I0,```````!'!````````!T`````````ZP4``*\`
M```U!```G0```!$&``!``P``O00```````"%`@```````*4&```S````P@$`
M````````````60,``/$%``!+!@```````````````````````+X&``#E````
MA0$``(H%````````.`8``'8$``#F!0``0@$``'(```!.`0``:0$````````.
M`````````/L````L!```F0````````!W!```````````````````MP4`````
M``#,`````````,H!``#S`P``````````````````60``````````````R`,`
M`!8"``#!!0``9`4``#`$```/`P````````````"J!``````````````!`@``
M`````#X&``!7!@``W````.0%``!K!0``XP$``,@%````````"P,``"8$````
M`````````!D%```]````GP$``*$$``#@!0``$0(``````````````````+H#
M``#B`````````%8#````````LP$`````````````IP(```````"6!```#04`
M``````";!@``#0,``%X&``#/`@``"@(``,T```"&`P``7`,``),!``#V`P``
MG`,``%L%``!?!@``J`0``,\#``##````/@$`````````````*`$``-L"``#W
M`@``40$``'$#``#"!@```````'T"````````E`,```````"%!```#@(``%`%
M``!@!````````/$#````````70,``,\$```=`0``Z0(`````````````;P0`
M``````"]`@``=`,```````````````````````"5!0```````+`#````````
M>@$``/X%```C````7P0``$`&``!C````S0$``/H!``!/`P``LP4``.4%``![
M!@``\`4``/4"``!\`P``D00``+4`````````)````#D&``"T`@``UP4``-T"
M```;!@``&P4``)H```!"!@``<P0```````#P`P```````%4%``!%`@``T@0`
M`$D&```?!0```````(X```#T`P````````````#L!```=04``",$``#=!0``
M*P4``"$%``#L`P```````,P"``#A`````````$8"````````/`8```````!+
M`@``-@4`````````````UP$``!L````@`P``RP$``#,%```%!```60$`````
M```*!```+0(`````````````0P4`````````````N0,``.````!0`@``C@(`
M`.0$``!1!@```````/8"``!4`@``CP$``$@&``"_`@``Z@(``)(%```^`@``
M.@4``%@````0!@``;P```+L"``"S!```KP8``/T%``",!@``$04``)P$```K
M`@```````-8!````````/P8````````_`@``:@8``*L%``!:`@``V04``!X#
M````````&P$``#,$````````<@8`````````````*@8``)0"``#F`0``+P4`
M```````C`P````````````"R`P```````"4#````````&P(``+@#``",!```
MYP````````"\!```$P0````````4`P```````)L!```0````1@0````````P
M`P``!P```"`$``".!@`````````````[`0``U0,``"T!``!:!```B`,`````
M``"L`P``G08``"(```"#!@````````````#W`P```````(`&````````````
M`"`%``!R`@```````*D%`````````````'T!``!L````;`4``-0$``"(`@``
M-08``#L&``"$`P``:P```-8#``#A`P``Q`(```````#V!```@@8``&D&``#]
M`P``X`$``*H&``!M!@``>@4```,$``"H`@``,0,``&4!```6`P``4P$``"P!
M```(!```Q@0``&8%```/`````````-@%````````F`4``%("```N````&`0`
M`/8%````````)P(``,$#```_`0``/P``````````````"@$``,P#````````
M'P0```8"````````````````````````_P4`````````````^`4``+$$``!_
M````H0,``)`&```V!```CP(``,`&``!K`@``R0(``"\#````````@`0``"D!
M``#3!0``4`0``,4&```B!```M04``'\&``!5`P``K0,``(8!``#L`0``\@0`
M`"<$`````````````'0&``"D`@``I@0``.\!``"A!@``R00``-@"```I!@``
M10```&D%``#&!@``O@,```````"+`````````%D$``"D````-`(``*8"``"=
M`@``B00```````!.`@``F0$```````"=!```H````.(#``!N`@```````$D$
M``"!!````````/$$``"*`P```````$@!``"``@``4@8``/4!``#``@``JP(`
M``````!X`@``1@$`````````````+00``$<#```W`@````````````"_!```
M_````/@#``#F`@``_`(``#$```!1`P```````*$```#D`0``D`(```````#J
M`0``%@8`````````!```[00``.(%````````(@$``*`#````````HP8``(H!
M````````````````````````L`0``&L!``!4!0``@@```.$!``"I`P``*`0`
M`&\%````````E@,```````#B`0``&````&@&``"(````I@4`````````````
M(@4``,T"``#^````K@$``,($``""!```U`,```````!_`P```````'`%```R
M!@```````$@%````````L0``````````````P0$``+P%``#S`@``D@8```T!
M``!%`P``L08``.8#``!G`@``?P0````````'`P``VP````````#:!0``````
M``````"1!@``7`8`````````````.`$``!$$``#/`0``5P4``,H````!`P``
MC04``'D````^!```@@$``&<&````````7```````````````&0(``/(```!3
M!@```````,@!```N!0``H`8``%`!``#;`P``'`$```````"M!```7@````H%
M````````JP,``(,"````````!P0```````#A!```?0````8```"M`@``:@(`
M``````!]!0``<P,``*<&````````)`$````````$!@``"00``#$$``"M`0``
MJ`8``&X&``#I`P``Q@```(H```!9`@``>P4`````````````.@0``'L$``#W
M!```Z`,``*D$```2`````````+D$```T!```CP0``"<&``#?`0``@0(`````
M``#K`0``*0,``&\!````````E@8`````````````T0(``"(#``!Q````E0``
M`!@&``#C`@```````!,#``"%!0``U04``$,!`````````````/(%``!U`0``
M80```#(#```5````9`$```(````T!@``^00```````#^`@```````-P!``!$
M`@``````````````````<`,```````!M`0``H@,``/L$``"2`@``U0$`````
M````````GP(``%\"``"B!0``N````","``!A!@``&08``)L"``!3````````
M`&T%````````E@(``!X$`````@``8P4``!`%``"<!@``/P0``)`````P!@``
MM@8```````!4!```.@(``.P````,`@``^`$``+<#``")`@``K@```&````#A
M`@``:`````````!P`0``:@````````#-!0``C00``-<#``"T!@```P$`````
M``"D`P``V@(```$&````````Z@```+<````E`0``>`4``%,$``"C`@``````
M`"<!``#@!```2`(``&H%``#;`0```````.<!```L`@```````%<"``!'!@``
M`````",%``#Q````!0,``!$```"G````E08``!H&``"L!@```````'L"``!H
M`P``WP0``+`"``":!0``20(``)@$``"#!0``_@$```````"Y`0``````````
M```)`0```````',%``!8`0``&@4```````":`@``;@``````````````#`,`
M`)$"``#<!```+P(``/D#``"H````_@,``#("``"``0```````"`&``#<!0``
M```````````/`@```````)8!``!+`0``U@(`````````````Q@$`````````
M````3P$``&T#``!!!```)@(``'8#``!V````6@8``&$$````````4@0``*L`
M`````````````(X%``!C`P```````'@$``"A`0````````````!5!@``]04`
M``````#$!```?`0``````````````````)0&```\`````````&D"``"H!0``
MZ0$```````">!@``OP8``*X&``!L`0```````$4$````````S@(``'$%``#,
M!```*````'X%``#;!```!P4`````````````.`4``%\%``#Z`P``7@$`````
M`````````````$\```!$`P````````,```"-`@`````````````H`P``Z04`
M`!H```"8`0``"08``!(&``"T!0``,@0```````!F`0````````````#_````
M`````"@&``#S`0```````)L%``"]`P``9```````````````F@0```8#``#G
M`P``5`$```````"X!0``PP4``!<```#7````%P,``+@$``#G!```K@(``+0!
M``!#````,0(``-(!``"O!```3`$``'D&``"B````?P$``$D`````````B@8`
M`*L&```+`0``+P$``*8#``!O`@``T`,``$`!```P`````````!($````````
MPP,``+<$``!&`````````*0&``!W````"0(``+,&```)!0``608``+`&``#_
M`P``D0,``,8"````````1P```-P"``#_!```%P$``)H#``#X`@``50(``,4!
M```/`0```````"(&````````'@```/<!``"2`P``GP`````````-!```-`$`
M``````#G`@```````$<!``!F!```_P(``&D$``!J`P``2P0``/@`````````
MAP````````"$````I00``"8#``")````BP0````````5!```HP0``"<#``"I
M`@``/0,``*,!``!8!0``)0```,(%````````A@(````````R!0``Q`,``,,"
M`````````````$T&``"P`0``-@,``"H#```T!0``0`0``#L#````````'`4`
M````````````3@4``.@``````````````'L#``"\`P``[`4```L$````````
MY`(``!4!````!@``H`(``+,"``!U`@````````@%``!Y`0``$@,``$$%```4
M!```$P$````````Q`0```````#P%``"5`0```````,<#```6`0``EP(``.T`
M``">!0``"````',```#``P``H`$``*,``````````````-4```!,`@``Y00`
M``````"G!0``<@0``*\!``#P!```%`(``!<$```E!0``3P0``*T%``"Z!@``
M#0(````````%`0``N`$``#H!```M````8`(``,,!`````````````$\%``"/
M``````````````#(````I04`````````````\````#4%``#Y`0```````,D!
M````````,04``.X!``!8!@``]P4``)`$````````1`$```````#]`0``4P4`
M`&$#``"K!````````!@%``"L`@``(0```"`!``!3`@``0@0``*8&````````
MU@```+(%```4`0```````'D%``#1`0``+`8``&P$``!E!```TP````````#0
M!```!`,```````"R!```BP4``'8"```9!```70$``*P```"(!@``W0``````
M``!5`0```````'(!``"$`@``*`(``%\!```U`@``'````!8%``!7!```M0,`
M``(!``#-`P``Y`,`````````````1@4````````,`0``\`(``#P!``!X!@``
M0P(``#L$```.`0``+08``.@%````````.`0```````"U`@``6P$``"P%``!#
M`P``F@8```L&````````?08``!0%````````[0$`````````````EP$``'@!
M``!%!0``K`4``+0```#K`P``EP8``"D```"5!```````````````````````
M`%8&```O!@``H04``!P#``#C`````````$4&``#O`P``^P4```$!````````
M#`4```````!G`P```````-,#````````M@4```````"V`P```````-,"``!.
M`P```````-(%``!U````S00```````#5!```#@4`````````````OP4``'8%
M```"!@``NP8``#0```````````````````"+`P``N04``,8#````````OP$`
M`"H"``!#!```D@````````!Z!@```````/P%``!`````2@,`````````````
M*P8``#D%````````!@0``.,#``#9`````````)$```#U!````````%P%```(
M`0```@0``.@!```S!@````$``&8#``"'`@``QP(```````!3`P```````(0%
M``#N!0```````%T&````````1P4``*L!`````````````#X%``"^````3```
M`(`#```0!```'P,``,<!```Y`@``"P(``*T&``"1!0``P`0``+0$``!G````
M?`$``$T``````````````%X$````````,`4``"0&````````C`$`````````
M````!`4``!D#``"H`P``0`4``%``````````D0$``,````"5`@```````.`#
M```=!0``]````$P&````````$P(```````"B!````````+L`````````W@4`
M`!P&```D!```"@```%H```#W`````````!,```!\`@``%P4```8%``!W`@``
MM08``%L$``#`!0``BP$```0!``#7!```HP,``$$&``#I!```%P(``'$$``#0
M`````````'H#``!H`0``7P````````#J!0``'@8``````````````````"8%
M````````X04``'H```"8`P``@@4``"H$``!V!@``Q0```(T!``#?`P``@08`
M`'0"``#P`0````````````!.`````````+H%``"G`P``8P$``/8```"$!@``
M`````+\```#2````=08``#T"````````=P4``/("``!@`P``<`(````````E
M`@``80(``(,#``````````````````````````````````!X````V@,```P&
M````````%0,``.4!`````````````#P$``"7`P``Q`4```````!;!@``)@$`
M`"T%````````<0$``&D#``!;`````````#,!``"Z`0``^@4``(T```!X`P``
MEP````````"7!```\P4``(("``"T`P``L@8``,(#````````T@,````````!
M!0```````-8%``!E`P``-`,``),&``!!````\0$``.L````F!@``MP(``+L#
M``!O`P``RP(```\$``!>!0``7`(``(P``````````````$@$````````I0(`
M``<!````````-0````````!<`0``\P0````````9`0``OP,````````A`P``
MZP(```P```![````````````````````L````&(#````````:`0``,H#``!>
M`P``8@```+L$``#T!````@4```````!K!@```````*0%``!1`@```````.@"
M``!]`P``2@$``",!```]`0``W@```),#```D`@``D@$``,(````0`0``````
M`!D```"L`0``-P```)X$````````;00``"0#``"8!@``Q`$``!$#```B`@``
ML@(``',&``!2````1````+H```"3````W00```````!@!@``]`4``#D#````
M````BP(``#8"``!&!@``H@8``%(%``!"`P```````)0%``#L`@``]`(`````
M``"B`0``AP4``),$``!W`0``L`4``'X&``#6!```<P$``+P!``#<`P``2P,`
M``````!L`P``L0$```````"\`@``G@```&,&``#B`@``*04``)L$````````
M3P(````````]!```@````-H$````````CP,```````#F!```F@$``-$$``"@
M!```0@````D```!P!```T`$``(,$`````````````)($```.`P```````(P%
M`````````````"X$````````5@```)X!``"]!@``;0```/\!``#*!0``W0,`
M``\&````````F````*\#````````[@0``.H#````````+`,```````"I!@``
M0@4``$("````````W@,````````7!@``F08``%T%``!%`0```````*\%``#0
M`@`````````````U`0```P(``.\%``"%`P``!P(``'`&``"X!@``,`$``*H!
M``!E`@``700```````#$````50```!T#``!!`P``DP4``((#```@````````
M`+X"``#*!```1`4``)L#``!Q`@``8P(``&H!````````RP```#$&``#=`0``
MAP$``,$```!1!0``````````````````5@$``)0!``!F`@``G0,`````````
M````$0$``%8%``!2`0``904``&0"``"M`````````*8`````````6@$``&H$
M```_!0``GP,``````````````````&@%````````O0````````#G!0``````
M`&T"````````'P8```````"R`0``````````````````G@,``"H`````````
M`````(@$```_`P``6`(``,X```"A`@``````````````````;P8````````#
M!@``@04``%T````!!```%0(``*8!``"G!````````+,#``#(`@``>0(``-D#
M``#``0```````*4`````````-P0``-@!``!^````)P```!X"````````````
M`$X&``"Q`@``U`$``(<$``!C!````P,``'X!``!_`@``"P4``-@$``!I````
M!````*("```Y````!0(``+D&``"W`0```````($!````````&P,`````````
M````'00``$T!```R````C@$```````"I`0``M@(``%`#``!B!0``U`(``+$#
M``#/````A0```'X$````````DP(```````#9!```!@$``$T#````````"`8`
M`!0&``".`P``O@0``"H!``!-`@``C`,````````]!0``.00``-$`````````
M?00``%P$``")!0``3`,``-H````[```````````````A`@``K@,``"$$``!N
M`0``Y`````````!R!0```````)D#``#>`0``7P,```@"````````K`0``.4"
M`````````````'\%````````@P```"X!``#V`0``V0(``*4!``"D!`````4`
M`$P%``"4!`````````````"N!0```````/L"``"W!@``S@,``)@"```?`@``
MT@(``,X!```Z`P```````+$%```S`P``300``#@#``"?!```N0```(H$````
M````S@0``$@#```:`0``C08````````W`P```````*H"```X````WP```$<"
M``#O!```C`(``%L"``"-`P``QP```.,$``#U````^0````P$```Z!@``2```
M`'<&`````````````!P$````````M00``'P&``#@`@``T04```````")`P``
M^P,``+D"``!\````8`4```````#U`P```````"X"````````?`4`````````
M`````````/H```".!```^04```````!/!@````````````!^`P```"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D
M87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T
M(&$@9&ER96-T;W)Y+@`E9"`E<R!A;F0@)7,`)60@8GET97,@=W)I='1E;BX`
M)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T90`E9"UD87D@
M9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U
M<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y
M(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO
M;B!E>'1R86-T)R!F:7)S="X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V
M:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@
M8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!
M32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI
M<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S
M:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O
M:P!!9&0@=7-E<@!!9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`
M061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I
M80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E
M9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S
M:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E
M($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E
M($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N
M871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R
M<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N
M>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R
M8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R
M;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G
M96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A
M`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I
M;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A
M;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@
M=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I
M<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!2
M97%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T
M;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z
M97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#
M;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R
M;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A
M;F=L861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E
M;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B
M(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG
M<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O
M<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN
M80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L
M86T`0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"=6EL9&EN
M9R!L;V-A;&4@)7,N+BX@`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T
M(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@
M<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L
M(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@
M;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E
M9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#
M96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`
M0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`
M0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC
M871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R
M(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A
M<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A4
M5%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P
M<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U
M<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#
M;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I
M;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`
M0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#
M;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F
M86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N
M;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R
M961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E
M<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P
M=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C
M96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M
M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$
M969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L
M971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD
M('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE
M=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L
M:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U
M9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q
M=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD
M<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R
M`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`
M17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R
M9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N
M96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL
M960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N
M`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D
M('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER
M`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A
M=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME
M.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`
M1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S
M`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U
M<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'
M96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A>7-C86QE
M`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`
M1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS
M97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M
M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M
M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES
M<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H
M`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M
M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E
M`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT
M96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT
M96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I
M>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT
M`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!)
M;6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@
M9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E
M<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S
M97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN
M8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`
M26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YI=&EA;&EZ:6YG(&UO9'5L
M92`E<RXN+B``26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F
M;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F
M=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN
M<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R
M86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R
M;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E
M9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D
M:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I
M8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!)
M;G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A
M;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`
M26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P
M<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@
M;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D
M92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)
M<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R
M865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU
M;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF
M>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L
M/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I
M;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I
M`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A
M+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T
M86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8P!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`
M3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO
M9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@
M;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E
M<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C
M:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN
M($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H
M="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO
M=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M
M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI
M;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE
M(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@
M5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W
M;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A
M;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E
M`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`
M3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%
M1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G
M87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R
M=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@
M5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF
M:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N
M`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=')I8P!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E
M`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G
M92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`
M36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@
M55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O
M;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H
M87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L
M>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/
M5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`
M3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.
M971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.
M971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V
M97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S
M97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@
M;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.
M:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C
M:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@
M;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D
M960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C
M871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@
M<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@
M9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!
M4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N
M=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-I9&5S`$YO('-U8V@@
M9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E
M(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N
M9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD
M<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y
M`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E
M<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N
M;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@
M;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@
M4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S
M:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0
M($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B
M;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(
M4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3
M;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D
M9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L
M>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W
M;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0
M871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N($1E;FEE
M9`!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A
M:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL
M<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`
M4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE
M8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U
M97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&5M<&QE+F5S+VAO<F1E*3H`4F5M;W9E`%)E;6]V
M92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V
M92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@
M9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S
M`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`
M4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`
M4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W
M(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E
M($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T
M:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S
M86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`
M4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L
M96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@
M82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS
M;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.
M=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S
M:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG
M`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@
M:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H
M;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``
M4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@
M4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3
M:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`
M4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R
M:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI
M<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN
M9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W
M`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE
M87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T
M<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@
M9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C
M=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E
M`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E
M.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA
M;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3
M=V5D96X`4W=I='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%135B!F:6QE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@
M<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!4
M86II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T
M.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@
M`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R
M871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H
M86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE
M961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K
M96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O
M;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@
M8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@
M=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES
M<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL
M;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E
M(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@=&5M<&]R87)Y(&9I;&4@
M(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE
M(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`
M5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS
M90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O
M(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O
M=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI
M=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E
M<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`
M56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N
M:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L
M;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R
M9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H
M92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO
M;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5
M<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S
M92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S
M97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD
M(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L
M=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E
M;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O
M;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A
M;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE
M=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER
M9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES
M:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C
M87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`
M5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ
M-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P
M:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E
M>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H
M.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I
M;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN
M("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI
M;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I
M;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)
M`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0
M<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L
M96YD87(`8V%L;0!C;&EC:R!H97)E`&9A;&QI;F<`9FEL90!F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S`&@Z`&AH`&EM;65D:6%T90!I;FQI;F4`;&EN97-=
M`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N
M86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P
M860`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS
M,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E
M<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C`U"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`U+3$Q(#$R
M.C4Q*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP-RTQ-"`Q,3HP."LP
M,3`P"DQA<W0M5')A;G-L871O<CH@2F]R9&D@1VER86QT(#QP<F]J96-T92YK
M,D!U<&-N970N961U/@I,86YG=6%G92U496%M.B!#871A;&%N(#QD979`;&ES
M=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`H9F$@)7,@9&EE<RD`("A#;&%U(&0G86-C
MZ7,@)7,I`"AE;B`E<R!D:65S*0`H879U:2D`*&1E;>`I`"AA:&ER*0!E;@`B
M)7,B(&YO(.ES('5N(&1I<F5C=&]R:2X`)60@)7,@:2`E<P`E9"!B>71E<R!E
M<V-R:71S+@`E9"!D92`E9"!E;G1R861E<R!M87)C861E<R!C;VT@86-T=6%L
M:71Z861E<P!P<F5V:7-I\R!P97(@86P@9&EA("5D`$%V[7,@+2`E<P!%;7!R
M96UT82!D86-T:6QA<B`E<P`E<R!+0@!/<&5R86-I;VYS(&1E(&UA;G1E;FEM
M96YT("5S("T@0V]N9FER;6%C:?,`0V]N9FEG=7)A8VGS(&1E("5S`$%L=&$@
M9&4@)7,`0V]N9&EC:6]N<R!D96P@8V]N=')A8W1E("5S`"5S(&IA(&5X:7-T
M96EX+@`E<R!E;B`E<R`E<P#)<R!N96-E<W-A<FD@)7,N`"5S(&UI;G5T<P!.
M;R!S)VAA('1R;V)A="`E<RX`)7,@;F\@=')O8F%T+B!%>&5C=71A("=T<F%N
M<VQA=&EO;B!E>'1R86-T)R!P<FEM97(N`"5S(&%L("5S(&1E("5S`$QL:6)R
M971A(&0G861R96-E<R!D92`E<P!!9V5N9&$@9&4@)7,`0FQO8R!D92!N;W1E
M<R!D92`E<P!,;&ES=&$@9&4@=&%S<75E<R!D92`E<P`E<SH@)7,`+"!V96YT
M\W,@)7,@)7,@`"P@=F%R:6%B;&4@9&4@)7,@82`E<P`M+2!S96QE8V-I;VYA
M<B`M+0`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T`9F]R;6%T(&1E(#$R
M(&AO<F5S`&9O<FUA="!D92`R-"!H;W)E<P`R-"!H;W)E<P`\06YT97)I;W(`
M4&5R(&$@87%U97-T(&)L;V,@97,@;F5C97-S:71A('5N(&UO=&]R(&1E(&)A
M<V5S(&1E(&1A9&5S+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@:7)R97!A<F%B
M;&4N`$5S(&YE8V5S<VET82!U;F$@8VQA=2!01U`@</IB;&EC82!P97(@>&EF
M<F%R('5N(&UI<W-A=&=E+@!%<R!N96-E<W-I=&$@=6YA(&-L874@4$=0('#Z
M8FQI8V$@<&5R('9E<FEF:6-A<B!U;B!M:7-S871G92!S:6=N870N`$5S(&YE
M8V5S<VET96X@=6YA(&-L874@4$=0('#Z8FQI8V$L('5N82!C;&%U(%!'4"!P
M<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!D97-X:69R87(@=6X@;6ES
M<V%T9V4N`$5S(&YE8V5S<VET96X@=6YA(&-L874@4$=0('#Z8FQI8V$L('5N
M82!C;&%U(%!'4"!P<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!S:6=N
M87(@=6X@;6ES<V%T9V4N`$5S(&YE8V5S<VET96X@=6YA(&-L874@4R]-24U%
M('#Z8FQI8V$L('5N82!C;&%U(%,O34E-12!P<FEV861A(&D@=6YA(&-O;G1R
M87-E;GEA('!E<B!D97-X:69R87(@=6X@;6ES<V%T9V4N`$5S(&YE8V5S<VET
M96X@=6YA(&-L874@4R]-24U%('#Z8FQI8V$L('5N82!C;&%U(%,O34E-12!P
M<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!S:6=N87(@=6X@;6ES<V%T
M9V4N`$5S(&YE8V5S<VET82!U;F$@8VQA=2!334E-12!P^F)L:6-A('!E<B!X
M:69R87(@=6X@;6ES<V%T9V4N`$[Z=F]L<R!A;"!M873M`%!L=6IA(&9E8FQE
M(&%L(&UA=.T`4&QU:F$@86P@;6%T[0!2=6EX871S(&%L(&UA=.T`6.!F96-S
M(&1E(&YE=2!A;"!M873M+@!!32]030!)1"!D92!!4$D`4V]B<F4@87%U97-T
M(&5D:71O<@!%;B!Q=6%N="!A+BXN`$%L:6YE86-I\R!I;F9E<FEO<B!E>&%C
M=&$`06QI;F5A8VGS(&%L(&UI9R!E>&%C=&$`4R=H82!D96YE9V%T(&PG86-C
MZ7,@96X@8W)E87(@96P@9&ER96-T;W)I(%9&4RX`4R=H82!D96YE9V%T(&PG
M86-CZ7,@96X@8W)E87(@;"=A<GAI=2!61E,N`$-O;G1R87-E;GEA(&1E;"!C
M;VUP=&4`0V]M<'1E(&-O;F=E;&%T+@!#;VUP=&%B:6QI='IA8VGS`$%F96=I
M<@!!9F5G:7(@=6X@9W)U<"!D97-C96YD96YT`$%F96=I<B!U;F$@875T;W)I
M='IA8VGS(&1E<V-E;F1E;G0`069E9VER(&$@8V]N=&EN=6%C:?,Z`$%F96=I
M<B!U;B!N;W4@9W)U<`!!9F5G:7(@=6YA(&YO=F$@875T;W)I='IA8VGS(`!!
M9F5G:7(@=6X@;F]U('5S=6%R:3H`069E9VER('5N82!C;VQU;6YA+@!!9F5G
M:7(@;F]U<R!M96UB<F5S+@!!9F5G:7(@=6YA('!A<F5L;&$`069E9VER(&5L
M(&UE;OH@)7,@8V]M('5N82!B87)R82!L871E<F%L(&1E($UO>FEL;&$`069E
M9V5I>"!A(&QA(&QL:6)R971A(&0G861R96-E<SH`069E9V5I>"!A(&QA(&UE
M=F$@;&QI8G)E=&$@9"=A9')E8V5S`$%F96=I<B!U;B!U<W5A<FD`069E9VEN
M="!N;W5S(&9I='AE<G,@86P@<F5P;W-I=&]R:0!3)VAA(&EN:&%B:6QI=&%T
M(&PG;W!C:?,@9"=A9F5G:7(@=7-U87)I<RX`061R9>=A`$QL:6)R971A(&0G
M861R96-E<P!!9&UI;FES=')A9&]R("T@9&5F:6YE:7@@;&5S(&%U=&]R:71Z
M86-I;VYS('!E<B!A(&%L=')E<R!U<W5A<FES`$%D;6EN:7-T<F%C:?,`06YU
M;F-I<P!!9F=A;FES=&%N`$%L8N!N:6$`06QGZ')I80#`;&EE<P!!;&EN96%R
M`$%L:6YE86-I\SH`5&]T<P!4;W1S(&5L<R!U<W5A<FES(&%U=&5N=&EC871S
M`%1O=',@96QS(&=R=7!S`%1O=',@96QS('!E<FUI<V]S`%1O=',@<75A=')E
M(&-O<W1A=',`4&5R;65T(&UO;'1E<R!A9')E8V5S`$5S('!E<FUE="!L82!C
M;VYF:6=U<F%C:?,@9&5L('1I<'5S(&1E(&QL:7-T97,@;W)D96YA9&5S/P!*
M82!E>&ES=&5I>`!!8V/I<R!)35-0(&%L=&5R;F%T:74`0V]N=')A<V5N>6$@
M24U34"!A;'1E<FYA=&EV80!.;VT@9"=U<W5A<FD@24U34"!A;'1E<FYA=&EU
M`$%D<F7G82!E;&5C='+R;FEC82!A;'1E<FYA=&EV80!0;&%N=&EL;&5S(&%L
M=&5R;F%T:79E<P!497AT(&%L=&5R;F%T:74Z`%-A;6]A($%M97)I8V%N80!3
M)VAA(&5S<&5C:69I8V%T('5N('9A;&]R('!R;VAI8FET+@!3)VAA('!R;V1U
M[W0@=6X@97)R;W(@9&5S8V]N96=U="X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`4V5R=FED;W(@4')O>'D@86[R;FEM`%)E<W!O<W1A`$%N=.!R=&ED80!!
M;G1I9W5A(&D@0F%R8G5D80!!<&QI8V%C:?,`3&QI<W1A(&0G87!L:6-A8VEO
M;G,`3"=A<&QI8V%C:?,@Z7,@82!P=6YT+@!!<&QI8V%R(&$@<F5C=7)S;W,@
M8V]M<&%R=&ET<R!D97-C96YD96YT<RX`07!R;W9A<@!-:61A(&%P<F]X:6UA
M9&$`06)R:6P`07+@8FEC("A7:6YD;W=S+3$R-38`36ED82!D92!L)V%R>&EU
M`$YO;2!D92!L)V%R>&EU`%9O;&5U('-U<')I;6ER(&QA('-O;+=L:6-I='5D
M(&0G86QT82!A("5S/P!!<F=E;G1I;F$`07)MZ&YI80!!<FUE;FD@*$%235-#
M24DM."D`07)T`$%R=6)A`$EL;&$@9&4@;"=!<V-E;G-I\P!G<N!F:6,@05-#
M24D`4F5G:?,@9&5L(%!A8^UF:6,@87-IX'1I8P!6;VQE=2!C;VYF:7)M86-I
M\R!A8F%N<R!D)V5F96-T=6%R(&QE<R!O<&5R86-I;VYS(&1E(&UA;G1E;FEM
M96YT/P!#;VQU;6YE<R!D)V%S<VEG;F%C:?,`4R=H82!I;G1E;G1A="!S=7!R
M:6UI<B!U;B!G<G5P(&YO(&5X:7-T96YT+@!3)VAA(&EN=&5N=&%T('-U<')I
M;6ER('5N82!A=71O<FET>F%C:?,@;F\@97AI<W1E;G0N`%,G:&$@:6YT96YT
M870@961I=&%R('5N82!A=71O<FET>F%C:?,@;F\@97AI<W1E;G0N`%,G:&$@
M:6YT96YT870@961I=&%R('5N(')E8W5R<R!C;VUP87)T:70@;F\@97AI<W1E
M;G0N`$%T<FEB=71S`$%G;W-T`$%U<W1RX&QI80#`=7-T<FEA`$%U=&A?8WER
M<W%L.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS(&EM87`@;F5C97-SX')I
M82X`075T:%]C>7)U<SH@16P@;6]T;W(@;F\@=.D@;&5S(&-A<&%C:71A=',@
M;F5C97-SX')I97,N`$%U=&A?8WER=7,Z($YO(',G:&$@=')O8F%T(&PG97AT
M96YS:?,@24U!4"!N96-E<W/@<FEA+@!!=71H7V9T<#H@3F\@<R=H82!T<F]B
M870@;"=E>'1E;G-I\R!&5%`@;F5C97-SX')I82X@0V%L(&-O;7!I;&%R(%!(
M4"!A;6(@96P@8V]M;75T861O<B`M96YA8FQE+69T<"X`075T:%]I;6%P.B!.
M;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($E-05`@;F5C97-SX')I82X`075T
M:%]K<F(U.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS(&MR8C4@;F5C97-S
MX')I82X`075T:%]L9&%P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($Q$
M05`@;F5C97-SX')I82X`075T:%]L9&%P.B!.;R!S)VAA('!O9W5T(&%F96=I
M<B!L)W5S=6%R:2`E<RX@06EX\B#I<R!E;"!Q=64@:&$@9&ET(&5L('-E<G9I
M9&]R.@!!=71H7VQD87`Z($YO(',G:&$@<&]G=70@<W5P<FEM:7(@;"=U<W5A
M<FD@)7,N`$%U=&]?;&1A<#H@3F\@<R=H82!P;V=U="!A8W1U86QI='IA<B!L
M)W5S=6%R:2`E<RX`075T;U]M8V%L.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N
M<VGS($U#04P@;F5C97-SX')I82X`075T:%]S;6)A=71H.B!.;R!S)VAA('1R
M;V)A="!L)V5X=&5N<VGS(%--0D%55$@@;F5C97-SX')I82X`4R=H82!P<F]D
M=>]T('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS+@!3)VAA('!R;V1U[W0@
M=6X@97)R;W(@96X@;"=A=71E;G1I8V%C:?,N("5S`$5L('-E<G9I9&]R(%)!
M1$E54R!H82!R96)U=&IA="!L)V%U=&5N=&EC86-I\RX`4R=H82!P<F]D=>]T
M('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS(&%M8B!E;"!S97)V:61O<B!&
M5%`N`%,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!L)V%U=&5N=&EC86-I\R!A
M;6(@96P@<V5R=FED;W(@4TU"+@!#86UP<R!D:7-P;VYI8FQE<SH`07IE<F)A
M:61J86X`0D]&2"!%>&-U<V5S`$9O;G,`0V]L;W(@9&5L(&9O;G,`0V]N=')A
M<V5N>6$@2V5R8F5R;W,@:6YC;W)R96-T82X`3F]M(&0G=7-U87)I($ME<F)E
M<F]S(&EN8V]R<F5C=&4N`$)A:&%M97,`0F%H<F%I;@!"X&QT:6,@*$E33RTX
M.#4Y+3$S*0!"86YG;&$@1&5S:`!"87)B861O<P!,[6YI82!B87-E`$)I96QO
M<G+Z<VEA`$+H;&=I8V$`0F5L:7IE`$)E;NUN`$)E<FUU9&5S`$)H=71A;@!!
M;FEV97)S87)I`$YO(',G:&$@=')O8F%T(&5L(&)L;V,@(B5S(B!D92!L)V%P
M;&EC86-I\R`B)7,B("X`4&%RX&UE=')E<R!D96P@8FQO8P!4:7!U<R!D92!B
M;&]C`$YE9W)E=&$`0F]L[79I80!-87)C861O<G,`0V]N=&]R;@!'<G5I>"!D
M96P@8V]N=&]R;@!#;VYT;W)N<P!"\G-N:6$@:2!(97)C96=O=FEN80!!;6)D
M\W,`0F]T<W=A;F$`26YF97)I;W(`26QL82!D92!";W5V970`0G)A<VEL`%1E
M<G)I=&]R:2!O8V7@;FEC(&1E(&PGS6YD:6$@8G)I=.!N:6-A`$)R=6YE:2!$
M87)U<W-A;&%M`$-O;G1R=6EN="!F:71X97)S($U/('!E<B!A;"!M\F1U;"`E
M<RXN+@!#;VYS=')U:6YT("5S+BXN`$)U;&?@<FEA`$QL:7-T82!D92!P:6-S
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`4'5N=',@9&4@9&ES=')I
M8G5C:?,@9&4@0U),`%!R;W!I971A=',@9&4@8V5LMVQA+BXN`$YO(',G:&$@
M9FEN86QI='IA="!E;"!P<F]CZ7,@9"=I;FEC:6%L:71Z86-I\R!D92!L82!M
M96WR<FEA(&-A=0!#86QE;F1A<FD`0V%L;6$`0V%M8F]D:F$`0V%M97)U;@#)
M<R!I;7!O<W-I8FQE(')E:6YI8VEA<B!L82!C;VYT<F%S96YY82!A=71O;>!T
M:6-A;65N="P@<&]S82=T(&5N(&-O;G1A8W1E(&%M8B!L)V%D;6EN:7-T<F%D
M;W(@9&5L('-I<W1E;6$N`,ES(&EM<&]S<VEB;&4@8V]N;F5C=&%R(&%M8B!E
M;"!S97)V:61O<B!)34%0.B`E<RX`0V%N863@`$-A;F-E;+=L87(`0V%N8V5L
MMVQA<B!L)VEN9F]R;64@9&4@<')O8FQE;65S+@!.;R!E<R!P;W0@97-B;W)R
M87(@;"=A<GAI=2`B)7,B+@!.;R!E<R!P;W0@=')O8F%R('5N(&1I<F5C=&]R
M:2!T96UP;W)A;"X`3F\@97,@<&]T(&-O;G1I;G5A<B!S96YS92!E;"!P87+@
M;65T<F4@)W1A<F=E=$9I;&4G+@!.;R!E<R!P;W0@97-B;W)R87(@96P@9&ER
M96-T;W)I("(E<R(N`$YO(&5S('!O="!E<V)O<G)A<BP@8V]N=.D@9&5S8V5N
M9&5N=',@)60N(`!.;R!E<R!P;W0@<F5O<F1E;F%R+"!E;"!N;VUB<F4@9"=E
M;G1R861E<R!Q=64@<R=H86X@9&4@<F5O<F1E;F%R(&YO(&-O:6YC:61E:7@@
M86UB(&QE<R!Q=64@:&D@:&$@96UM86=A='IE;6%D97,N`$YO(&5S('!O="!A
M9')EYV%R(&5L(&UI<W-A=&=E(&%L(&YO;6)R92!E<W!E8VEF:6-A="X`0V%P
M(%9E<F0`3&QE9V5N9&$`0V%T96=O<FEE<R!I(&5T:7%U971E<P!);&QE<R!#
M86EM86X`5&5LZ&9O;B!M\F)I;`!0<F]P:65T871S(&1E(&-E;+=L80!&87)C
M:6UE;G0@9&4@8V5LMVQA`%!R;W!I971A=',@9&4@;&$@8V5LMVQA`$5S<&%I
M870@96YT<F4@8V5LMVQE<P!496SH9F]N(&WR8FEL`$/H;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1R87(`4F5P^F)L:6-A($-E;G1R96%F<FEC86YA`$5U<F]P
M82!C96YT<F%L("A)4T\M.#@U.2TR*0!$971A;&QS(&1E;"!C97)T:69I8V%T
M`%1I='5L87(@9&5L(&-E<G1I9FEC870`4&]L[71I<75E<R!D92!C97)T:69I
M8V%C:?,`5'AA9`!$97-FZ7,`0V%N=FEE=2!E;"!N;VT@:2!L)V%D<F7G82!Q
M=64@<_-N('9I<VEB;&5S('%U86X@97,@;&QE9V5I>&5N(&\@97,@<F5S<&]N
M96X@96QS('9O<W1R97,@;6ES<V%T9V5S(&1E(&-O<G)E=2!E;&5C='+R;FEC
M+@!#:&%R`%9E<FEF:6-A(&PG96YL;&'G+BXN`%AI;&4`6&EN80!8:6[H<R!S
M:6UP;&EF:6-A="`H1T(R,S$R*0!8:6[H<R!T<F%D:6-I;VYA;"`H0FEG-2D`
M5')I82!U;F$@8V]N=')A<V5N>6$`5')I82!U;B!N;VT@9"=U<W5A<FD`5')I
M82!C;VT@=F]L<R!V:7-U86QI='IA<B!L97,@9&%T97,Z`%1R:6$@=6X@=&EP
M=7,@9"=E<W1I;"!D92!L;&ES=&$@*'!E<B!A(&QL:7-T97,@;W)D96YA9&5S
M*0!);&QA(&1E($-H<FES=&UA<P!.;R!S)VAA('1R;V)A="!L82!D969I;FEC
M:?,@9&4@8VQA<W-E(&1E("`E<RX`16QI;6EN87(`16QI;6EN82!L97,@971I
M<75E=&5S(&1E($U33V9F:6-E`$5S8F]R<F$@;"=U<W5A<FDZ("5S`$5S8F]R
M<F$@;"=U<W5A<FD`17-B;W)R82!L97,@9&%D97,@9&4@;"=U<W5A<FD`4R=A
M8VQA<FERX"!C87`@86P@=&%R9"X`4')E;6D@<&5R(&-O;G1I;G5A<@!#;&EC
M:V%T96QL('!E<B!(5%10`%1A;F-A(&QA(&9I;F5S=')A`$[Z=F]L<P!.^G9O
M;',@82!P<FEM97)A(&AO<F$`16YN=79O;&%T`$EL;&5S(&1E($-O8V]S("A+
M965L:6YG*0!2961U[W4@;&$@8F%R<F$@;&%T97)A;`!-87)G97,@<F5D=>]T
M<P!#;VSR;6)I80!#;VQO<@!396QE8W1O<B!D92!C;VQO<@!396QE8V-I\R!D
M92!C;VQO<@!#;VQU;6YE<SH`5.UT;VQS(&1E(&QE<R!C;VQU;6YE<P!#\FUI
M8W,`3W)D<F4`0V]N<V]L80!#;VUE;G1A<FD`3F]M(&-O;?H`0V]M;W)E<P!#
M;VUP86YY:6$`17-C<FEU(&5L(&UI<W-A=&=E("@E<RD`3W)D:6YA9&]R<P!#
M;VYD:6-I;VYS`$1I9F5RZ&YC:65S(&1E(&-O;F9I9W5R86-I\P!,82!C;VYF
M:6=U<F%C:?,@;F\@97-TX"!A8W1U86QI='IA9&$N`$-O;F9I9W5R82`E<P!#
M;VYF:7)M87(@;&$@8V]N=')A<V5N>6$`0V]N9V\`0V]N9V\L(%)E</IB;&EC
M82!$96UO8W+@=&EC82!D96P`3F\@Z7,@<&]S<VEB;&4@<F5A;&ET>F%R(&QA
M(&-O;FYE>&GS+@!.;R#I<R!P;W-S:6)L92!R96%L:71Z87(@;&$@8V]N;F5X
M:?,Z`%,G:&$@<F5B=71J870@;&$@8V]N;F5X:?,@86P@<V5R=FED;W(@9&4@
M8VQA=7,@</IB;&EQ=65S+@!3)VAA(')E8G5T:F%T(&QA(&-O;FYE>&GS(&%L
M('-E<G9I9&]R(&1E(&-L875S('#Z8FQI<75E<RX@4F'S.B`E<R`H)7,I`$YO
M(.ES('!O<W-I8FQE(')E86QI='IA<B!L82!C;VYN97AI\R!A;"!S97)V:61O
M<B!&5%`N`$5L<R!C;VYT86-T97,@<R=H86X@869E9VET(&-O<G)E8W1A;65N
M="!A(&QA('1E=F$@;&QI8G)E=&$@9"=A9')E8V5S+@!#;VYT:6YU87(`26QL
M97,@0V]O:P!'86QE=&$`0V]P:6%R`,ES(&EM<&]S<VEB;&4@8V]P:6%R.B`E
M<P!#;W!I87(@<V5L96-C:?,`0V]S=&$@4FEC80!#;W-T82!D)TEV;W)I`$YO
M(&5S('!O="!X:69R87(@96P@;6ES<V%T9V4@86UB(%,O34E-12X`3F\@97,@
M<&]T('-I9VYA<B!E;"!M:7-S871G92!A;6(@4R]-24U%+@!.;R!E<R!P;W0@
M869E9VER(&5L(&-O;G1A8W1E+B`E<P!.;R!E<R!P;W0@8V]N;F5C=&%R(&%M
M8B!E;"!S97)V:61O<B!,1$%0+@!.;R!E<R!P;W0@8V]M<')O=F%R(&5L('-A
M;&1O+B`E<P!.;R!S)VAA('!O9W5T(&-R96%R('5N82!L;&ES=&$@9&4@9&ES
M=')I8G5C:?,N("5S`$YO(',G:&$@<&]G=70@9&5S>&EF<F%R(&QE<R!D861E
M<R!3+TU)344N`$YO(',G:&$@<&]G=70@97-B;W)R87(@96P@8V]N=&%C=&4N
M("5S`$YO(',G:&$@<&]G=70@97-B;W)R87(@;&$@;&QI<W1A(&1E(&1I<W1R
M:6)U8VGS+B`E<P!.;R!S)VAA('!O9W5T(&1E=&5R;6EN87(@;"=A9')EYV$@
M96QE8W1R\FYI8V$@9&5L(&1E<W1I;F%T87)I+@!.;R!S)VAA('!O9W5T(')E
M8V]L;&ER('1O=&$@;&$@;&QI8G)E=&$@9"=A9')E8V5S+@!.;R!S)VAA('!O
M9W5T(')E8V]L;&ER('1O=&$@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+@!.
M;R!S)VAA('!O9W5T(')E8V]L;&ER('1O=&$@;&$@;&QI<W1A(&1E(&QE<R!L
M;&ES=&5S(&1E(&1I<W1R:6)U8VGS+@!.;R!S)VAA('!O9W5T(&]B=&5N:7(@
M=6YA(&-L874@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=7,N`$YO(',G
M:&$@<&]G=70@;V)R:7(@)7,N`$YO(',G:&$@<&]G=70@;V)R:7(@96P@;?)D
M=6P@9&4@=&%S<75E<R!D92!M86YT96YI;65N="`E<RX`3F\@<R=H82!P;V=U
M="!L;&5G:7(@)7,N`$YO(',G:&$@<&]G=70@<F5I;FEC:6%R(&QA(&-O;G1R
M87-E;GEA('!E<B!A(&PG=7-U87)I('-O;+=L:6-I=&%T+B!!;&=U;G,@9&5T
M86QL<R!O('1O=',@;F\@<_-N(&-O<G)E8W1E<RX@5&]R;F%R+6AO(&$@:6YT
M96YT87(@;RP@<&5R(&$@;>ES(&EN9F]R;6%C:?,L('!O<V$G="!E;B!C;VYT
M86-T92!A;6(@;"=A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+@!.;R!S)VAA
M('!O9W5T(')E8W5P97)A<B!L97,@04-,`$YO(',G:&$@<&]G=70@<F5C=7!E
M<F%R(&QA(&QL:6)R971A(&0G861R96-E<RX@)7,`3F\@<R=H82!P;V=U="!R
M96-U<&5R87(@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<P!.;R!S)VAA
M('!O9W5T(')E8W5P97)A<B!L97,@;&QI<W1E<R!D92!D:7-T<FEB=6-I\RX@
M)7,`3F\@<R=H82!P;V=U="!R96-U<&5R87(@;&5S('!O<W-I8FEL:71A=',@
M9&5L('-E<G9I9&]R`$YO(',G:&$@<&]G=70@<F5S=&%U<F%R(&QA(&-O;F9I
M9W5R86-I\RX`3F\@<R=H82!P;V=U="!D97-A<B!L82!C;VYF:6=U<F%C:?,@
M)7,N`$YO(',G:&$@<&]G=70@9&5S87(@=6YA(&-O;F9I9W5R86-I\R!D92!S
M96=U<F5T870N`$YO(',G:&$@<&]G=70@9&5S87(@=6YA(&-O;F9I9W5R86-I
M\R!D92!S96=U<F5T870Z("5S`$YO(',G:&$@<&]G=70@9&5S87(@;&$@8_)P
M:6$@9&4@<V5G=7)E=&%T(&1E(&PG87)X:74@9&4@8V]N9FEG=7)A8VGS("5S
M+@!.;R!S)VAA('!O9W5T(&1E<V%R(&PG87)X:74@9&4@8V]N9FEG=7)A8VGS
M("5S+B!0;W1S('5T:6QI='IA<B!U;F$@9&4@;&5S(&]P8VEO;G,@<&5R('1O
M<FYA<B!A(&1E<V%R(&5L(&-O9&D@96X@)7,@;R!BZ2!C;W!I87(@;6%N=6%L
M;65N="!E;"!C;V1I('-E9_QE;G0@96X@)7,N`$YO(',G:&$@<&]G=70@8V5R
M8V%R(&%L('-E<G9I9&]R($Q$05`N`$YO(',G:&$@<&]G=70@86-T=6%L:71Z
M87(@96P@8V]N=&%C=&4N("5S`$YO(',G:&$@<&]G=70@86-T=6%L:71Z87(@
M;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<P!.;R!S)VAA('!O9W5T(&QO
M8V%L:71Z87(@;&$@8F%R<F$@;&%T97)A;"!D92!-;WII;&QA+B!#;VUP<F]V
M82!Q=64@;&$@8F%R<F$@;&%T97)A;"!E<W1I9W5I(&]B97)T82X`5&5X="!C
M;VUP=&%T`%!A[7,`0W5R<V]S`$-R96%R`$-R96%R('5N(&5N;&QAYP!#<F5A
M<BUN92!U;B!D92!N;W4`0W)E87(@<W5B8V%R<&5T97,`4&5R;6ES;W,@9&5L
M(&-R96%D;W(`3OIM97)O(&1E(&QA('1A<F=E=&$@9&4@8W+H9&ET`$-R;^!C
M:6$`0W5B80`T(&9A<V5S(&%C='5A;',`5&5M<',@86-T=6%L`$5L(%523"!A
M8W1U86P@Z7,`5&5M<',@86-T=6%L`$-O;F1I8VGS(&%C='5A;#H`17-T:6P@
M86-T=6%L`%!E<G-O;F%L:71Z974@;&5S('1A<W%U97,@<75E(',G:&%N(&5X
M96-U=&%R('%U86X@<R=I;FEC:6$@;&$@<V5S<VGS(&$@)7,N`%)E=&%L;&%R
M`%)E=&%L;&%R(&QA('-E;&5C8VGS`%AI<')E`$-I<NULMVQI8R`H2T])."U2
M*0!#:7+M;+=L:6,@*%=I;F1O=W,M,3(U,2D`0VER[6RW;&EC+U5C<F'O;NAS
M("A+3TDX+54I`%)E</IB;&EC82!4>&5C80!$1`!$:>!R:6%M96YT`$YA=F5G
M861O<B!D92!$871A5')E90!$871A`%,G:&$@<F5B=70@;&$@9&%T80!396QE
M8V-I\R!D92!D871A`$1I80!3=7!R:6UI<B!C;VQU;6YA`$1E<V5M8G)E`$YO
M;6)R97,@9&5C:6UA;',`4F5D=>]U(&5L('-A9VYA=`!0<F5D971E<FUI;F%T
M`$-O;&]R('!R961E=&5R;6EN870`261E;G1I=&%T('!R961E=&5R;6EN861A
M`$1E9FEN:6-I;VYS`%-U<')I;6ER`%-U<')I;6ER(&=R=7``4W5P<FEM:7(@
M<&5R;>US`%-U<')I;6ER(&D@8G5I9&%R(&UI<W-A=&=E<P!3=7!R:6UI<B!C
M96RW;&$`4W5P<FEM:7(@8V]L=6UN80!3=7!R:6UI<B!L82!P;&%N=&EL;&$@
M86QT97)N871I=F$@97AI<W1E;G0`4W5P<FEM:7(@9FEL80!3=7!R:6UI<B!L
M82!I9&5N=&ET870@<V5L96-C:6]N861A`%-U<')I;6ER(&QA(&-O;'5M;F$@
M86-T=6%L`%-U<')I;6ER(&QA(&9I;&$@86-T=6%L`$AO<F$@9&4@;&QI=7)A
M;65N=`!$:6YA;6%R8V$`1&5S8W)I=FEU(&5L('!R;V)L96UA`$1E<V-R:7!C
M:?,`1&5T86QL<R`H=&%M8ND@86P@9FET>&5R(&1E(')E9VES=')E(&1E($AO
M<F1E*3H`16QS(&1E=&%L;',@:&%N(&5S=&%T(')E9VES=')A=',@<&5R(&$@
M;"=A9&UI;FES=')A9&]R+@!$97-E;G9O;'5P86UE;G0`4'5N="!D92!R;W-A
M9&$`4'5N="!D92!R;W-A9&$@9&4@;&$@9&%R<F5R82!H;W)A.@!0=6YT(&1E
M(')O<V%D83H@`$0G97-Q=65R<F$@82!D<F5T80!$92!D<F5T82!A(&5S<75E
M<G)A`$1I<F5C=&]R:0!6;VQS('9I<W5A;&ET>F%R+6AO(&5N(&9O<FUA="!D
M92`R-"!H;W)E<S\`3W!C:6]N<R!D92!V:7-U86QI='IA8VGS`$UO<W1R82!L
M82!P<F5V:7-I\R`H5$%&*0!&;W)M870@9&4@=FES=6%L:71Z86-I\P!.;W1I
M9FEC86-I\R!D92!R96-E<&-I\P!$:FEB;W5T:0!.;R!H;R!S=7!R:6UI=0!.
M;R!A8V-E9&EU(&1I<F5C=&%M96YT(&$@;6%I;G1E;F%N8V4N<&AP`$QA('!R
M:6UE<F$@9FEL82!C;VYTZ2!E;',@;F]M<R!D96QS(&-A;7!S/R!%;B!C87,@
M869I<FUA=&EU+"!A8W1I=F$@87%U97-T82!C87-E;&QA.@!$;VUI;FEC80!2
M97#Z8FQI8V$@1&]M:6YI8V%N80!$97-C87)R96=A<@!$97-C87)R96=A<B`E
M<P!$97-C87)R96=A<B!L82!C;VYF:6=U<F%C:?,@9V5N97)A9&$@8V]M('5N
M82!S97'\Z&YC:6$@4$A0+@!,;&ES=&$@9&5S<&QE9V%B;&4`1')O9W5E<P!#
M;W)R974@96QE8W1R\FYI8P!%4E(`17%U861O<@!%9&ET80!%9&ET82!B;&]C
M`$5D:71A(&=R=7``161I=&$@<&5R;>US`$5D:71A('!E<FUI<V]S`$5D:71A
M('!E<FUI<V]S(&1E("5S`$5D:71A(&]P8VEO;G,@9&4Z`$5D:71A('!E<FUI
M<V]S(&1E("5S`$5D=6-A8VGS`$5G:7!T90!%;"!386QV861O<@!%;&5M96YT
M+BXN`%%U861R873M`$-O<G)E=2!E;&5C='+R;FEC`$%D<F7G82!E;&5C='+R
M;FEC80!,97,@861R96-E<R!E;&5C='+R;FEQ=65S(&AA;B!D92!C;VEN8VED
M:7(N`$-O<G)E=2!E;&5C='+R;FEC(&%M8B!C;VYF:7)M86-I\P!%;6]T:6-O
M;F5S`$UI<W-A=&=E(&5N(&)L86YC+@!297-U;'1A="!E;B!B;&%N8RX`0G5I
M9&%R(&5L<R!T97)M97,@9&4@8V5R8V$`2&%B:6QI=&%R(&QA(&EN<V5R8VGS
M(&1E(&EM871G97,@9&4@;&5S(&=A;&5R:65S(&1E(&9O=&]S(&5N(&5L('1E
M>'0_`$AA8FEL:71A<B!E;"!M96[Z(&1E(&-O;G1E>'0@8VQI8V%N="!E;B!E
M;"!B;W3S(&1R970_`$%N>2!D92!F:6YA;&ET>F%C:?,`06UP;&EA<B!L)V5D
M:71O<@!);G1R;V1U[W4@=6YA('!R96=U;G1A(&1E('-E9W5R971A="!Q=64@
M<V4@=7,@9F]R;75L87+@('-I('5S(&-A;"!R96EN:6-I87(@;&$@8V]N=')A
M<V5N>6$L('!E<B!E>&5M<&QE("=C;VT@97,@9&EU(&5L('9O<W1R92!A;FEM
M86P@9&4@8V]M<&%N>6EA/R<Z`$EN=')O9'7O=2!A<77M(&5L(%523"!D92!L
M82!I;6%T9V4`1W5I;F5A($5Q=6%T;W)I86P`17)I=')E80!%<G)O<@!(:2!H
M82!H86=U="!U;B!E<G)O<B!A;6(@96P@;6ES<V%T9V4@96QE8W1R\FYI8RX`
M17-T\FYI80!%=&GR<&EA`,AT;FEC`$5U<F]P80!#861A(#$U(&UI;G5T<P!#
M861A(#(@;6EN=71S`$-A9&$@,S`@<V5G;VYS`$-A9&$@-2!M:6YU=',`0V%D
M82!I;FEC:2!D92!S97-S:?,`0V%D82!M:71J82!H;W)A`$-A9&$@;6EN=70`
M5F%L;W)S(&0G97AE;7!L93H`17AE8W5T80!%>'!A;F1E:7@`17AP86YD:7(@
M;&$@8F%R<F$@;&%T97)A;`!3)V5S<&5R879A("<I)P!3)V5S<&5R879A('5N
M('-O;"!M;W0@;R!U;B!T97)M92!D92!C97)C82!C:71A=`!$871A(&1E('9E
M;F-I;65N=`!%>'!O;F5N=`!#;VQO<B!D92!P<FEM97(@<&QA`$/@<G)E9V$@
M9&4@;&$@8V]N9FEG=7)A8VGS(&1E;"!&5%``R7,@:6UP;W-S:6)L92!R96-U
M<&5R87(@;&5S('!R969E<NAN8VEE<RX`R7,@:6UP;W-S:6)L92!C;VYN96-T
M87(@86UB(&5L('-E<G9I9&]R($Q$05`N`,ES(&EM<&]S<VEB;&4@8V]N;F5C
M=&%R(&%M8B!E;"!S97)V:61O<B!334(N`,ES(&EM<&]S<VEB;&4@8V]P:6%R
M(&1E("(E<R(N`,ES(&EM<&]S<VEB;&4@8V]P:6%R(&$@(B5S(BX`R7,@:6UP
M;W-S:6)L92!C<F5A<B!U;F$@;F]V82!C;VYN97AI\R!305-,+@#)<R!I;7!O
M<W-I8FQE('1R86YS9F5R:7(@82`B)7,B+@#)<R!I;7!O<W-I8FQE(')E8W5P
M97)A<CH@)7,`0VQA<@!);&QE<R!&86QK;&%N9"`H36%L=FEN97,I`$EL;&5S
M($;H<F]E`$5R<F]R(&ER<F5C=7!E<F%B;&4@`$9A>`!&96)R97(`4V4@<V5N
M="!C;VT`4V4@<V5N="!C;VTZ`%!O<75E<R!P;'5G97,`4&]C<R!XX&9E8W,@
M9&4@;F5U`$UA=')I=2!D96P@8V%M<`!&:6II`%)E8V]M<'1E(&0G87)X:75S
M.B!A<GAI=2`E<P!296-O;7!T92!D)V%R>&EU<SH@)7,@87)X:75S`$=E<W1O
M<B!D)V%R>&EU<P!.;VT@9&4@;"=A<GAI=0!396QE8V-I\R!D)V%R>&EU<P!#
MX')R96=A(&1E(&PG87)X:74`3F\@Z7,@<&5R;>AS('!E;FIA<B!A<GAI=7,`
M1FEL=')E<P!&:6YLX&YD:6$`4')I;65R82!M96ET870`4')I;65R('%U87)T
M`%)A\R!F:7AA(R,`26YV97)T:74`0V]M82!F;&]T86YT`$)O:7)A`$QA(&-A
M<G!E=&$@)7,@;F\@97AI<W1E:7@`0V]L;W(@9&4@;&$@9F]N=`!-96YJ87(`
M4&5R(&%L<R!N879E9V%D;W)S('%U92!N;R!A9&UE=&5N(&QE<R!I;6%T9V5S
M`%!R979I<VGS("A4048I`%!R979I<VGS('!E<B!A;',@9&EE<R`H=&EN9W5E
M=2!P<F5S96YT('%U92!L82!P<F5V:7-I\R!F86-I;&ET861A(&-O;7!RZ&X@
M96P@9&EA(&D@;&$@;FET.B!U;B!N;VUB<F4@96QE=F%T('!O9')I82!T96YI
M<B!C;VT@82!R97-U;'1A="!U;B!B;&]C(&%M<&QE+@!(974@;V)L:61A="!L
M82!C;VYT<F%S96YY83\`1F]R;75L87)I<P!$:71A`%1I<'5S(&1E(&1I=&5S
M`$1I=&5S`$1I=&5S(#(`1O)R=6US`%)E96YV:6%M96YT<P!$=BX`36%R8W,`
M1G)A;N=A`$9R86[G82!M971R;W!O;&ET86YA`$=U86EA;F$@1G)A;F-E<V$`
M4&]L:6[H<VEA($9R86YC97-A`%1E<G)I=&]R:7,@1G)A;F-E<V]S(&1E;"!3
M=60`1&5S(&1E`$1E<R!D96P`1&5S8W)I<&-I\R!C;VUP;&5T80!,;'5N82!P
M;&5N80!.;VT@8V]M<&QE=`!'86)O;@!,82!G86QE<FEA(&1E(&QA('%U86P@
M<R=E>'1R974@;&$@:6UA=&=E`$=A;&5R:6$`1^!M8FEA`$5S(&=E;F5R82!L
M82!C;VYF:6=U<F%C:?,@)7,`0V]D:2!G96YE<F%T`$=E\G)G:6$`06QE;6%N
M>6$`1VAA;F$`1VEB<F%L=&%R`$YO;2!D92!P:6QA`$%N87(@80!']F1E;`!#
M97)C82!A;"!';V]G;&4`17-C86QA(&1E(&=R:7-O<P!'<NAC:6$`1W)E8R`H
M25-/+3@X-3DM-RD`1W)E;FS@;F1I80!'<F%N861A`$=E<W1I\R!D92!G<G5P
M<P!%;',@;F]M<R!D92!G<G5P(&YO(&5S('!O9&5N(&1E:7AA<B!E;B!B;&%N
M8P!'<G5P<P!'=6%D86QU<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4&5R
M;6ES;W,@9&5L<R!V:7-I=&%N=',`3&QI8G)E(&1E('9I<VET86YT<P!'=6EN
M96$`1W5I;F5A($)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!N;R!P97)M
M970@<W5P<FEM:7(@;&$@9&%R<F5R82!C96RW;&$@9&4@;&$@9FEL82X`2%1-
M3$%R96$@;F\@<&5R;65T('-U<')I;6ER(&QA(&1A<G)E<F$@8V]L=6UN82!D
M92!L82!T875L82X`2%1-3$%R96$@;F\@<&5R;65T('-U<')I;6ER(&QA(&1A
M<G)E<F$@9FEL82!D92!L82!T875L82X`3F\@<R=H82!T<F]B870@;"=A=71E
M;G1I8V%C:?,@2%144"X`2&%I=.T`06QG;W)I<VUE(&1E(&AA<V@`0V%L:71J
M80!#87#G86QE<F$`26QL82!(96%R9"!I(&EL;&5S($UC1&]N86QD`$AE8G)E
M=2`H25-/+3@X-3DM."U)*0!!;.=A9&$`06IU9&$`06IU9&$@<&5R('5T:6QI
M='IA<B!L)V5D:71O<@!!<&QI8V%C:?,@9"=A:G5D80!(96UI<V9E<FD`07%U
M97-T(.ES(&PG:6YI8VD@9&5L(&9I='AE<CH`06QT`$EN:6-I`&QA(%-A;G1A
M(%-E=2`H0VEU=&%T($5S=&%T(&1E;"!6871I8^`I`$EN:6-I`$%D<F7G82!P
M87)T:6-U;&%R`%1E;.AF;VX@<&%R=&EC=6QA<@!(;VYD=7)E<P!(;VYG($MO
M;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%,G:&%N('1R;V)A="!D861E<R!834P@
M)7,@;F\@=N!L:61E<R!E;B!E;"!M:7-S871G92`E<P!(;W)D92]+;VQA8CH@
M3F\@:&D@:&$@8V%P(&UI<W-A=&=E('%U92!E<R!C;W)R97-P;VYG=6D@86UB
M(&PG;V)J96-T92`E<P!(;W)D92]+;VQA8CH@3F\@<R=H82!T<F]B870@8V%P
M(&]B:F5C=&4@9&5L('1I<'5S("5S(&5N(&5L(&UI<W-A=&=E("5S`$AO<F1E
M+TMO;&%B.B`E<R`B)7,B(&AA(&5S=&%T(&5X=')E="!C;W)R96-T86UE;G0`
M2&]R9&4O2V]L86(Z($5L(&UO=&]R(&0G:6YT96=R86-I\R!N96-E<W-I=&$@
M;"=E>'1E;G-I\R!02%`@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($YO(',G:&$@
M<&]G=70@8W)E87(@=6X@;F]U(&%R8G)E(%A-3"!P97(@82!L)V]B:F5C=&4@
M)7,`2&]R9&4O2V]L86(Z($YO(',G:&$@<&]G=70@97AT<F5U<F4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z($YO(',G:&$@<&]G=70@<F5C=7!E<F%R(&PG
M:61E;G1I9FEC861O<B!-24U%('!E<B!A(&QA('!A<G0@9&5L('1I<'5S("5S
M`$AO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA<B`E<R(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA
M<B!L97,@<75O=&5S.B`E<P!(;W)D92]+;VQA8CH@17-P86D@9&ES<&]N:6)L
M92!D97-C;VYE9W5T("(E<R(`4F5G;&$@:&]R:71Z;VYT86P`1F%R8VEM96YT
M(&AO<FET>F]N=&%L`$AO<FET>F]N=&%L.@!#;VT@:&5U(&%R<FEB870@9FEN
M<R!A<77M/R`H1F5U+6YO<RUH;R!S86)E<B$I`%%U86YT97,@8V]L=6UN97,@
M=F]L974@<F5F;VYD<F4_`%%U86YT<R!C86UP<R`H8V]L=6UN97,I(&AI(&AA
M/P!1=6%N=&5S(&9I;&5S('9O;&5U(')E9F]N9')E/P!(=6UI=&%T`$AU;6ET
M870Z`$AU;6]R:7-T97,`2&]N9W)I80#)<R!I;7!O<W-I8FQE(&-R96%R(&QA
M(&+Z<W1I82!)34%0.B`E<P#)<R!I;7!O<W-I8FQE('-U<')I;6ER(&QA(&+Z
M<W1I82!)34%0.B`E<P#)<R!I;7!O<W-I8FQE(&-R96%R('5N(&5S<&%I(&1I
M<W!O;FEB;&4@<&5R(&$@;&$@8OIS=&EA($E-05`Z("5S`$%D<F7G82!)4`!,
M)V%D<F7G82!)4"!N;R!E<W3@(&1I<W!O;FEB;&4N`$PG861R9>=A($E0(&YO
M(&5S('1R;V)A(&5N(&5L(&)L;V,@0TE$4B!P97)MZ',N`%9I;VQA8VGS(&1E
M;"!B;&]Q=65I9R!)4"X`26YS97)I=2!U;F$@9FEL82!D86UU;G0`27-LX&YD
M:6$`3F]MZ7,@:6-O;F5S`$EC;VYE<R!D92`E<P!)8V]N97,@86UB('1E>'0`
M3F]M(&0G:61E;G1I=&%T.@!3:2!N;R!E<R!V:7-U86QI='IA(&-O<G)E8W1A
M;65N="P@;V)R:74@)7,@96X@=6YA(&YO=F$@9FEN97-T<F$N`%-I(&YO('9I
M<W5A;&ET>F5U(&-A<"!I8V]N82!M:71J86[G86YT(&PG26YT97)N970@17AP
M;&]R97(L(.ES('!O<W-I8FQE('%U92!HX&=I=2!D)V%C=&EV87(@87%U97-T
M('%U861R92!P97(@9&5S86-T:79A<B!L82!T<F%N<W!A<NAN8VEA(&1E(%!.
M1RX`4VD@=F5I974@87%U97-T(&UI<W-A=&=E(&5N(&QL;V,@9&4@;&$@:6UA
M=&=E+"!E;"!V;W-T<F4@;F%V96=A9&]R(&YO('!O="!M;W-T<F%R(&QA(&EM
M871G92!Q=64@=F]L974@<&5N:F%R+@!6:7-U86QI='IA8VGS('!RZ'9I82!D
M92!L82!I;6%T9V4Z`%523"!D92!L82!I;6%T9V4`55),(&1E(&QA(&EM871G
M93H`26UA=&=E(&1E(&QA(&=A;&5R:6$`26UA=&=E(&1E(&QA(&=A;&5R:6$Z
M`$/@<G)E9V$@9&4@;&$@:6UA=&=E`$EM871G97,`26UP;W)T86-I\RP@<&%S
M("5D`$-A;7`@:6UP;W)T870Z("5S`$-A;7!S(&EM<&]R=&%T<SH`26YS97)I
M=2!U;F$@9FEL82!A('-O=&$`16P@8V]D:2!D92!L)V%C8VGS('%U92!S)VAA
M(&9A8VEL:71A="#I<R!I;F-O<G)E8W1E+@!.;VT@9"=U<W5A<FD@:2]O(&-O
M;G1R87-E;GEE<R!I;F-O<G)E8W1E<RX`4R=H82!F86-I;&ET870@=6X@;F]M
M(&0G=7-U87)I(&\@=6YA(&%D<F7G82!A;'1E<FYA=&EV82!I;F-O<G)E8W1E
M<RX@5&]R;F5U+6AO(&$@:6YT96YT87(@;R!P;W-E=2UV;W,@96X@8V]N=&%C
M=&4@86UB(&PG861M:6YI<W1R861O<B!P97(@82!MZ7,@86IU9&$N`$%U9VUE
M;G1A<B!E;"!S86=N870`S6YD:6$`57-U87)I<R!I;F1I=FED=6%L<P!);F1O
M;NAS:6$`26YF;W)M86-I\P!);F9O<FUA8VGS`$EN:6-I86QI='IA;G0@;?)D
M=6P@)7,N+BX@`$EN<V5R96EX('5N82!C;VQU;6YA(&$@<V]T80!);G-E<F5I
M>"!U;F$@:6UA=&=E`$EN<V5R96EX('5N82!T875L80!);G-E<F5I>"!E;FQL
M8><@=V5B`$EN<V5R96EX(&QA(&-O;'5M;F$@9&%M=6YT`$EN<V5R96EX('5N
M82!N;W9A(&-O;'5M;F$@82!S;W1A(&1E(&PG86-T=6%L`$EN<V5R96EX('5N
M82!N;W9A(&-O;'5M;F$@82!S;V)R92!D92!L)V%C='5A;`!);G-E<F5I>"!U
M;F$@;F]V82!F:6QA(&$@<V]T82!D92!L)V%C='5A;`!);G-E<F5I>"!U;F$@
M;F]V82!F:6QA(&$@<V]B<F4@9&4@;"=A8W1U86P@`$EN<V5R96EX('5N('!A
M<N!G<F%F(&$@<V]T82!D96P@;F]D92!A8W1U86P`26YS97)E:7@@=6X@<&%R
MX&=R868@82!S;V)R92!D96P@;F]D92!A8W1U86P`26YS97)E:7@@;"=A;'1R
M82!P;&%N=&EL;&$`26YS97)E:7@@=6YA(&%D<F7G82!D92!C;W)R974@<&5R
M(')E8G)E(&QA(&YO=F$@8V]N=')A<V5N>6%);G-E<FEU('5N82!A9')EYV$@
M96QE8W1R\FYI8V$@82!L82!Q=6%L('!O9&5U(')E8G)E(&QA(&YO=F$@8V]N
M=')A<V5N>6$Z`$EN<V5R96EX('5N82!C96RW;&$@82!S;W1A`$EN<V5R96EX
M('5N82!C96RW;&$@82!S;V)R90!);G-E<FEU('5N82!C;VQU;6YA(&$@<V]T
M80!);G-E<FEU('5N82!C;VQU;6YA(&$@<V]B<F4`26YS97)I=2!M:7-S871G
M97,`26YS97)I=2!U;B!P87+@9W)A9B!A('-O=&$`26YS97)I=2!U;B!P87+@
M9W)A9B!A('-O8G)E`$EN<V5R:74@=6YA(&9I;&$@82!S;W1A`$EN<V5R:74@
M=6YA(&9I;&$@82!S;V)R90!);G-E<FEU(&QA(')E<W!O<W1A(&$@;&$@<')E
M9W5N=&$@9&4@<V5G=7)E=&%T.@!);G-E<FER+TUO9&EF:6-A<B!I;6%T9V4`
M26YS97)I<B]-;V1I9FEC87(@96YL;&'G`$YO(&1I<W!O<V5U(&1E('!R;W4@
M8W+H9&ET('!E<B!E;G9I87(M;&\@82!L82!L;&ES=&$@9&4@9&ES=')I8G5C
M:?,N`$-RZ&1I="!I;G-U9FEC:65N="X`3F]M8G)E(&5N=&5R`$QL:7-T82!D
M92!N;VUB<F5S(&5N=&5R<P!51$@@;F\@=N!L:61A+B`H0V%PYV%L97)A(&1E
M(&1A9&5S(&0G=7-U87)I*2X`07!L:6-A8VGS(&YO(';@;&ED82X`3"=I9&5N
M=&EF:6-A9&]R(&1E;"!L;W0@;F\@Z7,@=N!L:60`3&5S(&1A9&5S('%U92!S
M)VAA;B!T<F%MZ',@;F\@<_-N(';@;&ED97,N`$PG861R9>=A(&1E(&1E<W1I
M;F%C:?,@;F\@Z7,@=N!L:61A+@!%;"!F;W)M870@9&4@;"=A<GAI=2!N;R#I
M<R!VX&QI9"X`3&$@8VQA=2!D92!L82!L;&ECZ&YC:6$@;F\@Z7,@=N!L:61A
M+@!,82!U8FEC86-I\R!Q=64@:&5U('!R;W!O<F-I;VYA="!N;R#I<R!VX&QI
M9&$N`$5L('1I<'5S+6US9R!N;R#I<R!VX&QI9"X`36%N8V$@96P@87!I7VED
M(&\@96P@<75E(',G:&$@9F%C:6QI=&%T(&YO(.ES(';@;&ED+@!-86YQ=65N
M('!A<N!M971R97,@;R!E;',@<75E(',G:&%N(&9A8VEL:71A="!N;R!S\VX@
M=N!L:61S+@!,)V%U=&]R:71Z86-I\R!P871E<FYA(&YO(.ES(';@;&ED82X`
M16P@8V]D:2!D)VED96YT:69I8V%C:?,@9&4@<V]C:2!N;R#I<R!VX&QI9"X`
M16P@8V]D:2!D96P@<')O9'5C=&4@;F\@Z7,@=N!L:60N`$5L('!R;W1O8V]L
M(&YO(.ES(';@;&ED+@!,)V]B:F5C=&4@8V]M<&%R=&ET(&YO(.ES(';@;&ED
M`$PG861R9>=A(&0G;W)I9V5N(&YO(.ES(';@;&ED82X`3&5S(&1A9&5S(%5N
M:6-O9&4@;F\@<_-N(';@;&ED97,N`$EN=F5N=&%R:0!)<F%N+"!297#Z8FQI
M8V$@27-LX&UI8V$@9"<`27)A<0!)<FQA;F1A`$EL;&$@9&4@36%N`%1E;7!E
M<W1E<R!A[VQL861E<P!)<W)A96P`16UI<W-O<@!#=7)S:79A`$ETX&QI80!*
M86UA:6-A`$=E;F5R`$IA</,`2F%P;V[H<R`H25-/+3(P,#(M2E`I`$IE<G-E
M>0!*;W)DX&YI80!*=6QI;VP`2G5N>0!*=7-T:69I8V%R`$IU<W1I9FEC87(@
M86P@8V5N=')E`$IU<W1I9FEC87(@82!T;W1S(&1O<R!M87)G97,`2G5S=&EF
M:6-A<B!A(&PG97-Q=65R<F$`2G5S=&EF:6-A<B!A(&QA(&1R971A`$MA>F%K
M:'-T86X`5F]L974@8V]N<V5R=F%R(&PG;W)I9VEN86P_`$ME;GEA`$5L('-E
M<G9I9&]R($ME<F)E<F]S(&AA(')E8G5T:F%T(&PG875T96YT:6-A8VGS+@!+
M97)N96P@3F5W8FEE<P!#<F5A8VGS(&1E(&-L875S`$5M<')E;71A(&1I9VET
M86P@9&4@;&$@8VQA=0!,;VYG:71U9"!D92!L82!C;&%U`%1I<'5S(&1E(&-L
M874`VG,@9&4@;&$@8VQA=0!*82!E>&ES=&5I>"!U;F$@8VQA=2!E;B!E;"!S
M97)V:61O<B!D92!C;&%U<R!P^F)L:7%U97,N`$YO:7,`2VER:6)A=&D`0V]R
M96$L(%)E</IB;&EC82!$96UO8W+@=&EC82!0;W!U;&%R(&1E`$-O<F5A+"!2
M97#Z8FQI8V$@9&4`0V]R9>`@*$550RU+4BD`2W5W86ET`$MI<F=U:7II<W1A
M;@!&;W)M870`261I;VUA`%)E</IB;&EC82!$96UO8W+@=&EC82!0;W!U;&%R
M(&1E($QA;W,`1&%R<F5R82!M96ET870`1&%R<F5R('%U87)T`$1A<G)E<F$@
M86-T=6%L:71Z86-I\SH`1&%R<F5R82!C;VYN97AI\SH@)7,`1&%R<F5R82!C
M;VYN97AI\SH@)7,@9&4@)7,`1&%R<F5R82!C;VYN97AI\SH`3&5T\FYI80!,
M;&5I`$1I<W-E;GD`1&5I>&%R+6AO(&5N(&)L86YC('!E<B!E;&EM:6YA<B!E
M;"!C;VYT;W)N`$SM8F%N`$5S<75E<G)A`$-A<.=A;&5R82!E<W%U97)R80!6
M86QO<G,@9&4@;"=E<W%U97)R80!,97-O=&AO`$QI8NAR:6$`3.UB:6$`3&EE
M8VAT96YS=&5I;@!0;'5G:6T@9F5B;&4`4&QU:F$@9F5B;&4`4&QU:F$@9F5B
M;&4@82!P<FEM97)A(&AO<F$`4&QU:F$@9F5B;&4@8V%P(&%L('1A<F0`4G5I
M>&%T(&9E8FQE`%)U:7AA="!F96)L92!A;6(@=')O;G,`3F5V861A(&9E8FQE
M`%C@9F5C(&1E(&YE=2!F96)L90!,:6UE<FEC:P!%;FQL8><`16YL;&%CYV%R
M(&5L<R!P=6YT<R!A;6(Z`$5N;&QAYV%R(&PG861R9>=A(&5L96-T<O)N:6-A
M(&$@;&$@<.!G:6YA(&1E(')E9&%C=&%T('%U86X@97,@;6]S=')I`$5N;&QA
MYV]S`$=A;&5T82!,:6YU>`!,;&ES=&%R("T@3"=U<W5A<FD@<&]T('9E=7)E
M(&QA(&-A<G!E=&$`3&QI<W1A<B!L97,@8F%S97,@9&4@9&%D97,`3&QI<W1A
M(&1E;',@=&5M97,@9"=A:G5D80!,;&ES=&%R(&QE<R!T875L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&$@;&QI<W1A(&0G
M=7-U87)I<R!E<W3@(&EN:&%B:6QI=&%D82X`0FEB;&EO9W)A9FEA`$QI='7@
M;FEA`%,G97-TX"!C87)R96=A;G0N+BX`2&]R82!L;V-A;#H@`$ED:6]M82!I
M(&AO<F$`56)I8V%C:?,`26YI8VEA(&QA('-E<W-I\P!3=7)T`%1A<W%U97,@
M9"=I;FEC:2!D92!S97-S:?,`2&D@:&$@:&%G=70@=6X@97)R;W(@9&4@8V]N
M;F5X:?,@<&5R<77H(&AE=2!I;G1R;V1U[W0@:6YC;W)R96-T86UE;G0@96P@
M;F]M(&0G=7-U87)I(&\@;&$@8V]N=')A<V5N>6$N`$AA(&9A;&QA="!L82!C
M;VYN97AI\RX`5&5X="!L;&%R9P!!;6]R`$)A:7@`06QF86)E="!G<F5C(&5N
M(&UI;OIS8W5L80!!;&9A8F5T(&QL873M(&5N(&UI;OIS8W5L80!8:69R97,@
M<F]M86YE<R!E;B!M:6[Z<V-U;&$`3'5X96UB=7)G`$U-`$U/5$0`3"=A<GAI
M=2!A9&IU;G0@35,M5$Y%1B!N;R!C;VYT96YI82!D861E<RX`35-'`$UA8V%U
M`$UA8V5D\FYI82P@06YT:6=A(%)E</IB;&EC82!)=6=O<VQA=F$@9&4`36%D
M86=A<V-A<@!-X&=I8P!#;W)R974@96QE8W1R\FYI8P!!9&UI;FES=')A9&]R
M(&1E(&-O<G)E=0!3)V5S=.`@8W)E86YT('5N(&5N;&QAYRXN+@!-86QA=VD`
M36%LX&ES:6$`36%L9&EV97,`36%L:0!-86QT80!'97-T:6]N974@;&$@;&QI
M<W1A(&1E(&-A=&5G;W)I97,@86UB(&QE<R!Q=6%L<R!H974@9"=E=&EQ=65T
M87(@96QS(&5L96UE;G1S+"!I(&5L<R!C;VQO<G,@87-S;V-I871S(&%M8B!A
M<75E<W1E<R!C871E9V]R:65S+@!-87!A($UA<#(T`$UA<&$@36%P475E<W0`
M36%RYP!-87)G90!-87)C87(@86UB(&EN9&EC861O<G,@=FES:6)L97,O:6YV
M:7-I8FQE<P!-87)C87(@86UB(&%L=')E<R!I;F1I8V%D;W)S("AP+B!E+BP@
M:6UP;W)T86YT+W)E<W!O<W0I`$EL;&5S($UA<G-H86QL`$UA<G1I;FEC80!#
M86UP<R!Q=64@8V]I;F-I9&5I>&EN`$UA=7)I=.!N:6$`36%U<FEC:0!#<NAD
M:70@;>!X:6T@<&5R;>AS+@!3)VAA('-U<&5R870@96P@;F]M8G)E(&W@>&EM
M(&1E('!A<G1S(&1E(&UI<W-A=&=E+@!496UP97)A='5R82!MX'AI;6$@9&4@
M;&5S(&1A<G)E<F5S(#(T(&AO<F5S.B``5&5M<&5R871U<F$@;>!X:6UA(&1E
M(&QE<R!D87)R97)E<R`V(&AO<F5S.B``3&]N9VET=60@;>!X:6UA`$UA:6<`
M36%Y;W1T90!-961I8VEN80!-96UB<F5S`%1I<'5S(&1E(&UE;OHZ`%)E9F]N
M87(@;&5S(&-E;+=L97,`36ES<V%T9V4`16P@;6ES<V%T9V4@:&$@97-T870@
M=F5R:69I8V%T(&-O<G)E8W1A;65N="P@<&5R\B!N;R!S)VAA('!O9W5T('9E
M<FEF:6-A<B!E;"!C97)T:69I8V%T(&5L('-I9VYA;G0N`$UI<W-A=&=E(&-A
M9'5C870N`%1I<'5S(&1E(&UI<W-A=&=E`%1E;7!S(&1E($U%5$%2`$5L(&)L
M;V,@345405(@;F\@97-TX"!D:7-P;VYI8FQE+@!%;"!B;&]C($U%5$%2(&YO
M(&5S=.`@9&ES<&]N:6)L92X@16QS(&1E=&%L;',@:&%N(&5S=&%T(')E9VES
M=')A=',@<&5R(&$@;"=A9&UI;FES=')A9&]R+@!,82!B87-E(&1E(&1A9&5S
M($U%5$%2(&YO(&5S=.`@8V]N;F5C=&%D82X`3>AT;V1E`$WH=')I8P!-Z'AI
M8P!-:6-R;V[H<VEA+"!%<W1A=',@1F5D97)A=',@9&4`0V5N=')E`%1I<'5S
M($U)344`5&5M<&5R871U<F$@;>UN:6UA(&1E(&QE<R!D87)R97)E<R`R-"!H
M;W)E<SH@`%1E;7!E<F%T=7)A(&WM;FEM82!D92!L97,@9&%R<F5R97,@-B!H
M;W)E<SH@`%+H<&QI8V$`36ES8V5LMVQA;FD`1F%L=&$@;&$@<V]LMVQI8VET
M=60@2%144"!P97(@86P@<&%Q=65T(%!%05(N`$9A;'1A(&QA(&-O;F9I9W5R
M86-I\RX@3"=H974@9&4@9V5N97)A<B!A<F$@<VD@=F]L974@=71I;&ET>F%R
M(&%Q=65S=&$@87!L:6-A8VGS+@!&86QT82!L)VED96YT:69I8V%D;W(@9&5L
M(&UI<W-A=&=E+@!&86QT82!E;"!C;W)R974@96QE8W1R\FYI8R!D96P@<&%Q
M=65T(%!%05(@;F5C97-S87)I+@!&86QT82!L)VED96YT:69I8V%D;W(@9&4@
M<V5S<VGS+@!$;"X`0V]R<F5U(&WR8FEL`$UO9&5R870`1&%T82!M;V1I9FEC
M861A`$UO9&EF:6-A<B!L82!54DP`3?)D=6P`36]L9.!V:6$L(%)E</IB;&EC
M82!D90!-\FYA8V\`36]N9_)L:6$`365S(&D@86YY`$UE;G-U86QM96YT`$UO
M;G1S97)R870`1F%S97,@;'5N87)S`$UA<G)O8P!-86IO<FETX')I86UE;G0@
M9&5S8V]B97)T`$UA:F]R:73@<FEA;65N="!E;FYU=F]L870`36%J;W)I=.!R
M:6%M96YT(&%S<V]L96QL870`36]U<F4@8V%P(&%V86QL`$UO=7)E(&$@;"=E
M<W%U97)R80!-;W5R92!A(&QA(&1R971A`$UO=7)E(&-A<"!A;75N=`!-;W5R
M92!C87`@879A;&P`36]U<F4@8V%P(&%M=6YT`$UOYV%M8FEC`$QI<W1E<R!D
M97-P;&5G86)L97,@96YL;&'G861E<R!E;B!D:79E<G-O<R!N:79E;&QS`%-E
M;&5C8VGS(&WZ;'1I<&QE`$5L(&UE=2!C;VUP=&4`16P@;65U('!O<G1A;`!$
M:7-S96YY(&1E;"!M974@<&]R=&%L`$UY86YM87(`3D\L($Y/(&AI(&5S=&EC
M(&0G86-O<F0`3F]M`$YA;>UB:6$`3F%U<G4`3F5P86P`4&'O<V]S($)A:7AO
M<P!!;G1I;&QE<R!.965R;&%N9&5S97,`55),(&)A<V4@9&4@3F5T<V-A<&4`
M55),(&1E(')E=F]C86-I\R!D92!#02!D92!.971S8V%P90!54DP@9&4@<&]L
M[71I<75E<R!D92!#02!D92!.971S8V%P90!54DP@9&4@<F5N;W9A8VGS(&1E
M($YE='-C87!E`%523"!D92!R979O8V%C:?,@9&4@3F5T<V-A<&4`3F]M(&1E
M;"!S97)V:61O<B!34TP@9&4@3F5T<V-A<&4`0V]M96YT87)I(&1E;"!C97)T
M:69I8V%T(&1E($YE='-C87!E`%1I<'5S(&1E(&-E<G1I9FEC870@9&4@3F5T
M<V-A<&4`6&%R>&$`36%I`$YO=F$@0V%L963R;FEA`$YO=F$@8V%T96=O<FEA
M`$QL=6YA(&YO=F$`3F]U(&YO;2!D)W5S=6%R:2`H;W!C:6]N86PI`$YO=F$@
M6F5L86YD80!.;W9A(&9I;F5S=')A("A?96X@8FQA;F,I`$UI<W-A=&=E<P!'
M<G5P<R!D92!D:7-C=7-S:?,`4V5G_&5N=``T(&9A<V5S('-E9_QE;G1S`$]P
M8VEO;G,@<V5G_&5N=',`4V5G_&5N=#X`3FEC87)A9W5A`$[M9V5R`$YI9^AR
M:6$`3FET`$YI=64`3F\`3F\@97,@9&ES<&]S96X@9&4@9&%D97,@9&4@8V]N
M9FEG=7)A8VGS('!E<B!M;W-T<F%R(&QE<R!D:69E<NAN8VEE<RX`3F\@97,@
M9&ES<&]S82!D)W5N82!E<W1R873H9VEA('!E<B!C<F5A<B!I;6%T9V5S($E3
M3RX`3F\@:&D@:&$@<&QA;G1I;&QA(&1E(&QO=',N`$YO(&5X:7-T96EX(&-A
M<"!B;&]C(&5N(&QA('!O<VEC:?,@<V]LMVQI8VET861A`$YO(',G:&$@<')O
M<&]R8VEO;F%T('5N(&YO;2!D)V%G96YD82!P97(@82!L)V%U=&5N=&EC86-I
M\R!-0T%,+@!396YS92!C86YV:7,N`$YO(&5S('!O9&5N(&%F96=I<B!D97-C
M96YD96YT<R!A(&%Q=65S="!P97)M[7,`3F\@<R=H82!E<W!E8VEF:6-A="!L
M97,@9&%D97,@9&4@8V]N9FEG=7)A8VGS('!E<B!A("5S+@!.;R!S)VAA(&5S
M<&5C:69I8V%T(&QE<R!D861E<R!D92!C;VYF:6=U<F%C:?,@<&5R(&$@1E10
M('!E<B!61E,N`$YO(',G:&$@97-P96-I9FEC870@;&5S(&1A9&5S(&1E(&-O
M;F9I9W5R86-I\R!P97(@82!344P@<&5R(%9&4RX`3F\@<R=H82!E<W!E8VEF
M:6-A="!L97,@9&%D97,@9&4@8V]N9FEG=7)A8VGS(&1E(%-13"!P97(@86P@
M9FET>&5R(%-13"X`3F\@<75E9&$@8W+H9&ET+@!.;R!S)VAA(&9A8VEL:71A
M="!U;F$@9&5S=&EN86-I\RX`3F\@<R=H82!C87)R96=A="!C87`@87)X:74N
M`$YO(',G:&$@=')O8F%T(&-A<"!I8V]N82X`3F\@<R=H82!D969I;FET('5N
M82!U8FEC86-I\RX`3F\@<R=H82!F86-I;&ET870@=6YA('5B:6-A8VGS+@!.
M;R!S)VAA(&EN=')O9'7O="!U;B!M:7-S871G92X`3F\@<R=H82!E<W!E8VEF
M:6-A="!U;B!N;VTN`$YO(',G:&$@97-P96-I9FEC870@=6YA('AI9G)A+@!.
M;R!E<R!P97)M971E;B!L97,@9&ET97,@;V9E;G-I=F5S+@!.;R!S)VAA(&EN
M=')O9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@
M2%144"X`3F\@<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A
M(&PG875T96YT:6-A8VGS($E-05`N`$YO(',G:&$@:6YT<F]D=>]T('5N82!C
M;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!+97)B97)O<RX`3F\@
M<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT
M:6-A8VGS(&0G:6YI8VDN`$YO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S
M96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!005-35T0N`$YO(',G:&$@:6YT
M<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!3
M34(N`$YO(',G:&$@:6YD:6-A="!L82!V:6$@9"=A8V/I<R!A;"!B:6YA<FD@
M3W!E;E-33"X@0V%L(&5L(&)I;F%R:2!/<&5N4U-,('!E<B!T<F5B86QL87(@
M86UB(&QE<R!D861E<R!02T-3(#$R+@!.;R!H:2!H82!A;'1E<R!P96YD96YT
M<RX`3F\@<R=H82!D969I;FET(&PG97-P86D@9&ES<&]N:6)L92X`4V5N<V4@
M<F5G;&5S`%-E;G-E(&-A<F5S`$YO(&5X:7-T96EX(&%Q=65S="!A<GAI=0!.
M;R!E<R!D:7-P;W-A(&1E(&-A<"!D:7)E8W1O<FD@=&5M<&]R86P@<&5R(&$@
M;&$@;65M\G)I82!C874N`$YO(&AE=2!E;G9I870@96P@;F]M(&0G=7-U87)I
M(&YI+V\@;&$@8V]N=')A<V5N>6$`3F\@<R=H86X@<F5T;W)N870@9&%D97,@
M6$U,(';@;&ED97,`4V5N<V4@=F%L;W)S`$YO(',G:&$@=')O8F%T(&QA('9E
M<G-I\R!E;B!L82!C;VYF:6=U<F%C:?,@;W)I9VEN86PN(%)E9V5N97)E=2!L
M82!C;VYF:6=U<F%C:?,N`$YO(',G:&$@=')O8F%T(&QA('9E<G-I\R!E;B!L
M82!C;VYF:6=U<F%C:?,N(%)E9V5N97)E=2!L82!C;VYF:6=U<F%C:?,N`$-A
M<`!#87`@*/IS(&EM<&SM8VET*0!.\G)D:6,@*$E33RTX.#4Y+3$P*0!);&QA
M(&1E($YO<F9O;&L`2&5M:7-F97)I(&YO<F0`26QL97,@36%R:6%N;F5S(&1E
M;"!.;W)D`$YO<G5E9V$`3F\@9&5S<'+I<P!.;R!A8F%N<P!.;R#I<R!U;B!D
M:7)E8W1O<FD`3F\@:6UP;&5M96YT870N`$YO(&1E9FEN:70`3F\@<&5R;>AS
M+@!.;W1E<P!.;R!H:2!H82!R97,@82!V:7-U86QI='IA<BP@<F5T<F]C961I
M=2X`3F]V96UB<F4`3F]M8G)E`$YO;6)R92!D92!C87+@8W1E<G,`3F]M8G)E
M(&1E(&-O;'5M;F5S`$YO;6)R92!D92!F:6QE<P!.;R!S)VAA;B!E<W!E8VEF
M:6-A="!N;VUB<F5S('%U92!H86=I;B!D92!S97(@86-T=6%L:71Z871S(&5N
M(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I\RX`1"=A8V]R9`!/8FIE8W1E`$-R
M96%D;W(@9&4@;"=O8FIE8W1E`$]C=&%L`$]C='5B<F4`1FEL=')E(&0G:6YF
M<F%C8VEO;G,`3V9I8VEN80!/;6%N`$YO;>ES(&5L<R!S97)V:61O<G,@24U!
M4"!P97)M971E;B!L)_IS(&1E(&-A<G!E=&5S(&-O;7!A<G1I9&5S+@!.;VWI
M<R!M:7-S871G97,@;V9E;G-I=7,`3F]MZ7,@Z7,@<&5R;65S82!U;F$@^FYI
M8V$@861R9>=A(&5L96-T<O)N:6-A+@!.;VWI<R!E;"!P<F]P:65T87)I(&\@
M;"=A9&UI;FES=')A9&]R(&1E('-I<W1E;65S('!O="!C86YV:6%R(&QA('!R
M;W!I971A="!O(&5L<R!P97)M:7-O<R!D96P@<')O<&EE=&%R:2!P97(@82!R
M96-U<G-O<R!C;VUP87)T:71S`$]B<FEU(&5N('5N82!N;W9A(&9I;F5S=')A
M`$5R<F]R($]P96Y34TPZ(&YO(',G:&%N('!O9W5T(&5X=')E=7)E(&QE<R!D
M861E<R!D92!L82!P87)T(%,O34E-12!S:6=N861A+@!/8G)E(&%Q=65S="!E
M;FQL8><@96X@=6YA(&YO=F$@9FEN97-T<F$`4VES=&5M82!O<&5R871I=0!/
M<&-I;VYS`$]P8VEO;G,@9"<E<P!,;&ES=&$@;W)D96YA9&$`3W)G86YI='IA
M8VGS`%5N:71A="!O<F=A;FET>F%T:79A`%,G97-TX"!O<F=A;FET>F%N=`!0
M;&%N=&EL;&$@9"=A<&QI8V%C:?,@;W)I9VEN86P`4&QA;G1I;&QE<R!O<FEG
M:6YA;',@96X@)7,Z`$%L=')E`$%L=')A(&EN9F]R;6%C:?,`4&5R;6ES;W,@
M9&5L('!R;W!I971A<FD`3"=A=71E;G1I8V%C:?,@4$%-(&YO(&5S=.`@9&ES
M<&]N:6)L92X`4VEG;F%T=7)A(&1I9VET86P@4$=0`$1A9&5S('AI9G)A9&5S
M(&%M8B!01U``0VQA=2!01U`@</IB;&EC80!$861E<R!S:6=N861E<R]X:69R
M861E<R!A;6(@4$=0`$-O9&D@4$A0`$EN=.AR<')E="!D)V]R9')E<R!02%``
M4&QU9VEM<R!D92!T87)D80!0;'5G97,@9&4@=&%R9&$`3F5V861E<R!D92!T
M87)D80!8X&9E8W,@9&4@;F5U(&$@;&$@=&%R9&$`4V]L(&1E('1A<F1A`%1E
M;7!E<W1E<R!D92!T87)D80!);G3H<G!R970@9"=O<F1R97,@4%](4`!397!A
M<F%C:?,`4&%K:7-T86X`4&%L874`5&5R<FET;W)I('!A;&5S=.TL(&]C=7!A
M=`!086YA;>``4&%P=6$@3F]V82!'=6EN96$`4&%R86=U86D`4&%R8VEA;&UE
M;G0@96YN=79O;&%T`$-O;G1R87-E;GEA`$-O;G1R87-E;GEA(&EN8V]R<F5C
M=&$`0V%L(&EN=')O9'5I<B!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E
M;G1I8V%C:?,@4D%$2553+@!#;VYT<F%S96YY82!A;6(@8V]N9FER;6%C:?,`
M0V]N=')A<V5N>6$Z`$-O;G1R87-E;GEA.B``3&5S(&-O;G1R87-E;GEE<R!H
M86X@9&4@8V]I;F-I9&ER+@!%;F=A;GAA<@!%;F=A;GAA<B!D96P@<&]R=&$M
M<F5T86QL<P!#86WM`$%L=&5S('!E;F1E;G1S.@!'96YT`%!E<F-E;G1A=&=E
M`%)E86QI='IA<B!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT`%9O;&5U(')E
M86QI='IA<B!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT(&5N(&EN:6-I87(@
M;&$@<V5S<VGS/P!097)M[7,`4&5R;6ES(&1E;F5G870`061M:6YI<W1R861O
M<B!D92!P97)M:7-O<P!$861E<R!P97)S;VYA;',`4&5R^@!!;FEM86QS(&1E
M(&-O;7!A;GEI80!&:6QI<&EN97,`5&5LZ&9O;@!&;W1O<P!0:71C86ER;@!0
M[7AE;',`5/)P:6-S`$-L:6-A<B!E;B!U;F$@8V5LMVQA`$-O;F9I<FUA<B!Q
M=64@=F]L974@<W5P<FEM:7(@87%U97-T(&5L96UE;G0Z`$-O;F9I<FUA<B!Q
M=64@=F]L974@9&5S96YL;&'G87(@87%U97-T(&5L96UE;G0N`$EN=')O9'7O
M=2!U;B!M97,@:2!U;B!A;GDN`$EN=')O9'7O=2!U;B!N;VT@<&5R(&$@;&$@
M;F]V82!C871E9V]R:6$Z`$EN=')O9'7O=2!U;F$@861R9>=A($E0(';@;&ED
M82X`26YT<F]D=>]U('5N82!D871A(';@;&ED82P@8V]M<')O=F5U(&5L<R!D
M:65S('%U92!TZ2!E;"!M97,N`$EN=')O9'7O=2!U;F$@:&]R82!VX&QI9&$N
M`%!R;W!O<F-I;VYE=2!U;B!R97-U;2!D96P@<')O8FQE;6$N`%!R;W!O<F-I
M;VYE=2!E;"!N;VT@9"=U<W5A<FD@:2!L82!C;VYT<F%S96YY80!496-L96=E
M=2!E;"!N;VT@9&4@;&$@;F]V82!C871E9V]R:6$Z`%!O;/)N:6$`4&]L[71I
M8V$`16YQ=65S=&5S`%!O<G1U9V%L`$-O;+=L;V-A8VGS(&0G87%U97-T82!I
M;6%T9V4`0V]LMVQO8V%C:?,@9"=A<75E<W1A('1A=6QA`$5N=FEA<B!A(&%Q
M=65S=&$@8V%R<&5T82`H;F\@:&D@;V)L:6=A($E-05`I`%!R96-I<&ET86-I
M\R!D=7)A;G0@;&$@9&%R<F5R82`E<R!H;W)A(&\@:&]R97,Z(`!0<F5F<U]L
M9&%P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($Q$05`@<V]LMVQI8VET
M861A+@!0<F5F<U]S97-S:6]N.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS
M(&1E('-E<W-I\R!S;VRW;&EC:71A9&$N`%!R97-S:?,`4')E<W-I\R!A;"!N
M:79E;&P@9&5L(&UA<CH`4')E<W-I\SH@`%9I<W5A;&ET>F%C:?,@<'+H=FEA
M`%9I<W5A;&ET>F%R('!RZ'9I86UE;G0@;&$@:6UA=&=E(&5N('5N82!N;W9A
M(&9I;F5S=')A`$]P8VEO;G,@<'+H=FEE<P!);7!R:6UI<B!E;"!D;V-U;65N
M=`!#;&%U('!R:79A9&$`4')O8FQE;6$`1&5S8W)I<&-I\R!D96P@<')O8FQE
M;6$`4')O:F5C=&5S`%1E>'0@:6YD:6-A9&]R`$-L874@</IB;&EC80!!;&=O
M<FES;64@9&4@8VQA=2!P^F)L:6-A`$EN9F]R;6%C:?,@9&4@8VQA=2!P^F)L
M:6-A`$YO(',G:&$@9V5N97)A="!C;W)R96-T86UE;G0@;&$@<&%R96QL82!D
M92!C;&%U<R!P^F)L:6-A+W!R:79A9&$`4'5E<G1O(%)I8V\`46%T87(`0V]N
M<W5L=&$`0VQA=2!P^F)L:6-A(%)302`H)60@8FET*0!";W3S(&1E('-E;&5C
M8VGS`%!L=6IA`%!L=6IA(&$@<')I;65R82!H;W)A`%!L=6IA(&-A<"!A;"!T
M87)D`%)U:7AA=`!0;'5J82!I(&YE=P!!:6=U86YE=0!$:71A(&%L96%T\G)I
M80!296QA8VGS`$QL96=I=0!,;&5G:74@96QS(&UI<W-A=&=E<P!#;VYF:7)M
M974@<75E('9O;&5U('-U<')I;6ER("5S/R!!<75E<W1A(&]P97)A8VGS(&YO
M(&5S('!O="!D97-F97(N`$-O;F9I<FUE=2!Q=64@=F]L974@<W5P<FEM:7(@
M;&5S(&1A9&5S(&1E(&PG=7-U87)I('!E<B!A(&PG=7-U87)I("5S/R!!<75E
M<W1A(&]P97)A8VGS(&YO(&5S('!O="!D97-F97(N`%1O<FYA(&$@9F5R(&QA
M(&1A<G)E<F$@86-C:?,`4F5F<F5S8V%R(&5L<R!E;&5M96YT<R!D96P@;65N
M^B!D:6[@;6EC<P!2969R97-C87(@;&$@=FES=6%L:71Z86-I\R!D96P@<&]R
M=&%L`$5X<')E<W-I\R!R96=U;&%R`$YA=F5G861O<B!D92!R96QA8VEO;G,`
M0V]M96YT87)I<P!397)V:61O<G,@<F5M;W1S`%523"!R96UO="`H:'1T<',Z
M+R]W=W<N97AE;7!L92YE<R]H;W)D92DZ`%-U<')I;6ER`%-U<')I;6ER(&)L
M;V,`4W5P<FEM:7(@8V]L=6UN80!3=7!R:6UI<B!L82!F;W)M871A8VGS`%-U
M<')I;6ER(&QA('!A<F5L;&$`4W5P<FEM:7(@;&$@<V5Q_.AN8VEA(&1E<V%D
M82!D96P@9&ER96-T;W)I('1E;7!O<F%L(&1E;"!S97)V:61O<BX`4W5P<FEM
M:7(@96P`4W5P<FEM:7(@87%U97-T(&YO9&4@9&5L(&1O8W5M96YT`%-U<')I
M;6ER(&PG=7-U87)I`%-U<')I;6ER(&PG=7-U87)I.B`E<P!.;R!S)VAA('!O
M9W5T(')E<W!O;F1R92!A(&QA('-O;+=L:6-I='5D+B!#;V1I(&0G97)R;W(@
M<F5T;W)N870Z(`!.;R!S)VAA('1R;V)A="!E;"!S97)V96D@<V]LMVQI8VET
M870N`$-A;7`@<V]LMVQI8VET870`4F5I;FEC:6$`4F5I;FEC:6%R(&QA(&-O
M;G1R87-E;GEA`%)E:6YI8VEA<B!L82!C;VYT<F%S96YY80!297-U;'1A=',`
M5&]R;F$@82!O<&-I;VYS`%)E=6YI\P!297-T875R87(@;&$@8V]N9FEG=7)A
M8VGS`$]P8VEO;G,@9&4@;"=E9&ET;W(@9&4@=&5X="!E;G)I<75I=`!%;FEG
M;65S`$1R971A`$-A<.=A;&5R82!D<F5T80!686QO<G,@9&4@;&$@9')E=&$`
M4')O<&EE=&%T<R!D92!L82!F:6QA+BXN`$9U;F-I\P!2;VUA;FEA`$=I<F%R
M(#$X,`!':7)A<B!A(&PG97-Q=65R<F$`1VER87(@82!L82!D<F5T80!0<F]P
M:65T871S(&1E(&QA(&9I;&$`4')O<&EE=&%T<R!D92!L82!F:6QA`$9I;&5S
M.@!296=L97,`07!A<F5I>&5R86X@<F5G;&5S(&5N=')E('1O=&5S(&QE<R!F
M:6QE<R!I(&-O;'5M;F5S`$%P87)E:7AE<F%N(')E9VQE<R!N;VWI<R!E;G1R
M92!C;VQU;6YE<P!!<&%R96EX97)A;B!R96=L97,@;F]MZ7,@96YT<F4@9FEL
M97,`17AE8W5T87(`1F5D97)A8VGS(%)U<W-A`%)W86YD80!3:6=N871U<F$@
M8W)I<'1O9W+@9FEC82!A;6(@4R]-24U%`$UI<W-A=&=E('AI9G)A="!A;6(@
M4R]-24U%`$PG875T96YT:6-A8VGS(%-!4TP@;F\@97-TX"!D:7-P;VYI8FQE
M+@!-:7-S871G97)I82!335,`26YTZ')P<F5T(&0G;W)D<F5S(%-13`!34T@`
MR%A)5`!);G3H<G!R970@9"=O<F1R97,@4U%,`$1S+@!386EN="!(96QE;F$`
M4V%I;G0@0VAR:7-T;W!H97(@:2!.979I<P!386EN="!,=6-I80!386EN="U0
M:65R<F4M970M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!I(&QE<R!'<F5N861I
M;F5S`$UA=&5I>"!M87)C("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]MZ2!I(%!R[6YC:7!E`%!R;W9E[V1O<B!D92!S873H;+=L:70`07+@8FEA
M(%-A=61I=&$`1&5S80!$97-A("5S`$1E<V$@;&5S(&]P8VEO;G,`1&5S974@
M;&$@8V]N9FEG=7)A8VGS(&=E;F5R861A(&-O;2!U;F$@<V5Q_.AN8VEA(%!(
M4"!E;B!E;"!D:7)E8W1O<FD@=&5M<&]R86P@9&5L('-E<G9I9&]R+@!3)VAA
M(&1E<V%T(&QA(&-O;F9I9W5R86-I\R!D92`E<RX`5&5M<&5S=&5S(&1I<W!E
M<G-E<P!#:>AN8VEA`$-E<F-A`$UO=&]R<R!D92!C97)C80!396QE8V-I;VYA
M<B!E;',@87)X:75S`%-E;&5C8VEO;F%R('5N82!D871A`%-E;&5C8VEO;F%R
M('5N(&=R=7`@<75E('9U;&=U974@869E9VER`%-E;&5C8VEO;F5U('5N(&YO
M=2!P<F]P:65T87)I`%-E;&5C8VEO;F5U('5N('-E<G9I9&]R`%-E;&5C8VEO
M;F5U('5N('5S=6%R:2!Q=64@=G5L9W5E=2!A9F5G:7(`4V5L96-C:6]N974@
M=&]T<R!E;',@96QE;65N=',@9&4@;&$@9&%T82X`4V5L96-C:6]N974@=6X@
M;V)J96-T90!396QE8V-I;VYE=2!E;',@8V%RX&-T97)S('%U92!N96-E<W-I
M=&5U(&1E(&QE<R!C87-E;&QE<R!D92!S;W1A+B!0;V1E=2!C;W!I87(M;&]S
M(&D@96YG86YX87(M;&]S(&1E(&PGX')E82!D92!T97AT+@!396QE8V-I;VYA
M<B!E;"!D96QI;6ET861O<B!D92!L82!D871A.@!396QE8V-I;VYA<B!E;"!F
M;W)M870@9&4@;&$@9&%T83H`4V5L96-C:6]N87(@;&$@:61E;G1I=&%T('%U
M92!V;VQE=2!Q=64@8V%N=FEA<CH`4V5L96-C:6]N87(@96P@9&5L:6UI=&%D
M;W(@9&4@;"=H;W)A.@!396QE8V-I;VYA<B!E;"!F;W)M870@9&4@;"=H;W)A
M.@!396QE8V-I;VYA<B!D;W,@8V%M<',@<75E(&-O:6YC:61E:7AI;BX`4V5L
M96-C:6]N87(@;&$@8V]M8FEN86-I\R!D92!C;VQO<G,N`%-E;&5C8VEO;F%R
M(&PG:61I;VUA('!R969E<FET.@!%;G9I87(@;"=I;F9O<FUE(&1E;',@<')O
M8FQE;65S`$5N=FEA<B!335,`4V5N96=A;`!396YS;W(Z(`!3971E;6)R90!3
MZ')B:6$@:2!-;VYT96YE9W)O`$[Z;65R;R!D92!SZ')I90!,97,@9&%D97,@
M9&5L('-E<G9I9&]R('/S;B!I;F-O<G)E8W1E<R!O(&YO(&5S=&%N(&1I<W!O
M;FEB;&5S+@!(82!C861U8V%T(&PG:61E;G1I9FEC861O<B!D92!S97-S:?,N
M`$1E9FEN96EX`$1E9FEN96EX(&QE<R!O<&-I;VYS('%U92!U<R!P97)M971E
M;B!R96EN:6-I87(@;&$@8V]N=')A<V5N>6$@<VD@;6%I(&PG;V)L:61E=2X`
M1&5F:6YI=2!E;',@<V5R=FED;W)S(')E;6]T<R!A('%UZ"!V;VQE=2!A8V-E
M9&ER(&1E<R!D96P@<&]R=&%L+@!$969I;FEU(&5L('9O<W1R92!I9&EO;6$@
M<')E9F5R:70L(&QA('IO;F$@:&]RX')I82!I(&QE<R!O<&-I;VYS(&1E(&1A
M=&$N`$1E9FEN:74@;"=A<&QI8V%C:?,@9"=I;FEC:2P@;&$@8V]M8FEN86-I
M\R!D92!C;VQO<G,L(&5L(')E9G)E<V-A;65N="!D92!L97,@<.!G:6YE<R!I
M(&%L=')E<R!O<&-I;VYS(&1E('9I<W5A;&ET>F%C:?,N`$-O;F9I9W5R86-I
M\P!(:2!H82!S97'\Z&YC:65S(&0G86-T=6%L:71Z86-I\R!D92!L82!C;VYF
M:6=U<F%C:?,`2&D@:&$@9&EV97)S97,@=6)I8V%C:6]N<R!P;W-S:6)L97,@
M86UB(&5L('!A<N!M971R93H@`%-E>6-H96QL97,`0V]M<')E<P!297-U;2!B
M<F5U`%9O;&5U(&1E9FEN:7(@;&5S(&-L875S(&0G86-CZ7,@<&5R(&$@;&$@
M;6%J;W(@<&%R="!D)V5N;&QAYV]S/P!-;W-T<F$`36]S=')A(&QE<R!D:69E
M<NAN8VEE<R!E;G1R92!L82!C;VYF:6=U<F%C:?,@9&5S861A(&D@;&$@;F]V
M82X`5F]L974@=FES=6%L:71Z87(@;"=H;W)A(&1E(&QA(&1A<G)E<F$@<V5S
M<VGS(&5N(&EN:6-I87(_`$UO<W1R82!L)V]P8VGS(&1E(&-O;G-E<G9A<B!L
M)V]R:6=I;F%L`$UO<W1R82!E;"!C87!T=7)A9&]R`%9O;&5U('9I<W5A;&ET
M>F%R(&QA(&)A<G)A(&1E(&UE;OH@9"=O<&5R86-I;VYS(&1E('1A=6QA/P!6
M;VQE=2!V:7-U86QI='IA<B!E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$_`$UO
M<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!C96RW;&$@9&4@=&%U
M;&$`36]S=')A(&5L(&1IX&QE9R!D92!P<F]P:65T871S(&1E('1A=6QA`$UO
M<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!F:6QA(&1E('1A=6QA
M`$UO<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!I;6%T9V4`36]S
M=')A(&QA(&/@<G)E9V$`4G5I>&%T<P!2=6EX871S(&$@<')I;65R82!H;W)A
M`%)U:7AA=',@8V%P(&%L('1A<F0`4G5I>&%T<R!A(&QA(')O9&%L:6$`4F5D
M=>]U`%!R:6UE<B!R961U[W4@;R!A<&%R=&5U(&5L*',I(&)L;V,H<RD@9&5L
M(&-O<W1A=`!3:65R<F$@3&5O;F4`1&]N974M=F]S(&0G86QT80!3:6=N871U
M<F$`06QG;W)I<VUE(&1E('-I9VYA='5R80!3:6YG87!U<@!-:61A`$]M970@
M;6%N=&5N:6UE;G0`17-L;W;@<75I80!%<VQO=NAN:6$`3F5V861A`%C@9F5C
M(&1E(&YE=0!8X&9E8W,@9&4@;F5U`%C@9F5C<R!D92!N974@82!P<FEM97)A
M(&AO<F$`6.!F96-S(&1E(&YE=2!C87`@86P@=&%R9`!'<G5I>"!D92!N974Z
M(`!%<75I=F%L96YT(&1E(&QA(&YE=2!E;B!A:6=U83H@`$EL;&5S(%-A;&]M
M\P!3;VW@;&EA`$-A;N=O;G,@:2!P;V5M97,`4V5L96-C:?,@96X@96P@<V5N
M=&ET(&1E(&QA(&-L87-S:69I8V%C:?,`061R9>=A(&0G;W)I9V5N`%-U9"W@
M9G)I8V$`4W5D+65U<F]P974@*$E33RTX.#4Y+3,I`$=E\G)G:6$@9&5L(%-U
M9"!I(&QE<R!I;&QE<R!386YD=VEC:"!D96P@4W5D`$AE;6ES9F5R:2!S=60`
M17-P86D@96YT<F4@8V5LMVQE<R!A9&IA8V5N=',`17-P86D@96YT<F4@96P@
M8V]N=&EN9W5T(&D@96P@8V]N=&]R;B!D92!L82!C96RW;&$`17-P86EA9&]R
M`$5S<&%I870`17-P86EA="!I(&9A<F-I;65N=`!%<W!A;GEA`$-O<G)E=2!B
M<F]S<V$`17-C<FEP='5R82!D92!C87+@8W1E<G,@97-P96-I86QS`$1I=FED
M:7(@8V5LMVQA`$1I=FED:7(@8V]L=6UN80!$:79I9&ER(&9I;&$`17-P;W)T
M<P!3<FD@3&%N:V$`17-TX&YD87)D`%-T87(@5')E:P!!;GD@9"=I;FEC:0!%
M<W1A="!O('!R;W;M;F-I80!%<W1A=`!&;W)M870@9"=E;6UA9V%T>F5M871G
M90!!9')EYV$@<&%R=&EC=6QA<@!"87)R870`3&QI<W1A(&1E(&-A9&5N97,`
M16QI;6EN974@96P@9&]M:6YI(&1E(&PG861R9>=A`$5S=&EL(%M#4U-=`$1G
M+@!!<W-U;7!T90!%;G9I80!3=6+M;F1E>`#(>&ET`%,G:&$@<F5S=&%U<F%T
M(&-O<G)E8W1A;65N="!L82!C;VYF:6=U<F%C:?,N($%C='5A;&ET>F5U('!E
M<B!V975R92!E;',@8V%N=FES+@!3)VAA(&1E<V%T(&-O<G)E8W1A;65N="!L
M82!C;VYF:6=U<F%C:?,@9&4@8_)P:6$N`%,G:&$@9&5S870@8V]R<F5C=&%M
M96YT(&PG87)X:74@9&4@;&$@8V]N9FEG=7)A8VGS(&1E(&/R<&EA("5S+@!3
M)VAA(&5S8W)I="!C;W)R96-T86UE;G0@)R5S)P!3=61A;@!297-U;0!3;W)T
M:61A(&1E;"!S;VP`4&]S=&$@9&5L('-O;`!!<W-O;&5L;&%T`%-O<G1I9&$@
M9&5L('-O;`!3;W)T:61A(&1E;"!S;VPO4&]S=&$@9&5L('-O;`!3;W)T:61A
M(&1E;"!S;VPZ(`!0;W-T82!D96P@<V]L`%!O<W1A(&1E;"!S;VPZ`%-U<&5R
M[6YD97@`07-S:7-TZ&YC:6$`4W5R:6YA;0!#;V=N;VT`4W9A;&)A<F0@:2!*
M86X@36%Y96X`4W=A>FELX&YD:6$`4W7H8VEA`%-U[W-S80!%<G)O<B!D92!S
M:6YT87AI(&5N(&5L<R!T97)M97,@9&4@8V5R8V$`4F5P^F)L:6-A(,!R86(@
M4VER:6%N80!496UP97-T80!496UP97-T82!I('9E;G3S<P!496UP97-T97,`
M07)X:74@5%-6`%!R;W!I971A=',@9&4@=&%U;&$`4')O<&EE=&%T<R!D92!T
M875L80!486EW86X`5&%I=V%N+"!P<F]V[6YC:6$@9&4@;&$@6&EN80!4861J
M:6MI<W1A;@!486YZX&YI82P@4F5P^F)L:6-A(%5N:61A(&1E`$]B:F5C=&EU
M.@!487-Q=65S`$[Z;65R;R!D92!T96SH9F]N`%1E;7!E<F%T=7)A(&1U<F%N
M="!L82!D87)R97)A(&AO<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@
M`$%D;6EN:7-T<F%C:?,@9&4@<&QA;G1I;&QE<P!497AT`$YO;>ES('1E>'0`
M06QI;F5A8VGS(&1E('1E>'0`06QI;F5A="!A(&1A;'0`1&HN`%1A:6QA;F3H
M<R`H5$E3+38R,"D`5&%I;.!N9&EA`$PG97AT96YS:?,@1E10(&YO(&5S=.`@
M9&ES<&]N:6)L92X`16P@;6]T;W(@9"=I;G1E9W)A8VGS($AO<F1E+TMO;&%B
M(&YO('!E<FUE="!L)_IS(&1E("(E<R(`3&$@8VQA<W-E($UA:6YT96YA;F-E
M.CH@;F\@<R=H82!C87)R96=A="!C;W)R96-T86UE;G0C(P!3)VAA('1A;F-A
M="!L82!F:6YE<W1R82!D)V]P8VEO;G,N(%-O<G1I;G0@9&5L('-I<W1E;6$`
M4VD@=F]L974@=71I;&ET>F%R(&5L<R!P97)M:7-O<RP@;"=A9&UI;FES=')A
M9&]R(&AA(&1E(&-O;F9I9W5R87(@=6X@;6]T;W(@9&4@<&5R;6ES;W,@<&5R
M;6%N96YT+@!.;VWI<R!E;"!C;VYT;W)N(&EN9F5R:6]R`$5L(&[Z;65R;R!I
M9&5N=&EF:6-A9&]R(&1E;"!C;VYT86-T92!N;R!S)VAA(&5S<&5C:69I8V%T
M+"!S)VAA(&1E:7AA="!E;B!B;&%N8R!O(&YO(',G:&$@=')O8F%T(&$@;&$@
M8F%S92!D92!D861E<RX`4R=H82!A9F5G:70@8V]R<F5C=&%M96YT(&5L(&-O
M;G1A8W1E(&$@;&$@;&QI8G)E=&$@9"=A9')E8V5S+@!%<R!N96-E<W-I=&$@
M96P@8FQO8R!D92!S:6=N871U<F5S(%!'4"!S97!A<F%T('!E<B!V97)I9FEC
M87(@96P@;6ES<V%T9V4@<VEG;F%T+@!,)VED96YT:69I8V%D;W(@9&4@;&$@
M;&QI<W1A(&1E(&1I<W1R:6)U8VGS(&YO(',G:&$@97-P96-I9FEC870L(',G
M:&$@9&5I>&%T(&5N(&)L86YC(&\@;F\@<R=H82!T<F]B870@82!L82!B87-E
M(&1E(&1A9&5S+@!.;R!S)VAA(&5S<&5C:69I8V%T(&QA(&QL:7-T82!D92!D
M:7-T<FEB=6-I\RX`3&5S(&-A<F%C=&5R[7-T:7%U97,@9&5L('AI9G)A=&=E
M(&5X:6=E:7AE;B!U;F$@8V]N;F5X:?,@=V5B(&9I86)L92X`3"=A<GAI=2`E
M<R!H875R:6$@9&4@8V]N=&5N:7(@=6X@<&%RX&UE=')E("5S+@!,)V%R>&EU
M("5S(&AA=7)I82!D92!C;VYT96YI<B!A;&=U;G,@<&%RX&UE=')E<R`E<RX`
M3"=A<GAI=2!N;R!C;VYT96YI82!D861E<RX`02!C;VYT:6YU86-I\R!E<R!P
M<F5S96YT96X@;&5S(&-A<.=A;&5R97,@9"=A<75E<W0@;6ES<V%T9V4O;6ES
M<V%T9V4@<F9C.#(R+@!3)VAA(&-O;G-T871A="!Q=64@96P@;6]D92!D92!P
M86YT86QL82!C;VUP;&5T82!D\VYA('!R;V)L96UE<R!A;6(@26YT97)N970@
M17AP;&]R97(@82!C875S82!D)V5R<F]R<R!E;B!E;"!N879E9V%D;W(@<75E
M(&YO(&AE;2!P;V=U="!R97-O;&1R92X@4&]T('-E<B!Q=64@=FES=6%L:71Z
M974@8G)O<W-A+"!U<R!M86YQ=6EN(&9U;F-I;VYS(&5N(&PG961I=&]R(&DO
M;R!Q=64@96P@;F%V96=A9&]R('5S(&9A;&QI(&1E(&UA;F5R82!A;&5A=/)R
M:6$N(%-I('1E;FEU(&5L('-I<W1E;6$@5VEN9&]W<R`Y>"#I<R!M;VQT('!R
M;V)A8FQE('%U92!E<R!P<F]D=65I>&D@=6X@)V5R<F]R(&1E('!R;W1E8V-I
M\R!G96YE<F%L)R!I(&AA9W5E=2!D92!R96EN:6-I87(@9&4@;F]U+B!3:2P@
M=&]T(&D@87%U97-T(&%D=F5R=&EM96YT+"!E;F-A<F$@=F]L974@<')O=F%R
M(&PG961I=&]R(&1E('!A;G1A;&QA(&-O;7!L971A+"!P<F5M974@1"=A8V]R
M9"X`4R=H82!S=7!R:6UI="!L82!I9&5N=&ET870@(B5S(BX`3F]MZ7,@96P@
M8V]S=&%T(&5S<75E<G)E`$QA('5B:6-A8VGS(&1E;"!B:6YA<FD@1VYU4$<@
M<R=H82!D)VEN9&EC87(@82!L82!C;&%S<V4@0W)Y<'1?<&=P+@!3)VAA(&UO
M<W1R870@96P@;6ES<V%T9V4@96YV:6%T(&5L("5S(&$@)7,@86UB(&PG87-S
M=6UP=&4@(B5S(BX@06EX\B!N;R!G87)A;G1E:7@@<75E(',G:&%G:2!L;&5G
M:70@;R!E;G3H<R!E;"!M:7-S871G92X`16P@;F]M('%U92!S)VAA(&0G=71I
M;&ET>F%R(&5N(&5N;&QAYV%R(&%M8B!#<F5A<B!PX&=I;F$`17,@;F5C97-S
M:71A(&5L(&WR9'5L(&]P96YS<VP@<&5R(&$@;&$@8VQA<W-E($AO<F1E7T-R
M>7!T7W-M:6UE+@!.;R!S)VAA('!O9W5T(&1E<V%R(&QA('!R969E<NAN8VEA
M("(E<R(@<&5R<77H(&QA(&EN9F]R;6%C:?,@<75E(&-O;G1E;FEA('-U<&5R
M879A(&QA(&UI9&$@;>!X:6UA('!E<FUE<V$N`$YO(',G:&$@=')O8F%T(&5N
M(&5L('-I<W1E;6$@96P@<')O9W)A;6$@=7-A="!P97(@=FES=6%L:71Z87(@
M87%U97-T('1I<'5S(&1E(&1A9&5S("@E<RDN`$YO;>ES(&5L<R!C;W-T871S
M(&1R970@:2!E<W%U97)R90!.;VWI<R!E;"!C;W-T870@9')E=`!3)VAA('-U
M<')I;6ET(&5L('-E<G9I9&]R("(E<R(N`%,G:&$@9&5S870@96P@<V5R=FED
M;W(@(B5S(BX`4R=H82!E;&EM:6YA="!L82!S;VRW;&EC:71U9"!D)V%L=&$@
M9&4@)7,N`$YO(&5X:7-T96EX(&PG87)X:74@=&5M<&]R86P@(B5S(BX`3F]M
MZ7,@96QS(&-O<W1A=',@<W5P97)I;W(@:2!I;F9E<FEO<@!.;VWI<R!E;"!C
M;W-T870@<W5P97)I;W(`4R=H86X@<&5R9'5T(&QE<R!D861E<R!C87)R96=A
M9&5S(&1E<R!D96P@<&%S(&%N=&5R:6]R+@!.;R!S)VAA('!O9W5T(&1E<V%R
M(&PG87)X:74@8V%R<F5G870N`$5L(&)L;V,@=V5A=&AE<BYC;VT@;F\@97-T
MX"!D:7-P;VYI8FQE+@!.;R!H:2!H82!C87`@;W!C:?,@9&ES<&]N:6)L92X`
M3F\@:&D@:&$@8V%P('!A<G0@<75E(&5S('!U9W5I(&UO<W1R87(@96X@;.UN
M:6$`07%U97-T(&-A;7`@8V]N=.D@;6%S<V$@8V%RX&-T97)S+B!(974@:6YT
M<F]D=>]T("5S(&-A<N!C=&5R<R!I(&XG:&5U(&0G:6YT<F]D=6ER(&UE;GES
M(&1E("5S+@!(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!C87)R96=A<B!L
M)V%R>&EU.B!N;R!S)VAA(&-A<G)E9V%T("5S+@!(:2!H82!H86=U="!U;B!P
M<F]B;&5M82!E;B!C87)R96=A<B!L)V%R>&EU.B!E;"`E<R!E<F$@<W5P97)I
M;W(@82!L82!M:61A(&W@>&EM82!P97)M97-A("@E(&)Y=&5S*2X`2&D@:&$@
M:&%G=70@=6X@<')O8FQE;6$@96X@8V%R<F5G87(@;"=A<GAI=3H@;F]MZ7,@
M<R=H82!C87)R96=A="!P87)C:6%L;65N="!E;"`E<RX`4R=H82!P<F]D=>]T
M('5N(&5R<F]R(&5N(&UO<W1R87(@87%U97-T82!P87)T(&1E;"!M:7-S871G
M90!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@:6UP;W)T87(@;&5S(&1A9&5S
M(&1E(&-O;G1A8W1E+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@:6UP;W)T
M87(@;&5S(&1A9&5S(&E#86QE;F1A<BX`4R=H82!P<F]D=>]T('5N(&5R<F]R
M(&5N(&5L(&9O<FUU;&%R:2!D92!C;VYF:6=U<F%C:?,N(%!O='-E<B!U<R!H
M974@9&5S8W5I9&%T(&0G96UP;&5N87(@=6X@8V%M<"!N96-E<W-A<FDN`%,G
M:&$@<')O9'7O="!U;B!E<G)O<B!E;B!E>&5C=71A<B!L82!F=6YC:?,@97-P
M96-I9FEC861A(&1E(&QA(&QL:6)R971A(&0G861R96-E<RX@5&]R;F5U+6AO
M(&$@:6YT96YT87(@;>ES('1A<F0N`%,G:&$@<')O9'7O="!U;B!E<G)O<B!E
M;B!A8W1U86QI='IA<B!E;',@9&5T86QL<R!D92!C;VYT86-T92X@5&]R;F5U
M+6AO(&$@:6YT96YT87(@;>ES('1A<F0N`%,G:&$@<')O9'7O="!U;B!E<G)O
M<B!E;B!A8W1U86QI='IA<B!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N(%1O
M<FYE=2UH;R!A(&EN=&5N=&%R(&WI<R!T87)D+@!!<75E<W0@<V5R=FED;W(@
M24U!4"!N;R!P97)M970@;"?Z<R!D92!C87)P971E<R!C;VUP87)T:61E<RX`
M3F\@<V5M8FQA('%U92!S:6=U:2!U;B!A<GAI=2!R87(@=N!L:60N`$YO('-E
M;6)L82!Q=64@<VEG=6D@=6X@87)X:74@>FEP(';@;&ED+@!.;R!S96UB;&$@
M<75E(&%Q=65S="!N^FUE<F\@9&4@=&%R9V5T82!S:6=U:2!VX&QI9"X`07%U
M97-T(&-O;G1R;VQA9&]R('!E<FUE="!E;G9I87(@;6ES<V%T9V5S('!E<B!M
M:71JX"!D92!L82!P87-S87)E;+=L82!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI+"!U=&EL:71Z86YT(&QA($%022!(5%10`$%Q=65S="!C
M;VYT<F]L861O<B!P97)M970@96YV:6%R(&UI<W-A=&=E<R!P97(@;6ET:N`@
M9&4@;&$@<&%S<V%R96RW;&$@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@=71I;&ET>F%N="!L82!!4$D@2%144`!!<75E<W0@8V]N=')O;&%D
M;W(@<&5R;65T(&5N=FEA<B!M:7-S871G97,@<&5R('9I82!D92!33510(&$@
M=')A=NES(&1E(&QA('!A<W-A<F5LMVQA(%9O9&%F;VYE(&0G273@;&EA+"!N
M;VWI<R!A(&[Z;65R;W,@5F]D869O;F4N($-A;"!T96YI<B!U;B!C;VUP=&4@
M9&4@8V]R<F5U(&5L96-T<O)N:6,@86UB(%9O9&%F;VYE(&0G273@;&EA("AH
M='1P.B\O=W=W+C$Y,"YI="DN`,ES(&YE8V5S<V%R:2!A<75E<W0@8V%M<"X`
M07%U97-T(&-A;7`@;F]MZ7,@<&]T(&-O;G1E;FER(&YO;6)R97,@96YT97)S
M+@!!<75E<W0@8V%M<"!N;VWI<R!P;W0@8V]N=&5N:7(@;F]M8G)E<R!I(&5L
M<R!D;W,@<'5N=',N`$%Q=65S="!C86UP(&YO;>ES('!O="!C;VYT96YI<B!V
M86QO<G,@;V-T86QS+@!!<75E<W0@8V%M<"!H82!D92!S97(@=6YA(&QL:7-T
M82!D92!N;VUB<F5S(&5N=&5R<R!S97!A<F%T<R!P97(@8V]M97,@;R!E<W!A
M:7,N`$%Q=65S="!C86UP(&AA(&1E('-E<B!U;B!N^FUE<F\@=N!L:60N`$%Q
M=65S="!C86UP(&AA(&1E(&-O;G1E;FER('5N(&-O9&D@9&4@8V]L;W(@9&4@
M9F]R;6%T(%)'0B!H97AA9&5C:6UA;"P@<&5R(&5X96UP;&4@)R,Q,C,T868G
M+@!*82!S)VAA('!R;V-E<W-A="!A<75E<W0@9F]R;75L87)I+@!!:7CR(.ES
M("5S+@!!:7CR(.ES('5N(&]B:F5C=&4@9&4@2V]L86(@1W)O=7!W87)E+B!0
M97(@=FES=6%L:71Z87(@87%U97-T(&]B:F5C=&4L('5S(&-A;"!U;B!C;&EE
M;G0@9&4@8V]R<F5U(&5L96-T<O)N:6,@<75E(&%D;65T:2!E;"!F;W)M870@
M9&4@2V]L86(@1W)O=7!W87)E+B!097(@=&5N:7(@86-CZ7,@82!U;F$@;&QI
M<W1A(&0G87%U97-T<R!C;&EE;G1S(&1E(&-O<G)E=2!E;&5C='+R;FEC+"!V
M:7-I=&5U("5S`$%Q=65S="!M:7-S871G92!V82!S97(@97-C<FET(&%M8B!U
M;B!J;V,@9&4@8V%RX&-T97)S("@E<RD@9&EF97)E;G0@9&5L('9O<W1R92X`
M07%U97-T(&[Z;65R;R!H82!D92!S97(@8V]M(&$@;>UN:6T@=6X@,2X`07%U
M97-T('-E<G9I9&]R(&YO('!O="!D97-C;VUP<FEM:7(@87)X:75S('II<"!I
M(&=Z:7`N`$%Q=65S="!S:7-T96UA(&5S=.`@9&5S86-T:79A="!A8W1U86QM
M96YT+@!!<75E<W0@=F%L;W(@:&$@9&4@<V5R('5N(&[Z;65R;RX`07%U97-T
M82!F:6YE<W1R82!S)VAA(&1E(&-R:61A<B!D97,@9"=U;F$@9FEN97-T<F$@
M9"=O<&-I;VYS`%1R;P!4:7%U971S`$AO<F$`0V]N=')O;"!D92!T96UP<P!&
M;W)M870@:&]R87)I`%-E;&5C8VGS(&1E('1E;7!S`%1I;6]R($]R:65N=&%L
M`%3M=&]L`%3M=&]L("ARZ'1O;"!I;F1I8V%D;W(@9&4@9G5N8VGS*3H`00!0
M97(@<V5L96-C:6]N87(@9&EV97)S;W,@96QE;65N=',L(&UA;G1I;F=U974@
M<&ET:F%D82!L82!T96-L82!#;VYT<F]L("A00RD@;R!#;VUM86YD("A-86,I
M(&UE;G1R92!C;&EQ=65U+@!!=G5I`$-O;6UU=&5U(&QA(&9O;G0@2%1-3`!4
M;V=O`%1O:V5L874`1&5MX`!4;VYG80!3=7!E<FEO<@!-87)C('-U<&5R:6]R
M("A?<W5P97)I;W(I`%1R861U8V-I;VYS`%1R:6YI=&%T(&D@5&]B86=O`%9E
M<FET870@;R!F86QS`$1T+@!4=6[M<VEA`%1U<G%U:6$`5'5R8R`H25-/+3@X
M-3DM.2D`5'5R:VUE;FES=&%N`$EL;&5S(%1U<FMS(&D@0V%I8V]S`%1U=F%L
M=0!496-L96=E=2!L82!V;W-T<F$@;W!C:?,Z(`#-;F1E>"!55CH@`%523`!5
M4DP@9&5L('9O<W1R92!I;F9O<FUE(&1E(&PG97-T870@9&4@=')A;65S82!D
M92!L82!S97'\Z&YC:6$`55),.@!59V%N9&$`56-R8>]N80!.;R!S)VAA('!O
M9W5T(&%C8V5D:7(@86P@9&ER96-T;W)I(%9&4RX`3F\@<R=H82!P;V=U="!A
M9F5G:7(@;>ES(&1A9&5S(&1E(&PG=7-U87)I(&5N(&5F96-T=6%R(&PG86QT
M82X`3F\@<R=H82!P;V=U="!C86YV:6%R(&5L('!E<FWM<R!D92!L)V%R>&EU
M(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@<&5R;>US(&1E
M(&PG87)X:74@5D93("5S+R5S+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@82`E
M<RX`3F\@<R=H82!P;V=U="!C;VYN96-T87(@86P@<V5R=FED;W(@4U%,+@!.
M;R!S)VAA('!O9W5T(&-O;FYE8W1A<B!A;6(@4U-,+@!.;R!S)VAA('!O9W5T
M(&-O<&EA<B!L)V%R>&EU(%9&4RX`3F\@<R=H82!P;V=U="!C<F5A<B!E;"!D
M:7)E8W1O<FD@5D93("(E<R(N`$YO(',G:&$@<&]G=70@8W)E87(@96P@9&ER
M96-T;W)I(%9&4RX`3F\@<R=H82!P;V=U="!C<F5A<B!L)V%R>&EU(%9&4RX`
M3F\@<R=H82!P;V=U="!C<F5A<B!L82!C87)P971A(%9&4R`B)7,B+@!.;R!S
M)VAA('!O9W5T(&-R96%R('5N(&%R>&EU(%9&4R!B=6ET+@!.;R!S)VAA('!O
M9W5T(&1E<V-O;7!R:6UI<B!L97,@9&%D97,N`$YO(',G:&$@<&]G=70@<W5P
M<FEM:7(@(B5S(BP@96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I="X`3F\@<R=H
M82!P;V=U="!S=7!R:6UI<B`E<RP@96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I
M="X`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!E;"!D:7)E8W1O<FD@5D93(&1E
M(&UA;F5R82!R96-U<G-I=F$N`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@96P@
M9&ER96-T;W)I(%9&4RX`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!E;"!D:7)E
M8W1O<FD@5D93.B`E<RX`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!L)V%R>&EU
M(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T('-U<')I;6ER(&PG87)X:74@5D93
M+@!.;R!S)VAA('!O9W5T('-U<')I;6ER(&QA(&-A<G!E=&$@5D93("(E<R(N
M`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@5D93(&1E(&UA;F5R82!R96-U<G-I
M=F$Z("5S+@!.;R!S)VAA('!O9W5T(&1E=&5R;6EN87(@96P@9&ER96-T;W)I
M(&%C='5A;"X`3F\@<R=H82!P;V=U="!E>'1R975R92!E;',@9&5T86QL<R!D
M96P@8V5R=&EF:6-A="X`3F\@<R=H82!P;V=U="!C87)R96=A<B!L82!D969I
M;FEC:?,@9&4@)7,N`$YO(',G:&$@<&]G=70@;6]U<F4@;"=A<GAI=2!61E,N
M`$YO(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!61E,@(B5S(BX`3F\@<R=H
M82!P;V=U="!O8G)I<B!L)V%R>&EU(%9&4R!P97(@97-C<FEU<F4M:&DN`$YO
M(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G=70@
M;V)R:7(@;"=A<GAI=2!C;VUP<FEM:70N`$YO(',G:&$@<&]G=70@;&QE9VER
M(&PG87)X:74@5D93("AL82!M:61A(&1E(&PG87)X:74H*2!H82!D;VYA="!E
M<G)O<BDN`$YO(',G:&$@<&]G=70@;&QE9VER(&PG87)X:74@5D93("AG971&
M:6QE4VEZ92@I(&AA(&1O;F%T(&5R<F]R*2X`3F\@<R=H82!P;V=U="!L;&5G
M:7(@;"=A<GAI=3H@+@!.;R!S)VAA('!O9W5T(&QL96=I<B!E;"!D:7)E8W1O
M<FD@87)R96P@9&4@5D93+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M
M(&1E("5S('!E<B`E<SH@;&$@8V%R<&5T82!D92!D97-T:6YA8VGS(&IA(&5X
M:7-T96EX`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I<F5C
M=&]R:2!61E,N`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I
M<F5C=&]R:2!61E,Z("5S+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M
M(&1E(&PG87)X:74@5D93("(E<R(N`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E
M;"!N;VT@9&4@;"=A<GAI=2!61E,@)7,O)7,N`$YO(',G:&$@<&]G=70@8V%N
M=FEA<B!E;"!N;VT@9&4@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G=70@97AE
M8W5T87(@)VUK:7-O9G,G+@!.;R!S)VAA('!O9W5T('1R861U:7(@87%U97-T
M(&1O8W5M96YT(&1E(%=O<F0`3F\@<R=H82!P;V=U="!E<V-R:75R92!L)V%R
M>&EU(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T(&5S8W)I=7)E(&PG87)X:74@
M5D93("@C<R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&-O<&EA<BUL;R@I(",I
M+@!.;R!S)VAA('!O9W5T(&5S8W)I=7)E(&QE<R!D861E<R!D92!L)V%R>&EU
M(%9&4RX`3F\@<R=H82!P;V=U="!E<V-R:75R92!L)V%R>&EU(%9&4RP@<V4@
M<W5P97)A<N`@;"=E<W!A:2!D:7-P;VYI8FQE+@!3=6)R871L;&%T`$1E<V;I
M<R!E;',@8V%N=FES`$1E<V;@(&QA(&1A<G)E<F$@86-C:?,`16P@<V5R=FED
M;W(@:&$@9&]N870@=6YA(')E<W!O<W1A(&EN97-P97)A9&$@96X@8V]N;F5C
M=&%R+7-E.B``16P@<V5R=FED;W(@:&$@9&]N870@=6YA(')E<W!O<W1A(&EN
M97-P97)A9&$@83H@`%-E;G-E(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`
M56YI\R!D96QS($5M:7)A=',@P')A8G,`4F5G;F4@56YI=`!%<W1A=',@56YI
M=',`26QL97,@4&5R:6;H<FEQ=65S($UE;F]R<R!D96QS($5S=&%T<R!5;FET
M<P!5;FET871S`$1E<V-O;F5G=70`87!I;7-G:60@*&ED96YT:69I8V%D;W(@
M9&5L(&UI<W-A=&=E(&1E(&QA($%022D@9&5S8V]N96=U="X`0VQI;7-G:60@
M9&5S8V]N96=U="`H:61E;G1I9FEC861O<B!D96P@;6ES<V%T9V4@9&5L(&-L
M:65N="DN`%,G:&$@<')O<&]R8VEO;F%T('5N82!U8FEC86-I\R!D97-C;VYE
M9W5D82X`3F]M(&0G=7-U87)I(&\@8V]N=')A<V5N>6$@9&5S8V]N96=U=',N
M`$1E<V5N;&QAYV%R(&PG96QE;65N="!A8W1U86P`4V5N<V4@;F]M`$QE<R!S
M97'\Z&YC:65S('-E;G-E('!E<FUI<V]S(&YO('!O9&5N(&%C8V5D:7(@82!2
M971A;&QA<B]#;W!I87(O16YG86YX87(@9&4@;6%N97)A('!R;V=R86W@=&EC
M82!P97(@<F%O;G,@9&4@<V5G=7)E=&%T+B!#;&EQ=65U(&5N($0G86-O<F0@
M<&5R('9I<W5A;&ET>F%R('5N82!N;W1A('3H8VYI8V$@82!M;WII;&QA+F]R
M9R!Q=64@=7,@;6]S=')A(&-O;2!P;V1E=2!F97(@<75E('5N82!S97'\Z&YC
M:6$@86-C961E:7AI(&%L('!O<G1A+7)E=&%L;',N(`!%;&EM:6YA<B!E;"!C
M;VQO<@!%>'1E;G-I\R!N;R!I;7!L96UE;G1A9&$`06-T=6%L:71Z87(`06-T
M=6%L:71Z87(@)7,`06-T=6%L:71Z87(@;"=U<W5A<FD`4R=H82!S=7!R:6UI
M="!L82!S97'\Z&YC:6$@9"=A8W1U86QI='IA8VGS+@!#87)R96=A<@!3)VAA
M(&-A<G)E9V%T(&%L('-E<G9I9&]R('1O=',@96QS(&%R>&EU<R!D92!C;VYF
M:6=U<F%C:?,@9"=A<&QI8V%C:6]N<RX`06QF86)E="!L;&%T[2!E;B!M86KZ
M<V-U;&$`6&EF<F5S(')O;6%N97,@96X@;6%J^G-C=6QA`%5R=6=U86D`571I
M;&ET>F%R(&PG86-T=6%L.B`E<P!5=&EL:71Z87(@4U-,`%5T:6QI='IE=2!S
M:2!E;"!N;VT@;R!L82!C;VYT<F%S96YY82!S\VX@9&EF97)E;G1S(&%L('-E
M<G9I9&]R($E-4U`N`$PG=7-U87)I("5S(&YO(&5S=.`@875T;W)I='IA="!P
M97(@82`E<RX`061M:6YI<W1R86-I\R!D)W5S=6%R:7,`3W!C:6]N<R!D)W5S
M=6%R:0!296=I<W1R92!D)W5S=6%R:7,`16P@<F5G:7-T<F4@9"=U<W5A<FES
M(&0G87%U97-T(&QL;V,@97-TX"!I;FAA8FEL:71A="X`3F]M(&0G=7-U87)I
M`$YO;2!D)W5S=6%R:3H`3F]M(&0G=7-U87)I.B``57-U87)I<R!D96P@<VES
M=&5M83H`57IB96MI<W1A;@!%;"!D:7)E8W1O<FD@5D93(&YO(&5X:7-T96EX
M+@!!8G/H;F-I80!,97,@=6)I8V%C:6]N<R!VX&QI9&5S('%U92!S)VAA;B!T
M<F]B870@<_-N.@!686QI9&5S80!686QO<B!E;B!M:6YU=',@82!P87)T:7(@
M9"=A<F$N`$5L('9A;&]R('-U<&5R82!L82!L;VYG:71U9"!MX'AI;6$@9&4@
M)7,N`%9A;&]R<P!686QO<G,@<75E(',G:&%N('-E;&5C8VEO;F%R(&1E`%9A
M;G5A='4`5F%R:6%B;&4`5F5N9>=U96QA`$AA(&9A;&QA="!L82!V97)I9FEC
M86-I\SH@Z7,@<&]S<VEB;&4@<75E(',G:&%G:2!A;'1E<F%T(&5L(&UI<W-A
M=&=E+@!697)S:?,`0V]N=')O;"!D92!V97)S:6]N<P!!;&EN96%C:?,@=F5R
M=&EC86P`1F%R8VEM96YT('9E<G1I8V%L`%9E<G1I8V%L.@!-;VQT(&%L=`!6
M:65T;F%M`%9I971N86UI=&$@*%9)4T-)22D`5FES=6%L:71Z87(@)7,`5FES
M=6%L:71Z87(@=6YA('#@9VEN82!W96(@97AT97)N80!6:7-U86QI='IA<B!C
M;VT@82`E<P!);&QE<R!697)G97,@8G)I=.!N:7%U97,`26QL97,@5F5R9V5S
M(&YO<F0M86UE<FEC86YE<P!6:7-I8FEL:71A=`!6:7-I8FEL:71A=#H@`%9O
M9&%F;VYE(&0G273@;&EA('!E<B!V:6$@9&4@4TU44`!!1%9%4E3(3D-)00!!
M5LU3(2!%3$E-24Y!4B!,02!315'<R$Y#24$@34%.54%,345.5"!$12`E<RX`
M5V%L;&ES(&D@1G5T=6YA`$%V[7,`1&,N`%!R979I<VGS(&1E;"!T96UP<P!)
M;F9O<FUA8VGS(&UE=&5O<F]L\F=I8V$@<')O<&]R8VEO;F%D82!P97(`5V5A
M=&AE<BYC;VT`5V5B`$QL;V,@=V5B`%-E=&UA;F%L;65N=`!"96YV:6YG=71S
M`$)E;G9I;F=U=',@82`E<P!"96YV:6YG=71S+"`E<P!/8V-I9&5N=&%L("A)
M4T\M.#@U.2TQ*0!/8V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4^!H87)A($]C
M8VED96YT86P`475I;F$@87!L:6-A8VGS(&AA=7)I82!D92!M;W-T<F%R("5S
M(&5N(&EN:6-I87(@;&$@<V5S<VGS/P!1=6EN(.ES(&5L(&-A<N!C=&5R(&1E
M;&EM:71A9&]R/P!1=6EN(.ES(&5L(&-A<N!C=&5R(&1E(&-I=&%C:?,_`%%U
M:6YE<R!F87-E<P!0;'5G:6YS(&AA8FEL:71A=',@9&4@;"=E9&ET;W(@9&4@
M=&5X="!E;G)I<75I="X`06UP;&%D80!!;7!L861A(&1E(&QE<R!U;FET871S
M($-34P!!;7!L861A(&1E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$@*&1I<W!O
M;FEB;&4@96X@;&$@<')O<&5R82!S97-S:?,I.@!!;7!L861A(&1E(&QA('1A
M=6QA`%5N:71A="!D)V%M<&QA9&$`06UP;&%D83H`5VEK:0!696YT`%9E;G0@
M82!P<FEM97)A(&AO<F$`5F5L;V-I=&%T(&1E;"!V96YT(&5N(&YU<V]S`%9E
M;G0Z`%9E;G0Z(`!3879I97-A`$9E:6YA`$%D<F7G82!D92!L82!F96EN80!4
M96SH9F]N(&1E(&QA(&9E:6YA`%@M4F5F`$QI;6ET86-I;VYS(&+@<VEQ=65S
M(%@U,#EV,P#:<R!D92!L82!C;&%U(&5S=&5S82!X-3`Y=C,`3F]M(&%L=&5R
M;F%T:74@9"=A<W-U;7!T92!8-3`Y=C,`261E;G1I9FEC861O<B!D92!C;&%U
M(&0G87-S=6UP=&4@6#4P.78S`$5X=&5N<VEO;G,@6#4P.'8S`$%!`$%!04$`
M36%P82!D92!986AO;R$`06YU86QM96YT`$EE;65N`%/M`%/M+"!H;R!A8V-E
M<'1O`%-O=2!E;B!E;"!-3T1%(%1%6%0N(%5S974@96P@8F]T\R!;/#Y=('!E
M<B!T;W)N87(@82!765-)5UE'+@!.;R!E<W1E=2!A=71E;G1I8V%T<RX`3F\@
M:&5U(&EN=')O9'7O="!U;F$@861R9>=A(&5L96-T<O)N:6-A(';@;&ED82X`
M3F\@:&5U(&%S<V]C:6%T(&-A<"!C86UP(&1E(&PG87)X:74@:6UP;W)T870@
M86UB(&5L<R!C86UP<R!C;W)R97-P;VYE;G1S(&1E("5S+@!(974@<V]R=&ET
M(&1E(&QA('-E<W-I\RX`2&5U(&0G:6YT<F]D=6ER('5N(&[Z;65R;R!D92!T
M96SH9F]N(&WR8FEL(';@;&ED+"!N;VWI<R!D[6=I=',@86UB('5N("<K)R!O
M<&-I;VYA;"!P97(@86P@<')E9FEX(&1E('1R=6-A9&$@:6YT97)N86-I;VYA
M;"X`2&5U(&0G:6YT<F]D=6ER('5N('9A;&]R(';@;&ED+@!(974@9&4@8V]N
M9FEG=7)A<B!U;B!M;W1O<B!D92!$871A5')E92!P97(@=71I;&ET>F%R($%L
M=&5S+@!(974@9&4@8V]N9FEG=7)A<B!U;B!M;W1O<B!D92!61E,N`$AE=2!D
M92!D97-C<FEU<F4@96P@<')O8FQE;6$@86)A;G,@9"=E;G9I87(M;F4@;"=I
M;F9O<FUE+@!(974@9"=I;G1R;V1U:7(@96P@55),('%U92!A<75E<W0@96YL
M;&'G(&EN9&EC82X`2&5U(&1E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R('%U
M92!V=6QG=65U(&5L:6UI;F%R+@!(974@9"=E<W!E8VEF:6-A<B!U;B!N;VT@
M9"=U<W5A<FD@<75E('9U;&=U974@97-B;W)R87(N`$AE=2!D)V5S<&5C:69I
M8V%R('5N(&YO;2!D)W5S=6%R:2!Q=64@=G5L9W5E=2!S=7!R:6UI<BX`2&5U
M(&0G97-P96-I9FEC87(@<75I;B!N;VT@9"=U<W5A<FD@=F]L974@869E9VER
M+@!(974@9"=E<W!E8VEF:6-A<B!E;"!N;VT@9"=U<W5A<FD@<75E('9O;&5U
M(&%C='5A;&ET>F%R+@!(974@9"=E<W!E8VEF:6-A<B!Q=6EN82!A8V-I\R!V
M;VQE=2!E>&5C=71A<BX`2&5U(&1E('1E8VQE:F%R('5N(&YO=2!N;VT@9&4@
M8V%T96=O<FEA+@!,82!V;W-T<F$@<V5S<VGS(&5N("5S(&AA(&5X<&ER870N
M(%-I('5S('!L874L(&EN:6-I974@=6YA(&YO=F$@<V5S<VGS+@!,82!V;W-T
M<F$@861R9>=A(&5L96-T<O)N:6-A`$QA('1E=F$@861R9>=A(&1E(')E<W!O
M<W1A`$QA('9O<W1R82!I;F9O<FUA8VGS`$QA('9O<W1R82!A9')EYV$@9"=)
M;G1E<FYE="!H82!C86YV:6%T(&1E<R!Q=64@:&5U(&-O;65NYV%T(&QA('-E
M<W-I\R`E<RX@4&5R(')A;VYS(&1E('-E9W5R971A="P@:&5U(&1E(')E:6YI
M8VEA<B!L82!S97-S:?,N`$5L('9O<W1R92!N;VT`16P@=F]S=')E(&UO=&]R
M(&0G875T96YT:6-A8VGS(&YO('!E<FUE="!Q=64@97,@;&QI<W1I;B!E;',@
M=7-U87)I<RP@;R!BZ2!P97(@86QG=6YA(')A\R!A<75E<W1A(&-A<F%C=&5R
M[7-T:6-A(&5S=.`@:6YH86)I;&ET861A+@!396UB;&$@<75E(&5L(&YA=F5G
M861O<B!H82!C86YV:6%T(&1E<R!Q=64@=F%U(&-O;65NYV%R(&QA('-E<W-I
M\R`E<RX@4&5R(')A;VYS(&1E('-E9W5R971A="P@:&5U(&1E('1O<FYA<B!A
M(&5N=')A<B!A;"!S:7-T96UA+@!%;"!V;W-T<F4@;F%V96=A9&]R(&YO(&%C
M8V5P=&$@87%U97-T82!C87)A8W1E<NUS=&EC82X`16P@=F]S=')E(&YA=F5G
M861O<B!N;R!P97)M970@87%U97-T82!O<&-I\R!D)VEM<')E<W-I\RX@4')E
M;6D@0V]N=')O;"`K(%`@<&5R(&EM<')I;6ER+@!:;VYA(&AO<N!R:6$@86-T
M=6%L.@!)9&5N=&ET870@<')E9&5T97)M:6YA9&$Z`$YO;2!C;VUP;&5T.@!,
M82!N;W9A(&-O;G1R87-E;GEA('!E<B!A("5S(.ES.B`E<P!,97,@;W!C:6]N
M<R!H86X@97-T870@86-T=6%L:71Z861E<R!P97(@82!L82!D=7)A9&$@9"=A
M<75E<W1A('-E<W-I\RX`3&5S(&]P8VEO;G,@:&%N(&5S=&%T(&%C='5A;&ET
M>F%D97,N`%,G:&$@<F5I;FEC:6%T(&QA('9O<W1R82!C;VYT<F%S96YY80!3
M)VAA(')E:6YI8VEA="!L82!V;W-T<F$@8V]N=')A<V5N>6$L(')E=FES82!E
M;"!C;W)R974@96QE8W1R\FYI8R!I(&EN:6-I82!L82!S97-S:?,@86UB(&QA
M(&YO=F$@8V]N=')A<V5N>6$N`%-E<G9I9&]R<R!R96UO=',Z`$EU9V]S;.!V
M:6$`6F%I<F4`6N!M8FEA`%II;6)A8G=E`%II<'!Y`%M/8W5L=&$@=&5X="!C
M:71A=%T`6TEN9F]R;64@9&5L('!R;V)L96UA70!;36]S=')A('1E>'0@8VET
M870@+0!;36]S=')A('1E>'0@8VET870@+2`E<R!L[6YI97-=`%ML[6YI82`E
M<R!D92`E<UT`7T%D;6YI<W1R86-I\P!?0TQ)`%]!<F)R92!D92!D861E<P!?
M4W5P<FEM:7(@9FEL80!?1W)U<',`7T%J=61A`%]0<F]P:65T871S(&1E(&QA
M(&EM871G92XN+@!?26YI8VEA(&QA('-E<W-I\P!?4W5R=`!?36]D:69I8V$@
M;"=E;FQL8><N+BX`7T]P8VEO;G,`7U!E<FUI<V]S`%]%;&EM:6YA(&PG96YL
M;&'G+BXN`%]#;VYF:6=U<F%C:?,`7U!R;W!I971A=',@9&4@;&$@=&%U;&$N
M+BX`7U5S=6%R:7,`;&QI8G)E=&$@9"=A9')E8V5S`&%G96YD80!C86QM80!0
M<F5M:2!A<77M`&5S=.`@8V%I96YT`&%R>&EU`&1E<R!D96P@)7,@*"5S*2!A
M(&QE<R`E<R`E<P!H.@!H:`!I;6UE9&EA=`!I;G-E<F5I>`!L[6YI97-=`%,G
M:&$@<')O9'7O="!U;B!C;V1I(&0G97)R;W(@)60@9&5L(&UK:7-O9G,@96X@
M8W)E87(@25-/+@`C;6TC`&YO;0!N;R!S)VAA(&EM<&QE;65N=&%T`&5N8V%R
M82!N;R!S)VAA(&EM<&QE;65N=&%T`&)L;V,@9&4@;F]T97,`<&5R8V5N=&%T
M9V4`<.UX96QS`&5S=.`@<'5J86YT`&UO<W1R87(@9&EF97+H;F-I97,`<VUS
M,F5M86EL('!E<B!V:6$@9&4@2%144`!S<P!C;VYS=&%N=`!L;&ES=&$@9&4@
M=&%S<75E<P!T96-L96=E=2!L82!C;VYT<F%S96YY82!D=65S('9E9V%D97,@
M<&5R(&-O;F9I<FUA<BUL80!U;FEF:6-A=`!S96YS92!N;VT`<V5L96-C:?,@
M9&4@;"=U<W5A<FD`=D-A<F0`=SHC(P!W96%T:&5R+F-O;0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V)S7T)!+P``````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V
M,0`P,38V,34`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8G-?0D$O
M3$-?34534T%'15,O````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#8Q`#`R,#0P,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]B<U]"02],0U]-15-304=%4R]H;W)D92YM;P``````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-34T,S<`,3`U,34T,S$P-C$`,#(R,#4S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-X2!)4`
M````C0$``!P```"$#```'0(``.P8````````8"$```X```!A(0``#0```'`A
M```(````?B$```L```"'(0``#````),A```$````H"$```P```"E(0``"P``
M`+(A```%````OB$``"@```#$(0``"````.TA```*````]B$``!4````!(@``
M$@```!<B```+````*B(```H````V(@``#0```$$B```.````3R(``!$```!>
M(@``#0```'`B```,````?B(```T```"+(@``!@```)DB```,````H"(```X`
M``"M(@``#@```+PB```(````RR(``!H```#4(@``!0```.\B```1````]2(`
M``@````'(P``$````!`C```/````(2,```H````Q(P```P```#PC```)````
M0",```\```!*(P``"@```%HC```D````92,``!0```"*(P``#````)\C```L
M````K",```L```#9(P``!P```.4C```'````[2,```,```#U(P``(P```/DC
M```4````'20``!<````R)```%P```$HD```?````8B0```4```"")```.0``
M`(@D```&````PB0``!0```#))```"@```-XD```$````Z20```<```#N)```
M"0```/8D```&`````"4``!$````')0``!P```!DE```6````(24```0````X
M)0``"````#TE```&````1B4```T```!-)0``!@```%LE```>````8B4``!$`
M``"!)0``"````),E```-````G"4```P```"J)0``!P```+<E```#````OR4`
M``,```##)0``$P```,<E```(````VR4```@```#D)0``"````.TE```@````
M]B4```8````7)@``!@```!XF```5````)28``!4````[)@``%````%$F```8
M````9B8``!T```!_)@``!@```)TF``!4````I"8```4```#Y)@``!0```/\F
M```;````!2<``!H````A)P``$0```#PG```1````3B<``!P```!@)P``*@``
M`'TG```0````J"<```4```"Y)P``$P```+\G```0````TR<```<```#D)P``
M!P```.PG```$````]"<```X```#Y)P``!@````@H```-````#R@``!`````=
M*```$@```"XH```H````02@```4```!J*```!````'`H```(````=2@```<`
M``!^*```#0```(8H```0````E"@```L```"E*```!@```+$H```9````N"@`
M`!@```#2*```%````.LH```+`````"D```D````,*0``%@```!8I```/````
M+2D``!8````]*0``"````%0I```+````72D```0```!I*0``#P```&XI```0
M````?BD``!<```"/*0``$0```*<I```-````N2D```D```#'*0``(````-$I
M```1````\BD```<````$*@``!0````PJ```'````$BH```@````:*@``!@``
M`",J```&````*BH``!`````Q*@``#P```$(J```0````4BH```\```!C*@``
M"P```',J```/````?RH```P```"/*@``#P```)PJ```(````K"H```<```"U
M*@``!````+TJ```0````PBH```(```#3*@``#0```-8J```2````Y"H``!4`
M``#W*@``!`````TK```%````$BL```0````8*P``#````!TK```*````*BL`
M``@````U*P``"0```#XK```%````2"L```H```!.*P``&0```%DK```I````
M<RL```<```"=*P``"@```*4K```,````L"L```\```"]*P``$````,TK```/
M````WBL```<```#N*P``%@```/8K```$````#2P```0````2+```!P```!<L
M```(````'RP``"`````H+```#0```$DL```.````5RP``!8```!F+```$0``
M`'TL```&````CRP```,```"6+```!@```)HL```'````H2P```<```"I+```
M!P```+$L```6````N2P```T```#0+```!0```-XL```>````Y"P```D````#
M+0``"@````TM```,````&"T```\````E+0``"````#4M```&````/BT```<`
M``!%+0``"P```$TM``!'````62T```T```"A+0``"0```*\M```*````N2T`
M`&@```#$+0``!0```"TN```;````,RX``"\```!/+@``$````'\N```*````
MD"X```\```";+@``"@```*LN```)````MBX```,```#`+@``!P```,0N```*
M````S"X```L```#7+@``!P```.,N```)````ZRX```<```#U+@``$````/TN
M```$````#B\```<````3+P``!0```!LO```-````(2\```P````O+P``"```
M`#PO```7````12\```L```!=+P``$P```&DO```$````?2\```H```""+P``
M!````(TO```,````DB\```D```"?+P``!0```*DO```'````KR\```4```"W
M+P``!````+TO```"````PB\``"$```#%+P``!````.<O```4````["\```@`
M```!,```!P````HP```0````$C````<````C,```#@```"LP```%````.C``
M`!$```!`,```"````%(P```&````6S````<```!B,```'@```&HP```H````
MB3````H```"R,```&@```+TP```4````V#```"@```#M,```*@```!8Q```0
M````03$```<```!2,0``$P```%HQ```-````;C$``!X```!\,0``%````)LQ
M```.````L#$``"H```"_,0``!0```.HQ```1````\#$```<````",@``%```
M``HR```8````'S(```P````X,@``!@```$4R```/````3#(``"<```!<,@``
M&0```(0R```?````GC(``!,```"^,@``"````-(R```'````VS(```@```#C
M,@``"0```.PR```5````]C(```T````,,P``$P```!HS```#````+C,``$8`
M```R,P``/P```'DS```W````N3,``%<```#Q,P``!0```$DT```*````3S0`
M``T```!:-```+0```&@T```$````EC0``"4```";-```'P```,$T```=````
MX30```0```#_-```$`````0U```;````%34```<````Q-0``!P```#DU```$
M````034``!\```!&-0``)P```&8U```C````CC4``!\```"R-0``+P```-(U
M```A`````C8``!P````D-@``,0```$$V```"````<S8``!0```!V-@``#```
M`(LV```'````F#8```\```"@-@``%````+`V```=````Q38```<```#C-@``
M,@```.LV```A````'C<```P```!`-P``$0```$TW```(````7S<```<```!H
M-P``!P```'`W```&````>#<```<```!_-P``#0```(<W```+````E3<``!0`
M``"A-P``%0```+8W```.````S#<``"\```#;-P``,0````LX```_````/3@`
M``8```!].````P```(0X```U````B#@``!D```"^.```,````-@X```2````
M"3D``!,````<.0``$````#`Y``!Y````03D```D```"[.0``*P```,4Y```7
M````\3D``!8````).@``#P```"`Z```?````,#H``$````!0.@``'P```)$Z
M```<````L3H``%$```#..@``%````"`[```*````-3L```4```!`.P``!@``
M`$8[```(````33L```4```!6.P``$@```%P[```0````;SL``!,```"`.P``
M'0```)0[```/````LCL```\```#".P``!````-([```)````USL```L```#A
M.P``!P```.T[```%````]3L``!0```#[.P``!P```!`\```(````&#P```\`
M```A/```"````#$\```,````.CP```\```!'/```!@```%<\```4````7CP`
M``8```!S/```#````'H\```)````ASP```<```"1/```!0```)D\```+````
MGSP``'4!``"K/```$````"$^```-````,CX```@```!`/@``"````$D^```'
M````4CX```,```!:/@``"@```%X^```-````:3X```4```!W/@``'P```'T^
M```.````G3X```H```"L/@``$0```+<^```/````R3X```H```#9/@``"0``
M`.0^```1````[CX```X`````/P``"@````\_```+````&C\```T````F/P``
M"0```#0_```&````/C\```\```!%/P``#P```%4_```/````93\```<```!U
M/P``&@```'T_```%````F#\```X```">/P``#0```*T_```8````NS\``!(`
M``#4/P``#0```.<_```%````]3\```P```#[/P``%@````A````,````'T``
M`!\````L0```$````$Q````&````74```#8```!D0```"@```)M````(````
MID````4```"O0````P```+5````E````N4```!<```#?0```%P```/=````@
M````#T$``!\````P00``!0```%!!```K````5D$```8```""00``%@```(E!
M```+````H$$```4```"L00``"````+)!```*````NT$```,```#&00``$```
M`,I!```&````VT$``!,```#B00```P```/9!```'````^D$```,````"0@``
M#0````9"```&````%$(``"8````;0@``$0```$)"```(````5$(``!````!=
M0@``#````&Y"```'````>T(```,```"#0@```P```(="```2````BT(```@`
M``">0@``!P```*="```'````KT(``"4```"W0@``!@```-U"```(````Y$(`
M`!P```#M0@``$P````I#```5````'D,``!L````T0P``'P```%!#```(````
M<$,``%$```!Y0P``!````,M#```$````T$,``"$```#50P``'````/=#```/
M````%$0``!@````D1```(@```#U$```K````8$0```\```",1```!@```)Q$
M```6````HT0```H```"Z1```!@```,5$```)````S$0```<```#61```$```
M`-Y$```'````[T0```P```#W1```#`````1%```6````$44``#L````H10``
M!@```&1%```%````:T4```@```!Q10``"@```'I%```/````A44``!$```"5
M10``"@```*=%```&````LD4``!T```"Y10``&0```-=%```D````\44```0`
M```61@``"@```!M&```D````)D8```X```!+1@``%@```%I&```(````<48`
M``L```!Z1@``"````(9&```0````CT8``!````"@1@``%@```+%&```5````
MR$8```P```#>1@``"````.M&```H````]$8``!4````=1P``"````#-'```&
M````/$<```@```!#1P``"````$Q'```'````54<```8```!=1P``$````&1'
M```/````=4<``!$```"%1P``#P```)='```1````IT<``!````"Y1P``"P``
M`,I'```5````UD<```<```#L1P``!P```/1'```"````_$<```T```#_1P``
M!0````U(```/````$T@``!(````C2```&````#9(```%````3T@```@```!5
M2```!P```%Y(```-````9D@```X```!T2```"````(-(```)````C$@```4`
M``"62```"0```)Q(```8````ID@``"P```"_2```!@```.Q(```*````\T@`
M``L```#^2```$`````I)```/````&TD``!`````K20``!@```#Q)```6````
M0TD```0```!:20``!````%])```)````9$D```4```!N20``(0```'1)```/
M````EDD``!(```"F20``(````+E)```5````VDD```<```#P20``!0```/A)
M```(````_DD```4````'2@``!@````U*```(````%$H``!P````=2@``"P``
M`#I*```'````1DH``"<```!.2@``!0```'9*```+````?$H``!$```"(2@``
M&@```)I*```(````M4H```H```"^2@``!0```,E*```.````STH``%(```#>
M2@``%0```#%+```*````1TL```H```!22P``2@```%U+```$````J$L``"4`
M``"M2P``-P```--+```0````"TP```@````<3```$@```"5,```+````.$P`
M``H```!$3````P```$],```'````4TP```T```!;3```"P```&E,```&````
M=4P```@```!\3```"````(5,```4````CDP```,```"C3```!0```*=,```&
M````K4P```\```"T3```#P```,1,```+````U$P``",```#@3```"P````1-
M```5````$$T```<````F30``"@```"Y-```%````.4T```\````_30``"0``
M`$]-```%````64T```@```!?30```P```&A-```$````;$T```(```!Q30``
M*````'1-```'````G4T``!<```"E30``"````+U-```'````QDT``!$```#.
M30``!@```.!-```,````YTT```8```#T30``$@```/M-```%````#DX```4`
M```43@``"````!I.```9````(TX``"T````]3@``!P```&M.```D````<TX`
M`!$```"83@``-0```*I.```U````X$X``!`````63P``"````"=/```-````
M,$\```X````^3P``(P```$U/```:````<4\``!````",3P``+````)U/```'
M````RD\```\```#23P``!P```.)/```9````ZD\``!4````$4```#@```!I0
M```%````*5```!`````O4```+````$!0```4````;5```!@```""4```&```
M`)M0```+````M%````<```#`4```"````,A0```)````T5```!(```#;4```
M#0```.Y0```5````_%````<````240``2````!I1``!'````8U$``#P```"K
M40``8@```.A1```(````2U(```<```!44@``"P```%Q2```L````:%(```<`
M``"54@``+P```)U2```F````S5(``!<```#T4@``"`````Q3```/````%5,`
M`!L````E4P``!````$%3```(````1E,```4```!/4P``)P```%53```F````
M?5,``!H```"D4P``%@```+]3```Q````UE,``"\````(5```'@```#A4```T
M````5U0```(```",5```$P```(]4```/````HU0```X```"S5```#@```,)4
M```:````T50``",```#L5```"````!!5```X````&54``!\```!250``$0``
M`')5```6````A%4```X```";50``"0```*I5```*````M%4```@```"_50``
M"P```,A5```1````U%4```\```#F50``%````/95```5````"U8```X````A
M5@``+````#!6``!$````758``$H```"B5@``"````.U6```"````]E8``#,`
M``#Y5@``(P```"U7```U````45<``!(```"'5P``$@```)I7```0````K5<`
M`(````"^5P``"````#]8```F````2%@``!@```!O6```%@```(A8```3````
MGU@``!P```"S6```,@```-!8```3`````UD``!<````760``3@```"]9```6
M````?ED```L```"560``!````*%9```'````IED```@```"N60``!0```+=9
M```7````O5D``!(```#560``&0```.A9```D`````EH```X````G6@``#P``
M`#9:```$````1EH```D```!+6@``"P```%5:```&````85H```8```!H6@``
M$0```&]:```+````@5H```8```"-6@``$0```)1:```'````IEH```@```"N
M6@``#P```+=:```'````QUH``!(```#/6@``"@```.):```&````[5H```X`
M``#T6@``"0````-;```%````#5L```L````36P```0```,<```!B`0``````
M````````````B@```$$!```7````8P````T```!I````'P```(\`````````
M%P$`````````````]P```%(````I`0``M````(D!``````````````H!``"F
M````@P```+\````?`0``9@```(T!``"D``````````````!M`0``_````&@!
M``"?`````````+L```"R``````````````"G````BP````````!"`0``1P``
M`!(!`````````````%D```!\`0``;@$``/L``````````````/````!U````
MW@```-L```#X````?P``````````````E````"X````"`0``<`$``'X`````
M````=@$``$P```"H````+````#0!``#5`````````#8```!8`0```````"\`
M``!0`0``7@$`````````````J@```$L!``!Y````!```````````````2@``
M`&<!``#+````(P$``%L!``!@`0``1`$`````````````(`$``*$`````````
M+0$````````R````EP```#<!``#6````)`$```,`````````Z0```!P```!5
M`````````(4````1`0```````*X```````````````,!```U````[P```($`
M``"2````6````&H!``"K`````````,T````_`0`````````````(````'`$`
M`),```!N````B```````````````^@````D```"E`````````(P!``!9`0``
M`````$,!```S`````````"T`````````@@$``%8!``!\``````````H```##
M`````````((```!)`0``G@````````````````````````!<`0```````!8`
M``!W````K````-<```!6````F@```&H````/`0```````,````#*````.```
M`-0```#F`````````-H```"'````C@````L`````````C````'(````1````
M3P$``#$!```O`0``)0$``,0``````````````!T`````````50$`````````
M````!@$``"X!````````ZP```-@`````````M0```````````````````!0`
M````````1@$``)$````S`0``G``````````]````SP```'H`````````B0``
M`'0````Q`````````$(````J````'@$``#L```!K`0``5P````X!``"\````
M-@$```````"=````P0```$L```#R````&0```#4!`````````````%(!````
M`````````+X```"I````(@```#X!``#D````)P$```````!0`````````/$`
M``!=`0``?@$````````$`0``%@$``,(````E`````````(````!V````````
M``````#M````&0$``&@```"!`0``^0````````#3````#@```'`````5````
MN0```(8```!_`0```````.X```#G````!0````````"&`0``2``````````^
M````%0$``&\!``#=````@P$``.``````````3@$``"8```";````B`$`````
M````````O0```!H!````````*P$``(`!``!S`0``T0```+H```"9````<P``
M`!@````W`````````-\```!*`0``L0```#H`````````_P```#\`````````
MH``````````Y````2`$``#````#A````.0$``&P```#<````4P$```@!``#J
M````-````$T````I````10```'<!``#,`````````$D``````````````'D!
M``!:`0``V0`````````R`0``/`$```````"-````A`$```<```![````Z```
M`(4!```4`0``AP$``'@!``!A`0```````````````````````-`````0`0``
M`````"L````,`0```````!H`````````40```'T`````````&P`````````H
M`0``/`````````!:````.P$``/,```!G`````````"(!````````!0$`````
M````````!@```!X```"*`0```````*,````````````````````L`0``(0$`
M`%P```!``0``8````'0!````````*@$``+@```#L````,`$``$````#]````
M7P$``&(```!Z`0``&`$``)4``````````````&$````]`0``:P```%L`````
M````;P`````````G````"P$``+8```!=````7P`````````X`0``]0```!(`
M```"````L````+<````3``````````````!,`0``T@```$X```#^````:0$`
M`$T!``"8````<@$``$$```!E````H@```,4````=`0```````*\```!$````
M(P```.4```!#````#P```&P!````````8P$``)````!&`````````+,````'
M`0``R0```/8`````````9```````````````1P$```````````````````P`
M````````X@````````!F`0``K0```'T!``!U`0```````#H!``#.````10$`
M`%0`````````4P```"0```!X````>P$``'$`````````Q@`````!```;`0``
M5P$``(0````-`0``40$```````#T`````````!````#(````5`$``$\````H
M````XP`````````F`0``E@`````````A`````````"````!E`0````````D!
M``!>`````0$``&0!````````<0$``!,!``!M````BP$````@*"5S(&1A>7,@
M86=O*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E<R`M($YO=&EC90`E<R!+0@`E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E
M='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A
M9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE
M;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+2T@<V5L
M96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$%-+U!-`$%B;W5T('1H:7,@
M961I=&]R`$%B;W5T+BXN`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z
M96XN`$%C8V]U;G1I;F<`061D`$%D9"!(97)E.@!!9&0@82!N97<@=7-E<CH`
M061D(&-O;'5M;@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O(&%D9')E<W,@8F]O:SH`061D<F5S<R!";V]K`$%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&P`06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!<')I;`!!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`
M075G=7-T`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)L;V-K(%1Y<&4`0F]L9`!"
M;VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R
M9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T
M=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E
M9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U]E;&P@4')O
M<&5R=&EE<RXN+@!#86QE;F1A<@!#86UB;V1I80!#86UE<F]O;@!#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E
M;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R:65S(&%N9"!,86)E;',`0V5L=&EC
M("A)4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-H86YG90!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAI;&4`0VAI;F$`0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQE87(`
M0VQE87(@35-/9F9I8V4@=&%G<P!#;VQO=7(@<V5L96-T:6]N`$-O;6]R;W,`
M0V]M<&%N>0!#;W!Y`$-O<'D@<V5L96-T:6]N`$-R96%T90!#<F5A=&4@82!L
M:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`1&%I;'D`1&%T
M90!$96-E;6)E<@!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N
M=&ET>0!$969I;FET:6]N<P!$96QE=&4`1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5S8W)I<'1I;VX`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`
M1&]W;FQO860`1&]W;FQO860@)7,`161I=`!%9&ET(%!E<FUI<W-I;VX`161I
M="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P
M=&EO;G,@9F]R.@!%;6%I;"!!9&1R97-S`$5M;W1I8V]N<P!%;F%B;&4@<FEG
M:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%<75A=&]R:6%L($=U:6YE80!%<FET
M<F5A`$5R<F]R`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S
M`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!&96)R=6%R>0!&:6QT97)S
M`$9R;VT`1G5L;"!$97-C<FEP=&EO;@!';P!';V]G;&4@4V5A<F-H`$=R965K
M("A)4T\M.#@U.2TW*0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5L<`!(;U]M
M90!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L
M92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`
M26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E
M>'0`261E;G1I='DG<R!N86UE.@!);G-E<G0@;65S<V%G97,`2F%N=6%R>0!*
M87!A;F5S92`H25-/+3(P,C(M2E`I`$IU;'D`2G5N90!,85]Y;W5T`$QA;F=U
M86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@57!D
M871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,
M87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96)A;F]N`$QE
M<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N
M<W1E:6X`3&EN:W,`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI
M=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I
M;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`
M3'5X96UB;W5R9P!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@
M:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87D`365M
M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`36EM92!4>7!E
M`$UO;G1H;'D`37D@4&]R=&%L($QA>6]U=`!.86UE`$YE='=O<FL`3F5V97(`
M3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N
M86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK
M*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A
M`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="X`3F]N90!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.
M;W9E;6)E<@!/8W1O8F5R`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I
M;VYS(&9O<B`E<P!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!0
M96]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M
M:7-S:6]N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2X`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I`%!R979I;W5S(&]P=&EO;G,`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%)E860@;65S<V%G97,`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N
M=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;6]T92!397)V97)S`%)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!297-E=`!2
M971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N
M`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!3879E($]P=&EO;G,`4V5A<F-H
M`%-E;&5C="!A('-E<G9E<@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93H`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`
M4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N
M9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D
M+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N
M+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I
M<W!L87D@;W!T:6]N<RX`4V5T=7``4V5Y8VAE;&QE<P!3:&]R="!3=6UM87)Y
M`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS
M/P!3:&]W`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I`%-U8FIE8W0`4W5C8V5S<P!497AT`%1H
M86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4;P!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!5;F1O($-H86YG97,`56YF:6QE9`!5;FEC;V1E("A55$8M."D`
M56YI=&5D($%R86(@16UI<F%T97,`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YN86UE9`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N
M86UE`%9I97<@)7,`5V%R;FEN9P!7965K;'D`5V5L8V]M90!796QC;VUE('1O
M("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@
M*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.@!996%R;'D`665S`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ
M(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE
M.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M('!A<W-W;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA
M:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`
M6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U
M;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI
M<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?
M2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-
M;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,
M:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D
M<F5S<R!B;V]K`'1A<VL@;&ES=`!U;FYA;65D`'9#87)D`'=E871H97(N8V]M
M`%!R;VIE8W0M260M5F5R<VEO;CH@:&]R9&4M8G,*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U
M+3`W+3`Q(#$S.C,Q*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!6961R86X@3&IU
M8F]V:6,@/'9L:G5B;W9I8T!S;6%R=&YE="YB83X*3&%N9W5A9V4M5&5A;3H@
M0F]S;FEA;B`\;&]K86Q`;&EN=7@N;W)G+F)A/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N97)A=&]R
M.B!+0F%B96P@,2XQ,`H`("AP<FEJ92`E<R!D86YA*0`@*'IA("5S(&1A;F$I
M`"`H9&%N87,I`"`H<W5T<F$I`"`H:G7H92D`('4@`"5D("5S(&D@)7,`)7,@
M+2!.87!O;65N80`E<R!+0@`E<R!397)V:7-N92!O<&5R86-I:F4@+2!P;W1V
M<F1A`"5S('!O9&6Y879A;FIE`"5S('!R:6IA=F$`)7,@=7-L;W9I('5G;W9O
M<F$`)7,@=F7F('!O<W1O:FDN`"5S('4@)7,@)7,`)7,@;6EN=71A`"5S(&YI
M:F4@<')O;F'P96XN`"5S('IA("5S(&]D("5S`"5S(&%D<F5S87(`)7,@:V%L
M96YD87(`)7,@8FEL:F6^;FEC80`E<R!Z861A8VD`)7,Z("5S`"TM(&EZ86)E
M<FET92`M+0`Q,BUS871N:2!F;W)M870`,C0M<V%T;FD@9F]R;6%T`#(T('-A
M=&$`1&^Y;&\@:F4@9&\@9F%T86QN92!G<F6Y:V4`04TO4$T`3R!O=F]M(&5D
M:71O<G4`3R!P<F]G<F%M=2XN+@"I:69R82!K;W)I<VYIZ&MO9R!N86QO9V$`
M3F%L;V<@:F4@>F%M<GIN=70N`%)AZ'5N;W9O9'-T=F\`1&]D86H`1&]D86H@
M;W9D:F4Z`$1O9&%J(&YO=F]G(&MO<FES;FEK83H`1&]D86H@:V]L;VYU`$1O
M9&%J("5S(&UE;FD@=2!-;WII;&QA(%-I9&5B87(`1&]D86H@=2!A9')E<V%R
M.@!);65N:6L`061M:6YI<W1R:7)A;FIE("T@<&]D9;EA=F%N:F4@9&]Z=F]L
M82!D<G5G:6@@:V]R:7-N:6MA`$%F9V%N:7-T86X`06QB86YI:F$`06R^:7(`
M4W9E`$1O>G9O;&D@<')A=FQJ96YJ92!N=6UE<FES86YI:"!L:7-T:3\`06QT
M97)N871I=FYI($E-4U`@;&]G:6X`06QT97)N871I=FYA($E-4U`@N6EF<F$`
M06QT97)N871I=FYO($E-4U`@:V]R:7-N:>AK;R!I;64`56YEN65N82!J92!I
M;&5G86QN82!V<FEJ961N;W-T+@!!<')I;`!0:71A:B!P<FEJ92!O8F%V;&IA
M;FIA('-E<G9I<VYI:"!O<&5R86-I:F$_`$%U9W5S=`!"86QT:>AK:2`H25-/
M+3@X-3DM,3,I`%9R<W1A(&)L;VMA`$UA<VYO`$)O;&EV:6IA`%IA8FEL:F6Y
M:V4`4G5B`$1E8FQJ:6YA(')U8F]V83H`4G5B;W9I`$)O<VYA(&D@2&5R8V5G
M;W9I;F$`3V)A`$)O8W9A;F$`1&YO`$)O=79E="!O<W1R=F\`0G)A>FEL`$)R
M:71A;G-K82!);F1I:G-K;RU/:V5A;G-K82!497)I=&]R:6IA`$)R=6YE:2!$
M87)U<W-A;&%M`$)U9V%R<VMA`$QI<W1A('-A('1AZ&MA;6$`0G5R:VEN82!&
M87-O`$)U<G5N9&D`0TU3`$-20P!/<V]B:6YE(.9?96QI:F4N+BX`2V%L96YD
M87(`2V%M8F_P80!+86UE<G5N`$YE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0
M('-E<G9E<CH@)7,`2V%N861A`$]D=7-T86YI`$]D=7-T86YI(&]D('!R:6IA
M=F4@<')O8FQE;6$`2V%T96=O<FEJ92!I(&]Z;F%K90!+96QT<VMI("A)4T\M
M.#@U.2TQ-"D`0V5N=')A;&YO+4%F<FGH:V$@4F5P=6)L:6MA`$-E;G1R86QN
M;RUE=G)O<'-K:2`H25-/+3@X-3DM,BD`4')O;6IE;FD`4')O;6EJ96YI=&4@
M:6UE(&D@861R97-U(&MO:F4@=FED92!D<G5G:2!K861A(.AI=&%J=2!I(&]D
M9V]V87)A:G4@;F$@=F&Y92!P;W)U:V4N`,AI;&4`2VEN80!+:6YE<VMI('!O
M:F5D;F]S=&%V;&IE;FD@*$=",C,Q,BD`2VEN97-K:2!T<F%D:6-I;VYA;&YI
M("A":6<U*0!)>F%B97)I=&4@N6EF<G4`27IA8F5R:71E(&MO<FES;FGH:V\@
M:6UE`$EZ86)E<FET92!K86MO('-E('!R:6MA>G5J92!D871U;3H`27IA8F5R
M:71E('9R<W1U('-T:6QA("AZ82!N=6UE<FES86YE(&QI<W1E*0!5<VMRN6YJ
M92!O<W1R=F\`3^AI<W1I`$_H:7-T:2!-4T]F9FEC92!T86=O=F4`27IB;W(@
M8F]J90!+;VUO<FD`2V]M<&%N:6IA`$MO<&ER86H`2V]P:7)A:B!I>F%B<F%N
M;P!+<F5I<F%J`$YA<')A=FD@;&EN:P!.87!R879I(&YO=FD`4')A=FQJ96YJ
M92!P;V0M9F]L9&5R80!0;V1E<VET92!Z861A=&ME(&MO:FD@YF4@<V4@:7IV
M<KEA=F%T:2!N86MO;B!P<FEJ879E(&YA("5S+@!$;F5V;F\`1&%T=6T`1&5C
M96UB87(`4W1A;F1A<F1N;P!3=&%N9&%R9&YA(&)O:F$`1&5F875L="!I9&5N
M=&ET970`1&5F:6YI8VEJ90!/8G)IN6D`0G)I<V%N:F4@:2!I>F)A8VEV86YJ
M92!P;W)U:V$`3V)R:;EI(&EZ86)R86YI(&ED96YT:71E=`!/<&FY:71E('!R
M;V)L96UE('4@<F%D=2!S82!W96)M86EL;VT`3W!I<P!$:7)E:W1O<FEJ`%!R
M:6MAOFD@=G)I:F5M92!U(#(T+7-A=&YO;2!F;W)M871U/P!/<&-I:F4@<')I
M:V%Z80!0<FEK8;YI('!R;V=N;WIU("A4048I`$1O=VYL;V%D`$1O=VYL;V%D
M("5S`$EZ;6EJ96YI`$EZ;6EJ96YI(&1O>G9O;'4`27IM:6IE;FD@9&]Z=F]L
M90!)>FUI:F5N:2!D;WIV;VQE('IA("5S`$EZ;6EJ96YI=&4@;W!C:6IE('IA
M.@!%;6%I;"!A9')E<V$`4VUA:FQI:FD`06MT:79I<F%J(&MO;G1E:W-T(&UE
M;FD@;F$@9&5S;F]M(&ML:6MU/P!%:W9A=&]R:6IA;&YA($=V:6YE:F$`17)I
M=')E:F$`1W)EN6MA`$5S=&]N:6IA`$5T:6]P:6IA`$5T;FGH:VD`179R;W!A
M`%-V86MI:"`Q-2!M:6YU=&$`4W9A:VEH(#(@;6EN=71E`%-V86MI:"`S,"!S
M96MU;F1I`%-V86MI:"`U(&UI;G5T80!+;V0@<W9A:V4@<')I:F%V90!3=F%K
M:6@@<&]L82!S871A`%-V86MI(&UI;G5T`%9R:6IE9&YO<W1I('!R:6UJ97)I
M.@!&96)R=6%R`$9I;'1E<FD`3V0`1&5T86QJ86X@;W!I<P!+<F5N:0!';V]G
M;&4@<')E=')A9V$`1W+H:VD@*$E33RTX.#4Y+3<I`$AE8G)E:G-K:2`H25-/
M+3@X-3DM."U)*0!0;VUOY@!0;^A?971A:P!0;^AE=&%K`$%D<F5S82`H:W7F
M:2D`5&5L969O;B`H:W7F:2D`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$E0
M(&%D<F5S80!)4"!A9')E<V$@;FEJ92!D;W-T=7!N82X`25`@861R97-A(&YI
M:F4@9&]Z=F]L:F5N82!U;G5T87(@0TE$4B!B;&]K82X`27-L86YD`%-A;6\@
M:6MO;F4`26MO;F4@>F$@)7,`26MO;F4@<V$@=&5K<W1O;0!);64@:61E;G1I
M=&5T83H`1&]D879A;FIE('!O<G5K80!*86YU87(`2F%P86YS:VD@*$E33RTR
M,#(R+4I0*0!*=6QI`$IU;FD`4F%?<W!O<F5D`$IE>FEK`$QA;R!.87)O9&YA
M($1E;6]K<F%T<VMA(%)E<'5B;&EK80!:861N:F$@:7IM:F5N83H`6F%D;FIA
M('!R:6IA=F$Z("5S`%IA9&YJ82!P<FEJ879A.B`E<R!S82!A9')E<V4Z("5S
M`%IA9&YJ82!P<FEJ879A.B!.:6MA9`!,871V:6IA`%IA:V]N`%)A<W!O<F5D
M`$QI8F%N`$QE<V]T;P!,:6)E<FEJ80!,:6)I:G-K82!!<F%P<VMA($2^86UA
M:&ER:6IA`$QI:'1E;KET86IN`$QI;FMO=FD`3&ES=&%N:F4@+2!K;W)I<VYI
M:R!M;[YE('9I9&IE=&D@9F]L9&5R`$QI='9A`%7H:71A=F%M+BXN`$QO:V%L
M;F\@=G)I:F5M93H@`$QO:V%L;F4@<&]S=&%V:V4@:2!V<FEJ96UE`$QO:V%C
M:6IA`%!R:6IA=FD@<V4`27IL87H`6F%D86-I('!R:6IA=F4`4')I:F%V82!N
M:6IE('5S<&IE;&$N($YA:G9E<F]V871N:6IE(&IE('!O9W)EN6YO('5N97-E
M;F\@:V]R:7-N:>AK;R!I;64@:6QI(+EI9G)A+@!0<FEJ879A(&YI:F4@=7-P
M:F5L82X`1'5G:2!T96MS=`!,=6MS96UB=7)G`$YA<')A=FET92!K871E9V]R
M:6IE('-T879K:2!I('IA('-V86MU(&]D(&YJ:6@@;V1R961I=&4@;V1G;W9A
M<F%J=>9U(&)O:G4N`$UA<G0`3WIN8>AA=F%N:F4@:V%O('!R;^AI=&%N;R]N
M97!R;^AI=&%N;P!/>FYAZ&%V86YJ92!D<G5G:6T@;WIN86MA;6$@*&YP<BX@
M=F&^;F\@:6QI(&]D9V]V;W)E;F\I`$UA<KEA;&]V82!O<W1R=F$`36%R=&EN
M:6L`3V1G;W9A<F%J=>9A('!O;&IA`$UA=7)I=&%N:6IA`$UA=7)I8VEJ=7,`
M36%J`,AL86YO=FD`5G)S=&$@;65N:6IA.@!3<&]J:2!P;VQJ80!0;W)U:V$`
M36EM92!T:7``36IE<V7H;F\`4F%S<&]R960@;6]G('!O<G1A;&$`26UE`$UR
M9;YA`$YI:V%D80!.;W9A($MA;&5D;VYI:F$`3F]V82!K871E9V]R:6IA`$YO
M=FD@;6IE<V5C`$YO=F\@:V]R:7-N:>AK;R!I;64@*&YI:F4@;V)A=F5Z;F\I
M`$YO=FD@6F5L86YD`$YO=FD@<')O>F]R("A?<')A>F%N*0!.;W9O<W1I`$YE
M=W,M9W)U<&4`1&%L:F4`4VQJ961EYF4@;W!C:6IE`$YI:V%R86=V80!.:6=E
M<@!.:6=E<FEJ80!.;^8`3FEU90!.90!.:6IE('!O<VQA;F\@:V]R:7-N:>AK
M;R!I;64@:2]I;&D@N6EF<F$N`$YI:F5D86X`3F]R9&EJ<VMI("A)4T\M.#@U
M.2TQ,"D`3F]V96UB87(`3VMT;V)A<@!/<&5R871I=FYI('-I<W1E;0!/<&-I
M:F4`3W!C:6IE('IA("5S`$]S=&%L;P!/<W1A;&4@:6YF;W)M86-I:F4`J6EF
M<F$`3&IU9&D`4')O8V5N870`27IV<KEI('-E<G9I<VYE(&]P97)A8VEJ90!)
M>G9RN6D@<V5R=FES;F4@;W!E<F%C:6IE('!R:6QI:V]M(&QO9VER86YJ83\`
M1&]Z=F]L90!!9&UI;FES=')A8VEJ82!D;WIV;VQA("AP<FEV:6QE9VEJ82D`
M3&GH;F4@:6YF;W)M86-I:F4`36]L:6UO(&1A:G1E(&MR871A:R!O<&ES('9A
MN65G('!R;V)L96UA('-A('=E8FUA:6QO;2X`4VQA;FIE('4@;W9A:B!F;VQD
M97(@*&YI:F4@<')I;G7P96YO(&]D('-T<F%N92!)34%082D`4')E=&AO9&YE
M(&]P8VEJ90!0<F]B;&5M/P!/<&ES('!R;V)L96UA`,AI=&%N:F4@<&]R=6MA
M`$&^=7)I<F%J(&1I;F%M:>AK92!E;&5M96YT92!M96YI:F$Z`$&^=7)I<F%J
M('!OZ&5T;G4@<W1R86YI8W4Z`%5D86QJ96YI('-E<G9E<FD`561A;&IE;FD@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4&]N:;ET:0!.
M87IA9"!N82!O<&-I:F4`4F5U;FEO;@!6<F%T:2!S=&%R=2!K;VYF:6=U<F%C
M:6IU`$]P8VEJ92!E9&ET;W)A('1E:W-T80!38>AU=F%J(&]P8VEJ90!4<F&^
M:0!)>F%B97)I=&4@<V5R=F5R`$EZ86)E<FET92!I9&5N=&ET970@:V]J:2"^
M96QI=&4@<')O;6EJ96YI=&DZ`$EZ86)E<FET92"Y96UU(&)O:F$N`$EZ86)E
M<FET92"^96QJ96YI(&IE>FEK.@!0;[EA;&II('!R:6IA=G4@<')O8FQE;6$`
M4&^Y86QJ:2!335,`4V5N96=A;`!396YZ;W(Z(`!397!T96UB87(`4W)B:6IA
M(&D@0W)N82!';W)A`%-E<FEJ<VMI(&)R;VH`240@<V5S:6IE(&IE(&ES=&5K
M86\N`$]D86)E<FD`4&]D97-I=&4@;W!C:6IE(&MO:F4@=F%M(&]M;V=UYG5J
M=2!D82!P;VYIN71I=&4@N6EF<G4@86MO(&IE('IA8F]R879I=&4N`%!O9&5S
M:71E('5D86QJ96YE('-E<G9E<F4@:V]J:6UA(+YE;&ET92!P<FES='5P:71I
M('!U=&5M('9AN65G('!O<G1A;&$N`$]D86)E<FET92"^96QJ96YI(&IE>FEK
M+"!V<F5M96YS:W4@>F]N=2!I('!O<W1A=FME('IA(&1A='5M+@!0;V1E<VET
M92!S=&%R=&YU(&MO;7!O;F5N='4L(+EE;74@8F]J82P@;W-V:F6^879A;FIE
M('-T<F%N:6-E(&D@9')U9V4@;W!C:6IE(&MO:F4@<V4@=&GH=2!P<FEK87IA
M+@!0;W-T879K90!396JY96QI`$MR871A:R!O<&ES`$1A(&QI(&1E9FEN:7-A
M=&D@<')I<W1U<&YE('1I<&ME('IA(&QI;FMO=F4_`%!R:6MAOFD`4')I:V&^
M:2!V<FEJ96UE('IA9&YJ92!P<FEJ879E(&YA:V]N(&QO9VER86YJ83\`4')I
M:V&^:2!M96YI('IA(&UA;FEP=6QA8VEJ92!T86)E;&%M83\`4')I:V&^:2`E
M<R!M96YI(&QI:F5V;S\`5F5L:>AI;F$`4')E<VMOZ&D@<V5R=FES`$IUOFYO
M+65V<F]P<VMI("A)4T\M.#@U.2TS*0!496UA`%5S<&IEN6YO`%1E:W-T`$AV
M86QA(+ET;R!K;W)I<W1I=&4@16YE<F=O9&%T82!W96)M86EL+@!0<F]Z;W(@
M>F$@;W!C:6IE('-E('IA='9O<FEO+B!)>FQA>FEM+@!)9&5N=&ET970@(B5S
M(B!J92!O8G)I<V%N+@!.96UA(&1O<W1U<&YI:"!O<&-I:F$N`$1E<VEL82!S
M92!G<F6Y:V$@=&]K;VT@<')I:V%Z82!O=F]G(&1I:F5L82!P;W)U:V4`5G)I
M:F5D;F]S="!O=F]G(&)R;VIA(&UO<F$@;F%J;6%N:F4@:7IN;W-I=&D@,2X`
M3W9A('9R:6IE9&YO<W0@;6]R82!B:71I(&)R;VHN`$]V86H@<')O>F]R('-E
M('-M:6IE('!O>FEV871I('-A;6\@:7H@<')O>F]R82!/<&-I:F4`6F$`5'5R
M<VMI("A)4T\M.#@U.2TY*0!0;VYIN71I(&EZ;6IE;F4`3F5K871E9V]R:7-A
M;F\`56YI:V]D("A55$8M."D`56IE9&EN:F5N:2!!<F%P<VMI($5M:7)A=&D`
M3F5P;WIN871O(&MO<FES;FGH:V\@:6UE(&EL:2"Y:69R82X`0F5Z:6UE;FD`
M2V]R:7-T:71E(&]V;R!A:V\@<V4@:6UE+[EI9G)A(')A>FQI:W5J=2!Z82!)
M35-0('-E<G9E<BX`2V]R:7-N:6L@)7,@;F5M82!D;WIV;VQU('IA("5S+@!+
M;W)I<VYIZ&ME(&]P8VEJ90!296=I<W1R86-I:F$@:V]R:7-N:6MA`$MO<FES
M;FGH:V\@:6UE`%!R:6MA>B`E<P!5<&]Z;W)E;FIE`%-E9&UIZ&YO`$1O8G)O
M(&1ON6QI`$1O8G)O(&1ON6QI(&YA("5S`$1O8G)O(&1ON6QI+"`E<P!:87!A
M9&YI("A)4T\M.#@U.2TQ*0!:87!A9&YI("A)4T\M.#@U.2TQ-2D`6F%P861N
M82!386AA<F$`2V]J=2!K;VUP;VYE;G1U(.9E("5S('!R:6MA>F%T:2!N86MO
M;B!U;&%Z83\`2V]J92!D;V1A=&ME(+YE;&ET92!A:W1I=FER871I('IA(&5D
M:71O<B!F;W)M871I<F%N;V<@*')I8V@I('1E:W-T82X`J6ER:6YA("5S(&UE
M;FEJ82!S82!L:6IE=F4@<W1R86YI8V4@*'-T=7!A(&YA('-N86=U(&MO9"!S
M;&IE9&7F92!P<FEJ879E*3H`1V]D:;EN:F4`1&$`3F4@;6^^92!S861ROF%V
M871I("=<)R!K87)A:W1E<B!U('1V;VT@<'5N;VT@:6UE;G4N`$]D:F%V;&II
M=F%N:F4@:F4@=7-P:F6Y;F\@:7IV<KEE;F\N`"`E<R!S97-I:F$@:F4@:7-T
M96ML82X@36]L:6UO(&1A('-E('!O;F]V;R!P<FEJ879I=&4N`%9AN6$@92UM
M86EL(&%D<F5S80!68;EA($9R;VTZ(&%D<F5S83H`5F&Y92!I;F9O<FUA8VEJ
M90!68;EA($EN=&5R;F5T(&%D<F5S82!J92!P<F]M:6IE;FIE;F$@;F%K;VX@
M<')I:F%V;&II=F%N:F$@;F$@)7,N($1A(&)I('9AN6$@<VEG=7)N;W-T(&)I
M;&$@<V'H=79A;F$L(&UO<F%T92!S92!P;VYO=F\@<')I:F%V:71I+@!68;EE
M(&EM90!68;D@8G)O=W-E<B!N92!P;V1ROF%V82!O=G4@;6]G=>9N;W-T+@!4
M<F5N=71N82!V<F5M96YS:V$@>F]N83H`5F&Y(&1E9F%U;'0@:61E;G1I=&5T
M.@!68;EE(&EM92!I('!R97II;64Z`%9AN6$@;F]V82"Y:69R82!Z82`E<R!J
M93H@)7,`5F&Y92!O<&-I:F4@<W4@<V'H=79A;F4@=&]K;VT@=')A:F%N:F$@
M;W9E('-E<VEJ92X`3W!C:6IE('-U('-AZ'5V86YE+@!68;EA(+EI9G)A(&IE
M('!O;FFY=&5N80!68;EA(+EI9G)A(&IE('!O;FFY=&5N82P@<')O=FIE<FET
M92!V8;D@92UM86EL(&D@<')I:F%V:71E('-E('-A(&YO=F]M(+EI9G)O;2X`
M5F&Y:2!U9&%L:F5N:2!S97)V97)I.@!*=6=O<VQA=FEJ80!:86ER`%IA;6)I
M:F$`6FEM8F%B=F4`6FEP<'D`6U-A:W)I:B!C:71I<F%N:2!T96MS=%T`6U!R
M:6IA=F$@<')O8FQE;6%=`%M0<FEK8;YI(&-I=&ER86YI('1E:W-T("T`6U!R
M:6MAOFD@8VET:7)A;FD@=&5K<W0@+2`E<R!R961O=F%=`%MR960@)7,@;V0@
M)7-=`%]!9&UI;FES=')A8VEJ80!?0TQ)`%]$871A5')E90!?3V)R:;EI(')E
M9`!?1W)U<&4`7U!O;6_F`%]/<V]B:6YE('-L:6ME+BXN`%]0<FEJ879I('-E
M`%])>FQA>@!?27IM:6IE;FD@;&EN:RXN+@!?3W!C:6IE`%]$;WIV;VQE`%]5
M:VQO;FD@;&EN:RXN+@!?4&]D97-I`$]S;V)I;F4@7W1A8F5L92XN+@!?2V]R
M:7-N:6-I`&EM96YI:P!L:7-T82!Z861A=&%K80!B97H@:6UE;F$`=D-A<F0`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M9&%?1$LO````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8Q,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]D85]$2R],0U]-15-304=%4R\`````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#(P
M,S<V`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1A7T1++TQ#7TU%
M4U-!1T53+VAO<F1E+FUO````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0P-3`P
M,0`Q,#4Q-30S,3`V,0`P,C(P,S$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0````"+!P``'````'0\```3"@``S'@`
M```````8H0``#@```!FA```/````**$```T````XH0``"````$:A```+````
M3Z$```P```!;H0``!````&BA```8````;:$``!L```"&H0``+0```**A```=
M````T*$``"0```#NH0``*0```!.B```9````/:(``"8```!7H@``#````'ZB
M```D````BZ(```\```"PH@``"P```,"B```.````S*(```4```#;H@``*```
M`.&B```(````"J,```H````3HP``%0```!ZC```2````-*,```L```!'HP``
MA0```%.C```.````V:,```H```#HHP``#0```/.C```.`````:0``!$````0
MI```#0```"*D```,````,*0```T````]I```!@```$ND``"4````4J0```H`
M``#GI```#P```/*D```8`````J4```P````;I0``#@```"BE```.````-Z4`
M``@```!&I0``"0```$^E```N````6:4``!H```"(I0``,@```*.E```X````
MUJ4``%0````/I@``40```&2F``!:````MJ8``%<````1IP``-````&FG```)
M````GJ<```T```"HIP``!P```+:G```*````OJ<```\```#)IP``!0```-FG
M```&````WZ<``!$```#FIP``"````/BG```)`````:@```D````+J```)0``
M`!6H```@````.Z@``!,```!<J```$````'"H```/````@:@```H```"1J```
M`P```)RH```/````H*@``!0```"PJ```"0```,6H```-````SZ@``!(```#=
MJ```&0```/"H```>````"JD```\````IJ0``"@```#FI```/````1*D```@`
M``!4J0``)````%VI```4````@JD``!8```"7J0``"````*ZI``!.````MZD`
M`"T````&J@``&0```#2J```'````3JH```P```!6J@``+````&.J```.````
MD*H```,```"?J@``"P```*.J```'````KZH```<```"WJ@``!0```+^J```%
M````Q:H```H```#+J@```P```-:J```7````VJH```H```#RJ@``#P```/VJ
M```.````#:L``!@````<JP``(P```#6K```.````6:L``!0```!HJP``%P``
M`'VK```7````E:L``!<```"MJP``$P```,6K```/````V:L```X```#IJP``
M'P```/BK```=````&*P```<````VK```!@```#ZL```(````1:P```\```!.
MK```!@```%ZL```*````9:P``!,```!PK```"P```(2L```0````D*P``!4`
M``"AK```%0```+>L```'````S:P``!````#5K```!0```.:L```5````[*P`
M`!$````"K0``#````!2M```[````(:T``#@```!=K0``"0```):M```'````
MH*T``!0```"HK0```P```+VM```%````P:T``!````#'K0``"0```-BM```3
M````XJT``#D```#VK0``$@```#"N```G````0ZX``"P```!KK@``*@```)BN
M```E````PZX```H```#IK@``!@```/2N```)````^ZX```<````%KP``+P``
M``VO```W````/:\``"X```!UKP``50```*2O```M````^J\``"T````HL```
M/0```%:P```_````E+```"T```#4L```0`````*Q```C````0[$``",```!G
ML0``0````(NQ```M````S+$``#,```#ZL0``)0```"ZR```5````5+(``!D`
M``!JL@``*0```(2R```D````KK(``"@```#3L@``$0```/RR```*````#K,`
M``P````9LP``"@```":S```0````,;,``!8```!"LP``%@```%FS```'````
M<+,```<```!XLP``%````("S```*````E;,```@```"@LP``)P```*FS```(
M````T;,```<```#:LP``!P```.*S```&````ZK,```4```#QLP``!P```/>S
M```&````_[,```@````&M```*0````^T```.````.;0```H```!(M```!```
M`%.T```'````6+0```D```!@M```!@```&JT```1````<;0```<```"#M```
M%@```(NT```$````HK0```@```"GM```!@```+"T```-````M[0```8```#%
MM```'@```,RT```1````Z[0```@```#]M```#0````:U```,````%+4```<`
M```AM0```P```"FU```#````+;4``!<````QM0``$P```$FU```=````7;4`
M``@```![M0``!````(2U```(````B;4```@```"2M0``00```)NU```:````
MW;4``"L```#XM0``(````"2V```5````1;8```8```!;M@``!@```&*V```5
M````:;8``!@```!_M@``(@```)BV```N````N[8``!T```#JM@``(0````BW
M``!4````*K<``"D```!_MP``"@```*FW```'````M+<```<```"\MP``%0``
M`,2W```.````VK<```H```#IMP``#P```/2W```-````!+@```\````2N```
M#0```"*X```)````,+@``!0````ZN```!@```$^X```8````5K@``!T```!O
MN```$P```(VX```1````H;@``!0```"SN```!````,BX```&````S;@``!0`
M``#4N```5````.FX``!D````/KD```0```"CN0``#@```*BY```%````M[D`
M``4```"]N0``&P```,.Y```:````W[D``!,```#ZN0``$0````ZZ```1````
M(+H``!P````RN@``*@```$^Z```0````>KH``"$```"+N@``!0```*VZ```3
M````L[H```L```#'N@``$@```-.Z```*````YKH```\```#QN@``#0````&[
M```1````#[L``!,````ANP``#````#6[```&````0KL```P```!)NP``!@``
M`%:[```7````7;L``!````!UNP``$0```(:[```(````F+L```4```"ANP``
M#````*>[```0````M+L```4```#%NP``#0```,N[```&````V;L```<```#@
MNP``#0```.B[```'````]KL```L```#^NP``!P````J\```'````$KP```D`
M```:O```"0```"2\```*````+KP``!D````YO```/0```%.\```=````D;P`
M``P```"OO```$````+R\```%````S;P``"4```#3O```$@```/F\```3````
M#+T``"L````@O0``.P```$R]```@````B+T```@```"IO0``-@```+*]```A
M````Z;T``!`````+O@``"````!R^```,````);X```8````RO@``!````#F^
M```/````/KX```X```!.O@``!P```%V^```*````9;X```T```!PO@``'P``
M`'Z^```<````GKX``"$```"[O@``'@```-V^```9````_+X``!X````6OP``
M&P```#6_```A````4;\``"X```!SOP``)@```**_```<````R;\``!X```#F
MOP``'`````7````F````(L```"L```!)P```,P```'7````F````J<```"L`
M``#0P```.````/S````=````-<$``!4```!3P0``+P```&G!```@````F<$`
M`!(```"ZP0``*0```,W!```>````]\$``"`````6P@``$@```#?"``"B````
M2L(``!8```#MP@``(P````3#```H````*,,``"D```!1PP``*````'O#```?
M````I,,``!4```#$PP``(````-K#```E````^\,``"@````AQ```+0```$K$
M```P````>,0``)(```"IQ```(0```#S%```6````7L4``!P```!UQ0``)@``
M`)+%```J````N<4``$$```#DQ0``1````";&```,````:\8```<```!XQ@``
M!P```(#&```&````B,8```T```"/Q@``$````)W&```2````KL8``!,```#!
MQ@``$@```-7&```'````Z,8```0```#PQ@``$````/7&```0````!L<```P`
M```7QP``#@```"3'```-````,\<```\```!!QP``$P```%''```-````9<<`
M`"@```!SQP```P```)S'```-````H,<```8```"NQP``$0```+7'```7````
MQ\<``!L```#?QP``#@```/O'```"````"L@``$D````-R```!0```%?(```0
M````7<@```\```!NR```!````'[(```-````@\@```X```"1R````P```*#(
M```.````I,@```@```"SR```#P```+S(```/````S,@```<```#<R```#0``
M`.3(```0````\L@```T````#R0``"P```!')```&````'<D```L````DR0``
M#````##)```*````/<D``!$```!(R0``&0```%K)```+````=,D```T```"`
MR0``(@```([)```/````L<D``!L```#!R0``-````-W)```*````$LH``!@`
M```=R@``$@```#;*```9````2<H``!8```!CR@``(@```'K*```-````G<H`
M``<```"KR@``%````+/*```+````R,H``"(```#4R@``+P```/?*```+````
M)\L```D````SRP``&0```#W+```+````5\L``!<```!CRP``%P```'O+```)
M````D\L``!8```"=RP``#P```+3+```9````Q,L``!8```#>RP``#@```/7+
M```8````!,P```@````=S```#0```";,```F````-,P``$,```!;S```"```
M`)_,```2````J,P``!\```"[S```"````-O,```+````Y,P``"\```#PS```
M#@```"#-```%````+\T```8````US0``10```#S-```#````@LT```<```"&
MS0``!````([-```*````D\T```H```">S0``#P```*G-```0````N<T``!<`
M``#*S0``$0```.+-```9````],T``!<````.S@``"0```";.```%````,,X`
M``L````VS@``"@```$+.```"````3<X```4```!0S@``#0```%;.```;````
M9,X``!<```"`S@``%````)C.```)````K<X```X```"WS@``#0```,;.```2
M````U,X``#@```#GS@``(````"#/```(````0<\```X```!*SP``>P```%G/
M```8````U<\``!@```#NSP``$0````?0```'````&=````4````AT```&```
M`"?0```>````0-```!L```!?T```&0```'O0```;````E=```!D```"QT```
M$P```,O0```'````W]````@```#GT```!@```/#0```&````]]```!````#^
MT```#P````_1```0````']$```\````PT0``"P```$#1```/````3-$```P`
M``!<T0``#P```&G1```'````>=$```8```"!T0``#@```(C1```,````E]$`
M`"@```"DT0``#P```,W1```(````W=$```@```#FT0``$P```._1```>````
M`](``"$````BT@``(````$32```9````9=(``!<```!_T@``)0```)?2```7
M````O=(``!8```#5T@``!````.S2```;````\=(```T````-TP``#````!O3
M```#````*-,```4````LTP``"````#+3```*````.],```P```!&TP``"P``
M`%/3```0````7],```P```!PTP``#@```'W3```+````C-,```0```"8TP``
M!````)W3```3````HM,``!0```"VTP``#````,O3```)````V-,```X```#B
MTP``"P```/'3```;````_=,```<````9U```!P```"'4```*````*=0```T`
M```TU```"0```$+4```$````3-0```4```!1U````P```%?4```8````6]0`
M``H```!TU```!````'_4```F````A-0```X```"KU```?````+K4```5````
M-]4```4```!-U0``!P```%/5```,````6]4```@```!HU0``"@```''5```&
M````?-4```@```"#U0```@```(S5```&````C]4```8```"6U0``%````)W5
M```-````LM4``!````#`U0``&P```-'5```$````[=4```D```#RU0``$```
M`/S5```)````#=8```D````7U@``!0```"'6```:````)]8```@```!"U@``
M!@```$O6```9````4M8```X```!LU@``!P```'O6```'````@]8```4```"+
MU@``"0```)'6```*````F]8```X```"FU@```@```+76```&````N-8```L`
M``"_U@``#0```,O6```)````V=8```8```#CU@``$@```.K6```)````_=8`
M``<````'UP``%`````_7```=````)-<``$(```!"UP``)0```(77```E````
MJ]<```8```#1UP``"@```-C7```$````X]<```D```#HUP``"````/+7```1
M````^]<```D````-V```!@```!?8```-````'M@```8````LV```!````#/8
M```Y````.-@``#T```!RV```.@```+#8```>````Z]@```4````*V0``#@``
M`!#9```$````']D```8````DV0``!P```"O9```A````,]D```T```!5V0``
M%0```&/9```&````>=D```0```"`V0``$0```(79```&````E]D```H```">
MV0``(@```*G9```$````S-D```4```#1V0``'0```-?9```$````]=D```P`
M``#ZV0``#@````?:```*````%MH```@````AV@``"0```"K:```%````--H`
M`#H````ZV@``,````'7:```U````IMH``"D```#<V@``1P````;;```X````
M3ML``"D```"'VP``/P```+';```N````\=L``"T````@W```'P```$[<```/
M````;MP``!(```!^W```"P```)'<```F````G=P``"D```#$W```)````.[<
M```F````$]T```@````ZW0``"@```$/=```)````3MT```<```!8W0``(```
M`&#=```@````@=T``"8```"BW0``"@```,G=```9````U-T``"D```#NW0``
M%@```!C>```2````+]X```<```!"W@``"@```$K>```,````5=X```\```!B
MW@``$````'+>``!`````@]X``'````#$W@``9@```#7?```.````G-\```D`
M``"KWP``"@```+7?```2````P-\``!,```#3WP``#````.??```&````]-\`
M``\```#[WP``$@````O@```0````'N```!$````OX```'````$'@```C````
M7N```&H```""X```#P```.W@```%````_>```!`````#X0``"0```!3A```$
M````'N$```L````CX0``(````"_A```4````4.$```P```!EX0``#````'+A
M```/````?^$``!4```"/X0``*0```*7A```J````S^$``"8```#ZX0``)P``
M`"'B```I````2>(``"H```!SX@``&0```)[B``!"````N.(``!$```#[X@``
M$@````WC```3````(.,``!0````TXP``#P```$GC```6````6>,``!<```!P
MXP``$````(CC```1````F>,``#0```"KXP``$P```.#C```2````].,``#4`
M```'Y```%````#WD```'````4N0```P```!:Y```(````&?D```0````B.0`
M`!0```"9Y```$0```*[D```7````P.0``!P```#8Y```$P```/7D```4````
M">4``!H````>Y0``$0```#GE```:````2^4``!X```!FY0``&@```(7E```3
M````H.4``!4```"TY0``$0```,KE```7````W.4``!0```#TY0``%P````GF
M```5````(>8```D````WY@``$````$'F```9````4N8```0```!LY@``!P``
M`''F```+````>>8``!$```"%Y@``!@```)?F```&````GN8```8```"EY@``
M!0```*SF```'````LN8```<```"ZY@``!0```,+F```6````R.8```8```#?
MY@``!@```.;F```$````[>8```0```#RY@``!P```/?F```.````_^8```P`
M```.YP``#````!OG```-````*.<```H````VYP``#@```$'G```%````4.<`
M`"@```!6YP``#@```'_G```,````CN<```\```";YP``"@```*OG```(````
MMN<```D```"_YP``*P```,GG```$````]><```@```#ZYP``)@````/H```2
M````*N@```\````]Z```!@```$WH```*````5.@```<```!?Z```"````&?H
M```@````<.@```D```"1Z```%````)OH```,````L.@```T```"]Z```#@``
M`,OH```6````VN@``!$```#QZ```!@````/I```#````"ND```8````.Z0``
M&0```!7I```'````+^D```0````WZ0``"P```#SI```+````2.D```<```!4
MZ0``!0```%SI```'````8ND``!8```!JZ0``#0```('I```-````C^D```H`
M``"=Z0``$````*CI```/````N>D``!$```#)Z0``%P```-OI```*````\^D`
M`!$```#^Z0``"````!#J```$````&>H```\````>Z@``.@```"[J```%````
M:>H```P```!OZ@``'@```'SJ```.````F^H``!````"JZ@``"P```+OJ```,
M````Q^H```D```#4Z@``!P```-[J```*````YNH```D```#QZ@``#@```/OJ
M```0````"NL``!L````;ZP``&````#?K```:````4.L```H```!KZP``"0``
M`';K```*````@.L```P```"+ZP``#P```)CK```(````J.L```8```"QZP``
M'````+CK```'````U>L```4```#=ZP``"P```./K``!'````[^L```T````W
M[```"0```$7L```$````3^P```,```!4[```$P```%CL```3````;.P``!,`
M``"`[```"@```)3L```"````G^P```0```"B[```)0```*?L```#````S>P`
M``4```#1[```*@```-?L```*`````NT```4````-[0``!````!/M```*````
M&.T```T````C[0``!@```#'M```(````..T```@```!![0``!````$KM```%
M````3^T``&@```!5[0``"0```+[M```,````R.T``!````#5[0``!0```.;M
M```&````[.T``!L```#S[0``+P````_N```0````/^X```H```!0[@``#P``
M`%ON```*````:^X```D```!V[@``$P```(#N```;````E.X``!@```"P[@``
M%P```,GN```?````X>X```X````![P```P```!#O```'````%.\```@````<
M[P``!P```"7O```*````+>\```L````X[P``!P```$3O``!1````3.\``!``
M``">[P``#````*_O```-````O.\``!H```#*[P``2@```.7O```9````,/``
M``8```!*\```&@```%'P```E````;/````8```"2\```!@```)GP```?````
MH/````8```#`\```"0```,?P```8````T?```!<```#J\```*`````+Q```&
M````*_$```T````R\0``(@```$#Q``!7````8_$``!,```"[\0``(P```,_Q
M```3````\_$```(````'\@``"P````KR```(````%O(```T````?\@``"@``
M`"WR```'````./(``!0```!`\@``!@```%7R```(````7/(```X```!E\@``
M!P```'3R```*````?/(```L```"'\@``,@```)/R```'````QO(```P```#.
M\@``#0```-OR```7````Z?(```P````!\P``"0````[S```)````&/,```H`
M```B\P``!P```"WS```)````-?,```<````_\P``"@```$?S```;````4O,`
M``\```!N\P``$@```'[S```*````D?,``!8```"<\P``"0```+/S```0````
MO?,```<```#.\P``$@```-;S```$````Z?,```<```#N\P``!0```/;S```%
M````_/,```L````"]```%`````[T```1````(_0``!H````U]```%@```%#T
M```4````9_0``!<```!\]```&````)3T```<````K?0``!D```#*]```!P``
M`.3T```%````[/0```T```#R]```#`````#U```(````#?4``!<````6]0``
M"P```"[U```,````.O4``!\```!']0``&@```&?U```3````@O4```0```"6
M]0``"@```)OU```$````IO4```T```"K]0``#````+GU```%````QO4```D`
M``#,]0``!0```-;U```'````W/4```4```#D]0``!````.KU```"````[_4`
M`#@```#R]0``+````"OV```2````6/8``"D```!K]@``,@```)7V```*````
MR/8``"P```#3]@``+@````#W```S````+_<``#,```!C]P``.````)?W```/
M````T/<``!@```#@]P``$````/GW```/````"O@``!,````:^```%0```"[X
M```4````1/@``!(```!9^```%````&SX```5````@?@``"T```"7^```+0``
M`,7X```Q````\_@``"X````E^0``+P```%3Y```L````A/D``&(```"Q^0``
M$P```!3Z```-````*/H```@````V^@``%P```#_Z```(````5_H```P```!@
M^@``*P```&WZ```A````F?H``!H```"[^@``"0```-;Z``!%````X/H``$$`
M```F^P``!````&C[```3````;?L``!0```"!^P``#@```);[```3````I?L`
M`!@```"Y^P``!@```-+[```)````V?L```H```#C^P``#P```.[[```0````
M_OL```<````/_```#@```!?\```%````)OP``!L````L_```"````$C\```&
M````4?P``!0```!8_```$0```&W\```.````?_P``#@```"._````@```,?\
M```&````ROP```X```#1_```!0```.#\```'````YOP```X```#N_```!@``
M`/W\```H````!/T```P````M_0``'````#K]```$````5_T``"D```!<_0``
M%P```(;]```?````GOT``%P```"^_0``%````!O^```^````,/X``!\```!O
M_@``$````(_^```'````H/X```X```"H_@``#````+?^```,````Q/X``!,`
M``#1_@``"@```.7^```=````\/X``!D````._P``!0```"C_```1````+O\`
M`!$```!`_P``)````%+_```2````=_\``!4```"*_P``$@```*#_```.````
ML_\``!D```#"_P``"````-S_```)````Y?\```T```#O_P``!P```/W_```*
M````!0`!``<````0``$`#P```!@``0`&````*``!``L````O``$`&@```#L`
M`0`*````5@`!``<```!A``$`"````&D``0`%````<@`!`!\```!X``$`!@``
M`)@``0`0````GP`!``@```"P``$`#0```+D``0`(````QP`!`!X```#0``$`
M$@```.\``0`L`````@$!`!H````O`0$`"0```$H!`0`*````5`$!`!4```!?
M`0$`!0```'4!`0`4````>P$!``0```"0`0$`$````)4!`0`&````I@$!``<`
M``"M`0$`'@```+4!`0`H````U`$!``H```#]`0$`'`````@"`0`1````)0(!
M``L````W`@$`&@```$,"`0`4````7@(!``0```!S`@$`!````'@"`0`+````
M?0(!``4```")`@$`!@```(\"`0`(````E@(!``8```"?`@$`"@```*8"`0`;
M````L0(!`#0```#-`@$`-`````(#`0`@````-P,!`"D```!8`P$`(````((#
M`0!!````HP,!`!H```#E`P$`*``````$`0`I````*00!`%````!3!`$`(@``
M`*0$`0`&````QP0!``@```#.!`$`!0```-<$`0`(````W00!`!D```#F!`$`
M&0`````%`0`J````&@4!`",```!%!0$`&0```&D%`0`N````@P4!`#0```"R
M!0$`"````.<%`0`7````\`4!``H````(!@$`!P```!,&`0`A````&P8!`!``
M```]!@$`#@```$X&`0`+````708!``<```!I!@$`$P```'$&`0`(````A08!
M``L```".!@$`"@```)H&`0`4````I08!``\```"Z!@$`,@```,H&`0`+````
M_08!``X````)!P$`!0```!@'`0`%````'@<!``4````D!P$`%P```"H'`0`/
M````0@<!``0```!2!P$`"@```%<'`0`)````8@<!``L```!L!P$`#0```'@'
M`0`,````A@<!``X```"3!P$`!0```*('`0`$````J`<!``T```"M!P$`,@``
M`+L'`0!%````[@<!`!<````T"`$`!P```$P(`0`>````5`@!`!0```!S"`$`
M!0```(@(`0`4````C@@!``8```"C"`$`!P```*H(`0`.````L@@!`"H```#!
M"`$`!@```.P(`0`,````\P@!``T`````"0$`$0````X)`0`+````(`D!`#8`
M```L"0$`"@```&,)`0`B````;@D!``L```"1"0$`#P```)T)`0`R````K0D!
M`"4```#@"0$`,`````8*`0`Q````-PH!`"T```!I"@$`#@```)<*`0`%````
MI@H!``X```"L"@$`$P```+L*`0`2````SPH!``<```#B"@$`$0```.H*`0`3
M````_`H!``<````0"P$`%````!@+`0`8````+0L!``<```!&"P$`!0```$X+
M`0`,````5`L!``P```!A"P$`$@```&X+`0`$````@0L!``<```"&"P$`"@``
M`(X+`0`+````F0L!``P```"E"P$`#@```+(+`0`.````P0L!``4```#0"P$`
M!0```-8+`0`N````W`L!`"8````+#`$`(P```#(,`0`#````5@P!`!(```!:
M#`$`!@```&T,`0`>````=`P!`!@```"3#`$`)0```*P,`0`-````T@P!``D`
M``#@#`$`'P```.H,`0`#````"@T!``<````.#0$`"@```!8-`0`"````(0T!
M``P````D#0$`%0```#$-`0`+````1PT!`!D```!3#0$`(````&T-`0`2````
MC@T!``4```"A#0$`"@```*<-`0`5````L@T!`!(```#(#0$`#````-L-`0`$
M````Z`T!``D```#M#0$`!P```/<-`0`,````_PT!`%(````,#@$`%P```%\.
M`0`D````=PX!`!(```"<#@$`!P```*\.`0`&````MPX!``X```"^#@$`#```
M`,T.`0`-````V@X!`!4```#H#@$`$@```/X.`0`/````$0\!`!0````A#P$`
M"@```#8/`0`;````00\!`!````!=#P$`"P```&X/`0!I````>@\!`!H```#D
M#P$`%P```/\/`0`G````%Q`!`!H````_$`$`%P```%H0`0`;````<A`!`!D`
M``".$`$`'P```*@0`0`3````R!`!``@```#<$`$`!P```.40`0`(````[1`!
M``D```#V$`$`%0`````1`0`-````%A$!`",````D$0$`#0```$@1`0`3````
M5A$!``@```!J$0$``P```',1`0!&````=Q$!`#\```"^$0$`-P```/X1`0!7
M````-A(!``4```".$@$`'P```)02`0`O````M!(!``H```#D$@$`"````.\2
M`0`-````^!(!`"T````&$P$`!````#03`0!/````.1,!`"4```")$P$`'```
M`*\3`0`+````S!,!`!\```#8$P$`'0```/@3`0`E````%A0!`"`````\%`$`
M)````%T4`0`@````@A0!``L```"C%`$`!P```*\4`0`-````MQ0!``P```#%
M%`$`%P```-(4`0`&````ZA0!`#D```#Q%`$`#````"L5`0`'````.!4!``D`
M``!`%0$`$P```$H5`0`)````7A4!``0```!H%0$`$````&T5`0`(````?A4!
M``@```"'%0$`!````)`5`0`+````E14!``P```"A%0$`$@```*X5`0`1````
MP14!``P```#3%0$`&@```.`5`0`/````^Q4!``<````+%@$`#0```!,6`0`4
M````(18!``X````V%@$`#````$46`0`;````4A8!`"P```!N%@$`$P```)L6
M`0`<````KQ8!`"@```#,%@$`!@```/46`0`'````_!8!`!,````$%P$`!0``
M`!@7`0`$````'A<!`!<````C%P$`"@```#L7`0`,````1A<!``D```!3%P$`
M!@```%T7`0`)````9!<!``@```!N%P$`"0```'<7`0`*````@1<!`!$```",
M%P$`!@```)X7`0`.````I1<!``X```"T%P$`#0```,,7`0`+````T1<!`!T`
M``#=%P$`"P```/L7`0`"````!Q@!`!P````*&`$`!P```"<8`0`&````+Q@!
M`&0````V&`$`"0```)L8`0`'````I1@!`"8```"M&`$`.````-08`0`:````
M#1D!`"H````H&0$`.P```%,9`0`H````CQD!`#0```"X&0$`&0```.T9`0`5
M````!QH!``4````=&@$`!P```",:`0`(````*QH!``<````T&@$`!0```#P:
M`0`'````0AH!``X```!*&@$`"0```%D:`0`&````8QH!``@```!J&@$`"P``
M`',:`0`'````?QH!``@```"'&@$`!P```)`:`0`6````F!H!``D```"O&@$`
M!@```+D:`0`+````P!H!`!````#,&@$`!@```-T:`0`<````Y!H!`!0````!
M&P$`!P```!8;`0`1````'AL!``@````P&P$`#@```#D;`0`(````2!L!``4`
M``!1&P$`$````%<;`0`)````:!L!`!````!R&P$`!@```(,;`0`9````BAL!
M``H```"D&P$`'````*\;`0`'````S!L!``4```#4&P$`$````-H;`0`4````
MZQL!``L`````'`$`#0````P<`0`H````&AP!`!@```!#'`$`%P```%P<`0`$
M````=!P!``D```!Y'`$`"@```(,<`0`'````CAP!``(```"6'`$`#@```)D<
M`0`(````J!P!`",```"Q'`$`'P```-4<`0`X````]1P!`"8````N'0$`,0``
M`%4=`0`G````AQT!`&0```"O'0$`%````!0>`0!5````*1X!`#@```!_'@$`
M2@```+@>`0!;`````Q\!`"@```!?'P$`.````(@?`0`H````P1\!`"P```#J
M'P$`)@```!<@`0`;````/B`!`#X```!:(`$`J0$``)D@`0`C````0R(!`!<`
M``!G(@$`2````'\B`0"%````R"(!`#````!.(P$`)0```'\C`0!!````I2,!
M`%L```#G(P$`20```$,D`0`Q````C20!`!T```"_)`$`&````-TD`0`K````
M]B0!`"$````B)0$`'P```$0E`0`K````9"4!`"8```"0)0$`(0```+<E`0`G
M````V24!`#H````!)@$`'0```#PF`0`1````6B8!`#,```!L)@$`)0```*`F
M`0`G````QB8!`"````#N)@$`'P````\G`0`P````+R<!`&D```!@)P$`,0``
M`,HG`0!!````_"<!`#,````^*`$`)0```'(H`0`]````F"@!`&4```#6*`$`
M30```#PI`0`O````BBD!`"X```"Z*0$`,````.DI`0!4````&BH!`%H```!O
M*@$`2````,HJ`0!*````$RL!`#(```!>*P$`+P```)$K`0`L````P2L!`"T`
M``#N*P$`<0```!PL`0!F````CBP!`&\```#U+`$`LP```&4M`0`7````&2X!
M`"4````Q+@$`,@```%<N`0`I````BBX!`#X```"T+@$`(@```/,N`0!2````
M%B\!`"4```!I+P$`"P```(\O`0"Q````FR\!`$4```!-,`$`(0```),P`0`P
M````M3`!`"4```#F,`$`'`````PQ`0`Q````*3$!``<```!;,0$`!P```&,Q
M`0`$````:S$!``T```!P,0$`"P```'XQ`0`.````BC$!``L```"9,0$`!0``
M`*4Q`0`0````JS$!``(```"\,0$`60```+\Q`0`%````&3(!`!(````?,@$`
M!````#(R`0`'````-S(!``@````_,@$`!0```$@R`0`P````3C(!``,```!_
M,@$`$````(,R`0`,````E#(!`!,```"A,@$`#0```+4R`0`"````PS(!``<`
M``#&,@$`!@```,XR`0`4````U3(!``P```#J,@$`&````/<R`0`&````$#,!
M`!(````7,P$`#````"HS`0`#````-S,!`"H````[,P$`!````&8S`0`&````
M:S,!``<```!R,P$`'P```'HS`0`U````FC,!`"X```#0,P$`+P```/\S`0`7
M````+S0!`"(```!'-`$`)0```&HT`0`@````D#0!`!L```"Q-`$`&````,TT
M`0`D````YC0!`!\````+-0$`&@```"LU`0`A````1C4!`"````!H-0$`&@``
M`(DU`0`R````I#4!`!H```#7-0$`+P```/(U`0`K````(C8!`!\```!.-@$`
M(P```&XV`0`?````DC8!`!H```"R-@$`(0```,TV`0`E````[S8!`"8````5
M-P$`)0```#PW`0`D````8C<!`!@```"'-P$`'0```*`W`0`D````OC<!`!@`
M``#C-P$`(@```/PW`0`L````'S@!`"\```!,.`$`%0```'PX`0`E````DC@!
M`#P```"X.`$`'P```/4X`0`C````%3D!`!\````Y.0$`(````%DY`0`:````
M>CD!`!@```"5.0$`)@```*XY`0`>````U3D!`"D```#T.0$`'@```!XZ`0`Q
M````/3H!``D```!O.@$`#````'DZ`0`7````ACH!`"\```">.@$`)````,XZ
M`0`'````\SH!``\```#[.@$`%`````L[`0`.````(#L!``T````O.P$`)```
M`#T[`0`%````8CL!``<```!H.P$`(@```'`[`0`E````DSL!`!H```"Y.P$`
M'0```-0[`0`:````\CL!``<````-/`$`QP```!4\`0`+````W3P!`!4```#I
M/`$`!@```/\\`0`)````!CT!``L````0/0$`#0```!P]`0`7````*CT!``8`
M``!"/0$`,P```$D]`0`3````?3T!`!,```"1/0$`!P```*4]`0`/````K3T!
M``<```"]/0$`,@```,4]`0`$````^#T!`"$```#]/0$`$P```!\^`0`,````
M,SX!`!$```!`/@$`,@```%(^`0`6````A3X!``@```"</@$`'0```*4^`0`)
M````PSX!``H```#-/@$`%````-@^`0`*````[3X!`!T```#X/@$`"````!8_
M`0`?````'S\!``@````_/P$`&@```$@_`0`G````8S\!``8```"+/P$`%0``
M`)(_`0`'````J#\!``@```"P/P$`"0```+D_`0`_````PS\!``<````#0`$`
M#P````M``0`.````&T`!`!`````J0`$`"0```#M``0`)````14`!``@```!/
M0`$`$P```%A``0`'````;$`!`!D```!T0`$`"@```(Y``0`7````F4`!`!0`
M``"Q0`$`"@```,9``0`,````T4`!`!<```#>0`$`!````/9``0`J````^T`!
M``P````F00$`$0```#-!`0`'````14$!``(```!-00$`$````%!!`0`8````
M84$!``L```!Z00$``P```(9!`0`(````BD$!``8```"300$`!P```)I!`0`-
M````HD$!``L```"P00$`%````+Q!`0`5````T4$!``X```#G00$`+P```/9!
M`0`@````)D(!`!P```!'0@$`%0```&1"`0`,````>D(!`#$```"'0@$`!0``
M`+E"`0`2````OT(!`#\```#20@$`$@```!)#`0`*````)4,!``8````P0P$`
M!````#=#`0`$````/$,!``H```!!0P$`$P```$Q#`0`%````8$,!``8```!F
M0P$`!@```&U#`0`(````=$,!``0```!]0P$`#````()#`0`*````CT,!`#D`
M``":0P$`+@```-1#`0`I`````T0!``4````M1`$`&````#-$`0`9````3$0!
M`!\```!F1`$`'0```(9$`0`1````I$0!``(```"V1`$`!````+E$`0`*````
MOD0!``8```#)1`$`!0```-!$`0`#````UD0!``P```#:1`$`10```.=$`0`R
M````+44!`!H```!@10$`-````'M%`0`H````L$4!`%,```#910$`&0```"U&
M`0!R````1T8!`"````"Z1@$`-0```-M&`0`A````$4<!`$4````S1P$`,```
M`'E'`0`H````JD<!`"D```#31P$`)@```/U'`0`E````)$@!`"@```!*2`$`
M*````'-(`0`B````G$@!`"L```"_2`$`,````.M(`0`2````'$D!`!,````O
M20$`$````$-)`0!Y````5$D!``D```#.20$`H0```-A)`0!S````>DH!`'P`
M``#N2@$`*P```&M+`0!4````ETL!`!<```#L2P$`)P````1,`0`6````+$P!
M``\```!#3`$`%P```%-,`0`?````:TP!`$````"+3`$`'P```,Q,`0`<````
M[$P!`%$````)30$`&@```%M-`0`4````=DT!``H```"+30$`!0```)9-`0`&
M````G$T!``@```"C30$`!0```*Q-`0`2````LDT!`!````#%30$`$P```-9-
M`0`=````ZDT!``\````(3@$`#P```!A.`0`$````*$X!``D````M3@$`"P``
M`#=.`0`'````0TX!``4```!+3@$`%````%%.`0`'````9DX!``@```!N3@$`
M#P```'=.`0`(````ATX!``P```"03@$`#P```)U.`0`&````K4X!`!0```"T
M3@$`!@```,E.`0`,````T$X!`!$```#=3@$`"````.].`0`$````^$X!`!D`
M``#]3@$`$0```!=/`0`*````*4\!`!@````T3P$`$P```$U/`0`<````84\!
M`!$```!^3P$`!````)!/`0`/````E4\!``<```"E3P$`!````*U/`0`9````
MLD\!``<```#,3P$``@```-1/`0`"````UT\!`!$```#:3P$`"0```.Q/`0`&
M````]D\!`!(```#]3P$`%P```!!0`0`&````*%`!`"<````O4`$``@```%=0
M`0`$````6E`!``\```!?4`$`$P```&]0`0`'````@U`!``<```"+4`$`$0``
M`)-0`0`&````I5`!`!@```"L4`$`!@```,50`0`3````S%`!`!````#@4`$`
M$@```/%0`0`"````!%$!``8````'40$`#`````Y1`0`)````&U$!`!$````E
M40$`(@```#=1`0`'````6E$!``<```!B40$`"P```&I1`0`%````=E$!``(`
M``!\40$`"P```']1`0"4`0``BU$!`!`````@4P$`#P```#%3`0`-````05,!
M``@```!/4P$`"P```%A3`0`(````9%,!``4```!M4P$`&````'-3`0`;````
MC%,!`"\```"H4P$`'@```-A3`0`E````]U,!`"@````=5`$`&@```$94`0`J
M````850!``L```",5`$`(````)A4`0`.````N50!``L```#(5`$`#P```-14
M`0`%````Y%0!`"````#J5`$`#`````M5`0`.````&%4!`!,````G50$`%P``
M`#M5`0`,````4U4!`(H```!@50$`"0```.M5`0`+````]54!``\````!5@$`
M#P```!%6`0`3````(58!``P````U5@$`#0```$)6`0`+````4%8!``8```!<
M5@$`J@```&-6`0`(````#E<!`!`````75P$`&@```"A7`0`*````0U<!`!``
M``!.5P$`$````%]7`0`(````<%<!``\```!Y5P$`+0```(E7`0`A````MU<!
M`#L```#95P$`1@```!58`0!;````7%@!`%D```"X6`$`8@```!)9`0!>````
M=5D!`#X```#460$`#P```!-:`0`2````(UH!``X````V6@$`#P```$5:`0`2
M````55H!``4```!H6@$`!@```&Y:`0`1````=5H!``4```"'6@$`"0```(U:
M`0`)````EUH!`"H```"A6@$`)@```,Q:`0`1````\UH!`!`````%6P$`$@``
M`!9;`0`*````*5L!``8````T6P$`$@```#M;`0`>````3EL!``L```!M6P$`
M$````'E;`0`3````BEL!`!L```">6P$`(0```+I;`0`5````W%L!``X```#R
M6P$`%`````%<`0`)````%EP!`"<````@7`$`&P```$A<`0`>````9%P!``P`
M``"#7`$`6@```)!<`0`P````ZUP!`"(````<70$`!P```#]=`0`/````1UT!
M`#,```!770$`#@```(M=`0`(````FET!``L```"C70$`"````*]=`0`(````
MN%T!``D```#!70$`"@```,M=`0`*````UET!``0```#A70$`$P```.9=`0`,
M````^ET!`!`````'7@$`#P```!A>`0`8````*%X!`"4```!!7@$`$P```&=>
M`0`5````>UX!`!<```"17@$`&@```*E>`0`2````Q%X!`!8```#77@$`$0``
M`.Y>`0`0`````%\!`"T````17P$`'@```#]?`0`'````7E\!``8```!F7P$`
M"````&U?`0`4````=E\!``8```"+7P$`"````))?`0`3````FU\!``L```"O
M7P$`$0```+M?`0`5````S5\!`!,```#C7P$`!P```/=?`0`.````_U\!``4`
M```.8`$`%@```!1@`0`2````*V`!``D````^8`$`0@```$A@`0!`````BV`!
M``D```#,8`$`"````-9@`0`3````WV`!``4```#S8`$`!0```/E@`0`,````
M_V`!``D````,80$`&0```!9A`0!$````,&$!``\```!U80$`,````(5A`0`T
M````MF$!`#,```#K80$`+P```!]B`0`+````3V(!``8```!;8@$`"@```&)B
M`0`&````;6(!`#````!T8@$`,0```*5B`0`O````UV(!`%$````'8P$`+@``
M`%EC`0`N````B&,!`$<```"W8P$`2````/]C`0`N````2&0!`#D```!W9`$`
M)````+%D`0`F````UF0!`$L```#]9`$`+@```$EE`0`T````>&4!`"````"M
M90$`#P```,YE`0`3````WF4!`"````#R90$`(P```!-F`0`C````-V8!`!0`
M``!;9@$`"P```'!F`0`3````?&8!``H```"09@$`#@```)MF`0`9````JF8!
M`!P```#$9@$`!@```.%F`0`'````Z&8!`!8```#P9@$`"@````=G`0`(````
M$F<!`"4````;9P$`"@```$%G`0`,````3&<!``<```!99P$`!@```&%G`0`%
M````:&<!``<```!N9P$`!@```'9G`0`*````?6<!`"H```"(9P$`#P```+-G
M`0`(````PV<!``,```#,9P$`"````-!G`0`)````V6<!``0```#C9P$`#@``
M`.AG`0`%````]V<!`!8```#]9P$`!0```!1H`0`(````&F@!``0````C:`$`
M"0```"AH`0`)````,F@!`!H````\:`$`$0```%=H`0`)````:6@!``H```!S
M:`$`#````'YH`0`'````BV@!``,```"3:`$``P```)=H`0`7````FV@!`!,`
M``"S:`$`-@```,=H`0`(````_F@!``H````':0$`"````!)I`0`(````&VD!
M`$$````D:0$`'````&9I`0`K````@VD!`"4```"O:0$`%P```-5I`0`&````
M[6D!``@```#T:0$`'0```/UI`0`9````&VH!`"<````U:@$`,````%UJ`0`=
M````CFH!`"0```"L:@$`90```-%J`0`L````-VL!``D```!D:P$`"P```&YK
M`0`'````>FL!`!0```"":P$`"P```)=K`0`%````HVL!`!````"I:P$`#0``
M`+IK`0`0````R&L!`!````#9:P$`#````.IK`0`5````]VL!``<````-;`$`
M'@```!5L`0`>````-&P!`!,```!3;`$`#P```&=L`0`5````=VP!``4```"-
M;`$`!0```)-L`0`1````F6P!`%\```"K;`$`7`````MM`0`$````:&T!``X`
M``!M;0$`!0```'QM`0`$````@FT!`!\```"';0$`'````*=M`0`1````Q&T!
M``\```#6;0$`$@```.9M`0`?````^6T!`"0````9;@$`!P```#YN`0`C````
M1FX!``4```!J;@$`&P```'!N`0`4````C&X!`!(```"A;@$`#@```+1N`0`2
M````PVX!``T```#6;@$`%0```.1N`0`3````^FX!``H````.;P$`!0```!EO
M`0`-````'V\!``4````M;P$`%0```#-O`0`5````26\!`!,```!?;P$`"0``
M`'-O`0`%````?6\!``L```"#;P$`"0```(]O`0`%````F6\!``T```"?;P$`
M"P```*UO`0`(````N6\!``T```#";P$`"0```-!O`0`+````VF\!``D```#F
M;P$`!0```/!O`0`)````]F\!``<`````<`$`"P````AP`0`7````%'`!`$,`
M```L<`$`'````'!P`0`-````C7`!``\```";<`$`!0```*MP`0`@````L7`!
M`!@```#2<`$`&0```.MP`0`M````!7$!`#P````S<0$`)P```'!Q`0`)````
MF'$!`#$```"B<0$`(0```-1Q`0`/````]G$!``<````&<@$`#`````YR`0`'
M````&W(!``8````C<@$`&0```"IR`0`0````1'(!``@```!5<@$`"@```%YR
M`0`/````:7(!`"````!Y<@$`'P```)IR`0`B````NG(!`"$```#=<@$`'@``
M`/]R`0`A````'G,!`"$```!`<P$`)````&)S`0`W````AW,!`"D```"_<P$`
M(````.ES`0`B````"G0!`!T````M=`$`*````$MT`0!$````='0!`"\```"Y
M=`$`)@```.ET`0`I````$'4!`$(````Z=0$`'P```'UU`0`6````G74!`#$`
M``"T=0$`(P```.9U`0`3````"G8!`"P````>=@$`'0```$MV`0`<````:78!
M`!,```"&=@$`LP```)IV`0`4````3G<!`"8```!C=P$`)P```(IW`0`H````
MLG<!`!X```#;=P$`(@```/IW`0`6````'7@!`"$````T>`$`*0```%9X`0`L
M````@'@!`#\```"M>`$`+P```.UX`0">````'7D!`!X```"\>0$`(````-MY
M`0`?````_'D!`"H````<>@$`+````$=Z`0!%````='H!`$0```"Z>@$`#```
M`/]Z`0`$````#'L!``8````1>P$`!0```!A[`0`3````'GL!``L````R>P$`
M$````#Y[`0`3````3WL!`!$```!C>P$`"````'5[`0`$````?GL!`!$```"#
M>P$`$P```)5[`0`*````J7L!`!````"T>P$`$0```,5[`0`,````UWL!`!``
M``#D>P$`"P```/5[`0`Z`````7P!``0````\?`$`"0```$%\`0`&````2WP!
M`!(```!2?`$`&````&5\`0`;````?GP!``@```":?`$``@```*-\`0!)````
MIGP!``8```#P?`$`$@```/=\`0`/````"GT!``0````:?0$`#P```!]]`0`(
M````+WT!``,````X?0$`#````#Q]`0`(````27T!``H```!2?0$`$0```%U]
M`0`(````;WT!``T```!X?0$`$@```(9]`0`-````F7T!``P```"G?0$`!```
M`+1]`0`*````N7T!``L```#$?0$`"P```-!]`0`0````W'T!`!@```#M?0$`
M"@````9^`0`,````$7X!`"<````>?@$`#0```$9^`0`9````5'X!`#L```!N
M?@$`"@```*I^`0`5````M7X!`!````#+?@$`&0```-Q^`0`7````]GX!`"``
M```.?P$`$@```"]_`0`'````0G\!`!$```!*?P$`"P```%Q_`0`A````:'\!
M`#\```"*?P$`"0```,I_`0`(````U'\!`!H```#=?P$`"@```/A_`0`9````
M`X`!`!D````=@`$`!P```#>``0`5````/X`!`!D```!5@`$`&````&^``0`4
M````B(`!``X```"=@`$`$P```*R``0`(````P(`!`!````#)@`$`*````-J`
M`0!"`````X$!`!D```!&@0$`&0```&"!`0`F````>H$!``0```"A@0$`!P``
M`*:!`0`P````KH$!`!$```#?@0$`#````/&!`0`&````_H$!`$@````%@@$`
M`P```$Z"`0`'````4H(!``<```!:@@$`"@```&*"`0`,````;8(!`!````!Z
M@@$`$0```(N"`0`8````G8(!``\```"V@@$`&@```,:"`0`8````X8(!``H`
M``#Z@@$`!P````6#`0`+````#8,!``H````9@P$``@```"2#`0`%````)X,!
M``X````M@P$`&P```#R#`0`6````6(,!`!0```!O@P$`!P```(2#`0`+````
MC(,!``\```"8@P$`"P```*B#`0`Z````M(,!`"````#O@P$`!P```!"$`0`9
M````&(0!`(,````RA`$`&@```+:$`0`;````T80!`!$```#MA`$`!P```/^$
M`0`$````!X4!`!T````,A0$`)0```"J%`0`C````4(4!`"(```!TA0$`)```
M`)>%`0`A````O(4!`!T```#>A0$`!P```/R%`0`(````!(8!``8````-A@$`
M!@```!2&`0`,````&X8!``X````HA@$`$````#>&`0`-````2(8!``\```!6
MA@$`#P```&:&`0`*````=H8!`!````"!A@$`!0```)*&`0`%````F(8!`!$`
M``">A@$`#@```+"&`0`J````OX8!``\```#JA@$`"0```/J&`0`(````!(<!
M`!@````-AP$`(0```":'`0`L````2(<!`",```!UAP$`'@```)F'`0`<````
MN(<!`"@```#5AP$`&P```/Z'`0`4````&H@!``4````OB`$`&0```#6(`0`(
M````3X@!``T```!8B`$``P```&:(`0`*````:H@!``<```!UB`$`!0```'V(
M`0`'````@X@!``@```"+B`$`"P```)2(`0`+````H(@!``X```"LB`$`%P``
M`+N(`0`$````TX@!``,```#8B`$`$P```-R(`0`5````\(@!``T````&B0$`
M!P```!2)`0`'````'(D!``H````DB0$`'0```"^)`0`&````38D!``<```!4
MB0$`#@```%R)`0`.````:XD!`!@```!ZB0$`!````).)`0`(````F(D!``0`
M``"AB0$`&````*:)`0`.````OXD!``,```#.B0$`,0```-*)`0`0````!(H!
M`(`````5B@$`$@```):*`0`*````J8H!``@```"TB@$`"P```+V*`0`*````
MR8H!``P```#4B@$`!````.&*`0`.````YHH!``,```#UB@$`!@```/F*`0`(
M`````(L!`!8````)BP$`#0```""+`0`1````+HL!`!L```!`BP$``P```%R+
M`0`#````8(L!`!````!DBP$`"````'6+`0`*````?HL!``4```")BP$`)@``
M`(^+`0`(````MHL!``8```"_BP$`&````,:+`0`.````WXL!``@```#NBP$`
M"````/>+`0`%`````(P!``D````&C`$`!P```!",`0`;````&(P!``4````T
MC`$`!0```#J,`0`+````0(P!``X```!,C`$`"````%N,`0`*````9(P!`!(`
M``!OC`$`"````(*,`0`'````BXP!`!4```"3C`$`'@```*F,`0`Y````R(P!
M`"4````"C0$`)P```"B-`0`'````4(T!``H```!8C0$`!````&.-`0`)````
M:(T!``@```!RC0$`$````'N-`0`(````C(T!``8```"5C0$`#0```)R-`0`&
M````JHT!``0```"QC0$`/@```+:-`0!`````]8T!`#X````VC@$`&0```'6.
M`0`%````CXX!``X```"5C@$``P```*2.`0`(````J(X!``P```"QC@$`(0``
M`+Z.`0`.````X(X!`!<```#OC@$`!0````>/`0`%````#8\!`!P````3CP$`
M!P```#"/`0`)````.(\!`!@```!"CP$``P```%N/`0`$````7X\!`!@```!D
MCP$`!````'V/`0`.````@H\!``T```"1CP$`#@```)^/`0`(````KH\!``D`
M``"WCP$`!0```,&/`0`V````QX\!`"X```#^CP$`-P```"V0`0`=````99`!
M`$````"#D`$`-0```,20`0`H````^I`!`#L````CD0$`+@```%^1`0`O````
MCI$!`!\```"^D0$`#0```-Z1`0`+````[)$!``@```#XD0$`-P````&2`0`M
M````.9(!`"0```!GD@$`*P```(R2`0`)````N)(!``L```#"D@$`"@```,Z2
M`0`&````V9(!`"0```#@D@$`(@````63`0`N````*),!``H```!7DP$`'0``
M`&*3`0`C````@),!`!8```"DDP$`$````+N3`0`&````S),!``H```#3DP$`
M#0```-Z3`0`0````[),!``\```#]DP$`/P````V4`0!]````390!`&X```#+
ME`$`%P```#J5`0`*````4I4!``L```!=E0$`$P```&F5`0`4````?94!`!``
M``"2E0$`"````*.5`0`4````K)4!`!8```#!E0$`$P```-B5`0`2````[)4!
M`"````#_E0$`)0```""6`0!_````1I8!`!````#&E@$`!@```->6`0`4````
MWI8!``H```#SE@$`!````/Z6`0`+`````Y<!`"0````/EP$`%````#27`0`.
M````29<!``P```!8EP$`%0```&67`0`2````>Y<!`"<```".EP$`)0```+:7
M`0`E````W)<!`",````"F`$`*P```":8`0`I````4I@!`!H```!\F`$`0@``
M`)>8`0`2````VI@!`!````#MF`$`%````/Z8`0`2````$YD!``\````FF0$`
M%0```#:9`0`5````3)D!`!(```!BF0$`$````'69`0`S````AID!`!0```"Z
MF0$`%P```,^9`0`[````YYD!`!<````CF@$`!@```#N:`0`,````0IH!`"``
M``!/F@$`$0```'":`0`5````@IH!`!,```"8F@$`%@```*R:`0`4````PYH!
M`!(```#8F@$`%````.N:`0`:`````)L!`!$````;FP$`'0```"V;`0`C````
M2YL!`!X```!OFP$`$P```(Z;`0`5````HIL!`!$```"XFP$`%@```,J;`0`6
M````X9L!`!L```#XFP$`%0```!2<`0`%````*IP!`!(````PG`$`&P```$.<
M`0`$````7YP!``8```!DG`$``P```&N<`0`.````;YP!``8```!^G`$`"```
M`(6<`0`)````CIP!``<```"8G`$`!P```*"<`0`&````J)P!``4```"OG`$`
M%0```+6<`0`&````RYP!``8```#2G`$`!````-F<`0`$````WIP!``8```#C
MG`$`!P```.J<`0`-````\IP!``\`````G0$`#0```!"=`0`*````'IT!``\`
M```IG0$`!0```#F=`0`Q````/YT!`!8```!QG0$`#@```(B=`0`2````EYT!
M``L```"JG0$`"0```+:=`0`/````P)T!`#@```#0G0$`!`````F>`0`(````
M#IX!``@````7G@$`"0```"">`0`1````*IX!``8````\G@$`"P```$.>`0`*
M````3YX!``4```!:G@$`!````&">`0`.````99X!`!8```!TG@$`#@```(N>
M`0`0````FIX!`!````"KG@$`'````+R>`0`4````V9X!``<```#NG@$``P``
M`/:>`0`&````^IX!`!0````!GP$`!P```!:?`0`'````'I\!`!`````FGP$`
M#P```#>?`0`&````1Y\!``8```!.GP$`"````%6?`0`&````7I\!``T```!E
MGP$`"````'.?`0`(````?)\!`!````"%GP$`#0```):?`0`(````I)\!`!,`
M``"MGP$`!P```,&?`0`,````R9\!``D```#6GP$`"@```."?`0`4````ZY\!
M`#X`````H`$`#````#^@`0`*````3*`!`!P```!7H`$`#@```'2@`0`9````
M@Z`!``T```"=H`$`#0```*N@`0`)````N:`!``<```##H`$`"@```,N@`0`)
M````UJ`!``X```#@H`$`$````.^@`0`@`````*$!`!\````AH0$`(````$&A
M`0`*````8J$!``<```!MH0$`"0```'6A`0`*````?Z$!`!,```"*H0$`!```
M`)ZA`0`'````HZ$!`"D```"KH0$`!@```-6A`0`'````W*$!``T```#DH0$`
M2````/*A`0`3````.Z(!``H```!/H@$`"0```%JB`0`#````9*(!``\```!H
MH@$`$0```'BB`0`,````BJ(!``D```"7H@$``@```*&B`0`$````I*(!`"(`
M``"IH@$``P```,RB`0`%````T*(!`"\```#6H@$`"@````:C`0`$````$:,!
M``8````6HP$`%````!VC`0`1````,J,!``8```!$HP$`"````$NC`0`*````
M5*,!``0```!?HP$`!0```&2C`0!P````:J,!``H```#;HP$`#0```.:C`0`1
M````]*,!``4````&I`$`!@````RD`0`8````$Z0!`"H````LI`$`#0```%>D
M`0`*````9:0!`!8```!PI`$`"P```(>D`0`)````DZ0!`!,```"=I`$`(0``
M`+&D`0`<````TZ0!`!P```#PI`$`'@````VE`0`.````+*4!``,````[I0$`
M!P```#^E`0`'````1Z4!``D```!/I0$`#@```%FE`0`,````:*4!``8```!U
MI0$`50```'RE`0`/````TJ4!``H```#BI0$`#0```.VE`0`;````^Z4!`%0`
M```7I@$`&@```&RF`0`&````AZ8!`!T```".I@$`)0```*RF`0`)````TJ8!
M``8```#<I@$`"P```..F`0`$````[Z8!``D```#TI@$`'````/ZF`0`;````
M&Z<!`"L````WIP$`!@```&.G`0`+````:J<!`"````!VIP$`:````)>G`0`2
M`````*@!`!\````3J`$`$P```#.H`0`#````1Z@!``P```!+J`$`!````%BH
M`0`,````7:@!``D```!JJ`$`!P```'2H`0`'````?*@!``8```"$J`$`"0``
M`(NH`0`+````E:@!``@```"AJ`$`"@```*JH`0`)````M:@!`#4```"_J`$`
M!P```/6H`0`,````_:@!``H````*J0$`%@```!6I`0`(````+*D!``@````U
MJ0$`$````#ZI`0`)````3ZD!``<```!9J0$`"````&&I`0`'````:JD!``H`
M``!RJ0$`'P```'VI`0`0````G:D!``T```"NJ0$`"0```+RI`0`8````QJD!
M``H```#?J0$`%0```.JI`0`'`````*H!`!4````(J@$`!````!ZJ`0`'````
M(ZH!``4````KJ@$`!0```#&J`0`,````-ZH!`!,```!$J@$`$0```%BJ`0`:
M````:JH!`!8```"%J@$`%````)RJ`0`7````L:H!`!@```#)J@$`'````.*J
M`0`8````_ZH!``<````8JP$`!@```""K`0`-````)ZL!``L````UJP$`!@``
M`$&K`0`9````2*L!``L```!BJP$`"P```&ZK`0`>````>JL!`!@```"9JP$`
M$P```+*K`0`'````QJL!``T```#.JP$`!0```-RK`0`-````XJL!``T```#P
MJP$`!@```/ZK`0`)````!:P!``4````/K`$`!P```!6L`0`#````':P!``0`
M```AK`$``P```":L`0`[````*JP!`#0```!FK`$`%@```)NL`0`Z````LJP!
M`"@```#MK`$`#@```!:M`0`P````):T!`"\```!6K0$`-````(:M`0`T````
MNZT!`#D```#PK0$`#@```"JN`0`?````.:X!``\```!9K@$`$P```&FN`0`6
M````?:X!`!,```"4K@$`%0```*BN`0`3````OJX!`!4```#2K@$`'````.BN
M`0`P````!:\!`#`````VKP$`-````&>O`0`I````G*\!`"H```#&KP$`)@``
M`/&O`0!D````&+`!`!T```!]L`$`%@```)NP`0`-````LK`!`!D```#`L`$`
M"P```-JP`0`/````YK`!`#0```#VL`$`*````"NQ`0`A````5+$!``T```!V
ML0$`1P```(2Q`0!"````S+$!``4````/L@$`%0```!6R`0`5````*[(!``<`
M``!!L@$`$@```$FR`0`3````7+(!``4```!PL@$`#P```':R`0`(````AK(!
M`!(```"/L@$`$P```**R`0`/````MK(!`!(```#&L@$`!0```-FR`0`>````
MW[(!``@```#^L@$``P````>S`0`*````"[,!``X````6LP$`#````"6S`0`U
M````,K,!``(```!HLP$`!@```&NS`0`,````<K,!``4```!_LP$`!P```(6S
M`0`1````C;,!``8```"?LP$`+0```*:S`0`/````U+,!`"````#DLP$`!```
M``6T`0`N````"K0!`!H````YM`$`'@```%2T`0!?````<[0!`!0```#3M`$`
M/P```.BT`0`E````*+4!``X```!.M0$`#0```%VU`0`4````:[4!``P```"`
MM0$`#````(VU`0`4````FK4!``P```"OM0$`'P```+RU`0`<````W+4!``4`
M``#YM0$`$0```/^U`0`/````$;8!`"$````AM@$`$````$.V`0`4````5+8!
M`!(```!IM@$`$P```'RV`0`;````D+8!``@```"LM@$`"````+6V`0`.````
MOK8!``H```#-M@$`"P```-BV`0`)````Y+8!``X```#NM@$`"0```/VV`0`+
M````![<!`!@````3MP$`"````"RW`0`'````-;<!``@````]MP$`!0```$:W
M`0`)````3+<!``8```!6MP$`#P```%VW`0`(````;;<!``T```!VMP$`!P``
M`(2W`0`/````C+<!``\```"<MP$`(@```*RW`0`7````S[<!``@```#GMP$`
M"0```/"W`0`9````^K<!``8````4N`$`&````!NX`0`#````-+@!`!<````X
MN`$`!````%"X`0`'````5;@!`!4```!=N`$`(@```'.X`0`+````EK@!`!T`
M``"BN`$`$0```,"X`0`+````TK@!`!H```#>N`$`"````/FX`0`$`````KD!
M``<````'N0$`#`````^Y`0`'````'+D!``4````DN0$`"````"JY`0`'````
M,[D!``L````[N0$`#P```$>Y`0`M````5[D!`"X```"%N0$`'@```+2Y`0`E
M````T[D!`!T```#YN0$`.````!>Z`0`@````4+H!`#H```!QN@$`)@```*RZ
M`0!,````T[H!`!T````@NP$`!0```#Z[`0`'````1+L!``\```!,NP$`"```
M`%R[`0`5````9;L!`!@```![NP$`,0```)2[`0`?````QKL!`!(```#FNP$`
M+0```/F[`0`U````)[P!``0```!=O`$`%0```&*\`0`&````>+P!``4```!_
MO`$`(````(6\`0`/````IKP!`!````"VO`$`#````,>\`0`'````U+P!`!(`
M``#<O`$`"0```.^\`0`-````^;P!`!`````'O0$`&0```!B]`0`;````,KT!
M`#$```!.O0$`"P```("]`0`/````C+T!``4```"<O0$`#````**]`0`%````
MK[T!`!P```"UO0$`#@```-*]`0`$````X;T!``P```#FO0$`"0```/.]`0`)
M````_;T!``L````'O@$`!````!.^`0`2````&+X!``<````KO@$``P```#.^
M`0`,````-[X!`#L```!$O@$`2P```("^`0`9````S+X!``<```#FO@$`(0``
M`.Z^`0`9````$+\!``\````JOP$`#@```#J_`0`*````2;\!``4```!4OP$`
M#@```%J_`0`I````:;\!``0```"3OP$`"0```)B_`0`-````HK\!`!````"P
MOP$`"````,&_`0`U````RK\!``4`````P`$`(`````;``0`+````)\`!``\`
M```SP`$`-````$/``0`C````>,`!`#````"<P`$`,````,W``0`O````_L`!
M``L````NP0$`!P```#K!`0`/````0L$!`!,```!2P0$`&P```&;!`0`*````
M@L$!`!L```"-P0$`$P```*G!`0`'````O<$!`!0```#%P0$`)@```-K!`0`%
M`````<(!``4````'P@$`#@````W"`0`-````',(!`!,````JP@$`!0```#["
M`0`(````1,(!``D```!-P@$`#0```%?"`0`+````9<(!`!````!QP@$`$```
M`(+"`0`'````D\(!``<```";P@$`+0```*/"`0`G````T<(!`"4```#YP@$`
M!0```!_#`0`'````)<,!``8````MPP$`'0```#3#`0`6````4L,!`"$```!I
MPP$``P```(O#`0`-````C\,!`"````"=PP$``P```+[#`0`&````PL,!``T`
M``#)PP$``P```-?#`0`+````V\,!`!,```#GPP$`"@```/O#`0`7````!L0!
M`!P````>Q`$`$P```#O$`0`%````3\0!``H```!5Q`$`%````&#$`0`.````
M=<0!``P```"$Q`$``P```)'$`0`(````E<0!``@```">Q`$`$P```*?$`0!.
M````N\0!`!8````*Q0$`-````"'%`0`-````5L4!``D```!DQ0$``P```&[%
M`0`,````<L4!``H```!_Q0$`#````(K%`0`9````E\4!``\```"QQ0$`#@``
M`,'%`0`9````T,4!``D```#JQ0$`&P```/3%`0`.````$,8!``H````?Q@$`
M80```"K&`0`6````C,8!`!````"CQ@$`)0```+3&`0`6````VL8!`!````#Q
MQ@$`*`````+'`0`<````*\<!`!H```!(QP$`%P```&/'`0`(````>\<!``<`
M``"$QP$`!P```(S'`0`)````E,<!`!4```">QP$`"P```+3'`0`K````P,<!
M`!4```#LQP$`$P````+(`0`)````%L@!``8````@R`$`7@```"?(`0`^````
MAL@!`#4```#%R`$`8````/O(`0`+````7,D!`#$```!HR0$`)````)K)`0`,
M````O\D!``@```#,R0$`$````-7)`0`\````YLD!``,````CR@$`2````"?*
M`0`P````<,H!`"8```"AR@$`"P```,C*`0`F````U,H!`!H```#[R@$`+P``
M`!;+`0`L````1LL!`"\```!SRP$`+````*/+`0`,````T,L!``4```#=RP$`
M#0```./+`0`*````\<L!`!````#\RP$`!@````W,`0`K````%,P!``P```!`
MS`$`"0```$W,`0`+````5\P!`!$```!CS`$`"0```'7,`0`)````?\P!`!L`
M``")S`$`"0```*7,`0`)````K\P!``,```"YS`$`!P```+W,`0`(````Q<P!
M`!````#.S`$`#0```-_,`0`*````[<P!`!8```#XS`$`#`````_-`0`'````
M',T!``X````DS0$`#@```#/-`0`/````0LT!``D```!2S0$`&0```%S-`0`E
M````=LT!`!$```"<S0$`%@```*[-`0`D````Q<T!`!````#JS0$`"0```/O-
M`0`/````!<X!``<````5S@$`"0```!W.`0`?````)\X!``D```!'S@$`"P``
M`%'.`0`)````7<X!``4```!GS@$`"0```&W.`0`(````=\X!``D```"`S@$`
M#0```(K.`0`5````F,X!``8```"NS@$`#@```+7.`0`#````Q,X!``\```#(
MS@$`$````-C.`0`9````Z<X!``H````#SP$``P````[/`0`>````$L\!``0`
M```QSP$`!P```#;/`0!M````/L\!``H```"LSP$`!@```+?/`0`@````OL\!
M`"\```#?SP$`#0````_0`0`:````'=`!`#L````XT`$`&@```'30`0`@````
MC]`!``\```"PT`$`#0```,#0`0`%````SM`!``<```#4T`$`"0```-S0`0`*
M````YM`!``<```#QT`$`"0```/G0`0`4`````]$!``L````8T0$`"@```"31
M`0`,````+]$!``P````\T0$`!0```$G1`0`'````3]$!``D```!7T0$`%0``
M`&'1`0`)````=]$!``<```"!T0$`!P```(G1`0`0````D=$!``8```"BT0$`
M%0```*G1`0`&````O]$!``8```#&T0$`#@```,W1`0`&````W-$!``X```#C
MT0$`!P```/+1`0`%````^M$!`!``````T@$`"P```!'2`0`0````'=(!``8`
M```NT@$`'0```#72`0`+````4](!``@```!?T@$`!````&C2`0`'````;=(!
M``T```!UT@$`$P```(/2`0`*````E](!``P```"BT@$`*0```*_2`0`:````
MV=(!`!<```#TT@$`!0````S3`0`)````$M,!``\````<TP$`"0```"S3`0`#
M````-M,!``X````ZTP$`"````$G3`0`D````4M,!`!\```!WTP$`-@```)?3
M`0`A````SM,!`"<```#PTP$`+````!C4`0!Q````1=0!``X```"WU`$`60``
M`,;4`0`R````(-4!`%<```!3U0$`4````*O5`0`A````_-4!`#H````>U@$`
M*0```%G6`0`N````@]8!`"<```"RU@$`&P```-K6`0`V````]M8!`,<!```M
MUP$`'````/78`0`1````$MD!`$,````DV0$`EP```&C9`0`X`````-H!`"0`
M```YV@$`.0```%[:`0!?````F-H!`%L```#XV@$`*0```%3;`0`9````?ML!
M`!,```"8VP$`+````*S;`0`9````V=L!`!8```#SVP$`*@````K<`0`G````
M-=P!`"(```!=W`$`)@```(#<`0!!````I]P!``\```#IW`$`!P```/G<`0`S
M`````=T!`"0````UW0$`*````%K=`0`@````@]T!`!L```"DW0$`,P```,#=
M`0!=````]-T!`$````!2W@$`3````)/>`0`[````X-X!`#(````<WP$`0P``
M`$_?`0!J````D]\!`$D```#^WP$`,P```$C@`0`]````?.`!`#D```"ZX`$`
M5@```/3@`0!9````2^$!`$4```"EX0$`1@```.OA`0`U````,N(!`#$```!H
MX@$`+@```)KB`0`R````R>(!`'L```#\X@$`<````'CC`0!Y````Z>,!`+X`
M``!CY`$`%0```"+E`0`C````..4!`"L```!<Y0$`*P```(CE`0!'````M.4!
M`"<```#\Y0$`1@```"3F`0`G````:^8!``P```"3Y@$`I0```*#F`0`_````
M1N<!`!@```"&YP$`-@```)_G`0`<````UN<!`!T```#SYP$`+@```!'H`0`&
M````0.@!``4```!'Z`$``P```$WH`0`-````4>@!``H```!?Z`$`"````&KH
M`0`+````<^@!``4```!_Z`$`$````(7H`0`#````EN@!`&D```":Z`$`!0``
M``3I`0`0````"ND!``0````;Z0$`!P```"#I`0`(````*.D!``4````QZ0$`
M/P```#?I`0`#````=^D!`!````![Z0$`#0```(SI`0`2````FND!`!````"M
MZ0$``P```+[I`0`(````PND!``<```#+Z0$`%````-/I`0`,````Z.D!`!4`
M``#UZ0$`!@````OJ`0`0````$NH!``T````CZ@$``P```#'J`0`Q````->H!
M``0```!GZ@$`!@```&SJ`0`'````<^H!`!T```![Z@$`/0```)GJ`0`L````
MU^H!`"T````$ZP$`%P```#+K`0`F````2NL!`"D```!QZP$`*P```)OK`0`@
M````Q^L!`!D```#HZP$`(`````+L`0`;````(^P!`!8````_[`$`(````%;L
M`0`:````=^P!`!L```"2[`$`+0```*[L`0`9````W.P!`"H```#V[`$`*```
M`"'M`0`<````2NT!`"````!G[0$`'0```(CM`0`8````INT!`!\```"_[0$`
M(@```-_M`0`B`````NX!`"0````E[@$`)````$KN`0`8````;^X!`!L```"(
M[@$`)````*3N`0`6````R>X!`"````#@[@$`*P````'O`0`N````+>\!`!,`
M``!<[P$`(````'#O`0`T````D>\!`!P```#&[P$`(````./O`0`=````!/`!
M`!X````B\`$`&````$'P`0`;````6O`!`"@```!V\`$`'0```)_P`0`I````
MO?`!`!P```#G\`$`-@````3Q`0`-````._$!`!$```!)\0$`&0```%OQ`0`M
M````=?$!`"````"C\0$`#````,3Q`0`/````T?$!`!H```#A\0$`#@```/SQ
M`0`#````"_(!`!4````/\@$`!P```"7R`0`&````+?(!`"$````T\@$`)```
M`%;R`0`4````>_(!`"````"0\@$`&````+'R`0`.````RO(!`-P```#9\@$`
M%0```+;S`0`<````S/,!``<```#I\P$`"@```/'S`0`.````_/,!``\````+
M]`$`(````!OT`0`&````//0!`#D```!#]`$`&````'WT`0`.````EO0!``<`
M``"E]`$`%````*WT`0`(````PO0!`#4```#+]`$`!@````'U`0`A````"/4!
M`!4````J]0$`$P```$#U`0`3````5/4!`#D```!H]0$`%P```*+U`0`*````
MNO4!`"````#%]0$`"P```.;U`0`,````\O4!`!,```#_]0$`"@```!/V`0`<
M````'O8!``4````[]@$`(0```$'V`0`)````8_8!`!D```!M]@$`+0```(?V
M`0`'````M?8!`!\```"]]@$`!P```-WV`0`)````Y?8!``D```#O]@$`/@``
M`/GV`0`'````./<!``\```!`]P$`$0```%#W`0`.````8O<!``<```!Q]P$`
M"0```'GW`0`'````@_<!`!4```"+]P$`!@```*'W`0`5````J/<!``H```"^
M]P$`$P```,GW`0`6````W?<!``D```#T]P$`"P```/[W`0`9````"O@!``0`
M```D^`$`*````"GX`0`,````4O@!`!````!?^`$`"````'#X`0`#````>?@!
M``H```!]^`$`)@```(CX`0`+````K_@!``,```"[^`$`!P```+_X`0`(````
MQ_@!``D```#0^`$`$````-KX`0`-````Z_@!`!0```#Y^`$`%0````[Y`0`*
M````)/D!`"X````O^0$`&````%[Y`0`8````=_D!`!<```"0^0$`#````*CY
M`0`V````M?D!``8```#L^0$`%````//Y`0!$````"/H!`!(```!-^@$`#```
M`&#Z`0`'````;?H!``0```!U^@$`!````'KZ`0`-````?_H!`!0```"-^@$`
M!0```*+Z`0`&````J/H!``8```"O^@$`"@```+;Z`0`'````P?H!`!$```#)
M^@$`$0```-OZ`0`Y````[?H!`"X````G^P$`-@```%;[`0`%````C?L!`!@`
M``"3^P$`&0```*S[`0`?````QOL!`!T```#F^P$`$@````3\`0`"````%_P!
M``0````:_`$`"P```!_\`0`%````*_P!``4````Q_`$``@```#?\`0`/````
M.OP!`%0```!*_`$`.0```)_\`0`1````V?P!`"T```#K_`$`+````!G]`0!B
M````1OT!`!<```"I_0$`;````,']`0`A````+OX!`$L```!0_@$`)````)S^
M`0!*````P?X!`#D````,_P$`*P```$;_`0`O````<O\!`"\```"B_P$`,```
M`-+_`0`Q`````P`"`"X````U``(`(P```&0``@`X````B``"`#$```#!``(`
M$@```/,``@`2````!@$"`!(````9`0(`B````"P!`@`(````M0$"`+0```"^
M`0(`@P```',"`@!]````]P("`#,```!U`P(`6````*D#`@`6`````@0"`"(`
M```9!`(`%P```#P$`@`/````5`0"`!8```!D!`(`'0```'L$`@!!````F00"
M`!H```#;!`(`(````/8$`@!8````%P4"`!<```!P!0(`%````(@%`@`+````
MG04"``4```"I!0(`!@```*\%`@`(````M@4"``4```"_!0(`%0```,4%`@`4
M````VP4"`!0```#P!0(`'P````4&`@`3````)08"``X````Y!@(``P```$@&
M`@`(````3`8"``H```!5!@(`!P```&`&`@`%````:`8"`!0```!N!@(`!P``
M`(,&`@`&````BP8"`!4```"2!@(`#0```*@&`@`+````M@8"`!(```#"!@(`
M"0```-4&`@`3````WP8"``<```#S!@(`#P```/L&`@`0````"P<"``@````<
M!P(`"@```"4'`@`9````,`<"`!4```!*!P(`"````&`'`@`E````:0<"`!(`
M``"/!P(`&0```*('`@`1````O`<"``<```#.!P(`$P```-8'`@`(````Z@<"
M``,```#S!P(`%0```/<'`@`)````#0@"``(````7"`(``@```!H(`@`1````
M'0@"``T````O"`(`"0```#T(`@`3````1P@"`!0```!;"`(`!P```'`(`@`J
M````>`@"``(```"C"`(`!````*8(`@`2````JP@"`!@```"^"`(`"0```-<(
M`@`'````X0@"`!$```#I"`(`!P```/L(`@`>`````PD"``@````B"0(`%0``
M`"L)`@`-````00D"`!(```!/"0(``@```&()`@`'````90D"``H```!M"0(`
M"P```'@)`@`8````A`D"`"H```"="0(`#0```,@)`@`*````U@D"``H```#A
M"0(`!0```.P)`@`"````\@D"``L```#U"0(``0```-,$```<!```,04``%\#
M````````G`$``&T"``"@!````````)0#``#'`0``_08``'P`````````````
M`(8"```K!P``"P$```````"#!P``P0```'<%```5!```\04``"P```#;`P``
MPP8``"4'```(`@```00``+P%```$!P``,0,```````"F`@``\`4``&0"``"R
M`@``#P0``($#````````````````````````U@0``%$%``"%!```````````
M``#V`0``<`(`````````````?P(``"X$````````(P$``*0%````````9`<`
M`.0%``"1!@``)0$``'(&``#U!```;@(``'`!```U!P``P@$``-$"```O!```
M;P,``%`'``!:````H@$``#,!``"+!P```````'L!``#K````F`8``,`%``!>
M!P``2@4``,X&````````E`0``&("``#R````*0(``&8"````````VP0``(8&
M``#>!0````````````"E````````````````````F`,```````!`````Y@8`
M``````#-`0```````)T$``!(`@``OP4```````#]`@``B@<````````,!0``
M`````$\$``#,!0``[`(``"8%```7`````````#0```!8````O`$`````````
M````M0(``%H$``!E`P``:@,``%\!``"$!P``````````````````^@$``&0#
M``!O````U@$```````!_!@````````H'``"0`````````$T#``";`@``````
M`!P#``!?!@``]`$``-\````H`P``W`$``-`!``"V`P``1P,````````=!P``
M$P<``"4#``#Q````L`4``-($`````````````*L#``"D`````````,L%``!A
M`P``>0,``)4$```*!````````(P&``#``0```````.$$``!Z!P``V0,``.<!
M````````_P4``$P'``"I`0``6`0``.0!````````3P```+X!````````````
M```````O`P``;@<```````"R`````````)@%``!G!```I@8``.(!``!(!@``
M`````"H```#[`0``:`$``%8'``#:`P``*@8``*,$``!6!@``5@0``+$&````
M````G0(``%L```"4!@``BP,``*D`````````K`4``-,```"@`P``>@$``&<"
M``#"`P``*@<``'L#```K`````````#8``````````````#$"``"#````Y`0`
M``````#V!```>00``$8'````````]P``````````````DP(``+H%````````
M%P4``*H#```K`@``?`<```````!T!```.P(`````````````D`(``(X!``"*
M!```W````'X'``!7!0``F@,```,"```]!P``7@,```8!````````100`````
M```O!P``GP,``*4!`````````````&<%``!Q`0````````````!$!@``VP``
M`#\'``!*``````````("````````*0$```````!6`P```````)P$````````
MS`$``&$$```6`P```````"<$``!A```````````````E!```=P```.X#``!H
M!@```````)X&````!@``>P`````````:!@``L00```,````%!P``W04``+D&
M``#)`P``?`(``!@'``#L``````````````!C`0```````.X"``":````D@``
M`)X#````````FP$``"L%``!Q`@``\P,``$8#``"^`@``N@$``-T$``#8!@``
MM`,``.,$``#*!```J@0````````:!P``%P(``+\$```8`0``L0(`````````
M````X@,``(\"````````?@$``/X%``!I`0``&`8``/@!```J`P``2P,``'(#
M``!'!```E@$``$<```#(`0``<0,``%`&```Z````8@8``%,```#7!@``=@(`
M```````N!0``)@(``'4&``#M````#`8```0```#D`@``?@,``(,%``")`0``
MDP0``/X"``!F!P``YP4``!<!````````GP$```\'``![`@``?@````4$```+
M!P``+P8``#8&````````4@(``+\`````````=P,``/\#````````"P```#,%
M`````````````&@'```I!@``W0````````#T`@``00<```````#8`P``V@0`
M````````````:`````T"``!T!@```````-4&``#'!@``<0```*````#^!@``
M0@(```````";!```N0,``,`````$!```$`8``$P!``"4`@``N04``*`!``#!
M`0````````4`````````3@<``-8"``!C`````````,0`````````````````
M``#R!````````$`%``!Q!P```````,\&````````%P,``(,&````````````
M`%(%`````````````/,$``!W!```I08``&\$```(````7@```$H'``"Z`P``
M=@4``-X```"$`P``)`0``#L%``#Y!@``G`,``'<"````````:@$``#X"``#`
M!@``[@4``+X$````````<08```````")````I0(````````U!@```````!X'
M````````50$``"($```X`0```````&T$````````AP(``'D%``"`!0``U@``
M```````A`@``408``#<$```S`@````````````"7`P``_P0```('```'`P``
M:P8```````#Q`0``Q@```/`#``"/````70<`````````````Z08``(4#````
M`````````-T"```N`P``5P$``/8&````````Y0$``/X```!-````S00``!`%
M````````-@$``)`#``!]`0``EP```%D$``!_!```<P```*<%``!8`@``@@(`
M``````!#!@``=@$``/X!````````YP0````````D`````````/@$``!K!```
MQ@0``%D!```A!```!@```)\"``!>`@`````````````$!@``E`4```````#C
M!@``C@,``#X````K`0``%`(``-<#``"3!@``0@<```````!L`P```````(X$
M``"C`````````,4#``!1````O0(``"P$```@!```Z00````````N!@``]@(`
M`#`&``!8!0``````````````````J0(``"0#`````````````+,!````````
M?0```"<#````````=`<```````"1!````````,X!``#R!@``"`$`````````
M```````````!``!,!0``.@8```````#)!0``$0$``%\$``#Z`P``G````+`#
M``#$`0```````'4$``!Q!```UP(``,H%``!\`0``C`$`````````````````
M`/T%```U!````````$`'``"G!@``T`,``*H&``#M`0``I@````````#O`@``
M````````````````K00``.L!``#Y!```WP,``"@$````````9@0``)\````1
M!@``N00``.H#````````R00``%L"``",!````````,0"``"^!0``0@4``'8'
M``#6!0``E08```````!E!P`````````````;!````````/0#``!4````V0``
M``````!(````E@````````!6`@``-P```"$&```\`@``<P(```````#S`@``
M``````@$``"W`@``I00``'D'````````W`8``!4`````````V00```````#\
M`````````!\%``"+!0``]P$``/<%``!\`P``V@8``+0%``"5!0```P4`````
M``````````````````"#!```OP(``,X"```.!P``F0,``/\"````````]`0`
M`#\"``!3`0```````,4$```R`0```````,L"``",``````````````!+`0``
M``````````"\!@``"0$``-X!```F!```I`,``,T%``!S`0``,P0``!(&``"+
M!```8@`````````O````H@8``#@"``!9`@``@0<``$D'``"-!0``&0``````
M``"M````[P,``-,&``!\!0``,@```+T%``#*`@```````/@&``"X!@``6P4`
M`$0!`````````````!T"```@!P``W08````````.!0```````&`!```Y`@``
M0P(``+L!``"``P```````"H!``!&````T`(``!4&````````?P```$(#```W
M!P``+0$``#$$``#A`0```````-(%``"T`@``Z`$``%0#``#X`P``?00`````
M``"B`P``U`(``&(#``#K!0````````````!?````'P(``#(#``#\`@``````
M`',$````````@@8``#<%```Z!0``&`0```````!V````HP,```````"7!0``
M8@4``!("``!L`0``(@$```````".`````````&H%````````Q04``!H!``#@
M`0```````),#``"8`````````(4%```8`````````"P%``"&!````````!P`
M``";!@``:@8``/L"``"%`0```````$P#``!J!P``>@0``!`$``!E````5`4`
M`,8&``!T`@``X```````````````MP,``'4#````````````````````````
M`````%P!````````.@<``'X"``!L``````````````"(`@```````-`&```+
M`@``#P4``&T!```M`@``X`4``.<"``!/`P``#0$``&````!G`````````,$&
M``#9`@``NP8``````````````````.H```"R!```*``````````Q!P``````
M`/,```"J!0``_0$``-4$```:````````````````````8@0```````#*!@``
M808``$X`````````$P(`````````````2@0``!<&```C````/P```((%``"H
M!```N`(``)$%``#D````0@0```````"X!0``004``!\!``"X`0```````)L%
M````````M0````,'```M!P````````````"P!````````&L'``![!0``9@``
M`````````````````,X$```'`0``608`````````````X08``&('```[`0``
M.P0``'4"``#M!@``.00``"$'``#_!@``<P8```P!````````208``)\&``"\
M!```9P8```D%``!'!P``````````````````<P,``(L```![!P``T@,```$"
M``"C`0``+`,```````"S!````````"8'```!`P``ZP(``'````!O!@``V```
M`!,&``!%`P``7P<``/,%``#J!@``T00``#\#````````^P4``&<'``"A!@``
MT@(```````!K`0``T0```(L&```P````R`(``*$$``#L`0``X@```&H"``"F
M`0``7`(````````X`P```````%T&```K!```8`,``.$%````````SP```)8%
M``#9!@``10(`````````````E0$`````````````"`8``$8%````!P``````
M`$D#``!L!0``50<``-,!``"``0````````````````````````````#]!```
M;`0```8$```^`P``'P0``-\$````````7`,``'X$```1`@``+08``,L$```;
M`P```````(`&``!U````!0,``)$!````````K``````````$`@``>0$``"D$
M```V!P```````'H```!T``````````````!B`0``5`$```T````_`0``W@,`
M`+8&```Y!P`````````````F````````````````````B`4``(\$````````
M1@0```$&````````LP```%`!``"2!@``L@$``!8"``!0`@``AP,``'`'``#U
M`@``M@```/0&``#Q`P``40$``.($``#O!````````-$&````````+P(`````
M```-!P``4`````````!4`@```````$T&``"!`@```````!T&````````]08`
M`(T&``"[````7@8```````#Y`0``A````$<&````````=0$`````````````
M1`(``$@!```5`P```````"0!``!9`P``]0```)H%``!3!0``W@8``#D!```;
M!P```````(@!``!<!0``5P0``$,'``":`@``/0,``!$#``"N!0``20$`````
M``"?!````````#X!``!J````?@4``*<#``"I!@``(`````````"N````2P``
M`!(```"F!````0$``'H&````````U0$``+H```#D`P``M@$`````````````
M:`0`````````````O@```+D```!R!````````!$```!?!0``Y@0``"`#``"K
M`0``Y@```"("``"@!@``O0$``/(!```[!@``A`8```````"!````$@0``+L"
M```]!```?P$``!L```"S`@```````+T#``!U!0``90(``(4`````````S0(`
M`,4&``!_!0```````%<"``"?!0``\`$``*T#````````B@4``'(!``"Q````
M@00```````#Q!@```````!('``!O`@```````.T#````````$`(``!0!```M
M`P``1`0```````#5`P``WP(```````!]!@``204```````#;!0``AP0`````
M``"S!@``]P(``*\$```%`@```````"$```#\!0``=P$``#P#```+!@``]`4`
M`/`"``!Q!0``N`,```````#4`P``Z`(``%H&````````>P0``$$#````````
M*@(``)P%``#&!0``V@4``&$%``````````````$'``!Z!0``1P(``#P```"\
M```````````````/`P`````````````1!P``.`8``!0$`````````````&$"
M```)!P``,P,```````!``0``/04```````"<!@````````````"'`0``R0``
M`.D#``#E!@``O0```(L!``"]!````````#8#```U`@``'04```````"(!@``
MK@0```<"``#K!```OP,``````````````````$D$``!2!@``M00``',%``#$
M`P```````&L#``#:`0``L`$```````"3!0```````,L&``"B!0````````D#
M``!]`P``$P````T$``#%`0``"P0```````!!`@``50```.,%````````K`,`
M``,#```9!```!P8`````````````Z@0``.P%```*`P``J`4``+<$```6````
M5`0``#<!``!5!0``I`(``/D"````````@`(``",%``#[`P``0P$``&H$````
M`````````#\%```3`0```````/(#``#'!```OP8```````!(`P```````,T#
M``!=!0``?`0``#X&``#Y````'@4``$8!````````JP```%8!``#H!```C0``
M``````#.`P``.08`````````````RP```(<```#=`P````````````#,!```
M`````%,'````````&04```````#G`P``,0```,P#``")!0``$`$```X```!L
M!P``IP```,\$``!C!P``&08``-H````A`0``H@(``)@"``!>!```+00``"0'
M``!E`0``>`(``!4'```=!```V04``)P"``!=`````````.`$``!F!0``0`8`
M`.8"````````L@4````````$`P``'@0```````````````````0%````````
MDP$``(<&``!T`P``KP,``/L&````````D@0``(4"```?!@```````-P#````
M````6P$``%P'```4`P``\0(``#0'``!T!0``J`,``%T!```L!@``````````
M````````L`8``.`#``!.`P``_`0``#L'``!X!````````"\%``!I!@``U```
M`*`"``#Y`P```````"@%``"'!P``[04``'("````````*0`````````&`@``
M``````P'``#E!````````%,&`````````````"@'```"!@```````$8"````
M``````````````#7`0``S0```#<#```$`0```````"P'``!S!P``9`8`````
M``"!!0``;@$``*\"``#$!```+@(``%4$``````````````````"$!0``$P0`
M`)$"``!8!@``T@```*X#``!*!@``.`<``'T'````````T`0``!L%````````
MN@0`````````````@@$`````````````(P(``%H!````````'`<``#,'```@
M`@``J`(``"<'````````.@0``(D"``!K````\P8``#D%```\`0``$04`````
M``#E!0``B@```!P!``"K!```B0,```8%````````(@4``%T"````````Z@$`
M``````#Z!````````-\!``!'!0```````!0&``"(````Z0(``#0$``#E`P``
MJP4``,X%``#'`P```````#\$``````````````````#J`@``H0,``/X#```8
M!0``,P```/8%``!X!P```````'`&````````RP,``&\!```>`P``604`````
M``"&````@P$```````"T````CP,``(0$```P!```MP$``)D"``"@!0``M@(`
M`.4"````````,@0``*$````L`@``R`,```L#````````C`4````````<!@``
MK`0``````````````````&L%````````V`$````````.!```"08````````E
M````X0,``)X``````````````'(%```@!@```````!4!```^!0``'0```,P"
M``">!0``B@8``(X"```A!0``E@(```````!!!@``0@8``*$!``"A!0``)P(`
M````````````+0```$L'``"5`@``4@0`````````````-`(``/@%``!T`0``
M70,``#4!````````3@0``%8%``"B!```"0```,,%``"#`P```````%@!``!I
M`@``[`,``!D"````````P@(``%L'``!#`P``/`0``)`!``#F`0``XP,``%$$
M`````````````*P"```.`@``'`(``$X!``!(!```"@````````!.!@``_`$`
M`"X```"-`0```````"X'``#M`@``Z0$``,\!``!L`@````````````#:`@``
MPP(``"<```"S`P``D@4```````!N````$`````````"-!```&P$``'`$``!W
M!P````,``-\%``!4!P``L@,```@'``"-`P```````(T"``!G`0``@@,``+\!
M``!X!@``;@0``*H```!.`@``9`4```````",`P``,`<``(($````````O`,`
M`#X$```8`@```````#<"``"2`P``@@`````$```````````````````/`@``
M%0(``,(```"[`P```````-(&```P!0``[@```,$%````````2`4``!0'``!:
M!P```@0``%X!`````````````-D!``!+!@``\00``&X&```X!0``/`<``)H!
M``#A````O`(``+X#```6!`````````````"9!0``Z@4``/4#````````1`<`
M`!D#``#L!```E0,```(#```*!@``CP8```````!M!@``80<``"X!```G!@``
M`````&8&``!I`P```````&`&``"U`P``"@(``$D"```?````#08``&0!````
M`````````$\"`````````````*8%```R!@``L0$```X&``#2`0``-04``(8!
M``!<`````````#P&``#F`P``&@4``+L$``"M`@```````(````!Z`P``B08`
M`,@%``"%!@``W0$``#4#``#O`0`````````````,````E@,``&,"``">`@``
M\@4``````````````````&0$`````````````.D```"V!0``HP8````````>
M`0``P0,``#T&``!P!0``A`$``&L"````````300``.@&````````R`8``(\!
M````````PP```!\'````````8P0``'4'````````#04``#T!``!1!P``;0,`
M`",&``!$````%P<`````````````V`(``$D````[`P``%P0```````#O````
M;`8````````*!0``4P,```<%```D!0``MP8``*D$```'!```1P$``$4&````
M```````````````@!0```````+````"O````,08``/`&``#C`````````"0&
M```2`P``P00``-L&`````````````'\#```,!```&`,``*P!````````N0$`
M`.0&``#.`````````)(!``"`!P``Q0(```(%````````-`$```````"H````
M+`$```X#````````D`0``!D!``"B````4`4```````#K!@``U0(`````````
M``````````D$``"9`0``FP,``*H!```,`@``U04``/4%``#U`0``#0,`````
M``"=`0``Q0````````#&`@``5P```#@````H`@````````````#]`P``IP0`
M`+L%````````P@4```````!/`0``'0$``.X&``#Z!@``E@0``%`$````````
MK0$`````````````I`$``*D%``"P`@``908```````#6`P``%@4``*8#````
M````&@(````%````````B`<``(('``#1!0``XP$``*X&``#C`@``P@8``*L"
M``!P`P``D`4``*\!````````TP4``*0&````````M04```````#/!0``;04`
M``````#X`@```````-\&`````````````!\#``!_!P``M`0``*@&````````
MQ`4``*<!``!#````G0,``!L"````````3`0````````"`0``EP(``$\%``!`
M`P``>P8``-P"````````2`<``&,%``"!!@``1`,``.4```!-!0``Q`8`````
M``````````````````#0````6P,``+<```!Y`@``0P4```````!4!@``UP4`
M`$H"```]````+04```````!\!@``X`(``&`$```:`P``````````````````
MPP0```````#3`P``X@(``'@#``"4````B0<``!H$````````````````````
M````000``!L&`````````````%('````````*0,``/T```!7`P``````````
M```C!P``40,``#H"``"3````\P$``%4"``````````````\&````````F00`
M``````!"`0``7P(``$L$``!-!P``;@4``+$#````````A`(``$\&````````
M)@$```````#;`0```````+$%``!R!P``W`0``&D%``"U!@``)P4``#X'``!%
M!P``2@,``&D$``#/`P```````&@"``"O!0``@`0``'8#``#1`P``4`,``)@!
M``#A`@``3`(``,($````````B`0``&T'``!R````````````````````^@(`
M```````R!0``:`,```<'```C`P``?@8```````#H`P``EP0``+4!``#,!@``
MSP(``"@!``"7`0``RP$```````!8!P``4P(``%H#``"&!0```````#`"``#X
M````F0````````#,````K@(``#0%````````UP````````"E!0``````````
M````````)@8``)H&``#N`0``(0,``#L```"9!@``00$``,8#``",`@``!@<`
M`!4%``!E!0``````````````````(@,``(H"```>````A0<``%<'``"M!0``
M10```'<&```X!```PP$``-0!``!"````900``"D'``!O!0``]P8``%8````.
M`0``^@4``$T"``#^!```6@(``*,%```&!@``Z04``"(```!%!0```````$P&
M``"8!```G08``,$"```#!`````````````"^!@``;@,``!8&``#O!@``````
M`'T%``#H````-`,``%H%```2!0``#P$``!X"````````:`4````````O`0``
M/0(``$T!```P`0``)0(``-4`````````)04``&8#``#V````>@(``)`&````
M`````````*,"````````K@$``/P#``!A`0``N````)$`````````````````
M``"5````)@,```\``````````````(H#````````?0(``,<%``#&`0``````
M`(8#```B!P``G@$```````#;`@``R0$```H!``!5`P``>0```-0$``##`P``
M`````,H!```3`P``````````````````;P<``/`$``!V!```"`,````````_
M!@``V`0```````"A`@``;0```(\%```9!P```````%D'```J!````@```&`"
M```<!0```````/D%``!.!0```````,@````,`P``BP(```````"E`P``"`4`
M```````Y`P``_P$``!`'``!=!```"0(```````!,````F@0``-$!```I!0``
MZ`4```````!X`````````&8!``#P````[P4``$L"``"W!0``!04```````!2
M````ZP,``$L%``#6!@``.0```,@$``"=!0``P`(``&`'```#`0``>08``$0%
M``#@!@`````````````'````-@4``"L#``#Z````R08``!8'```#!@``R@``
M`'@!```2`0``]P,``.8%``"L!@``4P0``%(!````````!@,``+D"``!/!P``
M%````)$#``"J`@``7`0``-<$```Z`P``,`,``/0```!`!````````-X"``"R
M!@````````4&``#<!0``8P8``,`#``#*`P``[00``%L$``"4`0``B`,``&D'
M``"&!P`````````````3!0``C@8``*0$```R!P``B@$``$,$``";````(@8`
M`/("``!V!@````````````"V!````````!`#``#L!@``8`4```````#[!```
ME@8``.(%```K!@````````````#W!````````+H"````````M`$``$8&````
M````KP8``%<&```\!0```````$$````V!````````#("`````````04`````
M``".!0``'0,``*<"`````````````%(#```H!@``U`4``/P&````````J`$`
M`&,#```1!`````````````!5!@``)P$``+,%````````YP8``-,"````````
MAP4``(,"``"Z!@``6`,``($!````````[@0``"0"``#4!@```````#4```"]
M!@``R0(``*D#``!9`````````#$!````````X@8``+0&```+!0``10$``%P&
M``"X!```-P8```````!;!@```````&0````E!@``QP(```````"=````_P``
M``4!``!``@``B00``&D```#8!0``(`$``)X$````````D@(``!0%````````
M.@$``-`%````````%@$```````!X!0``QP```,T&`````````````%X%```C
M!```]@,``"H%``#G````P`0``*L&```>!@``2@$``#,&`````@``9P,``-X$
M```V`@````````````#[````K08``)<&``!1`@```````#0&````("@E<R!D
M87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A
M>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@
M82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S
M(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD
M("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD
M87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3
M971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU
M=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO
M;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E
M<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U
M<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-
M($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3
M;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B
M;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U
M<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U
M<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S
M(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S
M97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S
M<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I
M;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO
M;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N
M`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'
M<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!
M;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M
M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S
M`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R
M960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!
M;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P
M<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`
M07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE
M`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E
M;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`
M07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO
M;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L
M:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA
M=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E
M<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE
M;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z
M`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N
M9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U
M<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI
M>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O
M9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`
M0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D
M97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`
M0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M
M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`
M0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T
M:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E
M>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A
M;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE
M("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#
M86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I
M97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@
M4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL
M('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT
M97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@
M3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E
M(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL
M90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4
M<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@
M82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L
M96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R
M('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L
M:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@
M16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E
M(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L
M;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE
M<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N
M($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N
M9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E
M("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C
M=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT
M:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S
M`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O
M:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E
M9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O
M<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@
M)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E
M<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B
M)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S
M97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B
M)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD
M97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R
M;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`
M0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R
M<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL
M90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U
M=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$
M871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@
M0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E
M;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F
M875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L
M971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE
M<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E
M;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@
M9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@
M8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B
M+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F
M;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T
M`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B
M;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@
M0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S
M:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'
M871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM
M86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L
M971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA
M`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG
M`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP
M:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@
M<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE
M9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O
M(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S
M*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A
M<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N
M;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T
M(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N
M80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D
M96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E
M`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!
M9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E
M;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S
M`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T
M;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S
M:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O
M<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O
M2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S
M<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S
M(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%
M($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5
M;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@
M<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M
M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)
M8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I
M='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS
M<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%52
M3`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A
M;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM
M<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W
M($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!)
M;F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S
M:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS
M97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O
M<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T
M97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS
M97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A
M9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O
M=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D
M(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I
M9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC
M:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI
M9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A
M;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@
M;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N
M97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L
M+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C
M=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T
M82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@
M5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*
M86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO
M<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y
M($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+
M965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@
M875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+
M97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+
M:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W
M86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#
M:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@
M)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,
M871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE
M8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE
M=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T
M96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY
M`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN
M('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI
M;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN
M:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E
M<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S
M`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H
M=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE
M`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N
M`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W
M97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O
M;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA
M9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA
M>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T
M(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G
M:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES
M;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-
M875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R
M<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I
M9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T
M92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S
M<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I
M<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E
M9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-
M971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`
M36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN
M('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N
M`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@
M<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@
M1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`
M36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E
M<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D
M('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-
M;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3
M=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-
M;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N
M`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`
M37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.
M86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!2
M96YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO
M<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.
M97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG
M97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H
M('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T
M:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@
M<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF
M:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T
M82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S
M`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL
M90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N
M`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!8
M34P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I
M;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM
M<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.
M;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.
M;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO
M="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU
M;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/
M8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY
M('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E
M(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/
M<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@
M97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T
M:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T
M:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A
M8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO
M=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R
M;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D
M:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY
M($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL
M>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG
M;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E
M<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL
M:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D
M97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E
M+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S
M>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L
M86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R
M:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S
M86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET
M*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!2
M86EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@
M1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E
M9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@
M4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A
M9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E
M;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M
M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D
M;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@
M=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T
M($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L
M97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E
M<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`
M4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O
M=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS
M(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N
M`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H
M:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`
M4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F
M<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R
M:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3
M879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E
M<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E
M;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D
M9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A
M('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O
M;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A
M;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E
M<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L
M92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS
M`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES
M<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`
M4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W
M97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T
M=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E
M`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W
M97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W
M(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)
M<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C
M=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD
M(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A
M9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI
M="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK
M80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V
M:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R
M:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@
M861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@
M9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D
M9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL
M('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S
M<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F
M=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`
M4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T
M`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M
M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R
M(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M
M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%13
M5B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE
M('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`
M5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E
M=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z
M(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^
M*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U
M;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R
M>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A
M=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO
M9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O
M='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K
M(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R
M87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO
M;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N
M('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T
M;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@
M;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA
M>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@
M9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES
M(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`
M5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S
M92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R
M86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O
M97,@;F]T(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES
M="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE
M('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD
M(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A
M=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N
M("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S
M>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F
M;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R
M;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C
M="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@
M9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C
M:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A
M8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE
M87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z
M+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--
M5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T
M;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O
M=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I
M96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E
M96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA
M8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@
M8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET
M=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O
M=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E
M<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI
M<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`
M5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO
M<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L
M92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O
M(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N
M`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A
M;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R
M:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD
M97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ
M("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN
M`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE
M9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER
M871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`
M56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP
M="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E
M='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`
M57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5
M<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@
M24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F
M;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@
M4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E
M<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z
M`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI
M;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N
M9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A
M='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S
M:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P
M861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S
M92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`
M5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L
M86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)
M=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-
M04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U
M;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P
M<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E
M;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M
M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI
M8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H
M(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@
M;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7
M:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T
M<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE
M("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F
M:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D
M('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S
M(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M
M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R
M97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H
M96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@
M0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I
M;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG
M960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO
M=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S
M<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S
M;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E
M9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`
M6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=
M`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?
M1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO
M9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5
M<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`
M8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN
M<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I
M9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D
M871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG
M`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH
M`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T
M<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N
M;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E
M<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I
M9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M
M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R
M('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,2XQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTQ
M,2`Q,CHS.2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,3$@,38Z
M-3(K,#$P,`I,87-T+51R86YS;&%T;W(Z($)R:6%N(%1R=65L<V5N(#QH;W)D
M92MI,3AN0&)R:6%N=')U96QS96XN9&L^"DQA;F=U86=E+51E86TZ($1A;FES
M:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O<FUS.B!N
M<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@,2D["@`@*"5S(&1A9V4@<VED96XI
M`"`H06-C97-S:V5Y("5S*0`@*&]M("5S(&1A9V4I`"`H:2!D86<I`"`H:2!M
M;W)G96XI`"`H:2!GY7(I`"!M960@`"(E<R(@97(@:6MK92!E="!K871A;&]G
M+@`B)7,B(&5R(&EN=&5T(&=Y;&1I9W0@=F%L9RX`(B5S(B!E<B!I:VME(&MO
M;F9I9W5R97)E="!I($AO<F1E<R!F;W)T96=N96QS92X`(B5S(B!T<N8M;W!B
M>6=G97(@:6MK92!F=6YD970N`"(E<R(@8FQE=B!T:6QF^&IE="!I(&=R=7!P
M92US>7-T96UE="X`(B5S(B!B;&5V('1I;&;X:F5T('1I;&QA9&5L<V5S+7-Y
M<W1E;65T+@`B)7,B(&)L978@:6MK92!D86YN970Z("5S+@`E+C)F34(@8G)U
M9W0@=60@868@)2XR9DU"('1I;&QA9'0@*"4N,F8E)2D`)60@)7,@;V<@)7,`
M)60@9&%G92!T:6P@9&ET(&MO9&5O<F0@=61L^&)E<BX`)60M9&%G<R!U9'-I
M9W0`)7,@+2!.;W1I=',`)7,@9FEN9V5R869T<GEK`"5S($M"`"5S(%9E9&QI
M9V5H;VQD96QS92`M($)E:W+F9G1E;'-E`"5S(&]P<^9T;FEN9P`E<R!O<'-K
M<FEV;FEN9P`E<R!B<G5G<V)E=&EN9V5L<V5R`"5S(&5K<VES=&5R97(@86QL
M97)E9&4N`"5S('9E9"`E<R`E<P`E<R!E<B!P87)A="!T:6P@870@=61F^')E
M(&1E('9E9&QI9V5H;VQD96QS97-H86YD;&EN9V5R+"!S;VT@97(@;6%R:V5R
M970@;F5D96YF;W(N("!3YG0@:&%K('5D(&9O<B!D92!H86YD;&EN9V5R+"!S
M;VT@9'4@^&YS:V5R('5D9OAR="!N=2X`)7,@:W+F=F5T`"5S(&UI;G5T=&5R
M`"5S(&EK:V4@9G5N9&5T+@`E<R!T:6P@)7,@868@)7,`)7-S(&%D<F5S<V5K
M87)T;W1E:P`E<W,@:V%L96YD97(`)7-S(&YO=&5S8FQO:P`E<W,@;W!G879E
M<@`E<SH@)7,`)7,Z($1E;FYE(&)E<VME9"!E<B!M=6QI9W9I<R!I:VME(&9R
M82!D96X@<&5R<V]N+"!S;VT@9&5N(&CF=F1E<B!A="!VYG)E(&9R82X@(%;F
M<B!V87)S;VT@;65D(&%T(&;X;&=E(&AE;G9I<VYI;F=E<B!E;&QE<B!F;W)S
M>6YE(&%F<V5N9&5R96X@;65D('!E<G-O;FQI9V4@:6YF;W)M871I;VYE<BX`
M+"!D:7-E="``+"!B;.9S96YD92`E<R`E<P`L('-K<FEF=&5N9&4@9G)A("5S
M('1I;"`E<P`M+2!VYFQG("TM`#$R+71I;65R<R!F;W)M870`,C0M=&EM97)S
M(&9O<FUA=``R-"!T:6UE<@`\1F]R96?E96YD92!D86<`16X@9&%T86)A<V4M
M8F%C:V5N9"!E<B!K<N9V970@9F]R(&1E;FYE(&)L;VLN`$1E<B!E<B!O<'-T
MY65T(&5N(&=R879E<F5N9&4@9F5J;`!%;B!O9F9E;G1L:6<@4$=0+6[X9VQE
M(&5R(&MRYG9E="!F;W(@870@:W)Y<'1E<F4@96X@8F5S:V5D+@!%;B!O9F9E
M;G1L:6<@4$=0+6[X9VQE(&5R(&MRYG9E="!F;W(@870@=F5R:69I8V5R92!E
M;B!S:6=N97)E="!B97-K960N`$5N(&]F9F5N=&QI9R!01U`M;OAG;&4L('!R
M:79A="!01U`M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T(&9O<B!A="!D
M96MR>7!T97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG(%!'4"UN^&=L92P@
M<')I=F%T(%!'4"UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970L(&9O<B!A
M="!S:6=N97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG(%,O34E-12UN^&=L
M92P@<')I=F%T(%,O34E-12UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970L
M(&9O<B!A="!D96MR>7!T97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG(%,O
M34E-12UN^&=L92P@<&5R<V]N;&EG(%,O34E-12UN^&=L92!O9R!L^'-E;B!E
M<B!K<N9V970@9F]R(&%T('-I9VYE<F4@96X@8F5S:V5D+@!%;B!O9F9E;G1L
M:6<@4R]-24U%+6[X9VQE(&5R(&MRYG9E="!F;W(@870@:W)Y<'1E<F4@96X@
M8F5S:V5D+@!&;W)M:61D86<@4VMY970`1F]R;6ED9&%G($QE="!296=N`$9O
M<FUI9&1A9R!296=N`$9O<FUI9&1A9R!">6=E<@!&;W)M:61D86<@4VYE8GEG
M97(`04TO4$T`05!)($E$`$]M(&1E;FYE('-K<FEB96YT`$]M+BXN`$%B<V)O
M='1O;0!!8G-M:61D;&4`061G86YG(&[F9W1E="!V960@9&%N;F5L<V4@868@
M5D93+6MA=&%L;V<N`$%D9V%N9R!NYF=T970@=F5D(&1A;FYE;'-E(&%F(%9&
M4RUF:6PN`$MO;G1O+6EN9F]R;6%T:6]N`$MO;G1O96YS(&MO9&5O<F0`2V]N
M=&\@:6YD969R;W-S970N`$MO;G1E<FEN9RX`5&EL9OAJ`%1I;&;X:B!U;F1E
M<F=R=7!P90!4:6QF^&H@=6YD97)O<F1N961E('1I;&QA9&5L<V4`5&EL9OAJ
M(&AE<CH`5&EL9OAJ(&YY(&=R=7!P90!4:6QF^&H@;GD@<F5T=&EG:&5D`%1I
M;&;X:B!U;F1E<F=R=7!P92!T:6P@(B5S(@!4:6QF^&H@96X@=6YD97)R971T
M:6=H960@=&EL("(E<R(`3W!R971T92!E;B!N>2!B<G5G97(Z`%1I;&;X:B!K
M;VQO;FYE`%1I;&;X:B!N>64@;65D;&5M;65R`$]P<F5T('!A<@!4:6QF^&H@
M)7,M;65N=65N('-O;2!E;B!-;WII;&QA(%-I9&5B87(`5&EL9OAJ('1I;"!A
M9')E<W-E:V%R=&]T96LZ`%1I;&;X:B!T:6P@;6ET(&%D<F5S<V5K87)T;W1E
M:P!/<')E="!B<G5G97(`2&%R('1I;&;X:F5T("(E<R(@=&EL('-Y<W1E;65T
M+"!M96X@:W5N;F4@:6MK92!T:6QF^&IE(&5K<W1R82!O<'-K<FEV;FEN9W-I
M;F9O<FUA=&EO;CH@)7,N`%1I;&;X:F5T("(E<R(@=&EL('-Y<W1E;65T+B!$
M=2!K86X@;&]G9V4@:6YD(&YU+@!/<')E='1E;'-E(&%F(&)R=6=E<F4@97(@
M<VSE970@9G)A`$%D<F5S<V4`061R97-S96MA<G1O=&5K`$%D;6EN:7-T<NER
M("T@:6YD<W1I;"!T:6QL861E;'-E<B!F;W(@86YD<F4@8G)U9V5R90!!9&UI
M;FES=')A=&EO;@!296ML86UE<@!!9F=H86YI<W1A;@!!;&)A;FEE;@!!;&=E
M<FEE=`!+86QD96YA=FX`3W!S=&EL;&EN9P!*=7-T97)I;F<Z`$%L;&4`06QL
M92#F9W1E9&4@8G)U9V5R90!!;&QE(&=R=7!P97(`06QL92!T:6QL861E;'-E
M<@!!;&QE(&9I<F4@<VED97(`5&EL;&%D(&UU;'1I<&QE(&%D<F5S<V5R`%1I
M;&QA9"!A;F=I=F5L<V4@868@;W)D;F5T(&QI<W1E='EP93\`16MS:7-T97)E
M<B!A;&QE<F5D90!!;'1E<FYA=&EV($E-4U`M;&]G:6X`06QT97)N871I=B!)
M35-0+6MO9&5O<F0`06QT97)N871I=B!)35-0+6)R=6=E<FYA=FX`1&EN(&4M
M;6%I;"UA9')E<W-E`$%L=&5R;F%T:79E('-K86)E;&]N97(`06QT97)N871I
M=B!T96MS=#H`06UE<FEK86YS:R!386UO80!$96X@=N9R9&DL(&1E<B!B;&5V
M(&%N9VEV970L('9A<B!I:VME(&=Y;&1I9RX`1&5R(&5R(&]P<W3E970@96X@
M=6ME;F1T(&9E:FPN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6ES
M97)E;F1E('!R;WAY`$)E<W9A<@!3>61P;VQE;@!!;G1I9W5A(&%N9"!"87)B
M=61A`$%P<&QI:V%T:6]N`$%P<&QI:V%T:6]N<VQI<W1E`$%P<&QI:V%T:6]N
M(&5R('!A<F%T+@!0Y6;X<B!U;F1E<F1E;&EN9V5R`$=O9&ME;F0`0VER:V%S
M=/AR<F5L<V4`07!R:6P`07)A8FES:R`H5VEN9&]W<RTQ,C4V*0!!<FMI=BUF
M:6QS=/AR<F5L<V4`07)K:79N879N`$5R(&1U('-I:VME<B!PY2P@870@9'4@
M=FEL('-L971T92!O<'-K<FEV;FEN9W-A;FUO9&YI;F=E;B!F;W(@)7,@/P!%
M<B!D=2!S:6MK97(L(&%T(&1U(/AN<VME<B!A="!S;&5T=&4@(B5S(B!O9R!E
M;FAV97(@=6YD97)G<G5P<&4_`$%R9V5N=&EN80!!<FUE;FEE;@!!<FUE;G-K
M("A!4DU30TE)+3@I`$MU;G-T`$%R=6)A`$%S8V5N<VEO;OAE;@!!4T-)22!!
M<G0`07-I871I<VLO<W1I;&QE:&%V<W)E9VEO;@!3</AR9R!E9G1E<B!B96MR
MYF9T96QS92!F^'(@=61F^')E;'-E(&%F('9E9&QI9V5H;VQD96QS97-H86YD
M;&EN9V5R/P!4:6QD96P@:V]L;VYN97(`1F]R<_AG('#E(&%T('-L971T92!E
M;B!I:VME+65K<VES=&5R96YD92!G<G5P<&4N`$9O<G/X9R!PY2!A="!S;&5T
M=&4@96X@:6MK92UE:W-I<W1E<F5N9&4@=&EL;&%D96QS92X`1F]R<_AG('#E
M(&%T(.9N9')E(&5N(&EK:V4M96MS:7-T97)E;F1E('1I;&QA9&5L<V4N`$9O
M<G/X9R!PY2!A="#F;F1R92!E;B!I:VME+65K<VES=&5R96YD92!D96QI;F<N
M`$%T=')I8G5T=&5R`$%U9W5S=`!!=7-T<F%L:65N`-AS=')I9P!!=71H7V-Y
M<G-Q;#H@2W+F=F5T($E-05`M=61V:61D96QS92!I:VME(&9U;F1E="X`075T
M:%]C>7)U<SH@0F%C:V5N9"!H87(@:6MK92!D92!N^&1V96YD:6=E(&5V;F5R
M+@!!=71H7V-Y<G5S.B!+<N9V970@24U!4"UU9'9I9&1E;'-E(&EK:V4@9G5N
M9&5T+@!!=71H7V9T<#H@2W+F=F5T($944"UU9'9I9&1E;'-E(&EK:V4@9G5N
M9&5T+B!/=F5R<^9T(%!(4"!M960@+2UE;F%B;&4M9G1P+69L86=E="X`075T
M:%]I;6%P.B!+<N9V970@24U!4"UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+@!!
M=71H7VMR8C4Z($MRYG9E="!+4D(U+75D=FED9&5L<V4@:6MK92!F=6YD970N
M`$%U=&A?;&1A<#H@5&EL9OAJ96QS92!B<G5G97)E(&5R(&EK:V4@=6YD97)S
M=/AT=&5T(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4VQE=&YI
M;F<@868@8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E="!V960@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z($MRYG9E="!,1$%0+75D=FED9&5L<V4@
M:6MK92!F=6YD970N`$%U=&A?;&1A<#H@2W5N;F4@:6MK92!T:6QF^&IE(&)R
M=6=E<B`E<RX@4V5R=F5R96X@<V%G9&4Z(`!!=71H7VQD87`Z($MA;B!I:VME
M('-L971T92!B<G5G97(@)7,`075T:%]L9&%P.B!+86X@:6MK92!O<&1A=&5R
M92!B<G5G97(@)7,`075T:%]L9&%P.B!/<&1A=&5R:6YG(&%F(&)R=6=E<F4@
M97(@:6MK92!U;F1E<G-T^'1T970@=F5D($%C=&EV92!$:7)E8W1O<GDN`$%U
M=&A?;6-A;#H@2W+F=F5T($U#04PM=61V:61D96QS92!I:VME(&9U;F1E="X`
M075T:%]S;6)A=71H.B!+<N9V970@4TU"05542"UU9'9I9&1E;'-E(&EK:V4@
M9G5N9&5T+@#&9W1N:6YG('9E9"!)34%0+7-E<G9E<B!F96IL961E+@#&9W1N
M:6YG(&9E:FQE9&4`QF=T;FEN9R!F96IL961E+B`E<P#&9W1N:6YG(&%F=FES
M="!A9B!2041)55,M<V5R=F5R+@#&9W1N:6YG(&]V97)F;W(@1E10+7-E<G9E
M<B!F96IL961E+@#&9W1N:6YG(&]V97)F;W(@4TU"+7-E<G9E<B!F96IL961E
M+@!&96QT97(@=&EL('+E9&EG:&5D.@!!<V5R8F%I9&IA;@!"3T9(+75N9'-K
M>6QD;FEN9V5R`$)A8VMG<F]U;F0`0F%G9W)U;F1S9F%R=F4`1.5R;&EG="!K
M97)B97)O<RUK;V1E;W)D+@!$Y7)L:6=T(&ME<F)E<F]S+6)R=6=E<FYA=FXN
M`$)A:&%M80!"86AR86EN`$)A;'1I:W5M("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87)B861O<P!"87-I<R!G<F%F:6MK871A;&]G("(E<R(@:6MK92!F
M=6YD970N`$)A<VES;&EN:64`2'9I9&5R=7-L86YD`$)E;&=I96X`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$;X9'-E;'-D86<`0FQO:R`B)7,B(&%F
M(&%P<&QI:V%T:6]N("(E<R(@:6MK92!F=6YD970N`$)L;VLM96=E;G-K86)E
M<@!";&]K='EP90!&960`0F]L:79I96X`0F]G;>9R:V5R`%)A;F0`4F%M;65T
M>6MK96QS93H`4F%N9&4`0F]S;FEE;B!O9R!(97)Z96=O=FEN80!"96=G90!"
M;W1S=F%N80!"=6YD`$)O=79E=/AE;@!"<F%S:6QI96X`0G)I=&ES:RU);F1I
M96X@3V-E86YO;7+E9&4`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:65N`%!U
M;FMT;&ES=&4`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@9&ES
M=')I8G5T:6]N<W-T961E<@!#96QL92UE9V5N<VMA8F5R+BXN`$EN:71I86QI
M<V5R:6YG(&%F(&UI9&QE<G1I9&EG="!L86=E<B!I:VME(&;F<F1I9V=J;W)T
M+@!+86QE;F1E<@!6:6YD<W1I;&QE`$MA;6)O9&EA`$-A;65R;W5N`$MA;B!I
M:VME(&YU;'-T:6QL92!K;V1E;W)D(&%U=&]M871I<VL[(&MO;G1A:W0@9&EN
M(&%D;6EN:7-T<F%T;W(N`$MA;B!I:VME('-K<FEV92!T:6P@9FEL("(E<R(`
M2V%N(&EK:V4@:.5N9'1E<F4@96MS=&5R;F4@<V5S<VEO;G-HY6YD=&%G+@!+
M86X@:6MK92!F;W)B:6YD92!T:6P@24U!4"!S97)V97(N("5S`$MA;B!I:VME
M(.5B;F4@9FEL("(E<R(N`$-A;F%D80!!;FYU;&QE<@!!9F)R>60@<F5P;W)T
M97)I;F<@868@<')O8FQE;0!+86X@:6MK92!S;&5T=&4@9FEL("(E<R(N`$MA
M;B!I:VME(&9I;F1E(&5T(&UI9&QE<G1I9&EG="!K871A;&]G+@!+86X@:6MK
M92!F;W)T<^9T=&4@=61E;B`G=&%R9V5T1FEL92<M<&%R86UE=')E;BX`2V%N
M(&EK:V4@9FIE<FYE(&MA=&%L;V<@(B5S(BX`2V%N(&EK:V4@9FIE<FYE+"`E
M9"!B^')N(&5K<VES=&5R97(N`$MA;B!I:VME(&]M9F]R9&5L93L@86YT86QL
M970@868@<'5N:W1E<B!A;F=I=F5T('1I;"!O;69O<F1E;&EN9R!S=F%R97(@
M:6MK92!T:6P@9&5T(&]P8F5V87)E9&4@86YT86PN`$MA;B!I:VME(&1I<FEG
M97)E(&)E<VME9"!T:6P@86YG:79N92!N=6UM97(N`$MA<"!697)D90!":6QL
M961T96MS=`!59&)Y9&5R`$MA=&5G;W)I97(@;V<@3>9R:V5R`$-A>6UA;OAE
M<FYE`$UO8FEL`$-E;&QE+65G96YS:V%B97(`0V5L;&5F;W)R:6YG.@!#96QL
M92UE9V5N<VMA8F5R`$-E;&QE+6UE;&QE;7)U;3H`36]B:6QT96QE9F]N`$ME
M;'1I<VL@*$E33RTX.#4Y+3$T*0!#96YT<NER`$1E;B!C96YT<F%L869R:6MA
M;G-K92!297!U8FQI:P!#96YT<F%L+65U<F]PYFES:R`H25-/+3@X-3DM,BD`
M0V5R=&EF:6MA="UD971A;&IE<@!#97)T:69I:V%T+65J97(`0V5R=&EF:6MA
M="UP;VQI=&EK:V5R`%1C:&%D`,9N9')E`,9N9')E(&1I="!K;V1E;W)D`$AE
M<B!K86X@9'4@YFYD<F4@9&5T(&YA=FX@;V<@9&5N(&%D<F5S<V4L('-O;2!A
M;F1R92!S97(L(&[E<B!D92!LYG-E<B!O9R!S=F%R97(@<.4@9&EN92!E+6UA
M:6PN`$MO9&5O<F1SYFYD<FEN9R!E<B!I:VME('5N9&5R<W3X='1E="!A9B!D
M96X@;G5VYG)E;F1E(&]P<^9T;FEN9RX@($MO;G1A:W0@9&EN(&%D;6EN:7-T
M<F%T;W(N`%1E9VX`2&%K(&QI;FL@868N+BX`0VAI;&4`2VEN80!3:6UP;&EF
M:6-E<F5T(&MI;F5S:7-K("A'0C(S,3(I`%1R861I=&EO;F5L="!K:6YE<VES
M:R`H0FEG-2D`5N9L9R!A<'!L:6MA=&EO;CH`5N9L9R!E="!K;V1E;W)D`%;F
M;&<@970@8G)U9V5R;F%V;@!6YFQG(&AV;W)D86X@9&%T;V5R('-K86P@=FES
M97,Z`%;F;&<@;&ES=&4M<W1I;"`H9F]R(&]R9&YE9&4@;&ES=&5R*0!*=6QE
M^&5N`$ML87-S961E9FEN:71I;VX@868@)7,@:6MK92!F=6YD970N`$ML87)T
M`$9J97)N($U33V9F:6-E+6]P;>9R:VYI;F=E<@!.=6QS=&EL(&9O<F5S</AR
M9W-E;`!296YS(&)R=6=E<B!U9#H@)7,`3G5L<W1I;"!B<G5G97(`5FES:R!B
M<G5G97)D871A('5D`%-E;B!O<&ML87)I;F<`2VQI:R!F;W(@870@9F]R='/F
M='1E`$-L:6-K871E;&P@=FEA($A45%``3'5K('9I;F1U90!3:WEE<@!3:WEE
M<B!T:61L:6=T`%-K>65T`$-O8V]S("A+965L:6YG*2#897)N90!&;VQD('-I
M9&5P86YE;"!S86UM96X`4V%M;65N9F]L9&5D92!R86YD90!+;VQU;6)I96X`
M1F%R=F4`1F%R=F5VYFQG97(`1F%R=F5V86QG`$MO;',Z`$MO;&]N;F5T:71L
M97(`5&5G;F5S97)I97(`2V]M;6%N9&\`2V]M;6%N9&]L:6YI90!+;VUM96YT
M87(`0V]M;6]N($YA;64`0V]M;W)E<FYE`$9I<FUA`$-O;7!U=&5R90!&;W)H
M;VQD`$)E=&EN9V5L<V5R`$MO;F9I9W5R871I;VYS9F]R<VME;&QE`$MO;F9I
M9W5R871I;VX@=&EL('-Y;FMR;VYI<V5R:6YG(&UE9"!01$%E<BP@4VUA<G1P
M:&]N97,@;V<@3W5T;&]O:RX`2V]N9FEG=7)A=&EO;F5N(&5R(&9O<N9L9&5T
M+@!+;VYF:6=U<NER("5S`$)E:W+F9G0@:V]D96]R9`!+;VYG;P!+;VYG;RP@
M1&5N(&1E;6]K<F%T:7-K92!R97!U8FQI:P!&;W)B:6YD96QS92!M:7-L>6MK
M961E<RX`1F]R8FEN9&5L<V4@;6ES;'EK:V5D97,Z(`!&;W)B:6YD96QS92!T
M:6P@;V9F96YT;&EG(&[X9VQE<V5R=F5R(&[F9W1E="X`1F]R8FEN9&5L<V4@
M=&EL(&]F9F5N=&QI9R!N^&=L97-E<G9E<B!NYF=T970N(,5R<V%G.B`E<R`H
M)7,I`$9O<F)I;F1E;'-E('1I;"!&5%`M<V5R=F5R(&UI<VQY:VME9&5S+@!+
M;VYT86MT97(`2V]N=&%K=&5R(&)L978@=&EL9OAJ970@=&EL(&1I="!A9')E
M<W-E:V%R=&]T96ME=`!);F1H;VQD<W1Y<&4@868@:V]M<')I;65R970@9FEL
M.B``26YD:&]L9"!A9B`B)7,B`$9O<G1SYG0`0V]O:R!)<VQA;F1S`%-MY6MA
M9V4`2V]P:65R`$MO<&EE<FEN9R!M:7-L>6MK961E<SH@)7,`2V]P:>ER(&UA
M<FME<FEN9P!'96)Y<B!)1`!#;W-T82!2:6-A`$5L9F5N8F5N<VMY<W1E;@!+
M=6YN92!I:VME(%!'4"UK<GEP=.ER92!B97-K960Z(`!+=6YN92!I:VME(%!'
M4"US:6=NZ7)E(&)E<VME9#H@`$MU;FYE(&EK:V4@4R]-24U%+6MR>7!T97)E
M(&)E<VME9"X`2W5N;F4@:6MK92!3+TU)344M<VEG;NER92!B97-K960N`$MU
M;FYE(&EK:V4@=&EL9OAJ92!K;VYT86MT+B`E<P!+=6YN92!I:VME(&MO8FQE
M('1I;"!,1$%0+7-E<G9E<BX`2W5N;F4@:6MK92!K;VYT<F]L;&5R(&)A;&%N
M8V4N("5S`$MU;FYE(&EK:V4@9F]R8FEN9&4@=&EL($Q$05`M<V5R=F5R+@!+
M=6YN92!I:VME(&9O<F)I;F1E('1I;"!S97)V97(@(B5S(B!V960@8G)U9R!A
M9B!&5%`Z("5S`$MU;FYE(&EK:V4@;W!R971T92!D:7-T<FEB=71I;VYS;&ES
M=&4N("5S`$MU;FYE(&EK:V4@9&5K<GEP=&5R92!01U`M9&%T83H@`$MU;FYE
M(&EK:V4@9&5K<GEP=&5R92!3+TU)344M9&%T82X`2W5N;F4@:6MK92!S;&5T
M=&4@:V]N=&%K="X@)7,`2W5N;F4@:6MK92!S;&5T=&4@9&ES=')I8G5T:6]N
M<VQI<W1E+B`E<P!+=6YN92!I:VME('-L971T92`\96T^<V-R:7!T/"]E;3X@
M(B5S(B!T:6P@;W!G<F%D97)I;F<@868@;W!SYG1N:6YG+@!+=6YN92!I:VME
M(&)E<W1E;6UE(&UO9'1A9V5R96YS(&4M;6%I;"UA9')E<W-E+@!+=6YN92!I
M:VME(&AE;G1E(&AE;&4@861R97-S96MA<G1O=&5K+@!+=6YN92!I:VME(&AE
M;G1E(&AE;&4@9&ES=')I8G5T:6]N<VQI<W1E+@!+=6YN92!I:VME(&AE;G1E
M(&9U;&1S=.9N9&EG(&9O<G1E9VYE;'-E(&]V97(@9&ES=')I8G5T:6]N<VQI
M<W1E<BX`2W5N;F4@:6MK92!H96YT92!S=')A=&5G:2`B)7,B+@!+=6YN92!I
M:VME(&UK9&ER("(E<R(N`$MU;FYE(&EK:V4@:&5N=&4@;V9F96YT;&EG(&[X
M9VQE(&9R82!N^&=L97-E<G9E<BX`2W5N;F4@:6MK92#E8FYE("(E<R(@9F]R
M('-K<FEV;FEN9RX`2W5N;F4@:6MK92#E8FYE("5S+@!+=6YN92!I:VME(.5B
M;F4@;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS92`E<P!+=6YN92!I:VME(.5B
M;F4@:V%T86QO9R`B)7,B+@!+=6YN92!I:VME(&[E($Q$05`M<V5R=F5R96XN
M`$MU;FYE(&EK:V4@;.9S92`E<RX`2W5N;F4@:6MK92!N=6QS=&EL;&4@:V]D
M96]R9&5T(&9O<B!D96X@86YM;V1E9&4@8G)U9V5R+B`@3F]G;&4@96QL97(@
M86QL92!D971A;&IE<B!E<B!U:V]R<F5K=&4N(%!R^'8@:6=E;B!E;&QE<B!K
M;VYT86MT(&1I;B!A9&UI;FES=')A=&]R+"!H=FES(&1U(&AA<B!B96AO=B!F
M;W(@>61E<FQI9V5R92!H:N9L<"X`2W5N;F4@:6MK92!H96YT92!!0TP`2W5N
M;F4@:6MK92!H96YT92!A9')E<W-E:V%R=&]T96ME="X@)7,`2W5N;F4@:6MK
M92!H96YT92!D:7-T<FEB=71I;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@:&5N
M=&4@9&ES=')I8G5T:6]N<VQI<W1E<BX@)7,`2W5N;F4@:6MK92!H96YT92!S
M97)V97)S(&5V;F5R`$MU;FYE(&EK:V4@9V5N9&%N;F4@:V]N9FEG=7)A=&EO
M;BX`2W5N;F4@:6MK92!R;61I<B`B)7,B+@!+=6YN92!I:VME(&=E;6UE("5S
M+6MO;F9I9W5R871I;VX`2W5N;F4@:6MK92!G96UM92!E;B!B86-K=7`M:V]N
M9FEG=7)A=&EO;BX`2W5N;F4@:6MK92!G96UM92!E;B!B86-K=7`M:V]N9FEG
M=7)A=&EO;CH@)7,`2W5N;F4@:6MK92!G96UM92!S8W)I<'0@=&EL(&]P9W)A
M9&5R:6YG(&%F(&]P<^9T;FEN9R!T:6PZ("(E<R(N`$MU;FYE(&EK:V4@9V5M
M;64@8F%C:W5P+6MO;F9I9W5R871I;VYS9FEL96X@)7,N`$MU;FYE(&EK:V4@
M9V5M;64@:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RX@1'4@:V%N(&5N=&5N(&%N
M=F5N9&4@96X@868@;75L:6=H961E<FYE(&9O<B!A="!G96UM92!K;V1E;B!T
M:6QB86=E('#E("5S(&5L;&5R(&UA;G5E;'0@:V]P:65R92!K;V1E;B!N961E
M;F9O<B!T:6P@)7,N`$MU;FYE(&EK:V4@<_AG92!,1$%0+7-E<G9E<F5N+@!+
M=6YN92!I:VME(#QE;3YU;FQI;FL\+V5M/B`B)7,B+@!+=6YN92!I:VME(&]P
M9&%T97)E(&MO;G1A:W0N("5S`$MU;FYE(&EK:V4@;W!D871E<F4@9&ES=')I
M8G5T:6]N<VQI<W1E+B`E<P!+=6YN92!I:VME('-K<FEV92!K;VYF:6=U<F%T
M:6]N(&9O<B`B)7,B.B`E<P!+=6YN92!I:VME(&9I;F1E($UO>FEL;&$@4VED
M96)A<BX@1F]R=FES(&1I9R!O;2!A="!S:61E8F%R96X@97(@Y6)E;BX`2W5N
M;F4@:6MK92!G:79E(&)R=6=E<B`B)7,B(&;X;&=E;F1E(')E='1I9VAE9&5R
M('1I;"!M87!P96X@(B5S(CH@)7,`3W!T86QT('1E:W-T`$QA;F0`2W5R<V5R
M`$]P<F5T`$]P<F5T(&5N(&AE;G9I<VYI;F<`3W!R970@96X@;GD`3W!R970@
M=6YD97)M87!P90!3:V%B97)S(')E='1I9VAE9&5R`$MR961I=&MO<G0M;G5M
M;65R`$MR;V%T:65N`$-U8F$`3G5VYG)E;F1E(#0@9F%S97(`26YD97;F<F5N
M9&4@<V5S<VEO;@!!:W1U96P@=&ED`$YU=N9R96YD92!54DP@97(`3G5VYG)E
M;F1E(&)R=6=E<F4`06MT=65L="!V96IR`$YU=N9R96YD92!V96IR.B``06MT
M=65L('-T:6P`5&EL<&%S(&]P9V%V97(L(&1E<B!B;&EV97(@=61F^')T+"!N
MY7(@9'4@;&]G9V5R(&EN9"!I("5S+@!+;&EP`$ML:7`@=F%L9P!#>7!E<FX`
M2WER:6QL:7-K("A+3TDX+5(I`$MY<FEL;&ES:R`H5VEN9&]W<RTQ,C4Q*0!+
M>7)I;&QI<VLO56MR86EN<VL@*$M/23@M52D`5&IE:VMI970`1$0`1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86=L:6<`1&%T851R964@<W1I9FEN
M9&5R`$1A=&%B87-E+6]P<VQA9P!$871O`$UO9'1A9V5L<V5S9&%T;P!$871O
M=F%L9P!$86<`4VQE="!K;VQO;FYE`$1E8V5M8F5R`$1E8VEM86QT86P`36EN
M9'-K(&EN9')Y:VYI;F<`4W1A;F1A<F0`4W1A;F1A<F1F87)V90!3=&%N9&%R
M9"UI9&5N=&ET970`4W1A;F1A<F0M<VMA;`!$969I;FET:6]N97(`4VQE=`!3
M;&5T(&-E;&QE`%-L970@9W)U<'!E`%-L970@;&]G8F]G`%-L970@=&EL;&%D
M96QS97(`1FIE<FX@;V<@=61S;&5T(&)E<VME9&5R`%-L970@8V5L;&4`4VQE
M="!K;VQO;FYE`%-L970@96MS:7-T97)E;F1E+"!A;'1E<FYA=&EV92!S:V%B
M96QO;@!3;&5T(&)E<VME9&5R`%-L970@=&EL;&%D96QS97(@9F]R("(E<R(`
M4VQE="!T:6QL861E;'-E<B!F;W(@(B5S(B!O9R!A;&QE('5N9&5R;W)D;F5D
M92!T:6QL861E;'-E<C\`4VQE="!RYFMK90!3;&5T('9A;&=T92!I9&5N=&ET
M970`4VQE="!U;F1E<FUA<'!E<@!3;&5T(&1E;B!A:W1U96QL92!K;VQO;FYE
M`%-L970@9&5N(&%K='5E;&QE('+F:VME`$]P9W)A9&5R:6YG<W-C<FEP="`B
M)7,B('-L971T970N`$QE=F5R:6YG<W1I9'-P=6YK=`!$86YM87)K`$)E<VMR
M:78@<')O8FQE;65T`$)E<VMR:79E;'-E`$1E=&%L:F5R("AO9W/E(&D@2&]R
M9&4G<R!L;V=F:6PI.@!$971A;&IE<B!E<B!S:W)E=F5T('1I;"!L;V=B;V=E
M;B!A9B!H96YS>6X@=&EL(&%D;6EN:7-T<F%T;W)E;BX`561V:6ML:6YG`$1U
M9W!U;FMT`$1U9W!U;FMT(&9O<B!S:61S=&4@=&EM93H@`$1U9W!U;FMT.B``
M4F5T;FEN9R!V96YS=')E('1I;"!H^&IR90!2971N:6YG(&CX:G)E('1I;"!V
M96YS=')E`$MA=&%L;V<`5FES('1I9"!M960@,C0@=&EM97(_`$EN9'-T:6QL
M:6YG97(@9F]R('9I<VYI;F<`5FES('5D9'EB96YD92!V96IR=61S:6=T`%9I
M<R!V96IR=61S:6=T("A4048I`%9I<VYI;F=S9F]R;6%T`$]V97)D<F%G96QS
M97-N;W1I=',`1&II8F]U=&D`1F]R=')Y9"!S;&5T;FEN9P!$=2!MY2!I:VME
M(&MA;&1E(&UA:6YT96YA;F-E+G!H<"!D:7)E:W1E`$EN9&5H;VQD97(@9&5N
M(&;X<G-T92!RYFMK92!F96QT;F%V;F4_($AV:7,@:F$L(&UA<FOI<B!D96YN
M92!B;VMS.@!$96X@9&]M:6YI:V%N<VME(%)E<'5B;&EK`$1E;B!D;VUI;FEK
M86YS:V4@4F5P=6)L:6L`2&%R(&1U(&EK:V4@;F]G96X@:V]N=&\_($UE;&0@
M9&EG('1I;"X`2&5N=`!(96YT("5S`$AE;G0@9V5N97)E<F5T(&MO;F9I9W5R
M871I;VX@;F5D('-O;2!02%`M<V-R:7!T+@!2=6QL96=A<F1I;BUL:7-T90!-
M961I:V%M96YT97(`12UM86EL`$5-86EL+71I;"U335,@9V%T97=A>2UD<FEV
M97(L(&9O<B!O<&5R873X<F5R+"!S;VT@=61B>61E<B!D96YN92!S97)V:6-E
M+@!%4E(`17%U861O<@!2961I9V5R`,9N9')E(&)L;VL`QFYD<F4@9W)U<'!E
M`,9N9')E('1I;&QA9&5L<V4`QFYD<F4@=&EL;&%D96QS97(`QFYD<F4@=&EL
M;&%D96QS97(@9F]R("5S`,9N9')E('9A;&<@9F]R.@#&;F1R92!T:6QL861E
M;'-E<B!F;W(@(B5S(@#&;F1R92!T:6QL861E;'-E<B!F;W(@)7,`561D86YN
M96QS90#&9WEP=&5N`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`94UA:6P`
M92UM86EL+6%D<F5S<V4`12UM86EL+6%D<F5S<V5R('-K86P@<&%S<V4N`$4M
M;6%I;"!M960@8F5K<N9F=&5L<V4`16UA:6PM=&\M4TU3($=A=&5W87D`4VUI
M;&5Y<P!4;VT@8F5S:V5D+@!);G1E="!R97-U;'1A="X`5&]M="!U9'1R>6L`
M06MT:7;I<B!I;F1SYG1T96QS92!A9B!B:6QL961E<B!F<F$@1F]T;V=A;&QE
M<FEE<B!I('1E:W-T/P!!:W1I=NER(&CX:G)E+6ML:6L@8V]N=&5X="UM96YU
M/P!3;'5T+>5R`$9O<G-T^'(@961I=&5R:6YG<W;F<FMT^&H`26YD=&%S="!E
M="!S:6MK97)H961S<W#X<F=S;>5L+"!S;VT@9'4@=FEL(&)L:79E('-P=7)G
M="P@;N5R(&1U(&AA<B!B<G5G(&9O<B!A="#F;F1R92!D:70@:V]D96]R9"P@
M9G@@)VAV860@97(@9&ET(&OF;&5D>7)S(&YA=FX_)SH`26YD=&%S="!54DP@
M=&EL(&)I;&QE9"!H97(`26YD=&%S="!B;V=S=&%V97(@;F5D96YF;W(Z`,9K
M=F%T;W)I86P@1W5I;F5A`,9R:71R96$`1F5J;`!&96IL('9E9"!D86YN96QS
M92!A9B!B;&]K.B`E<P!&96IL('5N9&5R('-L971N:6YG(&%F('-Y;F,M:.9G
M=&4Z("5S`$9E:FP@=6YD97(@<VQE=&YI;F<@868@<WEN8R!L;V<Z("5S`$9E
M:FP@=6YD97(@:&5N=&YI;F<@868@:6YD:&]L9#H@)7,`1F5J;"!U;F1E<B!O
M<&1A=&5R:6YG(&%F(&MO9&5O<F0Z("5S`$9E:FP@9F]R8G5N9&5T(&UE9"!E
M+7!O<W0@8F5S:V5D+@!&96IL('5N9&5R('-K<FEV;FEN9R!A9B`B)7,B+@!%
M<W1L86YD`,9T:6]P:65N`$5T;FES:P!%=7)O<&$`2'9E<B!K=F%R=&5R`$AV
M97)T(#(N(&UI;G5T`$AV97(@:&%L=F4@;6EN=70`2'9E<B`U+B!M:6YU=`!!
M;'1I9"!V960@;&]G:6X`2'9E<B!H86QV92!T:6UE`$AV97(@;6EN=70`16MS
M96UP96QVYG)D:65R.@!59&;X<@!59'9I9`!&;VQD('-I9&5P86YE;"!U9`!&
M;W)V96YT961E("<I)P!&;W)V96YT961E(')E;G0@;W)D(&5L;&5R(&-I=&5R
M970@<_AG971E<FT`1F]RYFQD96QS97-D871O`$5K<W!O;F5N=`!&1RUF87)V
M90!&5%`M;&%G<FEN9R!A9B!O<'/F=&YI;F<`2W5N;F4@:6MK92#F;F1R92!I
M;F1S=&EL;&EN9V5R;F4N`$MU;FYE(&EK:V4@9N4@9F]R8FEN9&5L<V4@=&EL
M($Q$05`@<V5R=F5R96XN`$MU;FYE(&EK:V4@9F]R8FEN9&4@=&EL(%--0BUS
M97)V97(N`$9E:FP@=6YD97(@:V]P:65R:6YG(&9R82`B)7,B+@!+=6YN92!I
M:VME(&MO<&EE<F4@=&EL("(E<R(N`$MU;FYE(&EK:V4@971A8FQE<F4@;GD@
M4T%33"UF;W)B:6YD96QS92X`2W5N;F4@:6MK92!F;'ET=&4@=&EL("(E<R(N
M`$MU;FYE(&EK:V4@:&5N=&4Z("5S`%-M=6MT`$9A;&ML86YD<_AE<FYE("A-
M86QV:6YA<RD`1N9R^&5R;F4`1/AD96QI9R!F96IL.@!&87@`1F%K<VEM:6QE
M<@!&96)R=6%R`$;X;&5S`$;X;&5S.B``1N4@8GEG97(`1N4@<VYE8GEG97(`
M1F5L=&UA=')I8V4`1FEG;&5T($-!4%1#2$$`1FEG;&5T('-K<FEF='-T>7!O
M9W)A9FD`1FEJ:0!&:6P`06YT86P@9FEL97(Z("5S(&9I;`!!;G1A;"!F:6QE
M<CH@)7,@9FEL97(`1FEL:.5N9'1E<FEN9P!&:6QN879N`$9I;'9A;&<`1FEL
M;&%G<FEN9P!&:6QL86=R:6YG(&EK:V4@=6YD97)S=/AT=&5T+@!&:6QT<F4`
M1FEN;&%N9`!&^')S=&4@:&%L=F1E;`!&^')S=&4@:W9A<G1A;`!&:6MSZ7(@
M<W3X<G)E;'-E<V9O<FAO;&0`1FQI<`!&;'ED96YD90!4Y6=E`$UA<'!E("5S
M(&5K<VES=&5R97(@:6MK90!4>7!O9W)A9FEF87)V90!-860`1F]R('=E8G!R
M;V=R86UM97(L('-O;2!I:VME('5N9&5R<W3X='1E<B!B:6QL961E<@!696IR
M=61S:6=T("A4048I`%5D<VEG='-D86=E("AB96WF<FL@870@9&5N(')E='5R
M;F5R92!V96IR=61S:6=T('9E9'+X<F5R(&+E9&4@9&%G(&]G(&YA=#L@970@
M<W1O<G0@86YT86P@:&5R(&MA;B!R97-U;'1E<F4@:2!E;B!M96=E="!B<F5D
M(&)L;VLI`$=L96UT(&1I="!K;V1E;W)D/P!&;W)M=6QA<F5R`$]R9'-P<F]G
M`$5P:6=R86UT>7!E`$5P:6=R86UM97(`17!I9W)A;6UE<B`R`$9O<F$`5FED
M97)E<V5N9&5L<V4`1G)E`%)A;6UE<@!&<F%N:W)I9P!&<F%N:W)I9RP@365T
M<F]P;VQI=&%N`$9R86YS:R!'=7EA;F$`1G)A;G-K(%!O;'EN97-I96X`1G)A
M;G-K92!S>61L:6=E(%1E<G)I=&]R:65R`$9R80!&<F$`1G5L9"!B97-K<FEV
M96QS90!&=6QD;>5N90!&=6QD="!N879N`$=A8F]N`$=A;&QE<FD@:'9O<F9R
M82!B:6QL961E('-K86P@=&%G97,@9G)A`$=A;&QE<FDZ`$=A;6)I80!'96YE
M<NER("5S+6MO;F9I9W5R871I;VX`1V5N97)E<F5T(&MO9&4`1V5O<F=I96X`
M5'ES:VQA;F0`1VAA;F$`1VEB<F%L=&%R`$9O<FYA=FX`1W)U;F1LYF=G96YD
M92!I;F1S=&EL;&EN9V5R`%5D9OAR`$?V9&5L`$=O;V=L92!-87!S`$=O;V=L
M92US^&=N:6YG`$=RY71O;F5R`$=RYFME;FQA;F0`1W+F<VL@*$E33RTX.#4Y
M+3<I`$=R^&YL86YD`$=R96YA9&$`1W)U<'!E+6%D;6EN:7-T<F%T:6]N`$=R
M=7!P96YA=FYE(&WE(&EK:V4@=N9R92!T;VUM90!'<F]U<%]L9&%P.B!+86X@
M:6MK92!T:6QF^&IE(&=R=7!P92`E<RX@4V5R=F5R96X@;65L9&5R.B``1W)O
M=7!?;&1A<#H@2V%N(&EK:V4@<VQE='1E(&=R=7!P92`E<P!'<F]U<%]L9&%P
M.B!+86X@:6MK92!O<&1A=&5R92!G<G5P<&4@)7,`1W)U<'!E<@!'=6%D96QO
M=7!E`$=U86T`1W5A=&%M86QA`$=U97)N<V5Y`$?F<W1E=&EL;&%D96QS97(`
M1^9S=&5B;V<`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-
M3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@870@<VQE='1E(&1E;B!S:61S=&4@
M8V5L;&4@:2!RYFMK92X`2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@870@
M<VQE='1E(&1E;B!S:61S=&4@:V]L;VYN92!I('1A8F5L+@!(5$U,07)E82!N
MYF=T97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N('-I9'-T92!RYFMK92!I
M('1A8F5L+@!(5%10+>9G=&YI;F<@:6MK92!F=6YD970N`$AA[W1I`$AA<V@M
M86QG;W)I=&UE`$1I<P!4;W!T96MS=`!/=F5R<VMR:69T97(`2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$MR869T:6<@=&]R9&5N`$AE8G)A
M:7-K("A)4T\M.#@U.2TX+4DI`$CX:F1E`$AJYFQP`$AJYFQP('1I;"!R961I
M9V5R:6YG<W;F<FMT^&H`2&KF;'!E<@!(96UI<V;F<F4`2&5R(&5R('-T87)T
M96X@868@9FEL96XZ`$CX:@!(:F5M`$AE;&QI9W/X("A6871I:V%N<W1A=&5N
M*0!(:F5M`%!R:79A="UA9')E<W-E`$AJ96UM96MA=&%L;V<`4')I=F%T+71E
M;&5F;VX`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!5
M9WEL9&EG("5S(%A-3"!D871A('#E=')U9F9E="!I(&)E<VME9"`E<P!(;W)D
M92]+;VQA8CH@26YG96X@8F5S:V5D('-V87)E<B!T:6P@;V)J96MT("5S`$AO
M<F1E+TMO;&%B.B!);G1E="!O8FIE:W0@868@='EP92`E<R!F=6YD970@:2!B
M97-K960@)7,`2&]R9&4O2V]L86(Z(%-L971T961E("5S("(E<R(`2&]R9&4O
M2V]L86(Z($EN=&5G<F%T:6]N<VUA<VMI;F5N(&MRYG9E<B!02%`M=61V:61D
M96QS92`G9&]M>&UL)P!(;W)D92]+;VQA8CH@2V%N(&EK:V4@9&%N;F4@;GET
M(%A-3"UT<N8@9F]R(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@2V%N(&EK:V4@
M<VQE='1E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!+86X@:6MK92!I;F1H
M96YT92!-24U%+4E$(&9O<B!D96QE;B!A9B!T>7!E("5S`$AO<F1E+TMO;&%B
M.B!+86X@:6MK92!S>6YK<F]N:7-E<F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z($MA;B!I:VME('-Y;FMR;VYI<V5R92!D96QI;F=E<CH@)7,`2&]R9&4O
M2V]L86(Z(%5K96YD="!D96QI;F<@(B5S(@!686YD<F5T('-T<F5G`%9A;F1R
M970@9F]R`%9A;F1R970Z`$AV;W)D86X@8F%R(&1U(&1I9R!A9"!M960@870@
M:&%V;F4@:&5R/R`H26YD<F%P<&]R=.ER(2D`2'9O<B!M86YG92!K;VQO;FYE
M<B#X;G-K97(@9'4@870@<V%M;65N;.9G9V4_`$AV;W(@;6%N9V4@9F5L=&5R
M("AK;VQO;FYE<BD@97(@9&5R/P!(=F]R(&UA;F=E('+F:VME<B#X;G-K97(@
M9'4@870@<V%M;65N;.9G9V4_`$9U9W1I9VAE9`!&=6=T:6=H960Z(`!(=6UO
M<FES=&5R`%5N9V%R;@!/<')E='1E;'-E(&%F($E-05`M;6%P<&4@9F5J;&5D
M93H@)7,`4VQE=&YI;F<@868@24U!4"UM87!P92!F96IL961E.B`E<P!$969I
M;F5R:6YG(&%F(&MV;W1E(&9O<B!)34%0+6UA<'!E(&9E:FQE9&4Z("5S`$E0
M+6%D<F5S<V4`25`M861R97-S92!I:VME('1I;&?F;F=E;&EG92X`25`M861R
M97-S92!I:VME(&EN9&5N9F]R($-)1%(M8FQO:RX`25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+@!);F1SYG0@<N9K:V4@9OAR`$ES;&%N9`!+=6X@:6MO;F5R`$EK
M;VYE<B!F;W(@)7,`26MO;F5R(&UE9"!T96MS=`!)9&5N=&ET971S;F%V;CH`
M2'9I<R!D96X@:6MK92!V:7-T(&MO<G)E:W0L("5S(&9O<B!A="#E8FYE(&1E
M;B!I(&5T(&YY="!V:6YD=64N`$AV:7,@9'4@:6MK92!S97(@;F]G96X@:6MO
M;F5R('9E9"!B<G5G(&%F($EN=&5R;F5T($5X<&QO<F5R('-K86P@9'4@;>5S
M:V4@:&%K:V4@9&5N;F4@8F]K<R!A9B!F;W(@870@<VSE(%!.1RUT<F%N<W!A
M<F5N<R!F<F$N`$AV:7,@9'4@<V5R(&1E;FYE(&)E<VME9"!I('-T961E="!F
M;W(@970@8FEL;&5D92P@<^4@=FEL(&1U(&EK:V4@:W5N;F4@<V4@9&5T(&D@
M9&EN(&YE="ULYG-E<B!E9G1E<B!O<&SF9VYI;F<N`$)I;&QE9"UF;W)HY6YD
M<W9I<VYI;F<Z`$)I;&QE9"U54DP`0FEL;&5D+5523#H`0FEL;&5D92!F<F$@
M9V%L;&5R:0!":6QL961E(&9R82!G86QL97)I.@!":6QL960M;W!LYF=N:6YG
M`$)I;&QE9&5R`$EM<&]R=&5R:6YG+"!T<FEN("5D`$EM<&]R=&5R961E(&9E
M;'1E<CH@)7,`26UP;W)T97)E9&4@9F5L=&5R.@!);F1SYG0@<N9K:V4@969T
M97(`1F5J;&%G=&EG(&AA;F1L:6YG<VMO9&4@86YG:79E="X`56MO<G)E:W0@
M8G)U9V5R;F%V;B!O9R]E;&QE<B!K;V1E;W)D+@!5:V]R<F5K="!B<G5G97)N
M879N(&5L;&5R(&%L=&5R;F%T:78@861R97-S92X@4'+X=B!I9V5N(&5L;&5R
M(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(L(&AV:7,@9'4@:&%R(&)R=6<@
M9F]R('ED97)L:6=E<F4@:&KF;'`N`$9O<OAG(&EN9')Y:VYI;F<`26YD:65N
M`$EN9&EV:61U96QL92!B<G5G97)E`$EN9&]N97-I96X`26YF;P!);F9O<FUA
M=&EO;@!);F9O<FUA=&EO;B!I:VME(&SF;F=E<F4@=&EL9^9N9V5L:6<`26YD
M<^9T(&MO;&]N;F4@969T97(`26YD<^9T(&)I;&QE9&4`26YD<^9T('1A8F5L
M`$EN9'/F="!W96(M:&5N=FES;FEN9P!);F1SYG0@:V]L;VYN92!F^'(`26YD
M<^9T(&5N(&YY(&MO;&]N;F4@969T97(@9&5N(&%K='5E;&QE`$EN9'/F="!E
M;B!N>2!K;VQO;FYE(&;X<B!D96X@86MT=65L;&4`26YD<^9T(&5N(&YY('+F
M:VME(&5F=&5R(&1E;B!A:W1U96QL90!);F1SYG0@96X@;GD@<N9K:V4@9OAR
M(&1E;B!A:W1U96QL90!);F1SYG0@96X@<&%R86=R868@969T97(@9&5T(&%K
M='5E;&QE('!U;FMT`$EN9'/F="!E;B!P87)A9W)A9B!F^'(@9&5T(&%K='5E
M;&QE('!U;FMT`$EN9'/F="!A;'1E<FYA=&EV('-K86)E;&]N`$EN9'1A<W0@
M96X@92UM86EL+6%D<F5S<V4L(&AV;W)T:6P@9'4@:V%N(&UO9'1A9V4@9&5T
M(&YY92!K;V1E;W)D.@!);F1SYG0@8V5L;&4@969T97(`26YD<^9T(&-E;&QE
M(&;X<@!);F1SYG0@:V]L;VYN92!E9G1E<@!);F1SYG0@:V]L;VYN92!F^'(`
M26YD<^9T(&)E<VME9&5R`$EN9'/F="!P87)A9W)A9B!E9G1E<@!);F1SYG0@
M<&%R86=R868@969T97(`26YD<^9T('+F:VME(&5F=&5R`$EN9'/F="!RYFMK
M92!F^'(`26YD=&%S="!D970@:W+F=F5D92!S=F%R('1I;"!S:6MK97)H961S
M<W#X<F=S;>5L970Z`$EN9'/F="_F;F1R92!B:6QL961E`$EN9'/F="_F;F1R
M92!H96YV:7-N:6YG`%5T:6QS='+F:VME;&EG(&MR961I="!T:6P@870@<V5N
M9&4@=&EL(&1I<W1R:6)U=&EO;G-L:7-T96XN`%5T:6QS='+F:VME;&EG92!K
M<F5D:70N`$AE;'1A;`!(96QT86QS;&ES=&4`56=Y;&1I9R!51$@N("A5<V5R
M($1A=&$@2&5A9&5R*2X`56=Y;&1I9V4@6DE0+61A=&$`56=Y;&1I9W0@87!P
M;&EK871I;VXN`%5G>6QD:6=T('-K<FEP="U)1"X`56=Y;&1I9V4@9&%T82!A
M9G-E;F1T+@!59WEL9&EG(&1E<W1I;F%T:6]N+@!59WEL9&EG="!F:6QF;W)M
M870`56=Y;&1I9R!L:6-E;G-N^&=L92X`56=Y;&1I9R!P;&%C97)I;F<@86YG
M:79E="X`56=Y;&1I9R!M<V=?='EP92X`56=Y;&1I9R!E;&QE<B!M86YG;&5N
M(&%P:5]I9"X`56=Y;&1I9V4@96QL97(@;6%N9VQE;F1E('!A<F%M971R92X`
M56=Y;&1I9V4@9F]RYFQD<F4M=&EL;&%D96QS97(N`%5G>6QD:6<@<&%R=&YE
M<BUI9"X`56=Y;&1I9R!P<F]D=6MT+6MO9&4N`%5G>6QD:6<@<')O=&]K;VPN
M`%5G>6QD:6<@;6]D=&%G97(Z("(E<R(`56=Y;&1I9W0@9&5L:6YG<V]B:F5K
M=`!59WEL9&EG(&]P<FEN9&5L<V5S861R97-S92X`56=Y;&1I9R!U;FEC;V1E
M+61A=&$N`$EN9&)O`$EN=F5R=.ER(&UA<FME<FEN9P!)<F%N+"!$96X@:7-L
M86UI<VL@<F5P=6)L:6L`27)A:P!)<FQA;F0`36%N`%-T961V:7,@=&]R9&5N
M`$ES<F%E;`!59'-T961E<@!)=&%L:65N<VL`271A;&EE;@!*86UA:6-A`$IA
M;G5A<@!*87!A;@!*87!A;G-K("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1E
M;@!*=6QI`$IU;FD`2G5S=.ER`$-E;G1RZ7(`3&EG92!M87)G96YE<@!696YS
M=')E:G5S=&5R970`2/AJ<F5J=7-T97)E=`!+87-A:VAS=&%N`$)E=F%R(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@869V:7-T92!G;V1K96YD
M96QS92!A9B!I9&5N=&ET970N`$ME<FYE+3QE;3Y.97=B:65S/"]E;3X`3OAG
M;&4M<VMA8F5L<V4`3OAG;&4M9FEN9V5R869T<GEK`$[X9VQE;.9N9V1E`$[X
M9VQE='EP90!.^&=L96%N=F5N9&5L<V4`3OAG;&4@96MS:7-T97)E<B!A;&QE
M<F5D92!PY2!D96X@;V9F96YT;&EG92!N^&=L97-E<G9E<BX`0OAR;@!+:7)I
M8F%T:0!3>61K;W)E80!.;W)D:V]R96$`:V]R96%N<VL@*$550RU+4BD`2W5W
M86ET`$MI<F=I<VES=&%N`%5D9F]R;6YI;F<`4W!R;V<`3&%O<P!3:61S=&4@
M:&%L=F1E;`!3:61S=&4@:V]D96]R9'/F;F1R:6YG`%-I9'-T92!K=F%R=&%L
M`%-I9'-T(&]P9&%T97)E=#H`4VED<W1E(&QO9VEN.B`E<P!3:61S=&4@:6YD
M;&]G;FEN9SH@)7,@9G)A("5S`%-I9'-T92!L;V=I;CH@06QD<FEG`$QE=&QA
M;F0`3&]V`$QA>6]U=`!4;VT@=F5D(&EN9V5N(')A;6UE<@!,:6)A;F]N`%9E
M;G-T<F4`5F5N<W1R92!T;W!T96MS=`!696YS=')E(';F<F1I97(`3&5S;W1O
M`$YI=F5A=0!,:6)E<FEE;@!,:6)Y96X`3&EE8VAT96YS=&5I;@!3=/AV<F5G
M;@!,970@<F5G;@!,970@<F5G;B!T:61L:6=T`$QE="!R96=N('-E;G0`3&5T
M(&)Y9V4`3&5T(&)Y9V4@;65D('1O<F1E;@!,970@<VYE`$QE="!S;F4@8GEG
M90!6:71T:6=H960`2&5N=FES;FEN9P!&;W)B:6YD('!U;FMT97(@=&EL.@!&
M;W)B:6YD(&4M;6%I;"UA9')E<W-E;B!M960@:6YD<VMR:79N:6YG<W-I9&5N
M('9E9"!F<F5M=FES;FEN9P!(96YV:7-N:6YG97(`3&EN=7@M:VEK<P!,:7-T
M92`M(&)R=6=E<B!K86X@<V4@;6%P<&5N`$QI<W0@9&%T86)A<V5R`$]P;&ES
M=&YI;F<@868@:&KF;'!E96UN97(`3&ES="!T86)E;&QE<@!,:7-T92U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&YI;F<@868@<V5S
M<VEO;G,@9F5J;&5D93H@)7,`3&ES=&YI;F<@868@8G)U9V5R92!F96IL961E
M.B`E<P!6:7-N:6YG(&%F(&)R=6=E<F4@97(@<VSE970@9G)A+@!,:71T97)A
M='5R`$QI=&%U96X`2&5N=&5R+BXN`$QO:V%L('1I9#H`4F5G:6]N86QD871A
M(&]G('1I9`!3=&5D`$QO9R!I;F0`3&]G(&%F('1I9&QI9V5R92!S>6YK<F]N
M:7-E<FEN9W-S97-S:6]N97(`3&]G('5D`$QO9R!I;F0`3&]G:6XM;W!G879E
M<@!,;V<@:6YD(&9E:FQE9&4@9F]R9&D@9&ET(&)R=6=E<FYA=FX@96QL97(@
M:V]D96]R9"!B;&5V(&%N9VEV970@9F]R:V5R="X`3&]G:6YD(&UI<VQY:VME
M9&5S+@!,86YG('1E:W-T`$OF<FQI9VAE9`!,878`4VWE(&=RYG-K92!T96=N
M`%-MY2!L871I;G-K92!T96=N`%-MY2!R;VUE<G1A;`!,=7AE;6)O<F<`34T`
M34]41`!-4RU43D5&+6)I;&%G(&EN9&AO;&1T(&EN9V5N(&1A=&$N`$U31P!-
M86-A;P!-86ME9&]N:65N+"!$96X@=&ED;&EG97)E(&IU9V]S;&%V:7-K92!R
M97!U8FQI:P!-861A9V%S:V%R`$UA9VD`12UM86EL`$4M;6%I;"UA9&UI;FES
M=')A=&]R`$1A;B!H96YV:7-N:6YG+BXN`$UA;&%W:0!-86QA>7-I80!-86QD
M:79E<FYE`$UA;&D`36%L=&$`2.5N9'3I<B!L:7-T96X@868@:V%T96=O<FEE
M<BP@<V]M(&1U('-K86P@;6%R:V5R92!E;6YE<B!M960L(&]G(&9A<G9E<FYE
M+"!D97(@<VMA;"!K;GET=&5S('1I;"!D:7-S92!K871E9V]R:65R+@!-87`R
M-"UK;W)T`$UA<%%U97-T+6MO<G0`2V]R=&SF9VYI;F<@9V5M="X`36%R=',`
M36%R9V5N`$UA<FOI<B!M960@4V5T+U5S970M9FQA9P!-87)KZ7(@;65D(&%N
M9')E(&9L86<@*&9X(%9I9W1I9R]"97-V87)E="D`36%R<VAA;&SX97)N90!-
M87)T:6YI<75E`$]V97)E;G-P87-S96YD92!F96QT97(`36%U<FET86YI96X`
M36%U<FET:75S`$UA>"!T:6QL861T(&MR961I="X`36%K<VEM=6T@8F5S:V5D
M+61E;&4@;W9E<G-K<F5D970N`$UA:W,N('1E;7`N('-I9'-T(#(T('1I;65R
M.B``36%K<RX@=&5M<"X@<VED<W1E(#8@=&EM97(Z(`!-86MS:6UU;2!A;G1A
M;"!A9B!P;W)T86QB;&]K:V4`36%K<VEM=6ULYFYG9&4`36%J`$UA>6]T=&4`
M365D:6-I;@!-961L96UM97(`365N=2UT:6QS=&%N9#H`1F]RZ6X@8V5L;&5R
M`$)E<VME9`!"97-K960@<W5C8V5S9G5L9'0@=F5R:69I8V5R970@;65D('5N
M9&5R<VMR:79E<F5N<R!C97)T:69I:V%T(&MU;FYE(&EK:V4@=F5R:69I8V5R
M97,N`$)E<VME9"!U9&SX8F5T+@!"97-K961T>7!E`$UE=&%R(%=E871H97(`
M365T87)B;&]K(&EK:V4@=&EL9^9N9V5L:6<N`$UE=&%R8FQO:R!I:VME('1I
M;&?F;F=E;&EG+B!$971A;&IE<B!E<B!B;&5V970@;F]T97)E="!T:6P@8G)U
M9R!F;W(@861M:6YI<W1R871O<F5N+@!-971A<D1"(&5R(&EK:V4@9F]R8G5N
M9&5T+@!-971O9&4`365T;V1E("(E<R(@97(@:6MK92!D969I;F5R970`365T
M;V1E(&EK:V4@9&5F:6YE9"X@365T;V1E(&MA;&1T.B`E<P!-Y6QE96YH960`
M365X:6-O`$UI:W)O;F5S:65N`$UI9'0`34E-12UT>7!E`$UI;BX@=&5M<"X@
M<VED<W1E(#(T('1I;65R.B``36EN+B!T96UP+B!S:61S=&4@-B!T:6UE<CH@
M`$UI;FEM=6T@:V]D96]R9'-A;&1E<B!E<B!E;F1N=2!I:VME('5D<W3E970`
M4W!E:FQE`$9O<G-K96QL:6=T`$UA;F=L97(@4$5!4BUP86MK92!(5%107U)E
M<75E<W0N`$MO;F9I9W5R871I;VX@;6%N9VQE<BX@1'4@8FQI=F5R(&[X9'0@
M=&EL(&%T(&=E;F5R97)E(&1E;B!N=2P@:'9I<R!D=2#X;G-K97(@870@8G)U
M9V4@9&5N;F4@87!P;&EK871I;VXN`$UA;F=L97(@8F5S:V5D+6ED+@!-86YG
M;&5R(&MRYG9E="!014%2+7!A:VME($UA:6PN`$UA;F=L97(@<V5S<VEO;BU)
M1"X`36%N`$UO8FEL($4M<&]S=`!*YG9N`,9N9')I;F=S9&%T;P#&;F1R92!5
M4DP`36]D=6QU<P!-;VQD;W9A`$UO;F%C;P!-;VYG;VQI96X`3>5N960@;V<@
MY7(`3>5N961L:6<`36]N='-E<G)A=`!-Y6YE9F%S97(`1FQE<F4@9F5L=&5R
M(&9U;F1E="!I(&QI;FEE("5D(&5N9"!D970@9F]R=F5N=&5D92`E9"X`36%R
M;VMK;P!-97-T('-K>69R:70`365S="!S:WEE=`!-97-T('-K>65T(&]G(&)L
MYG-E;F1E`$UE<W0@<V]L`$9L>70@;F5D`$9L>70@=&EL('9E;G-T<F4`36]D
M(&CX:G)E`$9L>70@;W``1FQY="!N960`1FQY="!O<`!-;V-A;6)I<75E`$UU
M;'1I+6YI=F5A=2!R=6QL96=A<F1I;G-L:7-T97(`375L=&EM87`@54L@:V]R
M=`!-=6QT:7!L92!V86QG`$UI;B!K;VYT;P!-:6YE(&MO;G1O+6EN9F]R;6%T
M:6]N97(`36EN(%!O<G1A;`!-:6X@4&]R=&%L+75D9F]R;6YI;F<`37EA;FUA
M<@!.14HL(&IE9R!E<B!)2TM%(&5N:6<`3F%V;@!.86UI8FEA`$YA=7)U`$YE
M<&%L`$YE9&5R;&%N9&5N90!(;VQL86YD<VME($%N=&EL;&5R`$YE='-C87!E
M($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E
M($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C
M87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-T92!T
M>7!E`$YE=';F<FL`06QD<FEG`$YY($MA;&5D;VYI96X`3GD@:V%T96=O<FD`
M3GEMY6YE`$YY="!B<G5G97)N879N("AV86QG9G)I="D`3F5W(%IE86QA;F0`
M3GET(&MO9&5O<F0`3GET(&MO9&5O<F0@=FEL('5D;/AB92!D96X@)7@N`$YY
M92!K;V1E;W)D(&5R(&EK:V4@96YS+@!.>70@=FEN9'5E("A?8FQA;FLI`$YY
M:&5D97(`3GEH961S9W)U<'!E<@!.YG-T90!.YG-T92`T(&9A<V5R`$[F<W1E
M('1I;'9A;&<`3N9S=&4^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YA=`!.
M:75E`$YE:@!);F=E;B!T:6QGYFYG96QI9V4@:V]N9FEG=7)A=&EO;F1A=&$@
M870@=FES92!F;W)S:V5L;&4@9F]R+@!);F=E;B!T:6QGYFYG96QI9R!S=')A
M=&5G:2!T:6P@870@;&%V92!)4T\M8FEL;&5D97(N`$EN9V5N('-K<FEP="US
M:V%B96QO;BX`1&5R(&5K<VES=&5R97(@:6MK92!N;V=E;B!B;&]K('#E(&1E
M;B!F;W)E<W!U<F=T92!P;W-I=&EO;@!);F=E;B!K86QE;F1E<B!A;F=I=F5T
M('1I;"!-0T%,+>9G=&YI;F<N`$EN9V5N(.9N9')I;F<N`$1E<B!K86X@:6MK
M92!T:6QF^&IE<R!B^')N('1I;"!D96YN92!T:6QL861E;'-E+@!);F=E;B!K
M;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R("5S+@!);F=E
M;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R($944"!6
M1E,N`$EN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E="!F
M;W(@4U%,(%9&4RX`26YG96X@:V]N9FEG=7)A=&EO;BUI;F9O<FUA=&EO;B!A
M;F=I=F5T(&9O<B!344PM1FEL92!61E,N`$MR961I="!U9'3X;70N`$EN=&5T
M(&)E<W1E;6UE;'-E<W-T960@86YG:79E="X`26YG96X@9FEL('-E;F1T`$9A
M;F1T(&EN9V5N(&EK;VYE<BX`26YT970@<W1E9"!I;F1S=&EL;&5T+@!);G1E
M="!S=&5D(&%N9VEV970N`$EN9V5N(&)E<VME9"!A;F=I=F5T+@!);G1E="!N
M879N(&%N9VEV970N`$EN=&5T(&YU;6UE<B!A;F=I=F5T+@!);F=E;B!A;G-T
M^&1E;&EG92!E<&EG<F%M;65R`$EN=&5T(&MO9&5O<F0@86YG:79E="!T:6P@
M8G)U9R!F;W(@2%144"WF9W1N:6YG+@!);G1E="!K;V1E;W)D(&%N9VEV970@
M=&EL(&)R=6<@9F]R($E-05`MYF=T;FEN9RX`26YT970@:V]D96]R9"!A;F=I
M=F5T('1I;"!B<G5G(&9O<B!+97)B97)O<RWF9W1N:6YG+@!);G1E="!K;V1E
M;W)D(&%N9VEV970@9F]R($QO9VEN9"WF9W1N:6YG+@!);G1E="!K;V1E;W)D
M(&%N9VEV971T('1I;"!005-35T0MYF=T;FEN9RX`26YT970@:V]D96]R9"!A
M;F=I=F5T(&9O<B!334(MYF=T;FEN9RX`4W1I('1I;"!/<&5N4U-,+6)I8FQI
M;W1E:V5T(&UA;F=L97(N("!/<&5N4U-,+6)I8FQI;W1E:V5T(&5R(&[X9'9E
M;F1I9W0@9F]R(&%T(&CE;F1T97)E(%!+0U,Q,BUD871A+@!);F=E;B!V96YT
M96YD92!O<'-K<FEV;FEN9V5R+@!+=F]T92!I:VME(&EN9'-T:6QL970N`$EN
M9V5N('-T<F5G97(`26YG96X@<VMI;&QE=&5G;B!A;F=I=F5T+@!);F=E;B!S
M:61E<@!);F=E;B!SY61A;B!F:6P`1&5R(&UA;F=L97(@970@;6ED;&5R=&ED
M:6=T(&MA=&%L;V<@=&EL(&UE;&QE;6QA9V5R+@!);G1E="!B<G5G97)N879N
M(&]G+V5L;&5R(&MO9&5O<F0@<V5N9'0N`$EN9V5N(&=Y;&1I9V4@6$U,+61A
M=&$@<F5T=7)N97)E=`!);F=E;B!VYG)D:65R`$]R:6=I;F%L(&MO;F9I9W5R
M871I;VX@;6%N9VQE<B!V97)S:6]N<VYU;6UE<BX@4F5G96YE<NER(&MO;F9I
M9W5R871I;VXN`$1I;B!K;VYF:6=U<F%T:6]N(&UA;F=L97(@=F5R<VEO;G-N
M=6UM97(N(%)E9V5N97+I<B!K;VYF:6=U<F%T:6]N+@!);F=E;@!);F=E;B`H
M8G)U9R!I;7!L:6-I="D`3F]R9&ES:R`H25-/+3@X-3DM,3`I`$YO<F9O;&L`
M3F]R9&QI9V4@:&%L=FMU9VQE`$YO<F1L:6=E($UA<FEA;F'X97(`3F]R9V4`
M26MK92!S96YE<F4@96YD`$EK:V4@9OAR`$EK:V4@;F]G970@:V%T86QO9P!)
M:VME(&EM<&QE;65N=&5R970N`$EK:V4@:6YD<W1I;&QE=`!):VME('5N9&5R
M<W3X='1E="X`3F]T97(`26YT970@870@8G)O=W-E+"!V96YD('1I;&)A9V4N
M`$YO=F5M8F5R`%1A;`!!;G1A;"!T96=N`$%N=&%L(&MO;&]N;F5R`$%N=&%L
M('+F:VME<@!486P@:6MK92!A;F=I=F5T(&9O<B!O<&1A=&5R:6YG(&D@9&ES
M=')I8G5T:6]N<VQI<W1E+@!/2P!/8FIE:W0`3V)J96MT9&%N;F5R`$]K=&%L
M`$]K=&]B97(`06YS=/AD96YD92!F:6QT97(`2V]N=&]R`$=A;6UE;'0@;V<@
M;GET(&MO9&5O<F0@<VMA;"!VYG)E(&9O<G-K96QL:6=E+@!'86UM96QT(&MO
M9&5O<F0`1V%M;65L="!K;V1E;W)D(&5R(&EK:V4@:V]R<F5K="X`3VUA;@!$
M96QT92!M87!P97(@=6YD97)S=/AT=&5S(&MU;B!A9B!)34%0+7-E<G9E<F4N
M`$MU;B!A;G-T^&1E;&EG92!E<&EG<F%M;65R`$MU;B#I;B!E+7!O<W0M861R
M97-S92!T:6QL861T+@!%;B!D96QI;F=S(&5J97)S:V%B(&]G(&5J97)T:6QL
M861E;'-E<B!MY2!K=6X@YFYD<F4@868@96X@<WES=&5M861M:6YI<W1R871O
M<B!E;&QE<B!E:F5R96X@<V5L=@#%8F5N(&D@970@;GET('9I;F1U90!/<&5N
M4U-,+69E:FPZ($1A=&$@:W5N;F4@:6MK92!U9&1R86=E<R!F<F$@<VEG;F5R
M970@4R]-24U%+61E;"X`Q6)E;B!D96YN92!H96YV:7-N:6YG(&D@970@;GET
M('9I;F1U90!/<&5R871I=G-Y<W1E;0!);F1S=&EL;&EN9V5R`$EN9'-T:6QL
M:6YG97(@9F]R("5S`$]R9&YE="!L:7-T90!/<F=A;FES871I;VX`3W)G86YI
M<V%T;W)I<VL@96YH960`3W)G86YI<V5R:6YG`$]P<FEN9&5L:6<@87!P;&EK
M871I;VYS<VMA8F5L;VX`3W!R:6YD96QI9V4@<VMA8F5L;VYE<B!I("5S.@!!
M;F1E;@!!;F1E;B!I;F9O<FUA=&EO;@!%:F5R<F5T=&EG:&5D97(`4$%-+>9G
M=&YI;F<@97(@:6MK92!T:6QGYFYG96QI9V4N`%!%05(Z.DUA:6PM;6]T;W(`
M4$=0(&1I9VET86P@<VEG;F%T=7(`4$=0+6MR>7!T97)E="!D871A`$]F9F5N
M=&QI9R!01U`M;OAG;&4`4$=0+7-I9VYE<F5T+VMR>7!T97)E="!D871A`%!(
M4"UK;V1E`%!(4"US:V%L`$5F=&TN(&QE="!R96=N`$5F=&TN(')E9VX`169T
M;2X@8GEG97(`169T;2X@<VYE`$5F=&TN('-N96)Y9V5R`$5F=&TN('-O;`!%
M9G0N('1O<F1E;@!03U-)6"UU9'9I9&1E;'-E(&UA;F=L97(`4$A0+7-K86P`
M1F]R<FEN9P!086MI<W1A;@!086QA=0!086SF<W1I;F$`4&%N86UA`%!A<'5A
M($YY($=U:6YE80!087)A9W5A>0!$96QV:7-T('-K>65T`$MO9&5O<F0`2V]D
M96]R9"#F;F1R970N`$MO9&5O<F0@9F]R:V5R=`!+;V1E;W)D(&MRYG9E="!V
M960@4D%$2553+>9G=&YI;F<N`$MO9&5O<F0@;65D(&)E:W+F9G1E;'-E`$MO
M9&5O<F0Z`$MO9&5O<F0Z(`!+;V1E;W)D96YE('-K86P@=N9R92!E;G,N`$EN
M9'/F=`!);F1SYG0@9G)A('5D:VQI<'-H;VQD97(`4W1I`%9E;G1E;F1E(&]P
M<VMR:79N:6YG97(Z`$9O;&L`4')O8V5N=`!59&;X<B!V961L:6=E:&]L9&5L
M<V4`561F^'(@=F5D;&EG96AO;&1E;'-E('9E9"!L;V<@:6YD/P!4:6QL861E
M;'-E<@!4:6QL861E;'-E("(E<R(@:6MK92!S;&5T=&5T+@!4:6QL861E;'-E
M(&[F9W1E=`!4:6QL861E;'-E<@!4:6QL861E;'-E<RUA9&UI;FES=')A=&EO
M;@!0<F]F:6QE<@!097)U`$OF;&5D>7(`1FEL:7!P:6YE<FYE`%1E;&5F;VX`
M1F]T;W,`4&ET8V%I<FX`4')I:VME<@!"86YA;&ET971E<@!+;&EK(&D@96X@
M8V5L;&4`0F5K<N9F="!A="!D=2#X;G-K97(@870@<VQE='1E(&1E='1E(&5L
M96UE;G0Z`$)E:W+F9G0@870@9'4@^&YS:V5R(&%T(&%F;.9N:V4@9&5T=&4@
M96QE;65N="X`26YD=&%S="!E;B!MY6YE9"!O9R!E="#E<G-T86PN`$EN9'1A
M<W0@970@;F%V;B!T:6P@9&5N(&YY92!K871E9V]R:3H`26YD=&%S="!E;B!G
M>6QD:6<@25`M861R97-S92X`26YD=&%S="!E;B!G>6QD:6<@9&%T;RP@=&IE
M:R!A;G1A;&QE="!A9B!D86=E(&D@;>5N961E;BX`26YD=&%S="!E;B!G>6QD
M:6<@=&ED<V%N9VEV96QS92X`4VMR:78@=F5N;&EG<W0L(&AV860@<')O8FQE
M;65T(&?E<B!U9"!PY2!O9R!H=F%D(&1E<B!S:V5R+@!);F1T87-T('9E;FQI
M9W-T(&)R=6=E<FYA=FX@;V<@:V]D96]R9`!,YG,@9OAL9V5N9&4@=&5K<W0N
M($1U(%-+04P@=N9R92!E;FEG(&D@8F5T:6YG96QS97)N92!F;W(@870@8G)U
M9V4@<WES=&5M970N`$EN9'1A<W0@9&5T(&YY92!K871E9V]R:6YA=FXZ`%!O
M;&5N`%!O;&ET:6L`365N:6YG<VWE;&EN9V5R`%!O<G1U9V%L`%!L86-E<FEN
M9R!A9B!B:6QL961E=`!0;&%C97)I;F<@868@9&5N;F4@=&%B96P`4V5N9"!T
M:6P@9&5N;F4@;6%P<&4@*&EK:V4@9V5N;F5M='9U;F=E="!A9B!)34%0*0!.
M961B^'(@9V5N;F5M('-E;F5S="`E<R!T:6UE<CH@`$YE9&+X<CQB<B`O/F-H
M86YC90!0<F5F<U]L9&%P.B!+<N9V970@3$1!4"UU9'9I9&1E;"!I:VME(&9U
M;F1E="X`4')E9G-?<V5S<VEO;CH@2W+F=F5T('-E<W-I;VXM=61V:61D96QS
M92!I:VME(&9U;F1E="X`5')Y:P!4<GEK('9E9"!O=F5R9FQA9&5N.B``5')Y
M:SH@`$=L:6UT`$)E=')A9W0@8FEL;&5D970@:2!E="!N>70@=FEN9'5E`$9O
M<G)I9V4@=&EL=F%L9P!59'-K<FEV(&1O:W5M96YT`%!R:79A="!N^&=L90!0
M<F]B;&5M`%!R;V)L96UB97-K<FEV96QS90!0<F]J96MT97(`4W1I:V]R9'-T
M96MS=`!/9F9E;G1L:6=E(&[X9VQE`$]F9F5N=&QI9RUN^&=L92UA;&=O<FET
M;64`3V9F96YT;&EG(&[X9VQE(&EN9F]R;6%T:6]N`$]F9F5N=&QI9R]P<FEV
M870M;OAG;&5SYG0M9V5N97)E<FEN9R!M:7-L>6MK961E<RX`4'5E<G1O(%)I
M8V\`561R96YS(&)E<VME9&5R`%%A=&%R`$9O<F5S</AR9W-E;`!+=F]T90!/
M9F9E;G1L:6<@4E-!+6[X9VQE("@E9"!B:70I`$5N:V5L='9I<R!V86QG`%)E
M9VX`4F5G;B!T:61L:6=T`%)E9VX@<V5N=`!296=N8GEG97(`4F5G;B!O9R!S
M;F4`4VQU9`!4:6QFYFQD:6=T(&5P:6=R86T`1F]R:&]L9`!,YG,`3.9S(&)E
M<VME9&5R`%9I<FME;&EG('-L971T92`E<S\@1&5N;F4@;W!E<F%T:6]N(&MA
M;B!I:VME(&)L:79E(&]M9VIO<G0N`%9I<FME;&EG('-L971T92!D871A(&9O
M<B!B<G5G97(@)7,_($1E;FYE(&]P97)A=&EO;B!K86X@:6MK92!B;&EV92!O
M;6=J;W)T+@!/;6?X<B!D:6X@<VED<W1E(&AA;F1L:6YG`$]P9&%T97(`3W!F
M<FES:R!D>6YA;6ES:V4@;65N=2UE;&5M96YT97(Z`$=E;F]P9G)I<VL@<&]R
M=&%L=FES;FEN9SH`4F5G=6SF<G0@=61T<GEK`%)E;&%T:6]N<VSF<V5R`$=E
M;F]P9G)I<VL`3F]T97(`1FIE<FYE('-E<G9E<F4`1FIE<FX@55),("AH='1P
M.B\O=W=W+F5K<V5M<&5L+F1K+VAO<F1E*3H`4VQE=`!3;&5T(&)L;VL`1FIE
M<FX@:V]L;VYN90!3;&5T(&9O<FUA=&5R:6YG`%-L970@<&%R`$9J97)N(&QA
M9W)E="!S:W)I<'0@9G)A('-E<G9E<G,@;6ED;&5R=&ED:6=E(&MA=&%L;V<N
M`$9J97)N`$9J97)N(&1E='1E('!U;FMT(&9R82!D;VMU;65N=&5T`%-L970@
M8G)U9V5R`%-L970@8G)U9V5R.B`E<P!!;FUO9&YI;F<@:W5N;F4@:6MK92!B
M97-V87)E<RX@4F5T=7)N97)E="!F96IL:V]D93H@`$%N;6]D970@=&IE;F5S
M=&4@:W5N;F4@:6MK92!F:6YD97,N`$MRYG9E9&4@)R5S)R!E<B!I:VME(&%N
M9VEV970@:2`E<RUK;VYF:6=U<F%T:6]N+@!+<N9V970@(B5S(B!E<B!I:VME
M(&%N9VEV970@:2!61E,@:V]N9FEG=7)A=&EO;BX`2W+F=F5D92`B)7,B(&5R
M(&EK:V4@86YG:79E="!I(&MO;F9I9W5R871I;VYE;BX`2W+F=F5T(&9E;'0`
M3G5L<W1I;`!.=6QS=&EL(&MO9&5O<F0`3G5L<W1I;"!D:70@:V]D96]R9`!'
M96YS:V%B('-I9'-T92!F;W)E<W#X<F=S96P`4F5S=6QT871E<@!4:6QB86=E
M('1I;"!I;F1S=&EL;&EN9V5R;F4`1V5N=&%S="!N>70@:V]D96]R9`!2975N
M:6]N`$=E;F1A;B!K;VYF:6=U<F%T:6]N`$EN9'-T:6QL:6YG97(@9F]R(%)I
M8V@@5&5X="UR961I9V5R:6YG`$?E9&5R`$CX:G)E`$CX:G)E('1O<'1E:W-T
M`$CX:G)E(';F<F1I97(`4N9K:V4M96=E;G-K86)E<BXN+@!296=E;`!2=6WF
M;FEE;@!2;W3I<B`Q.#``4F]TZ7(@=F5N<W1R90!2;W3I<B!H^&IR90!2YFMK
M92UE9V5N<VMA8F5R`%+F:VME+65G96YS:V%B97(`4N9K:V5R.@!3=')E9V5R
M`%-T<F5G97(@=FEL(&]P='+F9&4@;65L;&5M('+F:VME<B!O9R!K;VQO;FYE
M<@!3=')E9V5R('9I;"!K=6X@;W!T<N9D92!M96QL96T@:V]L;VYN97(`4W1R
M96=E<B!V:6P@:W5N(&]P='+F9&4@;65L;&5M('+F:VME<@!59&;X<@!2=7-L
M86YD`%)W86YD80!+<GEP=&]G<F%F:7-K(%,O34E-12US:6=N871U<@!3+TU)
M344M<VEG;F5R970@8F5S:V5D`%-!4TPMYF=T;FEN9R!E<B!I:VME('1I;&?F
M;F=E;&EG+@!335,`4U%,+69O<G1O;&ME<@!344PM=61T<GEK(&9O<B!O<'-L
M86<@868@=N9R9&EE<@!34T@`4U5#0T53`%-13"UF;W)T;VQK97(`3/AR`%-K
M="X@2&5L96YA`%-K="X@2VET=',@;V<@3F5V:7,`4VMT+B!,=6-I80!3:W0N
M(%!I97)R92!O9R!-:7%U96QO;@!3:W0N(%9I;F-E;G0@;V<@1W)E;F%D:6YE
M<FYE`%-A;6UE(')A;6UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3;V$@
M5&]M92!O9R!0<FEN8VEP90!3871E;&ET=61B>61E<@!3875D:6%R86)I96X`
M1V5M`$=E;2`B)7,B`$=E;2`B)7,B`$=E;6UE($EN9'-T:6QL:6YG97(`1V5M
M(&=E;F5R97)E="!K;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T(&D@9&EN
M('-E<G9E<G,@;6ED;&5R=&ED:6=E(&MA=&%L;V<N`$=E;70@)7,M:V]N9FEG
M=7)A=&EO;BX`1V5M=&4@<VMR:7!T(&9O<B!O<&=R861E<FEN9R!A9B!O<'/F
M=&YI;F<@=&EL.B`B)7,B+@!3<')E9'0@=&]R9&5N`%9I9&5N<VMA8@!3^&<`
M4_AG96UA<VMI;F5R`%;F;&<@9FEL97(`5N9L9R!E;B!D871O`%;F;&<@96X@
M9W)U<'!E(&%T('1I;&;X:F4`5N9L9R!E;B!N>2!E:F5R`%;F;&<@96X@<V5R
M=F5R`%;F;&<@96X@8G)U9V5R(&%T('1I;&;X:F4`5N9L9R!A;&QE`%;F;&<@
M86QL92!D871O+6MO;7!O;F5N=&5R+@!6YFQG(&5T(&]B:F5K=`!6YFQG(&EN
M9V5N`%;F;&<@9&4@=&5G;B!D=2!H87(@8G)U9R!F;W(@9G)A(&MA<W-E<FYE
M(&YE9&5N9F]R+B!$92!K86X@<^4@:VQI<'!E<R!O9R!K;W!I97)E<R!F<F$@
M=&5X=&9E;'1E="X`5N9L9R!D871O+6%D<VMI;&QE<F5N.@!6YFQG(&1A=&]F
M;W)M870Z`%;F;&<@9&5N(&ED96YT:71E="P@<V]M(&1U('9I;"#F;F1R93H`
M5N9L9R!T:61S+6%D<VMI;&QE<F5N.@!6YFQG('1I9'-F;W)M870Z`%;F;&<@
M=&\@9F5L=&5R+"!D97(@<W9A<F5R('1I;"!H:6YA;F1E;BX`5N9L9R!D:6X@
M9F%R=F5S86UM96YSYG1N:6YG+@!6YFQG(&1I="!F;W)E=')U:VYE('-P<F]G
M.@!396YD('!R;V)L96UB97-K<FEV96QS90!396YD(%--4P!396YE9V%L`$;X
M;&5R.B``4V5P=&5M8F5R`%-E<F)I96X@;V<@36]N=&5N96=R;P!397)I96YU
M;6UE<@!397)V97(M9&%T82!F;W)K97)T(&5L;&5R(&EK:V4@=&EL9^9N9V5L
M:6<N`%-E<W-I;VYS861M:6YI<W1R871O<@!397-S:6]N+4E$('5D;/AB970N
M`%-E<W-I;VYE<@!-YFYG9&4`26YD<W1I;&QI;F=E<B!D97(@=&EL;&%D97(@
M9&EG(&%T(&YU;'-T:6QL92!D:70@:V]D96]R9"P@:'9I<R!D=2!N;V=E;G-I
M;F1E('-K=6QL92!G;&5M;64@9&5T+@!);F1S=&EL(&9J97)N92!S97)V97)E
M+"!S;VT@9'4@^&YS:V5R(&%T('1I;&?E(&9R82!D:6X@<&]R=&%L+@!);F1S
M=&EL(&1I;B!F;W)E=')U:VYE('-P<F]G+2P@=&ED<WIO;F4M(&]G(&1A=&]V
M86QG+@!);F1S=&EL(&1I;F4@;W!S=&%R='-A<'!L:6MA=&EO;F5R+"!F87)V
M97-A;6UE;G/F=&YI;F<L('-I9&5O<&9R:7-K;FEN(&]G(&%N9')E('9I<VYI
M;F=S=&EL=F%L9RX`26YD<W1I;&QI;F<`4VMR:7!T<R!T:6P@;W!G<F%D97)I
M;F<@868@;W!SYG1N:6YG('1I;&?F;F=E;&EG90!&;&5R92!S=&5D97(@;75L
M:6<@;65D('!A<F%M971E<F5N.B``4V5Y8VAE;&QE<FYE`%-H;W!P:6YG`$MO
M<G0@;W!S=6UM97)I;F<`4VMA;"!H=7)T:6<M=&%S=&5R(&1E9FEN97)E<R!F
M;W(@9&4@9FQE<W1E(&AE;G9I<VYI;F=E<C\@*/<I`%9I<P!6:7,@9F]R<VME
M;&QE;F4@;65L;&5M(&1E;B!G96UT92!O9R!D96X@;GEL:6=T(&=E;F5R97)E
M9&4@:V]N9FEG=7)A=&EO;BX`5FES('1I9'-P=6YK="!F;W(@<V5N97-T92!T
M:6QG86YG('9E9"!PY6QO9VYI;F<_`%9I<R!M=6QI9VAE9"!F;W(@870@8F5H
M;VQD92!O<')I;F1E;&EG`%9I<R!S;G5P<&5R`%9I<R!486)E;&]P97)A=&EO
M;F5R+6MN87!P96X@:2!M96YU96X_`%9I<R`E<RUM96YU96X@=&EL('9E;G-T
M<F4_`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@9F]R('1A8F5L
M8V5L;&5N`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@9F]R('1A
M8F5L;&5N`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@9F]R('1A
M8F5L<N9K:V5N`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@9F]R
M(&)I;&QE9&5T`%9I<R!A9G-E;F1T90!">6=E<@!">6=E<B!T:61L:6=T`$)Y
M9V5R('-E;G0`0GEG97(@:2!NYG)H961E;@!3:W)U;7``4VMR=6UP(&5L;&5R
M(&9L>70@;F%B;V)L;VMK92!A9B!V96IE;B!F^')S=`!3:65R<F$@3&5O;F4`
M4VMR:78@:6YD`%5N9&5R<VMR:69T`%-I9VYA='5R86QG;W)I=&UE`%-I;F=A
M<&]R90!3=/AR<F5L<V4`4W!R:6YG('9E9&QI9V5H;VQD96QS92!O=F5R`%-L
M;W9A:VEE=`!3;&]V96YI96X`4VYE`%-N96)Y9V4`4VYE8GEG97(`4VYE8GEG
M97(@=&ED;&EG=`!3;F5B>6=E<B!S96YT`%-N961Y8F1E.B``4VYEYFMV:79A
M;&5N="!I('9A;F0Z(`!386QO;6]N^&5R;F4`4V]M86QI80!386YG92!O9R!P
M;V5S:0!3;W)T97)I;F=S=F%L9P!!9G-E;F1E<F%D<F5S<V4`4WED869R:6MA
M`%-Y9&5U<F]PYFES:R`H25-/+3@X-3DM,RD`4WED($=E;W)G:6$@;V<@1&4@
M<WED;&EG92!386YD=VEC:/AE<@!3>61L:6=E(&AA;'9K=6=L90!,=69T(&UE
M;&QE;2!N86)O8V5L;&5R`$QU9G0@;65L;&5M(&EN9&AO;&0@;V<@<F%M;64@
M:2!C96QL90!-96QL96UR=6US=&%N9V5T`$UE;&QE;7)U;0!,=69T(&]G(&9O
M<G)I;F<`4W!A;FEE;@!3:VED='!O<W0`26YD=&%S=&YI;F<@9F]R('-P96-I
M86QK87)A:W1E<@!$96P@8V5L;&4`1&5L(&MO;&]N;F4`1&5L('+F:VME`%-P
M;W)T`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`0F5G>6YD96QS97/E
M<@!$96QS=&%T(&5L;&5R('!R;W9I;G,`4W1A='5S`$QA9W)I;F=S9F]R;6%T
M`%9E:@!'96YN96US=')E9VYI;F<`3&ES=&4@868@<W1R96YG90!&:F5R;B!D
M;VWF;F4@9G)A(&%D<F5S<V5N`%-T:6P@6T-34UT`4_AN`%5N9&5R:V%T86QO
M9R`B)7,B(&EK:V4@9G5N9&5T+@!%;6YE`$=O9&ME;F0`06YM;V1N:6YG(&]M
M(&%T('1I;&;X:F4@(B5S(B!T:6P@<WES=&5M(&%F<V5N9'0N("!$=2!K86X@
M:6MK92!L;V=G92!PY2!F^'(@9&EN(&%N;6]D;FEN9R!E<B!B;&5V970@86YE
M<FME;F1T+@!,878@<VMR:69T`%5D9OAR=``B)7,B(&)L978@=&EL9OAJ970@
M=&EL('-Y<W1E;65T+@!$871A(&9O<B!B<G5G97(@(B5S(B!B;&5V('-L971T
M970@9G)A('-Y<W1E;65T+@`B)7,B('-L971T970N`"(E<R(@<VQE='1E="!F
M<F$@<WES=&5M970N`$MO;F9I9W5R871I;VX@=&EL8F%G96;X<G0N($=E;FEN
M9&SF<R!F;W(@870@<V4@YFYD<FEN9V5R;F4N`%)E<V5R=F5K;VYF:6=U<F%T
M:6]N(&=E;70N`%)E<V5R=F5K;VYF:6=U<F%T:6]N9FEL("5S(&=E;70N`"(E
M<R(@;W!D871E<F5T+@`B)7,B('-K<F5V970N`%-U9&%N`$EN9&AO;&0`4V]L
M;W!G86YG`%-O;&YE9&=A;F<`4V]L<FEG=`!3;VQO<&=A;F<`4V]L;W!G86YG
M+W-O;&YE9&=A;F<`4V]L;W!G86YG.B``4V]L;F5D9V%N9P!3;VQN961G86YG
M.B``2.9V970@<VMR:69T`$AJYFQP`%-U<FEN86T`169T97)N879N`%-V86QB
M87)D(&]G($IA;B!-87EE;@!3=V%Z:6QA;F0`4W9E<FEG90!38VAW96EZ`%-Y
M;F,@;&]G('-L971T970`4WEN8TU,`%-Y;G1A:W-F96IL(&D@<_AG96QE9`!3
M>7)I96X`5&]R9&5N`%1O<F1E;B!O9R!V:6YD`%1O<F1E;@!4;W)D96X@=&ED
M;&EG=`!44U8M9FEL`%1A8F5L`%1A8F5L+65G96YS:V%B97(`5&%B96QMYFYG
M9&4`5&%B96PM96=E;G-K86)E<@!486EW86X`5&%I=V%N+"!$96X@:VEN97-I
M<VME('!R;W9I;G,`5&%D:FEK:7-T86X`5&%N>F%N:6$`3>5L.@!/<&=A=F5R
M`%1E;&5F;VYN=6UM97(`5&5M<"X@<VED<W1E('1I;64Z(`!496UP97)A='5R
M`%1E;7!E<F%T=7(Z(`!496UP97)A='5R/&)R("\^*"5S2/AJ)7,O)7-,878E
M<RD@)F1E9SLE<P!3:V%B96QO;B`B)7,B(&EK:V4@9G5N9&5T+@!3:V%B96QO
M;BUA9&UI;FES=')A=&EO;@!496MS=`!296X@=&5K<W0`5&5K<W0M:G5S=&5R
M:6YG`%1E:W-T+71O<`!4;W(`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`1E10
M+75D=FED9&5L<V5N(&5R(&EK:V4@=&EL9^9N9V5L:6<N`$AI<W1O<FEK+7-Y
M<W1E;65T(&5R('-LY65T(&9R82X`2&]R9&4O2V]L86(M:6YT96=R871I;VYS
M;6]T;W)E;B!U;F1E<G-T^'1T97(@:6MK92`B)7,B`$E-4U`M;&]G9V5N(&MU
M;FYE(&EK:V4@:VQA<F?X<F5S+@!-86EN=&5N86YC93HZ+6ML87-S96X@8FQE
M=B!I:VME(&EN9&SF<W0`5&EL=F%L9W-V:6YD=65T(&5R(&)L979E="!L=6MK
M970N($%F<VQU='1E<BX`061M:6YI<W1R871O<F5N(&)L:79E<B!N^&1T('1I
M;"!A="!K;VYF:6=U<F5R92!E;B!P97)M86YE;G0@5&EL;&%D96QS97,M8F%C
M:V5N9"P@:'9I<R!D=2!V:6P@86YV96YD92!4:6QL861E;'-E<BX`2W5N('5N
M9&5R<VED96X`2V]N=&%K="U)1"UN=6UM97)E="!B;&5V(&EK:V4@86YG:79E
M="P@969T97)L861T('1O;70@96QL97(@8FQE=B!I:VME(&9U;F1E="!I(&1A
M=&%B87-E;BX`2V]N=&%K=&5N(&)L978@=&EL9OAJ970@=&EL(&1I="!A9')E
M<W-E:V%R=&]T96ME="X`1&5N(&SX<V=J;W)T92!01U`M<VEG;F%T=7(M8FQO
M:R!E<B!K<N9V970@9F]R(&%T(&MU;FYE('9E<FEF:6-E<F4@9&5N('-I9VYE
M<F5D92!B97-K960N`$1I<W1R:6)U=&EO;G-L:7-T92U)1"!E<B!E;G1E;B!I
M:VME(&%N9VEV970L('1O;70@96QL97(@:6MK92!F=6YD970@:2!D871A8F%S
M96XN`$1I<W1R:6)U=&EO;G-L:7-T96X@:6MK92!A;F=I=F5T+@!+<GEP=&5R
M:6YG<V9A8VEL:71E=&5R;F4@:W+F=F5R(&5N('-I:VME<B!W96(M9F]R8FEN
M9&5L<V4N`$9I;&5N("5S(&+X<B!I;F1E:&]L9&4@96X@)7,M:6YD<W1I;&QI
M;F<N`$9I;&5N("5S(&+X<B!I;F1E:&]L9&4@;F]G;&4@)7,M:6YD<W1I;&QI
M;F=E<BX`1FEL96X@:V%N(&EK:V4@:V]P:65R97,@;W9E;G#E('-I9W-E;'8N
M`$9I;&5N(&EN9&5H;VQD="!I;F=E;B!D871A+@!&^&QG96YD92!E<B!H;W9E
M9&5R;F4@9G)A(&1E;FYE(&UE<W-A9V4O<F9C.#(R+6)E<VME9"X`1G5L9'-K
MYG)M<W1I;'-T86YD('9I9&5S(&%T('9O;&1E('!R;V)L96UE<B!I($EN=&5R
M;F5T($5X<&QO<F5R(&=R=6YD970@8G)O=W-E<BUF96IL+"!S;VT@=FD@:6MK
M92!H87(@:W5N;F5T(&]M9^4N($1U('9I;"!M=6QI9W9I<R!O<&QE=F4@9F]R
M=F%N<VME9&4@=FES;FEN9V5R+"!M86YG96P@<.4@961I=&5R:6YG<V9U;FMT
M:6]N97(@;V<O96QL97(@=&EL9N9L9&EG92!B<F]W<V5R+6YE9&)R=60N($AV
M:7,@9&ET('-Y<W1E;2!E<B!7:6YD;W=S)FYB<W`[.7@@=FEL(&1U(&UE9"!H
M^&H@<V%N9'-Y;FQI9VAE9"!O<&QE=F4@)T=E;F5R96P@8F5S:WET=&5L<V5S
M9F5J;"<@;V<@=FEL(&)L:79E(&[X9'0@=&EL(&%T(&=E;G-T87)T92!M87-K
M:6YE;BY<;EQN1'4@97(@;G4@861V87)E="X@(%1R>6L@3TL@:'9I<R!D=2!S
M=&%D:6<@^&YS:V5R(&%T('!R^'9E="!F=6QD<VOF<FUS<F5D:6=E<FEN9RX`
M261E;G1I=&5T96X@(B5S(B!E<B!S;&5T=&5T+@!+=6X@=F5N<W1R92!S:61E
M+@!0;&%C97)I;F=E;B!A9B!';G501RUP<F]G<F%M;65T('-K86P@9VEV97,@
M=&EL($-R>7!T7W!G<#HZ+6ML87-S96XN`$)E<VME9&5N+"!S;VT@97(@<V5N
M9'0@9&5N("5S('1I;"`E<R!M960@96UN970@(B5S(B!E<B!B;&5V970@=FES
M="X*1&5T=&4@97(@:6YG96X@9V%R86YT:2!F;W(L(&%T(&)E<VME9&5N(')E
M;G0@9F%K=&ES:R!E<B!B;&5V970@;.9S="!E;&QE<B!F;W)S=.5E="X`3F%V
M;F5T+"!D97(@<VMA;"!B<G5G92P@;N5R(&1E<B!H96YV:7-E<R!T:6P@<VMR
M:79E<VED96X`06YT86QL970@868@9F5L=&5R('-K86P@=N9R92!E="!T86PN
M`&]P96YS<VPM;6]D=6QE="!E<B!K<N9V970@868@2&]R9&5?0W)Y<'1?<VUI
M;64Z.BUK;&%S<V5N+@!0<N9F97)E;F-E;B`B)7,B(&MU;FYE(&EK:V4@9V5M
M;65S(&9O<F1I(&1E;G,@9&%T82!O=F5R<VMR:61E<B!D96X@;6%K<VEM86QT
M('1I;&QA9'1E('-T^')R96QS90!0<F]G<F%M;65T+"!D97(@8G)U9V5S('1I
M;"!A="!B971R86=T92!D96YN92!D871A='EP92`H)7,I+"!B;&5V970@:6MK
M92!F=6YD970@<.4@<WES=&5M970N`$-I=&%T:6]N<W1E9VYE="!S:V%L(';F
M<F4@970@96YK96QT('1E9VXN`$MU;B!H^&IR92!O9R!V96YS=')E('-I9&4`
M2W5N('-I9&5N('1I;"!H^&IR90!!9'-K:6QL96QS97-T96=N970@<VMA;"!V
MYG)E(&5T(&5N:V5L="!T96=N+@!397)V97)E;B`B)7,B(&5R('-L971T970N
M`%-E<G9E<F5N("(E<R(@97(@9V5M="X`3W!S:W)I=FYI;F=S86YM;V1N:6YG
M96X@9F]R("5S(&5R('-L971T970N`$1E;B!A;F=I=FYE('+F:VME("@E9"D@
M96MS:7-T97)E<B!I:VME+@!$96X@86YG:79N92!RYFMK92!E:W-I<W1E<F5R
M(&EK:V4N`$1E;B!M:61L97)T:61I9V4@9FEL("(E<R(@9FEN9&5S(&EK:V4N
M`$1E;B!T96MS="P@<V]M(&1U(&EN9'1A<W1E9&4L('!A<W-E<B!I:VME('1I
M;"!T96MS=&5N('#E('-KYG)M96XN`$MU;B!T;W`@;V<@8G5N9`!+=6X@=&]P
M`$1E;B!A9G-E;F1T92!I;F9O<FUA=&EO;B!E<B!T86)T('-I9&5N('-I9'-T
M92!T<FEN+@!$96X@;W9E<F;X<G1E(&9I;"!K=6YN92!I:VME(&=E;6UE<RX`
M=V5A=&AE<BYC;VTM8FQO:VME;B!E<B!I:VME('1I;&?F;F=E;&EG+@!496UA
M+6MA=&%L;V=E="`B)7,B(&EK:V4@9G5N9&5T+@!);F=E;B!T:6QV86QG('1I
M;"!RY61I9VAE9"X`1&5R(&9O<F5F:6YD97,@:6YG96X@9&5L92P@<V]M(&MA
M;B!V:7-E<R!I;F1L96IR970N`$1E<B!E<B!F;W(@;6%N9V4@=&5G;B!I(&1E
M='1E(&9E;'0N($1U(&AA<B!I;F1T87-T970@)7,@=&5G;CL@9'4@<VMA;"!I
M;F1T87-T92!M:6YD<F4@96YD("5S+@!$97(@;W!S=&]D(&5T('!R;V)L96T@
M=6YD97(@=&EL9OAJ96QS96X@868@)R5S)R!T:6P@<WES=&5M970Z("5S`$1E
M<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:F5R;F5L<V4@868@9&%T82!F
M;W(@8G)U9V5R("(E<R(@9G)A('-Y<W1E;65T.B``1&5R(&]P<W1O9"!E="!P
M<F]B;&5M('5N9&5R('-L971N:6YG(&%F("(E<R(@9G)A('-Y<W1E;65T.B``
M1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&]P9&%T97)I;F<@868@(B5S
M(CH@)7,`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9I;&]V97)F^')S
M;&5N.B!);F=E;B`E<R!B;&5V(&]V97)F^')T+@!$97(@;W!S=&]D(&5T('!R
M;V)L96T@=6YD97(@9FEL;W9E<F;X<G-L96XZ("5S('9A<B!S=/AR<F4@96YD
M(&1E;B!M86MS:6UA;'0@=&EL;&%D=&4@<W3X<G)E;'-E("@E9"!B>71E<RDN
M`$1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@
M)7,@8FQE=B!K=6X@9&5L=FES="!O=F5R9OAR="X`1&5R(&]P<W1O9"!E;B!F
M96IL('5N9&5R('9I<VYI;F<@868@9&5N;F4@8F5S:V5D9&5L`$1E<B!O<'-T
M;V0@96X@9F5J;"!U;F1E<B!I;7!O<G1E<FEN9V5N(&%F(&MO;G1A:W1I;F9O
M<FUA=&EO;BX`1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG
M96X@868@:4-A;&5N9&%R(&1A=&$N`$1E<B!O<'-T;V0@96X@9F5J;"!I(&MO
M;F9I9W5R871I;VYS9F]R;75L87)E;BX@3G5L:6=V:7,@:&%R(&1U('5D96QA
M9'0@970@:W+F=F5T(&9E;'0N`$1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E
M<B!U9&;X<F5L<V4@868@9&5N(&%N9VEV;F4@861R97-S96MA<G1O=&5K<V9U
M;FMT:6]N+B!0<OAV(&EG96XN`$1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!O
M<&1A=&5R:6YG(&%F(&MO;G1A:W0M9&5T86QJ97)N92X@4'+X=B!I9V5N+@!$
M97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@;W!D871E<FEN9R!A9B!D:7-T<FEB
M=71I;VYS;&ES=&5N+B!0<OAV(&EG96XN`$1E;FYE($E-05`M<V5R=F5R('5N
M9&5R<W3X='1E<B!I:VME(&1E;&EN9R!A9B!M87!P97(N`$1E='1E('1Y9&5R
M(&EK:V4@<.4@870@=N9R92!E="!G>6QD:6=T(')A<BUA<FMI=BX`1&5N;F4@
M='ED97(@:6MK92!PY2!A="!VYG)E(&5N(&=Y;&1I9R!Z:7`M9FEL+@!$971T
M92!T>61E<B!I:VME('#E(&%T(';F<F4@970@9WEL9&EG="!K;W)T;G5M;65R
M+@!$96YN92!D<FEV97(@=&EL;&%D97(@869S96YD96QS92!A9B!B97-K961E
M<B!I9V5N;F5M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M861G86YG<W!U;FMT970@=F5D(&)R=6<@868@2%144"!!4$D`1&5N;F4@9')I
M=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D97(@:6=E;FYE;2!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2!A9&=A;F=S<'5N:W1E="!V960@8G)U
M9R!A9B!(5%10($%020!$96YN92!D<FEV97(@=&EL;&%D97(@869S96YD96QS
M92!A9B!B97-K961E<B!I9V5N;F5M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E
M;6%I;"YC;VTI(&%D9V%N9W-P=6YK=&5T('9E9"!B<G5G(&%F($A45%`@05!)
M`$1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E;'-E(&%F(&)E<VME9&5R
M('9I82!33510(&EG96YN96T@5F]D869O;F4@271A;&EE;B!A9&=A;F=S<'5N
M:W1E="P@9&]G(&MU;B!T:6P@5F]D869O;F4M;G5M<F4N($1E;B!K<N9V97(@
M96X@92UM86EL:V]N=&\@:&]S(%9O9&%F;VYE($ET86QI96X@*&AT='`Z+R]W
M=W<N,3DP+FET*2X`1&5T=&4@9F5L="!E<B!K<N9V970N`$1E='1E(&9E;'0@
M;>4@:W5N(&EN9&5H;VQD92!H96QT86PN`$1E='1E(&9E;'0@;>4@:W5N(&EN
M9&5H;VQD92!N=6UR92!O9R!K;VQO;BX`1&5T=&4@9F5L="!MY2!K=6X@:6YD
M96AO;&1E(&]K=&%L92!VYG)D:65R+@!$971T92!F96QT('-K86P@=N9R92!E
M;B!K;VUM82T@96QL97(@;65L;&5M<G5M<V%D<VMI;&1T(&QI<W1E(&%F(&AE
M;'1A;`!$971T92!F96QT('-K86P@=N9R92!E="!G>6QD:6=T(&YU;6UE<BX`
M1&5T=&4@9F5L="!S:V%L(&EN9&5H;VQD92!E;B!F87)V96MO9&4@:2!21T(@
M:&5X+69O<FUA="P@9G@@)R,Q,C,T868G+@!$96YN92!F;W)M=6QA<B!E<B!A
M;&QE<F5D92!P<F]C97-S97)E="X`1&5T=&4@97(@)7,N`$1E='1E(&5R(&5T
M($MO;&%B($=R;W5P=V%R92UO8FIE:W0N($9O<B!A="!S92!D971T92!O8FIE
M:W0@:&%R(&1U(&)R=6<@9F]R(&5N(&4M;6%I;"UK;&EE;G0L('-O;2!F;W)S
M=.5R($MO;&%B($=R;W5P=V%R92UF;W)M871E="X@0F5S^&<@)7,@9F]R(&5N
M(&QI<W1E(&%F(&ML:65N=&5R+@!$96YN92!B97-K960@97(@<VMR979E="!M
M960@970@86YD970@=&5G;G/F="`H)7,I(&5N9"!D:70@96=E="X`5&%L;&5T
M('-K86P@=N9R92!M:6XN(#$N`$1E;FYE('-E<G9E<B!K86X@:6MK92!D96MO
M;7!R:6UE<F4@>FEP+2!O9R!G>FEP+69I;&5R+@!$971T92!S>7-T96T@97(@
M9&5A:W1I=F5R970N`$1E;FYE(';F<F1I('-K86P@=N9R92!E="!T86PN`$1E
M='1E('9I;F1U92!S:V%L(&MA;&1E<R!F<F$@970@5&EL=F%L9W-V:6YD=64`
M5&]R9&5N`%-A9V5R`%1I9`!4:61S;W!G^')E;'-E`%1I9'-F;W)M870`5&ED
M<W9A;&<`5&EM;W(M3&5S=&4`5&ET96P`5&ET;&4@*'1O;VQT:7`I.@!4:6P`
M1F]R(&%T(';F;&=E(&UU;'1I<&QE(&EN9&=A;F=E('-K86P@0W1R;"T@*%!#
M*2!E;&QE<B!#;VUM86YD("A-86,I+71A<W1E;B!H;VQD97,@;F5D92!M961E
M;G,@9&5R(&ML:6MK97,N`$D@1&%G`%-K:69T($A434PM:VEL9&4`5&]G;P!4
M;VME;&%U`$D@;6]R9V5N`%1O;F=A`$9O<B!M86YG92!U9WEL9&EG92!L;V=I
M;F0M9F]R<_AG(&D@;/AB970@868@9&4@<VED<W1E(&UI;G5T=&5R+@!4;W``
M5&]P(&9R86UE("A?=&]P*0!/=F5R<^9T=&5L<V5R`%1R:6YI9&%D(&]G(%1O
M8F%G;P!386YD(&5L;&5R(&9A;'-K`%1I<@!4=6YE<VEE;@!4>7)K:65T`%1Y
M<FMI<VL@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!O9R!#86EC
M;W,@V&5R;F4`5'5V86QU`%-K<FEV(&1I="!V86QG.B``52Y6+BUI;F1E:W,Z
M(`!54DP`55),(&9O<B!S:W)I<'0@=&EL(&UO9'1A9V5L<V4@868@<W1A='5S
M(')A<'!O<G1E;@!54DPZ`%5G86YD80!5:W)A:6YE`$MU;FYE(&EK:V4@=&EL
M9^4@5D93+6MA=&%L;V<N`$MA;B!I:VME('1I;&;X:F4@96MS=')A(&)R=6=E
M<B!I;F9O<FUA=&EO;B!U;F1E<B!O<'-K<FEV;FEN9RX`2V%N(&EK:V4@YFYD
M<F4@=&EL;&%D96QS97(@9F]R(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@YFYD
M<F4@=&EL;&%D96QS97(@9F]R(%9&4RUF:6P@)7,O)7,N`$MA;B!I:VME('-K
M:69T92!T:6P@)7,N`$MA;B!I:VME('1J96MK92!F:6QS=/AR<F5L<V5N(&%F
M("(E<R(N`$MA;B!I:VME('1J96MK92!F:6QS=/AR<F5L<V5N(&%F("(E<R\E
M<R(N`$MU;FYE(&EK:V4@9N4@9F]R8FEN9&5L<V4@=&EL(%-13"!S97)V97)E
M;BX`2V%N(&EK:V4@9N4@9F]R8FEN9&5L<V4@;65D(%-33"X`2V%N(&EK:V4@
M:V]P:65R92!61E,M9FEL+@!+86X@:6MK92!D86YN92!61E,M:V%T86QO9R`B
M)7,B+@!+86X@:6MK92!D86YN92!61E,M:V%T86QO9RX`2V%N(&EK:V4@;&%V
M92!61E,M9FEL+@!+86X@:6MK92!O<')E='1E(%9&4RUM87!P92`B)7,B+@!+
M86X@:6MK92!L879E('1O;2!61E,M9FEL+@!+86X@:6MK92!D96MO;7!R:6UE
M<F4@9&%T82X`2V%N(&EK:V4@<VQE='1E("(E<R([(&MA=&%L;V=E="!E<B!I
M:VME('1O;70N`$MA;B!I:VME('-L971T92`B)7,B.B`E<RX`2V%N(&EK:V4@
M<VQE='1E("5S.R!K871A;&]G970@97(@:6MK92!T;VUT`$MA;B!I:VME('-L
M971T92!61E,M:V%T86QO9V5T(')E:W5R<VEV="X`2V%N(&EK:V4@<VQE='1E
M(%9&4RUK871A;&]G+@!+86X@:6MK92!S;&5T=&4@5D93+6MA=&%L;V<Z("5S
M+@!+86X@:6MK92!S;&5T=&4@5D93+69I;"`B)7,B+@!+86X@:6MK92!S;&5T
M=&4@5D93+69I;"X`2V%N(&EK:V4@<VQE='1E(%9&4RUM87!P92`B)7,B+@!+
M86X@:6MK92!S;&5T=&4@5D93(')E:W5R<VEV=#H@)7,N`$MA;B!I:VME(&)E
M<W1E;6UE(&%K='5E;'0@:V%T86QO9RX`2V%N(&EK:V4@=61D<F%G92!C97)T
M:69I:V%T+61E=&%L:F5R`$MA;B!I:VME(&EN9&SF<V4@9&5F:6YI=&EO;F5N
M(&%F("5S+@!+86X@:6MK92!F;'ET=&4@5D93+69I;"X`2V%N(&EK:V4@Y6)N
M92!61E,M9FEL("(E<R(N`$MA;B!I:VME(.5B;F4@5D93+69I;"!T:6P@<VMR
M:79N:6YG+@!+86X@:6MK92#E8FYE(%9&4RUF:6PN`$MA;B!I:VME(.5B;F4@
M:V]M<')I;65R970@87)K:78N`$MA;B!I:VME(&SF<V4@5D93+69I;"`H9FEL
M97-I>F4H*2!F96IL961E*2X`2V%N(&EK:V4@;.9S92!61E,M9FEL("AG971&
M:6QE4VEZ92@I(&9E:FQE9&4I+@!+86X@:6MK92!LYG-E(&9I;#H@`$MA;B!I
M:VME(&SF<V4@=F9S<F]O="UK871A;&]G970N`$MA;B!I:VME(&]M9/AB92`E
M<R!T:6P@)7,Z(&WE;&UA<'!E;B!F:6YD97,@86QL97)E9&4`2V%N(&EK:V4@
M;VUD^&)E(%9&4RUK871A;&]G+@!+86X@:6MK92!O;63X8F4@5D93+6MA=&%L
M;V<Z("5S+@!+86X@:6MK92!O;63X8F4@5D93+69I;"`B)7,B+@!+86X@:6MK
M92!O;63X8F4@5D93+69I;"`E<R\E<RX`2V%N(&EK:V4@;VUD^&)E(%9&4RUF
M:6PN`$MA;B!I:VME(&%F=FEK;&4@)VUK:7-O9G,G+@!+=6YN92!I:VME(&]V
M97)SYG1T92!D971T92!7;W)D(&1O:W5M96YT`$MA;B!I:VME('-K<FEV92!6
M1E,M9FEL("(E<R(N`$MA;B!I:VME('-K<FEV92!61E,M9FEL("AC;W!Y*"D@
M9F5J;&5D92DN`$MA;B!I:VME('-K<FEV92!61E,M9FEL9&%T82X`2V%N(&EK
M:V4@<VMR:79E(%9&4RUF:6P[(&MV;W1E;B!V:6P@8FQI=F4@;W9E<G-K<F5D
M970N`%5N9&5R;&EN:65R970`1F]R=')Y9"#F;F1R:6YG97(`3VUG^'(@9&EN
M('-I9'-T92!H86YD;&EN9P!5=F5N=&5T(')E86MT:6]N(&9R82!S97)V97(@
M<.4@9F]R8FEN9&5L<V5N.B``579E;G1E="!R96%K=&EO;B!F<F$@<V5R=F5R
M('#E.B``26MK92!A;F)R86=T`%5N:6-O9&4@*%541BTX*0!&;W)E;F5D92!!
M<F%B:7-K92!%;6ER871E<@!3=&]R8G)I='1A;FEE;@!54T$`55-!<R!U;F1E
M<F]R9&YE9&4@^&5R`$5N:&5D97(`56ME;F1T`%5K96YD="!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+@!5:V5N9'0@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56ME;F1T('-T960@86YG:79E="X`56ME;F1T(&)R=6=E<FYA
M=FX@96QL97(@:V]D96]R9"X`2.9G="!A:W1U96QT(&5L96UE;G0@868N`$EK
M:V4@;F%V;F=I=F5T`%5P<FEV:6QI9V5R961E('-K<FEP=&5R(&MA;B!I:VME
M('1I;&?E(&ML:7!P92]K;W!I+VEN9'/F="!P<F]G<F%M;>9S<VEG="!A9B!S
M:6MK97)H961SY7)S86=E<BX@($ML:6L@3TL@9F]R(&%T('-E(&5N('1E:VYI
M<VL@;F]T92!H;W,@;6]Z:6QL82YO<F<L('-O;2!V:7-E<B!D:6<L(&AV;W)D
M86X@9'4@:V%N('1I;&QA9&4@970@<VMR:7!T(&%T('1I;&?E('5D:VQI<'-H
M;VQD97)E;BX`1F%R=F4@:6MK92!I;F1S=&EL;&5T`%5D=FED9&5L<V4@:6MK
M92!U;F1E<G-T^'1T970`3W!D873I<@!/<&1A=.ER("5S`$]P9&%TZ7(@8G)U
M9V5R`"(E<R(@;W!D871E<F5T+@!/<&=R861E<FEN9W,M9F]R97-K<FEF="!S
M;&5T=&5T+@!5<&QO860`3W!SYG1N:6YG<V9I;&5R('1I;"!A;&QE(&%P<&QI
M:V%T:6]N97(@;&%G="!O<"!PY2!S97)V97(N`%-T;W)E(&QA=&EN<VME(&)O
M9W-T879E<@!3=&]R92!R;VUE<G1A;`!5<G5G=6%Y`$%N=F5N9"!N=7;F<F5N
M9&4Z("5S`$)R=6<@4U-,`$)R=6<@:'9I<R!N879N+VMO9&5O<F0@97(@9F]R
M<VME;&QI9R!F;W(@24U34"US97)V97(N`$)R=6=E<@!"<G5G97(@)7,@:6MK
M92!B96UY;F1I9V5T('1I;"`E<RX`0G)U9V5R+6%D;6EN:7-T<F%T:6]N`$)R
M=6=E<FEN9'-T:6QL:6YG97(`0G)U9V5R+7)E9VES=')E<FEN9P!"<G5G97(M
M<F5G:7-T<F5R:6YG(&5R(&)L979E="!S;.5E="!F<F$@<.4@9&5T=&4@=V5B
M<W1E9"X`0G)U9V5R:V]N=&\@:6MK92!F=6YD970`0G)U9V5R;F%V;@!"<G5G
M97)N879N("(E<R(@9FEN9&5S(&%L;&5R961E+@!"<G5G97)N879N.@!"<G5G
M97)N879N.B``0G)U9V5R92!I('-Y<W1E;65T.@!5<V)E:VES=&%N`%9&4RUK
M871A;&]G(&5K<VES=&5R97(@:6MK92X`1F5R:64`1WEL9&EG92!F=6YD970@
M<W1E9&5R(&EN:VQU9&5R97(Z`$=Y;&1I9VAE9`!6YG)D:2!E<B!M:6YU='1E
M<B!F<F$@;G4N`%;F<F1I(&5R(&UE<F4@96YD(&1E;B!M86MS:6UA;&4@;.9N
M9V1E(&%F("5S+@!6YG)D:65R`%;F<F1I97(L(&1E<B!K86X@=N9L9V5S(&EB
M;&%N9'0`5F%N=6%T=0!3:VEF=&5N9&4`5F5N97IU96QA`$5F=&5R<'+X=FYI
M;F<@9F5J;&5D92`M(&1E<B!E<B!B;&5V970@<&EL;&5T('9E9"!D96YN92!B
M97-K960N`%9E<G-I;VX`5F5R<VEO;G-K;VYT<F]L`$QO9')E="!O<'-T:6QL
M:6YG`$QO9')E="!F;W)R:6YG`$QO9')E=#H`365G970@:/AJ`%9I971N86T`
M5FEE=&YA;65S:7-K("A625-#24DI`%9I<R`E<P!392!PY2!E:W-T97)N('=E
M8G-I9&4`5FES('-O;2`E<P!*;VUF<G7X97(L($)R:71I<VME`$IO;69R=?AE
M<BP@06UE<FEK86YS:V4`4WEN;&EG:&5D`%-Y;FQI9VAE9#H@`%9O9&%F;VYE
M($ET86QI96X@=FEA(%--5%``5T%23@!!1%9!4E-%3"$A(2!&2D523B!30U))
M4%0@34%.545,5"!&4D$@)7,N`%=)3B!V:6$@2%144`!786QL:7,@;V<@1G5T
M=6YA`$%D=F%R<V5L`$]N<P!696IR=61S:6=T`%9E:G)I;F9O<FUA=&EO;B!S
M=&EL;&5T('1I;'+E9&EG:&5D(&%F`%=E871H97(N8V]M`%=E8@!796)S:71E
M`%5G96YT;&EG`%9E;&MO;6UE;@!696QK;VUM96X@=&EL("5S`%9E;&MO;6UE
M;BP@)7,`5F5S=&QI9R`H25-/+3@X-3DM,2D`5F5S=&QI9R`H25-/+3@X-3DM
M,34I`%9E<W1S86AA<F$`2'9I;&ME;B!A<'!L:6MA=&EO;B!S:V%L("5S('9I
M<V4@969T97(@;&]G:6YD/P!(=F%D(&5R('-E<&%R871O<G1E9VYE=#\`2'9A
M9"!E<B!C:71A=&EO;G-T96=N970_`%=H97)E:7,@075S=')A;&EE;BUK;W)T
M`$AV:6QK92!F87-E<@!(=FEL:V4@<&QU9VEN<R!S:V%L(&%K=&EV97)E<R!F
M;W(@4FEC:"!497AT+7;F<FMT^&IE="X`0G)E9&1E`$)R961D92!I($-34RUE
M;FAE9&5R`$)R961D92!A9B`E<RUM96YU96X@=&EL('9E;G-T<F4@*&)L:79E
M<B!A:W1I=F5R970@=F5D(&[F<W1E(&QO9VEN9"DZ`$)R961D92!A9B!T86)E
M;&QE;@!"<F5D9&4M96YH960`0G)E9&1E.@!7:6MI`%9I;F0`0FSF<W0@=&ED
M;&EG=`!6:6YD:&%S=&EG:&5D(&D@:VYO8@!6:6YD.@!6:6YD.B``5FES9&]M
M`-AN<VME;&ES=&4`07)B96ID90!!9')E<W-E("AA<F)E:F1E*0!496QE9F]N
M("AA<F)E:F1E*0!&;W)K97)T(&%N=&%L(&9E;'1E<B!I(&QI;FEE("5D+B!&
M;W)V96YT961E("5D+"!F86YD="`E9"X`1F]R:V5R="!A;G1A;"!F96QT97(N
M($9O<G9E;G1E9&4@)60L(&9A;F1T("5D+@!&;W)K97)T(&9O<G-K>61N:6YG
M("5D('5N9&5R(&EN9&SF<VYI;F<@868@96X@5D93+69I;"X`6"U2968`6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A
M9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@=61V:61D96QS97(`Q<4`Q<7%
MQ0!986AO;R$M:V]R=`#%<FQI9P!996UE;@!*80!*82P@:F5G(&5R(&5N:6<`
M1'4@8F5F:6YD97(@9&EG(&D@5$5+4U0@34]$55,N("!"<G5G(%L\/ETM:VYA
M<'!E;B!T:6P@870@<VMI9G1E('1I;&)A9V4@=&EL(%=94TE764<N`$1U(&AA
M<B!I:VME('1I;&QA9&5L<V4@=&EL(&%T(&]P<F5T=&4@;65R92!E;F0@)60@
M8FQO:VME+@!$=2!E<B!I:VME(.9G=&5T+@!$=2!K86X@:6MK92!H879E("=<
M)RUT96=N970@:2!D:70@9G5L9&4@;F%V;BX`1'4@:6YD=&%S=&5D92!I:VME
M(&5N(&=Y;&1I9R!E+7!O<W0M861R97-S92X`1F]R(&%T(&EM<&]R=&5R92!S
M:V%L(&1U('1I;&]R9&YE(&9E;'1E<B!F<F$@9&5N(&9I;"!D=2!I;7!O<G1E
M<F5R('1I;"!D92!T:6QS=F%R96YD92!F96QT97(@:2`E<RX`1'4@97(@8FQE
M=F5T(&QO9V=E="!U9"X`1'4@<VMA;"!I;F1T87-T92!E="!F=6YG97)E;F1E
M(&UO8FEL;G5M;65R.R!K=6X@8VEF<F4@;65D(&5T('9A;&=F<FD@)RLG(&9O
M<B!D96X@:6YT97)N871I;VYA;"!R971N:6YG<VMO9&4N`$1U('-K86P@:6YD
M=&%S=&4@96X@9WEL9&EG(';F<F1I+@!$=2!S:V%L(&MO;F9I9W5R97)E(&5N
M($1A=&%4<F5E+6)A8VME;F0@9F]R(&%T(&MU;FYE(&%N=F5N9&4@3W!S:W)I
M=FYI;F=E<BX`1'4@<VMA;"!K;VYF:6=U<F5R92!E;F0@5D93+6)A8VME;F0N
M`$1U(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@<')O8FQE;6)E<VMR:79E
M;'-E+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N`$1U('-K86P@:6YD=&%S
M=&4@9&5N(%523"!H=F]R=&EL(&1E;FYE(&CF9W1E('-K86P@:&5N=FES90!$
M=2!S:V%L(';F;&=E(&1E;B!S97)V97(L('-O;2!S:V%L('-L971T97,N`$1U
M('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F:F5R;F4N
M`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F:F5R
M;F4N`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!T
M:6QF^&IE+@!$=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D=2!V
M:6P@;W!D871E<F4N`$1U('-K86P@86YG:79E(&1E;B!H86YD;&EN9RP@<V]M
M('-K86P@=61F^')E<RX`1'4@<VMA;"!A;F=I=F4@970@;GET(&MA=&5G;W)I
M;F%V;BX`1'4@8FQI=F5R(&[X9'0@=&EL(&%T(&%N9VEV92!E="!I=&%L:65N
M<VME('1E;&5F;VYN=6UM97(`1&EN("5S('-E<W-I;VX@97(@=61L^&)E="X@
M3&]G('9E;FQI9W-T(&EN9"!I9V5N+@!$:6X@92UP;W-T+6%D<F5S<V4`1&EN
M($9R;VTZ(&%D<F5S<V4Z`$1I;F4@:6YF;W)M871I;VYE<@!$:6X@26YT97)N
M970M861R97-S92!E<B!S:VEF=&5T('-I9&5N(&)E9WEN9&5L<V5N(&%F(&1I
M;B`E<RUS97-S:6]N+B!&;W(@870@8F5S:WET=&4@9&EN('-I:VME<FAE9"!B
M;&EV97(@9'4@;OAD="!T:6P@870@;&]G9V4@:6YD(&EG96XN`$1I="!N879N
M`$1I;B#F9W1N:6YG<RUB86-K96YD('5N9&5R<W3X='1E<B!I:VME('1I;&;X
M:F5L<V5N(&%F(&)R=6=E<F4N($AV:7,@9'4@^&YS:V5R(&%T(&)R=6=E($AO
M<F1E('1I;"!A="!A9&UI;FES=')E<F4@8G)U9V5R:V]N=&DL(&)L:79E<B!D
M=2!N^&1T('1I;"!A="!B<G5G92!E;B!A;F1E;B#F9W1N:6YG<RUB86-K96YD
M+@!$:6X@875T;W)I<V%T:6]N<RUB86-K96YD('5N9&5R<W3X='1E<B!I:VME
M(&]P;&ES=&YI;F=E;B!A9B!B<G5G97)E(&5L;&5R(&5R(&1E;B!F=6YK=&EO
M;B!A9B!E;B!E;&QE<B!A;F1E;B!G<G5N9"!B;&5V970@<VSE970@9G)A+@!$
M:6X@8G)O=W-E<B!S>6YE<R!A="!VYG)E('-K:69T970@<VED96X@8F5G>6YD
M96QS96X@868@9&EN("5S+7-E<W-I;VXN($9O<B!A="!B97-K>71T92!D:6X@
M<VEK:V5R:&5D+"!S:V%L(&1U(&QO9V=E(&EN9"!I9V5N+@!$:6X@8G)O=W-E
M<B!U;F1E<G-T^'1T97(@:6MK92!D96YN92!F=6YK=&EO;F%L:71E="X`1&EN
M(&)R;W=S97(@=6YD97)S=/AT=&5R(&EK:V4@9&5N;F4@<')I;G0M;75L:6=H
M960N(%1R>6L@0W1R;"]#;VUM86YD("L@4"!F;W(@870@<')I;G1E+@!$:6X@
M86MT=65L;&4@=&ED<WIO;F4Z`$1I;B!F;W)V86QG=&4@:61E;G1I=&5T(&5R
M(.9N9')E="X`1&EN('-T86YD87)D+6ED96YT:71E=#H`1&ET(&9U;&1E(&YA
M=FXZ`$1I="!L;V=I;F0@97(@=61L^&)E="X`1&ET(&YY92!K;V1E;W)D(&9O
M<B`E<R!E<CH@)7,`1&EN92!T:6QV86QG(&5R(&)L979E="!O<&1A=&5R970@
M9F]R('9A<FEG:&5D96X@868@9&5N;F4@<V5S<VEO;BX`1&EN92!T:6QV86QG
M(&5R(&]P9&%T97)E="X`1&ET(&MO9&5O<F0@97(@8FQE=F5T(&YU;'-T:6QL
M970`1&ET(&MO9&5O<F0@97(@8FQE=F5T(&YU;'-T:6QL93L@:V]N=')O;&SI
M<B!D:6X@:6YD8F%K:V4@;V<@;&]G(&EN9"!M960@9&ET(&YY92!K;V1E;W)D
M+@!$:70@:V]D96]R9"!E<B!U9&SX8F5T+@!$:6YE(&9J97)N92!S97)V97)E
M.@!*=6=O<VQA=FEE;@!:8>]R90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6U-K
M:G5L(&-I=&5R970@=&5K<W1=`%M0<F]B;&5M8F5S:W)I=F5L<V5=`%M6:7,@
M8VET97)E="!T96MS="`M`%M6:7,@8VET97)E="!T96MS="`M("5S(&QI;FEE
M<ET`6VQI;FEE("5S('5D(&%F("5S70!!9&UI;FES=')A=&EO;@!#3$D`1&%T
M851R964`4VQE="!RYFMK90!'<G5P<&5R`$AJYFQP`$)I;&QE9"UE9V5N<VMA
M8F5R+BXN`$QO9R!I;F0`3&]G('5D`,9N9')I;F<@:&5N=FES;FEN9RXN+@!)
M;F1S=&EL;&EN9V5R`%1I;&QA9&5L<V5R`%-L970@:&5N=FES;FEN9RXN+@!/
M<'/F=&YI;F<`5&%B96PM96=E;G-K86)E<BXN+@!"<G5G97)E`&%D<F5S<V5K
M87)T;W1E:P!A9')E<W-E;G0@=6ME;F1T`&MA;&5N9&5R`'9I;F1S=&EL;&4`
M:V%N(&EK:V4@9&%N;F4@=61D871A+69I;`!K86X@:6MK92#E8FYE(&EN9&1A
M=&$`:VQI:R!H97(`9F5J;"!V960@86YV96YD96QS92!A9B!K;VUM86YD;RUL
M:6YI90!K;VYF:6=U<F%T:6]N<V9E:FP`;6%N9VQE<B!K<FET:7-K('-Y<W1E
M;69I;`!F96IL(&D@9&%T869O<FUA=`!R961I9V5R`&EN9&=A;F<@:6MK92!F
M=6YD970`9F%L9&5N9&4`9FEL`&9R82`E<R`H)7,I(&UE9"`E<R`E<P!S=&]R
M;69U;&0`:#H`:&@`=6ME;F1T(&UA<VMI;FYA=FX`^&IE8FQI:VME;&EG=`!I
M;F1L96IR970`:6YD9&%T82]U9&1A=&$M9F5J;`!I;G1E<FX@<V]F='=A<F4M
M9F5J;`!L:6YI97)=`&UK:7-O9G,@9F5J;&MO9&4@)60@=6YD97(@9&%N;F5L
M<V4@868@25-/+@!M;0!N879N`&EK:V4@:6UP;&5M96YT97)E=`!E;F1N=2!I
M:VME(&EM<&QE;65N=&5R970`;F]T97-B;&]K`'!R;V-E;G0`=&EL;&%D96QS
M92!NYF=T970`<')I:VME<@!F96IL(&D@<')O=&]K;VP@9G)A(&9J97)N('-I
M9&4`<W1I9V5N9&4`=&IE;F5S=&4@=71I;&?F;F=E;&EG`'9I<R!F;W)S:V5L
M;&4`<VUS,F5M86EL('9I82!(5%10`'-S`'-T86)I;'0`<WES=&5M9F5J;`!O
M<&=A=F5L:7-T90!M:61L97)T:61I9R!F96IL=&EL<W1A;F0`:6YD=&%S="!K
M;V1E;W)D970@=&\@9V%N9V4@9F]R(&%T(&)E:W+F9G1E`'-A;6UE;G-M96QT
M970`=6YA=FYG:79E;@!B<G5G97)V86QG`'9#87)D`'<Z`'=E871H97(N8V]M
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]D85]$2R]H96QP+GAM;```````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,S,C``,3`U,34T,S$P-C$`,#(P,C4V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_>&UL('9E<G-I
M;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+V1A7T1++VAE
M;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,38@:F%N($5X<"`D("TM
M/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\
M=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@
M<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y
M;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@
M;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@
M(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@
M8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN
M97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-
M86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S
M:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O
M<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N
M9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H
M92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B
M;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@
M8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R
M=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E
M('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R
M(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T
M:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I
M9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T
M:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T
M:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E
M;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O
M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O
M=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@
M0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF
M('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A
M<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L
M969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA
M="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A
M;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO
M<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M9&5?1$4O````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8P-P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]D95]$12],0U]-15-304=%4R\`````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#(P
M,S<T`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1E7T1%+TQ#7TU%
M4U-!1T53+VAO<F1E+FUO````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0R-C,T
M,``Q,#4Q-30S,3`V,0`P,C(P-#``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0````"0!P``'````)P\```?"@``''D`
M``````"8H0``#@```)FA```/````J*$```T```"XH0``"````,:A```+````
MSZ$```P```#;H0``!````.BA```8````[:$``!L````&H@``+0```"*B```=
M````4*(``"0```!NH@``*0```).B```9````O:(``"8```#7H@``#````/ZB
M```D````"Z,```\````PHP``"P```$"C```.````3*,```4```!;HP``*```
M`&&C```(````BJ,```H```"3HP``%0```)ZC```2````M*,```L```#'HP``
MA0```-.C```.````6:0```H```!HI```#0```'.D```.````@:0``!$```"0
MI```#0```**D```,````L*0```T```"]I```!@```,ND``"4````TJ0```H`
M``!GI0``#P```'*E```8````@J4```P```";I0``#@```*BE```.````MZ4`
M``@```#&I0``"0```,^E```N````V:4``!H````(I@``,@```".F```X````
M5J8``%0```"/I@``40```.2F``!:````-J<``%<```"1IP``-````.FG```)
M````'J@```T````HJ```#0```#:H```'````1*@```H```!,J```#P```%>H
M```%````9Z@```8```!MJ```$0```'2H```(````AJ@```D```"/J```"0``
M`)FH```E````HZ@``"````#)J```$P```.JH```0````_J@```\````/J0``
M"@```!^I```#````*JD```\````NJ0``%````#ZI```)````4ZD```L```!=
MJ0``#0```&FI```2````=ZD``!D```"*J0``'@```*2I```/````PZD```H`
M``#3J0``"````-ZI```D````YZD``!0````,J@``%@```"&J```(````.*H`
M`$X```!!J@``+0```)"J```9````OJH```<```#8J@``#````."J```L````
M[:H```X````:JP```P```"FK```+````+:L```<````YJP``!P```$&K```%
M````2:L```4```!/JP``"@```%6K```#````8*L``!<```!DJP``"@```'RK
M```/````AZL```X```"7JP``&````*:K```C````OZL```X```#CJP``%```
M`/*K```7````!ZP``!<````?K```%P```#>L```3````3ZP```\```!CK```
M#@```'.L```?````@JP``!T```"BK```!P```,"L```&````R*P```@```#/
MK```#P```-BL```&````Z*P```H```#OK```$P```/JL```+````#JT``!``
M```:K0``%0```"NM```5````0:T```<```!7K0``$````%^M```%````<*T`
M`!4```!VK0``$0```(RM```,````GJT``#L```"KK0``.````.>M```)````
M(*X```<````JK@``%````#*N```#````1ZX```4```!+K@``$````%&N```)
M````8JX``!,```!LK@``.0```("N```2````NJX``"<```#-K@``+````/6N
M```J````(J\``"4```!-KP``"@```'.O```&````?J\```D```"%KP``!P``
M`(^O```O````EZ\``#<```#'KP``+@```/^O``!5````+K```"T```"$L```
M+0```+*P```]````X+```#\````>L0``+0```%ZQ``!`````C+$``",```#-
ML0``(P```/&Q``!`````%;(``"T```!6L@``,P```(2R```E````N+(``!4`
M``#>L@``&0```/2R```I````#K,``"0````XLP``*````%VS```1````AK,`
M``H```"8LP``#````*.S```*````L+,``!````"[LP``%@```,RS```6````
MX[,```<```#ZLP``!P````*T```4````"K0```H````?M```"````"JT```G
M````,[0```@```!;M```!P```&2T```'````;+0```8```!TM```!0```'NT
M```'````@;0```8```")M```"````)"T```I````F;0```X```##M```"@``
M`-*T```$````W;0```<```#BM```"0```.JT```&````]+0``!$```#[M```
M!P````VU```6````%;4```0````LM0``"````#&U```&````.K4```T```!!
MM0``!@```$^U```>````5K4``!$```!UM0``"````(>U```-````D+4```P`
M``">M0``!P```*NU```#````L[4```,```"WM0``%P```+NU```3````T[4`
M`!T```#GM0``"`````6V```$````#K8```@````3M@``"````!RV```K````
M);8``"````!1M@``%0```'*V```&````B+8```8```"/M@``%0```):V```Z
M````K+8``!@```#GM@``(@````"W```S````([<``"X```!7MP``'0```(:W
M```A````I+<``%0```#&MP``0````!NX```I````7+@``!D```"&N```"@``
M`*"X```'````J[@```<```"SN```%0```+NX```.````T;@```H```#@N```
M#P```.NX```-````^[@```\````)N0``#0```!FY```)````)[D``!0````Q
MN0``!@```$:Y```8````3;D``!T```!FN0``$P```(2Y```1````F+D``!0`
M``"JN0``!````+^Y```&````Q+D``!0```#+N0``5````."Y``!D````-;H`
M``0```":N@``#@```)^Z```%````KKH```4```"TN@``&P```+JZ```:````
MUKH``!,```#QN@``$0````6[```1````%[L``!P````INP``*@```$:[```0
M````<;L``"$```""NP``!0```*2[```3````JKL```L```"^NP``$@```,J[
M```*````W;L```\```#HNP``#0```/B[```1````!KP``!,````8O```#```
M`"R\```&````.;P```P```!`O```!@```$V\```7````5+P``!````!LO```
M$0```'V\```(````C[P```4```"8O```#````)Z\```0````J[P```4```"\
MO```#0```,*\```&````T+P```<```#7O```#0```-^\```'````[;P```L`
M``#UO```!P````&]```'````";T```D````1O0``"0```!N]```*````);T`
M`!D````PO0``'0```$J]```,````:+T``!````!UO0``!0```(:]```E````
MC+T``!(```"RO0``$P```,6]```K````V;T``#L````%O@``(````$&^```(
M````8KX``#8```!KO@``(0```**^```0````Q+X```@```#5O@``#````-Z^
M```&````Z[X```0```#RO@``#P```/>^```.````![\```<````6OP``"@``
M`!Z_```-````*;\``!\````WOP``'````%>_```A````=+\``!X```"6OP``
M&0```+6_```>````S[\``!L```#NOP``(0````K````N````+,```"8```!;
MP```'````(+````>````G\```!P```"^P```)@```-O````K`````L$``#,`
M```NP0``)@```&+!```K````B<$``#@```"UP0``'0```.[!```5````#,(`
M`"\````BP@``(````%+"```2````<\(``"D```"&P@``'@```+#"```@````
MS\(``!(```#PP@``H@````/#```6````IL,``",```"]PP``*````.'#```I
M````"L0``"@````TQ```'P```%W$```5````?<0``"````"3Q```)0```+3$
M```H````VL0``"T````#Q0``,````#'%``"2````8L4``"$```#UQ0``%@``
M`!?&```<````+L8``"8```!+Q@``*@```'+&``!!````G<8``$0```#?Q@``
M#````"3'```'````,<<```<````YQP``!@```$''```-````2,<``!````!6
MQP``$@```&?'```3````>L<``!(```".QP``!P```*''```$````J<<``!``
M``"NQP``$````+_'```,````T,<```X```#=QP``#0```.S'```/````^L<`
M`!,````*R```#0```![(```H````+,@```,```!5R```#0```%G(```&````
M9\@``!$```!NR```%P```(#(```;````F,@```X```"TR````@```,/(``!)
M````QL@```4````0R0``$````!;)```/````)\D```0````WR0``#0```#S)
M```.````2LD```,```!9R0``#@```%W)```(````;,D```\```!UR0``#P``
M`(7)```'````E<D```T```"=R0``$````*O)```-````O,D```L```#*R0``
M!@```-;)```+````W<D```P```#IR0``"@```/;)```1`````<H``!D````3
MR@``"P```"W*```-````.<H``"(```!'R@``#P```&K*```;````>LH``#0`
M``"6R@``"@```,O*```8````ULH``!(```#OR@``&0````++```6````',L`
M`"(````SRP``#0```%;+```'````9,L``!0```!LRP``"P```('+```B````
MC<L``"\```"PRP``"P```.#+```)````[,L``!D```#VRP``"P```!#,```7
M````',P``!<````TS```"0```$S,```6````5LP```\```!MS```&0```'W,
M```6````E\P```X```"NS```&````+W,```(````ULP```T```#?S```)@``
M`.W,``!#````%,T```@```!8S0``$@```&'-```?````=,T```@```"4S0``
M"P```)W-```O````J<T```X```#9S0``!0```.C-```&````[LT``$4```#U
MS0```P```#O.```'````/\X```0```!'S@``"@```$S.```*````5\X```\`
M``!BS@``$````'+.```7````@\X``!$```";S@``&0```*W.```7````Q\X`
M``D```#?S@``!0```.G.```+````[\X```H```#[S@```@````;/```%````
M"<\```T````/SP``&P```!W/```7````.<\``!0```!1SP``"0```&;/```.
M````<,\```T```!_SP``$@```(W/```X````H,\``"````#9SP``"````/K/
M```.`````]```'L````2T```&````([0```8````I]```!$```#`T```!P``
M`-+0```%````VM```!@```#@T```'@```/G0```;````&-$``!D````TT0``
M&P```$[1```9````:M$``!,```"$T0``!P```)C1```(````H-$```8```"I
MT0``!@```+#1```0````M]$```\```#(T0``$````-C1```/````Z=$```L`
M``#YT0``#P````72```,````%=(```\````BT@``!P```#+2```&````.M(`
M``P```!!T@``*````$[2```/````=](```@```"'T@``"````)#2```3````
MF=(``!X```"MT@``(0```,S2```@````[M(``!D````/TP``%P```"G3```E
M````0=,``!<```!GTP``%@```'_3```$````EM,``!L```";TP``#0```+?3
M```,````Q=,```,```#2TP``!0```-;3```(````W-,```H```#ETP``#```
M`/#3```+````_=,``!`````)U```#````!K4```.````)]0```L````VU```
M!````$+4```$````1]0``!,```!,U```%````&#4```,````==0```D```""
MU```#@```(S4```+````F]0``!L```"GU```!P```,/4```'````R]0```H`
M``#3U```#0```-[4```)````[-0```0```#VU```!0```/O4```#`````=4`
M`!@````%U0``"@```![5```$````*=4``"8````NU0``#@```%75``!\````
M9-4``!4```#AU0``!0```/?5```'````_=4```P````%U@``"````!+6```*
M````&]8```8````FU@``"````"W6```"````-M8```8````YU@``!@```$#6
M```4````1]8``!````!<U@``#0```&W6```0````>]8``!L```",U@``!```
M`*C6```)````K=8``!````"WU@``"0```,C6```)````TM8```4```#<U@``
M&@```.+6```(````_=8```8````&UP``&0````W7```.````)]<```<````V
MUP``!P```#[7```%````1M<```D```!,UP``"@```%;7```.````8=<```(`
M``!PUP``!@```'/7```+````>M<```T```"&UP``"0```)37```&````GM<`
M`!(```"EUP``"0```+C7```'````PM<``!0```#*UP``'0```-_7``!"````
M_=<``"4```!`V```)0```&;8```&````C-@```H```"3V```!````)[8```)
M````H]@```@```"MV```$0```+;8```)````R-@```8```#2V```#0```-G8
M```&````Y]@```0```#NV```.0```//8```]````+=D``#H```!KV0``'@``
M`*;9```%````Q=D```X```#+V0``!````-K9```&````W]D```<```#FV0``
M(0```.[9```-````$-H``!4````>V@``!@```#3:```$````.]H``!$```!`
MV@``!@```%+:```*````6=H``"(```!DV@``!````(?:```%````C-H``!T`
M``"2V@``#````+#:```.````O=H```H```#,V@``"````-?:```)````X-H`
M``4```#JV@``.@```/#:```P````*]L``#4```!<VP``*0```)+;``!'````
MO-L``#@````$W```*0```#W<```_````9]P``"X```"GW```+0```-;<```?
M````!-T```\````DW0``$@```#3=```+````1]T``"8```!3W0``*0```'K=
M```D````I-T``"8```#)W0``"````/#=```*````^=T```D````$W@``!P``
M``[>```@````%MX``"`````WW@``)@```%C>```*````?]X``!D```"*W@``
M*0```*3>```6````SMX``!(```#EW@``!P```/C>```*`````-\```P````+
MWP``#P```!C?```0````*-\``$`````YWP``<````'K?``!F````Z]\```X`
M``!2X```"0```&'@```*````:^```!(```!VX```$P```(G@```,````G>``
M``8```"JX```#P```+'@```2````P>```!````#4X```$0```.7@```<````
M]^```",````4X0``:@```#CA```/````H^$```4```"SX0``$````+GA```)
M````RN$```0```#4X0``"P```-GA```@````Y>$``!$````&X@``%````!CB
M```,````+>(```P````ZX@``#P```$?B```5````5^(``"D```!MX@``*@``
M`)?B```F````PN(``"<```#IX@``*0```!'C```J````.^,``!D```!FXP``
M0@```(#C```1````P^,``!(```#5XP``$P```.CC```4````_.,```\````1
MY```%@```"'D```7````..0``!````!0Y```$0```&'D```T````<^0``!,`
M``"HY```$@```+SD```U````S^0``!0````%Y0``!P```!KE```,````(N4`
M`"`````OY0``$````%#E```4````8>4``!$```!VY0``%P```(CE```<````
MH.4``!,```"]Y0``%````-'E```:````YN4``!$````!Y@``&@```!/F```>
M````+N8``!H```!-Y@``$P```&CF```5````?.8``!$```"2Y@``%P```*3F
M```4````O.8``!<```#1Y@``%0```.GF```)````_^8``!`````)YP``&0``
M`!KG```$````-.<```<````YYP``"P```$'G```1````3><```8```!?YP``
M!@```&;G```&````;><```4```!TYP``!P```'KG```'````@N<```4```"*
MYP``%@```)#G```&````I^<```8```"NYP``!````+7G```$````NN<```<`
M``"_YP``#@```,?G```,````UN<```P```#CYP``#0```/#G```*````_N<`
M``X````)Z```!0```!CH```H````'N@```X```!'Z```#````%;H```/````
M8^@```H```!SZ```"````'[H```)````A^@``"L```"1Z```!````+WH```(
M````PN@``"8```#+Z```$@```/+H```/````!>D```8````5Z0``"@```!SI
M```'````)^D```@````OZ0``(````#CI```)````6>D``!0```!CZ0``#```
M`'CI```-````A>D```X```"3Z0``%@```*+I```1````N>D```8```#+Z0``
M`P```-+I```&````UND``!D```#=Z0``!P```/?I```$````_^D```L````$
MZ@``"P```!#J```'````'.H```4````DZ@``!P```"KJ```6````,NH```T`
M``!)Z@``#0```%?J```*````9>H``!````!PZ@``#P```('J```1````D>H`
M`!<```"CZ@``"@```+OJ```1````QNH```@```#8Z@``!````.'J```(````
MYNH```\```#OZ@``#P```/_J```+````#^L```D````;ZP``.@```"7K```4
M````8.L```4```!UZP``#````'OK```>````B.L```X```"GZP``$````+;K
M```+````Q^L```P```#3ZP``"0```.#K```'````ZNL```H```#RZP``"0``
M`/WK```.````!^P``!`````6[```&P```"?L```8````0^P``!H```!<[```
M"@```'?L```)````@NP```H```",[```#````)?L```/````I.P```@```"T
M[```!@```+WL```<````Q.P```<```#A[```!0```.GL```+````[^P``$<`
M``#[[```#0```$/M```)````4>T```0```!;[0```P```&#M```3````9.T`
M`!,```!X[0``$P```(SM```*````H.T```(```"K[0``!````*[M```E````
ML^T```,```#9[0``!0```-WM```J````X^T```H````.[@``!0```!GN```$
M````'^X```H````D[@``#0```"_N```&````/>X```@```!$[@``"````$WN
M```$````5NX```4```!;[@``:````&'N```)````RNX```P```#4[@``$```
M`.'N```%````\NX```8```#X[@``&P```/_N```O````&^\``!````!+[P``
M"@```%SO```/````9^\```H```!W[P``"0```(+O```3````C.\``!L```"@
M[P``&````+SO```7````U>\``!\```#M[P``#@````WP```#````'/````<`
M```@\```"````"CP```'````,?````H````Y\```"P```$3P```'````4/``
M`%$```!8\```$````*KP```,````N_````T```#(\```&@```-;P``!*````
M\?```!D````\\0``!@```%;Q```:````7?$``"4```!X\0``!@```)[Q```&
M````I?$``!\```"L\0``!@```,SQ```)````T_$``!@```#=\0``%P```/;Q
M```H````#O(```8````W\@``#0```#[R```B````3/(``%<```!O\@``$P``
M`,?R```C````V_(``!,```#_\@```@```!/S```+````%O,```@````B\P``
M#0```"OS```*````.?,```<```!$\P``%````$SS```&````8?,```@```!H
M\P``#@```''S```'````@/,```H```"(\P``"P```)/S```R````G_,```<`
M``#2\P``#````-KS```-````Y_,``!<```#U\P``#`````WT```)````&O0`
M``D````D]```"@```"[T```'````.?0```D```!!]```!P```$OT```*````
M4_0``!L```!>]```#P```'KT```2````BO0```H```"=]```%@```*CT```)
M````O_0``!````#)]```!P```-KT```2````XO0```0```#U]```!P```/KT
M```%`````O4```4````(]0``"P````[U```4````&O4``!$````O]0``&@``
M`$'U```6````7/4``!0```!S]0``%P```(CU```8````H/4``!P```"Y]0``
M&0```-;U```'````\/4```4```#X]0``#0```/[U```,````#/8```@````9
M]@``%P```"+V```+````.O8```P```!&]@``'P```%/V```:````<_8``!,`
M``".]@``!````*+V```*````I_8```0```"R]@``#0```+?V```,````Q?8`
M``4```#2]@``"0```-CV```%````XO8```<```#H]@``!0```/#V```$````
M]O8```(```#[]@``.````/[V```L````-_<``!(```!D]P``*0```'?W```R
M````H?<```H```#4]P``+````-_W```N````#/@``#,````[^```,P```&_X
M```X````H_@```\```#<^```&````.SX```0````!?D```\````6^0``$P``
M`";Y```5````.OD``!0```!0^0``$@```&7Y```4````>/D``!4```"-^0``
M+0```*/Y```M````T?D``#$```#_^0``+@```#'Z```O````8/H``"P```"0
M^@``8@```+WZ```3````(/L```T````T^P``"````$+[```7````2_L```@`
M``!C^P``#````&S[```K````>?L``"$```"E^P``&@```,?[```)````XOL`
M`$4```#L^P``00```#+\```$````=/P``!,```!Y_```%````(W\```.````
MHOP``!,```"Q_```&````,7\```&````WOP```D```#E_```"@```._\```/
M````^OP```H````*_0``$````!7]```'````)OT```X````N_0``!0```#W]
M```;````0_T```@```!?_0``!@```&C]```4````;_T``!$```"$_0``#@``
M`);]```X````I?T```(```#>_0``!@```.']```.````Z/T```4```#W_0``
M!P```/W]```.````!?X```8````4_@``*````!O^```,````1/X``!P```!1
M_@``!````&[^```-````<_X``"D```"!_@``%P```*O^```?````P_X``%P`
M``#C_@``%````$#_```^````5?\``!\```"4_P``$````+3_```'````Q?\`
M``X```#-_P``#````-S_```,````Z?\``!,```#V_P``"@````H``0`=````
M%0`!`!D````S``$`!0```$T``0`1````4P`!`!$```!E``$`)````'<``0`2
M````G``!`!4```"O``$`$@```,4``0`.````V``!`!D```#G``$`"`````$!
M`0`)````"@$!``T````4`0$`!P```"(!`0`*````*@$!``<````U`0$`#P``
M`#T!`0`&````30$!``L```!4`0$`&@```&`!`0`*````>P$!``<```"&`0$`
M"````(X!`0`%````EP$!`!\```"=`0$`!@```+T!`0`0````Q`$!``@```#5
M`0$`#0```-X!`0`(````[`$!`!X```#U`0$`$@```!0"`0`L````)P(!`!H`
M``!4`@$`"0```&\"`0`*````>0(!`!4```"$`@$`!0```)H"`0`4````H`(!
M``0```"U`@$`$````+H"`0`&````RP(!``<```#2`@$`'@```-H"`0`H````
M^0(!``H````B`P$`'````"T#`0`1````2@,!``L```!<`P$`&@```&@#`0`4
M````@P,!``0```"8`P$`!````)T#`0`+````H@,!``4```"N`P$`!@```+0#
M`0`(````NP,!``8```#$`P$`"@```,L#`0`;````U@,!`#0```#R`P$`-```
M`"<$`0`@````7`0!`"D```!]!`$`(````*<$`0!!````R`0!`!H````*!0$`
M*````"4%`0`I````3@4!`%````!X!0$`(@```,D%`0`&````[`4!``@```#S
M!0$`!0```/P%`0`(`````@8!`!D````+!@$`&0```"4&`0`J````/P8!`",`
M``!J!@$`&0```(X&`0`N````J`8!`#0```#7!@$`"`````P'`0`7````%0<!
M``H````M!P$`!P```#@'`0`A````0`<!`!````!B!P$`#@```','`0`+````
M@@<!``<```".!P$`$P```)8'`0`(````J@<!``L```"S!P$`"@```+\'`0`4
M````R@<!``\```#?!P$`,@```.\'`0`+````(@@!``X````N"`$`!0```#T(
M`0`%````0P@!``4```!)"`$`%P```$\(`0`/````9P@!``0```!W"`$`"@``
M`'P(`0`)````AP@!``L```"1"`$`#0```)T(`0`,````JP@!``X```"X"`$`
M!0```,<(`0`$````S0@!``T```#2"`$`,@```.`(`0!%````$PD!`!<```!9
M"0$`!P```'$)`0`>````>0D!`!0```"8"0$`!0```*T)`0`4````LPD!``8`
M``#("0$`!P```,\)`0`.````UPD!`"H```#F"0$`!@```!$*`0`,````&`H!
M``T````E"@$`$0```#,*`0`+````10H!`#8```!1"@$`"@```(@*`0`B````
MDPH!``L```"V"@$`#P```,(*`0`R````T@H!`"4````%"P$`,````"L+`0`Q
M````7`L!`"T```"."P$`#@```+P+`0`%````RPL!``X```#1"P$`$P```.`+
M`0`2````]`L!``<````'#`$`$0````\,`0`3````(0P!``<````U#`$`%```
M`#T,`0`8````4@P!``<```!K#`$`!0```',,`0`,````>0P!``P```"&#`$`
M$@```),,`0`$````I@P!``<```"K#`$`"@```+,,`0`+````O@P!``P```#*
M#`$`#@```-<,`0`.````Y@P!``4```#U#`$`!0```/L,`0`N`````0T!`"8`
M```P#0$`(P```%<-`0`#````>PT!`!(```!_#0$`!@```)(-`0`>````F0T!
M`!@```"X#0$`)0```-$-`0`-````]PT!``D````%#@$`'P````\.`0`#````
M+PX!``<````S#@$`"@```#L.`0`"````1@X!``P```!)#@$`%0```%8.`0`+
M````;`X!`!D```!X#@$`(````)(.`0`2````LPX!``4```#&#@$`"@```,P.
M`0`5````UPX!`!(```#M#@$`#``````/`0`$````#0\!``D````2#P$`!P``
M`!P/`0`,````)`\!`%(````Q#P$`%P```(0/`0`D````G`\!`!(```#!#P$`
M!P```-0/`0`&````W`\!``X```#C#P$`#````/(/`0`-````_P\!`!4````-
M$`$`$@```",0`0`/````-A`!`!0```!&$`$`"@```%L0`0`;````9A`!`!``
M``""$`$`"P```),0`0!I````GQ`!`!H````)$0$`%P```"01`0`G````/!$!
M`!H```!D$0$`%P```'\1`0`;````EQ$!`!D```"S$0$`'P```,T1`0`3````
M[1$!``@````!$@$`!P````H2`0`(````$A(!``D````;$@$`%0```"42`0`-
M````.Q(!`",```!)$@$`#0```&T2`0`3````>Q(!``@```"/$@$``P```)@2
M`0!&````G!(!`#\```#C$@$`-P```",3`0!7````6Q,!``4```"S$P$`'P``
M`+D3`0`O````V1,!``H````)%`$`"````!04`0`-````'10!`"T````K%`$`
M!````%D4`0!/````7A0!`"4```"N%`$`'````-04`0`+````\10!`!\```#]
M%`$`'0```!T5`0`E````.Q4!`"````!A%0$`)````((5`0`@````IQ4!``L`
M``#(%0$`!P```-05`0`-````W!4!``P```#J%0$`%P```/<5`0`&````#Q8!
M`#D````6%@$`#````%`6`0`'````718!``D```!E%@$`$P```&\6`0`)````
M@Q8!``0```"-%@$`$````)(6`0`(````HQ8!``@```"L%@$`!````+46`0`+
M````NA8!``P```#&%@$`$@```-,6`0`1````YA8!``P```#X%@$`&@````47
M`0`/````(!<!``<````P%P$`#0```#@7`0`4````1A<!``X```!;%P$`#```
M`&H7`0`;````=Q<!`"P```"3%P$`$P```,`7`0`<````U!<!`"@```#Q%P$`
M!@```!H8`0`'````(1@!`!,````I&`$`!0```#T8`0`$````0Q@!`!<```!(
M&`$`"@```&`8`0`,````:Q@!``D```!X&`$`!@```((8`0`)````B1@!``@`
M``"3&`$`"0```)P8`0`*````IA@!`!$```"Q&`$`!@```,,8`0`.````RA@!
M``X```#9&`$`#0```.@8`0`+````]A@!`!T````"&0$`"P```"`9`0`"````
M+!D!`!P````O&0$`!P```$P9`0`&````5!D!`&0```!;&0$`"0```,`9`0`'
M````RAD!`"8```#2&0$`.````/D9`0`:````,AH!`"H```!-&@$`.P```'@:
M`0`H````M!H!`#0```#=&@$`&0```!(;`0`5````+!L!``4```!"&P$`!P``
M`$@;`0`(````4!L!``<```!9&P$`!0```&$;`0`'````9QL!``X```!O&P$`
M"0```'X;`0`&````B!L!``@```"/&P$`"P```)@;`0`'````I!L!``@```"L
M&P$`!P```+4;`0`6````O1L!``D```#4&P$`!@```-X;`0`+````Y1L!`!``
M``#Q&P$`'`````(<`0`4````'QP!``<````T'`$`$0```#P<`0`(````3AP!
M``X```!7'`$`"````&8<`0`0````;QP!``D```"`'`$`$````(H<`0`&````
MFQP!`!D```"B'`$`"@```+P<`0`<````QQP!``<```#D'`$`!0```.P<`0`0
M````\AP!`!0````#'0$`"P```!@=`0`-````)!T!`"@````R'0$`&````%L=
M`0`7````=!T!``0```",'0$`"0```)$=`0`*````FQT!``<```"F'0$``@``
M`*X=`0`.````L1T!``@```#`'0$`(P```,D=`0`?````[1T!`#@````-'@$`
M)@```$8>`0`Q````;1X!`"<```"?'@$`9````,<>`0`4````+!\!`%4```!!
M'P$`.````)<?`0!*````T!\!`%L````;(`$`*````'<@`0`X````H"`!`"@`
M``#9(`$`+`````(A`0`;````+R$!`#X```!+(0$`J0$``(HA`0`C````-",!
M`!<```!8(P$`2````'`C`0"%````N2,!`#`````_)`$`)0```'`D`0!!````
MEB0!`%L```#8)`$`20```#0E`0`Q````?B4!`!T```"P)0$`&````,XE`0`K
M````YR4!`"$````3)@$`'P```#4F`0`K````528!`"8```"!)@$`)P```*@F
M`0`Z````T"8!`!T````+)P$`$0```"DG`0`S````.R<!`"4```!O)P$`)P``
M`)4G`0`@````O2<!`!\```#>)P$`,````/XG`0!I````+R@!`#$```"9*`$`
M00```,LH`0`S````#2D!`"4```!!*0$`/0```&<I`0!E````I2D!`$T````+
M*@$`+P```%DJ`0`N````B2H!`#````"X*@$`5````.DJ`0!:````/BL!`$@`
M``"9*P$`2@```.(K`0`R````+2P!`"\```!@+`$`+````)`L`0`M````O2P!
M`'$```#K+`$`9@```%TM`0!O````Q"T!`+,````T+@$`%P```.@N`0`E````
M`"\!`#(````F+P$`*0```%DO`0`^````@R\!`"(```#"+P$`4@```.4O`0`E
M````.#`!``L```!>,`$`L0```&HP`0!%````'#$!`"$```!B,0$`,````(0Q
M`0`E````M3$!`!P```#;,0$`,0```/@Q`0`'````*C(!``<````R,@$`!```
M`#HR`0`-````/S(!``L```!-,@$`#@```%DR`0`+````:#(!``4```!T,@$`
M$````'HR`0`"````BS(!`%D```".,@$`!0```.@R`0`2````[C(!``0````!
M,P$`!P````8S`0`(````#C,!``4````7,P$`,````!TS`0`#````3C,!`!``
M``!2,P$`#````&,S`0`3````<#,!``T```"$,P$``@```)(S`0`'````E3,!
M``8```"=,P$`%````*0S`0`,````N3,!`!@```#&,P$`!@```-\S`0`2````
MYC,!``P```#Y,P$``P````8T`0`J````"C0!``0````U-`$`!@```#HT`0`'
M````030!`!\```!)-`$`-0```&DT`0`N````GS0!`"\```#.-`$`%P```/XT
M`0`B````%C4!`"4````Y-0$`(````%\U`0`;````@#4!`!@```"<-0$`)```
M`+4U`0`?````VC4!`!H```#Z-0$`(0```!4V`0`@````-S8!`!H```!8-@$`
M,@```',V`0`:````IC8!`"\```#!-@$`*P```/$V`0`?````'3<!`",````]
M-P$`'P```&$W`0`:````@3<!`"$```"<-P$`)0```+XW`0`F````Y#<!`"4`
M```+.`$`)````#$X`0`8````5C@!`!T```!O.`$`)````(TX`0`8````LC@!
M`"(```#+.`$`+````.XX`0`H````&SD!`!4```!$.0$`)0```%HY`0`\````
M@#D!`!\```"].0$`(P```-TY`0`?`````3H!`"`````A.@$`&@```$(Z`0`8
M````73H!`"8```!V.@$`*0```)TZ`0`>````QSH!`"D```#F.@$`'@```!`[
M`0`Q````+SL!``D```!A.P$`#````&L[`0`7````>#L!`"\```"0.P$`)```
M`,`[`0`'````Y3L!``\```#M.P$`%````/T[`0`.````$CP!``T````A/`$`
M)````"\\`0`%````5#P!``<```!:/`$`(@```&(\`0`E````A3P!`!H```"K
M/`$`'0```,8\`0`:````Y#P!``<```#_/`$`QP````<]`0`+````SST!`!4`
M``#;/0$`!@```/$]`0`)````^#T!``L````"/@$`#0````X^`0`7````'#X!
M``8````T/@$`,P```#L^`0`3````;SX!`!,```"#/@$`!P```)<^`0`/````
MGSX!``<```"O/@$`,@```+<^`0`$````ZCX!`"$```#O/@$`$P```!$_`0`,
M````)3\!`!$````R/P$`,@```$0_`0`6````=S\!``@```"./P$`'0```)<_
M`0`)````M3\!``H```"_/P$`%````,H_`0`*````WS\!`!T```#J/P$`"```
M``A``0`?````$4`!``@````Q0`$`&@```#I``0`G````54`!``8```!]0`$`
M%0```(1``0`'````FD`!``@```"B0`$`"0```*M``0`_````M4`!``<```#U
M0`$`#P```/U``0`.````#4$!`!`````<00$`"0```"U!`0`)````-T$!``@`
M``!!00$`$P```$I!`0`'````7D$!`!D```!F00$`"@```(!!`0`7````BT$!
M`!0```"C00$`"@```+A!`0`,````PT$!`!<```#000$`!````.A!`0`J````
M[4$!``P````80@$`$0```"5"`0`'````-T(!``(````_0@$`$````$)"`0`8
M````4T(!``L```!L0@$``P```'A"`0`(````?$(!``8```"%0@$`!P```(Q"
M`0`-````E$(!``L```"B0@$`%````*Y"`0`5````PT(!``X```#90@$`+P``
M`.A"`0`@````&$,!`!P````Y0P$`%0```%9#`0`,````;$,!`#$```!Y0P$`
M!0```*M#`0`2````L4,!`#\```#$0P$`$@````1$`0`*````%T0!``8````B
M1`$`!````"E$`0`$````+D0!``H````S1`$`$P```#Y$`0`%````4D0!``8`
M``!81`$`!@```%]$`0`(````9D0!``0```!O1`$`#````'1$`0`*````@40!
M`#D```",1`$`+@```,9$`0`I````]40!``4````?10$`&````"5%`0`9````
M/D4!`!\```!810$`'0```'A%`0`1````ED4!``(```"H10$`!````*M%`0`*
M````L$4!``8```"[10$`!0```,)%`0`#````R$4!``P```#,10$`10```-E%
M`0`R````'T8!`!H```!21@$`-````&U&`0`H````HD8!`%,```#+1@$`&0``
M`!]'`0!R````.4<!`"````"L1P$`-0```,U'`0`A`````T@!`$4````E2`$`
M,````&M(`0`H````G$@!`"D```#%2`$`)@```.](`0`E````%DD!`"@````\
M20$`*````&5)`0`B````CDD!`"L```"Q20$`,````-U)`0`2````#DH!`!,`
M```A2@$`$````#5*`0!Y````1DH!``D```#`2@$`H0```,I*`0!S````;$L!
M`'P```#@2P$`*P```%U,`0!4````B4P!`!<```#>3`$`)P```/9,`0`6````
M'DT!``\````U30$`%P```$5-`0`?````74T!`$````!]30$`'P```+Y-`0`<
M````WDT!`%$```#[30$`&@```$U.`0`4````:$X!``H```!]3@$`!0```(A.
M`0`&````CDX!``@```"53@$`!0```)Y.`0`2````I$X!`!````"W3@$`$P``
M`,A.`0`=````W$X!``\```#Z3@$`#P````I/`0`$````&D\!``D````?3P$`
M"P```"E/`0`'````-4\!`!0````]3P$`!P```%)/`0`(````6D\!``\```!C
M3P$`"````'-/`0`,````?$\!``\```")3P$`!@```)E/`0`4````H$\!``8`
M``"U3P$`#````+Q/`0`1````R4\!``@```#;3P$`!````.1/`0`9````Z4\!
M`!$````#4`$`"@```!50`0`8````(%`!`!,````Y4`$`'````$U0`0`1````
M:E`!``0```!\4`$`#P```(%0`0`'````D5`!``0```"94`$`&0```)Y0`0`'
M````N%`!``(```#`4`$``@```,-0`0`1````QE`!``D```#84`$`!@```.)0
M`0`2````Z5`!`!<```#\4`$`!@```!11`0`G````&U$!``(```!#40$`!```
M`$91`0`/````2U$!`!,```!;40$`!P```&]1`0`'````=U$!`!$```!_40$`
M!@```)%1`0`8````F%$!``8```"Q40$`$P```+A1`0`0````S%$!`!(```#=
M40$``@```/!1`0`&````\U$!``P```#Z40$`"0````=2`0`1````$5(!`"(`
M```C4@$`!P```$92`0`'````3E(!``L```!64@$`!0```&)2`0`"````:%(!
M``L```!K4@$`6`$``'=2`0`/````T%,!`!,```#@4P$`#@```/13`0`(````
M`U0!``D````,5`$`"@```!94`0`%````(50!`!H````G5`$`'P```$)4`0`R
M````8E0!`#````"55`$`*0```,94`0`H````\%0!`!X````950$`,P```#A5
M`0`,````;%4!`"<```!Y50$`$@```*%5`0`,````M%4!`!````#!50$`!0``
M`-)5`0`A````V%4!`!````#Z50$`$`````M6`0`6````'%8!`!4````S5@$`
M#````$E6`0"%````5E8!`!````#<5@$`"@```.U6`0`2````^%8!`!`````+
M5P$`#@```!Q7`0`,````*U<!``X````X5P$`$0```$=7`0`&````65<!`,$`
M``!@5P$`!P```")8`0`+````*E@!`!H````V6`$`#P```%%8`0`1````85@!
M`!$```!S6`$`"@```(58`0`'````D%@!`"P```"86`$`)````,58`0!5````
MZE@!`&$```!`60$`>0```*)9`0!X````'%H!`'P```"56@$`>P```!);`0!8
M````CEL!`!$```#G6P$`&0```/E;`0`>````$UP!`!`````R7`$`$@```$-<
M`0`8````5EP!``4```!O7`$`!@```'5<`0`2````?%P!``<```"/7`$`#0``
M`)=<`0`-````I5P!`#<```"S7`$`+@```.M<`0`2````&ET!``T````M70$`
M$@```#M=`0`+````3ET!``H```!:70$`&P```&5=`0`;````@5T!`!````"=
M70$`%0```*Y=`0`6````Q%T!`!8```#;70$`'@```/)=`0`>````$5X!`"4`
M```P7@$`$0```%9>`0`/````:%X!`"H```!X7@$`&@```*->`0`?````OEX!
M`!,```#>7@$`>@```/)>`0!"````;5\!`"\```"P7P$`!P```.!?`0`*````
MZ%\!`#````#S7P$`#@```"1@`0`'````,V`!``L````[8`$`"````$=@`0`(
M````4&`!``D```!98`$`"P```&-@`0`,````;V`!``0```!\8`$`%````(%@
M`0`,````EF`!``L```"C8`$`$````*]@`0`9````P&`!`"8```#:8`$`$0``
M``%A`0`:````$V$!`!H````N80$`'@```$EA`0`:````:&$!`!0```"#80$`
M$@```)AA`0`2````JV$!`"<```"^80$`)P```.9A`0`'````#F(!``8````6
M8@$`"````!UB`0`.````)F(!``<````U8@$`"0```#UB`0`3````1V(!``D`
M``!;8@$`#P```&5B`0`5````=6(!`!@```"+8@$`"@```*1B`0`/````KV(!
M``4```"_8@$`%P```,5B`0`+````W6(!``H```#I8@$`2P```/1B`0!%````
M0&,!``L```"&8P$`"````))C`0`5````FV,!``4```"Q8P$`!0```+=C`0`0
M````O6,!``L```#.8P$`%P```-IC`0`N````\F,!`!`````A9`$`/0```#)D
M`0`\````<&0!`#\```"M9`$`/P```.UD`0`)````+64!``8````W90$`"@``
M`#YE`0`*````264!`$$```!490$`/0```)9E`0!`````U&4!`'$````59@$`
M/P```(=F`0!#````QV8!`%,````+9P$`4````%]G`0`_````L&<!`%$```#P
M9P$`,P```$)H`0`W````=F@!`%<```"N:`$`/P````9I`0!#````1FD!`"H`
M``"*:0$`(````+5I`0`<````UFD!`#T```#S:0$`*0```#%J`0`I````6VH!
M`!(```"%:@$`#0```)AJ`0`-````IFH!``L```"T:@$`$````,!J`0`;````
MT6H!`!\```#M:@$`!P````UK`0`'````%6L!`!8````=:P$`"P```#1K`0`(
M````0&L!`"T```!):P$`"@```'=K`0`*````@FL!``<```"-:P$`!@```)5K
M`0`%````G&L!``@```"B:P$`!@```*MK`0`*````LFL!`"T```"]:P$`$@``
M`.MK`0`(````_FL!``0````';`$`"`````QL`0`+````%6P!``0````A;`$`
M#````"9L`0`&````,VP!`!,````Z;`$`!@```$YL`0`(````56P!``4```!>
M;`$`"P```&1L`0`)````<&P!`"D```!Z;`$`$0```*1L`0`)````MFP!`!,`
M``#`;`$`#````-1L`0`'````X6P!``,```#I;`$``P```.UL`0`7````\6P!
M`!<````);0$`-P```"%M`0`(````66T!``D```!B;0$`"@```&QM`0`'````
M=VT!`#H```!_;0$`/````+IM`0`J````]VT!``8````B;@$`"0```"EN`0`8
M````,VX!`$X```!,;@$`+````)MN`0`E````R&X!`%(```#N;@$`-@```$%O
M`0`R````>&\!`#,```"K;P$`D0```-]O`0!C````<7`!`$@```#5<`$`+```
M`!YQ`0`)````2W$!``L```!5<0$`"````&%Q`0`=````:G$!``T```"(<0$`
M#````)9Q`0`3````HW$!``T```"W<0$`$P```,5Q`0`.````V7$!``P```#H
M<0$`%@```/5Q`0`)````#'(!`!P````6<@$`'0```#-R`0`1````47(!`!(`
M``!C<@$`%0```'9R`0`&````C'(!``8```"3<@$`%P```)IR`0"#````LG(!
M`'L````V<P$`!P```+)S`0`3````NG,!``4```#.<P$`!0```-1S`0`?````
MVG,!`!X```#Z<P$`%````!ET`0`7````+G0!`!X```!&=`$`-````&5T`0`O
M````FG0!``\```#*=`$`*````-IT`0`&`````W4!`!@````*=0$`%````"-U
M`0`9````.'4!`!4```!2=0$`%0```&AU`0`1````?G4!``H```"0=0$`$P``
M`)MU`0`1````KW4!``8```#!=0$`"P```,AU`0`'````U'4!``L```#<=0$`
M#@```.AU`0`7````]W4!``D````/=@$`!0```!EV`0`+````'W8!``@````K
M=@$`"````#1V`0`4````/78!``8```!2=@$`!@```%EV`0`,````8'8!``D`
M``!M=@$`$````'=V`0`'````B'8!``4```"0=@$`"````)9V`0`+````GW8!
M``L```"K=@$`&@```+=V`0`K````TG8!`!````#^=@$`$P````]W`0`%````
M(W<!`!P````I=P$`&@```$9W`0`;````87<!`#T```!]=P$`3````+MW`0`H
M````"'@!``@````Q>`$`/0```#IX`0`D````>'@!``\```"=>`$`!@```*UX
M`0`+````M'@!``8```#`>`$`"````,=X`0`;````T'@!`!````#L>`$`"0``
M`/UX`0`*````!WD!``X````2>0$`.0```"%Y`0`Y````6WD!`#L```"5>0$`
M.P```-%Y`0`K````#7H!`"H````Y>@$`+````&1Z`0`J````D7H!`$(```"\
M>@$`+P```/]Z`0`N````+WL!`#````!>>P$`*````(][`0`O````N'L!`#P`
M``#H>P$`0````"5\`0`T````9GP!`#$```";?`$`.0```,U\`0`O````!WT!
M`#(````W?0$`1@```&I]`0`P````L7T!`!\```#B?0$`.@````)^`0`N````
M/7X!`#L```!L?@$`'P```*A^`0#<````R'X!`!\```"E?P$`+@```,5_`0`Q
M````]'\!`#(````F@`$`-0```%F``0`P````CX`!`"X```#`@`$`,0```.^`
M`0`Y````(8$!`#P```!;@0$`1````)B!`0`\````W8$!`,4````:@@$`+P``
M`.""`0`B````$(,!`"\````S@P$`,P```&.#`0`^````EX,!`&0```#6@P$`
M70```#N$`0`.````F80!``0```"HA`$`!0```*V$`0`)````LX0!``X```"]
MA`$`%@```,R$`0`5````XX0!``\```#YA`$`$@````F%`0`(````'(4!``0`
M```EA0$`$0```"J%`0`1````/(4!``T```!.A0$`$````%R%`0`1````;84!
M`!````!_A0$`&````)"%`0`.````J84!`%$```"XA0$`#`````J&`0`4````
M%X8!``8````LA@$`$P```#.&`0`9````1X8!`!X```!AA@$`%0```("&`0`"
M````EH8!`$L```"9A@$`!P```.6&`0`0````[88!`!````#^A@$`!0````^'
M`0`-````%8<!``T````CAP$``P```#&'`0`/````-8<!``@```!%AP$`!@``
M`$Z'`0`1````58<!``@```!GAP$`#0```'"'`0`1````?H<!``T```"0AP$`
M#````)Z'`0`'````JX<!``T```"SAP$`#@```,&'`0`+````T(<!``X```#<
MAP$`(0```.N'`0`-````#8@!``X````;B`$`)@```"J(`0`3````48@!`!<`
M``!EB`$`+0```'V(`0`-````JX@!`!T```"YB`$`$P```->(`0`;````ZX@!
M`!H````'B0$`+@```"*)`0`1````48D!``@```!CB0$`&P```&R)`0`,````
MB(D!`"(```"5B0$`,````+B)`0`+````Z8D!``@```#UB0$`'0```/Z)`0`*
M````'(H!`!4````GB@$`%0```#V*`0`+````4XH!`",```!?B@$`%0```(.*
M`0`?````F8H!`!D```"YB@$`#0```-.*`0`3````X8H!``D```#UB@$`#0``
M`/^*`0`O````#8L!`%$````]BP$`"````(^+`0`7````F(L!`"(```"PBP$`
M#0```-.+`0`0````X8L!`#0```#RBP$`#````">,`0`&````-(P!``8````[
MC`$`3````$*,`0`&````CXP!``<```"6C`$`"@```)Z,`0`0````J8P!`!$`
M``"ZC`$`$0```,R,`0`1````WHP!`!H```#PC`$`'0````N-`0`:````*8T!
M`!@```!$C0$`!P```%V-`0`'````98T!``L```!MC0$`"@```'F-`0`"````
MA(T!``8```"'C0$`#@```(Z-`0`G````G8T!`!X```#%C0$`%P```.2-`0`'
M````_(T!`!`````$C@$`$````!6.`0`4````)HX!`#L````[C@$`)P```'>.
M`0`'````GXX!`!$```"GC@$`EP```+F.`0`9````48\!`",```!KCP$`$0``
M`(^/`0`'````H8\!``8```"ICP$`)@```+"/`0`R````UX\!`#`````*D`$`
M)````#N0`0`D````8)`!`!\```"%D`$`'P```*60`0`'````Q9`!``D```#-
MD`$`"0```->0`0`&````X9`!``\```#HD`$`#@```/B0`0`0````!Y$!``X`
M```8D0$`$P```">1`0`1````.Y$!`!````!-D0$`#@```%Z1`0`)````;9$!
M``H```!WD0$`#````(*1`0`]````CY$!``T```#-D0$`"````-N1`0`0````
MY)$!`",```#UD0$`,P```!F2`0`G````39(!`"8```!UD@$`+P```)R2`0`I
M````S)(!`#8```#VD@$`+````"V3`0`5````6I,!``8```!PDP$`#@```'>3
M`0`&````AI,!`!````"-DP$``P```)Z3`0`$````HI,!``<```"GDP$`$P``
M`*^3`0`5````PY,!`!,```#9DP$`&0```.V3`0`*````!Y0!``X````2E`$`
M"P```"&4`0`'````+90!``4````UE`$`$````#N4`0`2````3)0!``P```!?
ME`$`"0```&R4`0`,````=I0!``\```"#E`$`,0```).4`0`&````Q90!``@`
M``#,E`$`#````-64`0`.````XI0!`!<```#QE`$`"`````F5`0`(````$I4!
M``4````;E0$`(@```"&5`0`,````1)4!``4```!1E0$`*@```%>5`0`0````
M@I4!`'$```"3E0$`$P````66`0`)````&98!``H````CE@$`#0```"Z6`0`+
M````/)8!``T```!(E@$`!0```%:6`0`-````7)8!``(```!JE@$`!@```&V6
M`0`*````=)8!`!<```!_E@$`$@```)>6`0`3````JI8!`!8```"^E@$`,0``
M`-66`0`#````!Y<!``0````+EP$`&0```!"7`0`(````*I<!`!(````SEP$`
M!0```$:7`0`9````3)<!``@```!FEP$`!@```&^7`0`9````=I<!``X```"0
MEP$`"````)^7`0`+````J)<!``4```"TEP$`"0```+J7`0`'````Q)<!`!@`
M``#,EP$``P```.67`0`&````Z9<!``L```#PEP$`#````/R7`0`*````"9@!
M``P````4F`$`%P```"&8`0`(````.9@!``<```!"F`$`$0```$J8`0`C````
M7)@!`%````"`F`$`-@```-&8`0`Z````")D!``<```!#F0$`"@```$N9`0`$
M````5ID!``D```!;F0$`"````&69`0`*````;ID!``D```!YF0$`!@```(.9
M`0`-````BID!``8```"8F0$`!````)^9`0`[````I)D!`#X```#@F0$`/0``
M`!^:`0`F````79H!``4```"$F@$`$````(J:`0`&````FYH!``L```"BF@$`
M#````*Z:`0`9````NYH!`!````#5F@$`&````.::`0`$````_YH!``4````$
MFP$`"P````J;`0`%````%IL!``H````<FP$`'@```">;`0`$````1IL!``L`
M``!+FP$`#````%>;`0`.````9)L!``\```!SFP$`#@```(.;`0`(````DIL!
M``D```";FP$`!0```*6;`0`S````JYL!`#,```#?FP$`/````!.<`0`O````
M4)P!`$X```"`G`$`2````,^<`0`U````&)T!`%8```!.G0$`.P```*6=`0!,
M````X9T!`#`````NG@$`$0```%^>`0`9````<9X!``L```"+G@$`0P```)>>
M`0`O````VYX!`"(````+GP$`+@```"Z?`0`0````79\!`!(```!NGP$`!P``
M`(&?`0`&````B9\!`#$```"0GP$`,0```,*?`0`X````])\!``H````MH`$`
M&P```#B@`0`I````5*`!`!\```!^H`$`$P```)Z@`0`&````LJ`!``H```"Y
MH`$`#````,2@`0`/````T:`!`!D```#AH`$`7P```/N@`0!]````6Z$!`'H`
M``#9H0$`#0```%2B`0`(````8J(!``D```!KH@$`$````'6B`0`1````AJ(!
M``X```"8H@$`!@```*>B`0`7````KJ(!`!4```#&H@$`$P```-RB`0`4````
M\*(!`!L````%HP$`*@```"&C`0"7````3*,!`!$```#DHP$`!@```/:C`0`1
M````_:,!``H````/I`$`"P```!JD`0`-````)J0!`",````TI`$`$P```%BD
M`0`6````;*0!``\```"#I`$`$````).D`0`-````I*0!`!<```"RI`$`+```
M`,JD`0`K````]Z0!`"L````CI0$`*@```$^E`0`V````>J4!`#4```"QI0$`
M'````.>E`0!1````!*8!`!4```!6I@$`%````&RF`0`6````@:8!`!4```"8
MI@$`%@```*ZF`0`6````Q:8!`!4```#<I@$`%0```/*F`0`4````"*<!`#,`
M```=IP$`&````%&G`0`8````:J<!`#L```"#IP$`$@```+^G`0`(````TJ<!
M`!0```#;IP$`(P```/"G`0`4````%*@!`!0````IJ`$`$P```#ZH`0`9````
M4J@!`!8```!LJ`$`%@```(.H`0`;````FJ@!`!D```"VJ`$`%````-"H`0`?
M````Y:@!`"(````%J0$`%0```"BI`0`5````/JD!`!<```!4J0$`%0```&RI
M`0`:````@JD!`!T```"=J0$`&P```+NI`0`8````UZD!``@```#PJ0$`$```
M`/FI`0`8````"JH!``0````CJ@$`!@```"BJ`0`+````+ZH!`!0````[J@$`
M!@```%"J`0`*````5ZH!``8```!BJ@$`!P```&FJ`0`'````<:H!``8```!Y
MJ@$`!0```("J`0`7````AJH!``8```">J@$`"0```*6J`0`$````KZH!``0`
M``"TJ@$`"0```+FJ`0`*````PZH!``D```#.J@$`$````-BJ`0`1````Z:H!
M``H```#[J@$`%0````:K`0`%````'*L!`#4````BJP$`#P```%BK`0`2````
M:*L!`!P```![JP$`#@```)BK`0`,````IZL!``X```"TJP$`20```,.K`0`&
M````#:P!``@````4K`$`(0```!VL`0`.````/ZP!`!,```!.K`$`!@```&*L
M`0`+````::P!``D```!UK`$`!P```'^L`0`$````AZP!``T```",K`$`%P``
M`)JL`0`/````LJP!`!8```#"K`$`%````-FL`0`;````[JP!`!H````*K0$`
M"````"6M`0`&````+JT!``8````UK0$`'0```#RM`0`'````6JT!``4```!B
MK0$`$0```&BM`0`+````>JT!``<```"&K0$`!0```(ZM`0`'````E*T!``8`
M``"<K0$`#0```*.M`0`*````L:T!``X```"\K0$`$P```,NM`0`5````WZT!
M`!0```#UK0$`&P````JN`0`3````)JX!`!4````ZK@$`"````%"N`0`$````
M6:X!``@```!>K@$`$@```&>N`0`2````>JX!``D```"-K@$`"0```)>N`0`9
M````H:X!`!,```"[K@$`!0```,^N`0`1````U:X!`"4```#GK@$`%`````VO
M`0`6````(J\!`!$````YKP$`#0```$NO`0`,````6:\!``D```!FKP$`#P``
M`'"O`0`.````@*\!`!````"/KP$`$````*"O`0`P````L:\!`#````#BKP$`
M+````!.P`0`)````0+`!``<```!*L`$`!P```%*P`0`0````6K`!`!````!K
ML`$``P```'RP`0`(````@+`!`"````")L`$`"````*JP`0`(````L[`!``\`
M``"\L`$`:0```,RP`0`9````-K$!``L```!0L0$`!0```%RQ`0`'````8K$!
M`!H```!JL0$`&@```(6Q`0`3````H+$!``D```"TL0$``@```+ZQ`0`$````
MP;$!`"0```#&L0$`!P```.NQ`0`%````\[$!`"\```#YL0$`"@```"FR`0`%
M````-+(!``<````ZL@$`%0```$*R`0`0````6+(!``8```!IL@$`"````'"R
M`0`)````>;(!``0```"#L@$`!0```(BR`0!T````CK(!``L````#LP$`#@``
M``^S`0`8````'K,!``0````WLP$`#````#RS`0`F````2;,!`#4```!PLP$`
M#@```*:S`0`*````M;,!`!(```#`LP$`"P```-.S`0`)````W[,!`!D```#I
MLP$`*`````.T`0`I````++0!`"@```!6M`$`(````'^T`0`.````H+0!``,`
M``"OM`$`#@```+.T`0`'````PK0!``H```#*M`$`"@```-6T`0`4````X+0!
M``D```#UM`$`6@```/^T`0`<````6K4!``X```!WM0$`#````(:U`0`;````
MD[4!`$P```"OM0$`'0```/RU`0`'````&K8!`"0````BM@$`,````$>V`0`(
M````>+8!``8```"!M@$`(@```(BV`0`%````J[8!``<```"QM@$`*0```+FV
M`0`H````X[8!`#0````,MP$`"````$&W`0`-````2K<!`!X```!8MP$`8@``
M`'>W`0`8````VK<!`!8```#SMP$`%0````JX`0`"````(+@!``P````CN`$`
M!0```#"X`0`.````-K@!``X```!%N`$`!P```%2X`0`/````7+@!``8```!L
MN`$`"````'.X`0`.````?+@!``D```"+N`$`"@```)6X`0`*````H+@!`#<`
M``"KN`$`!P```..X`0`2````Z[@!`!,```#^N`$`'@```!*Y`0`2````,;D!
M``H```!$N0$`"@```$^Y`0`+````6KD!``D```!FN0$`"@```'"Y`0`)````
M>[D!``@```"%N0$`'P```(ZY`0`1````KKD!``\```#`N0$`"@```-"Y`0`*
M````V[D!``L```#FN0$`$0```/*Y`0`%````!+H!`!D````*N@$`!````"2Z
M`0`'````*;H!``4````QN@$`!0```#>Z`0`+````/;H!`!@```!)N@$`$@``
M`&*Z`0`9````=;H!`!L```"/N@$`(@```*NZ`0`6````SKH!`!<```#EN@$`
M$@```/VZ`0`6````$+L!``@````GNP$``P```#"[`0`-````-+L!``X```!"
MNP$`!P```%&[`0`=````6;L!``H```!WNP$`#@```(*[`0`F````D;L!`"L`
M``"XNP$`%@```.2[`0`+````^[L!``L````'O`$`!@```!.\`0`0````&KP!
M`!4````KO`$`!P```$&\`0`)````2;P!``4```!3O`$`!P```%F\`0`&````
M8;P!``0```!HO`$`!````&V\`0!`````<KP!`#H```"SO`$`%````.Z\`0`S
M`````[T!`#L````WO0$`$0```'.]`0!,````A;T!`#H```#2O0$`2P````V^
M`0!+````6;X!`%$```"EO@$`%P```/>^`0`9````#[\!`!<````IOP$`%0``
M`$&_`0`=````5[\!`!,```!UOP$`&@```(F_`0`4````I+\!`!<```"YOP$`
M'````-&_`0`W````[K\!`#<````FP`$`.P```%[``0`X````FL`!`#D```#3
MP`$`-@````W!`0!U````1,$!`",```"ZP0$`*0```-[!`0`,````",(!`!P`
M```5P@$`#````#+"`0`4````/\(!`#0```!4P@$`+````(G"`0`P````ML(!
M``L```#GP@$`7````//"`0!6````4,,!``4```"GPP$`&0```*W#`0`6````
MQ\,!``P```#>PP$`%````.O#`0`2`````,0!``@````3Q`$`"@```!S$`0`)
M````)\0!`!`````QQ`$`#P```$+$`0`4````4L0!`!````!GQ`$`$@```'C$
M`0`'````B\0!`"4```"3Q`$`"````+G$`0`$````PL0!`!(```#'Q`$`$@``
M`-K$`0`1````[<0!`"\```#_Q`$``@```"_%`0`&````,L4!``\````YQ0$`
M"0```$G%`0`'````4\4!`!P```!;Q0$`!````'C%`0`[````?<4!``X```"Y
MQ0$`&````,C%`0`$````X<4!``T```#FQ0$`+P```/3%`0`9````),8!`"``
M```^Q@$`7@```%_&`0`7````OL8!`$<```#6Q@$`*0```!['`0`-````2,<!
M``T```!6QP$`%````&3'`0`1````><<!``P```"+QP$`%@```)C'`0`,````
MK\<!`!T```"\QP$`%@```-K'`0`(````\<<!`!0```#ZQP$`#@````_(`0`J
M````'L@!`!(```!)R`$`&0```%S(`0`8````=L@!`!H```"/R`$`*P```*K(
M`0`(````UL@!``D```#?R`$`&0```.G(`0`1`````\D!`!,````5R0$`$@``
M`"G)`0`9````/,D!`!$```!6R0$`%````&C)`0`;````?<D!``H```"9R0$`
M#````*3)`0`(````L<D!``4```"ZR0$`(0```,#)`0`&````XLD!``\```#I
MR0$`"````/G)`0`1`````LH!``@````4R@$`'@```!W*`0`1````/,H!`#D`
M``!.R@$`&````(C*`0`)````H<H!``H```"KR@$`(@```+;*`0`(````V<H!
M`!\```#BR@$`!`````++`0`<````!\L!``@````DRP$`!P```"W+`0`<````
M-<L!`#````!2RP$`!@```(/+`0`@````BLL!`!(```"KRP$`!@```+[+`0`0
M````Q<L!`!,```#6RP$`!````.K+`0`)````[\L!``L```#YRP$`!P````7,
M`0`%````#<P!``@````3S`$`!0```!S,`0`+````(LP!`!\````NS`$`/@``
M`$[,`0!,````C<P!`"<```#:S`$`-@````+-`0`G````.<T!`%4```!AS0$`
M)P```+?-`0`W````W\T!`#<````7S@$`BP```$_.`0`H````V\X!``4````$
MSP$`!P````K/`0`(````$L\!``@````;SP$`&P```"3/`0`=````0,\!`"H`
M``!>SP$`*@```(G/`0`F````M,\!`$````#;SP$`1@```!S0`0`)````8]`!
M`!<```!MT`$`"P```(70`0`(````D=`!`#@```":T`$`%@```-/0`0`0````
MZM`!`!(```#[T`$`"`````[1`0`3````%]$!``@````KT0$`#0```#31`0`6
M````0M$!`"<```!9T0$`*````('1`0!#````JM$!``L```#NT0$`'0```/K1
M`0`%````&-(!``<````>T@$`&````";2`0`C````/](!``P```!CT@$`!0``
M`'#2`0`*````=M(!``P```"!T@$`#````([2`0`+````F](!`!H```"GT@$`
M"@```,+2`0`*````S=(!``4```#8T@$`$0```-[2`0!)````\-(!`%T````Z
MTP$`'@```)C3`0`,````M],!`"8```#$TP$`'````.O3`0`2````"-0!`!,`
M```;U`$`#0```"_4`0`+````/=0!`!````!)U`$`+0```%K4`0`)````B-0!
M``T```"2U`$`#@```*#4`0`6````K]0!``P```#&U`$`/@```-/4`0`(````
M$M4!`"D````;U0$`$````$75`0`4````5M4!`$4```!KU0$`,P```+'5`0`W
M````Y=4!`#0````=U@$`,````%+6`0`0````@]8!``P```"4U@$`%0```*'6
M`0`>````M]8!`!<```#6U@$`"@```.[6`0`7````^=8!`!X````1UP$`!P``
M`##7`0`:````.-<!`!P```!3UP$`!@```'#7`0`&````=]<!`!(```!^UP$`
M#````)'7`0`7````GM<!``4```"VUP$`"````+S7`0`.````Q=<!`!$```#4
MUP$`$@```.;7`0`3````^=<!`!,````-V`$`!P```"'8`0`&````*=@!`"@`
M```PV`$`&P```%G8`0`:````==@!``<```"0V`$`%0```)C8`0`&````KM@!
M`",```"UV`$`(P```-G8`0`K````_=@!``L````IV0$`"0```#79`0`C````
M/]D!``,```!CV0$`!@```&?9`0`*````;MD!``(```!YV0$`#````'S9`0`5
M````B=D!``L```"?V0$`&0```*O9`0`@````Q=D!`!<```#FV0$`!0```/[9
M`0`*````!-H!`!4````/V@$`$@```"7:`0`-````.-H!``D```!&V@$`#@``
M`%#:`0`,````7]H!`!<```!LV@$`6````(3:`0`=````W=H!`#0```#[V@$`
M%````##;`0`,````1=L!``4```!2VP$`#0```%C;`0`1````9ML!``\```!X
MVP$`(````(C;`0`8````J=L!`!````#"VP$`(@```-/;`0`.````]ML!`"8`
M```%W`$`$````"S<`0`0````/=P!`)$```!.W`$`(@```.#<`0`<`````]T!
M`#$````@W0$`(````%+=`0`:````<]T!`"P```".W0$`&@```+O=`0`C````
MUMT!`!D```#ZW0$`#P```!3>`0`'````)-X!``@````LW@$`"0```#7>`0`6
M````/]X!``P```!6W@$`*@```&/>`0`2````CMX!`!8```"AW@$`"0```+C>
M`0`,````PMX!`'L```#/W@$`5````$O?`0!%````H-\!`'````#FWP$`#0``
M`%?@`0`E````9>`!`"P```"+X`$`"@```+C@`0`'````P^`!`!4```#+X`$`
M0@```.'@`0`&````).$!`%0````KX0$`,````(#A`0`B````L>$!`!(```#4
MX0$`)0```.?A`0`J````#>(!`"\````XX@$`*0```&CB`0`O````DN(!`"4`
M``#"X@$`%0```.CB`0`'````_N(!``P````&XP$`#@```!/C`0`7````(N,!
M``L````ZXP$`/0```$;C`0`,````A.,!``P```"1XP$`"````)[C`0`3````
MI^,!``@```"[XP$`!0```,3C`0`=````RN,!``@```#HXP$`"0```/'C`0`&
M````^^,!``T````"Y`$`#0```!#D`0`2````'N0!`!0````QY`$`#````$;D
M`0`8````4^0!``T```!LY`$`"````'KD`0`1````@^0!`!X```"5Y`$`$```
M`+3D`0`)````Q>0!`!H```#/Y`$`+````.KD`0`3````%^4!`"T````KY0$`
M+0```%GE`0`-````A^4!``<```"5Y0$`"````)WE`0`'````IN4!``0```"N
MY0$`%0```+/E`0`,````R>4!``T```#6Y0$`#````.3E`0`%````\>4!``D`
M``#WY0$`"`````'F`0`)````"N8!``D````4Y@$`&````![F`0`&````-^8!
M``X````^Y@$`!@```$WF`0`/````5.8!``P```!DY@$`(````''F`0`*````
MDN8!``(```"=Y@$`)0```*#F`0`'````QN8!``H```#.Y@$`B@```-GF`0`,
M````9.<!``8```!QYP$`(P```'CG`0`T````G.<!`"````#1YP$`(````/+G
M`0!7````$^@!`#$```!KZ`$`-````)WH`0`C````TN@!`"````#VZ`$`!0``
M`!?I`0`/````'>D!``T````MZ0$`#P```#OI`0`&````2^D!``T```!2Z0$`
M$P```&#I`0`/````=.D!``\```"$Z0$`$0```)3I`0`,````IND!``<```"S
MZ0$`!P```+OI`0`(````P^D!`!8```#,Z0$`"0```./I`0`(````[>D!``<`
M``#VZ0$`'````/[I`0`=````&^H!`!D````YZ@$`"````%/J`0`3````7.H!
M``@```!PZ@$`#0```'GJ`0`)````A^H!`!4```"1Z@$`!P```*?J`0`5````
MK^H!``8```#%Z@$`&P```,SJ`0`-````Z.H!`!P```#VZ@$`!0```!/K`0`(
M````&>L!``T````BZP$`'P```##K`0`*````4.L!``P```!;ZP$`*0```&CK
M`0`<````DNL!`!(```"OZP$`!````,+K`0`(````Q^L!``L```#0ZP$`"0``
M`-SK`0`"````YNL!`!8```#IZP$`"`````#L`0`F````">P!`"8````P[`$`
M/@```%?L`0`O````ENP!`#0```#&[`$`.@```/OL`0!O````-NT!``D```"F
M[0$`;````+#M`0`[````'>X!`%,```!9[@$`<@```*WN`0`I````(.\!`$<`
M``!*[P$`+P```)+O`0`Q````PN\!`!\```#T[P$`/@```!3P`0#H`0``4_`!
M`"(````\\@$`"0```%_R`0!)````:?(!`*@```"S\@$`*P```%SS`0`U````
MB/,!`$,```"^\P$`=@````+T`0!(````>?0!`$(```#"]`$`%`````7U`0`*
M````&O4!`#T````E]0$`'P```&/U`0`B````@_4!`#````"F]0$`*@```-?U
M`0`I`````O8!`%`````L]@$`$@```'WV`0`(````D/8!`$@```"9]@$`-P``
M`.+V`0`J````&O<!`"<```!%]P$`)@```&WW`0`K````E/<!`&@```#`]P$`
M0P```"GX`0!&````;?@!`$(```"T^`$`.P```/?X`0!0````,_D!`&T```"$
M^0$`6````/+Y`0!!````2_H!`#T```"-^@$`0````,OZ`0!F````#/L!`'@`
M``!S^P$`<````.S[`0!P````7?P!`#@```#._`$`+@````?]`0`N````-OT!
M`#````!E_0$`@P```);]`0!X````&OX!`'\```"3_@$`U0```!/_`0`:````
MZ?\!`"P````$``(`-@```#$``@`K````:``"`%@```"4``(`+0```.T``@!7
M````&P$"`"H```!S`0(`#````)X!`@#`````JP$"`%T```!L`@(`(P```,H"
M`@`X````[@("`"<````G`P(`(````$\#`@!#````<`,"``8```"T`P(`!P``
M`+L#`@`$````PP,"``T```#(`P(`"@```-8#`@`+````X0,"``L```#M`P(`
M!0```/D#`@`0````_P,"``(````0!`(`7P```!,$`@`%````<P0"`!P```!Y
M!`(`!````)8$`@`'````FP0"``8```"C!`(`!0```*H$`@`Z````L`0"``0`
M``#K!`(`%P```/`$`@`-````"`4"`!,````6!0(`$````"H%`@`"````.P4"
M``@````^!0(`!@```$<%`@`5````3@4"``P```!D!0(`%P```'$%`@`&````
MB04"``X```"0!0(`"@```)\%`@`(````J@4"`"X```"S!0(`"````.(%`@`&
M````ZP4"``<```#R!0(`.````/H%`@!<````,P8"`$@```"0!@(`20```-D&
M`@`R````(P<"`#````!6!P(`,P```(<'`@`X````NP<"`"\```#T!P(`*@``
M`"0(`@`V````3P@"`#$```"&"`(`*P```+@(`@`V````Y`@"`"T````;"0(`
M+0```$D)`@!"````=PD"`"0```"Z"0(`/P```-\)`@`Z````'PH"`#$```!:
M"@(`-0```(P*`@`P````P@H"`"L```#S"@(`-@```!\+`@`R````5@L"`#8`
M``")"P(`-0```,`+`@`K````]@L"`"T````B#`(`,````%`,`@`[````@0P"
M`"L```"]#`(`*````.D,`@!&````$@T"`$(```!9#0(`)P```)P-`@`T````
MQ`T"`$\```#Y#0(`,@```$D.`@`V````?`X"`#$```"S#@(`,@```.4.`@`L
M````&`\"`"D```!%#P(`+@```&\/`@!'````G@\"`#,```#F#P(`1@```!H0
M`@`O````81`"`&````"1$`(`#0```/(0`@`<`````!$"`"(````=$0(`00``
M`$`1`@`E````@A$"`!````"H$0(`#P```+D1`@`<````R1$"`!8```#F$0(`
M$@```/T1`@`D````$!("``D````U$@(`"0```#\2`@`E````21("`"@```!O
M$@(`)P```)@2`@`G````P!("`"0```#H$@(`"0````T3`@`#`0``%Q,"`!(`
M```;%`(`'0```"X4`@`.````3!0"`!````!;%`(`%@```&P4`@`8````@Q0"
M`!\```"<%`(`"0```+P4`@!.````QA0"`!H````5%0(`$P```#`5`@`'````
M1!4"`!4```!,%0(`#````&(5`@!9````;Q4"``@```#)%0(`*0```-(5`@`2
M````_!4"`!4````/%@(`%0```"46`@`^````.Q8"`!P```!Z%@(`#````)<6
M`@`H````I!8"``T```#-%@(`#@```-L6`@`5````ZA8"``H`````%P(`)```
M``L7`@`+````,!<"`!D````\%P(`"@```%87`@`=````81<"`"T```!_%P(`
M!0```*T7`@`G````LQ<"``<```#;%P(`!P```.,7`@`)````ZQ<"`$P```#U
M%P(`!P```$(8`@`1````2A@"``L```!<&`(`%P```&@8`@`)````@!@"``D`
M``"*&`(`!P```)08`@`6````G!@"``L```"S&`(`'@```+\8`@`/````WA@"
M`!@```#N&`(`'`````<9`@`%````)!D"``<````J&0(`&0```#(9`@`'````
M3!D"`#$```!4&0(`#0```(89`@`1````E!D"``<```"F&0(``@```*X9`@`0
M````L1D"``\```#"&0(`"P```-(9`@`#````WAD"``<```#B&0(`"P```.H9
M`@`*````]AD"`!$````!&@(`#@```!,:`@`;````(AH"`!P````^&@(`"@``
M`%L:`@`V````9AH"`"0```"=&@(`*@```,(:`@`7````[1H"``T````%&P(`
M/@```!,;`@`&````4AL"`!<```!9&P(`0````'$;`@`.````LAL"``<```#!
M&P(`!P```,D;`@`$````T1L"``0```#6&P(`"0```-L;`@`>````Y1L"``4`
M```$'`(`!@````H<`@`(````$1P"``P````:'`(`!@```"<<`@`4````+AP"
M`!0```!#'`(`0````%@<`@`T````F1P"`"X```#.'`(`#````/T<`@`>````
M"AT"`"$````I'0(`+P```$L=`@`I````>QT"`!0```"E'0(``@```+H=`@`$
M````O1T"``P```#"'0(`"````,\=`@`%````V!T"``(```#>'0(`$0```.$=
M`@!A````\QT"`"X```!5'@(`&@```(0>`@`Z````GQX"`#$```#:'@(`7@``
M``P?`@`6````:Q\"`'T```""'P(`*0`````@`@!6````*B`"`"D```"!(`(`
M0````*L@`@`^````["`"`#4````K(0(`3````&$A`@`U````KB$"`#<```#D
M(0(`.0```!PB`@`?````5B("`"X```!V(@(`,@```*4B`@!`````V"("`!,`
M```9(P(`$@```"TC`@`,````0","`(D```!-(P(`"````-<C`@#&````X","
M`'$```"G)`(`BP```!DE`@`M````I24"`&4```#3)0(`%P```#DF`@`F````
M428"`!<```!X)@(`%P```)`F`@`:````J"8"`"0```##)@(`0P```.@F`@`F
M````+"<"`"````!3)P(`=P```'0G`@`<````["<"``P````)*`(`"P```!8H
M`@`%````(B@"``8````H*`(`"````"\H`@`%````."@"`!8````^*`(`$```
M`%4H`@`5````9B@"`"````!\*`(`$0```)TH`@`/````KR@"``T```"_*`(`
M"0```,TH`@`.````UR@"``@```#F*`(`%0```.\H`@`)````!2D"``D````/
M*0(`$P```!DI`@`.````+2D"``<````\*0(`$@```$0I`@`.````5RD"`!D`
M``!F*0(`"0```(`I`@`*````BBD"`!(```"5*0(`"````*@I`@`)````L2D"
M`"D```"[*0(`(@```.4I`@`0````""H"`"4````9*@(`%````#\J`@`;````
M5"H"`!$```!P*@(`"@```((J`@`6````C2H"``<```"D*@(`!0```*PJ`@`5
M````LBH"``0```#(*@(``@```,TJ`@`"````T"H"`!(```#3*@(`!@```.8J
M`@`&````[2H"`!(```#T*@(`%P````<K`@`'````'RL"`#H````G*P(``@``
M`&(K`@`$````92L"`!,```!J*P(`&````'XK`@`*````ERL"``<```"B*P(`
M$@```*HK`@`%````O2L"`!D```##*P(`"````-TK`@`7````YBL"`!4```#^
M*P(`$P```!0L`@`"````*"P"``X````K+`(`#````#HL`@`-````1RP"`!8`
M``!5+`(`.@```&PL`@`'````IRP"``D```"O+`(`$0```+DL`@`%````RRP"
M``(```#1+`(`"P```-0L`@`!````7P<``#`````O!@``(`4```````#`!```
MK@8``!X`````````&`<``.@!``#.!```E`4``"T"````````EP$``+,%````
M``````````````!N!```80(``"D$``#,`````````"`#``"<!````````"$`
M````````VP(```````"A`@``>P$``*(#```J``````````````";!```````
M`-8!``!E!@``:P$``!\!``"6`P```````,<#``">`@``;`$``(4'```H````
M*`(``((!``#]`P```````'T'````````1P(``#<%`````````````!\'````
M`````````,$#``!%!````````'@$``!-````Z@8``$<!``!>`0``3@8``#P"
M``"V`@``IP(```````!3`0``30(````````?`@``>P<``(4"``"H`@``````
M`!P!``"`!`````````X!``!"```````````````F!0```````,T```#]`@``
M,P```&$&``#6`P``IP0``)<%``!A`0````````````![!```[0(```$$``!L
M`@````````D'````````X0$`````````````<0```,,!````````K08``'@#
M`````````````'$%````````-00``&L&``#&````D`$``!($``#V`P``3@$`
M`'<"``!6`@```````#$``````````````*8`````````#0$``,T&```$````
M=@4``'X&````````JP8``.\&````````(`0``````````````````#0```#K
M!```NP4``+$%``#3````)P```!T$````````7@0``.L"``!C!```N`,`````
M``#7`@````````````#4`P``!P0``````````````````,P&```R`@``````
M`-H#``#Y`0```````/L"```:`@```````!`'````````<P(``%8```#X`P``
MQ`,``+<%``#!!0``NP$``.`$``"5!0``:00``-8%``!2!P```````'<!```*
M````6`<```````!=`0``S@$``$L```#M!@``A`$``,`#``#8`0```````(H&
M````````T`0``%\!``#"````O@8```````##!0``9P8``&(```#Y`P``3P$`
M`"P"```L!```=@8``&<%``!=````;P,``%0%````````LP$```0'``#J!```
M````````````````,P8````````````````````````B`P``PP,``)X```#&
M`@``X0,`````````````E`8```<#``"_````BP(```````"U!0```````.`&
M```=`P``$@,``'('````````N`8```````"'````Q@$``+,&``#Q!```D`,`
M``````!V`0``,00``%8%`````````````",%``"B````&@0```````!>`@``
M/0,``-4%``"C`@```````)X#``!J!```#`4``-X&````````(````"H$``#,
M`0``3`8``+H$```E!@``1P<``+0$``"``P```````)4#``#3`@``7P,``#X#
M``#9`0``F@$```````!\!@```````'````#D!0````````````#U!@``````
M`(\!```/`P``Y@4``.`#``!,!P``G`4``'D$``#Z````9`$``$4&````````
M(00``#0%``".````)`8```````"X`@``3P8```````#>````2`<``+P!``"+
M`0``<0<``/0#```^!```)P0``",!``!I````M0```!(`````````JP4`````
M``"T`@``<@```/<!``!]`````@8``!$'``"+``````````$#``"4````S@(`
M``````"=`0``(0<``+T#``!W!@``4`<``',&`````````````*T#``""!0``
M````````````````/0(``&H!``!4!P``@@(``*X!``";!@``'@(``#$!```Z
M!@``H04`````````````'0$``%````"\!@``]P8``*X$`````````````,L`
M````````F0,```````#B!@``WP```,X&``#C````^````#0!```"`0``,@0`
M`$H```"J`P``?P$```````#S``````````````#<!0``3P```&<'``!$!P``
M<@$``*,$``"D````,@<``(@%``#``0``;0<```````"O`0````````4&````
M````+P```/P"````````=`$```````#@`0````````````#C`@````````L&
M```1`0``$@<``.$$``!;````_@$``",$```/````"04``)`````E!0``````
M```````,!```6P8``$L&``"-!@```````%8!````````X@4``"D%``"7!```
M_P4``-(``````````````'L&````````$@$``#@"``#X!@``P@$``%,"``#X
M!0``S04``)`'``"A``````````````"P`P``K`8``),%``"D`P``O@4``&D&
M````````[P,```````"#!@``T@(``&\````&`0``0@,``!T'``"2!@``````
M````````````.`,``(P```!#`0``3@```%\%``!-`0```````%@$````````
MV`(``+$```!A`P``/P0``$8!``#!!@``7`<``-T```"?!````````"0````,
M`0``A`,``.@$``"$!@``.@$``+0%```1````%@0``-X$````````-0$``-`!
M``"[`@```````#D```#%!``````````````4!```#0<``$X'``!5!P``OP,`
M`"X"````````)P,``&H"``"@!```VP,``"("````````Q@4``.0````+`P``
M>0$``,H&``!L!@```````/(#``!2!```Y0(``#H#``!%`0``Z````,H$````
M````3P(``'4#````````@@0```````!9`@``CP0``.(``````````````)(%
M``"C`P``/P4``*<%``"^`0``_@4```````"^`P``+0,``$@&``#=!0``DP(`
M`&('```$`@``,@8```H#```K!0``K@(``%`"```'!@``,P<``.`%```V!@``
M`````'0```"2!```]@$``````````@````````````#^````V`8``.\````]
M!0``C`0``'$#``!P!@````````````#W````8P(``!<!``!$`0``B`0`````
M``"]!```-@```"P#``#^!```3P4```````!#!0``7`,``(,#``#9!@``&@4`
M`#\!``!L!```%@<`````````````@`<```````!S!P``Z`(```````#V````
M/P(``%`$```J`0``D0,```D$``#L`@``QP8``-4!```,`@``AP4``"X$```$
M!```X@0``.X&`````````````'T#`````````0$``!X%``")`P``!00``-$"
M```X!@``3@,``-\#``!3````<P0```D#```C`P``Z08`````````````;@,`
M`)(#````````4P4```````!4````/08``&\"```D`P```````)T"```B!P``
M`````!,'``!\`0``6````.0&``![````*@4``&L$``#*`@````````````"C
M!@``G0```%<!````````B04``!0%``!U!@``!@,``"4"```X````7`4`````
M```M````CP<``"8"````````)@$``&@`````````Y0,``%4````S!0``*`$`
M`````````````````$L$````````$`4``/D%````````<`4``#4%````````
M`````$4`````````B00``#L'``#Q`P``708``!D$`````````````"T'````
M````B@```+8```#@`````````'@&`````````````&D%```+`0```````!$"
M``````````````````#K`0``FP```-,#``#C`P````````````"Q`@``:0(`
M`)8$````````0`<```````!A!```&0,````````*!P``W`````````#8!```
M^P0```````!:`@```````&@$``"%!```T`8``,\%``"T````*P0```````"+
M`P``:@<``+<```#M````L@4```8&```:`````````$P```!R!```S00``,4#
M``!:`P```````#8"`````````````*<!```"`````````*L$````````````
M``````#G`P``604``"H#``!/`P``)0<``-X!````!0``]04``$<#``!@````
M`````+`&```6`````````````````````````#P```#\````K00``#D$``#5
M`@``P0(``/,&```>`P``C0```*4#``!.`@```````&8%````````6P,``-H%
M````````@P(```````!2`P``]`8``*X#``#5````T0````````#F!@``@P``
M`-L$```-!```8@(``"0%``!E!P``[00``/@$``!7`@``,08``,8&``!?!```
MR0$``'$&````````2`0```````"$````H@0```,"``"U!@``6`,``+T```"5
M`0``H@8```````````````````````"%````AP8``%`!````````````````
M``#^`@```````(H!``#B`P```````#H%``#Q`@``$P$``(@!```>!@``````
M`+(````;!@``;0$``(,!````````E@```.<$```^`0``?@$``(\"``#(`@``
MOP0``%H'````````3`(``!$&``#-`P``-@,```L"```X!0``>@4``,X#``!\
M!P``3`0``&T%``#E`0```````"X!``!2`0``4P0``-L!``"F`P``!0$``,X%
M````````6@$``-0%``"!`P``M0,``-H```"T`0``0P0``#4"``!9!```#@4`
M``````!+!0``1@,``*@!``"9!```'P```*("````````"@4```````#%`0``
M70<``)\!``#_!@```````"$%``#R`0``<P$```````"\!0``=`4``-H"```$
M!@```````-T!````````_`,`````````````,`0``&0`````````````````
M``````````````````#'`@``_P,``!L"``#8`P``&`0``&8"````````OP(`
M````````````:P,```````#)````%@(``&@'``"7`P``1P4``%8#```^````
M```````````C!@```````,@%``!H!@``F0$`````````````!P<``'P"````
M````M0$``+@`````````3@0``(L$``!_````KP4``,\!````````^P,``)@&
M``!8!0``/`<``(<'```H`P``%0```(P#```]!```/P<``&`"````````+`<`
M`````````````````+D&``#Y!```(P<``)@````H!`````````````!7!@``
MUP8``,,$``"W!@``H@$```P````(`0``-`8``$4'``#?!0``FP(```````#)
M!```Z@,``+8!```$!0```````'4'````````=@,``'\$```(!0``308``,P$
M``#]`````````%<'``#A`@``'P8``$`#``"Q!@```````-H&```'!0``Y`0`
M```````U````"`,``%4"````````>`$``"8&````````"P0``-<!````````
MJ08``(T#``!!`0``R0,``$0%``"0!@``````````````````@0````````"&
M````&@8``'P#````````\P0``,(#````````B08````````P`@``L@8``),`
M``!2!@``H0,``%`%````````5P```.(!``":!```DP,``%H%````````=@(`
M`'H#```0!@``&0$```````"@````C00`````````````?@<``$,&```+!0``
MH@4``$('````````208``&,&``````````````````"O`P``.P```(D'``".
M`P``E@4``($"````````$00```````!T`@``704``-\&``"D!@``LP``````
M```3`@``H`$````````/`@``GP(````````5`0```````!P'``!:!```3`$`
M`-\"```#!0```````!D'``!N`@```````.8$```W!@``60,``$8'``#F`P``
M``````````#C!0``'`0``'(&``"M````%`(``*@$````````M0(```````#3
M!0``JP$``+D"``#K!@``=P,``&`!``#M`0``J`4``"`"`````````````.8"
M```E!`````````````"+!@``*`<`````````````]@4``&<"````````S0$`
M`'("```I`@``]`$``,("```E`0``&P4``!4&```[!@``6@```%X```!W!0``
MXP$``/\"```[`0``_00``"($``````````````````#F`0``W@(``!,$``"M
M!0``I@$```<"``"%`P``D@(``&H#````````5P0``.H```#`````>`4`````
M``#1!`````8``)L!`````````````&\!```9!@``/@4``)D"````````````
M`+@%``"?`P``-`(``+,$````````A04``)T&``!-!P```0(``(`````?!0``
MRP$```('``!O!@``R@,``(`&```8`0``[@$```````!C`0``M@4``/4````7
M`P```````'@"````````:0$``%X#````````C@<``"\#````````)@,``,P"
M``!P`P```````)\`````````````````````````L@0``+@!``"Y!```T`(`
M``````!1!P``/0<``/H#````````V@0``#`#```<`P``B`,``-<#```Y!P``
M`````-(%``#Y`@``40````````#:`0```````&,```#<!```#0(`````````
M````EP(``)$```#[!@```````"P&````````SP(``*L#``#S`@``9@<``-L`
M````````;@<``,0&````````400``$(&````````\@(``"D```"*`@``````
M`$,'````````?0$``!(%``!:!@``,P(`````````````X@(``+L$````````
MYP(``,\````-````\`````````!M!```T04```````#8````Y`$``(D!```[
M!0``R0(``)H%``!Y`P```````.,&``!C!0``*`8```````!4`0``[```````
M```5!0````````````!P`0``$@(```````"E!@````````````#$!```8P<`
M`(8"```3!@``3P<``-4&``!!!P```````)8!``#3!````````)H#````````
MT@$``(\&``"[````I`(``/@"``!%!0``1@0```0!``!1`@``80<````````D
M`0``G`$``-D#```*!```N@(``,8#````````=`8``,\&``#7!```\`8`````
M```B!0``Z@4``*D````X`0```P8``!P&````````-0<```D!``#I`0``+0$`
M`+8&`````````````*L"``#+`P``_P0````````P`0``2@(``*8%```<````
M%P(``*\"```V!```=`0``)`$``#4`0``WP0``.D#```O`@``90```#$%```N
M!0``O0$``)H&``!3!@``)`(``","``!`!0``[@0```$'````!P``$````&($
M````````2@,``%@&``!*!P``508`````````````A`(``+$!```T`P``````
M`"(&```;!P````````````"^````504```````"!!@``[@4``.H"``"O!@``
M`````.4&```8`@``5@0``*4$`````````````/P!``"4`@``T@8``!L```!V
M````MP,```````#L`0``]P0``/,#``#E`````````*,```#2`P``L@(``)T#
M``"9!@````````````!B!0``[0,``%T#``!@!```_04``"<%```K!P``IP8`
M`*D$`````P``I@(```````"W`@```P$``&`#```%`P``]`0``-<%````````
M``````($``"8`@``:`$``'\&``!)!P``!04``,<!``#*`0````````````#E
M!````````&4%````````PP8``'X"``#"!```[@(``#4#``!\!```Y`,``&X!
M````````W00``.X#``#[`0``P@4``/`%```)`````````(P'``"9!0``Q@0`
M````````````90(``&X```!9``````````,```!&!0``!@<```````#^!@``
MQ0```,4"````````G`8```````!Z`@```````#\#``````````````````##
M`@``I`$``(\```!-!0``/`4``#8'```*!@``:P(``"<"``!2!0```````+\%
M```#`P```````-P#```I!P``.`<``(X"``"-`0``]00``)8&```;`0``````
M`-\!``"-!0```````*4```!D!@``'04``(D"````````\04````````=````
M(`8```````"W`0``H`8``(\%`````````````)@#```-!@``,0(``)4`````
M````>@$``$(!````````%@8```````!A!0``:P4``,H%``#H!@``C0<`````
M``#R!0``[`0``+X$``#Y!@``N@4```````!)`0``5`(``#T!````````W`(`
M``````!)`@``0`8``.D%````````C`8``.8```#$`@```08```````"8!0``
M2````/,%``!#`P```````````````````````)(````^!P``;0(``),&```\
M`0``Z@$``(T"````````7````(@````D!P``O04``.<!``"J`@``]````#<!
M```>!P``;P<``(X%``!4`P``R`$`````````````J0$``,@&````````2`,`
M`-D%``"G`````````'L%``#=`P``90$```````"=!````````/(`````````
MM00```````#Z`0``*@<``,`%``".`0````````````!4!@``X04``"$#````
M`````````/($``"4`0``Q04``!@%``!_!0`````````````Q!P``AP(``&@%
M````````!P```/<#``!'!@```````!P%``!=!```P`8`````````````"@(`
M`#`&``!Z!````````#,#``!@!@```````#<"```W!P```````!<`````````
M`````+P$``#0````H`4``+X"```I`0``<`<``!4'``!/!```4@```&T&````
M````"P<``!X$``!-`P```04`````````````ZP```!4$```(`@``A@<``!4"
M````````@P0``(`"````````A@$```\%````````(0(``+0#```Z!P``RP0`
M``````!I`P``-`<``$0"``#V!```80````````"`!0``>P(``$D$````````
M<P```/\!``"*!```1@8``*0%``#Z!```.08``.$&````````0`$``+$#```W
M``````````````!;!````````"4```!0!@``)P<``"$&``#,!0```````&<#
M`````````````.@#``!T!P``^P4```````"@`@``A08``"H&````````_P``
M`!L$````````8@8``,L&``#O!0````````````"A!@``#@,``!8#````````
MS0(``-X%```M!```%0,``)<&````````GP4`````````````1@```+`$``!1
M!@``.04`````````````Q````+H!``"W!```'0(```````"&!0```````),$
M``#4`@``N@````\'````````PP```"X'`````````````-<````3`P``_`8`
M`/X#``"H````2`4``-P!```Y`@``RP4`````````````SP0``,P#``"Q!```
M`````.$`````````D`4``&P#``!L`````````&,#``#Q````N0$``%4#````
M````6P$``````````````````*P%``!]!@``!0(```````!1!0``.@(``(8$
M``"L`````````)X%``!!`P```P0``'L#````````#@0``+(#``!O!```5P4`
M`-$!```9!0```````,\#``"R`0``=0$```````#Z!@`````````````'`0``
M90,``"L#````````9@8```H!````````FP,``&T#``"J!```C`(``'4%``#5
M`P``7P(``/$&````````<0$``*$$``#(````J`,``%P"``#Y`````````,$`
M```.````:@4```````!Y!0``$P```)H```!R`P````````\&````````IP,`
M`/(&```0!```.P(```````!9`0``J@8```P&``#'````B@,```X&```I!@``
M7@4``%L"``">`0``B`8``$$&``"'`P``@`$``#<$``!O!0``>@8``(8&````
M````000``(<$```F!P``%P8``(L'````````]@(``$($``!8`0```````/`#
M``#I`@```````"8```!4!```$`,`````````````````````````````````
M`"(```#\!0``:@8``"X```"_`0````````````!]`@``AP$``&H```!*!0``
MF0`````````?`P```````/$!``"0`@``V0````````!+`@````````````!L
M!P``:`,``$X%``!$!```#0,``)4"``"J!0```````(('``!)!0``)`0``*X`
M``!]!```&@$``-0````K!@``9@,`````````````:P<``*D%``"5!@``YP8`
M`"`'``!-!```,`<``'<```!+`P``TP$```````#M!0``,P$```(%```4`0``
M/0````````````````````````#V!@``]`4``,D%````````0@4``.L%````
M````%P<```````#I!```;@4``"\$`````````````-`#``!^!```J0(`````
M```@`0``?@4``$@!``#)!@``#`<```````#4!```20````8```#N````````
M`(X$``!<!@``0`0```X"```4````H0$``%L%``#\!```7@<``)0#````````
M``$```````!D`@```````!T&`````````````-0&``"/`P```````!L#```H
M!0``/P8``&0'``!*!@``_0$``&@"``!6!P``=@<``*@&```(!```?`````,'
M``!=`@```````'`$````````+08``'`"``#S`0``.@```"H"````````Y`(`
M``````````````````````"$!P``LP(``#(````O`0```````/4"```/`0``
M)@0``!(&``!3`P``I0$```````"Z!@``R@```%\&``!M````K0(```````!%
M`P``!@(``&8```!6!@``B`(```````""`P``I0(``+P#``#I````L`$`````
M```+````%`<``!$%``"V!```-@4``&<!`````````````,@$````````9`0`
M`)<```#U`P``/@(```````"P````?`4```````!U!```D@$```````#U`0``
M>0<``!0#``"O````&@,```````"#!0``V00``!8!```N`P``900``!P"``"N
M!0``=`,```````"5!```!0```#0$```-!0```````$H$```$`P``>`<``"4#
M``!R!0``,0,``)@$`````````````````````````````%<#````````U@(`
M`!8%``!1`P``/@8```````!<`0```````*H!``#H!0````````````#1`P``
ME@(``*L```#O!```G`(``%L'`````````````)P#``!Y`@``Y04``'D&````
M````I`0``/<"``!G````X`(``$P#```,`P```````&0%``!,!0``O08``.P#
M``!2`@``BP4`````````````0`(``+L#````!```/`0``&P%``#L!@``.0,`
M`&(#``#2!````````&0#``!#`@``N`0``*P#```L`````````+D%``#P!```
M^@(````````/!```H`,``/<%``#<!@```````!`"```"`P``%`8``(D````B
M`0``N0,```@'``#]!@``G@8``.<%`````````````*,!```N!@``$`$`````
M``"_!@``VP4```````!G!```\`(``'\'``"Z`P``"````$8"```7!0``00(`
M`$0&``"L!```A@,``/`!``!(`@```````',%````````+04``-4$``"!`0``
M```````````W`P``+`4``'\"``"(!P```````)$"``#>`P``&`8``-8$```G
M`0````````````"O!```2P<```````#$`0``+P4```@&`````````````$H!
M``">!```(P```.,$```&!```O0(``*P!````````M`8``#(!``!'!```D08`
M``````#0!0``````````````````&0```)0$`````````````($$``!5!```
M*0,``"$!``#L!0``U@8``.L#````````G04``)L%``"$!0``Q08````````)
M`@``20,``,`"``!<!```4P<````````)!@``7P```!\$````````=P0```("
M````````S@```!H'``#8!0```````'8$``#1!@```````(4!``",`0``````
M`"L"```Z!```0P```'H'```&!0```````,$!``!K````0@(``,<$``"[!@``
MV0(``````````````````#8!``"!!P``DP$``$4"``"1`0``L`4``$<````R
M`P``F@(``,@#``!9!@`````````````8````<00``+P"``!0`P``60<`````
M````````````````````````%P0``'T%``!U`@``#@<```````!8`@``9@$`
M`"L!``#=!@``8`4``*H```!@!P````````````#!!```+`$``"L```"1!```
M`````$0#````````.P,``!$#``"S`P``[P$``#`%``!N!@```````#P&```R
M!0``!0<``'$"```9`@``C`4```````"<````TP8``-L&``!1`0``O````%X&
M```X!````````-8```"*!P``^`$```````!!``````````````!B`0``$P4`
M`+8#``!+`0```````/0"````````[P(``"<&```>`0````````````"1!0``
M`````*4%``!X````@04``*8&``".!@``A`0`````````````-08``((&````
M````,P0``#P#```8`P``004``',#```O!P``@P<``(H%``"F!```:0<``$0`
M````````/P````````#G````W0(``'4```!_`P``QP4```````#+`@``^@4`
M``````#"!@``?@```*T!````````@@``````````````>0```)@!```[!```
M`````'H```"P`@``^P````````"?!@``K`(``$````"I`P``N0```#D!``!W
M!P``50$``*,%````````?@,```````#$!0``9@0````@*"5S(&1A>7,@86=O
M*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C
M=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@
M<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS
M('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@
M9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E
M8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S
M(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI
M<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@
M;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E
M<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E
M<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L
M86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@
M:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N
M86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&
M;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F
M871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S
M`$%-($QI9VAT(%)A:6X`04T@3&EG:'0@4VYO=P!!32!286EN`$%-(%-H;W=E
M<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D
M:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!-
M96UB97)S`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A
M(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!P86ER`$%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D
M<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A
M=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I
M;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R
M;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA
M=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X
M>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI
M8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN
M`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I
M>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3
M:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!
M<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U
M8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E
M9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T
M<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S
M`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L
M9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R
M;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O
M<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM
M,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"
M96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!"
M;W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N
M9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N)W0@861M:6YI<W1E<B!E
M>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A
M;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&-O<'D@9FEL92AS
M*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE+@!#86YN
M;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!#86YN;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@
M:7,@=VET:&EN('-O=7)C92X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B
M)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R97-E
M="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BX`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%N;F]T('=R:71E('1O(&9I;&4@(B5S(@!#87!E(%9E<F1E`$-A
M<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES
M;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG
M.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L
M=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U
M8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T
M92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC
M:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H
M87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF
M:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S
M92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E
M<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES
M;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`
M0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E
M<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T
M90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D
M97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N
M9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#
M;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF
M:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E
M;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B
M`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE
M9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@
M9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD
M(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'
M4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T
M(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@
M;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T
M(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3
M;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U
M;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I
M=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E
M871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S
M:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R
M<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT
M('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I
M`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O
M:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E
M($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L
M;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E
M('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E
M('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O
M8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I
M9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I
M;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F
M;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO
M="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S
M/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@
M4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA
M:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`
M161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E
M<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N
M<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S
M:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE
M;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M
M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E
M<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I
M=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q
M=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@
M8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O
M<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H
M:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!E8W1E9"`G*2<`17AP96-T960@
M8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A
M=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@
M=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N
M+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z
M("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES
M;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,
M:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S
M`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II
M`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE
M<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@
M=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I
M;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP
M`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R
M='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S
M`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E97II
M;F<@1')I>GIL90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA
M;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`
M1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE
M`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`
M1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A
M`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M
M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`
M2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A
M=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``
M2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E
M("A6871I8V%N($-I='D@4W1A=&4I`$AO;64@061D<F5S<P!(;VUE($1I<F5C
M=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A
M;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L
M;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD
M`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@
M9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2
M;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E
M8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N
M97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N`$EN:&5R:71E9"!-96UB97)S`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS
M97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@
M;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI
M;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E
M9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L
M:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI
M9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O
M9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B
M`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N
M`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C
M=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)
M<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET
M86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE
M=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H
M`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA
M;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@
M2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5
M<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S
M`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE
M9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!2
M86EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A
M:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`
M3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK(%523`!,:6YK
M(&%C8V5S<R!K97D`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&%R9V5T`$QI;FL@
M=&5X=`!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FL@=&ET;&4@871T<FEB=71E`$QI;FMS
M`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`
M3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,
M:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T
M+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG
M('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A
M;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,
M;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R
M(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA
M;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I
M8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES
M:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M
M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN
M`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA
M;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U
M<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`
M365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A
M9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I
M;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T
M<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI
M9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N
M;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-
M:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E
M<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A
M=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO
M;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R
M870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S
M=&QY($-L;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N
M;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!-
M>2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY
M(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M
M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S
M($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C
M871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N
M97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE
M9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@
M=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X
M="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T
M96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO
M;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U
M<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE
M9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.
M;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L
M:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R
M=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R
M=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@
M9F]U;F0N`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D
M+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`
M3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYC
M;&EC:R!E=F5N=`!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD
M;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R
M9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/
M<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I
M;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`
M3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N
M871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI
M9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3
M:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@
M;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L
M97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W
M($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D
M.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI
M<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I
M;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES
M<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF
M;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0
M:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S
M;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H
M(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L
M96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N
M`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E
M(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H
M('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R
M='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R
M90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`
M4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P
M=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B
M;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+
M97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A
M`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN
M`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N
M;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A
M9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@
M=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L
M871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E
M<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R
M;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E
M;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I
M9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!2
M97-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S
M="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@
M<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E
M>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`
M4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`
M4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E
M<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W
M86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N
M8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N
M="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@
M3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!3
M96%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A
M=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!3
M96QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L
M;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M
M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!3
M97)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I
M;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3
M:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@
M<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T
M:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO
M=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H
M92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG
M(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3
M:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R
M90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO
M=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY
M`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F
M(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O
M=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@
M1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE
M<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R
M`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3
M=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O
M<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T
M`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U
M`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D
M960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL
M>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U
M;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O
M4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`
M4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y
M96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE
M=&5D`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@
M4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4
M+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L92!0<F]P97)T:65S`%1A8FQE
M(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@
M;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E
M<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`
M5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`
M5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4
M:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<
M;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T
M+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B
M(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM
M=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H
M="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I
M9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S
M(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE
M(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O(&UA;GD@:6YV86QI9"!L;V=I
M;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N`%1O<`!4;W`@9G)A;64@*%]T
M;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@
M9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`
M5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`
M5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y
M;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A
M`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG
M('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E
M("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AS:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@
M`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A
M9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0`56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P9&%T92!F
M;W(@)7,`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L
M('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG
M97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I
M`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3
M=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N
M:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO
M=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E
M<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A
M;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P
M97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`
M57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5
M<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O
M=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@
M97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES
M=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L
M:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@
M<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L
M(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6
M:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I
M;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%14
M4`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A
M<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!7
M96(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U
M*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA
M<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@
M075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I
M;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T
M86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7
M:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI
M<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8
M+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!
M9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N
M;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9
M;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P
M87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO
M=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`
M6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H
M;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4
M<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E
M<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E
M<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W
M;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N
M;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O
M=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U
M<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN
M90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`
M;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D
M`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA
M8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T
M96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+6-V<PI297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP-RTS,2`Q.#HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M
M,#@M,#D@,38Z-#4K,#(P,`I,87-T+51R86YS;&%T;W(Z($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"DQA;F=U86=E+51E86TZ($=E<FUA;B`\9&5V
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`H=F]R("5S(%1A9V5N*0`@*%IU
M9W)I9F9S=&%S=&4@)7,I`"`H:6X@)7,@5&%G96XI`"`H:&5U=&4I`"`H;6]R
M9V5N*0`@*&=E<W1E<FXI`"!M:70@`"(E<R(@:7-T(&ME:6X@5F5R>F5I8VAN
M:7,N`"(E<R(@:7-T(&ME:6YE(&?\;'1I9V4@075S=V%H;"X`(B5S(B!I<W0@
M:6X@9&5R($AO<F1E(%)E9VES=')Y(&YI8VAT(&MO;F9I9W5R:65R="X`1&5R
M($)A=6TM4F5N9&5R97(@9OQR("(E<R(@=W5R9&4@;FEC:'0@9V5F=6YD96XN
M`"(E<R(@=W5R9&4@>G5M($=R=7!P96YS>7-T96T@:&EN>G5G96;\9W0N`"(E
M<R(@=W5R9&4@>G5M(%)E8VAT97-Y<W1E;2!H:6YZ=6=E9OQG="X`(B5S(B!W
M=7)D92!N:6-H="!E<G-T96QL=#H@)7,N`"4N,F9-0B`H)3,D+C)F)24I('9O
M;B`E,B0N,F9-0B!E<FQA=6)T96X@=F5R8G)A=6-H=``E9"`E<R!U;F0@)7,`
M26X@)60@5&%G96X@=VER9"!):'(@4&%S<W=O<G0@=6YG_&QT:6<N`"5D+51A
M9V4M5F]R:&5R<V%G90`E<R`M($AI;G=E:7,`)7,@1FEN9V5R86)D<G5C:P`E
M<R!+0@`E<R!787)T=6YG<V%R8F5I=&5N("T@0F5S=.1T:6=U;F<`)7,M2V]N
M9FEG=7)A=&EO;@`E<R!296=I<W1R:65R=6YG`"5S($YU='IU;F=S8F5D:6YG
M=6YG96X`)7,@97AI<W1I97)T(&)E<F5I=',N`"5S(&UI="`E<R`E<P`E<R!W
M:7)D(&1I92!787)T=6YG<V%R8F5I=&5N(&1U<F-H9OQH<F5N+"!D:64@=6YT
M96X@;6%R:VEE<G0@<VEN9"X@36%R:VEE<F5N(%-I92!A;&QE($%U9F=A8F5N
M+"!D:64@:F5T>G0@9'5R8VAG96;\:')T('=E<F1E;B!S;VQL96XN`"5S(&ES
M="!N;W1W96YD:6<`)7,@36EN=71E;@`E<R!N:6-H="!G969U;F1E;BX`)7,@
M8FES("5S('9O;B`E<P`E<W,@061R97-S8G5C:``E<W,@2V%L96YD97(`)7-S
M($YO=&EZ8FQO8VL`)7-S($%U9F=A8F5N;&ES=&4`)7,Z("5S`"5S.B!$:65S
M92!.86-H<FEC:'0@<W1A;6UT('5N=&5R(%5M<W3D;F1E;B!N:6-H="!V;VX@
M9&5M(&%N9V5G96)E;F5N($%B<V5N9&5R+B!&;VQG96X@4VEE(&ME:6YE;B!,
M:6YK<R!I;B!D:65S97(@3F%C:')I8VAT('5N9"!H_'1E;B!3:64@<VEC:"!D
M879O<BP@9&5M($%B<V5N9&5R('!E<G/V;FQI8VAE($1A=&5N('!R96ES>G5G
M96)E;BX`+"!B]FEG(``L(&)I9R`E<R`E<P`L('-C:'=A;FME;F0@=F]N("5S
M(&)I<R`E<P`M+2!!=7-WY&AL96X@+2T`,3(M4W1U;F1E;BU&;W)M870`,C0M
M4W1U;F1E;BU&;W)M870`,C0@4W1U;F1E;@`\6G5R_&-K`$9R(&1I97-E;B!"
M;&]C:R!W:7)D(&5I;F4@1&%T96YB86YK(&)E;G1I9W0N`$5I;B!S8VAW97)E
M<B!&96AL97(@:7-T(&%U9F=E=')E=&5N.@!%:6X@]F9F96YT;&EC:&5R(%!'
M4"U38VAL_'-S96P@=VER9"!F_'(@9&EE(%9E<G-C:&S\<W-E;'5N9R!E:6YE
M<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@4$=0+5-C
M:&S\<W-E;"!W:7)D(&;\<B!D:64@W&)E<G!R_&9U;F<@96EN97(@=6YT97)Z
M96EC:&YE=&5N($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE
M<B!U;F0@96EN('!R:79A=&5R(%!'4"U38VAL_'-S96P@<V]W:64@96EN(%!A
M<W-W;W)T('=I<F0@9OQR(&1I92!%;G1S8VAL_'-S96QU;F<@96EN97(@3F%C
M:')I8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@<')I
M=F%T97(@4$=0+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@=VER9"!F
M_'(@9&EE(%5N=&5R>F5I8VAN=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG
M="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%,O34E-12U3
M8VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!%;G1S
M8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+@!%:6X@]F9F
M96YT;&EC:&5R('5N9"!E:6X@<')I=F%T97(@4R]-24U%+5-C:&S\<W-E;"!S
M;W=I92!E:6X@4&%S<W=O<G0@=VER9"!F_'(@9&EE(%5N=&5R>F5I8VAN=6YG
M(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!3
M+TU)344M4V-H;/QS<V5L('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@
M96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+@!6;W)M:71T86=S(%=O;&ME;@!6
M;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N`%9O<FUI='1A9W,@;&5I8VAT97(@
M4V-H;F5E9F%L;`!6;W)M:71T86=S(%)E9V5N`%9O<FUI='1A9W,@4V-H875E
M<@!6;W)M:71T86=S(%-C:&YE97-C:&%U97(`04TO4$T`05!)($E$`-QB97(@
M9&EE<V5N($5D:71O<@!);F9O+BXN`$%B<V]L=70@56YT96X`06)S;VQU="!-
M:71T90!:=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE9V5N(&1E<R!61E,M
M5F5R>F5I8VAN:7-S97,N`%IU9W)I9F8@=F5R=V5I9V5R="!B96EM($%N;&5G
M96X@9&5R(%9&4RU$871E:2X`2V]N=&]I;F9O<FUA=&EO;F5N`$MO;G1O<&%S
M<W=O<G0`2V]N=&\@96EN9V5F<F]R96XN`$)U8VAH86QT=6YG`$AI;GIU9OQG
M96X`3F5U92!5;G1E<F=R=7!P92!H:6YZ=6;\9V5N`$YE=64@56YT97)R96-H
M=&4@:&EN>G5F_&=E;@!(:65R(&AI;GIU9OQG96XZ`$UI=&=L:65D97(@:&EN
M>G5F_&=E;@!.975E($=R=7!P92!H:6YZ=6;\9V5N`$YE=64@4F5C:'1E(&AI
M;GIU9OQG96X`56YT97)G<G5P<&4@>G4@(B5S(B!H:6YZ=6;\9V5N`%5N=&5R
M<F5C:'1E('IU("(E<R(@:&EN>G5F_&=E;@!&_&=E;B!3:64@96EN96X@;F5U
M96X@0F5N=71Z97(@:&EN>G4Z`%-P86QT92!H:6YZ=6;\9V5N`%!A87(@:&EN
M>G5F_&=E;@!$87,@)7,M365N_"!Z=7(@36]Z:6QL82!3:61E8F%R(&AI;GIU
M9OQG96X`6G5M($%D<F5S<V)U8V@@:&EN>G5F_&=E;CH`6G4@;65I;F5M($%D
M<F5S<V)U8V@@:&EN>G5F_&=E;@!"96YU='IE<B!H:6YZ=6;\9V5N`"(E<R(@
M=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ=6=E9OQG="P@86)E<B!D:64@>G5SY'1Z
M;&EC:&5N(%)E9VES=')I97)U;F=S:6YF;W)M871I;VYE;B!K;VYN=&5N(&YI
M8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,N`"(E<R(@=W5R9&4@>G5M(%-Y
M<W1E;2!H:6YZ=6=E9OQG="X@4VEE(&OV;FYE;B!S:6-H(&IE='IT(&%N;65L
M9&5N+@!$87,@2&EN>G5F_&=E;B!V;VX@0F5N=71Z97)N(&ES="!N:6-H="!M
M]F=L:6-H+@!!9')E<W-E`$%D<F5S<V)U8V@`5F5R=V%L=&5N("T@4F5C:'1E
M(&;\<B!A;F1E<F4@0F5N=71Z97(@9F5S=&QE9V5N`$%D;6EN:7-T<F%T:6]N
M`%=E<F)U;F<`069G:&%N:7-T86X`06QB86YI96X`06QG97)I96X`4W!I='IN
M86UE`$%U<W)I8VAT=6YG`$%U<W)I8VAT=6YG.@!!;&QE`$%N9V5M96QD971E
M($)E;G5T>F5R`$%L;&4@1W)U<'!E;@!!;&QE(%)E8VAT90!!;&QE('9I97(@
M4V5I=&5N`$UE:')E<F4@061R97-S96X@97)L875B96X`1F]R;6%T('9O;B!N
M=6UM97)I97)T96X@3&ES=&5N(.1N9&5R;C\`17AI<W1I97)T(&)E<F5I=',`
M06QT97)N871I=F4@24U34"U!;FUE;&1U;F<`06QT97)N871I=F5S($E-4U`M
M4&%S<W=O<G0`06QT97)N871I=F5R($E-4U`M0F5N=71Z97)N86UE`$%L=&5R
M;F%T:79E($4M36%I;"U!9')E<W-E`$%L=&5R;F%T:79E(%9O<FQA9V5N`$%L
M=&5R;F%T:79E<B!497AT.@!!;65R:6MA;FES8V@M4V%M;V$`17,@=W5R9&4@
M96EN('5N9_QL=&EG97(@5V5R="!A;F=E9V5B96XN`$5I;B!U;F)E:V%N;G1E
M<B!&96AL97(@:7-T(&%U9F=E=')E=&5N+@!!;F1O<G)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N>6UE<B!0<F]X>0!!;G1W;W)T`$%N=&%R:W1I<P!!;G1I9W5A
M('5N9"!"87)B=61A`$%N=V5N9'5N9P!!;G=E;F1U;F=S;&ES=&4`06YW96YD
M=6YG(&ES="!B97)E:70N`$%U9B!5;G1E<G)E8VAT92!A;G=E;F1E;@!"97-T
MY'1I9V5N`%5N9V5FY&AR92!'<O;?90!!<')I;`!!<F%B:7-C:"`H5VEN9&]W
M<RTQ,C4V*0!!<F-H:79G<O;?90!!<F-H:79N86UE`%-I;F0@4VEE('-I8VAE
M<BP@9&%S<R!3:64@9&EE(%)E9VES=')I97)U;F=S86YF<F%G92!V;VX@)7,@
M;/9S8VAE;B!M]F-H=&5N/P!3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE("(E
M<R(@=6YD(&%L;&4@56YT97)G<G5P<&5N(&SV<V-H96X@;?9C:'1E;C\`07)G
M96YT:6YI96X`07)M96YI96X`07)M96YI<V-H("A!4DU30TE)+3@I`$MU;G-T
M`$%R=6)A`$%S8V5N<VEO;BU);G-E;&X`05-#24DM2W5N<W0`07-I96XO4&%Z
M:69I<V-H92!296=I;VX`06YS=&5H96YD92!787)T=6YG<V%R8F5I=&5N(&)E
M<W3D=&EG96X@;&%S<V5N/P!:=6]R9&YU;F=S9F5L9&5R`$5S('=U<F1E('9E
M<G-U8VAT+"!E:6YE(&YI8VAT(&5X:7-T:65R96YD92!'<G5P<&4@>G4@;/9S
M8VAE;BX`17,@=W5R9&4@=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N
M9&5S(%)E8VAT('IU(&SV<V-H96XN`$5S('=U<F1E('9E<G-U8VAT+"!E:6X@
M;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z=2!B96%R8F5I=&5N+@!%<R!W
M=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R96YD97,@4F5C:'0@
M>G4@8F5A<F)E:71E;BX`071T<FEB=71E`$%U9W5S=`!!=7-T<F%L:65N`-9S
M=&5R<F5I8V@`075T:%]C>7)S<6PZ($1I92!B96[V=&EG=&4@24U!4"U%<G=E
M:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]C>7)U<SH@1&%S
M($)A8VME;F0@:&%T(&YI8VAT(&1I92!B96[V=&EG=&5N($;D:&EG:V5I=&5N
M+@!!=71H7V-Y<G5S.B!$:64@8F5N]G1I9W1E($E-05`M17)W96ET97)U;F<@
M=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?9G1P.B!$:64@8F5N]G1I9W1E
M($944"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX@2V]M<&EL
M:65R96X@4VEE(%!(4"!M:70@9&5M("TM96YA8FQE+69T<"!087)A;65T97(N
M`$%U=&A?:6UA<#H@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG('=U
M<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7VMR8C4Z($1I92!B96[V=&EG=&4@
M2V5R8F5R;W,M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U
M=&A?;&1A<#H@1&%S($AI;GIU9OQG96X@=F]N($)E;G5T>F5R;B!W:7)D(&;\
M<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\='IT`$%U=&A?;&1A
M<#H@1&%S($SV<V-H96X@=F]N($)E;G5T>F5R;B!W:7)D(&;\<B!!8W1I=F4@
M1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\='IT`$%U=&A?;&1A<#H@1&EE(&)E
M;O9T:6=T92!,1$%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N
M+@!!=71H7VQD87`Z($1E<B!"96YU='IE<B`E<R!K;VYN=&4@;FEC:'0@:&EN
M>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG(&1E<R!397)V97)S.B``075T:%]L
M9&%P.B!"96YU='IE<B`E<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M`$%U=&A?;&1A<#H@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&%K='5A;&ES
M:65R="!W97)D96X`075T:%]L9&%P.B!$87,@06MT=6%L:7-I97)E;B!V;VX@
M0F5N=71Z97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O<GD@;FEC:'0@=6YT
M97)S=/QT>G0N`$%U=&A?;6-A;#H@1&EE(&)E;O9T:6=T92!-0T%,+45R=V5I
M=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7W-M8F%U=&@Z($1I
M92!B96[V=&EG=&4@4V%M8F$M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F
M=6YD96XN`$%N;65L9'5N9R!B96EM($E-05`M4V5R=F5R(&9E:&QG97-C:&QA
M9V5N+@!!=71H96YT:69I>FEE<G5N9R!F96AL9V5S8VAL86=E;@!!;FUE;&1U
M;F<@9F5H;&=E<V-H;&%G96XN("5S`$1I92!!=71H96YT:69I>FEE<G5N9R!W
M=7)D92!V;VT@4D%$2553+5-E<G9E<B!Z=7+\8VMG97=I97-E;BX`06YM96QD
M=6YG(&)E:6T@1E10+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`06YM96QD=6YG
M(&)E:6T@4TU"+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`5F5R9OQG8F%R92!&
M96QD97(Z`$%S97)B86ED<V-H86X`0D]&2"U!=7-R961E;@!(:6YT97)G<G5N
M9`!(:6YT97)G<G5N9&9A<F)E`$9A;'-C:&5S($ME<F)E<F]S+5!A<W-W;W)T
M+@!&86QS8VAE<B!+97)B97)O<RU"96YU='IE<FYA;64N`$)A:&%M87,`0F%H
M<F5I;@!"86QT:7-C:"`H25-/+3@X-3DM,3,I`$)A;F=L861E<V-H`$)A<F)A
M9&]S`$)A<VES+4)I;&1E<BU697)Z96EC:&YI<R`B)7,B(&YI8VAT(&=E9G5N
M9&5N+@!'<G5N9&QI;FEE`%=E:=]R=6QA;F0`0F5L9VEE;@!"96QI>F4`0F5N
M:6X`0F5R;75D87,`0FAU=&%N`$=E8G5R='-T86<`0FQO8VL@(B5S(B!D97(@
M06YW96YD=6YG("(E<R(@;FEC:'0@9V5F=6YD96XN`$)L;V-K96EN<W1E;&QU
M;F=E;@!";&]C:W1Y<`!&971T`$)O;&EV:65N`$QE<V5Z96EC:&5N`%)A;F0`
M4F%H;65N9&EC:V4Z`%+D;F1E<@!";W-N:65N+4AE<GIE9V]W:6YA`$)E:61E
M<P!";W1S=V%N80!5;G1E;@!";W5V971I;G-E;`!"<F%S:6QI96X`0G)I=&ES
M8VAE<R!497)R:71O<FEU;2!I;2!);F1I<V-H96X@3WIE86X`0G)U;F5I($1A
M<G5S<V%L86T`0G5L9V%R:65N`%5N;G5M;65R:65R=&4@3&ES=&4`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N<W-T96QL
M90!?6F5L;&5N96EG96YS8VAA9G1E;BXN+@!$97(@6G=I<V-H96YS<&5I8VAE
M<B!K;VYN=&4@;FEC:'0@:6YI=&EA;&ES:65R="!W97)D96XN`$MA;&5N9&5R
M`%=I;F1S=&EL;`!+86UB;V1S8VAA`$MA;65R=6X`17AT97)N92!397-S:6]N
M+4AA;F1L97(@:_9N;F5N(&YI8VAT(&%D;6EN:7-T<FEE<G0@=V5R9&5N+@!6
M97)B:6YD=6YG('IU;2!)34%0+5-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E
M;&QT('=E<F1E;CH@)7,`1&EE($1A=&5I("(E<R(@:V%N;B!N:6-H="!G9?9F
M9FYE="!W97)D96XN`$MA;F%D80!!8F)R96-H96X`4')O8FQE;6)E<FEC:'0@
M86)B<F5C:&5N`$1A=&5I*&5N*2!K]FYN96X@;FEC:'0@:V]P:65R="!W97)D
M96X@+2!1=65L;"T@=6YD(%II96QD871E:65N('-I;F0@:61E;G1I<V-H+@!$
M:64@1&%T96D@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+@!+
M96EN('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9V5F=6YD96XN`$1A=&5I*&5N
M*2!K]FYN96X@;FEC:'0@=F5R<V-H;V)E;B!W97)D96X@+2!::65L9&%T96D@
M8F5F:6YD970@<VEC:"!I;2!1=65L;&]R9&YE<BX`1F]R='-E='IU;F<@;VAN
M92`B=&%R9V5T1FEL92(M4&%R86UE=&5R(&YI8VAT(&WV9VQI8V@N`$1A<R!6
M97)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!E;G1F97)N="!W97)D96XN
M`$MO;FYT92!N:6-H="!E;G1F97)N="!W97)D96XL("5D($MI;F1E<B!E>&ES
M=&EE<F5N+@!5;7-O<G1I97)E;B!N:6-H="!M]F=L:6-H+B!$:64@06YZ86AL
M(&1E<B!%:6YT<N1G92P@9&EE('5M<V]R=&EE<G0@=V5R9&5N('-O;&QE;BP@
M<W1I;6UT(&YI8VAT(&UI="!D97(@06YZ86AL(&1E<B!G97-P96EC:&5R=&5N
M($5I;G1RY&=E(/QB97)E:6XN`%!A<W-W;W)T(&MA;FX@;FEC:'0@875T;VUA
M=&ES8V@@>G5R_&-K9V5S971Z="!W97)D96XL(&)I='1E('=E;F1E;B!3:64@
M<VEC:"!A;B!):')E;B!!9&UI;FES=')A=&]R+@!$:64@3F%C:')I8VAT(&MO
M;FYT92!N:6-H="!A;B!D:64@86YG96=E8F4@3G5M;65R('=E:71E<F=E;&5I
M=&5T('=E<F1E;BX`1&EE($1A=&5I("(E<R(@:V%N;B!N:6-H="!G97-P96EC
M:&5R="!W97)D96X`2V%P(%9E<F1E`-QB97)S8VAR:69T`%!R;W9I9&5R`$MA
M=&5G;W)I96X@=6YD($)E<V-H<FEF='5N9V5N`$-A>6UA;BU);G-E;&X`36]B
M:6QT96QE9F]N`%IE;&QE;F5I9V5N<V-H869T96X`26YN96YA8G-T86YD.@!:
M96QL96YE:6=E;G-C:&%F=&5N`%IE;&QE;F%B<W1A;F0Z`$UO8FEL=&5L969O
M;@!+96QT:7-C:"`H25-/+3@X-3DM,30I`%IE;G1R:65R=`!:96YT<F%L869R
M:6MA;FES8VAE(%)E<'5B;&EK`$UI='1E;&5U<F]PY&ES8V@@*$E33RTX.#4Y
M+3(I`%IE<G1I9FEK871D971A:6QS`%IE<G1I9FEK871B97-I='IE<@!:97)T
M:69I:V%T<FEC:'1L:6YI96X`5'-C:&%D`,1N9&5R;@#$;F1E<FX@4VEE($EH
M<B!087-S=V]R=`#$;F1E<FX@4VEE(&1E;B!.86UE;B!O9&5R(&1I92!!9')E
M<W-E+"!D:64@9&EE($5M<&;D;F=E<B!):')E<B!%+4UA:6PM3F%C:')I8VAT
M96X@<V5H96XL('=E;FX@<VEE(&1I97-E(&QE<V5N(&]D97(@9&%R875F(&%N
M=V]R=&5N+@!$87,@Q&YD97)N($EH<F5S(%!A<W-W;W)T<R!W:7)D('9O;B!D
M:65S96T@4WES=&5M('IU<B!:96ET(&YI8VAT('5N=&5R<W3\='IT+B!":71T
M92!W96YD96X@4VEE('-I8V@@86X@26AR96X@061M:6YI<W1R871O<BX`6F5I
M8VAE;@!,:6YK(/QB97)?<'+\9F5N+BXN`$-H:6QE`$-H:6YA`$-H:6YE<VES
M8V@@=F5R96EN9F%C:'0@*$=",C,Q,BD`0VAI;F5S:7-C:"!T<F%D:71I;VYE
M;&P@*$)I9S4I`$%N=V5N9'5N9R!A=7-WY&AL96XZ`%?D:&QE;B!3:64@96EN
M(%!A<W-W;W)T`%?D:&QE;B!3:64@96EN96X@0F5N=71Z97)N86UE;@!,96=E
M;B!3:64@9F5S="P@=VEE(&1A<R!$871U;2!A;F=E>F5I9W0@=V5R9&5N('-O
M;&PZ`$QI<W1E;F9O<FUA="!A=7-WY&AL96X@*&;\<B!N=6UM97)I97)T92!,
M:7-T96XI`%=E:6AN86-H='-I;G-E;`!+;&%S<V5N9&5F:6YI=&EO;B!F_'(@
M)7,@;FEC:'0@9V5F=6YD96XN`$AE:71E<@!-4RU/9F9I8V4M5&%G<R!E;G1F
M97)N96X`06)F<F%G92!Z=7+\8VMS971Z96X`0F5N=71Z97)D871E;B!L]G-C
M:&5N.B`E<P!"96YU='IE<F1A=&5N(&SV<V-H96X`0F5N=71Z97)D871E;B!L
M]G-C:&5N`%-PY'1E<B!!=69K;&%R96YD`$9O<G1F86AR96X`0VQI8VMA=&5L
M;"!P97(@2%144`!&96YS=&5R('-C:&QI9=]E;@!7;VQK96X`1G+\:"!7;VQK
M96X`0F5W]FQK=`!+;VMO<VEN<V5L;@!-96[\(&5I;F9A:')E;@!:=7-A;6UE
M;FCD;F=E;F1E(%)A:&UE;@!+;VQU;6)I96X`1F%R8F4`1F%R8F%U<W=A:&P`
M1F%R8G=A:&P`4W!A;'1E;CH`4W!A;'1E;OQB97)S8VAR:69T96X`0V]M:6-S
M`$)E9F5H;`!"969E:&QS>F5I;&4`2V]M;65N=&%R`$5I;F1E=71I9V5R($YA
M;64`2V]M;W)E;@!&:7)M80!#;VUP=71E<@!"961I;F=U;F=E;@!"961I;F=U
M;F=E;@!+;VYF:6=U<F%T:6]N<W5N=&5R<V-H:65D90!$:64@2V]N9FEG=7)A
M=&EO;B!M=7-S(&%K='5A;&ES:65R="!W97)D96XN`"5S(&MO;F9I9W5R:65R
M96X`4&%S<W=O<G0@8F5S=.1T:6=E;@!+;VYG;P!$96UO:W)A=&ES8VAE(%)E
M<'5B;&EC($MO;F=O`%9E<F)I;F1U;F<@9F5H;&=E<V-H;&%G96XN`%9E<F)I
M;F1U;F<@9F5H;&=E<V-H;&%G96XZ(`!697)B:6YD=6YG('IU;2#V9F9E;G1L
M:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B9V5W:65S96XN`%9E<F)I
M;F1U;F<@>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(@=W5R9&4@
M86)G97=I97-E;BX@1W)U;F0Z("5S("@E<RD`5F5R8FEN9'5N9R!Z=6T@1E10
M+5-E<G9E<B!F96AL9V5S8VAL86=E;@!+;VYT86MT90!$:64@2V]N=&%K=&4@
M=W5R9&5N(&5R9F]L9W)E:6-H($EH<F5M($%D<F5S<V)U8V@@:&EN>G5G96;\
M9W0N`$EN:&%L='-T>7`@9&5R(&MO;7!R:6UI97)T96X@1&%T96DZ(`!);FAA
M;'0@=F]N("(E<R(`5V5I=&5R`$-O;VLM26YS96QN`$-O;VMI90!+;W!I97)E
M;@!+;W!I97)E;B!F96AL9V5S8VAL86=E;CH@)7,`075S=V%H;"!K;W!I97)E
M;@!+;W-T96XM240`0V]S=&$@4FEC80!%;&9E;F)E:6YK_'-T90!$:64@3F%C
M:')I8VAT(&MO;FYT92!N:6-H="!M:70@4$=0('9E<G-C:&S\<W-E;'0@=V5R
M9&5N.B``1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!U;G1E
M<GIE:6-H;F5T('=E<F1E;CH@`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT
M(&UI="!3+TU)344@=F5R<V-H;/QS<V5L="!W97)D96XN`$1I92!.86-H<FEC
M:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)344@=6YT97)Z96EC:&YE="!W97)D
M96XN`$MO;G1A:W0@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@
M)7,`5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G96XN
M`$MO;G1O<W1A;F0@:V]N;G1E(&YI8VAT(/QB97)P<OQF="!W97)D96XN("5S
M`%9E<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!&
M5%`M5F5R8FEN9'5N9R!Z=6T@4V5R=F5R("(E<R(@:V]N;G1E(&YI8VAT(&AE
M<F=E<W1E;&QT('=E<F1E;CH@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI
M8VAT(&5R<W1E;&QT('=E<F1E;BX@)7,`4$=0+41A=&5N(&MO;FYT96X@;FEC
M:'0@96YT<V-H;/QS<V5L="!W97)D96XZ(`!3+TU)344M1&%T96X@:V]N;G1E
M;B!N:6-H="!E;G1S8VAL_'-S96QT('=E<F1E;BX`2V]N=&%K="!K;VYN=&4@
M;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B`E<P!697)T96EL97)L:7-T92!K;VYN
M=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B`E<P!$87,@06MT=6%L:7-I97)U
M;F=S<VMR:7!T("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`
M1&EE($4M36%I;"U!9')E<W-E(&1E<R!%;7!FY&YG97)S(&MO;FYT92!N:6-H
M="!E<FUI='1E;'0@=V5R9&5N+@!$87,@061R97-S8G5C:"!K;VYN=&4@;FEC
M:'0@:V]M<&QE='0@9V5L97-E;B!W97)D96XN`%9E<G1E:6QE<FQI<W1E(&MO
M;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`3&ES=&4@9&5R(%9E
M<G1E:6QE<FQI<W1E;B!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN
M`$1I92!3=')A=&5G:64@(B5S(B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D
M96XN`$1A<R!697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!A;F=E;&5G
M="!W97)D96XN`-9F9F5N=&QI8VAE<B!38VAL_'-S96P@:V]N;G1E(&YI8VAT
M('9O;2!38VAL_'-S96QS97)V97(@9V5H;VQT('=E<F1E;BX`(B5S(B!K;VYN
M=&4@;FEC:'0@>G5M(%-C:')E:6)E;B!G9?9F9FYE="!W97)D96XN`"5S(&MO
M;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX`1&%S($UA:6YT96YA;F-E7U1A
M<VL@36]D=6P@)7,@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;@!697)Z
M96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN`%9E
M<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&MO;FYT92!N:6-H="!H97)G97-T
M96QL="!W97)D96XN`"5S(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX`
M1&%S(%!A<W-W;W)T(&;\<B!D96X@86YG96=E8F5N96X@0F5N=71Z97(@:V]N
M;G1E(&YI8VAT('IU<OQC:V=E<V5T>G0@=V5R9&5N+"!W96EL(&5I;FEG92!!
M;F=A8F5N(&YI8VAT(')I8VAT:6<@=V%R96XN(%9E<G-U8VAE;B!3:64@97,@
M97)N975T(&]D97(@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T
M<F%T;W(L('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I9V5N+@!!0TP@
M:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N`$1A<R!!9')E<W-B=6-H(&MO
M;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@
M:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<P!697)T96EL97)L
M:7-T96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<P!$:64@
M4V5R=F5R9N1H:6=K96ET96X@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E
M<F1E;@!+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!Z=7+\8VMG97-E='IT
M('=E<F1E;BX`5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N+@`E<RU+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!K;VYN
M=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!"86-K=7`@9&5R($MO;F9I
M9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,`
M1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="!K;VYN=&4@;FEC:'0@;F%C:"`B
M)7,B(&=E<W!E:6-H97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T
M:6]N("5S(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN`$1I92!+
M;VYF:6=U<F%T:6]N("5S(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D
M96XN(%-I92!K]FYN96X@96YT=V5D97(@96EN92!D97(@3?9G;&EC:&ME:71E
M;B!U;G1E<B`E<R!V97)W96YD96XL('5M(&1E;B!#;V1E('IU('-P96EC:&5R
M;BP@;V1E<B!D96X@=6YT96YS=&5H96YD96X@0V]D92!M86YU96QL(&YA8V@@
M)7,@:V]P:65R96XN`$1E<B!,1$%0+5-E<G9E<B!K;VYN=&4@;FEC:'0@9'5R
M8VAS=6-H="!W97)D96XN`"(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E
M<F1E;BX`1&5R($MO;G1A:W0@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E
M<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&%K='5A;&ES
M:65R="!W97)D96XN("5S`$1I92!+;VYF:6=U<F%T:6]N(&;\<B`B)7,B(&MO
M;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S`$1I92!-;WII;&QA
M(%-I9&5B87(@:V]N;G1E(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX@4W1E;&QE
M;B!3:64@<VEC:&5R+"!D87-S(&1I92!3:61E8F%R(&=E]F9F;F5T(&ES="X`
M1&5M($)E;G5T>F5R("(E<R(@:V]N;G1E;B!D:64@9F]L9V5N9&4@4F5C:'1E
M(&;\<B!D96X@3W)D;F5R("(E<R(@;FEC:'0@>G5G97=I97-E;B!W97)D96XZ
M("5S`$=E>N1H;'1E<B!497AT`$QA;F0`2W5R<V4`17)S=&5L;&5N`$QI;FL@
M97)S=&5L;&5N`$YE=64@261E;G1I=.1T(&%N;&5G96X`56YT97)O<F1N97(@
M97)S=&5L;&5N`$5R<W1E;&QE<G)E8VAT90!+<F5D:71K87)T96YN=6UM97(`
M2W)O871I96X`2W5B80!!:W1U96QL92`T(%!H87-E;@!!:W1U96QL92!397-S
M:6]N<P!!:W1U96QL92!:96ET`$%K='5E;&QE(%523"!I<W0`06MT=65L;&4@
M0F5N=71Z97(`06MT=65L;&5S(%=E='1E<@!$97)Z96ET:6=E($)E9&EN9W5N
M9V5N.B``06MT=65L;&5R(%-T:6P`3&5G96X@4VEE(&9E<W0L('=E;&-H92!!
M=69G86)E;B!N86-H(&1E<B!!;FUE;&1U;F<@8F5I("5S(&5R;&5D:6=T('=E
M<F1E;B!S;VQL96XN`$%U<W-C:&YE:61E;@!!=7-W86AL(&%U<W-C:&YE:61E
M;@!:>7!E<FX`2WER:6QL:7-C:"`H2T])."U2*0!+>7)I;&QI<V-H("A7:6YD
M;W=S+3$R-3$I`$MY<FEL;&ES8V@O56MR86EN:7-C:"`H2T])."U5*0!4<V-H
M96-H:7-C:&4@4F5P=6)L:6L`5%0`1%-.("AS:65H92!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S
M;BYP:'`I`%3D9VQI8V@`1&%T851R964@0G)O=W-E<@!$871E;F)A;FMA8F9R
M86=E`$1A='5M`$5M<&9A;F=S9&%T=6T`1&%T=6US875S=V%H;`!486<`4W!A
M;'1E(%]L]G-C:&5N`$1E>F5M8F5R`%IA:&QE;@!%:6YZ=6<@=F5R<FEN9V5R
M;@!3=&%N9&%R9`!3=&%N9&%R9&9A<F)E`%-T86YD87)D:61E;G1I=.1T`%-T
M86YD87)D<VAE;&P`1&5F:6YI=&EO;F5N`$SV<V-H96X`6F5L;&4@;/9S8VAE
M;@!'<G5P<&4@;/9S8VAE;@!,;V<@;/9S8VAE;@!296-H=&4@;/9S8VAE;@!.
M86-H<FEC:'1E;B!L]G-C:&5N('5N9"!E;G1F97)N96X`6F5L;&4@;/9S8VAE
M;@!3<&%L=&4@;/9S8VAE;@!"97-T96AE;F1E(&%L=&5R;F%T:79E(%9O<FQA
M9V4@;/9S8VAE;@!.86-H<FEC:'1E;B!L]G-C:&5N`%)E8VAT92!F_'(@(B5S
M(B!L]G-C:&5N`%)E8VAT92!F_'(@(B5S(B!U;F0@86QL92!5;G1E<G)E8VAT
M92!L]G-C:&5N/P!:96EL92!L]G-C:&5N`$%U<V=E=^1H;'1E($ED96YT:73D
M="!L]G-C:&5N`%5N=&5R;W)D;F5R(&SV<V-H96X`1&EE(&%K='5E;&QE(%-P
M86QT92!L]G-C:&5N`$1I92!A:W1U96QL92!:96EL92!L]G-C:&5N`$1A<R!!
M:W1U86QI<VEE<G5N9W-S:W)I<'0@(B5S(B!W=7)D92!G96SV<V-H="X`075S
M;&EE9F5R=6YG<WIE:70`1.1N96UA<FL`0F5S8VAR96EB96X@4VEE(&1A<R!0
M<F]B;&5M`$)E<V-H<F5I8G5N9P!$971A:6QS("AA=6-H(&EN($AO<F1E<R!,
M;V=D871E:2DZ`$1E=&%I;',@=W5R9&5N(&;\<B!D96X@061M:6YI<W1R871O
M<B!M:71G96QO9V=T+@!%;G1W:6-K;'5N9P!4875P=6YK=`!4875P=6YK="!D
M97(@;&5T>G1E;B!3='5N9&4Z(`!4875P=6YK=#H@`%9O;B!L:6YK<R!N86-H
M(')E8VAT<P!6;VX@<F5C:'1S(&YA8V@@;&EN:W,`5F5R>F5I8VAN:7,`6F5I
M="!I;2`R-"U3='5N9&5N+49O<FUA="!A;GIE:6=E;C\`06YZ96EG92U%:6YS
M=&5L;'5N9V5N`$1E=&%I;&EE<G1E(%9O<FAE<G-A9V4@86YZ96EG96X`5F]R
M:&5R<V%G92`H5$%&*2!A;GIE:6=E;@!!;GIE:6=E9F]R;6%T`$5M<&9A;F=S
M8F5S=.1T:6=U;F<`1'-C:&EB=71I`$YI8VAT(&SV<V-H96X`1W)E:69E;B!3
M:64@;FEC:'0@9&ER96MT(&%U9B!M86EN=&5N86YC92YP:'`@>G4`16YT:.1L
M="!D:64@97)S=&4@6F5I;&4@9&EE($9E;&1N86UE;C\@5V5N;B!J82P@9&EE
M<V5S($%U<W=A:&QKY'-T8VAE;B!M87)K:65R96XZ`$1O;6EN:6-A`$1O;6EN
M:6MA;FES8VAE(%)E<'5B;&EK`$YO8V@@:V5I;F5N(%IU9V%N9S\@2&EE<B!A
M;FUE;&1E;BX`2&5R=6YT97)L861E;@`E<R!(97)U;G1E<FQA9&5N`$5R>F5U
M9W1E($MO;F9I9W5R871I;VX@86QS(%!(4"U3:W)I<'0@:&5R=6YT97)L861E
M;BX`075S=V%H;&QI<W1E`$1R;V=E;@!%+4UA:6P`12U-86EL+6YA8V@M4TU3
M+6=A=&5W87D@9OQR(%!R;W9I9&5R+"!D:64@96EN96X@<V]L8VAE;B!$:65N
M<W0@=6YT97)S=/QT>F5N+@!&14A,15(`16-U861O<@!"96%R8F5I=&5N`$)L
M;V-K(&)E87)B96ET96X`1W)U<'!E(&)E87)B96ET96X`4F5C:'1E(&)E87)B
M96ET96X`4F5C:'1E(&)E87)B96ET96X`4F5C:'1E(&;\<B`G)7,G(&)E87)B
M96ET96X`16EN<W1E;&QU;F=E;B!B96%R8F5I=&5N(&;\<CH`4F5C:'1E(&;\
M<B`B)7,B(&)E87)B96ET96X`4F5C:'1E(&;\<B`E<R!B96%R8F5I=&5N`$)I
M;&1U;F<`Q&=Y<'1E;@!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$4M36%I
M;`!%+4UA:6PM061R97-S90!$:64@12U-86EL+4%D<F5S<V5N(&W\<W-E;B!G
M;&5I8V@@<V5I;BX`12U-86EL+4%D<F5S<V4@;6ET($)E<W3D=&EG=6YG`$4M
M36%I;"UN86-H+5--4RU'871E=V%Y`%-M:6QE>7,`3&5E<F4@3F%C:')I8VAT
M+@!,965R97,@17)G96)N:7,N`%-U8VAB96=R:69F92!L]G-C:&5N`$5I;F;\
M9V5N('9O;B!":6QD97)N(&%U<R!&;W1O9V%L97)I96X@:6X@9&5N(%1E>'0@
M97)L875B96X_`$MO;G1E>'1M96[\(&)E:2!296-H='-K;&EC:R!A:W1I=FEE
M<F5N/P!%;F1J86AR`$5D:71O<B!V97)G<O;?97)N`$=E8F5N(%-I92!E:6YE
M(%-I8VAE<FAE:71S9G)A9V4@96EN+"!D:64@26AN96X@9V5S=&5L;'0@=VER
M9"P@=V5N;B!3:64@26AR(%!A<W-W;W)T('IU<OQC:W-E='IE;B!M]F-H=&5N
M+"!Z+B!"+B`B5VEE(&QA=71E="!D97(@3F%M92!):')E<R!(875S=&EE<G,_
M(CH`2&EE<B!D:64@0FEL9"U54DP@86YG96)E;@!'96)E;B!S:64@9&EE($)U
M8VAS=&%B96X@=6YT96X@96EN.@#$<75A=&]R:6%L+4=U:6YE80!%<FET<F5A
M`$9E:&QE<@!&96AL97(@8F5I;2!%<G-T96QL96X@96EN97,@0FQO8VMS.B`E
M<P!&96AL97(@8F5I;2!,]G-C:&5N(&1E<R!3>6YC:')O;FES871I;VYS86YK
M97)S.B`E<P!&96AL97(@8F5I;2!,]G-C:&5N(&1E<R!3>6YC:')O;FES871I
M;VYS;&]G<SH@)7,`1F5H;&5R(&)E:6T@17)Z975G96X@9&5S($EN:&%L=',Z
M("5S`$9E:&QE<B!B96EM(,1N9&5R;B!D97,@4&%S<W=O<G1S.B`E<P!&96AL
M97(@:6X@9&5R($4M36%I;"U.86-H<FEC:'0N`$9E:&QE<B!B96EM(%-C:')E
M:6)E;B!V;VX@(B5S(BX`17-T;&%N9`#$=&AI;W!I96X`171N:7-C:&5S`$5U
M<F]P80!!;&QE(#$U($UI;G5T96X`06QL92`R($UI;G5T96X`06QL92`S,"!3
M96MU;F1E;@!!;&QE(#4@36EN=71E;@!"96D@:F5D97(@06YM96QD=6YG`$%L
M;&4@:&%L8F4@4W1U;F1E`$%L;&4@-C`@4V5K=6YD96X`0F5I<W!I96QW97)T
M93H`075S9OQH<F5N`%9E<F=R]M]E<FX`)RDG(&5R=V%R=&5T`$5I;GIE;&YE
M<R!7;W)T(&]D97(@4W5C:&)E9W)I9F8@:6X@06YF_&AR=6YG<WIE:6-H96X@
M97)W87)T970`5F5R9F%L;'-D871U;0!%>'!O;F5N=`!6;W)D97)G<G5N9&9A
M<F)E`$AO8VAL861E;B!D97(@2V]N9FEG=7)A=&EO;B!P97(@1E10`$)E;G5T
M>F5R96EN<W1E;&QU;F=E;B!K;VYN=&5N(&YI8VAT(&=E;&%D96X@=V5R9&5N
M+@!697)B:6YD=6YG('IU;2!,1$%0(%-E<G9E<B!G97-C:&5I=&5R="X`5F5R
M8FEN9'5N9R!Z=6T@4TU"+5-E<G9E<B!G97-C:&5I=&5R="X`17,@:V]N;G1E
M(&ME:6YE($MO<&EE('9O;B`B)7,B(&5R<W1E;&QT('=E<F1E;BX`17,@:V]N
M;G1E(&YI8VAT(&YA8V@@(B5S(B!K;W!I97)T('=E<F1E;BX`075F8F%U(&5I
M;F5N(&YE=65N(%-!4TPM5F5R8FEN9'5N9R!I<W0@9F5H;&=E<V-H;&%G96XN
M`$5S(&MO;FYT92!N:6-H="!N86-H("(E<R(@=F5R<V-H;V)E;B!W97)D96XN
M`$9E:&QE<B!B96EM($QE<V5N.B`E<P!(96ET97(`1F%L:VQA;F1I;G-E;&X`
M1F%R]F5R`%-C:'=E<F5R($9E:&QE<CH`1F%X`$9A>&4`1F5B<G5A<@!'96;\
M:&QT92!496UP97)A='5R`$=E9OQH;'1E(%1E;7!E<F%T=7(Z(`!697)E:6YZ
M96QT92!38VAA=65R`%9E<F5I;GIE;'1E(%-C:&YE97-C:&%U97(`1F5L9&UA
M=')I>`!&:6=L970@0T%05$-(00!&:6=L970M1F]N=`!&:61S8VAI`$1A=&5I
M`$%N>F%H;#H@)7,@1&%T96D`06YZ86AL.B`E<R!$871E:65N`$1A=&5I;6%N
M86=E<@!$871E:6YA;64`1&%T96EA=7-W86AL`$1A=&5I+4AO8VAL861E;@!$
M87,@2&]C:&QA9&5N('9O;B!$871E:65N('=I<F0@;FEC:'0@=6YT97)S=/QT
M>G0N`$9I;'1E<@!&:6YN;&%N9`!%<G-T92!(Y&QF=&4`17)S=&5S(%9I97)T
M96P`5F5R:.1L=&YI<R!Z=7+\8VMS971Z96X`56UD<F5H96X`5&5X=&9L==\`
M3F5B96P`1&%S(%9E<GIE:6-H;FES("5S(&5X:7-T:65R="!N:6-H=`!38VAR
M:69T9F%R8F4`17-S96X`1OQR($)R;W=S97(L(&1I92!K96EN92!":6QD97(@
M=6YT97)S=/QT>F5N`%9O<FAE<G-A9V4@*%1!1BD`5F]R:&5R9V5S86=T92!4
M86=E("A6;W)H97)S86=E;B!E;G1H86QT96X@5&%G92!U;F0@3N1C:'1E+"!E
M:6X@:&]H97(@5V5R="!K86YN('IU(&5I;F5M('-E:'(@9W)OWV5N($)L;V-K
M(&;\:')E;BD`4&%S<W=O<G0@=F5R9V5S<V5N/P!&;W)M=6QA<F4`1VS\8VMS
M:V5K<P!';/QC:W-K96MS='EP`$=L_&-K<VME:W-E`$=L_&-K<VME:W-E(#(`
M1F]R96X`5V5I=&5R;&5I='5N9P!&<@!286AM96X`1G)A;FMR96EC:`!%=7)O
M<.1I<V-H97,@1G)A;FMR96EC:`!'969R:65R96YD97(@4F5G96X`1G)A;GKV
M<VES8V@M1W5A>6%N80!&<F%N>O9S:7-C:"U0;VQY;F5S:65N`$9R86YZ]G-I
M<V-H92!'96)I971E(&EM('/\9&QI8VAE;B!);F1I<V-H96X@3WIE86X`5F]N
M`$%U<R``5F]L;'-TY&YD:6=E($)E<V-H<F5I8G5N9P!6;VQL;6]N9`!6;VQL
M<W3D;F1I9V5R($YA;64`1V%B=6X`0FEL9&5R(&%U<R!D:65S97(@1V%L97)I
M90!'86QE<FEE.@!'86UB:6$`)7,M2V]N9FEG=7)A=&EO;B!E<GIE=6=E;@!%
M<GIE=6=T97(@0V]D90!'96]R9VEE;@!$975T<V-H;&%N9`!':&%N80!':6)R
M86QT87(`5F]R;F%M90!!;&QG96UE:6YE($5I;G-T96QL=6YG96X`3&]S`$=O
M961E;`!';V]G;&4@36%P<P!';V]G;&4@4W5C:&4`1W)A=7-T=69E;@!'<FEE
M8VAE;FQA;F0`1W)I96-H:7-C:"`H25-/+3@X-3DM-RD`1W+V;FQA;F0`1W)E
M;F%D80!'<G5P<&5N=F5R=V%L='5N9P!'<G5P<&5N;F%M96X@9/QR9F5N(&YI
M8VAT(&QE97(@<V5I;@!'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT
M92!N:6-H="!H:6YZ=6=E9OQG="!W97)D96XN($UE;&1U;F<@9&5S(%-E<G9E
M<G,Z(`!'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT92!N:6-H="!G
M96SV<V-H="!W97)D96X`1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN
M=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;@!'<G5P<&5N`$=U861E;&]U
M<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1V%S=')E8VAT90!'Y'-T96)U
M8V@`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`1&5R($5D:71O
M<B!K86YN(&1I92!L971Z=&4@6F5L;&4@96EN97(@6F5I;&4@;FEC:'0@;/9S
M8VAE;BX`1&5R($5D:71O<B!K86YN(&1I92!L971Z=&4@4W!A;'1E(&5I;F5R
M(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BX`1&5R($5D:71O<B!K86YN(&1I92!L
M971Z=&4@6F5I;&4@96EN97(@5&%B96QL92!N:6-H="!L]G-C:&5N+@!(5%10
M+4%U=&AE;G1I9FEZ:65R=6YG(&YI8VAT(&=E9G5N9&5N+@!(86ET:0!(87-H
M+4%L9V]R:71H;75S`$1I97-I9P#<8F5R<V-H<FEF=`!+;W!F96EN='+D9V4`
M2&5A<F0M('5N9"!-8T1O;F%L9&EN<V5L;@!38VAW97)E($=E=VET=&5R`$AE
M8G+D:7-C:"`H25-/+3@X-3DM."U)*0!(]FAE`$AI;&9E`$5D:71O<FAI;&9E
M`$AI;&9E`$AE;6ES<&AE<F4`1&EE<R!I<W0@9&5R($)E9VEN;B!D97(@1&%T
M96DZ`$AO8V@`7U-T87)T<V5I=&4`5F%T:6MA;G-T861T`$%D<F5S<V4@<')I
M=F%T`$AE:6UV97)Z96EC:&YI<P!496QE9F]N('!R:79A=`!(;VYD=7)A<P!(
M;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%5N9_QL=&EG92`E<RU834PM
M1&%T96X@:6X@3F%C:')I8VAT("5S`$AO<F1E+TMO;&%B.B!%<R!P87-S="!K
M96EN92!.86-H<FEC:'0@>G5M($]B:F5K="`E<P!(;W)D92]+;VQA8CH@2V5I
M;B!/8FIE:W0@=F]M(%1Y<"`E<R!I;B!.86-H<FEC:'0@)7,@9V5F=6YD96X`
M2&]R9&4O2V]L86(Z("5S("(E<R(@=W5R9&4@97)F;VQG<F5I8V@@96YT9F5R
M;G0`2&]R9&4O2V]L86(Z($1I92!);G1E9W)A=&EO;G-F=6YK=&EO;F5N(&)E
M;O9T:6=E;B!D:64@(F1O;7AM;"(@4$A0+45R=V5I=&5R=6YG`$AO<F1E+TMO
M;&%B.B!&_'(@9&%S($]B:F5K="`E<R!K;VYN=&4@:V5I;B!N975E<B!834PM
M0F%U;2!E<GIE=6=T('=E<F1E;@!(;W)D92]+;VQA8CH@)7,@(B5S(B!K;VYN
M=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N.B`E<P!(;W)D92]+;VQA8CH@1&EE
M($U)344M240@9&5S($%B<V-H;FET=',@=F]M(%1Y<"`E<R!K;VYN=&4@;FEC
M:'0@:&5R875S9V5F=6YD96X@=V5R9&5N+@!(;W)D92]+;VQA8CH@)7,@(B5S
M(B!K;VYN=&4@;FEC:'0@<WEN8VAR;VYI<VEE<G0@=V5R9&5N.B`E<P!(;W)D
M92]+;VQA8CH@1&EE(&=E;65I;G-A;65N($]B:F5K=&4@:V]N;G1E;B!N:6-H
M="!S>6YC:')O;FES:65R="!W97)D96XZ("5S`$AO<F1E+TMO;&%B.B!5;F)E
M:V%N;G1E<R!G96UE:6YS86UE<R!/8FIE:W0@(B5S(@!(;W)I>F]N=&%L92!,
M:6YI90!(;W)I>F]N=&%L97(@26YN96YA8G-T86YD`$AO<FEZ;VYT86PZ`%=I
M92!S:6YD(%-I92!H:65R:&5R9V5L86YG=#\@0FET=&4@86X@9&EE($5N='=I
M8VML97(@>G5R_&-K;65L9&5N(2D`5VEE('9I96QE(%-P86QT96X@<V]L;&5N
M('IU<V%M;65N9V5F_&=T('=E<F1E;C\`5VEE=FEE;&4@1F5L9&5R("A3<&%L
M=&5N*2!G:6)T(&5S/P!7:64@=FEE;&4@6F5I;&5N('-O;&QE;B!Z=7-A;6UE
M;F=E9OQG="!W97)D96X_`$QU9G1F975C:'1I9VME:70`3'5F=&9E=6-H=&EG
M:V5I=#H@`$MO;6EK97(`56YG87)N`$%N;&5G96X@9&5S($E-05`M4&]S=&9A
M8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,`3/9S8VAE;B!D97,@24U!4"U0
M;W-T9F%C:',@:7-T(&9E:&QG97-C:&QA9V5N.B`E<P!&97-T;&5G96X@9&5R
M($E-05`M4&]S=&9A8V@M475O=&$@:7-T(&9E:&QG97-C:&QA9V5N.B`E<P!)
M4"U!9')E<W-E`$E0+4%D<F5S<V4@;FEC:'0@=F5R9OQG8F%R+@!)4"U!9')E
M<W-E(&YI8VAT(&EM(&5R;&%U8G1E;B!#2412+4)L;V-K+@!697)L971Z=6YG
M(&1E<B!F97-T9V5L96=T96X@25`N`%IE:6QE(&5I;F;\9V5N(%]V;W(`27-L
M86YD`$YU<B!":6QD97(`26-O;G,@9OQR("5S`$)I;&1E<B!U;F0@5&5X=`!"
M97IE:6-H;G5N9R!D97(@261E;G1I=.1T`%=E;FX@<VEE(&YI8VAT(&MO<G)E
M:W0@86YG97IE:6=T('=I<F0L("5S+"!U;2!S:64@:6X@96EN96T@;F5U96X@
M1F5N<W1E<B!A;F=E>F5I9W0@>G4@8F5K;VUM96XN`%=E;FX@4VEE(&UI="!D
M96T@26YT97)N970@17AP;&]R97(@:V5I;F4@4WEM8F]L92!S96AE;BP@;?QS
M<V5N(%-I92!D:65S97,@2^1S=&-H96X@;6%R:VEE<F5N+"!U;2!03D<M5')A
M;G!A<F5N>B!A=7-Z=7-T96QL96XN`%=E;FX@4VEE(&1I97-E($YA8VAR:6-H
M="!A;B!3=&5L;&4@96EN92!":6QD97,@<V5H96XL(&MA;FX@26AR($)R;W=S
M97(@9&%S($)I;&0L(&1A<R!3:64@:&]C:&QA9&5N(&WV8VAT96X@;FEC:'0@
M86YZ96EG96XN`$)I;&1V;W)S8VAA=3H`0FEL9"U54DP`0FEL9"U54DPZ`$)I
M;&0@=F]N($=A;&5R:64`0FEL9"!V;VX@1V%L97)I93H`0FEL9"U(;V-H;&%D
M96X`0FEL9&5R`$EM<&]R=&EE<F5N+"!38VAR:71T("5D`$EM<&]R=&EE<G1E
M<R!&96QD.B`E<P!);7!O<G1I97)T92!&96QD97(Z`%IE:6QE(&5I;F;\9V5N
M(%]N86-H`%5N9_QL=&EG92!!:W1I;VX@86YG96=E8F5N+@!5;F?\;'1I9V5R
M($)E;G5T>F5R;F%M92!U;F0O;V1E<B!087-S=V]R="X`1F%L<V-H97(@0F5N
M=71Z97)N86UE(&]D97(@12U-86EL+4%D<F5S<V4N(%9E<G-U8VAE;B!3:64@
M97,@97)N975T(&]D97(@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N(%-Y<W1E
M;6%D;6EN:7-T<F%T;W(L('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I
M9V5N+@!%:6YZ=6<@=F5R9W+VWV5R;@!);F1I96X`16EN>F5L;F4@0F5N=71Z
M97(`26YD;VYE<VEE;@!);F9O<FUA=&EO;@!);F9O<FUA=&EO;F5N`$EN9F]R
M;6%T:6]N96X@;FEC:'0@;65H<B!V97)F_&=B87(N`%9E<F5R8G1E($UI=&=L
M:65D97(`7U-P86QT92!D879O<B!E:6YF_&=E;@!":6QD(&AI;GIU9OQG96X`
M5&%B96QL92!E:6YF_&=E;@!,:6YK(&5I;F;\9V5N`%-?<&%L=&4@9&%N86-H
M(&5I;F;\9V5N`$5I;F4@;F5U92!3<&%L=&4@;F%C:"!D97(@86MT=65L;&5N
M(&5I;F;\9V5N`$5I;F4@;F5U92!3<&%L=&4@=F]R(&1E<B!A:W1U96QL96X@
M96EN9OQG96X`16EN92!N975E(%IE:6QE(&YA8V@@9&5R(&%K='5E;&QE;B!E
M:6YF_&=E;@!%:6YE(&YE=64@6F5I;&4@=F]R(&1E<B!A:W1U96QL96X@96EN
M9OQG96X`16EN96X@;F5U96X@06)S871Z(&YA8V@@9&5M(&%K='5E;&QE;B!%
M;&5M96YT(&5I;F;\9V5N`$5I;F5N(&YE=65N($%B<V%T>B!V;W(@9&5M(&%K
M='5E;&QE;B!%;&5M96YT(&5I;F;\9V5N`$%L=&5R;F%T:79E(%9O<FQA9V4@
M96EN9OQG96X`1V5B96X@4VEE(&5I;F4@12U-86EL+4%D<F5S<V4@86XL(&%N
M(&1I92!D87,@;F5U92!087-S=V]R="!G97-C:&EC:W0@=V5R9&5N('-O;&PZ
M`%IE;&QE(&1A;F%C:"!E:6YF_&=E;@!:96QL92!D879O<B!E:6YF_&=E;@!3
M<&%L=&4@9&%N86-H(&5I;F;\9V5N`%-P86QT92!D879O<B!E:6YF_&=E;@!.
M86-H<FEC:'1E;B!H:6YZ=6;\9V5N`$%B<V%T>B!D86YA8V@@96EN9OQG96X`
M06)S871Z(&1A=F]R(&5I;F;\9V5N`%IE:6QE(&1A;F%C:"!E:6YF_&=E;@!:
M96EL92!D879O<B!E:6YF_&=E;@!'96)E;B!3:64@9&EE($%N='=O<G0@875F
M(&1I92!3:6-H97)H96ET<V9R86=E(&5I;CH`0FEL9"!E:6YF_&=E;B]B96%R
M8F5I=&5N`$QI;FL@96EN9OQG96XO8F5A<F)E:71E;@!:=2!W96YI9R!'=71H
M86)E;BP@=6T@86X@9&EE(%9E<G1E:6QE<FQI<W1E('IU('9E<G-C:&EC:V5N
M+@!:=2!W96YI9R!'=71H86)E;BX`1V%N>GIA:&P`3&ES=&4@=F]N($=A;GIZ
M86AL96X`56YG_&QT:6=E<B!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`56YG
M_&QT:6=E(%I)4"U$871E;BX`56YG_&QT:6=E($%N=V5N9'5N9RX`56YG_&QT
M:6=E($)A=&-H+4E$+@!5;F?\;'1I9V4@1&%T96X@96EN9V5B96XN`%5N9_QL
M=&EG92!::65L861R97-S92X`56YG_&QT:6=E<R!$871E:69O<FUA=`!5;F?\
M;'1I9V5R($QI>F5N>G-C:&S\<W-E;"X`56YG_&QT:6=E<B!/<G0@86YG96=E
M8F5N+@!5;F?\;'1I9V5R(&US9U]T>7!E+@!5;F?\;'1I9V4@;V1E<B!F96AL
M96YD92!A<&E?:60N`%5N9_QL=&EG92!O9&5R(&9E:&QE;F1E(%!A<F%M971E
M<BX`56YG_&QT:6=E<R#<8F5R<F5C:'0N`%5N9_QL=&EG92!087)T;F5R+4E$
M+@!5;F?\;'1I9V5R(%!R;V1U:W1C;V1E+@!5;F?\;'1I9V5S(%!R;W1O:V]L
M;"X`56YG_&QT:6=E<B!%;7!FY&YG97(Z("(E<R(`56YG_&QT:6=E<R!G96UE
M:6YS86UE<R!/8FIE:W0`56YG_&QT:6=E(%5R<W!R=6YG<V%D<F5S<V4N`%5N
M9_QL=&EG92!5;FEC;V1E+41A=&5N+@!);G9E;G1A<@!!=7-W86AL('5M:V5H
M<F5N`$ES;&%M:7-C:&4@4F5P=6)L:6L@27)A;@!)<F%K`$ER;&%N9`!)<VQE
M(&]F($UA;@!697)E:6YZ96QT92!'97=I='1E<@!)<W)A96P`075S<W1E;&QE
M<@!+=7)S:78`271A;&EE;@!*86UA:6MA`$IA;G5A<@!*87!A;@!*87!A;FES
M8V@@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:65N`$IU;&D`2G5N:0!"
M;&]C:W-A='H`6F5N=')I97)E;@!";&]C:W-A='H`3&EN:W,@875S<FEC:'1E
M;@!296-H=',@875S<FEC:'1E;@!+87-A8VAS=&%N`$]R:6=I;F%L(&)E:6)E
M:&%L=&5N/P!+96YI80!+97)B97)O<RU397)V97(@:&%T($%U=&AE;G1I9FEZ
M:65R=6YG('IU<OQC:V=E=VEE<V5N+@!+97)N96PM3F5U;&EN9V4`4V-H;/QS
M<V5L97)Z975G=6YG`$9I;F=E<F%B9')U8VL@9&5S(%-C:&S\<W-E;',`4V-H
M;/QS<V5L;.1N9V4`4V-H;/QS<V5L='EP`%-C:&S\<W-E;'IW96-K`$1E<B!3
M8VAL_'-S96P@8F5F:6YD970@<VEC:"!B97)E:71S(&%U9B!D96T@]F9F96YT
M;&EC:&5N(%-C:&S\<W-E;'-E<G9E<BX`2VEN9&5R`$MI<FEB871I`$1E;6]K
M<F%T:7-C:&4@5F]L:W-R97!U8FQI8R!+;W)E80!297!U8FQI:R!+;W)E80!+
M;W)E86YI<V-H("A%54,M2U(I`$MU=V%I=`!+:7)G:7-I<W1A;@!!;E]P87-S
M96X`4W!R86-H90!,86]S`$QE='IT92!(Y&QF=&4`3&5T>G1E(%!A<W-W;W)T
MY&YD97)U;F<`3&5T>G1E<R!6:65R=&5L`$QE='IT92!!:W1U86QI<VEE<G5N
M9SH`3&5T>G1E($%N;65L9'5N9SH@)7,`3&5T>G1E($%N;65L9'5N9SH@)7,@
M=F]N("5S`$QE='IT92!!;FUE;&1U;F<Z($YO8V@@;FEE`$QE='1L86YD`$=E
M<V5T>@!&;W)M870`3&5E<B!L87-S96X@9OQR(&ME:6YE;B!286AM96X`3&EB
M86YO;@!,:6YK<P!,:6YK92#<8F5R<V-H<FEF=`!,:6YK92!797)T90!,97-O
M=&AO`$5B96YE`$QI8F5R:6$`3&EB>65N`$QI96-H=&5N<W1E:6X`4W!R_&AR
M96=E;@!,96EC:'1E<B!296=E;@!&<OQH(&QE:6-H=&5R(%)E9V5N`%-PY'1E
M<B!,96EC:'1E<B!296=E;@!,96EC:'1E(%)E9V5N<V-H875E<@!,96EC:'1E
M<B!296=E;B!M:70@1V5W:71T97(`3&5I8VAT97(@4V-H;F5E9F%L;`!,96EC
M:'1E(%-C:&YE97-C:&%U97(`3&EM97)I8VL`3&EN:P!,:6YK+5523`!,:6YK
M+5IU9W)I9F9S=&%S=&4`3&EN:R!V97)W96ES="!A=68Z`$QI;FLM6FEE;`!,
M:6YK+51E>'0`12U-86EL+4%D<F5S<V4@=F5R;&EN:V5N/P!,:6YK+51I=&QE
M+4%T=')I8G5T`$QI;FMS`$QI;G5X+4=L_&-K<VME:W-E`$QI<W0@+2!"96YU
M='IE<B!K86YN(&1E;B!/<F1N97(@<V5H96X`1&%T96YB86YK96X@86YZ96EG
M96X`2&EL9F5E:6YT<N1G92!A;GIE:6=E;@!486)E;&QE;B!A;GIE:6=E;@!,
M:7-T96XM07)C:&EV`$QI<W1E;BU(:6QF90!,:7-T96XM260`3&ES=&5N+4)E
M<VET>F5R`$QI<W1E;BU!9')E<W-E`$QI<W1E;BU!;FUE;&1U;F<`3&ES=&5N
M+4%B;65L9'5N9P!$87,@06YZ96EG96X@9&5R(%-E<W-I;VYS(&ES="!F96AL
M9V5S8VAL86=E;CH@)7,`1&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!I<W0@
M9F5H;&=E<V-H;&%G96XZ("5S`$1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@
M:7-T(&YI8VAT(&WV9VQI8V@N`$QI=&5R871U<@!,:71A=65N`$QA9&4N+BX`
M3&]K86QE(%5H<GIE:70Z(`!3<')A8VAE('5N9"!:96ET`$]R=`!!;FUE;&1E
M;@!,;V<@9&5R(&QE='IT96X@4WEN8VAR;VYI<V%T:6]N+@!!8FUE;&1E;@!!
M;FUE;&1E;@!!;FUE;&1E875F9V%B96X`1&EE($%N;65L9'5N9R!I<W0@9F5H
M;&=E<V-H;&%G96XL('=E:6P@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@;V1E
M<B!):'(@4&%S<W=O<G0@9F%L<V-H(&5I;F=E9V5B96X@:&%B96XN`$%N;65L
M9'5N9R!F96AL9V5S8VAL86=E;BX`3&%N9V5R(%1E>'0`3&EE8F4`3FEE9')I
M9P!+;"X@9W)I96-H:7-C:&4@0G5C:'-T86)E;@!+;"X@;&%T96EN:7-C:&4@
M0G5C:'-T86)E;@!+;"X@<O9M:7-C:&4@6F%H;&5N`$QU>&5M8G5R9P!-30!-
M3U1$`$U3+51.148M06YH86YG(&5N=&AI96QT(&ME:6YE($1A=&5N+@!(24Y7
M14E3`$UA8V%O`$1I92!E:&5M86QI9V4@2G5G;W-L87=I<V-H92!297!U8FQI
M:R!-87IE9&]N:65N`$UA9&%G87-K87(`36%G:64`5V5B;6%I;`!%+4UA:6P@
M061M:6YI<W1R871I;VX`3&EN:R!?86YL96=E;BXN+@!-86QA=VD`36%L87ES
M:6$`36%L:61I=F5N`$UA;&D`36%L=&$`5F5R=V%L=&5N(%-I92!D:64@2V%T
M96=O<FEE;BP@;6ET(&1E;F5N(%-I92!%;&5M96YT92!U;F0@16EN='+D9V4@
M:V5N;GIE:6-H;F5N(&OV;FYE;BP@<V]W:64@9&EE('IU9V5H]G)I9V5N($9A
M<F)E;BX`36%P,C0M2V%R=&4`36%P475E<W0M2V%R=&4`6G5O<F1N=6YG96X@
M9V5S<&5I8VAE<G0N`$WD<GH`077?96YA8G-T86YD`$UI="!'96QE<V5N+2]5
M;F=E;&5S96XM4W1A='5S('9E<G-E:&5N`$UI="!A;F1E<F5M(%-T871U<R!V
M97)S96AE;B`H>BY"+B!7:6-H=&EG+T)E86YW;W)T970I`$UA<G-H86QL:6YS
M96QN`$UA<G1I;FEQ=64`6G5G96]R9&YE=&4@1F5L9&5R`$UA=7)E=&%N:65N
M`$UA=7)I=&EU<P!-87AI;6%L(&5R;&%U8G1E<B!+<F5D:70N`$UA>&EM86QE
M($YA8VAT:6-H=&5N=&5I;&4@_&)E<G-C:')I='1E;BX`2/9C:'-T=&5M<&5R
M871U<B!D97(@;&5T>G1E;B`R-"!3='5N9&5N.B``2/9C:'-T=&5M<&5R871U
M<B!D97(@;&5T>G1E;B`V(%-T=6YD96XZ(`!-87AI;6%L92!!;GIA:&P@86X@
M4&]R=&%L8FSV8VME;@!-87AI;6%L92!,Y&YG90!-86D`36%Y;W1T92!)<VQA
M;F0`365D:7II;@!-:71G;&EE9&5R`$UE;OQM;V1U<SH`6F5L;&5N('IU<V%M
M;65N9OQG96X`3F%C:')I8VAT`$1I92!.86-H<FEC:'0@:V]N;G1E(&5R9F]L
M9W)E:6-H(/QB97)P<OQF="!W97)D96X@86)E<B!N:6-H="!D87,@6F5R=&EF
M:6MA="!D97,@06)S96YD97)S+@!.86-H<FEC:'0@;FEC:'0@;65H<B!G_&QT
M:6<N`$YA8VAR:6-H=&5N='EP`$UE=&%R(%=E='1E<@!-971A<F)L;V-K(&YI
M8VAT('9E<F;\9V)A<BX`365T87)B;&]C:R!N:6-H="!V97)F_&=B87(N($1E
M=&%I;',@=W5R9&5N(&;\<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T
M+@!+96EN92!697)B:6YD=6YG('IU<B!-971A<D1"+@!-971H;V1E`$1I92!-
M971H;V1E("(E<R(@:7-T(&YI8VAT(&1E9FEN:65R=`!-971H;V1E(&YI8VAT
M(&1E9FEN:65R="X@075F9V5R=69E;F4@365T:&]D93H@)7,`365T<FES8V@`
M365X:6MO`$;V9&5R:65R=&4@4W1A871E;B!V;VX@36EK<F]N97-I96X`36ET
M=&4`36EM971Y<`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T
M=6YD96XZ(`!4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#8@4W1U;F1E
M;CH@`$1A<R!M:6YI;6%L92!087-S=V]R=&%L=&5R(&ES="!N;V-H(&YI8VAT
M(&%B9V5L875F96X`4W!I96=E;&X`5F5R<V-H:65D96YE<P!014%2+5!A:V5T
M($A45%!?4F5Q=65S="!F96AL="X`1F5H;&5N9&4@2V]N9FEG=7)A=&EO;BX@
M4VEE(&W\<W-E;B!D:65S92!J971Z="!E<GIE=6=E;BP@=V5N;B!3:64@9&EE
M($%N=V5N9'5N9R!V97)W96YD96X@;?9C:'1E;BX`1F5H;&5N9&4@3F%C:')I
M8VAT96XM240N`%!%05(M4&%K970@36%I;"!F96AL="X`1F5H;&5N9&4@4VET
M>G5N9W,M240N`$UO`$4M36%I;"!-;V)I;`!-Y-]I9P#$;F1E<G5N9W-D871U
M;0!54DP@8F5A<F)E:71E;@!-;V1U;'5S`%)E<'5B;&EK($UO;&1A=0!-;VYA
M8V\`36]N9V]L96D`36]N870@=6YD($IA:'(`36]N871L:6-H`$UO;G1S97)R
M870`36]N9'!H87-E;@!-96AR($9E;&1E<B!I;B!:96EL92`E9"!A;',@9&EE
M(&5R=V%R=&5T96X@)60@9V5F=6YD96XN`$UA<F]K:V\`W&)E<G=I96=E;F0@
M:&5I=&5R`-QB97)W:65G96YD($)E=_9L:W0`W&)E<G=I96=E;F0@0F5W]FQK
M="!U;F0@5VEN9&EG`-QB97)W:65G96YD(%-O;FYI9P!.86-H('5N=&5N`$YA
M8V@@;&EN:W,`3F%C:"!R96-H=',`3F%C:"!O8F5N`$YA8V@@=6YT96X`3F%C
M:"!O8F5N`$UO<V%M8FEK`$%U<W=A:&QL:7-T92!I;B!M96AR97)E;B!%8F5N
M96X`375L=&EM87`M54LM2V%R=&4`365H<F9A8VAA=7-W86AL`$UE:6X@2V]N
M=&\`365I;B!+;VYT;P!-96EN(%!O<G1A;`!-96EN(%!O<G1A;&QA>6]U=`!"
M=7)M80!.14E.+"!I8V@@<W1I;6UE($Y)0TA4('IU`$YA;64`3F%M:6)I80!.
M875R=0!.97!A;`!.:65D97)L86YD90!.:65D97)LY&YD:7-C:&4@06YT:6QL
M96X`3F5T<V-A<&4M0F%S:7,M55),`$YE='-C87!E+4-!+5-P97)R=6YG<RU5
M4DP`3F5T<V-A<&4M0T$M4FEC:'1L:6YI96XM55),`$YE='-C87!E+5IE=&EF
M:6MA='-E<FYE=65R=6YG<RU54DP`3F5T<V-A<&4M4W!E<G)U;F=S+5523`!.
M971S8V%P92U34TPM4V5R=F5R;F%M90!.971S8V%P92U+;VUM96YT87(`3F5T
M<V-A<&4M6F5R=&EF:6MA='1Y<`!.971Z=V5R:P!.:64`3F5U:V%L961O;FEE
M;@!.975E($MA=&5G;W)I90!.975M;VYD`$YE=65R($)E;G5T>F5R;F%M92`H
M;W!T:6]N86PI`$YE=7-E96QA;F0`3F5U97,@4&%S<W=O<G0`1&%S(&YE=64@
M4&%S<W=O<F0@=VER9"!A;2`E>"!A8FQA=69E;BX`1&EE(&YE=65N(%!A<W-W
M]G)T97(@<W1I;6UE;B!N:6-H="#\8F5R96EN+@!.975E<R!&96YS=&5R("A?
M8FQA;FLI`$YA8VAR:6-H=&5N`$YE=W-G<G5P<&5N`%=E:71E<@!.Y&-H<W1E
M(#0@4&AA<V5N`$[D8VAS=&4@16EN<W1E;&QU;F=E;@!796ET97(^`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YA8VAT<P!.:75E`$YE:6X`2V5I;F4@2V]N
M9FEG=7)A=&EO;G-D871E;B!V97)F_&=B87(L('5M(%5N=&5R<V-H:65D92!A
M;GIU>F5I9V5N+@!+96EN92!3=')A=&5G:64@>G5M($5R<W1E;&QE;B!V;VX@
M25-/+4%B8FEL9&5R;B!V97)F_&=B87(N`$ME:6YE($)A=&-H+59O<FQA9V4N
M`$5S(&5X:7-T:65R="!K96EN($)L;V-K(&%N(&1E<B!A;F=E9V5B96YE;B!0
M;W-I=&EO;@!+96EN($MA;&5N9&5R;F%M92!F_'(@9&EE($U#04PM075T:&5N
M=&EF:7II97)U;F<@86YG96=E8F5N+@!+96EN92#$;F1E<G5N9V5N+@!5;G1E
M<FAA;&(@9&EE<V5R($5B96YE(&OV;FYE;B!K96EN92!W96ET97)E;B!5;G1E
M<G)E8VAT92!H:6YZ=6=E9OQG="!W97)D96XN`$;\<B`E<R!W=7)D96X@:V5I
M;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N9V5G96)E;BX`1OQR
M(&1E;B!&5%`M5D93+51R96EB97(@=W5R9&5N(&ME:6YE($MO;F9I9W5R871I
M;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$;\<B!D96X@4U%,+59&4RU4
M<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N
M96X@86YG96=E8F5N+@!&_'(@9&5N(%-13"U$871E:2U61E,M5')E:6)E<B!W
M=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N9V5G
M96)E;BX`2V5I;B!+<F5D:70@;65H<B#\8G)I9RX`2V5I;B!%;7!FY&YG97(@
M86YG96=E8F5N+@!+96EN92!$871E:2!H;V-H9V5L861E;@!+96EN92!)8V]N
M<R!G969U;F1E;BX`17,@=W5R9&4@:V5I;B!/<G0@9F5S=&=E;&5G="X`2V5I
M;B!/<G0@86YG96=E8F5N+@!+96EN92!.86-H<FEC:'0@86YG96=E8F5N+@!+
M96EN($YA;64@86YG96=E8F5N+@!+96EN92!.=6UM97(@86YG96=E8F5N+@!+
M96EN92!A;G-T]M]I9V5N($=L_&-K<VME:W-E`$ME:6X@4&%S<W=O<G0@9OQR
M(&1I92!(5%10+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!0
M87-S=V]R="!F_'(@9&EE($E-05`M075T:&5N=&EF:7II97)U;F<@86YG96=E
M8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@2V5R8F5R;W,M075T:&5N=&EF
M:7II97)U;F<@86YG96=E8F5N+@!+96EN(%!A<W-W;W)T(&;\<B!D:64@3&]G
M:6XM075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+96EN(%!A<W-W;W)T
M(&;\<B!D:64@4$%34U=$+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`
M2V5I;B!087-S=V]R="!F_'(@9&EE(%--0BU!=71H96YT:69I>FEE<G5N9R!A
M;F=E9V5B96XN`$ME:6X@4&9A9"!Z=6T@3W!E;E-33"U0<F]G<F%M;2!A;F=E
M9V5B96XN($1A<R!/<&5N4U-,+5!R;V=R86UM('=I<F0@8F5N]G1I9W0L('5M
M(%!+0U,M,3(M1&%T96X@=F5R87)B96ET96X@>G4@:_9N;F5N+@!+96EN92!A
M=7-S=&5H96YD96X@4F5G:7-T<FEE<G5N9V5N+@!+96EN(%-P96EC:&5R<&QA
M='HM2V]N=&EN9V5N="!F97-T9V5L96=T+@!+96EN92!286AM96X`2V5I;B!4
M<F5N;GIE:6-H96X@86YG96=E8F5N+@!+96EN92!396ET96X`1&%T96D@;FEC
M:'0@9V5F=6YD96X`2V5I;F4@=&5M<&]RY')E<R!697)Z96EC:&YI<R!F_'(@
M9&5N($-A8VAE(&=E9G5N9&5N+@!+96EN($)E;G5T>F5R;F%M92!U;F0O;V1E
M<B!087-S=V]R="!A;F=E8F5N+@!%<R!W=7)D96X@:V5I;F4@9_QL=&EG96X@
M6$U,+41A=&5N('IU<OQC:V=E9V5B96X`2V5I;F4@5V5R=&4`2V5I;F4@5F5R
M<VEO;G-N=6UM97(@:6X@9&5R($]R:6=I;F%L:V]N9FEG=7)A=&EO;B!G969U
M;F1E;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG=7)A=&EO;BX`2V5I;F4@
M5F5R<VEO;G-N=6UM97(@:6X@26AR97(@2V]N9FEG=7)A=&EO;B!G969U;F1E
M;BX@17)N975E<FX@4VEE($EH<F4@2V]N9FEG=7)A=&EO;BX`2V5I;F4`2V5I
M;G,@*%-T86YD87)D(&)E;G5T>F5N*0!.;W)D:7-C:"`H25-/+3@X-3DM,3`I
M`$YO<F9O;&MI;G-E;`!.]G)D;&EC:&4@2&5M:7-P:&5R90!.]G)D;&EC:&4@
M36%R:6%N96X`3F]R=V5G96X`1_QL=&EG(&)I<P!'_&QT:6<@86(`2V5I;B!6
M97)Z96EC:&YI<P!.:6-H="!G969U;F1E;BX`3FEC:'0@:6UP;&5M96YT:65R
M="X`3FEC:'0@9F5S=&=E;&5G=`!.:6-H="!U;G1E<G-T_'1Z="X`3F]T:7IE
M;@!.:6-H=',@86YZ=7IE:6=E;BP@8FET=&4@>G5R_&-K9V5H96XN`$YO=F5M
M8F5R`%IA:&P`06YZ86AL(&1E<B!:96EC:&5N`$%N>F%H;"!D97(@4W!A;'1E
M;@!!;GIA:&P@9&5R(%IE:6QE;@!+96EN92!.=6UM97)N(&;\<B!D:64@5F5R
M=&5I;&5R;&ES=&4@86YG96=E8F5N+@!/2P!/8FIE:W0`3V)J96MT97)S=&5L
M;&5R`$]K=&%L>F%H;`!/:W1O8F5R`$9I;'1E<B!F_'(@86YS=/;?:6=E($EN
M:&%L=&4`0OQR;P!):'(@;F5U97,@4&%S<W=O<G0@;75S<R!S:6-H('9O;B!)
M:')E;2!A;'1E;B!U;G1E<G-C:&5I9&5N+@!!;'1E<R!087-S=V]R=`!&86QS
M8VAE<R!A;'1E<R!087-S=V]R="X`3VUA;@!/;F-L:6-K+45V96YT`$YU<B!)
M34%0+5-E<G9E<B!U;G1E<G-T_'1Z96X@9V5M96EN<V%M92!/<F1N97(N`$YU
M<B!A;G-T]M]I9V4@1VS\8VMS:V5K<V4`3G5R(&5I;F4@12U-86EL+4%D<F5S
M<V4@97)L875B="X`3G5R(&1E<B!"97-I='IE<B!O9&5R(&1E<B!3>7-T96UA
M9&UI;FES=')A=&]R(&MA;FX@9&5N($)E<VET>F5R(&]D97(@9&EE($)E<VET
M>F5R<F5C:'1E(.1N9&5R;@!);B!N975E;2!&96YS=&5R(/9F9FYE;@!/<&5N
M4U-,+49E:&QE<CH@4VEG;FEE<G1E(%,O34E-12U$871E;B!K;VYN=&5N(&YI
M8VAT(&5X=')A:&EE<G0@=V5R9&5N+@!$:65S96X@3&EN:R!I;B!E:6YE;2!N
M975E;2!&96YS=&5R(/9F9FYE;@!"971R:65B<WES=&5M`$5I;G-T96QL=6YG
M96X`16EN<W1E;&QU;F=E;B!F_'(@)7,`3G5M;65R:65R=&4@3&ES=&4`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;G-A8G1E:6QU;F<`3W)G86YI<VEE<F5N
M`$]R:6=I;F%L=F]R;&%G92!D97(@06YW96YD=6YG`$]R:6=I;F%L=F]R;&%G
M92!I;B`E<SH`4V]N<W1I9V4`06YD97)E($EN9F]R;6%T:6]N96X`0F5S:71Z
M97)R96-H=&4`4$%-+4%U=&AE;G1I9FEZ:65R=6YG(&ES="!N:6-H="!V97)F
M_&=B87(N`%!%05(Z.DUA:6PM0F%C:V5N9`!$:6=I=&%L92!01U`M56YT97)S
M8VAR:69T`%!'4"UV97)S8VAL_'-S96QT92!$871E;@#69F9E;G1L:6-H97(@
M4$=0+5-C:&S\<W-E;`!-:70@4$=0('5N=&5R>F5I8VAN971E+W9E<G-C:&S\
M<W-E;'1E($1A=&5N`%!(4"!#;V1E`%!(4"!3:&5L;`!6;W)M:71T86=S(&QE
M:6-H=&5R(%)E9V5N`$YA8VAM:71T86=S(%)E9V5N`$YA8VAM:71T86=S(%-C
M:&%U97(`3F%C:&UI='1A9W,@4V-H;F5E`$YA8VAM:71T86=S(%-C:&YE97-C
M:&%U97(`3F%C:&UI='1A9W,@4V]N;F4`3F%C:&UI='1A9W,@1V5W:71T97(`
M1&EE(%!/4TE8+45R=V5I=&5R=6YG(&9E:&QT`%]02%`@4VAE;&P`26YN96YA
M8G-T86YD`%!A:VES=&%N`%!A;&%U`$)E<V5T>G1E(%!A;.1S=&EN96YS:7-C
M:&4@1V5B:65T90!086YA;6$`4&%P=6$M3F5U9W5I;F5A`%!A<F%G=6%Y`%1E
M:6QW96ES92!"97?V;&MT`%!A<W-W;W)T`%!A<W-W;W)T(&5R9F]L9W)E:6-H
M(&=EY&YD97)T+@!&86QS8VAE<R!087-S=V]R=`!+96EN(%!A<W-W;W)T(&;\
M<B!D:64@4D%$2553+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`4&%S
M<W=O<G0@;6ET($)E<W3D=&EG=6YG`%!A<W-W;W)T.@!087-S=V]R=#H@`$1I
M92!087-S=_9R=&5R(&W\<W-E;B!G;&5I8V@@<V5I;BX`16EN9OQG96X`5F]N
M(&1E<B!:=VES8VAE;F%B;&%G92!E:6YF_&=E;@!09F%D`$%U<W-T96AE;F1E
M(%)E9VES=')I97)U;F=E;CH`4&5R<V]N96X`4')O>F5N=`!787)T=6YG<V%R
M8F5I=&5N(&1U<F-H9OQH<F5N`%=A<G1U;F=S87)B96ET96X@;F%C:"!D97(@
M06YM96QD=6YG(&1U<F-H9OQH<F5N/P!296-H=&4`4F5C:'0@(B5S(B!W=7)D
M92!N:6-H="!G96SV<V-H="X`6G5G<FEF9B!V97)W96EG97)T`%)E8VAT90!2
M96-H=&5V97)W86QT=6YG`%!E<G/V;FQI8VAE($%N9V%B96X`4&5R=0!(875S
M=&EE<F4`4&AI;&EP<&EN96X`5&5L969O;@!&;W1O<P!0:71C86ER;@!0:7AE
M;`!0;&%T=&AE:71E;@!":71T92!K;&EC:V5N(%-I92!I;B!E:6YE(%IE;&QE
M`$)I='1E(&)E<W3D=&EG96X@4VEE+"!D87-S(%-I92!D:65S97,@16QE;65N
M="!L]G-C:&5N(&WV8VAT96XZ`$)I='1E(&)E=.1T:6=E;B!3:64L(&1A<W,@
M4VEE(&1E;B!,:6YK('9O;B!D:65S96T@16QE;65N="!E;G1F97)N96X@;?9C
M:'1E;BX`0FET=&4@96EN96X@36]N870@=6YD(&5I;B!*86AR(&%N9V5B96XN
M`$)I='1E(&=E8F5N(%-I92!E:6YE;B!.86UE;B!F_'(@9&EE(&YE=64@2V%T
M96=O<FEE(&%N.@!":71T92!E:6YE(&?\;'1I9V4@25`M061R97-S92!E:6YG
M96)E;BX`0FET=&4@9V5B96X@4VEE(&5I;B!G_&QT:6=E<R!$871U;2!A;CL@
M_&)E<G!R_&9E;B!3:64@9&EE(%IA:&P@9&5R(%1A9V4@:6X@9&5M($UO;F%T
M+@!":71T92!E:6YE;B!G_&QT:6=E;B!:96ET=V5R="!E:6YG96)E;BX`0FET
M=&4@9V5B96X@4VEE(&5I;F4@6G5S86UM96YF87-S=6YG($EH<F5S(%!R;V)L
M96US(&%N+@!":71T92!G96)E;B!3:64@26AR96X@0F5N=71Z97)N86UE;B!U
M;F0@26AR(%!A<W-W;W)T(&%N`$)I='1E(&QE<V5N(%-I92!S:6-H(&1E;B!F
M;VQG96YD96X@5&5X="!S;W)G9N1L=&EG(&1U<F-H+B!3:64@3=Q34T5.(&1I
M97-E;B!"961I;F=U;F=E;B!Z=7-T:6UM96XL('=E;FX@4VEE(&1I97-E<R!3
M>7-T96T@8F5N=71Z96X@;?9C:'1E;BX`0FET=&4@9&5N(&YE=65N($MA=&5G
M;W)I96YA;65N(&5I;F=E8F5N.@!0;VQE;@!0;VQI=&EK`%5M9G)A9V5N`%!O
M<G1U9V%L`%!O<VET:6]N:65R=6YG(&1I97-E($)I;&1E<P!0;W-I=&EO;FEE
M<G5N9R!D:65S97(@5&%B96QL90!396YD96X@86X@9&EE<V5N($]R9&YE<B`H
M;FEC:'0@9'5R8V@@24U!4"D`3FEE9&5R<V-H;&%G(&EN(&1E;B!L971Z=&5N
M("5S(%-T=6YD92AN*3H@`$YI961E<G-C:&QA9W,M/&)R("\^=V%H<G-C:&5I
M;FQI8VAK96ET`%!R969S7VQD87`Z($1I92!B96[V=&EG=&4@3$1!4"U%<G=E
M:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`4')E9G-?<V5S<VEO;CH@
M1&EE(&)E;O9T:6=T92!397-S:6]N+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT
M(&=E9G5N9&5N+@!,=69T9')U8VL`3'5F=&1R=6-K(&%U9B!3965H]FAE.B``
M3'5F=&1R=6-K.B``5F]R<V-H874`16EN92!6;W)S8VAA=2!D97,@0FEL9&5S
M(&EN(&5I;F5M(&YE=65M($9E;G-T97(@86YZ96EG96X`5F]H97)I9V4@16EN
M<W1E;&QU;F=E;@!$;VMU;65N="!D<G5C:V5N`%!R:79A=&5R(%-C:&S\<W-E
M;`!0<F]B;&5M90!0<F]B;&5M8F5S8VAR96EB=6YG`%!R;VIE:W1E`$YA8VAF
M<F%G971E>'0`UF9F96YT;&EC:&5R(%-C:&S\<W-E;`!!;&=O<FET:&UU<R!D
M97,@]F9F96YT;&EC:&5N(%-C:&S\<W-E;',`26YF;W)M871I;VYE;B!Z=6T@
M]F9F96YT;&EC:&5N(%-C:&S\<W-E;`!$87,@]F9F96YT;&EC:&4O<')I=F%T
M92!38VAL_'-S96QP86%R(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN
M`%!U97)T;R!2:6-O`$YA8VAR:6-H=&5N(&5N9&?\;'1I9R!L]G-C:&5N`$MA
M=&%R`$%B9G)A9V4`4W!E:6-H97)P;&%T>BU+;VYT:6YG96YT`-9F9F5N=&QI
M8VAE<B!24T$@4V-H;/QS<V5L("@E9"!":70I`$%U<W=A:&QK;F]P9@!296=E
M;@!&<OQH(%)E9V5N`%-PY'1E<B!296=E;@!296=E;G-C:&%U97(`4V-H;F5E
M<F5G96X`4F5G96X@:6X@4V-H;F5E(/QB97)G96AE;F0`1VS\8VMS:V5K<P!6
M97)HY&QT;FES`$QE<V5N`$YA8VAR:6-H=&5N(&QE<V5N`"5S('=I<FML:6-H
M(&SV<V-H96X_($1I97-E<B!6;W)G86YG(&MA;FX@;FEC:'0@<OQC:V?D;F=I
M9R!G96UA8VAT('=E<F1E;BX`1&%T96X@9&5S($)E;G5T>F5R<R`E<R!W:7)K
M;&EC:"!L]G-C:&5N/R!$:65S97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMG
MY&YG:6<@9V5M86-H="!W97)D96XN`$;\:')T(&QE='IT92!!:W1I;VX@97)N
M975T(&%U<P!!:W1U86QI<VEE<F4`1'EN86UI<V-H92!-96[\96QE;65N=&4@
M86MT=6%L:7-I97)E;CH`4&]R=&%L86YS:6-H="!A:W1U86QI<VEE<F5N.@!2
M96=U;.1R97(@075S9')U8VL`5F5R8FEN9'5N9W,M0G)O=W-E<@!!:W1U86QI
M<VEE<F5N`$)E;65R:W5N9V5N`$5N=&9E<FYT92!397)V97(`4V5R=F5R861R
M97-S92`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$5N=&9E<FYE
M;@!";&]C:R!L]G-C:&5N`%-P86QT92!L]G-C:&5N`$9O<FUA=&EE<G5N9R!E
M;G1F97)N96X`4&%A<B!L]G-C:&5N`$=E<W!E:6-H97)T97,@4VMR:7!T(&%U
M<R!D96T@=&5M<&]RY')E;B!697)Z96EC:&YI<R!E;G1F97)N96XN`$5N=&9E
M<FYE`$1I97-E<R!%;&5M96YT(&%U<R!D96T@1&]K=6UE;G0@96YT9F5R;F5N
M`$)E;G5T>F5R(&SV<V-H96X`0F5N=71Z97(@;/9S8VAE;CH@)7,`06YF<F%G
M92!K;VYN=&4@;FEC:'0@8F5A;G1W;W)T970@=V5R9&5N+B!:=7+\8VMG96=E
M8F5N97(@1F5H;&5R8V]D93H@`$1E<B!G97?\;G-C:'1E($1I96YS="!K;VYN
M=&4@;FEC:'0@9V5F=6YD96X@=V5R9&5N+@`B)7,B('=U<F1E(&EN(&1E<B!+
M;VYF:6=U<F%T:6]N(&;\<B`E<R!N:6-H="!A;F=E9V5B96XN`"(E<R(@=W5R
M9&4@:6X@9&5R(%9&4RU+;VYF:6=U<F%T:6]N(&YI8VAT(&%N9V5G96)E;BX`
M(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A=&EO;B!N:6-H="!A;F=E9V5B
M96XN`$YO='=E;F1I9V5S($9E;&0`6G5R_&-K<V5T>F5N`%!A<W-W;W)T('IU
M<OQC:W-E='IE;@!3971Z96X@4VEE($EH<B!087-S=V]R="!Z=7+\8VL`3&5T
M>G1E($%B9G)A9V4@96EN9OQG96X`17)G96)N:7-S90!:=7+\8VL@>G4@16EN
M<W1E;&QU;F=E;@!.975E<R!087-S=V]R="!E<FYE=70@96EN9V5B96X`4NEU
M;FEO;@!+;VYF:6=U<F%T:6]N('IU<OQC:W-E='IE;@!765-)5UE'+45D:71O
M<B!%:6YS=&5L;'5N9V5N`%+D='-E;`!296-H=',`4F5C:'1E(-QB97)S8VAR
M:69T`%)E8VAT92!797)T90!?6F5I;&5N96EG96YS8VAA9G1E;BXN+@!2;VQL
M90!2=6WD;FEE;@!5;2`Q.#"P(&1R96AE;@!.86-H(&QI;FMS(&1R96AE;@!.
M86-H(')E8VAT<R!D<F5H96X`6F5I;&5N96EG96YS8VAA9G1E;@!:96EL96YE
M:6=E;G-C:&%F=&5N`%IE:6QE;CH`4F5G96QN`%)A:&UE;B!Z=VES8VAE;B!A
M;&QE;B!:96EL96X@=6YD(%-P86QT96X`4F%H;65N(&YU<B!Z=VES8VAE;B!3
M<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@6F5I;&5N`%-T87)T96X`4G5S
M<VES8VAE($;V<F1E<F%T:6]N`%)U86YD80!3+TU)344@:W)Y=&]G<F%P:&ES
M8VAE(%5N=&5R<V-H<FEF=`!-:70@4R]-24U%('9E<G-C:&S\<W-E;'1E($YA
M8VAR:6-H=`!305-,+4%U=&AE;G1I9FEZ:65R=6YG(&ES="!N:6-H="!V97)F
M_&=B87(N`%--4RU697)S86YD`%-13"!3:&5L;`!344PM06YW96ES=6YG('IU
M<B!!8F9R86=E(&1E<B!797)T90!34T@`15)&3TQ'`%-?44P@4VAE;&P`4V$`
M4V%I;G0@2&5L96YA`%-A:6YT($MI='1S('5N9"!.979I<P!386EN="!,=6-I
M80!386EN="!0:65R<F4@=6YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@=6YD
M(&1I92!'<F5N861I;F5N`$=L96EC:&5R(%)A:&UE;B`H7W-E;&8I`%-A;6]A
M`%-A;B!-87)I;F\`4V%O(%1O;64@=6YD(%!R:6YC:7!E`%-A=&5L;&ET96YP
M<F]V:61E<@!3875D:2U!<F%B:65N`%-P96EC:&5R;@`B)7,B('-P96EC:&5R
M;@`E<R!S<&5I8VAE<FX`16EN<W1E;&QU;F=E;B!S<&5I8VAE<FX`17)Z975G
M=&4@2V]N9FEG=7)A=&EO;B!A;',@4$A0+5-K<FEP="!I;2!T96UP;W+D<F5N
M(%9E<GIE:6-H;FES($EH<F5S(%-E<G9E<G,@<W!E:6-H97)N+@`E<RU+;VYF
M:6=U<F%T:6]N(&=E<W!E:6-H97)T+@!$87,@06MT=6%L:7-I97)U;F=S<VMR
M:7!T('=U<F1E(&EN("(E<R(@9V5S<&5I8VAE<G0N`%9E<F5I;GIE;'1E($=E
M=VET=&5R`%=I<W-E;G-C:&%F=`!3=6-H90!3=6-H;6%S8VAI;F5N`$1A=&5I
M96X@875S=^1H;&5N`$1A='5M(&%U<W?D:&QE;@!(:6YZ=7IU9OQG96YD92!'
M<G5P<&5N(&%U<W?D:&QE;@!.975E;B!"97-I='IE<B!A=7-WY&AL96X`4V5R
M=F5R(&%U<W?D:&QE;@!(:6YZ=7IU9OQG96YD96X@0F5N=71Z97(@875S=^1H
M;&5N`$%L;&4@875S=^1H;&5N`$QE9V5N(%-I92!A;&QE($1A='5M<VMO;7!O
M;F5N=&5N(&9E<W0N`$]B:F5K="!A=7-WY&AL96X`2V5I;F5N(&%U<W?D:&QE
M;@!7Y&AL96X@4VEE(&1I92!B96[V=&EG=&5N(%IE:6-H96X@875S(&1E;B!J
M97=E:6QI9V5N($9E;&1E<FX@875S+B!$86YN(&OV;FYE;B!3:64@9&EE<V4@
M875S(&1E;2!497AT9F5L9"!K;W!I97)E;B!U;F0@:6X@26AR92!.86-H<FEC
M:'0@96EN9OQG96XN`%?D:&QE;B!3:64@9&%S($1A='5M<W1R96YN>F5I8VAE
M;CH`5^1H;&5N(%-I92!D87,@1&%T=6US9F]R;6%T.@!7Y&AL96X@4VEE(&1I
M92!)9&5N=&ETY'0L(&1I92!3:64@Y&YD97)N(&WV8VAT96XZ`%?D:&QE;B!3
M:64@9&%S(%IE:71T<F5N;GIE:6-H96XZ`%?D:&QE;B!3:64@9&%S(%IE:71F
M;W)M870Z`%?D:&QE;B!3:64@>G=E:2!Z=7-A;6UE;F=E:/9R:6=E($9E;&1E
M<B!A=7,N`%?D:&QE;B!3:64@96EN($9A<F)S8VAE;6$N`%?D:&QE;B!3:64@
M26AR92!B979O<GIU9W1E(%-P<F%C:&4Z`%!R;V)L96UB97)I8VAT(&%B<V-H
M:6-K96X`4TU3('9E<G-C:&EC:V5N`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<F)I96X@=6YD($UO;G1E;F5G<F\`4V5R:65N;G5M;65R`%-E<G9E
M<F1A=&5N('5N9_QL=&EG(&]D97(@;FEC:'0@=F5R9OQG8F%R+@!397-S<VEO
M;G9E<G=A;'1U;F<`4V5S<VEO;BU)1"!A8F=E;&%U9F5N+@!3:71Z=6YG96X`
M075S=V%H;"U3871Z`$QE9V5N(%-I92!D:64@16EN<W1E;&QU;F=E;B!F97-T
M+"!D:64@97,@26AN96X@97)L875B96X@26AR(%!A<W-W;W)T('IU<OQC:WIU
M<V5T>F5N+"!F86QL<R!S:64@97,@96EN;6%L('9E<F=E<W-E;B!S;VQL=&5N
M+@!,96=E;B!3:64@96YT9F5R;G1E(%-E<G9E<B!F97-T+"!A=68@9&EE(%-I
M92!V;VX@26AR96T@4&]R=&%L(&%U<R!Z=6=R96EF96X@;?9C:'1E;BX`5^1H
M;&5N(%-I92!):')E(&)E=F]R>G5G=&4@4W!R86-H92P@6F5I='IO;F4@=6YD
M($1A='5M<V5I;G-T96QL=6YG96XN`$QE9V5N(%-I92!D87,@9&EE(%-T87)T
M86YW96YD=6YG+"!D87,@1F%R8G-C:&5M82P@9&EE(%-E:71E;F%K='5A;&ES
M:65R=6YG('5N9"!A;F1E<F4@06YZ96EG965I;G-T96QL=6YG96X@9F5S="X`
M2V]N9FEG=7)A=&EO;@!!:W1U86QI<VEE<G5N9W-S:W)I<'1E('-I;F0@=F5R
M9OQG8F%R`$UE:')E<F4@<&%S<V5N9&4@3W)T92!M:70@9&EE<V5M(%!A<F%M
M971E<CH@`%-E>6-H96QL96X`16EN:V%U9@!+=7)Z92!:=7-A;6UE;F9A<W-U
M;F<`4V]L;&5N(%1A<W1E;FMO;6)I;F%T:6]N96X@9OQR(&1I92!M96ES=&5N
M($QI;FMS(&%K=&EV:65R="!W97)D96X_`%IE:6=E;@!5;G1E<G-C:&EE9&4@
M>G=I<V-H96X@9&5R(&%K='5E;&QE;B!U;F0@9&5R(&=E<F%D92!E<GIE=6=T
M96X@2V]N9FEG=7)A=&EO;B!A;GIE:6=E;BX`06YZ96EG96XL('=A;FX@9&EE
M(&QE='IT92!!;FUE;&1U;F<@97)F;VQG="!I<W0_`$5R:&%L=&5N(&1E<R!/
M<FEG:6YA;',@97)M]F=L:6-H96X`075S=^1H;&5R(&%N>F5I9V5N`%=E<FMZ
M975G;&5I<W1E(&;\<B!486)E;&QE;B!A;GIE:6=E;C\`1&%S("5S+4UE;OP@
M875F(&1E<B!L:6YK96X@4V5I=&4@86YZ96EG96X_`$1I86QO9R!F_'(@5&%B
M96QL96YZ96QL96YE:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@
M5&%B96QL96YE:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@5&%B
M96QL96YZ96EL96YE:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$1I86QO9R!F_'(@
M0FEL9&5I9V5N<V-H869T96X@86YZ96EG96X`2&]C:&QA9&5N(&5R;?9G;&EC
M:&5N`%-C:&%U97(`1G+\:"!38VAA=65R`%-PY'1E<B!38VAA=65R`%-C:&%U
M97(@:6X@9&5R(%5M9V5B=6YG`%9E<FML96EN97)N`%9E<FML96EN97)N(&]D
M97(@=F5R<V-H:65B96X@4VEE(&5R<W0@9&EE(&)E;F%C:&)A<G1E;B!";/9C
M:V4`4VEE<G)A($QE;VYE`%)E9VES=')I97)E;@!3:6=N871U<@!3:6=N871U
M<F%L9V]R:71H;75S`%-I;F=A<'5R`$=R]M]E`%=A<G1U;F=S87)B96ET96X@
M_&)E<G-P<FEN9V5N`%-L;W=A:V5I`%-L;W=E;FEE;@!38VAN964`4V-H;F5E
M<V-H875E<@!38VAN965S8VAA=65R`$9R_&@@4V-H;F5E<V-H875E<@!3<.1T
M97(@4V-H;F5E<V-H875E<@!38VAN965H]FAE.B``4V-H;F5E;65N9V4@86QS
M(%=A<W-E<CH@`%-O;&]M;VYI;G-E;&X`4V]M86QI96X`3&EE9&5R("8@1V5D
M:6-H=&4`075S=V%H;"!D97(@4V]R=&EE<G)E:6AE;F9O;&=E`%5R<W!R=6YG
M<V%D<F5S<V4`4_QD869R:6MA`%/\9&5U<F]PY&ES8V@@*$E33RTX.#4Y+3,I
M`%/\9&=E;W)G:65N('5N9"!D:64@4_QD;&EC:&5N(%-A;F1W:6-H:6YS96QN
M`%/\9&QI8VAE($AE;6ES<&AE<F4`06)S=&%N9"!Z=VES8VAE;B!A=69E:6YA
M;F1E<B!F;VQG96YD96X@6F5L;&5N`$%B<W1A;F0@>G=I<V-H96X@26YH86QT
M('5N9"!286AM96X@=F]N(%IE;&QE;@!!8G-T86YD:&%L=&5R`$%B<W1A;F0`
M06)S=.1N9&4`4W!A;FEE;@!3<&%M`%-O;F1E<GIE:6-H96XM16EN9V%B90!:
M96QL92!T96EL96X`4W!A;'1E('1E:6QE;@!:96EL92!T96EL96X`4W!O<G0`
M4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=&IA:'(`0G5N9&5S
M<W1A870@;V1E<B!0<F]V:6YZ`%-T871U<P!3<&5I8VAE<F9O<FUA=`!3=')A
MWV4`1'5R8VAG97-T<FEC:&5N`%IE:6-H96YL:7-T90!$;VUA:6X@875S(&1E
M<B!!9')E<W-E(&5N=&9E<FYE;@!3=&EL(%M#4U-=`%-O`%5N=&5R=F5R>F5I
M8VAN:7,@(B5S(B!N:6-H="!G969U;F1E;BX`0F5T<F5F9@!!8G-C:&EC:V5N
M`$1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@9OQR("(E<R(@=W5R9&4@86)G
M97-C:&EC:W0N(%-I92!K]FYN96X@<VEC:"!N;V-H(&YI8VAT(&%N;65L9&5N
M+"!S;VQA;F=E(&1I92!!;F9R86=E(&YO8V@@;FEC:'0@8F5S=.1T:6=T('=U
M<F1E+@!4:65F9V5S=&5L;'0`17)F;VQG`"(E<R(@=W5R9&4@97)F;VQG<F5I
M8V@@:&EN>G5G96;\9W0N`$1A=&5N(&1E<R!"96YU='IE<G,@(B5S(B!W=7)D
M92!E<F9O;&=R96EC:"!G96SV<V-H="X`(B5S(B!W=7)D92!E<F9O;&=R96EC
M:"!G96SV<V-H="X`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="X`
M2V]N9FEG=7)A=&EO;B!E<F9O;&=R96EC:"!Z=7+\8VMG97-E='IT+B!396ET
M92!N974@;&%D96XL('5M(&1I92#$;F1E<G5N9V5N(&%N>G5Z96EG96XN`$)A
M8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!E<F9O;&=R96EC:"!G97-P96EC:&5R
M="X`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N("5S(&5R9F]L9W)E:6-H(&=E
M<W!E:6-H97)T+@`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&%K='5A;&ES:65R
M=``E<R!W=7)D92!E<F9O;&=R96EC:"!G97-P96EC:&5R=`!3=61A;@!:=7-A
M;6UE;F9A<W-U;F<`4V]N;F5N875F9V%N9P!3;VYN96YU;G1E<F=A;F<`4V]N
M;FEG`%-O;FYE;F%U9F=A;F<`4V]N;F5N875F+W5N=&5R9V%N9P!3;VYN96YA
M=69G86YG.B``4V]N;F5N=6YT97)G86YG`%-O;FYE;G5N=&5R9V%N9SH@`$AO
M8VAG97-T96QL=`!3=7!P;W)T`%-U<FEN86T`3F%C:&YA;64`4W9A;&)A<F0@
M=6YD($IA;B!-87EE;@!3=V%S:6QA;F0`4V-H=V5D96X`4V-H=V5I>@!3>6YC
M:')O;FEZ871I;VYS;&]G(&=E;/9S8VAT`$9O<FUA=&9E:&QE<B!I;B!3=6-H
M8F5G<FEF9F5N`$%R86)I<V-H92!297!U8FQI:R!3>7)I96X`1V5W:71T97(`
M1V5W:71T97(@=6YD(%=I;F1I9P!'97=I='1E<@!&<OQH($=E=VET=&5R`%13
M5BU$871E:0!486)E;&QE;F5I9V5N<V-H869T96X`5&%B96QL90!486)E;&QE
M;F5I9V5N<V-H869T96X`5&%I=V%N`%1A:7=A;BP@8VAI;F5S:7-C:&4@4')O
M=FEN>@!4861S8VAI:VES=&%N`%9E<F5I;FEG=&4@4F5P=6)L:6L@5&%N<V%N
M:6$`6FEE;#H`075F9V%B96X`5&5L969O;FYU;6UE<@!496UP97)A='5R(&1E
M<B!L971Z=&5N(%-T=6YD93H@`%1E;7!E<F%T=7(`5&5M<&5R871U<CH@`%1E
M;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S`%9O<FQA
M9V4@(B5S(B!N:6-H="!G969U;F1E;BX`5F]R;&%G96YV97)W86QT=6YG`%1E
M>'0`3G5R(%1E>'0`075S<FEC:'1U;F<`5&5X="!/8F5N`$1O`%1H86ELY&YD
M:7-C:"`H5$E3+38R,"D`5&AA:6QA;F0`1&EE($944"U%>'1E;G-I;VX@:7-T
M(&YI8VAT('9E<F;\9V)A<BX`1&EE($-H<F]N:6L@<W1E:'0@;FEC:'0@>G5R
M(%9E<F;\9W5N9RX`1&EE($AO<F1E+TMO;&%B($EN=&5G<F%T:6]N<V9U;FMT
M:6]N96X@=6YT97)S=/QT>F5N("(E<R(@;FEC:'0`1&EE($E-4U`M3&]G9&%T
M96D@:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;BX`1&EE($UA:6YT96YA
M;F-E.CH@2VQA<W-E(&MO;FYT92!N:6-H="!G96QA9&5N('=E<F1E;@!$87,@
M16EN<W1E;&QU;F=E;BU&96YS=&5R(&ES="!G97-C:&QO<W-E;B!W;W)D96XN
M($%B8G)U8V@N`$1E<B!!9&UI;FES=')A=&]R(&UU<W,@96EN('!E<FUA;F5N
M=&5S(%)E8VAT92U"86-K96YD(&5I;G)I8VAT96XL('=E;FX@4VEE(&1I92!2
M96-H=&5V97)W86QT=6YG(&YU='IE;B!M]F-H=&5N+@!.=7(@=6YT96X`1&EE
M($E$+4YU;6UE<B!D97,@2V]N=&%K=',@=W5R9&4@;FEC:'0@86YG96)E;BP@
M=V%R(&QE97(@;V1E<B!K;VYN=&4@:6X@9&5R($1A=&5N8F%N:R!N:6-H="!G
M969U;F1E;B!W97)D96XN`$1E<B!+;VYT86MT('=U<F1E(&5R9F]L9W)E:6-H
M($EH<F5M($%D<F5S<V)U8V@@:&EN>G5G96;\9W0N`$1E<B!01U`M4VEG;F%T
M=7)B;&]C:R!W:7)D(&)E;O9T:6=T+"!U;2!D:64@=6YT97)Z96EC:&YE=&4@
M3F%C:')I8VAT('IU(/QB97)P<OQF96XN`$1I92!)1"U.=6UM97(@9&5R(%9E
M<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D
M97(@:V]N;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R
M9&5N+@!$:64@5F5R=&5I;&5R;&ES=&4@=W5R9&4@;FEC:'0@86YG96=E8F5N
M+@!$:64@5F5R<V-H;/QS<V5L=6YG<V9U;FMT:6]N96X@8F5N]G1I9V5N(&5I
M;F4@<VEC:&5R92!397)V97)V97)B:6YD=6YG+@!$:64@1&%T96D@)7,@<V]L
M;'1E(&5I;F5N("5S($5I;G1R86<@96YT:&%L=&5N+@!$:64@1&%T96D@)7,@
M<V]L;'1E(&5I;FEG92`E<R!%:6YT<N1G92!E;G1H86QT96XN`$1I92!$871E
M:2!E;G1H:65L="!K96EN92!$871E;BX`2&EE<B!S:6YD(&1I92!+;W!F96EN
M='+D9V4@9OQR(&1I97-E(&UE<W-A9V4O<F9C.#(R($YA8VAR:6-H="X`1&5R
M(%9O;&QB:6QD;6]D=7,@=F5R=7)S86-H="!A=68@1W)U;F0@=F]N($9E:&QE
M<FX@:6T@26YT97)N970@17AP;&]R97(@8F5K86YN=&5R;6'?96X@4')O8FQE
M;64@;6ET(&1I97-E;2!"<F]W<V5R+"!D:64@=VER(&YI8VAT('5M9V5H96X@
M:_9N;F5N+B!5;G1E<B!5;7-TY&YD96X@97)H86QT96X@4VEE(&5I;F4@9F5H
M;&5R:&%F=&4@06YZ96EG92P@9F5H;&5N($5D:71O<F9U;FMT:6]N96XL(&]D
M97(@9&5R($)R;W=S97(@<W3\<GIT(&%B+B!!=68@96EN96T@5VEN9&]W(#EX
M(%-Y<W1E;2!W97)D96X@4VEE('9E<FUU=&QI8V@@96EN92`G06QL9V5M96EN
M92!38VAU='IV97)L971Z=6YG)R!E<FAA;'1E;B!U;F0@;?QS<V5N(&1E;B!2
M96-H;F5R(&YE=2!S=&%R=&5N+EQN7&Y3:64@=W5R9&5N(&=E=V%R;G0N($)I
M='1E(&1R_&-K96X@4VEE(&%U9B!/2RP@=V5N;B!3:64@;F]C:"!I;6UE<B!D
M96X@5F]L;&)I;&1M;V1U<R!V97)W96YD96X@;?9C:'1E;BX`1&EE($ED96YT
M:73D="`B)7,B('=U<F1E(&=E;/9S8VAT+@!.=7(@;&EN:W,`1&5R($]R="!D
M97,@1VYU4$<M4')O9W)A;6US(&UU<W,@9&5R($-R>7!T7W!G<#HZ($ML87-S
M92#\8F5R9V5B96X@=V5R9&5N+@!$:64@3F%C:')I8VAT(&UI="!D96T@0F5T
M<F5F9B`B)3,D<R(L(&1I92!A;2`E,21S(&%N("4R)',@9V5S8VAI8VMT('=U
M<F1E+"!I<W0@86YG97IE:6=T('=O<F1E;BX*1&%S(&AE:=]T(&YI8VAT+"!D
M87-S(&1I92!.86-H<FEC:'0@875C:"!G96QE<V5N(&]D97(@=F5R<W1A;F1E
M;B!W=7)D92X`3F%M92!F_'(@9&5N($QI;FL@>G5R($YA8VAR:6-H=&5N97)S
M=&5L;'5N9P!$:64@06YZ86AL(&1E<B!&96QD97(@;75S<R!A;',@6F%H;"!A
M;F=E9V5B96X@=V5R9&5N+@!$87,@3W!E;E-33"U-;V1U;"!W:7)D(&;\<B!D
M:64@2&]R9&5?0W)Y<'1?<VUI;64Z.B!+;&%S<V4@8F5N]G1I9W0N`$1I92!"
M96YU='IE<F5I;G-T96QL=6YG("(E<R(@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;BP@=V5I;"!I:')E($1A=&5N(&1I92!M87AI;6%L(&5R;&%U
M8G1E($=R]M]E(/QB97)S8VAR96ET96X`1&%S(%!R;V=R86UM(&;\<B!D:64@
M06YZ96EG92!D:65S97,@1&%T96ET>7!S("@E<RD@=W5R9&4@;FEC:'0@9V5F
M=6YD96XN`$1A<R!!;F;\:')U;F=S>F5I8VAE;B!M=7-S(&%L<R!E:6YZ96QN
M97,@6F5I8VAE;B!A;F=E9V5B96X@=V5R9&5N+@!.=7(@;&EN:W,@=6YD(')E
M8VAT<P!.=7(@<F5C:'1S`$1A<R!4<F5N;GIE:6-H96X@;75S<R!A;',@96EN
M>F5L;F5S(%IE:6-H96X@86YG96=E8F5N('=E<F1E;BX`1&5R(%-E<G9E<B`B
M)7,B('=U<F1E(&5N=&9E<FYT+@!$97(@4V5R=F5R("(E<R(@=W5R9&4@9V5S
M<&5I8VAE<G0N`$1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S('=U
M<F1E(&5N=&9E<FYT+@!$:64@86YG96=E8F5N92!:96EL92`H)60I(&5X:7-T
M:65R="!N:6-H="X`1&EE('1E;7!O<N1R92!$871E:2`B)7,B(&5X:7-T:65R
M="!N:6-H="X`1&5R(%1E>'0L(&1E;B!3:64@86YG96=E8F5N(&AA8F5N+"!E
M;G1S<')I8VAT(&YI8VAT(&1E;2!497AT(&%U9B!D96T@0FEL9'-C:&ER;2X`
M3G5R(&]B96X@=6YD('5N=&5N`$YU<B!O8F5N`$1I92!H;V-H9V5L861E;F5N
M($1A=&5N('-I;F0@;F%C:"!D96T@;&5T>G1E;B!38VAR:71T('9E<FQO<F5N
M(&=E9V%N9V5N+@!$:64@:&]C:&=E;&%D96YE($1A=&5I(&MO;FYT92!N:6-H
M="!G97-P96EC:&5R="!W97)D96XN`$1E<B!W96%T:&5R+F-O;2!";&]C:R!I
M<W0@;FEC:'0@=F5R9OQG8F%R+@!4:&5M96XM5F5R>F5I8VAN:7,@(B5S(B!N
M:6-H="!G969U;F1E;BX`17,@<VEN9"!K96EN92!%:6YS=&5L;'5N9V5N('9E
M<F;\9V)A<BX`17,@9VEB="!K96EN92!A;GIE:6=B87)E;B!.86-H<FEC:'1E
M;G1E:6QE+@!$:65S97,@1F5L9"!E;G1HY&QT('IU('9I96QE(%IE:6-H96XN
M(%-I92!H86)E;B`E<R!:96EC:&5N(&%N9V5G96)E;CL@4VEE(&W\<W-E;B!W
M96YI9V5R(&%L<R`E<R!A;F=E8F5N+@!"96EM($AI;GIU9OQG96X@=F]N("(E
M<R(@>G5M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ("5S
M`$)E:6T@3/9S8VAE;B!D97(@1&%T96X@=F]N($)E;G5T>F5R("(E<R(@:7-T
M(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B``0F5I;2!,]G-C:&5N('9O;B`B
M)7,B(&%U<R!D96T@4WES=&5M(&ES="!E:6X@4')O8FQE;2!A=69G971R971E
M;CH@`$)E:6T@06MT=6%L:7-I97)E;B!V;VX@(B5S(B!I<W0@96EN(%!R;V)L
M96T@875F9V5T<F5T96XZ("5S`$)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I
M<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=W5R9&4@;FEC:'0@:&]C
M:&=E;&%D96XN`$)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I<W0@96EN($9E
M:&QE<B!A=69G971R971E;BX@)7,@=V%R(&=R]M]E<B!A;',@9&EE(&UA>&EM
M86P@97)L875B=&4@1W+VWV4@*"5D($)Y=&5S*2X`0F5I;2!(;V-H;&%D96X@
M9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W=7)D
M92!N=7(@=&5I;'=E:7-E(&AO8VAG96QA9&5N+@!"96EM($%N>F5I9V5N(&1I
M97-E<R!.86-H<FEC:'1E;G1E:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E
M=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<B!+;VYT86MT9&%T96X@:7-T(&5I
M;B!&96AL97(@875F9V5T<F5T96XN`$)E:6T@26UP;W)T:65R96X@9&5R(&E#
M86QE;F1A<B!$871E;B!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`1&%S
M($MO;F9I9W5R871I;VYS+49O<FUU;&%R(&5N=&AI96QT(&5I;F5N($9E:&QE
M<BX@5FEE;&QE:6-H="!H86)E;B!3:64@96EN(%!F;&EC:'1F96QD(&QE97(@
M9V5L87-S96XN`$)E:6T@075S9OQH<F5N(&1E<B!A;F=E9V5B96YE;B!!9')E
M<W-B=6-H9G5N:W1I;VX@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I
M='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+@!"96D@
M9&5R($%K='5A;&ES:65R=6YG(&1E<B!+;VYT86MT9&5T86EL<R!I<W0@96EN
M($9E:&QE<B!A=69G971R971E;BX@0FET=&4@=F5R<W5C:&5N(%-I92!E<R!S
M<.1T97(@;F]C:"!E:6YM86PN`$)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R
M(%9E<G1E:6QE<FQI<W1E(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!"
M:71T92!V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`1&EE
M<V5R($E-05`M4V5R=F5R('5N=&5R<W3\='IT(&ME:6YE(&=E;65I;G-A;65N
M($]R9&YE<BX`1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@4D%2+4%R8VAI
M=B!Z=2!S96EN+@!$:65S('-C:&5I;G0@:V5I;B!G_&QT:6=E<R!:25`M07)C
M:&EV('IU('-E:6XN`$1I97,@<V-H96EN="!K96EN92!G_&QT:6=E($MA<G1E
M;FYU;6UE<B!Z=2!S96EN+@!$:65S97(@5')E:6)E<B!E<FQA=6)T(&1A<R!6
M97)S8VAI8VME;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@9&5N($-L:6-K871E
M;&PM1V%T97=A>2`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!M:70@2&EL9F4@
M9&5R($A45%`M05!)+@!$:65S97(@5')E:6)E<B!E<FQA=6)T(&1A<R!697)S
M8VAI8VME;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@9&5N(%=)3BU'871E=V%Y
M("AH='1P.B\O=VEN<&QC+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10+4%022X`
M1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA
M8VAR:6-H=&5N(&1U<F-H(&1E;B!S;7,R;6%I;"U'871E=V%Y("AH='1P.B\O
M<VUS,FUA:6PN8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)+@!$:65S97(@
M5')E:6)E<B!E<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I8VAT
M96X@<&5R(%--5%`@9'5R8V@@9&5N(%9O9&%F;VYE+4ET86QI96XM1V%T97=A
M>2!A=7-S8VAL:67?;&EC:"!A;B!6;V1A9F]N92U.=6UM97)N+B!$86;\<B!W
M:7)D(&5I;B!%+4UA:6PM2V]N=&\@8F5I(%9O9&%F;VYE($ET86QI96X@*&AT
M='`Z+R]W=W<N,3DP+FET*2!B96[V=&EG="X`1&EE<V5S($9E;&0@:7-T(&YO
M='=E;F1I9RX`1&EE<V5S($9E;&0@9&%R9B!N=7(@9V%N>F4@6F%H;&5N(&5N
M=&AA;'1E;BX`1&EE<V5S($9E;&0@9&%R9B!N=7(@6F%H;&5N('5N9"!E:6YE
M;B!0=6YK="!E;G1H86QT96XN`$1I97-E<R!&96QD(&1A<F8@;G5R($]K=&%L
M>F%H;&5N(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@;75S<R!E:6YE(&MO;6UA
M+2!O9&5R(&QE97)Z96EC:&5N9V5T<F5N;G1E($QI<W1E('9O;B!G86YZ96X@
M6F%H;&5N(&5N=&AA;'1E;@!$:65S97,@1F5L9"!M=7-S(&5I;F4@9_QL=&EG
M92!:86AL(&5N=&AA;'1E;BX`1&EE<V5S($9E;&0@;75S<R!E:6YE;B!&87)B
M=V5R="!I;2!H97AA9&5Z:6UA;&5N(%)'0BU&;W)M870@96YT:&%L=&5N+"!Z
M+B!"+B`G(S$R,S1A9B<N`$1I97-E<R!&;W)M=6QA<B!W=7)D92!B97)E:71S
M('9E<F%R8F5I=&5T+@!$:65S(&ES="`E<RX`1&EE(&ES="!E:6X@2V]L86(M
M1W)O=7!W87)E+4]B:F5K="X@56T@9&EE<V5S($]B:F5K="!A;GIU>F5I9V5N
M+"!B96[V=&EG96X@4VEE(&5I;B!%+4UA:6PM4')O9W)A;6TL(&1A<R!D87,@
M2V]L86(M1W)O=7!W87)E+49O<FUA="!U;G1E<G-T_'1Z="X@16EN92!,:7-T
M92!S;VQC:&5R(%!R;V=R86UM92!F:6YD96X@4VEE('5N=&5R("5S`$1I97-E
M($YA8VAR:6-H="!W=7)D92!I;B!E:6YE;2!:96EC:&5N<V%T>B`H)7,I(&5R
M<W1E;&QT+"!D97(@;FEC:'0@26AR96T@96EG96YE;B!E;G1S<')I8VAT+@!$
M:65S92!:86AL(&UU<W,@,2!O9&5R(&=R]M]E<B!S96EN+@!$:65S97(@4V5R
M=F5R(&MA;FX@6DE0+2!U;F0@1UI)4"U$871E:6X@;FEC:'0@96YT<&%C:V5N
M+@!$:65S97,@4WES=&5M(&ES="!Z=7(@6F5I="!D96%K=&EV:65R="X`1&EE
M<V5R(%=E<G0@;75S<R!E:6YE(%IA:&P@<V5I;BX`1&EE<V5S($9E;G-T97(@
M;75S<R!V;VX@96EN96T@16EN<W1E;&QU;F=E;BU&96YS=&5R(&=E]F9F;F5T
M('=E<F1E;@!$;VYN97(`5&EC:V5T<P!:96ET`%IE:71E<F9A<W-U;F<`6F5I
M=&9O<FUA=`!:96ET875S=V%H;`!4:6UO<BU,97-T90!4:71E;`!4:71E;"`H
M5&]O;'1I<"DZ`$%N`$AA;'1E;B!3:64@8F5I;2!+;&EC:V5N(%-T<F<@8GIW
M+B`H4$,I($-O;6UA;F0@*$UA8RD@9V5D<OQC:W0L('5M(&UE:')E<F4@16EN
M='+D9V4@875S>G5WY&AL96XN`$AE=71E`%IU($A434PM475E;&QC;V1E('5M
M<V-H86QT96X`5&]G;P!4;VME;&%U`$UO<F=E;@!4;VYG80!:=2!V:65L92!U
M;F?\;'1I9V4@06YM96QD979E<G-U8VAE(&EN(&1E;B!L971Z=&5N($UI;G5T
M96XN`$]B96X`Q'7?97)S=&5R(%)A:&UE;B`H7W1O<"D`W&)E<G-E='IU;F=E
M;@!4<FEN:61A9"!U;F0@5&]B86=O`%=A:'(@;V1E<B!F86QS8V@`1&D`5'5N
M97-I96X`5/QR:V5I`%3\<FMI<V-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
M86X`5'5R:W,M('5N9"!#86EC;W-I;G-E;&X`5'5V86QU`$EH<F4@075S=V%H
M;#H@`%56+4EN9&5X.B``2&]M97!A9V4`55),($EH<F5S(%-K<FEP=',@9OQR
M(&1E;B!697)S86YD<W1A='5S8F5R:6-H=`!!9')E<W-E.@!59V%N9&$`56MR
M86EN90!!=68@9&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@>G5G
M96=R:69F96X@=V5R9&5N+@!$:64@>G5SY'1Z;&EC:&5N($)E;G5T>F5R:6YF
M;W)M871I;VYE;B!K;VYN=&5N(&)E:2!D97(@4F5G:7-T<FEE<G5N9R!N:6-H
M="!H:6YZ=6;\9W0@=V5R9&5N+@!$:64@6G5G<FEF9G-R96-H=&4@9OQR(&1I
M92!61E,M1&%T96D@(B5S(B!K;VYN=&5N(&YI8VAT(&=EY&YD97)T('=E<F1E
M;BX`1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D:64@5D93+41A=&5I("5S+R5S
M(&MO;FYT96X@;FEC:'0@9V7D;F1E<G0@=V5R9&5N+@!%<R!K86YN(&YI8VAT
M(&EN(%9E<GIE:6-H;FES("5S(&=E=V5C:'-E;'0@=V5R9&5N+@!$:64@1W+V
MWV4@=F]N("(E<R(@:V]N;G1E(&YI8VAT(&)E<W1I;6UT('=E<F1E;BX`1&EE
M($=R]M]E('9O;B`B)7,O)7,B(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D
M96XN`%9E<F)I;F1U;F<@>G5M(%-13"!397)V97(@:V%N;B!N:6-H="!H97)G
M97-T96QL="!W97)D96XN`%-33"U697)B:6YD=6YG(&MO;FYT92!N:6-H="!H
M97)G97-T96QL="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT
M(&MO<&EE<G0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES("(E<R(@:V]N
M;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI
M<R!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1A<R!61E,M5F5R>F5I
M8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!,965R
M92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`1&EE
M($1A=&5N(&MO;FYT96X@;FEC:'0@9&5K;VUP<FEM:65R="!W97)D96XN`"(E
M<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BP@9&%S(%9E<GIE:6-H
M;FES(&ES="!N:6-H="!L965R+@`B)7,B(&MA;FX@;FEC:'0@9V5L]G-C:'0@
M=V5R9&5N.B`E<RX`)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BP@
M9&%S(%9E<GIE:6-H;FES(&ES="!N:6-H="!L965R`$1A<R!61E,M5F5R>F5I
M8VAN:7,@:V]N;G1E(&YI8VAT(')E:W5R<VEV(&=E;/9S8VAT('=E<F1E;BX`
M1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV<V-H
M="!W97)D96XZ("5S+@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT
M(&=E;/9S8VAT('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES("(E<R(@:V]N
M;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&4R!K;VYN=&4@;FEC
M:'0@<F5K=7)S:78@9V5L]G-C:'0@=V5R9&5N.B`E<RX`1&%S(&%K='5E;&QE
M(%9E<GIE:6-H;FES(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN`$1I
M92!:97)T:69I:V%T9&5T86EL<R!K;VYN=&5N(&YI8VAT(&%U<V=E;&5S96X@
M=V5R9&5N`$1E<B`E<RU4<F5I8F5R(&MO;FYT92!N:6-H="!G96QA9&5N('=E
M<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@=F5R<V-H;V)E;B!W
M97)D96XN`$1I92!61E,M1&%T96D@(B5S(B!K;VYN=&4@;FEC:'0@9V7V9F9N
M970@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!Z=6T@0F5S
M8VAR96EB96X@9V7V9F9N970@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT
M92!N:6-H="!G9?9F9FYE="!W97)D96XN`$1A<R!!<F-H:78@:V]N;G1E(&YI
M8VAT(&=E]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V5L97-E;B!W97)D96X@*&9I;&5S:7IE*"D@9F5H;&=E<V-H;&%G96XI
M+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;B`H
M<VEZ92@I(&9E:&QG97-C:&QA9V5N*2X`1&EE($1A=&5I(&MO;FYT92!N:6-H
M="!G96QE<V5N('=E<F1E;CH@`$1A<R!V9G-R;V]T+59E<GIE:6-H;FES(&MO
M;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX`)7,@:V]N;G1E(&YI8VAT(&YA
M8V@@)7,@=6UB96YA;FYT('=E<F1E;CH@1&%S(%II96QV97)Z96EC:&YI<R!E
M>&ES=&EE<G0@8F5R96ET<P!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N
M:6-H="!U;6)E;F%N;G0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES(&MO
M;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N.B`E<RX`1&EE(%9&4RU$871E
M:2`B)7,B(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+@!$:64@5D93
M+41A=&5I("5S+R5S(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+@!$
M:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+@`B
M;6MI<V]F<R(@:V]N;G1E(&YI8VAT(&%U<V=E9OQH<G0@=V5R9&5N+@!$:65S
M97,@5V]R9"U$;VMU;65N="!LY'-S="!S:6-H(&YI8VAT(&%N>F5I9V5N`$1I
M92!&<F5I+T=E8G5C:'0M26YF;W)M871I;VYE;B!F_'(@)7,@:V]N;G1E;B!N
M:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N`$1I92!61E,M1&%T96D@(B5S(B!K
M;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!G97-C:')I96)E;B!W97)D96X@*&-O<'DH*2!F96AL
M9V5S8VAL86=E;BDN`$1I92!61E,M1&%T96X@:V]N;G1E;B!N:6-H="!G97-C
M:')I96)E;B!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E
M<V-H<FEE8F5N('=E<F1E;BP@9&%S(%-P96EC:&5R<&QA='HM2V]N=&EN9V5N
M="!W_')D92#\8F5R<V-H<FET=&5N+@!5;G1E<G-T<FEC:&5N`,1N9&5R=6YG
M96X@<OQC:V?D;F=I9R!M86-H96X`36%C:'0@9&EE(&QE='IT92!!:W1I;VX@
M<OQC:V?D;F=I9P!5;F?\;'1I9V4@4OQC:VUE;&1U;F<@=F]M(%-E<G9E<B!B
M96EM($AE<G-T96QL96X@9&5R(%9E<F)I;F1U;F<Z(`!5;F5R=V%R=&5T92!!
M;G1W;W)T(&1E<R!397)V97)S(&%U9CH@`$YI8VAT('IU9V5O<F1N970`56YI
M8V]D92`H551&+3@I`%9E<F5I;FEG=&4@07)A8FES8VAE($5M:7)A=&4`5F5R
M96EN:6=T97,@2_9N:6=R96EC:`!697)E:6YI9W1E(%-T86%T96X`2VQE:6YE
M<F4@06UE<FEK86YI<V-H92#<8F5R<V5E:6YS96QN`$5I;FAE:71E;@!5;F)E
M:V%N;G0`56YB96MA;FYT92!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;F)E:V%N;G1E(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$5S('=U
M<F1E(&5I;B!U;F)E:V%N;G1E<B!/<G0@86YG96=E8F5N+@!5;F)E:V%N;G1E
M<B!"96YU='IE<FYA;64@;V1E<B!087-S=V]R="X`3&EN:R!V;VT@86MT=65L
M;&5N($5L96UE;G0@96YT9F5R;F5N`%5N8F5N86YN=`!!=7,@4VEC:&5R:&5I
M='-G<OQN9&5N(&3\<F9E;B!U;F%U=&]R:7-I97)T92!3:W)I<'1E(&YI8VAT
M(&%U<V-H;F5I9&5N+"!K;W!I97)E;B!U;F0@96EN9OQG96XN($ML:6-K96X@
M4VEE(&%U9B!/2RP@=6T@96EN96X@2&EN=V5I<R!A=68@;6]Z:6QL82YO<F<@
M86YG97IE:6=T('IU(&)E:V]M;65N+"!D97(@8F5S8VAR96EB="P@=VEE(%-I
M92!E:6YE;2!3:W)I<'0@9&5N(%IU9W)I9F8@875F(&1I92!:=VES8VAE;F%B
M;&%G92!E<FQA=6)E;B!K]FYN96XN`$9A<F)E('IU<OQC:W-E='IE;@!%<G=E
M:71E<G5N9R!N:6-H="!U;G1E<G-T_'1Z=`!!:W1U86QI<VEE<G5N9P`E<R!A
M:W1U86QI<VEE<F5N`$)E;G5T>F5R(&%K='5A;&ES:65R96X`(B5S(B!W=7)D
M92!A:W1U86QI<VEE<G0N`$%K='5A;&ES:65R=6YG<W-K<FEP="!G96SV<V-H
M="X`2&]C:&QA9&5N`$1I92!+;VYF:6=U<F%T:6]N<V1A=&5I96X@86QL97(@
M06YW96YD=6YG96X@=W5R9&5N(&%U9B!D96X@4V5R=F5R(&AO8VAG96QA9&5N
M+@!'<BX@;&%T96EN:7-C:&4@0G5C:'-T86)E;@!'<BX@<O9M:7-C:&4@6F%H
M;&5N`%5R=6=U87D`06MT=65L;&4@8F5N=71Z96XZ("5S`%-33"!B96YU='IE
M;@!":71T92!A=7-F_&QL96XL('=E;FX@4VEE(&5I;F5N(&%N9&5R96X@0F5N
M=71Z97)N86UE;B]087-S=V]R="!F_'(@9&5N($E-4U`M4V5R=F5R(&AA8F5N
M+@!"96YU='IE<@!"96YU='IE<B`E<R!I<W0@9OQR("5S(&YI8VAT(&%U=&]R
M:7-I97)T+@!"96YU='IE<G9E<G=A;'1U;F<`0F5N=71Z97)E:6YS=&5L;'5N
M9V5N`$)E;G5T>F5R<F5G:7-T<FEE<G5N9P!$:64@0F5N=71Z97)R96=I<W1R
M:65R=6YG('=U<F1E(&%U9B!D:65S96T@4WES=&5M(&1E86MT:79I97)T+@!"
M96YU='IE<FMO;G1O(&YI8VAT(&=E9G5N9&5N`$)E;G5T>F5R;F%M90!$97(@
M0F5N=71Z97)N86UE("(E<R(@97AI<W1I97)T(&)E<F5I=',N`$)E;G5T>F5R
M;F%M93H`0F5N=71Z97)N86UE.B``0F5N=71Z97(@9&5S(%-Y<W1E;7,Z`%5S
M8F5K:7-T86X`1&%S(%9&4RU697)Z96EC:&YI<R!E>&ES=&EE<G0@;FEC:'0N
M`$%B=V5S96YH96ET`%!A<W-E;F1E(&=E9G5N9&5N92!/<G1E.B``1_QL=&EG
M:V5I=`!797)T(&EN($UI;G5T96X@=F]N(&IE='IT(&%N+@!$97(@5V5R="!I
M<W0@_&)E<B!D97(@;6%X:6UA;&5N($SD;F=E('9O;B`E<RX`5V5R=&4`5V5R
M=&4L(&%U<R!D96YE;B!A=7-G97?D:&QT('=E<F1E;B!K86YN`%9A;G5A='4`
M1')E:&5N9`!696YE>G5E;&$`W&)E<G!R_&9U;F<@9F5H;&=E<V-H;&%G96X@
M+2!D:65S92!.86-H<FEC:'0@:_9N;G1E(&UA;FEP=6QI97)T('=O<F1E;B!S
M96EN+@!697)S:6]N`%9E<G-I;VYS:V]N=')O;&QE`$%U<W)I8VAT=6YG`%9E
M<G1I:V%L97(@26YN96YA8G-T86YD`%9E<G1I:V%L.@!396AR($AO8V@`5FEE
M=&YA;0!6:65T;F%M97-I<V-H("A625-#24DI`"5S(&%N>F5I9V5N`$5I;F4@
M97AT97)N92!796)S96ET92!A;GIE:6=E;@!!;GIE:6=E;B!A;',@)7,`0G)I
M=&ES8VAE($IU;F=F97)N:6YS96QN`$%M97)I:V%N:7-C:&4@2G5N9V9E<FYI
M;G-E;&X`4VEC:'0`4VEC:'0Z(`!6;V1A9F]N92!)=&%L:65N('!E<B!33510
M`%=!4DY53D<`5T%23E5.1R$A(2!,UE-#2$5.(%-)12!$05,@4TM225!4($U!
M3E5%3$P@0553("5S+@!724X@_&)E<B!(5%10`%=A;&QI<R!U;F0@1G5T=6YA
M`%=A<FYU;F<`36D`5V5T=&5R=F]R:&5R<V%G90!7971T97)D871E;B!V;VX`
M5V5A=&AE<BYC;VT`5V5B`%=E8G-I=&4`5_9C:&5N=&QI8V@`5VEL;&MO;6UE
M;@!7:6QL:V]M;65N(&)E:2`E<P!7:6QL:V]M;65N+"`E<P!797-T975R;W#D
M:7-C:"`H25-/+3@X-3DM,2D`5V5S=&5U<F]PY&ES8V@@*$E33RTX.#4Y+3$U
M*0!797-T<V%H87)A`%=E;&-H92!!;G=E;F1U;F<@<V]L;"`E<R!N86-H(&1E
M;2!!;FUE;&1E;B!A;F=E>F5I9V5N/P!796QC:&5S(%1R96YN>F5I8VAE;B!W
M:7)D('9E<G=E;F1E=#\`5V5L8VAE($%N9OQH<G5N9W-Z96EC:&5N('=E<F1E
M;B!V97)W96YD970_`%=H97)E:7,M075S=')A;&EA+4MA<G1E`%=E;&-H92!0
M:&%S96X`5V5L8VAE(%!L=6=I;G,@9OQR(&1E;B!765-)5UE'+45D:71O<B!S
M;VQL96X@86MT:79I97)T('=E<F1E;C\`0G)E:71E`$)R96ET92!I;B!#4U,M
M16EN:&5I=&5N`$)R96ET92!D97,@)7,M365N_',@;&EN:W,@*'=I<FMS86T@
M;F%C:"!D97(@;N1C:'-T96X@06YM96QD=6YG*3H`5&%B96QL96YB<F5I=&4`
M16EN:&5I=`!"<F5I=&4Z`%=I:VD`5VEN9`!&<OQH(%=I;F0`5VEN9&=E<V-H
M=VEN9&EG=&ME:70@:6X@2VYO=&5N`%=I;F0Z`%=I;F0Z(`!796ES:&5I=`!7
M=6YS8VAZ971T96P`07)B96ET`$%D<F5S<V4@9V5S8VCD9G1L:6-H`%1E;&5F
M;VX@9V5S8VCD9G1L:6-H`$9A;'-C:&4@06YZ86AL(&%N($9E;&1E<FX@:6X@
M6F5I;&4@)60N("5D(&5R=V%R=&5T+"`E9"!G969U;F1E;BX`1F%L<V-H92!!
M;GIA:&P@86X@1F5L9&5R;BX@)60@97)W87)T970L("5D(&=E9G5N9&5N+@!5
M;F?\;'1I9V5R($]F9G-E="`E9"!B96EM($QE<V5N(&1E<B!61E,M1&%T96DN
M`%%U97)V97)W96ES90!8-3`Y=C,@1V5N97)E;&QE($5I;G-C:'+D;FMU;F<`
M6#4P.78S($5R=V5I=&5R=&5R(%-C:&S\<W-E;'IW96-K`%@U,#EV,R!!;'1E
M<FYA=&EV97(@3F%M92!D97,@6F5R=&EF:6MA=&EN:&%B97)S`%@U,#EV,R!)
M9&5N=&ETY'0@9&5S(%IE<G1I9FEK871S8VAL_'-S96QS`%@U,#EV,R!%<G=E
M:71E<G5N9V5N`$I*`$I*2DH`66%H;V\A($MA<G1E`$KD:')L:6-H`$IE;65N
M`$IA`$IA+"!I8V@@<W1I;6UE('IU`%-I92!B969I;F1E;B!S:6-H(&EM(%1E
M>'1M;V1U<RX@0F5N=71Z96X@4VEE(&1E;B!;/#Y=($MN;W!F+"!U;2!I;B!D
M96X@5UE325=)1RU-;V1U<R!Z=2!W96-H<V5L;BX`4VEE(&3\<F9E;B!N:6-H
M="!M96AR(&%L<R`E9"!";/9C:V4@97)S=&5L;&5N+@!3:64@<VEN9"!N:6-H
M="!A;F=E;65L9&5T+@!3:64@9/QR9F5N(&1A<R!:96EC:&5N("=<)R!N:6-H
M="!I;B!):')E;2!.86UE;B!V97)W96YD96XN`%-I92!H86)E;B!K96EN92!G
M_&QT:6=E($4M36%I;"U!9')E<W-E(&%N9V5G96)E;BX`4VEE(&AA8F5N(&ME
M:6YE($9E;&1E<B!A=7,@9&5N(&EM<&]R=&EE<G1E;B!$871E;B!D96X@96YT
M<W!R96-H96YD96X@1F5L9&5R;B!I;B`E<R!Z=6=E;W)D;F5T+@!3:64@=W5R
M9&5N(&%B9V5M96QD970N`%-I92!M_'-S96X@96EN92!G_&QT:6=E($UO8FEL
M=&5L969O;FYU;6UE<B!A;F=E8F5N+"!N=7(@875S(%IA:&QE;B!U;F0@9V=F
M+B!E:6YE;2`B*R(@9OQR(&EN=&5R;F%T:6]N86QE(%9O<G=A:&QE;B!B97-T
M96AE;F0N`%-I92!M_'-S96X@96EN96X@9_QL=&EG96X@5V5R="!A;F=E9V5B
M96XN`%-I92!M_'-S96X@96EN($1A=&%4<F5E+4)A8VME;F0@:V]N9FEG=7)I
M97)E;BP@=6T@4F5G:7-T<FEE<G5N9V5N('9E<G=E;F1E;B!Z=2!K]FYN96XN
M`%-I92!M_'-S96X@96EN(%9&4RU"86-K96YD(&MO;F9I9W5R:65R96XN`%-I
M92!M_'-S96X@9&%S(%!R;V)L96T@8F5S8VAR96EB96XL('5M(&1E;B!"97)I
M8VAT(&%B>G5S8VAI8VME;BX`4VEE(&W\<W-E;B!D:64@55),(&%N9V5B96XL
M(&%U9B!D:64@9&EE<V5R($QI;FL@=F5R=V5I<V5N('-O;&P`4VEE(&W\<W-E
M;B!E<G-T(&1E;B!Z=2!E;G1F97)N96YD96X@4V5R=F5R(&%U<W?D:&QE;BX`
M4VEE(&W\<W-E;B!E:6YE;B!"96YU='IE<FYA;65N(&%N9V5B96XL(&1E<W-E
M;B!$871E;B!G96SV<V-H="!W97)D96X@<V]L;&5N+@!3:64@;?QS<V5N(&5I
M;F5N('IU(&SV<V-H96YD96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+@!3:64@
M;?QS<V5N(&5I;F5N(&AI;GIU>G5F_&=E;F1E;B!"96YU='IE<FYA;65N(&%N
M9V5B96XN`%-I92!M_'-S96X@9&5N('IU(&%K='5A;&ES:65R96YD96X@0F5N
M=71Z97)N86UE;B!A;F=E8F5N+@!3:64@;?QS<V5N(&5I;F4@06MT:6]N(&%N
M9V5B96XN`%-I92!M_'-S96X@96EN96X@;F5U96X@2V%T96=O<FEE;F%M96X@
M86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE($ET86QI96YI<V-H92!496QE9F]N
M;G5M;65R(&%N9V5B96X`26AR92`E<RU397-S:6]N(&ES="!A8F=E;&%U9F5N
M+B!":71T92!M96QD96X@4VEE('-I8V@@97)N975T(&%N+@!):')E($4M36%I
M;"U!9')E<W-E`$EH<F4@5F]N.B!!9')E<W-E.@!):')E($%N9V%B96X`26AR
M92!);G1E<FYE=&%D<F5S<V4@:&%T('-I8V@@9V7D;F1E<G0L('-E:70@4VEE
M(&1I92`E<RU3:71Z=6YG(&)E9V]N;F5N(&AA8F5N+B!:=6T@4V-H=71Z($EH
M<F5R(%-I8VAE<FAE:70@;?QS<V5N(%-I92!S:6-H(&YE=2!A;FUE;&1E;BX`
M26AR($YA;64`26AR($%U=&AE;G1I9FEZ:65R=6YG<W-Y<W1E;2!E<FQA=6)T
M(&ME:6X@2&EN>G5F_&=E;B!V;VX@;F5U96X@0F5N=71Z97)N+B!796YN(%-I
M92!(;W)D92!B96YU='IE;B!M]F-H=&5N+"!U;2!):')E($)E;G5T>F5R('IU
M('9E<G=A;'1E;BP@;?QS<V5N(%-I92!E:6YE;B!A;F1E<F5N($%U=&AE;G1I
M9FEZ:65R=6YG<W1R96EB97(@8F5N=71Z96XN`$EH<B!!=71H96YT:69I>FEE
M<G5N9W-S>7-T96T@97)L875B="!D87,@06YZ96EG96X@9&5R($)E;G5T>F5R
M(&YI8VAT+"!O9&5R(&1I97-E($WV9VQI8VAK96ET('=U<F1E(&%U<V=E<V-H
M86QT970N`$EH<B!"<F]W<V5R(&AA="!S:6-H(&%N<V-H96EN96YD(&=EY&YD
M97)T('-E:70@4VEE(&1I92`E<RU3:71Z=6YG(&)E9V]N;F5N(&AA8F5N+B!:
M=6T@4V-H=71Z($EH<F5R(%-I8VAE<FAE:70@;?QS<V5N(%-I92!S:6-H(&YE
M=2!A;FUE;&1E;BX`26AR($)R;W=S97(@=6YT97)S=/QT>G0@9&EE<V4@1G5N
M:W1I;VX@;FEC:'0N`$EH<B!"<F]W<V5R('5N=&5R<W3\='IT(&1I97-E($1R
M=6-K9G5N:W1I;VX@;FEC:'0N($)I='1E(&1R_&-K96X@4VEE(%-T<F<O2V]M
M;6%N9&\@*R!0('5M('IU(&1R=6-K96XN`$EH<F4@86MT=65L;&4@6F5I='IO
M;F4Z`$EH<F4@4W1A;F1A<F1I9&5N=&ETY'0@=W5R9&4@9V7D;F1E<G0N`$EH
M<F4@4W1A;F1A<F1I9&5N=&ETY'0Z`$EH<B!V;VQL<W3D;F1I9V5R($YA;64Z
M`$EH<B!:=6=A;F<@:7-T(&%B9V5L875F96XN`$EH<B!N975E<R!087-S=V]R
M="!F_'(@)7,@;&%U=&5T.B`E<P!):')E($5I;G-T96QL=6YG96X@=W5R9&5N
M(&;\<B!D:64@1&%U97(@9&EE<V5R(%-I='IU;F<@9V5S<&5I8VAE<G0N`$EH
M<F4@16EN<W1E;&QU;F=E;B!W=7)D96X@9V5S<&5I8VAE<G0N`$EH<B!087-S
M=V]R="!W=7)D92!Z=7+\8VMG97-E='IT`$EH<B!087-S=V]R="!W=7)D92!Z
M=7+\8VMG97-E='IT+B!2=69E;B!3:64@26AR92!%+4UA:6PM3F%C:')I8VAT
M96X@86(@=6YD(&UE;&1E;B!3:64@<VEC:"!M:70@26AR96T@;F5U96X@4&%S
M<W=O<G0@86XN`$EH<B!087-S=V]R="!I<W0@86)G96QA=69E;BX`26AR92!3
M97)V97(Z`$IU9V]S;&%W:65N`%IA:7)E`%-A;6)I80!3:6UB86)W90!::7!P
M>0!;6FET871T97AT('9E<G-T96-K96Y=`%M0<F]B;&5M8F5R:6-H=%T`6UII
M=&%T=&5X="!A;GIE:6=E;B`M`%M::71A='1E>'0@86YZ96EG96X@+2`E<R!:
M96EL96Y=`%M:96EL92`E<R!V;VX@)7-=`%]!9&UI;FES=')A=&EO;@!"95]F
M96AL<WIE:6QE`%]$871A5')E90!:96EL92!?;/9S8VAE;@!?1W)U<'!E;@!?
M0FEL9&5I9V5N<V-H869T96XN+BX`06Y?;65L9&5N`$%B7VUE;&1E;@!,:6YK
M(%]B96%R8F5I=&5N+BXN`%]%:6YS=&5L;'5N9V5N`%]296-H=&4`3&EN:R!?
M96YT9F5R;F5N+BXN`%]+;VYF:6=U<F%T:6]N`%]486)E;&QE;F5I9V5N<V-H
M869T96XN+BX`7T)E;G5T>F5R`$%D<F5S<V)U8V@`061R97-S870@=6YB96MA
M;FYT`$MA;&5N9&5R`'=I;F1S=&EL;`!!=7-G86)E9&%T96D@:V]N;G1E(&YI
M8VAT(&5R<W1E;&QT('=E<F1E;@!%:6YG86)E(&MA;FX@;FEC:'0@9V7V9F9N
M970@=V5R9&5N`&ML:6-K96X@4VEE(&AI97(`56YG_&QT:6=E($)E;G5T>G5N
M9R!D97(@2V]M;6%N9&]Z96EL90!+;VYF:6=U<F%T:6]N<V9E:&QE<@!+<FET
M:7-C:&4@4WES=&5M9&%T96D@9F5H;'0`1&%T96YF;W)M871F96AL97(`8F5A
M<F)E:71E;@!%:6YT<F%G(&YI8VAT(&=E9G5N9&5N`&9A;&QE;F0`1&%T96D`
M875S("5S("@E<RD@;6ET("5S("5S`&+V:6<`:#H`:&@`2&]S=&YA;64@=6YB
M96MA;FYT`'-O9F]R=`!);FQI;F4`16EN+2]!=7-G86)E9F5H;&5R`$EN=&5R
M;F5R(%-O9G1W87)E9F5H;&5R`%IE:6QE;ET`;6MI<V]F<RU&96AL97)C;V1E
M("5D(&)E:2!D97(@17)S=&5L;'5N9R!D97,@25-/+4%B8FEL9&5S+@!M;0!.
M86UE`&YI8VAT(&EM<&QE;65N=&EE<G0`3F]C:"!N:6-H="!I;7!L96UE;G1I
M97)T`$YO=&EZ8FQO8VL`4')O>F5N=`!:=6=R:69F('9E<G=E:6=E<G0`4&EX
M96P`4F5M;W1E9F5H;&5R(&EM(%!R;W1O:V]L;`!S=&5I9V5N9`!397)V:6-E
M(&YI8VAT('9E<F;\9V)A<@!5;G1E<G-C:&EE9&4@86YZ96EG96X`<VUS,F5M
M86EL(/QB97(@2%144`!S<P!G;&5I8VAB;&5I8F5N9`!3>7-T96UF96AL97(`
M075F9V%B96YL:7-T90!6;W+\8F5R9V5H96YD97(@1F5H;&5R`&=E8F5N(%-I
M92!D87,@4&%S<W=O<G0@96EN('IW96ET97,@36%L('IU<B!"97-TY'1I9W5N
M9R!E:6X`=6YI9FEE9`!U;F)E;F%N;G0`8F5N=71Z97)D969I;FEE<G0`=D-A
M<F0`8CH`=V5A=&AE<BYC;VT`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&5?1$4O:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-#$P`#$P-3$U-#,Q
M,#8Q`#`R,#(U-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U
M.2TQ(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O9&5?1$4O:&5L<"YX
M;6PL=B`Q+C4@,C`P-"\Q,"\R,B`Q,SHS-SHQ.2!J86X@17AP("0@+2T^"CQH
M96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@;60U/2(V.&-A,S-F-V8P8SEA
M864T8S$P,V5B-#<T.3)C9&,Q-2(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT
M:71L93Y$:64@4&]R=&%L<V5I=&4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@
M($1I92!0;W)T86QS96ET92!E<FQA=6)T(&5I;F4@:W5R>F4@W&)E<G-I8VAT
M(/QB97(@86QL92!):')E('=I8VAT:6=E;@H@("`@("!);F9O<FUA=&EO;F5N
M+B!3:64@:V%N;B!Z=6T@0F5I<W!I96P@86YZ96EG96XL('=I92!V:65L92!N
M975E($5M86EL<R!3:64*("`@("`@:&%B96XL('=E;&-H92!497)M:6YE(&1E
M;6[D8VAS="!A;G-T96AE;BP@=V5L8VAE($%U9F=A8F5N(%-I92!N;V-H('IU
M"B`@("`@(&5R;&5D:6=E;B!H86)E;B!O9&5R(&%U8V@@9&EE(&YE=65S=&5N
M($YA8VAR:6-H=&5N+B!6:65L92!D:65S97(*("`@("`@W&)E<G-I8VAT96X@
M96YT:&%L=&5N('-C:&YE;&QE(%IU9W)I9F9E(&%U9B!HY'5F:6<@8F5N]G1I
M9W1E($9U;FMT:6]N96XL"B`@("`@('=I92!D87,@4V-H<F5I8F5N(&YE=65R
M($5M86EL<R!O9&5R(&1E;2!!;FQE9V5N(&YE=65R($MA;&5N9&5R96EN='+D
M9V4*("`@("`@;V1E<B!!=69G86)E;BX*("`@(#PO<&%R83X*("`@(#QP87)A
M/@H@("`@("!$97(@26YH86QT(&1I97-E<B!0;W)T86QS96ET92!K86YN(/QB
M97(@9&5N(")!;G!A<W-E;B(M3&EN:PH@("`@("!V97+D;F1E<G0@=V5R9&5N
M+B!3:64@:_9N;F5N('IU;2!"96ES<&EE;"!A=7-WY&AL96XL('=E;&-H92#<
M8F5R<VEC:'1E;@H@("`@("!I;B!D:64@4&]R=&%L<V5I=&4@875F9V5N;VUM
M96X@=V5R9&5N('-O;&QE;BP@=6YD(&9E<W1L96=E;BP@:6X@=V5L8VAE<@H@
M("`@("!296EH96YF;VQG92!S:64@86YG97IE:6=T('=E<F1E;BX*("`@(#PO
M<&%R83X*("`\+V5N=')Y/@H*("`\96YT<GD@:60](FYA=F)A<B(@;60U/2)B
M.&-F,&%E,3EE-3=D9F$P8S)B.38R934Q-C<X,F8T-R(@<W1A=&4](G5P=&]D
M871E(CX*("`@(#QT:71L93Y$:64@06YW96YD=6YG<RU.879I9V%T:6]N<VQE
M:7-T93PO=&ET;&4^"B`@("`\<&%R83X*("`@("`@075F(&1E<B!L:6YK96X@
M4V5I=&4@9&5S($9E;G-T97)S(&)E9FEN9&5T('-I8V@@9&EE($YA=FEG871I
M;VYS;&5I<W1E"B`@("`@(&;\<B!D:64@06YW96YD=6YG96XN($ML:6-K96X@
M4VEE(&%U9B!D:64@4WEM8F]L92!O9&5R($YA;65N(&1E<@H@("`@("!!;G=E
M;F1U;F=E;BP@=6T@<V-H;F5L;"!U;F0@96EN9F%C:"!Z=VES8VAE;B!D:65S
M96X@:&EN+2!U;F0*("`@("`@:&5R>G5S8VAA;'1E;BX*("`@(#PO<&%R83X*
M("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B
M('-T871E/2)U<'1O9&%T92(@;60U/2)D9#DU9&8P-V$P,S`S,3(S,F)A96$Y
M,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^16EN<W1E;&QU;F=E;CH@06YM96QD
M96%U9F=A8F5N.B!787)T=6YG<V%R8F5I=&5N"B`@("`@(&1U<F-H9OQH<F5N
M/"]T:71L93X*("`@(#QP87)A/@H@("`@("!796YN(%-I92!M]F-H=&5N+"!D
M87-S(&YA8V@@9&5R($%N;65L9'5N9R!787)T=6YG<V%R8F5I=&5N(&1U<F-H
M9V5F_&AR=`H@("`@("!W97)D96XL(&UA<FMI97)E;B!3:64@9&EE<V5S($%U
M<W=A:&QF96QD+@H@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB83(Q,38R8V1F9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@
M/'1I=&QE/D5I;G-T96QL=6YG96XZ($%N;65L9&5A=69G86)E;CH@5V%R='5N
M9W-A<F)E:71E;B!B97-TY'1I9V5N/"]T:71L93X*("`@(#QP87)A/@H@("`@
M("!796YN(%-I92!A;&QE(%=A<G1U;F=S87)B96ET96X@8F5S=.1T:6=E;B!M
M]F-H=&5N+"!B979O<B!D:65S90H@("`@("!A=7-G96;\:')T('=E<F1E;BP@
M;6%R:VEE<F5N(%-I92!D:65S97,@075S=V%H;&9E;&0N(%=E;FX@4VEE(&1A
M<R!&96QD"B`@("`@(&1E86MT:79I97)T(&QA<W-E;BP@=V5R9&5N(&%L;&4@
M5V%R='5N9W-A<F)E:71E;B!A=71O;6%T:7-C:`H@("`@("!D=7)C:&=E9OQH
M<G0L(&]H;F4@9&%S<R!3:64@8F5I(&1E<B!!;FUE;&1U;F<@9&EE($=E;&5G
M96YH96ET(&AA8F5N+`H@("`@("!D:65S92!A8GIU8G)E8VAE;BX*("`@(#PO
M<&%R83X*("`\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO````
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8U,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]C<U]#6B],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#(P-#,U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V-S7T-:+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,S-C`S-0`Q,#4Q-30S
M,3`V,0`P,C(Q,#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````"8!@``'````-PT``#+"```G&D```````#(C```
M#@```,F,```/````V(P```T```#HC```"````/:,```+````_XP```P````+
MC0``!````!B-```,````'8T```\````JC0``"P```#J-```.````1HT```4`
M``!5C0``*````%N-```(````A(T```H```"-C0``%0```)B-```2````KHT`
M``L```#!C0``#@```,V-```*````W(T```T```#GC0``#@```/6-```1````
M!(X```T````6C@``#````"2.```-````,8X```8````_C@``#P```$:.```8
M````5HX```P```!OC@``#@```'R.```.````BXX```@```":C@``+@```*..
M```:````THX``#(```#MC@``.````""/``!4````68\``%$```"NCP``6@``
M``"0``!7````6Y```#0```"SD```!P```.B0```*````\)````\```#[D```
M!0````N1```&````$9$``!$````8D0``"````"J1```)````,Y$```D````]
MD0``)0```$>1```@````;9$``!````".D0``#P```)^1```*````KY$```,`
M``"ZD0``#P```+Z1```4````SI$```D```#CD0``#0```.V1```2````^Y$`
M``\````.D@``"@```!Z2```/````*9(```@````YD@``)````$*2```4````
M9Y(``!8```!\D@``"````).2```9````G)(```<```"VD@``#````+Z2```L
M````RY(```X```#XD@```P````>3```+````"Y,```<````7DP``!P```!^3
M```%````)Y,```4````MDP``"@```#.3```#````/I,``!<```!"DP``"@``
M`%J3```/````99,```X```!UDP``&````(23```C````G9,```X```#!DP``
M%````-"3```7````Y9,``!<```#]DP``%P```!64```3````+90```\```!!
ME```#@```%&4```?````8)0```<```"`E```!@```(B4```(````CY0```\`
M``"8E```!@```*B4```*````KY0``!,```"ZE```"P```,Z4```0````VI0`
M`!4```#KE```%0````&5```'````%Y4``!`````?E0``!0```#"5```5````
M-I4``!$```!,E0``#````%Z5```[````:Y4```D```"GE0``!P```+&5```4
M````N94```,```#.E0``!0```-*5```0````V)4```D```#IE0``$P```/.5
M```Y````!Y8``!(```!!E@``)P```%26```L````?)8``"H```"IE@``)0``
M`-26```*````^I8```8````%EP``"0````R7```'````%I<``"\````>EP``
M-P```$Z7```N````AI<``%4```"UEP``+0````N8```M````.9@``"T```!G
MF```0````)68```C````UI@``",```#ZF```+0```!Z9```S````3)D``!4`
M``"`F0``&0```):9```I````L)D``"0```#:F0``$0```/^9```*````$9H`
M``P````<F@``"@```"F:```0````-)H``!8```!%F@``%@```%R:```'````
M<YH```<```![F@``%````(.:```*````F)H```@```"CF@``"````*R:```'
M````M9H```<```"]F@``!@```,6:```%````S)H```<```#2F@``!@```-J:
M```(````X9H``"D```#JF@``#@```!2;```*````(YL```0````NFP``!P``
M`#.;```)````.YL```8```!%FP``$0```$R;```'````7IL``!8```!FFP``
M!````'V;```(````@IL```8```"+FP``#0```)*;```&````H)L``!X```"G
MFP``$0```,:;```(````V)L```T```#AFP``#````.^;```'````_)L```,`
M```$G````P````B<```7````#)P``!,````DG```"````#B<```$````09P`
M``@```!&G```"````$^<``!!````6)P``"````":G```!@```+N<```&````
MPIP``!4```#)G```&````-^<```B````^)P``"X````;G0``'0```$J=```A
M````:)T``%0```"*G0``*0```-^=```*````"9X```<````4G@``%0```!R>
M```.````,IX```H```!!G@``#P```$R>```-````7)X```\```!JG@``#0``
M`'J>```)````B)X``!0```"2G@``!@```*>>```8````KIX``!T```#'G@``
M$P```.6>```4````^9X```0````.GP``!@```!.?``!4````&I\```0```!O
MGP``#@```'2?```%````@Y\```4```")GP``&P```(^?```:````JY\``!$`
M``#&GP``$0```-B?```<````ZI\``"H````'H```$````#*@```A````0Z``
M``4```!EH```$P```&N@```2````?Z````H```"2H```#P```)V@```1````
MK:```!,```"_H```#````-.@```&````X*````8```#GH```%P```.Z@```0
M````!J$``!$````7H0``"````"FA```%````,J$```P````XH0``$````$6A
M```%````5J$```T```!<H0``!@```&JA```'````<:$```T```!YH0``!P``
M`(>A```+````CZ$```<```";H0``!P```*.A```)````JZ$```H```"UH0``
M&0```,"A```,````VJ$``!````#GH0``!0```/BA```E````_J$``!(````D
MH@``$P```#>B```K````2Z(``#L```!WH@``(````+.B```V````U*(```@`
M```+HP``#````!2C```&````(:,```0````HHP``#@```"VC```*````/*,`
M``T```!'HP``'@```%6C```;````=*,``"$```"0HP``'@```+*C```9````
MT:,``!X```#KHP``&P````JD```F````)J0``!L```!-I```'@```&FD```<
M````B*0``"8```"EI```,P```,RD```F`````*4``"L````GI0``.````%.E
M```O````C*4``!(```"\I0``*0```,^E```2````^:4``*(````,I@``%@``
M`*^F```C````QJ8``"@```#JI@``*0```!.G```H````/:<``!\```!FIP``
M(````(:G```E````IZ<``#````#-IP``(0```/ZG```<````(*@``"8````]
MJ```00```&2H```,````IJ@```<```"SJ```!P```+NH```&````PZ@```T`
M``#*J```$````-BH```2````Z:@``!,```#\J```$@```!"I```'````(ZD`
M``0````KJ0``#````#"I```.````/:D```\```!,J0``$P```%RI```-````
M<*D``"@```!^J0```P```*>I```-````JZD```8```"YJ0``$0```,"I```7
M````TJD``!L```#JJ0``#@````:J```"````%:H```4````8J@``$````!ZJ
M```$````+ZH```T````TJ@``#@```$*J```#````4:H```X```!5J@``"```
M`&2J```/````;:H```\```!]J@``!P```(VJ```-````E:H``!````"CJ@``
M"P```+2J```&````P*H```P```#'J@``$0```-2J```9````YJH```L`````
MJP``#0````RK```B````&JL```H````]JP``&````$BK```9````8:L``!8`
M``![JP``#0```)*K```'````H*L``!0```"HJP``"P```+VK```B````R:L`
M`"\```#LJP``"P```!RL```)````**P``!D````RK```"P```$RL```7````
M6*P``!<```!PK```"0```(BL```6````DJP```\```"IK```%@```+FL```.
M````T*P``!@```#?K```"````/BL```-`````:T``"8````/K0``0P```#:M
M```(````>JT``!(```"#K0``"````):M```+````GZT``"\```"KK0``#@``
M`-NM```%````ZJT```8```#PK0```P```/>M```'````^ZT```0````#K@``
M"@````BN```*````$ZX```\````>K@``$````"ZN```7````/ZX``!$```!7
MK@``%P```&FN```)````@:X```4```"+K@``"P```)&N```*````G:X```(`
M``"HK@``!0```*NN```-````L:X``!L```"_K@``%P```-NN```)````\ZX`
M``X```#]K@``#0````RO```2````&J\``#@````MKP``(````&:O```(````
MAZ\```X```"0KP``>P```)^O```8````&[```!$````TL```!P```$:P```%
M````3K```!D```!4L```!P```&ZP```(````=K````8```!_L```!@```(:P
M```0````C;````\```">L```$````*ZP```/````O[````L```#/L```#P``
M`-NP```,````Z[````\```#XL```!P````BQ```&````$+$```X````7L0``
M#````":Q```H````,[$```\```!<L0``"````&RQ```(````=;$``!,```!^
ML0``'@```)*Q```A````L;$``"````#3L0``&0```/2Q```7````#K(``"4`
M```FL@``%P```$RR```$````9+(``!L```!IL@``#0```(6R```,````D[(`
M``,```"@L@``"````*2R```*````K;(```P```"XL@``"P```,6R```0````
MT;(```P```#BL@``!````.^R```3````]+(``!0````(LP``#````!VS```)
M````*K,```X````TLP``"P```$.S```;````3[,```<```!KLP``!P```'.S
M```*````>[,```T```"&LP``"0```)2S```$````GK,```4```"CLP```P``
M`*FS```8````K;,```H```#&LP``!````-&S```F````UK,```X```#]LP``
M?`````RT```5````B;0```4```"?M```!P```*6T```,````K;0```@```"Z
MM```"@```,.T```&````SK0```@```#5M````@```-ZT```&````X;0```8`
M``#HM```%````.^T```-````!+4``!`````2M0``&P```".U```$````/[4`
M``D```!$M0``$````$ZU```)````7[4```D```!IM0``!0```'.U```:````
M>;4```@```"4M0``!@```)VU```9````I+4```X```"^M0``!P```,VU```'
M````U;4```4```#=M0``"0```..U```*````[;4```(```#XM0``!@```/NU
M```-`````K8```D````0M@``!@```!JV```2````(;8```D````TM@``!P``
M`#ZV```4````1K8``!T```!;M@``!@```'FV```*````@+8```0```"+M@``
M"0```)"V```(````FK8``!$```"CM@``"0```+6V```&````O[8```T```#&
MM@``!@```-2V```$````V[8``#D```#@M@``/0```!JW```Z````6+<``!X`
M``"3MP``!0```+*W```.````N+<```0```#'MP``!@```,RW```A````T[<`
M`!4```#UMP``!@````NX```$````$K@``!$````7N```!@```"FX```*````
M,+@``"(````[N```!````%ZX```%````8[@``!T```!IN```!````(>X```,
M````C+@```H```"9N```"````*2X```)````K;@```4```"WN```.@```+VX
M```P````^+@``#4````IN0``*0```%^Y``!'````B;D``#@```#1N0``*0``
M``JZ```_````-+H``"X```!TN@``+0```*.Z```?````T;H```\```#QN@``
M$@````&[```+````%+L``"8````@NP``*0```$>[```D````<;L``"8```"6
MNP``"````+V[```*````QKL```D```#1NP``!P```-N[```@````X[L``"``
M```$O```)@```"6\```*````3+P``!D```!7O```*0```'&\```6````F[P`
M`!(```"RO```!P```,6\```*````S;P```P```#8O```#P```.6\```0````
M];P``$`````&O0``<````$>]``!F````N+T```X````?O@``"0```"Z^```*
M````.+X``!(```!#O@``$P```%:^```,````:KX```8```!WO@``#P```'Z^
M```2````CKX``!````"AO@``$0```+*^```<````Q+X``",```#AO@``:@``
M``6_```/````<+\```4```"`OP``$````(:_```)````E[\```0```"AOP``
M"P```*:_```4````LK\```P```#'OP``#````-2_```/````X;\``!4```#Q
MOP``*0````?````J````,<```"8```!<P```)P```(/````I````J\```"H`
M``#5P```&0````#!``!"````&L$``!$```!=P0``$@```&_!```3````@L$`
M`!0```"6P0``#P```*O!```6````N\$``!<```#2P0``$````.K!```1````
M^\$``#0````-P@``$P```$+"```2````5L(``#4```!IP@``%````)_"```'
M````M,(```P```"\P@``(````,G"```4````ZL(``!$```#_P@``%P```!'#
M```<````*<,``!,```!&PP``$0```%K#```:````;,,``!X```"'PP``&@``
M`*;#```1````P<,``!0```#3PP``%P```.C#```5`````,0```D````6Q```
M&0```"#$```$````.L0```<````_Q```"P```$?$```1````4\0```8```!E
MQ```!@```&S$```&````<\0```4```!ZQ```!P```(#$```'````B,0```4`
M``"0Q```%@```);$```&````K<0```8```"TQ```!````+O$```$````P,0`
M``<```#%Q```#@```,W$```,````W,0```P```#IQ```#0```/;$```*````
M!,4```X````/Q0``!0```![%```H````),4```X```!-Q0``#````%S%```/
M````:<4```H```!YQ0``"````(3%```)````C<4``"L```"7Q0``!````,/%
M```(````R,4``"8```#1Q0``$@```/C%```/````"\8```8````;Q@``"@``
M`"+&```'````+<8```@````UQ@``(````#[&```)````7\8```P```!IQ@``
M#0```';&```.````A,8``!8```"3Q@``$0```*K&```&````O,8```,```##
MQ@``!@```,?&```9````SL8```<```#HQ@``!````/#&```+````]<8```L`
M```!QP``!P````W'```'````%<<``!8````=QP``#0```#3'```-````0L<`
M``H```!0QP``$````%O'```/````;,<``!$```!\QP``%P```(['```*````
MIL<``!$```"QQP``"````,/'```$````S,<```\```#1QP``.@```.''```%
M````',@```P````BR```'@```"_(```.````3L@``!````!=R```"P```&[(
M```,````>L@```D```"'R```!P```)'(```*````F<@```D```"DR```#@``
M`*[(```0````O<@``!H```#.R```"@```.G(```)````],@```H```#^R```
M#`````G)```/````%LD```@````FR0``!@```"_)```'````-LD```L````^
MR0``1P```$K)```-````DLD```D```"@R0``!````*K)```#````K\D``!,`
M``"SR0``$P```,?)```3````V\D```H```#OR0```@```/K)```$````_<D`
M`"4````"R@```P```"C*```%````+,H``"H````RR@``"@```%W*```%````
M:,H```0```!NR@``"@```'/*```-````?LH```8```",R@``"````)/*```(
M````G,H```0```"ER@``!0```*K*``!H````L,H```D````9RP``#````"/+
M```%````,,L```8````VRP``&P```#W+```O````6<L``!````")RP``"@``
M`)K+```/````I<L```H```"URP``"0```,#+```3````RLL``!L```#>RP``
M&````/K+```7````$\P```X````KS````P```#K,```'````/LP```@```!&
MS```!P```$_,```*````5\P```L```!BS```!P```&[,``!1````=LP``!``
M``#(S```#````-G,```-````YLP``!H```#TS```2@````_-```&````6LT`
M``8```!AS0``!@```&C-```?````;\T```8```"/S0``"0```);-```8````
MH,T``!<```"YS0``!@```-'-```-````V,T``"(```#FS0``5P````G.```3
M````8<X``",```!US@``$P```)G.```"````K<X```L```"PS@``"````+S.
M```-````Q<X```H```#3S@``!P```-[.```4````YLX```8```#[S@``"```
M``+/```.````"\\```<````:SP``"@```"+/```+````+<\```<````YSP``
M#````$'/```-````3L\```P```!<SP``"0```&G/```)````<\\```H```!]
MSP``!P```(C/```)````D,\```<```":SP``"@```*+/```;````K<\``!(`
M``#)SP``"@```-S/```)````Y\\``!````#QSP``!P````+0```2````"M``
M``0````=T```!P```"+0```%````*M````4````PT```"P```#;0```4````
M0M```!$```!7T```&@```&G0```6````A-```!0```";T```%P```+#0```8
M````R-```!P```#AT```&0```/[0```'````&-$```4````@T0``#0```";1
M```,````--$```@```!!T0``%P```$K1```+````8M$``!,```!NT0``!```
M`(+1```*````A]$```0```"2T0``#````)?1```)````I-$```4```"NT0``
M!P```+31```%````O-$```0```#"T0```@```,?1```X````RM$``"P````#
MT@``$@```##2```I````0](``#(```!MT@``"@```*#2```L````J](``"X`
M``#8T@``,P````?3```S````.],``#@```!OTP``#P```*C3```8````N-,`
M`!````#1TP``#P```.+3```3````\M,``!0````&U```$@```!O4```4````
M+M0``!4```!#U```+0```%G4```M````A]0``#$```"UU```+@```.?4```O
M````%M4``"P```!&U0``8@```'/5```3````UM4```@```#JU0``"````//5
M```K````_-4``"$````HU@``&@```$K6```)````9=8``$4```!OU@``00``
M`+76```$````]]8``!,```#\U@``%````!#7```.````)=<``!,````TUP``
M&````$C7```&````8=<```D```!HUP``"@```'+7```/````?=<``!````"-
MUP``!P```)[7```.````IM<```4```"UUP``&P```+O7```(````U]<```8`
M``#@UP``%````.?7```1````_-<```X````.V```.````!W8```"````5M@`
M``8```!9V```#@```&#8```%````;]@```<```!UV```#@```'W8```&````
MC-@```0```"3V```*0```)C8```7````PM@``!\```#:V```7````/K8```4
M````5]D``#X```!LV0``'P```*O9```0````R]D```<```#<V0``#@```.39
M```,````\]D```P`````V@``$P````W:```*````(=H``!T````LV@``&0``
M`$K:```%````9-H``!$```!JV@``$0```'S:```D````CMH``!4```"SV@``
M$@```,G:```.````W-H``!D```#KV@``"`````7;```)````#ML```T````8
MVP``"@```";;```'````,=L```\````YVP``"P```$G;```*````5=L```<`
M``!@VP``"````&C;```%````<=L``!\```!WVP``!@```)?;```0````GML`
M``@```"OVP``#0```+C;```(````QML``!(```#/VP``+````.+;```:````
M#]P```D````JW```"@```#3<```5````/]P```4```!5W```%````%O<```$
M````<-P``!````!UW```!@```(;<```'````C=P``!X```"5W```*````+3<
M```*````W=P``!H```#HW```%`````/=```$````&-T```0````=W0``"P``
M`"+=```%````+MT```8````TW0``"````#O=```&````1-T```H```!+W0``
M&P```%;=```T````<MT``#0```"GW0``(````-S=```I````_=T``"`````G
MW@``00```$C>```:````BMX``"@```"EW@``*0```,[>```B````^-X```8`
M```;WP``"````"+?```%````*]\```@````QWP``&0```#K?```9````5-\`
M`"H```!NWP``(P```)G?```N````O=\``#0```#LWP``"````"'@```7````
M*N````H```!"X```!P```$W@```A````5>```!````!WX```#@```(C@```+
M````E^````<```"CX```$P```*O@```(````O^````L```#(X```"@```-3@
M```4````W^```#(```#TX```"P```"?A```%````,^$```4````YX0``%P``
M`#_A```/````5^$```0```!GX0``"@```&SA```)````=^$```L```"!X0``
M#0```(WA```,````F^$```X```"HX0``!0```+?A```$````O>$```T```#"
MX0``,@```-#A``!%`````^(``!<```!)X@``'@```&'B```4````@.(```4`
M``"5X@``%````)OB```'````L.(```X```"XX@``*@```,?B```&````\N(`
M``P```#YX@``#0````;C```1````%.,```L````FXP``-@```#+C```*````
M:>,``"(```!TXP``"P```)?C```/````H^,``#(```"SXP``#@```.;C```%
M````]>,```X```#[XP``$P````KD```'````'N0``!$````FY```!P```#CD
M```4````0.0``!@```!5Y```!P```&[D```%````=N0```P```!\Y```#```
M`(GD```2````EN0```0```"IY```!P```*[D```*````MN0```L```#!Y```
M#````,WD```.````VN0```X```#IY```!0```/CD```%````_N0``"X````$
MY0``)@```#/E```C````6N4```,```!^Y0``$@```(+E```&````E>4``!X`
M``"<Y0``&````+OE```E````U.4```T```#ZY0``"0````CF```#````$N8`
M``<````6Y@``"@```![F```"````*>8```P````LY@``%0```#GF```+````
M3^8``!D```!;Y@``(````'7F```2````EN8```4```"IY@``"@```*_F```5
M````NN8``!(```#0Y@``#````./F```$````\.8```<```#UY@``#````/WF
M``!2````"N<``!<```!=YP``!P```'7G```&````?><```X```"$YP``#```
M`)/G```-````H.<``!4```"NYP``$@```,3G```/````U^<``!0```#GYP``
M&P```/SG```0````&.@``&D````IZ```&@```)/H```7````KN@``"<```#&
MZ```&@```.[H```7````">D``!L````AZ0``&0```#WI```?````5^D``!,`
M``!WZ0``"````(OI```'````E.D```@```"<Z0``"0```*7I```5````K^D`
M``T```#%Z0``$P```-/I```#````Y^D``$8```#KZ0``/P```#+J```W````
M<NH``%<```"JZ@``!0````+K```?````".L``"\````HZP``"@```%CK```(
M````8^L```T```!LZP``+0```'KK```$````J.L``$\```"MZP``)0```/WK
M```<````(^P```L```!`[```'P```$SL```=````;.P``"4```"*[```(```
M`+#L```D````T>P``"````#V[```"P```!?M```'````(^T```T````K[0``
M#````#GM```7````1NT```8```!>[0``.0```&7M```,````G^T```<```"L
M[0``"0```+3M```3````ONT```D```#2[0``!````-SM```0````X>T```@`
M``#R[0``"````/OM```$````!.X```L````)[@``#````!7N```2````(NX`
M`!$````U[@``#````$?N```:````5.X```\```!O[@``!P```'_N```-````
MA^X``!0```"5[@``#@```*KN```,````N>X``!L```#&[@``+````.+N```3
M````#^\``!P````C[P``*````$#O```&````:>\```<```!P[P``$P```'CO
M```%````C.\```0```"2[P``%P```)?O```*````K^\```P```"Z[P``"0``
M`,?O```&````T>\```D```#8[P``"````.+O```)````Z^\```H```#U[P``
M$0````#P```&````$O````X````9\```#@```"CP```-````-_````L```!%
M\```'0```%'P```+````;_````(```![\```!P```'[P```&````AO````D`
M``"-\```!P```)?P```[````G_```"@```#;\```-`````3Q```5````.?$`
M``4```!/\0``!P```%7Q```(````7?$```<```!F\0``!0```&[Q```'````
M=/$```X```!\\0``"0```(OQ```&````E?$```@```"<\0``"P```*7Q```'
M````L?$```@```"Y\0``!P```,+Q```6````RO$```D```#A\0``!@```.OQ
M```+````\O$``!P```#^\0``%````!OR```'````,/(```@````X\@``"```
M`$'R```%````2O(``!````!0\@``$````&'R```&````<O(``!D```!Y\@``
M"@```)/R```<````GO(```<```"[\@``!0```,/R```0````R?(``!0```#:
M\@``"P```._R```-````^_(``!<````)\P``!````"'S```)````)O,```H`
M```P\P``!P```#OS```"````0_,```X```!&\P``"````%7S```?````7O,`
M`",```!^\P``.````*+S```Q````V_,``"<````-]```9````#7T```4````
MFO0``%4```"O]```.`````7U``!*````/O4``%L```")]0``*````.7U```X
M````#O8``"@```!']@``+````'#V```G````G?8``!L```#%]@``/@```.'V
M``"I`0``(/<``",```#*^```%P```.[X``!(````!OD``(4```!/^0``,```
M`-7Y``!!````!OH``%L```!(^@``20```*3Z```=````[OH``!@````,^P``
M(0```"7[```?````1_L``"L```!G^P``(0```)/[```G````M?L``!T```#=
M^P``$0```/O[```S````#?P``"4```!!_```)P```&?\```?````C_P``#``
M``"O_```:0```.#\```]````2OT``&4```"(_0``30```.[]```O````//X`
M`"X```!L_@``,````)O^``!4````S/X``%H````A_P``2````'S_``!*````
MQ?\``#(````0``$`+P```$,``0`L````<P`!`"T```"@``$`<0```,X``0!O
M````0`$!`+,```"P`0$`%P```&0"`0`E````?`(!`#(```"B`@$`*0```-4"
M`0`^````_P(!`"(````^`P$`4@```&$#`0`E````M`,!``L```#:`P$`L0``
M`.8#`0!%````F`0!`"$```#>!`$`,``````%`0`E````,04!`!P```!7!0$`
M,0```'0%`0`'````I@4!``<```"N!0$`!````+8%`0`-````NP4!``L```#)
M!0$`#@```-4%`0`+````Y`4!``4```#P!0$`$````/8%`0`"````!P8!`%D`
M```*!@$`!0```&0&`0`2````:@8!``0```!]!@$`!P```((&`0`(````B@8!
M``4```"3!@$``P```)D&`0`0````G08!``P```"N!@$`$P```+L&`0`-````
MSP8!``(```#=!@$`!P```.`&`0`&````Z`8!`!0```#O!@$`#`````0'`0`8
M````$0<!``8````J!P$`$@```#$'`0`,````1`<!``,```!1!P$`*@```%4'
M`0`$````@`<!``8```"%!P$`!P```(P'`0`?````E`<!`#4```"T!P$`+@``
M`.H'`0`O````&0@!`!<```!)"`$`(````&$(`0`;````@@@!`!@```">"`$`
M)````+<(`0`?````W`@!`!H```#\"`$`(````!<)`0`:````.`D!`#(```!3
M"0$`+P```(8)`0`K````M@D!`!\```#B"0$`(P````(*`0`?````)@H!`!H`
M``!&"@$`)0```&$*`0`F````APH!`"4```"N"@$`)````-0*`0`8````^0H!
M`!T````2"P$`)````#`+`0`8````50L!`"(```!N"P$`)0```)$+`0`\````
MMPL!`!\```#T"P$`(P```!0,`0`?````.`P!`"````!8#`$`&@```'D,`0`8
M````E`P!`"8```"M#`$`'@```-0,`0`I````\PP!`!X````=#0$`"0```#P-
M`0`,````1@T!`!<```!3#0$`+P```&L-`0`D````FPT!``<```#`#0$`#P``
M`,@-`0`4````V`T!``X```#M#0$`#0```/P-`0`D````"@X!``4````O#@$`
M!P```#4.`0`B````/0X!`"4```!@#@$`'0```(8.`0`:````I`X!``<```"_
M#@$`QP```,<.`0`+````CP\!`!4```";#P$`!@```+$/`0`)````N`\!``L`
M``#"#P$`%P```,X/`0`&````Y@\!`#,```#M#P$`$P```"$0`0`3````-1`!
M``<```!)$`$`#P```%$0`0`'````81`!`#(```!I$`$`(0```)P0`0`3````
MOA`!``P```#2$`$`$0```-\0`0`R````\1`!``@````D$0$`"0```"T1`0`*
M````-Q$!`!0```!"$0$`"@```%<1`0`=````8A$!``@```"`$0$`'P```(D1
M`0`(````J1$!`!H```"R$0$`!@```,T1`0`5````U!$!``<```#J$0$`"```
M`/(1`0`)````^Q$!`#\````%$@$`!P```$42`0`/````31(!``X```!=$@$`
M$````&P2`0`)````?1(!``D```"'$@$`"````)$2`0`3````FA(!``<```"N
M$@$`&0```+82`0`*````T!(!`!<```#;$@$`%````/,2`0`*````"!,!``P`
M```3$P$`%P```"`3`0`$````.!,!`"H````]$P$`$0```&@3`0`'````>A,!
M``(```""$P$`$````(43`0`8````EA,!``L```"O$P$``P```+L3`0`(````
MOQ,!``8```#($P$`!P```,\3`0`-````UQ,!``L```#E$P$`%````/$3`0`5
M````!A0!``X````<%`$`+P```"L4`0`@````6Q0!`!P```!\%`$`#````)D4
M`0`Q````IA0!``4```#8%`$`$@```-X4`0`_````\10!`!(````Q%0$`"@``
M`$05`0`&````3Q4!``0```!6%0$`!````%L5`0`*````8!4!`!,```!K%0$`
M!0```'\5`0`&````A14!``8```",%0$`!````),5`0`,````F!4!``H```"E
M%0$`!0```+`5`0`8````MA4!`!D```#/%0$`'P```.D5`0`=````"18!`!$`
M```G%@$``@```#D6`0`$````/!8!``H```!!%@$`!@```$P6`0`%````4Q8!
M``,```!9%@$`#````%T6`0!%````:A8!`!H```"P%@$`-0```,L6`0`H````
M`1<!`%,````J%P$`&0```'X7`0!R````F!<!`"`````+&`$`-0```"P8`0`A
M````8A@!`$4```"$&`$`,````,H8`0`H````^Q@!`"D````D&0$`)@```$X9
M`0`E````=1D!`"@```";&0$`*````,09`0`B````[1D!`#`````0&@$`$@``
M`$$:`0`3````5!H!`!````!H&@$`>0```'D:`0`)````\QH!`',```#]&@$`
M?````'$;`0`K````[AL!`!<````:'`$`%@```#(<`0`/````21P!`!\```!9
M'`$`0````'D<`0`?````NAP!`!P```#:'`$`40```/<<`0`4````21T!``H`
M``!>'0$`!0```&D=`0`&````;QT!``@```!V'0$`!0```'\=`0`2````A1T!
M`!````"8'0$`$P```*D=`0`=````O1T!``\```#;'0$`#P```.L=`0`$````
M^QT!``D`````'@$`"P````H>`0`'````%AX!``4````>'@$`%````"0>`0`'
M````.1X!``@```!!'@$`#P```$H>`0`(````6AX!``P```!C'@$`#P```'`>
M`0`&````@!X!`!0```"''@$`!@```)P>`0`,````HQX!``@```"P'@$`!```
M`+D>`0`*````OAX!``<```#)'@$`!````-$>`0`9````UAX!``(```#P'@$`
M"0```/,>`0`&````_1X!``8````$'P$`)P````L?`0`$````,Q\!``\````X
M'P$`$P```$@?`0`'````7!\!``<```!D'P$`!@```&P?`0`&````<Q\!`!``
M``!Z'P$`$@```(L?`0`&````GA\!``D```"E'P$`(@```*\?`0`'````TA\!
M``<```#:'P$`"P```.(?`0`%````[A\!``(```#T'P$`"P```/<?`0#'`0``
M`R`!``X```#+(0$`%0```-HA`0`-````\"$!``<```#^(0$`"`````8B`0`(
M````#R(!``H````8(@$`"@```",B`0`2````+B(!``T```!!(@$`"````$\B
M`0`%````6"(!`!T```!>(@$`#````'PB`0`-````B2(!`!4```"7(@$`$```
M`*TB`0`+````OB(!`!````#*(@$`"````-LB`0`3````Y"(!``T```#X(@$`
M"@````8C`0`+````$2,!``L````=(P$`#P```"DC`0`&````.2,!`!````!`
M(P$`%@```%$C`0`+````:",!`!(```!T(P$`$@```(<C`0`(````FB,!`"T`
M``"C(P$`&0```-$C`0`X````ZR,!`$$````D)`$`4P```&8D`0!1````NB0!
M`%D````,)0$`5P```&8E`0`[````OB4!``H```#Z)0$`#@````4F`0`6````
M%"8!``4````K)@$`!@```#$F`0`9````."8!``P```!2)@$`%````%\F`0`7
M````="8!`"<```",)@$`)@```+0F`0`1````VR8!`!\```#M)@$`#P````TG
M`0`$````'2<!`!$````B)P$`$````#0G`0`'````12<!`!0```!-)P$`$0``
M`&(G`0`8````="<!``X```"-)P$`$0```)PG`0`*````KB<!`"D```"Y)P$`
M$P```.,G`0`7````]R<!`!`````/*`$`(P```"`H`0`&````1"@!``<```!+
M*`$`2@```%,H`0`,````GB@!``@```"K*`$`"P```+0H`0`'````P"@!``@`
M``#(*`$`#P```-$H`0`(````X2@!``H```#J*`$``P```/4H`0`9````^2@!
M``\````3*0$`&0```",I`0`4````/2D!`!(```!2*0$`*````&4I`0`,````
MCBD!`"<```";*0$`%P```,,I`0`C````VRD!`!T```#_*0$`$@```!TJ`0`2
M````,"H!``X```!#*@$`'P```%(J`0`&````<BH!``8```!Y*@$`"````(`J
M`0`.````B2H!``<```"8*@$`"@```*`J`0`1````JRH!``@```"]*@$`#P``
M`,8J`0`6````UBH!`!H```#M*@$`"`````@K`0`2````$2L!``4````D*P$`
M%@```"HK`0`>````02L!``T```!@*P$`,````&XK`0`)````GRL!``<```"I
M*P$`%````+$K`0`%````QBL!``4```#,*P$`$````-(K`0`+````XRL!`!H`
M``#O*P$`,P````HL`0`/````/BP!`"8```!.+`$`,P```'4L`0`Q````J2P!
M`#````#;+`$`"`````PM`0`%````%2T!``D````;+0$`"````"4M`0`Y````
M+BT!`"T```!H+0$`.````)8M`0!3````SRT!`#<````C+@$`-P```%LN`0`V
M````DRX!`#<```#*+@$`)0````(O`0`J````*"\!`#<```!3+P$`/0```(LO
M`0`/````R2\!`!,```#9+P$`)P```.TO`0`<````%3`!``X````R,`$`"P``
M`$$P`0`,````33`!``8```!:,`$`#````&$P`0`:````;C`!`"8```"),`$`
M!@```+`P`0`'````MS`!`!8```"_,`$`"0```-8P`0`(````X#`!``8```#I
M,`$`"0```/`P`0`&````^C`!``4````!,0$`!0````<Q`0`'````#3$!``8`
M```5,0$`"@```!PQ`0`E````)S$!``\```!-,0$`"0```%TQ`0`%````9S$!
M``<```!M,0$`!P```'4Q`0`%````?3$!``T```"#,0$`!@```)$Q`0`3````
MF#$!``,```"L,0$`"````+`Q`0`*````N3$!``T```#$,0$`"````-(Q`0`C
M````VS$!`!$```#_,0$`"0```!$R`0`2````&S(!``P````N,@$`!P```#LR
M`0`#````0S(!``,```!',@$`%````$LR`0`4````8#(!``@```!U,@$`"```
M`'XR`0`(````AS(!``<```"0,@$`5P```)@R`0`D````\#(!``8````5,P$`
M!@```!PS`0`7````(S,!`!H````[,P$`'````%8S`0`L````<S,!`!L```"@
M,P$`+@```+PS`0!R````ZS,!`"4```!>-`$`"@```(0T`0`'````CS0!`!(`
M``"7-`$`$0```*HT`0`/````O#0!``X```#,-`$`%````-LT`0`0````\#0!
M`!0````!-0$`#P```!8U`0`5````)C4!``4````\-0$`%P```$(U`0`;````
M6C4!`!<```!V-0$`%````(XU`0`#````HS4!``8```"G-0$`:````*XU`0`$
M````%S8!`!8````<-@$`!0```#,V`0`$````.38!`!X````^-@$`&````%TV
M`0`,````=C8!`!@```"#-@$`&````)PV`0`M````M38!``X```#C-@$`(@``
M`/(V`0`(````%3<!`!H````>-P$`&````#DW`0`3````4C<!`!P```!F-P$`
M&````(,W`0`4````G#<!``L```"Q-P$`"````+TW`0`'````QC<!`!````#.
M-P$`%0```-\W`0`0````]3<!``@````&.`$`!0````\X`0`+````%3@!``P`
M```A.`$`"````"XX`0`-````-S@!``<```!%.`$`!@```$TX`0`1````5#@!
M``@```!F.`$`#````&\X`0`'````?#@!``4```"$.`$`"````(HX`0`(````
MDS@!`!,```"<.`$`"P```+`X`0`.````O#@!``4```#+.`$`'0```-$X`0`0
M````[S@!`!$`````.0$`-````!(Y`0!$````1SD!`!\```",.0$`,0```*PY
M`0`*````WCD!``\```#I.0$`!P```/DY`0`)`````3H!``\````+.@$`"0``
M`!LZ`0`1````)3H!`"$````W.@$`(0```%DZ`0`D````>SH!`"0```"@.@$`
M&````,4Z`0`A````WCH!`!L`````.P$`)0```!P[`0`:````0CL!`!T```!=
M.P$`&````'L[`0`C````E#L!`"D```"X.P$`&P```.([`0`F````_CL!`#``
M```E/`$`+@```%8\`0`1````A3P!`"D```"7/`$`#@```,$\`0"P````T#P!
M`!````"!/0$`&````)(]`0`C````JST!`"0```#//0$`'P```/0]`0`;````
M%#X!`"`````P/@$`(0```%$^`0`N````<SX!`!P```"B/@$`'@```+\^`0`I
M````WCX!`$L````(/P$`#P```%0_`0`$````9#\!`!(```!I/P$`"````'P_
M`0`.````A3\!``X```"4/P$`$@```*,_`0`+````MC\!`!0```#"/P$`"@``
M`-<_`0`$````XC\!``P```#G/P$`#P```/0_`0`/````!$`!`!,````40`$`
M#````"A``0`Q````-4`!``L```!G0`$`$0```'-``0`$````A4`!``\```"*
M0`$`%0```)I``0`8````L$`!``\```#)0`$``@```-E``0`%````W$`!`!(`
M``#B0`$`!0```/5``0`+````^T`!``P````'00$``P```!1!`0`/````&$$!
M``@````H00$`&````#%!`0`0````2D$!``H```!;00$`$````&9!`0`3````
M=T$!``@```"+00$`!@```)1!`0`.````FT$!``P```"J00$`&````+=!`0`,
M````T$$!``X```#=00$`(P```.Q!`0`,````$$(!`!X````=0@$`%P```#Q"
M`0`5````5$(!``P```!J0@$`!@```'="`0`.````?D(!``4```"-0@$`)P``
M`)-"`0`_````NT(!``4```#[0@$`"0````%#`0`>````"T,!``L````J0P$`
M$P```#9#`0`3````2D,!``<```!>0P$`&0```&9#`0`2````@$,!`!@```"3
M0P$`$````*Q#`0`5````O4,!``@```#30P$`"````-Q#`0`F````Y4,!`$@`
M```,1`$`"````%5$`0`6````7D0!``<```!U1`$`"@```'U$`0`Q````B$0!
M``\```"Z1`$`!0```,I$`0`&````T$0!``,```#71`$`!P```-M$`0`'````
MXT0!``P```#K1`$`#P```/A$`0`-````"$4!``T````610$`%````"1%`0`5
M````.44!`!0```!/10$`!0```&1%`0`%````:D4!``L```!P10$`"````'Q%
M`0`"````A44!``4```"(10$`#P```(Y%`0`A````GD4!`!(```#`10$`$```
M`--%`0`/````Y$4!`!$```#T10$`'@````9&`0`Q````)48!`"T```!71@$`
M"@```(5&`0`.````D$8!`(L```"?1@$`%@```"M'`0`0````0D<!``<```!3
M1P$`!0```%M'`0`A````84<!``@```"#1P$`!P```(Q'`0`'````E$<!``8`
M``"<1P$`$````*-'`0`.````M$<!`!$```##1P$`#P```-5'`0`;````Y4<!
M`!$````!2`$`#0```!-(`0`7````(4@!``<````Y2`$`"0```$%(`0`4````
M2T@!``T```!@2`$`.P```&Y(`0`9````JD@!``@```#$2`$`#0```,U(`0`=
M````VT@!`!D```#Y2`$`(0```!-)`0`@````-4D!`!H```!620$`&P```'%)
M`0`E````C4D!`!H```"S20$`!0```,Y)`0`=````U$D!`!````#R20$`#@``
M``-*`0`#````$DH!``0````62@$`#0```!M*`0`.````*4H!``\````X2@$`
M%P```$A*`0`+````8$H!``0```!L2@$`&````'%*`0`9````BDH!``\```"D
M2@$`#0```+1*`0`-````PDH!``X```#02@$`'P```-]*`0`&````_TH!``8`
M```&2P$`#@````U+`0`.````'$L!``T````K2P$`"````#E+`0`(````0DL!
M``0```!+2P$`%````%!+`0`+````94L!``4```!Q2P$`)````'=+`0`/````
MG$L!`&L```"L2P$`&@```!A,`0`)````,TP!``8````]3`$`"@```$1,`0`&
M````3TP!``@```!63`$`!````%],`0`*````9$P!``(```!O3`$`!````'),
M`0`'````=TP!`!4```!_3`$`$@```)5,`0`4````J$P!`!H```"]3`$``@``
M`-A,`0`"````VTP!``X```#>3`$`!@```.U,`0`*````]$P!``4```#_3`$`
M&0````5-`0`(````'TT!``8````H30$`%P```"]-`0`0````1TT!``D```!8
M30$`!P```&)-`0`%````:DT!``D```!P30$`#0```'I-`0`&````B$T!``8`
M``"/30$`&0```)9-`0`+````L$T!``4```"\30$`$@```,)-`0`'````U4T!
M``<```#=30$`&````.5-`0`=````_DT!``<````<3@$`"@```"1.`0`$````
M+TX!``D````T3@$`"````#Y.`0`+````1TX!``L```!33@$`!@```%].`0`-
M````9DX!``8```!T3@$`!````'M.`0`W````@$X!`$$```"X3@$`.````/I.
M`0`F````,T\!``4```!:3P$`#P```&!/`0`&````<$\!``@```!W3P$`'P``
M`(!/`0`:````H$\!``4```"[3P$`"````,%/`0`3````RD\!``@```#>3P$`
M"0```.=/`0`7````\4\!``8````)4`$`!@```!!0`0`5````%U`!``4````M
M4`$`"P```#-0`0`,````/U`!``@```!,4`$`"0```%50`0`%````7U`!`"X`
M``!E4`$`-````)10`0`\````R5`!`"<````&40$`/@```"Y1`0`X````;5$!
M`"@```"F40$`,@```,]1`0`M`````E(!`#4````P4@$`*````&92`0`2````
MCU(!`!,```"B4@$`#0```+92`0`Q````Q%(!`!P```#V4@$`'````!-3`0`:
M````,%,!``<```!+4P$`"````%-3`0`'````7%,!``@```!D4P$`)@```&U3
M`0`D````E%,!`#$```"Y4P$`"0```.M3`0`8````]5,!`"@````.5`$`%@``
M`#=4`0`2````3E0!``8```!A5`$`"P```&A4`0`,````=%0!``X```"!5`$`
M#P```)!4`0`X````H%0!`(````#95`$`9@```%I5`0`/````P54!``L```#1
M50$`#````-U5`0`1````ZE4!`!(```#\50$`#@````]6`0`'````'E8!``\`
M```F5@$`%````#96`0`1````2U8!``\```!=5@$`'@```&U6`0`P````C%8!
M`'T```"]5@$`$````#M7`0`%````3%<!`!0```!25P$`"0```&=7`0`)````
M<5<!``D```![5P$`$@```(57`0`.````F%<!``X```"G5P$`$P```+97`0`5
M````RE<!`!\```#@5P$`(0````!8`0`=````(E@!`!\```!`6`$`(````&!8
M`0`B````@5@!`!@```"D6`$`-P```+U8`0`/````]5@!`!$````%60$`$0``
M`!=9`0`3````*5D!``T````]60$`$@```$M9`0`4````7ED!``\```!S60$`
M$0```(-9`0`R````E5D!`!8```#(60$`%````-]9`0`\````]%D!`!0````Q
M6@$`"@```$9:`0`3````45H!`"(```!E6@$`$@```(A:`0`H````FUH!`!D`
M``#$6@$`&0```-Y:`0`7````^%H!`!(````06P$`'P```"-;`0`B````0UL!
M`!H```!F6P$`$@```(%;`0`7````E%L!`!P```"L6P$`%@```,E;`0`(````
MX%L!`!@```#I6P$`!`````)<`0`%````!UP!``L````-7`$`$````!E<`0`&
M````*EP!``P````Q7`$`!P```#Y<`0`&````1EP!``<```!-7`$`!0```%5<
M`0`(````6UP!`!@```!D7`$`!@```'U<`0`)````A%P!``@```".7`$`!@``
M`)=<`0`(````GEP!`!$```"G7`$`$@```+E<`0`/````S%P!`!````#<7`$`
M"@```.U<`0`1````^%P!``0````*70$`(0````]=`0`/````,5T!``\```!!
M70$`%@```%%=`0`+````:%T!``D```!T70$`"P```'Y=`0`O````BET!``0`
M``"Z70$`"````+]=`0`$````R%T!``4```#-70$`$0```--=`0`&````Y5T!
M``H```#L70$`"@```/==`0`%`````EX!`",````(7@$`#@```"Q>`0`1````
M.UX!`!4```!-7@$`%P```&->`0`<````>UX!`!H```"87@$`!0```+->`0`%
M````N5X!``D```"_7@$`&0```,E>`0`'````XUX!``8```#K7@$`#0```/)>
M`0`.`````%\!``<````/7P$`!P```!=?`0`%````'U\!``\````E7P$`#@``
M`#5?`0`*````1%\!`!````!/7P$`$@```&!?`0`4````<U\!`!0```"(7P$`
M#0```)U?`0`6````JU\!``@```#"7P$`!0```,M?`0`2````T5\!`$@```#D
M7P$`!@```"U@`0`/````-&`!`",```!$8`$`#P```&A@`0`5````>&`!``X`
M``".8`$`#0```)U@`0`/````JV`!``D```"[8`$`#P```,5@`0`/````U6`!
M`!$```#E8`$`$````/=@`0`>````"&$!``H````G80$`"````#)A`0`,````
M.V$!``P```!(80$`#````%5A`0`%````8F$!``P```!H80$`"0```'5A`0`>
M````?V$!`&<```">80$`$P````9B`0`+````&F(!``4````F8@$`!0```"QB
M`0`2````,F(!`!0```!%8@$`$P```%IB`0`+````;F(!``(```!Z8@$`"@``
M`'UB`0`O````B&(!``,```"X8@$`!0```+QB`0`F````PF(!``H```#I8@$`
M!0```/1B`0`%````^F(!`!,`````8P$`$@```!1C`0`&````)V,!``@````N
M8P$`!P```#=C`0`$````/V,!``4```!$8P$`;@```$IC`0`*````N6,!``T`
M``#$8P$`!@```-)C`0`%````V6,!`"D```#?8P$`,@````ED`0`1````/&0!
M``H```!.9`$`$0```%ED`0`*````:V0!``D```!V9`$`&0```(!D`0`G````
MFF0!`"D```#"9`$`*````.QD`0`/````%64!``8````E90$`!P```"QE`0`(
M````-&4!``<````]90$`#@```$5E`0`,````5&4!``8```!A90$`10```&AE
M`0`0````KF4!``H```"_90$`!@```,IE`0`<````T64!`&$```#N90$`!@``
M`%!F`0`(````5V8!``8```!@9@$`%````&=F`0`)````?&8!``@```"&9@$`
M*0```(]F`0`H````N68!``D```#B9@$`!0```.QF`0`K````\F8!`&<````>
M9P$`*0```(9G`0`N````L&<!`!@```#?9P$``@```/AG`0`-````^V<!``4`
M```):`$`%`````]H`0`*````)&@!``4````O:`$`"````#5H`0`&````/F@!
M``D```!%:`$`"P```$]H`0`'````6V@!``@```!C:`$`"P```&QH`0`&````
M>&@!``X```!_:`$`$````(YH`0`1````GV@!``T```"Q:`$`#P```+]H`0`0
M````SV@!``\```#@:`$`#0```/!H`0`/````_F@!``@````.:0$`'@```!=I
M`0`3````-FD!``@```!*:0$`"@```%-I`0`6````7FD!``<```!U:0$`#P``
M`'UI`0`%````C6D!``<```"3:0$`!0```)MI`0`%````H6D!``@```"G:0$`
M$0```+!I`0`1````PFD!`!H```#4:0$`%@```.]I`0`4````!FH!`!<````;
M:@$`&@```#-J`0`?````3FH!`!@```!N:@$``P```(=J`0`%````BVH!``X`
M``"1:@$`#@```*!J`0`6````KVH!`"(```#&:@$`"P```.EJ`0`4````]6H!
M``<````*:P$`"@```!)K`0`%````'6L!``X````C:P$`"0```#)K`0`%````
M/&L!``<```!":P$``P```$IK`0`$````3FL!``(```!3:P$`/@```%9K`0`T
M````E6L!`!0```#*:P$`*@```-]K`0!%````"FP!``H```!0;`$`+````%ML
M`0`S````B&P!`#@```"\;`$`.````/5L`0`]````+FT!`!0```!L;0$`&@``
M`(%M`0`;````G&T!`!P```"X;0$`&P```-5M`0`?````\6T!`!L````1;@$`
M&P```"UN`0`.````26X!`#````!8;@$`,````(EN`0`T````NFX!`#T```#O
M;@$`,@```"UO`0`O````8&\!`'(```"0;P$`)@````-P`0`,````*G`!``H`
M```W<`$`,P```$)P`0`U````=G`!`"<```"L<`$`#0```-1P`0!$````XG`!
M`#\````G<0$`!0```&=Q`0`;````;7$!`!8```")<0$`$@```*!Q`0`1````
MLW$!`!D```#%<0$`!@```-]Q`0`'````YG$!``D```#N<0$`#@```/AQ`0`4
M````!W(!``X````<<@$`$0```"MR`0`(````/7(!`!X```!&<@$`"````&5R
M`0`%````;G(!``L```!T<@$`#0```(!R`0`+````CG(!`#H```":<@$``@``
M`-5R`0`&````V'(!``X```#?<@$`"0```.YR`0`%````^'(!`!(```#^<@$`
M"````!%S`0`$````&G,!`#,````?<P$`#@```%-S`0`I````8G,!`%````",
M<P$`%0```-US`0`Z````\W,!`"`````N=`$`#P```$]T`0`(````7W0!``\`
M``!H=`$`#P```'AT`0`*````B'0!`!0```"3=`$`#````*AT`0`:````M70!
M`!4```#0=`$`!P```.9T`0`1````[G0!`!$`````=0$`(0```!)U`0`4````
M-'4!`!(```!)=0$`$````%QU`0`C````;74!``<```"1=0$`"P```)EU`0`4
M````I74!`!(```"Z=0$`$0```,UU`0`:````WW4!`!````#Z=0$`#`````MV
M`0`'````&'8!``@````@=@$`!0```"EV`0`A````+W8!``8```!1=@$`$0``
M`%AV`0`(````:G8!``X```!S=@$`!0```()V`0`/````B'8!`"\```"8=@$`
M$@```,AV`0`&````VW8!``<```#B=@$`%P```.IV`0`&`````G<!`!(````)
M=P$`!0```!QW`0`5````(G<!``0````X=P$`!P```#UW`0`6````17<!`#$`
M``!<=P$`!0```(YW`0`3````E'<!`!````"H=P$`!````+EW`0`.````OG<!
M``@```#-=P$`!P```-9W`0`*````WG<!``@```#I=P$`!@```/)W`0`%````
M^7<!`"````#_=P$`-0```"!X`0`U````5G@!`!L```",>`$`)````*AX`0`C
M````S7@!`#\```#Q>`$`&P```#%Y`0`F````37D!`"T```!T>0$`)````*)Y
M`0`&````QWD!``@```#.>0$`"0```-=Y`0`+````X7D!`!<```#M>0$`$```
M``5Z`0`N````%GH!`"0```!%>@$`-````&IZ`0`X````GWH!`!$```#8>@$`
M(@```.IZ`0`2````#7L!``8````@>P$`&P```"=[`0`2````0WL!`!$```!6
M>P$`#0```&A[`0`'````=GL!``X```!^>P$`"````(U[`0`+````EGL!``P`
M``"B>P$`&P```*][`0`T````RWL!``D`````?`$`!0````I\`0`)````$'P!
M`!H````:?`$`$0```#5\`0`$````1WP!``H```!,?`$`"P```%=\`0`0````
M8WP!``X```!T?`$`#````(-\`0`6````D'P!``4```"G?`$`!0```*U\`0`/
M````LWP!`"P```##?`$`2P```/!\`0`6````/'T!`!T```!3?0$`&@```'%]
M`0`%````C'T!`!````"2?0$`!P```*-]`0`1````JWT!`"P```"]?0$`"0``
M`.I]`0`.````]'T!`!$````#?@$`%0```!5^`0`-````*WX!`#D````Y?@$`
M"0```'-^`0`=````?7X!`!,```";?@$`%P```*]^`0`O````QWX!``\```#W
M?@$`$0````=_`0`7````&7\!`!X````Q?P$`"````%!_`0`2````67\!``<`
M``!L?P$`%````'1_`0`:````B7\!``<```"D?P$`!P```*Q_`0`0````M'\!
M``\```#%?P$`$0```-5_`0`%````YW\!``@```#M?P$`#0```/9_`0`-````
M!(`!``X````2@`$`$````"&``0`0````,H`!``8```!#@`$`"````$J``0`N
M````4X`!`"8```""@`$`)````*F``0`'````SH`!``X```#6@`$`!@```.6`
M`0`7````[(`!`!<````$@0$`(@```!R!`0`*````/X$!``L```!*@0$``P``
M`%:!`0`&````6H$!``P```!A@0$``@```&Z!`0`,````<8$!`!,```!^@0$`
M"P```)*!`0`9````GH$!`"````"X@0$`$@```-F!`0`%````[($!``H```#R
M@0$`%0```/V!`0`1````$X(!``X````E@@$`!@```#2"`0`)````.X(!`!``
M``!%@@$`2@```%:"`0`7````H8(!``0```"Y@@$`"````+Z"`0`4````QX(!
M``X```#<@@$`#````.N"`0`B````^((!`!<````;@P$`#0```#.#`0`C````
M08,!`!P```!E@P$`#0```(*#`0!B````D(,!`"(```#S@P$`%@```!:$`0`K
M````+80!`"````!9A`$`%````'J$`0`>````CX0!`!8```"NA`$`'P```,6$
M`0`8````Y80!``H```#^A`$`!P````F%`0`'````$84!``0````9A0$`$P``
M`!Z%`0`-````,H4!`!$```!`A0$`"````%*%`0!!````6X4!`#P```"=A0$`
M0@```-J%`0!@````'88!``D```!^A@$`/@```(B&`0`O````QX8!``H```#W
MA@$`"@````*'`0`.````#8<!`#L````<AP$`"````%B'`0`X````88<!`"X`
M``":AP$`(@```,F'`0`/````[(<!`"D```#\AP$`&````":(`0`P````/X@!
M`"(```!PB`$`*````).(`0`B````O(@!``\```#?B`$`"````.^(`0`.````
M^(@!``\````'B0$`$````!>)`0`'````*(D!`#T````PB0$`#````&Z)`0`.
M````>XD!``8```"*B0$`%0```)&)`0`(````IXD!``@```"PB0$`#P```+F)
M`0`)````R8D!``D```#3B0$`!P```-V)`0`0````Y8D!`!````#VB0$`%@``
M``>*`0`7````'HH!`!$````VB@$`&P```$B*`0`3````9(H!``@```!XB@$`
M#0```(&*`0`,````CXH!``\```"<B@$`#````*R*`0`9````N8H!`"P```#3
MB@$`#P````"+`0`?````$(L!`"@````PBP$`"````%F+`0`&````8HL!`!``
M``!IBP$`"0```'J+`0`$````A(L!`!@```")BP$`#@```**+`0`0````L8L!
M``X```#"BP$`!0```-&+`0`)````UXL!``@```#ABP$`"0```.J+`0`+````
M](L!`!$`````C`$`!````!*,`0`.````%XP!``4````FC`$`"P```"R,`0`.
M````.(P!`"$```!'C`$`"@```&F,`0`"````=(P!``<```!WC`$`!0```'^,
M`0`+````A8P!``<```"1C`$`,@```)F,`0`D````S(P!`#$```#QC`$`%P``
M`".-`0`%````.XT!``<```!!C0$`!P```$F-`0`,````48T!``@```!>C0$`
M#0```&>-`0`3````=8T!``\```")C0$`#````)F-`0`.````IHT!``L```"U
MC0$`!P```,&-`0`(````R8T!``@```#2C0$`%@```-N-`0`)````\HT!``<`
M``#\C0$`"0````2.`0`@````#HX!``4````OC@$`!@```#6.`0`&````/(X!
M``H```!#C@$`!P```$Z.`0`2````5HX!`!(```!IC@$`!@```'R.`0`6````
M@XX!``L```":C@$`&P```*:.`0`$````PHX!``4```#'C@$`#P```,V.`0`<
M````W8X!``<```#ZC@$`"0````*/`0`5````#(\!``0````BCP$`"@```">/
M`0`/````,H\!``H```!"CP$``@```$V/`0`1````4(\!``<```!BCP$`'@``
M`&J/`0`>````B8\!`#,```"HCP$`)0```-R/`0`I`````I`!`%T````LD`$`
M$P```(J0`0!4````GI`!`"X```#SD`$`00```"*1`0!>````9)$!`"````##
MD0$`2@```.21`0`H````+Y(!`#(```!8D@$`(P```(N2`0`=````KY(!`"P`
M``#-D@$`[@$``/J2`0`;````Z90!`!0````%E0$`1@```!J5`0"%````894!
M`#\```#GE0$`,0```">6`0!+````698!`#@```"EE@$`'````-Z6`0`5````
M^Y8!`!@````1EP$`%P```"J7`0`K````0I<!`!P```!NEP$`'P```(N7`0`3
M````JY<!``P```"_EP$`+P```,R7`0`>````_)<!`!\````;F`$`(0```#N8
M`0!"````79@!`%````"@F`$`-0```/&8`0!A````)YD!`$8```")F0$`+P``
M`-"9`0`G`````)H!`"P````HF@$`1P```%6:`0!0````G9H!`$$```#NF@$`
M3@```#";`0`M````?YL!`"4```"MFP$`)0```-.;`0`F````^9L!`&H````@
MG`$`:````(N<`0"N````])P!`!L```"CG0$`*@```+^=`0`V````ZIT!`"\`
M```AG@$`10```%&>`0`@````EYX!`%$```"XG@$`(0````J?`0`+````+)\!
M`+4````XGP$`/````.Z?`0`B````*Z`!`"H```!.H`$`*P```'F@`0`<````
MI:`!`"\```#"H`$`!@```/*@`0`&````^:`!``,`````H0$`#@````2A`0`+
M````$Z$!``H````?H0$`"P```"JA`0`%````-J$!``P````\H0$`!````$FA
M`0!N````3J$!``0```"]H0$`%@```,*A`0`$````V:$!``<```#>H0$`!0``
M`.:A`0`%````[*$!``0```#RH0$`$````/>A`0`(````"*(!`!$````1H@$`
M$P```".B`0`"````-Z(!``<````ZH@$`!P```$*B`0`4````2J(!``P```!?
MH@$`%@```&RB`0`&````@Z(!`!,```"*H@$`#````)ZB`0`#````JZ(!`"@`
M``"OH@$`!````-BB`0`&````W:(!``@```#DH@$`&P```.VB`0`T````":,!
M`"<````^HP$`*````&:C`0`3````CZ,!`"````"CHP$`'0```,2C`0`;````
MXJ,!`"````#^HP$`&P```!^D`0`:````.Z0!`"(```!6I`$`%````'FD`0`Q
M````CJ0!`"\```#`I`$`)@```/"D`0`:````%Z4!`!X````RI0$`'@```%&E
M`0`9````<*4!`",```"*I0$`'0```*ZE`0`H````S*4!`!H```#UI0$`&P``
M`!"F`0`@````+*8!`",```!-I@$`&0```'&F`0`A````BZ8!`!X```"MI@$`
M-@```,RF`0`>`````Z<!`"(````BIP$`(@```$6G`0`C````:*<!`!T```",
MIP$`&````*JG`0`B````PZ<!`"$```#FIP$`,@````BH`0`@````.Z@!``H`
M``!<J`$`"P```&>H`0`6````<Z@!`"@```"*J`$`'0```+.H`0`*````T:@!
M``\```#<J`$`%P```.RH`0`.````!*D!`!8````3J0$`(0```"JI`0`(````
M3*D!``<```!5J0$`(@```%VI`0`E````@*D!`"4```"FJ0$`%@```,RI`0`*
M````XZD!`-P```#NJ0$`$0```,NJ`0`5````W:H!``P```#SJ@$`#P````"K
M`0`6````$*L!`",````GJP$`!@```$NK`0!`````4JL!`!4```"3JP$`%```
M`*FK`0`'````OJL!`!,```#&JP$`"@```-JK`0`W````Y:L!`"D````=K`$`
M%@```$>L`0`4````7JP!`!0```!SK`$`,0```(BL`0`1````NJP!`!(```#,
MK`$`$P```-^L`0`1````\ZP!``H````%K0$`%P```!"M`0`(````**T!`"``
M```QK0$`"````%*M`0`3````6ZT!``<```!OK0$`$0```'>M`0`'````B:T!
M``@```"1K0$`"0```)JM`0`V````I*T!``4```#;K0$`#P```.&M`0`4````
M\:T!`!$````&K@$`"P```!BN`0`,````)*X!``<````QK@$`$P```#FN`0`+
M````3:X!`!L```!9K@$`$````'6N`0`:````AJX!`!<```"AK@$`"P```+FN
M`0`,````Q:X!`!@```#2K@$`"0```.NN`0`J````]:X!`!$````@KP$`"@``
M`#*O`0`"````/:\!`!````!`KP$`%P```%&O`0`+````::\!``,```!UKP$`
M"@```'FO`0`%````A*\!``<```"*KP$`#````)*O`0`+````GZ\!`!0```"K
MKP$`%0```,"O`0`.````UJ\!`#@```#EKP$`&````!ZP`0`8````-[`!``H`
M``!0L`$`)0```%NP`0`%````@;`!`!8```"'L`$`/````)ZP`0`-````V[`!
M``X```#IL`$`!@```/BP`0`$````_[`!``0````$L0$`"@````FQ`0`7````
M%+$!``4````LL0$`!@```#*Q`0`(````.;$!``4```!"L0$`%````$BQ`0`5
M````7;$!``4```!SL0$`%P```'FQ`0`>````D;$!`!\```"PL0$`&@```-"Q
M`0`0````Z[$!``(```#\L0$`!````/^Q`0`+````!+(!``4````0L@$`!0``
M`!:R`0`#````'+(!``X````@L@$`3````"^R`0`<````?+(!`"H```"9L@$`
M)@```,2R`0!.````Z[(!`!\````ZLP$`70```%JS`0`=````N+,!`$<```#6
MLP$`(````!ZT`0`Q````/[0!`#,```!QM`$`*````*6T`0`T````SK0!`#8`
M```#M0$`-````#JU`0`P````;[4!`"@```"@M0$`(@```,FU`0`X````[+4!
M`!0````EM@$`%0```#JV`0`.````4+8!`&$```!?M@$`"@```,&V`0!C````
MS+8!`&D````PMP$`)P```)JW`0`;````PK<!`!@```#>MP$`$0```/>W`0`=
M````";@!`#D````GN`$`(@```&&X`0`;````A+@!`&H```"@N`$`%@````NY
M`0`*````(KD!``0````MN0$`!@```#*Y`0`(````.;D!``4```!"N0$`%0``
M`$BY`0`2````7KD!`!D```!QN0$`(P```(NY`0`/````K[D!``T```"_N0$`
M!````,VY`0`)````TKD!``T```#<N0$`"````.JY`0`)````\[D!`!8```#]
MN0$`"P```!2Z`0`*````(+H!`!4````KN@$`"0```$&Z`0`&````2[H!`!,`
M``!2N@$`"@```&:Z`0`6````<;H!``H```"(N@$`!P```).Z`0`(````F[H!
M``@```"DN@$`#````*VZ`0`&````NKH!``8```#!N@$`&0```,BZ`0`"````
MXKH!``@```#EN@$`!@```.ZZ`0`&````];H!`"D```#\N@$`!0```":[`0`3
M````++L!`!D```!`NP$`"````%J[`0`'````8[L!``8```!KNP$`"@```'*[
M`0`0````?;L!`!D```".NP$`"````*B[`0`,````L;L!`",```"^NP$`"@``
M`.*[`0`)````[;L!`!````#WNP$`!0````B\`0`"````#KP!``L````1O`$`
M`0```"X!```0!0``B`8``,\$``#B!0``_P```!4"````````-`4``!T!```_
M`P```````$@$````````!0,``"0```!U!@`````````````B`0``U0,``&@!
M``">`0``(0,``&P$``#.`0``0`8``$D#``!``````````)\#````````````
M`.`#```I!0``EP$```````"Y`P``E00````````I```````````````<!```
M1P8```````"O`P`````````````Z`0``;0$``-<$```]`P``]@,``#8#````
M````"00````````M`0``(P0``/(%``!<`0````````````!7`P```````+$#
M``"=`@``E@,``%T!``!X!```_@(```````#=`@``^@```)4!````````+@8`
M`-(````4!@``!P0```````"\`P``Y`4``)($```,`P``<@8``*(#``!!`0``
M`````.L$``````````````````!5````.0(``+P````7!@``X````#<$``!A
M`````P`````````#`0``TP(``)<$``!*`P``T@$```D"````````A@$``,D$
M```?`@``X0````````">`P``#00``$X#``!V`P``MP,``,\`````````QP$`
M`$4!````````(`4``'X%```E!@``Y@```/`$```X`P``;00`````````````
M&0(``.X"``"8!@``=P0``*,!``#,!```W````.L"``!-`0``$`(``,<````-
M`P``4P,``!@&``!`!0``"`$```````!N!```1@$```````#_`@``>04``-<!
M``"N!```9@`````````J!```````````````````]`(``$8&``"8!```Y@0`
M`%<&``#B`P``)@8``/T#``#+!0``W0,``````````````````"8"````````
M'@```.`%``#.`@``````````````````B04``)`#```S`@``\@,``+D!``#D
M`@``?P0``$H%````````V@4``(X&``"E`P``=0```.`!``">!0``)`(`````
M``!R!0``P`0``%L"``!'`0``%`0`````````````Q@,``(T%``";`P``````
M``````!@`0``B@```"T%``!]`P``A`4``'P%``"^`P``"`````0&``#G!```
MV`0``-H$````````!P$``#P````X`@``1@```.T$```[`@```````#8`````
M````D`0```````#;`````````(0$``"(!````````*<#``!3`0``/0(``.4#
M```2`0```````)L"````````I`,``*0"``!L`P``6`,``.<"``````````4`
M`-0"``#X`0``/P```*X!````````B`4``&$"``#%!0``10(``#,%``"E`0``
M=`,``(T&``"2````N@4``$,!``"^!````````````````````````)(&``#Q
M`0``A@0``),!``!$`@```````'<&````````6````%$!``"H!```C`(`````
M``!F`P``I0(```````"H````-`$```````"A````>P$``-@%``!6!@``4@8`
M`&`#``!)!@````````````!P`0``O00`````````````304``(,#````````
M3`0``/T$```7`@``20```.,!``#3`P```````*H!``!X````:P,``.P"``"T
M!`````````````!P!0``G````,(%```Z````)0(``"T$``!>`@```````/,#
M```*`@```````'`"``#_!```A````,D````6!@````````````!-````,P``
M`.4$````````I@$``%X#```K`0``=P,``*<%````````/@,``$P!````````
M#P```)$&``!7`@``\`````````#!!0``#P(``(0"``!M`P``=`0```L#```H
M````G00``(\#``"!`P``,0,``'H$``"A`0``N@,``)@#```N!0``4P8````"
M```[`P``T@,```````!S!```2@0``(X!``"]!0``L@4``*P"```@`@``````
M``````#<!0``Q@(````````!`@``%0$``,P"````````$````%T`````````
M`````$`!``"K!0``[`,``#P"```)!@```````(T!``".!0```````,8%``!D
M`0``\P(````````@````XP```!,%````````)00``````````````````'0&
M``#5`@``<@```!@$`````````````#0$``#<`@```````)\```#6`@```P8`
M``````"1`P``#P4``&("```Z!0````````````!N!0``K@4``!D&``!4!@``
MKP(``)T!``"/`````````*D%````````]P$``!8````2`P``P0```'`#```.
M`@``(P4```````!O!``````````````P!@``5````%@!``"_`0``@00``(,"
M````````J0(``(<&```<````50(````````G`0```````$,%``#Y`@``^`(`
M`,`%``!&!0``F00`````````````-@0```<#``!C!0``C`$`````````````
M````````````````8`0`````````````=@$```````!Y`@``````````````
M````LP$```````!U`0```````.D$``#T!0``P0$``````````````````#<`
M``""!```(P```$(!``#3`````````,(`````````3@``````````````9P0`
M`'L$``#?````3@4``/`#`````````````,`!```=`@```````!D%```+!@``
MM04``(@```#F!0``]0(``,@"```T`P```````%X&``!B````60$``*$"``",
M!@``X00``*`$``````````````````".````Z`(``"@#``"`!0``9P8``"<"
M```;`@``F@(``,,```!2!0``!`(``%T$``#,`P``D`$``+8"``!Y````@P4`
M`!`&```"`@``:P4``(,!```C`@``$`,``'P!``#G`0``'`$```````!3````
MN00``/`%``#M`@``Z`4``&4```#)`@``>@8`````````````6@```+L```#L
M````K0(``%0!````````*0$``*H```"(`0``)P8``"$"```8!0``*`8`````
M````````,@(``%T&````````0P,``)H%````````#@4``'4$``"6!@```04`
M`!D$```Y`0```````#`$``!2`P````````````"_`P```````+@%````````
M`````%8"````````.08``,D%``!E`P``[P4``+,%``!G`P``[0$``/8$````
M``````````````#E!0``J`4``$0```#%`0```````$<%```S!```%04``",&
M``"H`0``?P$```T"``"2`0``V0```%H!``#>!0``?P4``!("``!O`@``>00`
M`-T%```#`@``1`,``%L%``!^`@``>P```%,$``"7`@``C`4```````"``0``
MR`$``%@$``"T!0```````.(`````````G@(``)\%``!!`@```````+(#````
M````<@(```````!.!@``4@$``/<#```&`P```````/(!``"C!0``````````
M````````CP$``%@"``!I`@``;@```"X$````````%@(``-4$````````U@,`
M`',#``!"`@``'P0``&4!``!6`P```````#$"``!`!```=@(``(L%``#?!0``
M`````&8"```1!@``(`8``/\%```8`P``@@,``&@%``#U!````````*D$```X
M!```N@(``'L%```:`0``;````)\"``````````````````!+````-04`````
M``#/`@```P,``#D$```=!@``508``*L$``#Y!```K`0``/0!```.`0``V`,`
M``<"````````8````"L%``":`P``J@0`````````````V04``,$"````````
MPP4``+`#``!$!@``FP```````````````````.\"``")!@``2P8```````#>
M`0```````+@```!&`@```````%`"``!U`@``*@$````````[!@``&`(``$,$
M``"V!0```````+($``#O`P```````+8$```1````I`4``),&``"3`@``4@(`
M`*0!``"%!````````"L```#<`0``8P(``````````````````-H#``"(`@``
M5@$``,<#``!(`0``3@0``!P"```_`0```@,``"\$````````^0$```````!)
M`@```````'<"```J`P``RP$``#\&````````>`4``%P"``"B!0``R```````
M``!7````C`0``.,#``!+!```B0```)$```"2!0``G`$``!P%``!S`0``U`4`
M`"T#``"K`0````````````"B````O0,``.("````````E@(``+<%````````
M`````'$!``!/`P``_0(``,X$``!*````?@```"L&```7`P``A`,``/<"````
M````R@4``"@!``#$`@``)@,``,<%```"!0``VP4`````````````'@$``"("
M``"C!````````!<%````````]0````$!``"!`0``H`4``,`````Z!```/0$`
M``````#6`0````````````#T`````````.$!`````````````&8$``"0````
M'@(````````>!```J0```+,"```P`P``W@```,(!`````````````%`&``!<
M`P```````'H#`````````````/$#```D`0```````#\%``!%!0``/@```(@#
M`````````````$$`````````RP````````!A!@``9```````````````E08`
M`(H%``#[`P``,@4````````3!@``E`8``.D"`````````````'0```#X`P``
M=@8``%$#```&!@``/04```````"V`P``N`$``,<"````````A04````````@
M`P``$@4``)<#````````>`8``*<$``"*!@````````````"C`@``L`(``!8!
M```A`0``/@0``%$"```8`0``1P```$0!``#Z`@```````"$$````````/`0`
M`&0"``#S````.````%D```#.````8P0``&0$``"O!````````(D$``#O!```
M``````````!N`@````````````"*`P``L`0``((%```G`P``2`(``(4"````
M```````````````=`P``WP$`````````````X04``!8%```W!@``-0```(4#
M````````L`4``&H``````````````,4#`````P``Z0$```````#;!```#P8`
M`,P%```3!````````+$````7`0``S0$``%0"```F!````````&X#````!@``
MC@(``&\#```,!0``A0$``"T&``!#`````````*X#``!2!```K0```)L%``"R
M`@```@0``-H!``!F!@``E`$``,0`````````MP0``'\```";!```0`(``&\!
M``!Z!0``IP````0#```F````AP,````!````````_`,``/X%``!D!@``````
M`(D!``#4!````````,,!``!B`0``Y0```'@#``!O!0```````*0$``!]!@``
M.P$```````!/````+P```$\"`````````````-$"``#H````T````&`"```$
M!```!0```*X"```.!```#P$``+\`````````O`(``(,&````````````````
M``"P`0``F@0``/T%``"M!```R`0```````!0!0```````-8```"5`@``2`8`
M``````#^`P``6P```!4````L`0``K04```````!\!@``SP,`````````````
M`````"\#``!'`@```````-0#``!I!```8@4``%4!```O`0```````/4!````
M````Y`0``.,"```*!0``_0$``"4````4````````````````````8`8`````
M````````````````````````%`4``````````````````-<`````````5`,`
M`"$&``"`!``````````````2`````````,T```!4!0``T@4``"4!``"/!```
M.0,``-4%```<!@``_P$``,0!````````7P8``+X"``!Q!@``W@,``&8!``!S
M!@``````````````````D0$``$\%``!>!0``;P```"X````*`0``````````
M``#1`0``V00```8!````````KP``````````````"P$```H$``#=!```````
M``T!````````608```````"4````^`4``"H"``"F`@``UP4``*(!```1`P``
M<````)$"``````````````````"G`@``3P0```````!0`P``S`$``"<$````
M````XP0``&0%`````````````!H"````````E@4``/H!``!+`0``+```````
M````````6@(`````````````?0$`````````````LP`````````1`@``/0``
M`$P"``#;`@``0@8```````!,````F`(``/L!```@`0``J@,`````````````
MI@```,X#``"7!0``Z0,``.0`````````]`0``"D#`````````````.T#``#D
M`P``Z@,``"4#`````````````%`$``"U!```UP(``-D#```Y!0``.`8``.X$
M``"=!0``NP0``)0$``"9`@``&@```#$&```B!0``E@$``&4%````````*`4`
M``````#X!````````&<"``!B!@``_`4``#\"````````-P(`````````````
MM`````\#``#A`@````0```X#````````+@,````````T`@``V`````````!;
M!@``)`,``+T!```E!0``^@,```````#?`@``404``/D```"$!@``)@4``%X`
M``#8`@``M@```',%````````*08``!(&``#Q````?`(``&\&```&`@``-@(`
M`,,#``#:`@``UP,```````!+`P````````\$``"0`@``G`4``(P#``#F`P``
M<@0``'(!````````600``)D``````````````%H#``!5!0``^P```/X!````
M````:@$``!L&````````&@4`````````````10,``',```":`````````/,$
M``!!`P``A`$``!T```"E````>@$``%\#``"^`0````````````"&`P``````
M```````U`@``X@0``%T#```L!@``?@0`````````````DP,``,(#```T````
M`````(\%```&`````````*`"``#%````\@0````````P`@``40```,,$```C
M`0``R`4``$D$``#^````:P$``*P`````````&P```.`"````````ZP4`````
M````````100``!0#``"A!```C00``$D!````````#`(``%\"````````OP4`
M``````#?!````````%\!```*!@``F@$``)D!``!A!```CP8``&`%```"````
M=0,``',"````````&0````````!"!```80$``'(#```&!0``Z@0``,8!``!8
M!@``:P8``.H```"'`@``R0$```````"<!````````*8%````````(0```)@%
M``!N!@``:`(``/P!``#,````AP$``*L#````````#`$``%D#``!/`0``#08`
M```````^`0``E@```&,&``!T`@``*P(```````#K````F`$``($&``"`````
MZP,``#8%``"K````G0,`````````````F``````````>`P``&@8``%(```#L
M!```#````"T```![`P```````$H!````````M0,``+<"``#W!0``>0$``#H"
M``!_`@``,0```$X"``!E!@``YP```#4&```(!@``YP,``-($``!8!0``1P,`
M`%X$``![`@```````,0%```2!````````+@#`````````08``!\#``#Q`@``
M`````*4$````````/P0``"(#````````;`$``'0!``#Y`P````````T```#I
M!0``,@0```````!(`P``P0,````````V`0``(04``(T```#3`0``Y@$``)X$
M`````````````&P"``!M!@``&@0``/<```!)!0``@0```-L#``"%````?@,`
M`/P$``#$`P```````,L$``!A!0``N@$``/L"``![!@``X@$``$8#``"S!```
MC0,``+(!```B!```K0$``!@```"\!```E0,``"T"````````U0$``$,&``!\
M`P```````!4$``!7!0``5`0`````````````$`0``,($````````M0```+4!
M``!\````7P4````````P!0``,@$``)\$```,!@```````*`!``!%!@``W`,`
M`&P&``"<`@``?04``.\!``!G`0````````````"J`@``1P0````````#!0``
MN`0``+D```!,!0``^````'X&````````2`4```````#0`P``8P```(8```"3
M````4P4``*0`````````[`4````````U!```O`4``/$$````````.P4`````
M``#+`@``#@8``#X%``#9`@``H04``+H$``!X`0``U@0``.X```"=````9@4`
M`"`$````````T0````````"N````2@8``($%``!<!`````````````!G````
MI@,``````````````````-,$``#?`P``E@0```````!&!```,@```/X$``";
M`0``:08`````````````E`,``-8%``#M`````````#`!```*````<`0``/8"
M``!E!```+`,``"(````"`0``&0$```````!J!```DP0``.H!``!+`@``N@``
M``4!``"[!0``;`4```````#%`@``H@(``,@#``#-`P``8@0``&@#``"]`@``
M`````/<$``"@````!P```!4#``#9`0``\P$```````#&````O@4````````1
M!0``@@8``%`!````````D`4``%P%``"``P``B0(``!,"``!X`@```````-0!
M``#\````\P4``%L!``#\`@``[@,``$(%``#]`````````(<$````````Z`0`
M```````````````````````K!```3P8`````````````BP(````````O!@``
M@@```%T"``"T`@``J0$``(4&``#=````BP```&H#```$`0```````$L%``!K
M`@``4`````````"U`@```````$$&```U`0```````.X!``!M`@``"P0``!\%
M```D!0``S0(``````````````````%P````[!```R@```*P#``"S`P``SP$`
M````````````ZP$``$`#``#P`@```````+````!3`@```````#,&``#8`0``
M"`,``.4"``#*`0``=P```*@#``#2`@``:0$`````````````10```%H&``#>
M!```N0(``(,$``!J!0``MP`````````\`0````````````"A`P``Z@(`````
M``"*`@``H`,`````````````T0,``(D#```O`@``^04``(,````J````````
M`*L"````````F0,``(T"``!;!```*00``(`"``"R````````````````````
MOP0``"P$```R!@``L00```````"7````Z`,``'4%````````"0````````#0
M`@``?`0``,X%````````"`0``#@%````````\04``-4````\!@``"0$```(&
M``"O`0````````````!T!0``MP$````````)!0````````````!I````V@``
M`)0"``"2`@``)`8``'T`````````C@,``+T```"2`P```````,D#``#3!0``
M80,``.,%````````%`$```````#"`@``+`4`````````````"`(`````````
M````'04``$P#``!W`0``NP,```````"V`0``,04``$@`````````,00``.4!
M````````+P4``$P&``"^````G@```!,```"L!0```P0``%<!``"T`0``]0,`
M`#T$``"&!0```````,,"```1!```Z`$``&@`````````308```````!>`0``
M7P0``'H"``!"`P``8P,```L%````````P`,``/8```!#`@``"`4```0```!9
M`@````````0%```Z`P``E`4````````;`P``'@8``)D%```D!```E04``%$$
M``"Y!0``?P,``.<%````````EP8``&<%``!]!```^P0``'$%```J!@``M`,`
M``````!5!```CP(``$$$````````>0,``%8```!V!```*@4``#,#```'!@``
MQP0``!L!```,!```HP,```````#<!```T`0``(("``#*!```)@$``(L!````
M````:`8``+$!```G````"P````````#$!```S04```H#`````````````/H%
M```W`P``AP```#H&``!J`@```````.P!``#U!0``6P,``%$&```P````````
M`*,```"3!0``,P$````````^`@``004````````Q`0```````)`&``"&`@``
M`````((!````````:P```*D#``#V!0``#@```.\```!Q`P``*`(``(L#``!V
M!0``-P4``'H`````````\`$```````!M!0```````/8!````````GP$``,H"
M```]!@```````,8$````````$0$``%8%``````````````````"!`@``30,`
M`'`&``!*`@``B@$```$$```H!````````%<$``#!!```+@(``-L!```G!0``
M"P(````````3`0``-P$``%P&`````````````/H$``"H`@``-`8````````-
M!0``=@```$0%``!:!````````'T"``!N`0``[@4``%H%``!5`P```````#P#
M`````````````",#```````````````````6!```!@0```````#A`P``*P,`
M`&D%``!$!```\@````````!D`P``'P8``,H#```6`P``<0(``)$%``#@!```
M``````````#/!0``RP,``(8&``!M`````````!<```#4````0@```!4&```4
M`@``_P,``-`!``!K!```300``.T%``!?````\@(``$T"````````L0(`````
M``!Y!@```````/0#```9`P``-@8```````#%!```T00``(P```"+!```````
M`!H#````````,@,``(`&```Y````%P0``"P"```<`P````````````"+!@``
M&P4``.0!```X`0``!0(``$X!````````````````````````H@0``%D%````
M````NP(``+L!``!=!0``T`4``&(#```%!@``?@$``*<!````````/`4``-X"
M``!W!0```````+\"``"X`@``!04```````#I`````````&4"``".!```?P8`
M`"(&```I`@``'P``````````````$P,``*4%``"O!0``-0,```D#``!J!@``
M<0````4$``!Q!```E0```+$%```=!```^P4```````"L`0``$`$``,`"``"M
M`P``O`$``!X%```'!0``Y@(``(H$````````/@8``-$%````````8P$``*8$
M```!`P```````)P#````````J@4``.H%```[`````````%8$``!H!```:0,`
M```````;!`````````````"'!0```````-T!````````D00````````?`0``
MS00````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D
M87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``E
M9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I
M;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!
M9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES
M(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O
M9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T
M97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@)7,@)7,`+"!V
M87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O
M<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%)A:6X`04T@4VAO=V5R<P!!
M32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI
M<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S
M:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O
M:P!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!
M;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI
M<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M
M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`
M06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E
M<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`
M07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@
M=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I
M;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C
M:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD
M`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!
M<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(
M($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B
M97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S
M`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B
M861O<P!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E
M<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I
M;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`
M0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S
M<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A
M;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"
M=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE
M;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@
M3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/
M9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A
M<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@
M2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP
M=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O
M;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@
M1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N
M`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN=64`0V]O
M:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I
M8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO
M="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@
M4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O
M=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT960@=&5X=`!#;W5N
M=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#
M<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@5&EM90!#
M=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I
M;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL
M;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC
M+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$
M871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C
M=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB
M97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F
M875L="!)9&5N=&ET>0!$969I;FET:6]N<P!$96QE=&4`1&5L971E($=R;W5P
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C
M=7)R96YT(')O=P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES
M<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F
M;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C
M=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S
M:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`
M161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U
M8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`
M16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA
M:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N
M`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N
M;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U871O<FEA;"!'=6EN96$`
M17)I=')E80!%<G)O<@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10
M('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@
M(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B
M+@!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA
M;F1S`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L
M<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M
M871R:7@`1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`
M1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E
M<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO
M`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&
M<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`
M1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB
M<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A
M>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R
M96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`
M1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'
M=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@
M:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE
M87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX
M.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R
M`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO
M;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U
M;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@
M8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE
M8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4
M:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!0
M2%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE
M=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L
M90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@
M9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A
M<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL
M8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R
M96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A
M=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@
M8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F
M;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET
M:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)
M9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L
M;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V
M:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`
M26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R
M="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R
M<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@
M57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YS97)T($-?;VQU
M;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B
M($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R
M90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN
M<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P
M87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B
M969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I
M9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R
M`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M<V=?='EP92X`26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@
M<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E
M(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-
M86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A
M;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*
M4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E
M;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`
M2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V
M97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME
M>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP
M90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E
M;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@
M*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S
M="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W
M`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F
M=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB
M>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ
M;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T
M90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,
M:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN
M:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE
M`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E
M<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@
M=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U
M=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I
M;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T
M97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,
M=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL
M($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S
M`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L
M9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H
M`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G
M92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E
M<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!7
M96%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-
M:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S
M.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@
M2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E
M('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A
M<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO
M`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%52
M3`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI
M80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S
M97,`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@
M4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``
M36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@
M4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@
M06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE
M=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E
M($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T
M<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R
M`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N
M:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS`$YI8V%R86=U
M80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@
M8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@
M;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE
M('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E
M(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG
M;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L
M=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD
M(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U
M.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T
M:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F
M;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`
M3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A
M8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB
M97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C
M:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/
M8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I
M;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN
M9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R
M("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@
M56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E
M`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M
M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3
M:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%0M4W1O<FUS`%!?
M2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!4
M97)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A
M<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R
M96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S
M=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M
M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E
M;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M
M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!0
M97)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I
M>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A
M<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T
M=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0
M<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T
M92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R
M;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA
M=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N
M9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO
M;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!2
M96UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN
M`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO
M=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M
M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75I<F5D($9I96QD
M`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S
M=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R="!#;VYF:6=U
M<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT
M`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN
M`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2
M:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N
M($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L
M;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN
M="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!3
M86UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A
M;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3
M879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V-I
M96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C
M="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O
M=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L
M96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T
M(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@
M:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@
M=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O
M<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S
M8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T
M:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE
M(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@
M;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3
M:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E
M`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V
M92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`
M4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O
M<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI
M80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W
M(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@
M`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3
M;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U
M<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M
M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3
M<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A
M<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A
M='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U
M9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`
M4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E
M<W,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3
M=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3
M=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R
M<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@
M2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN=&%X
M(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4
M+5-T;W)M`%0M4W1O<FUS`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I
M97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA
M<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@
M061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT
M=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@
M=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@
M:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I
M9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A
M<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4
M:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I
M>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H
M87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N
M`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O
M;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V
M:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL
M("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T
M<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I
M;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A
M>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O
M;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A
M9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`
M5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@
M:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`
M56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B
M)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E
M;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E
M;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI
M;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N
M:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN
M9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI
M;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@
M=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5
M<&1A=&4@)7,`57!D871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`
M57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N
M(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE
M('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X
M:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@
M`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!6
M86QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E
M;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L
M`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E
M<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)
M<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI
M='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`
M5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A
M;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!7
M96%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3
M:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E
M<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7
M:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2
M968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!9
M60!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R
M964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@
M:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M
M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD
M<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY
M('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D
M:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U
M<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T
M(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P
M9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M
M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.
M86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P
M<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO
M=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S
M<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`
M6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O
M8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D
M(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A
M=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP
M`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF
M>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN
M+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S
M(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&9A;&QI;F<`9FEL90!F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z`&EM;65D:6%T90!I;FQI;F4`
M;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO
M=&5P860`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`
M<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E
M<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C`*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`T+3`W+3(R(#$Q.C0Y+3`W
M,#`*3&%S="U4<F%N<VQA=&]R.B!-:6QO<R!7:6UM97(@/'=I;6UE<D!Z8W4N
M8WH^"DQA;F=U86=E+51E86TZ($-Z96-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4E33RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3,[('!L=7)A;#TH;B4Q
M,#T],2`F)B!N)3$P,"$],3$@/R`P(#H@;B4Q,#X],B`F)B!N)3$P/#TT("8F
M("AN)3$P,#PQ,"!\?"!N)3$P,#X],C`I(#\@,2`Z(#(I.PH`("AP^&5D("5S
M(&1N>2D`("A0^.US='5P;W;](&ML[>@@)7,I`"`H=B`E<R!D;F5C:"D`("AD
M;F5S*0`@*'KM=')A*0`@*';H97)A*0`@<GEC:&QO<W0@`"5D("5S(&$@)7,`
M)60M9&5N;NT@</AE9'!O=NSO`"5S("T@;WINX6UE;NT`)7,@;W1I<VL`)7,@
M2T(`)7,@;W!E<F%C92#Z9'*^8GD@+2!P;W1V<GIE;NT`)7,@;F%S=&%V96[M
M`"5S(')E9VES=')A8V4`)7,@<&]D;>UN:WD@<&]UONUVX6[M`"5S(&IIOB!E
M>&ES='5J92X`)7,@;F$@)7,@)7,`)7,@:F4@<&^^861O=N%N;P`E<R!M:6YU
M=``E<R!N96)Y;&\@;F%L97IE;F\N`"5S(&&^("5S('H@)7,`)7,@861R97/A
M^``E<R!K86QE;F3A^``E<R!ZX7!I<V[M:P`E<R!S97IN86T@^FMO;/D`)7,Z
M("5S`"P@;N%R87IO=OT@)7,@)7,`+"!P<F]M[&YNX2!O9"`E<R!D;R`E<P`M
M+2!V_6+L<B`M+0`Q,B!H;V1I;F]V_2!F;W)MX70`,C0@:&]D:6YO=OT@9F]R
M;>%T`#(T(&AO9&EN`%!R;R!T96YT;R!B;&]K(&IE('9YOF%D;W;A;B!D871A
M8N%Z;W;]('ID<F]J+@!6>7-K>71L82!S92!ZX79AOF[A(&-H>6)A`%!R;R!Z
M8;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0
M(&ML[>@N`%!R;R!V97)I9FEK86-I('!O9&5P<V%NZ2!Z<'+A=GD@:F4@;G5T
M;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@N`%!R;R!D9;EI9G)O=N%N[2!Z
M<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A
M=&[M(%!'4"!K;.WH(&$@:&5S;&\N`%!R;R!P;V1E<'/A;NT@>G!RX79Y(&IE
M(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+"!P<FEVX71N[2!01U`@
M:VSMZ"!A(&AE<VQO+@!0<F\@9&6Y:69R;W;A;NT@>G!RX79Y(&IE(&YU=&YO
M('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N[2!3+TU)344@
M:VSMZ"!A(&AE<VQO+@!0<F\@<&]D97!SX6[M('IP<N%V>2!J92!N=71N;R!P
M;W6^[70@=F7X96IN_2!3+TU)344@:VSMZ"P@<')I=N%T;NT@4R]-24U%(&ML
M[>@@82!H97-L;RX`4')O('IAN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P
M;W6^[70@=F7X96IN_2!3+TU)344@:VSMZ"X`4F%N;NT@9.FYNP!286YN[2!P
M^&5HX?)K>0!286YN[2!S;NQH;W;I('#X96CA\FMY`$%-+U!-`$%022!)1`!)
M;F9O<FUA8V4@;R!T;VUT;R!E9&ET;W)U`$EN9F]R;6%C92XN+@!497AT(&1O
M;/D@9&\@;V)RX7IK=0!497AT(&1O<')O<W3X960@;V)RX7IK=0!6>71V;_AE
M;NT@5D93(&%D<F%SX?AE(&YE8GEL;R!P;W9O;&5N;RX`5GET=F_X96[M(%9&
M4R!S;W5B;W)U(&YE8GEL;R!P;W9O;&5N;RX`5;YI=F%T96QS:^D@:&5S;&\`
M5;YI=F%T96QK_2#ZZ&5T(&)Y;"!Z86)L;VMO=N%N+@!5OFEV871E;&OI(/KH
M='D`5FQOO@!0^&ED870@<&]D<VMU<&EN=0!0^&ED870@<&]D+7!RX79A`%#X
M:61A=#H`4/AI9&%T(&YO=F]U('-K=7!I;G4`4/AI9&%T(&YO=N$@<'+A=F$`
M4/AI9&%T(&YO=NEH;R!UOFEV871E;&4Z`%#X:61A="!S;&]U<&5C`%#X:61A
M="!N;W;I(.AL96YY`%#X:61A="!PX7(`4/AI9&%T("5S(&UE;G4@:F%K;R!B
M;^AN[2!S;&]U<&5C($UO>FEL;'D`4/AI9&%T(&1O(&%D<F5SX?AE.@!0^&ED
M870@9&\@;>EH;R!A9')E<^'X90!0^&ED870@=;YI=F%T96QE`%#X:63A=N%N
M[2!UOFEV871E;/D@:F4@>F%B;&]K;W;A;F\N`$%D<F5S80!!9')E<^'X`%9Y
M:V]NX79A="!A9&UI;FES=')A8VD@+2!N87-T879E;NT@</CM<W1U<&]V_6-H
M('!RX78@<')O(&]S=&%T;NT@=;YI=F%T96QE`$%D;6EN:7-T<F%C90!);GIE
M<N%T>0!!9F=HX6YI<W3A;@!!;&+A;FEE`$%LONUR<VMO`%#X97ID[79K82]!
M;&EA<P!:87)O=FYA=`!:87)O=F[A;NTZ`%:Y90!6N6EC:&YI(&]V[/AE;NT@
M=;YI=F%T96SI`%:Y96-H;GD@<VMU<&EN>0!6N65C:&YA('6^:79A=&5L<VOA
M('!RX79A`%:Y96-H;GD@Z'1Y^&D@<W1R86YY`%!O=F]L:70@=NUC92!A9')E
M<P!0;W9O;&ET(&YA<W1A=F5N[2!T>7!U('-E=/CM9.QN_2!S97IN86T_`$II
MOB!E>&ES='5J90!!;'1E<FYA=&EV;NT@24U34"!P^&EH;.&Y96[M(&1O('-Y
M<W3I;74`06QT97)N871I=F[M($E-4U`@:&5S;&\`06QT97)N871I=F[M($E-
M4U`@=;YI=F%T96QS:^D@:FWI;F\`06QT97)N871I=F[M(&4M;6%I;&]VX2!A
M9')E<V$`06QT97)N871I=F[M('9Z;W)Y`$%L=&5R;F%T:79N[2!T97AT.@!!
M;65R:6-KX2!386UO80!">6QA('IA9.%N82!N97!O=F]L96[A(&AO9&YO=&$N
M`$%N9&]R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;NT@<')O>'D`3V1P;W;L
M[P!!;G1A<FMT:6MA`$%N=&EG=6$@82!"87)B=61A`$%P;&EK86-E`%-E>FYA
M;2!A<&QI:V%C[0!!<&QI:V%C92!J92!P^&EP<F%V96YA`%!O=;[M="!P<F\@
M9.QD:>ANZ2!S9.UL96[M`%-C:';A;&ET`%#X:6)L:;YNX2!V96QI:V]S=`!$
M=6)E;@!!<F%B<VMY("A7:6YD;W=S+3$R-38I`%9E;&EK;W-T(&%R8VAI=F]V
M86[I:&\@<V]U8F]R=0!*;>EN;R!A<F-H:79U`%5RZ&ET["!C:&-E=&4@=GEM
M87IA=""^X61O<W0@;R!P^&EH;.&Y96[M(&1O("5S/P!!<F=E;G1I;F$`07)M
MZ6YI90!!<FWI;G-K_2`H05)-4T-)22TX*0!5;>QN[0!!<G5B80!!<V-E;G-I
M;VX@27-L86YD`$%S8VEI('5M[&[M`$%S:64O<F5G:6]N(%1I8VCI:&\@;V-E
MX6YU`%!OON%D870@;R!P;W1V<GIE;NT@</AE9"!P<F]V961E;NUM(&]P97)A
M8^T@^F1ROF)Y/P!3;&]U<&-E(',@^FMO;'D`4&]K=7,@;R!V>6UA>N%N[2!N
M965X:7-T=6KM8^T@<VMU<&EN>2X`4&]K=7,@;R!V>6UA>N%N[2!N965X:7-T
M=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N`%!O:W5S(&\@^G!R879U(&YE
M97AI<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@<'+A=BX`4&]K=7,@;R#Z<')A
M=G4@;F5E>&ES='5J[6/M:&\@<V3M;&5NZ6AO(&]B:F5K='4N`$%T<FEB=71Y
M`%-R<&5N`$%U<W1RX6QI90!286MO=7-K;P!!=71H7V-Y<G-Q;#H@3F5B>6QA
M(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:6UA<"X`075T:%]C
M>7)U<SH@6F1R;VH@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN`$%U=&A?
M8WER=7,Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O
M(&EM87`N`$%U=&A?9G1P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P
M^.UP;VYA('!R;R!F='`N($MO;7!I;'5J=&4@4$A0(',@+2UE;F%B;&4M9G1P
M`$%U=&A?:6UA<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N
M82!P<F\@24U!4"X`075T:%]K<F(U.B!.96)Y;&$@;F%L97IE;F$@<&^^861O
M=F%NX2!P^.UP;VYA('!R;R!K<F(U+@!!=71H7VQD87`Z($YE8GEL82!N86QE
M>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O($Q$05``075T:%]L9&%P.B!.
M96QZ92!P^&ED870@=;YI=F%T96QE("5S+B!(;.&Y96[M('-E<G9E<G4Z(`!!
M=71H7VQD87`Z($YE;'IE('9Y;6%Z870@=;YI=F%T96QE("5S`$%U=&A?;&1A
M<#H@3F5L>F4@86MT=6%L:7IO=F%T('6^:79A=&5L92`E<P!!=71H7VUC86PZ
M($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O($U#04PN
M`$%U=&A?<VUB875T:#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM
M<&]N82!P<F\@<VUB875T:"X`3W;L^&5N[2!S96QH86QO`$]V[/AE;NT@<V5L
M:&%L;RX@)7,`3W;L^&5N[2!B>6QO('IA;>UT;G5T;R!2041)55,@<V5R=F5R
M96TN`%-E;&AA;&\@;W;L^&5N[2!&5%`@<V5V97)E;2X`1&]S='5P;N$@<&]L
M93H`07IE<F)A:F2^X6X`0D]&2"!V_6UL=79Y`%!O>F%D[0!"87)V82!P;WIA
M9.T`J7!A=&[I(&AE<VQO('!R;R!K97)B97)O<RX`J7!A=&[I('6^:79A=&5L
M<VOI(&IMZ6YO('!R;R!K97)B97)O<RX`0F%H86UY`$)A:')A:6X`0F%L=&EC
M:^D@*$E33RTX.#4Y+3$S*0!"86YG;&%DZ;D`0F%R8F%D;W,`6N%K;&%D`$+L
M;&]R=7-K;P!"96QG:64`0F5L:7H`0F5N:6X`0F5R;75D>0!":/ITX6X`3F%R
M;WIE;FEN>0!.96QZ92!N86SI>G0@Z.%S="`B)7,B(&%P;&EK86-E("(E<R(N
M`$YA<W1A=F5N[2!B;&]K=0!4>7`@8FQO:W4`5'7H;NP`0F]L[79I90!:X6QO
MOFMY`$]K<F%J`*GM^&MA(&]K<F%J93H`3VMR86IE`$)O<VYA(&$@2&5R8V5G
M;W9I;F$`3V)A`$)O='-W86YA`$1O;&[M(.CA<W0`0F]U=F5T($ES;&%N9`!"
M<F%Z[6QI90!"<FET<VOA('1E<FET;W)I82!V($EN9&EC:^EM(&]C9>%N[`!"
M<G5N96D@1&%R=7-S86QA;0!"=6QH87)S:V\`4V5Z;F%M(',@;V1RX;YK86UI
M`$)U<FMI;F$@1F%S;P!"=7)U;F1A`$--4P!#4D,`0U),(&1I<W1R:6)UZ&[M
M(&)O9'D`5FQA<W1N;W-T:2!B7W7R:WDN+BX`2V%L96YDX?@`0F5Z=NQT^.T`
M2V%M8F]DOF$`2V%M97)U;@!(97-L;R!N96QZ92!N87-T879I="!A=71O;6%T
M:6-K>2P@<')O<^UM(&MO;G1A:W1U:G1E(%9AN65H;R!S>7-TZ6UO=NEH;R!A
M9&UI;FES='+A=&]R82X`3F5L>F4@<V4@</AI<&]J:70@:R!)34%0('-E<G9E
M<G4Z("5S`$MA;F%D80!3=&]R;F\`4W1O<FYO(&ALX;EE;NT@<')O8FSI;74`
M3F5L>F4@=GEM87IA="!S;W5B;W(@(B5S(BX`3F5L>F4@;F%J[70@9&_H87-N
M_2!A9')E<^'X+@!.96QZ92!P;VMR8>AO=F%T(&)E>B!P87)A;65T<G4@)W1A
M<F=E=$9I;&4G+@!.96QZ92!V>6UA>F%T(&%D<F5SX?@@(B5S(BX`3F5L>F4@
M=GEM87IA="P@<')O=&^^92!E>&ES='5J[2!P;V1S:W5P:6YY("5D+@!.96QZ
M92!P<F]VZ7-T('IM[&YU('5S<&_XX63A;NTL('!OZ&5T('!O<VMY=&YU=/UC
M:"!P;VQOOF5K('!R;R!N;W;I('5S<&_XX63A;NT@;F5O9'!O=NUDX2!P;^AT
M=2!U;&^^96[]8V@@<&]L;[YE:RX`3F5L>F4@>F%S;&%T('IP<N%V=2!N82!Z
M861A;ND@Z.US;&\N(`!#87!E(%9E<F1E`%1I='5L:WD`2V%T96=O<FEE(&$@
M>FYAZ&MY`$MA:FUA;G-KZ2!O<W1R;W9Y`$UO8FEL;NT@=&5L969O;@!-;[YN
M;W-T:2!B=?)K>0!/9'-T=7`@;65Z:2!B=?)K86UI.@!6;&%S=&YO<W1I(&)U
M\FMY`$UE>F5R>2!M97II(&)U\FMA;6DZ`$UO8FEL;NT@=&5L969O;@!+96QT
M<VO]("A)4T\M.#@U.2TQ-"D`4W3X960`4W3X961O869R:6-KX2!R97!U8FQI
M:V$`4W3X961O979R;W!S:_T@*$E33RTX.#4Y+3(I`%!O9')O8FYO<W1I(&-E
M<G1I9FEKX71U`%!O9&WM;FMY(&-E<G1I9FEKX71U`,AA9`!:;>QN:70`3F%S
M=&%V96[M(&IMZ6YA(&$@96UA:6QO=ND@861R97-Y+B!4>71O('!O;&^^:WD@
M;&EDZ2!U=FED[2P@:V1YOB!S:2#H=&]U(&YE8F\@;V1P;W;M9&%J[2!N82!6
M8;EE('IP<N%V>2X`6FYA:P!::V]N=%]R;VQO=F%T(&]D:V%Z+BXN`$-H:6QE
M`,CM;F$`R.UNN71I;F$@>FIE9&YO9'6Y96[A("A'0C(S,3(I`%1R861IZ&[M
M(.CM;KET:6YA("A":6<U*0!:=F]L=&4@:&5S;&\`6G9O;'1E('6^:79A=&5L
M<VOI(&IMZ6YO`%9Y8G)A="!Z;V)R87IE;NT@9&%T=6UU.@!6>6)R870@='EP
M('-T>6QU('-E>FYA;74@*'!R;R#X87IE;ND@<V5Z;F%M>2D`5N%N;^AN[2!O
M<W1R;W8`3F5B>6QA(&YA;&5Z96YA(&1E9FEN:6-E('3X[61Y("5S+@!6>>AI
M<W1I=`!6>>AI<W1I="!Z;F'H:WD@>B!-4T]F9FEC90!/9'-T<F%N[&[M('6^
M:79A=&5L93H@)7,`3V1S=')A;FET('6^:79A=&5L90!/9'-T<F%N[&[M(/ID
M86KY(&\@=;YI=F%T96QI`$ML:6MN['1E('!R;R!P;VMR8>AO=N%N[0!#;&EC
M:V%T96QL('#X97,@2%144`!:87;X[70@;VMN;P!:871AOF5N;P!/8FQAZ&YO
M`$MO:V]S;W;I(&]S=')O=GD`4VML87!N;W5T(&)OZ&[M(&QIN71U`%-K;&%P
M;F]U="!O:W)A:F4`2V]L=6UB:64`0F%R=F$`5OUB['(@8F%R978`4&%L971A
M(&)A<F5V`%-L;W5P8V4Z`$[A>G9Y('-L;W5P8V4`2V]M:6MS>0!0^.UK87H`
M4/CM:V%Z;W;A(&MO;GIO;&$`4&]Z;N%M:V$`3V)E8V[I(&IMZ6YO`$MO;6]R
M;W,`1FER;6$`4&_H[71AZ&4`4&]D;>UN:WD`4F]Z9.UL>2!V(&YA<W1A=F5N
M[0!.87-T879I="`E<P!0;W1V<F1I="!H97-L;P!+;VYG;P!+;VYG;RP@1&5M
M;VMR871I8VOA(')E<'5B;&EK80!3<&]J96[M('-E;&AA;&\N`%-P;VIE;NT@
M<V5L:&%L;SH@`$)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[];2!K
M;.WH;W;];2!S97)V97)E;2X`0GEL;R!Z86WM=&YU=&\@<W!O:F5N[2!S('9E
M^&5J;OUM(&ML[>AO=OUM('-E<G9E<F5M+B!$^79O9"`Z("5S("@E<RD`4V5L
M:&%L;R!S<&]J96[M(',@1E10('-E<G9E<F5M+@!+;VYT86MT>2!B>6QY(/IS
M<.RY;NP@</AI9.%N>2!D;R!68;EE:&\@861R97/A^&4N`%!O:W)AZ&]V870`
M0V]O:V]V>2!O<W1R;W9Y`$MO;.'H96L`2V]P[7)O=F%T`$MO<.UR;W9A="!V
M_6+L<@!+;W-T87)I:V$`4&]B^&6^[2!S;&]N;W9I;GD`6G!RX79U(&YE;'IE
M(+EI9G)O=F%T('!O;6]C[2!01U`N`%IP<N%V=2!N96QZ92!P;V1E<'-A="!P
M;VUO8^T@4$=0+@!:<'+A=G4@;F5L>F4@N6EF<F]V870@<&]M;V/M(%,O34E-
M12X`6G!RX79U(&YE;'IE('!O9&5P<V%T('!O;6]C[2!3+TU)344N`$YE;'IE
M('#X:61A="!K;VYT86MT+B`E<P!.96QZ92!S92!P^&EP;VII="!K($Q$05`@
M<V5R=F5R=2X`3F5L>F4@>FMO;G1R;VQO=F%T(/KH970N("5S`$YE;'IE('9Y
M='9O^&ET(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,`3F5L>F4@9&6Y:69R;W9A
M="!01U`@9&%T82X`3F5L>F4@9&6Y:69R;W9A="!3+TU)344@9&%T82X`3F5L
M>F4@<VUA>F%T(&MO;G1A:W0N("5S`$YE;'IE('-M87IA="!D:7-T<FEB=>AN
M[2!S97IN86TN("5S`$YE;'IE('IJ:7-T:70@92UM86EL;W9O=2!A9')E<W4@
M</CM:F5M8V4N`$YE;'IE('KM<VMA="#Z<&QN_2!A9')E<^'X+@!.96QZ92!Z
M[7-K870@^G!L;OT@9&ES=')I8G7H;NT@<V5Z;F%M+@!.96QZ92!Z[7-K870@
M^G!L;OT@<V5Z;F%M(&1I<W1R:6)UZ&[M8V@@<V5Z;F%M^2X`3F5L>F4@>NUS
M:V%T('9E^&5J;OT@:VSMZ"!Z(&ML[>AO=NEH;R!S97)V97)U+@!.96QZ92!O
M=&5V^.UT("5S+@!.96QZ92!P<F]VZ7-T(&]P97)A8V4@^F1ROF)Y('!R;R!M
M;V1U;"`E<P!.96QZ92#H[7-T("5S+@!.96QZ92!R97-E=&]V870@:&5S;&\@
M<')O(&1A;NEH;R!UOFEV871E;&4N(%:Y96-H;GD@;F5B;R!N[&MT97+I('H@
M<&]D<F]B;F]S=.T@;F5B>6QY('-P<N%V;NP@>F%DX6YY+B!::W5S=&4@=&\@
M>FYO=G4@;F5B;R!P;VMU9"!P;W3X96)U:F5T92!P;VUO8RP@:V]N=&%K='5J
M=&4@<W!RX79C92!S>7-TZ6UU+@!.96QZ92!Z[7-K870@04-,`$YE;'IE('KM
M<VMA="!A9')E<^'X+B`E<P!.96QZ92!Z[7-K870@9&ES=')I8G7H;NT@<V5Z
M;F%M+B`E<P!.96QZ92!Z[7-K870@9&ES=')I8G7H;NT@<V5Z;F%M>2X@)7,`
M3F5L>F4@>NUS:V%T('-C:&]P;F]S=&D@<V5R=F5R=0!.96QZ92!P^&5P;F]U
M="!K;VYF:6=U<F%C:2X`3F5L>F4@=6QOOFET(&MO;F9I9W5R86-I('!R;R`E
M<RX`3F5L>F4@=6QOOFET('KA;&^^;NT@:V]N9FEG=7)A8VDN`$YE;'IE('5L
M;[YI="!ZX6QO:'4@:V]N9FEG=7)AZ&[M:&\@<V]U8F]R=2`E<RX`3F5L>F4@
M:&QE9&%T('8@3$1!4"!S97)V97)U+@!.96QZ92!A:W1U86QI>F]V870@:V]N
M=&%K="X@)7,`3F5L>F4@86MT=6%L:7IO=F%T(&1I<W1R:6)UZ&[M('-E>FYA
M;2X@)7,`3F5L>F4@;F%LZ7IT(&)OZ&[M(&QIN71U('!R;R!-;WII;&QU+B!0
M<F]S[6T@</AE<W;L9.AT92!S92P@OF4@:F4@;W1E=OAE;N$N`$]D<&_H[71A
M;OT@=&5X=`!:96WL`%9Y=>AO=F%C[2!P^&5D;>QT>0!6>71V;_AI=`!6>71V
M;_AI="!O9&MA>@!6>71V;_AI="!N;W9O=0!6>71V;_AI="!P;V1S;&^^:WD`
M5';Y<F-E('!RX78`R.US;&\@:W)E9&ET;NT@:V%R='D`0VAO<G9A='-K;P!+
M=6)A`$%K='7A;&[M(.AA<P!!:W1UX6QN[2!54DP@:F4`06MT=>%L;NT@<&_H
M87/M`$%K='7A;&[M('!O9&WM;FMY.B``3GEN[&JY[2!S='EL`$YA<W1A=F5N
M[2#Z:V]L^2!P<F]VX63L;OUC:"!P^&D@</AI:&SAN65N[2!D;R`E<RX`5GES
M=/AI:&YO=70`5GES=/AI:&YO=70@=OUB['(`2WEP<@!!>F)U:V$@*$M/23@M
M4BD`07IB=6MA("A7:6YD;W=S+3$R-3$I`$%Z8G5K82]5:W)A:FEN82`H2T])
M."U5*0#(97-KX2!R97!U8FQI:V$`1$0`1&5N;NP`1&%T851R964@<')O:&SM
MOF7H`$1A='5M`%#X:6IA=&\@9&YE`%;]8NQR(&1A='5M=0!$96X`4VUA7WIA
M="!S;&]U<&5C`%!R;W-I;F5C`,CM<VQA(&1E<^UT:V]VZ2!S;W5S=&%V>0!:
M;65NN6ET(&]D<V%Z96[M`$EM<&QI8VET;NT`26UP;&EC:71N[2!B87)V80!)
M;7!L:6-I=&[M(&ED96YT:71A`$1E9FEN:6-E`%-M87IA=`!3;6%Z870@<VMU
M<&EN=0!3;6%Z870@<'+A=F$`4VUA>F%T(&$@=GGH:7-T:70@>G!RX79Y`%-M
M87IA="!B=?)K=0!3;6%Z870@<VQO=7!E8P!3;6%Z870@97AI<W1U:NUC[2!A
M;'1E<FYA=&EV;NT@=GIO<@!3;6%Z870@^.%D96L`4VUA>F%T('9Y8G)A;F]U
M*.DI(&ED96YT:71U*'DI`%-M87IA="!S;W7H87-N_2!S;&]U<&5C`%-M87IA
M="!S;W7H87-N_2#XX61E:P#(87,@9&]R=>AE;NT`1.%N<VMO`%!O<'-A="!P
M<F]B;.EM`%!O<&ES`%!O9')O8FYO<W1I("AT86OI('8@;&]G('-O=6)O<G4@
M2&]R9&4I.@!0;V1R;V)N;W-T:2!B>6QY('IA>FYA;65NX6YY(&1O(&QO9R!S
M;W5B;W)U('!R;R!A9&UI;FES='+A=&]R82X`5OUV;VH`4F]S;OT@8F]D`%)O
M<V[](&)O9"!Z82!P;W-L961N[2!H;V1I;G4Z(`!2;W-N_2!B;V0Z(`!3;>QR
M('H@;&5V82!D;W!R879A`%-M['(@>B!P<F%V82!D;VQE=F$`061R97/A^`!:
M;V)R87II="`R-"UH;V1I;F]V_2#H87,_`$UOOFYO<W1I('IO8G)A>F5N[0!:
M;V)R87II="!P^&5D<&]V[.\@*%1!1BD`1F]R;>%T('IO8G)A>F5N[0!$:7-P
M;WIIZ&[M('5P;WIO<F[L;NT`1&II8F]U=&D`3F5S;6%Z870`3F5P^&ES='5P
M;W9A="!P^.UM;R!D;R!M86EN=&5N86YC92YP:'``3V)S86AU:F4@<')V;NT@
M^.%D96L@;N%Z978@<VQO=7!C^3\@4&]K=60@86YO+"!Z8;EK<G1N['1E('1E
M;G1O('+A;67H96LZ`$1O;6EN:6MA`$1O;6EN:6OA;G-KX2!R97!U8FQI:V$`
M4W1AOF5N[0!3=&&^96[M("5S`%-T86AN;W5T(&=E;F5R;W9A;F]U(&MO;F9I
M9W5R86-I(&IA:V\@4$A0('-K<FEP="X`4F]L971O=OT@<V5Z;F%M`$1R;V=Y
M`$4M;6%I;`!%4E(`16MVX61O<@!5<')A=FET`%5P<F%V:70@8FQO:P!5<')A
M=FET('-K=7!I;G4`57!R879I="!P<N%V80!5<')A=FET('!RX79A`%5P<F%V
M:70@<'+A=F$@<')O("5S`%5P<F%V:70@;6^^;F]S=&D@<')O.@!5<')A=FET
M('!RX79A('!R;R`E<P!6_75K80!%9WEP=`!%;"!386QV861O<@!0<G9E:RXN
M+@!%;0!%;6%I;`!%;6%I;&]VX2!A9')E<V$`16UA:6QO=ND@861R97-Y('-E
M(&UU<^T@<VAO9&]V870N`$5M86EL(',@<&]T=G)Z96[M;0!):V]N:WD@<R!E
M;6]C96UI`%!RX7ID;N$@>G!RX79A+@!0<N%Z9&[](';]<VQE9&5K+@!0<N%Z
M9&[]('1E<FWM;B!P<F\@=GEH;&5DX7;A;NT`4&]V;VQI="!V:VSA9.%N[2!O
M8G)A>FOY('H@9F]T;R!G86QE<FGM(&1O('1E>'1U/P!!:W1I=F]V870@<')A
M=ND@:VQI:VYU=.T@<')O(&MO;G1E>'1O=ND@;65N=3\`2V]N96,@<F]K=0!:
M=NQTN6ET(&5D:71O<@!:861E:G1E(&)E>G!EZ&YO<W1N[2!O=.%Z:W4L(&YA
M(&MT97)O=2!B=61E=&4@;75S970@;V1P;W;L9.QT('!O:W5D('-I(&)U9&5T
M92!C:'3M="!R97-E=&]V870@<W;I(&AE<VQO+"!N87#X+B`G2F%KZ2!J92!J
M;>EN;R!68;EE:&\@<'-A/R<Z`%ID92!V;&^^:70@55),(&]B<N%Z:W4`4F]V
M;NUK;W;A($=U:6YE80!%<FET<F5A`$-H>6)A`$YA<W1A;&$@8VAY8F$@<R!P
M;[ET;W9N[2!Z<'+A=F]U+@!%<W1O;G-K;P!%=&EO<&EE`$5T;FEC:^D`179R
M;W!A`$MAOF3]8V@@,34@;6EN=70`2V&^9.D@,B!M:6YU='D`2V&^9/UC:"`S
M,"!S96MU;F0`2V&^9/UC:"`U(&UI;G5T`$MAOF3I('#X:6ALX;EE;NT@9&\@
M<WES=.EM=0!+8;YD;W4@</EL(&AO9&EN=0!+8;YD;W4@;6EN=71U`%9Z;W)O
M=OT@</CM:VQA9"!H;V1N;W0Z`%!R;W;I<W0`4F]Z=FEN;W5T`%)O>F)A;&ET
M(&)OZ&[M(&QIN71U`$_H96OA=N%N82`G*2<`3^AE:^%VX6YO('-A;6]S=&%T
M;ND@<VQO=F\@;F5B;R!H;&5D86[]('1E<FWM;B!V('5V;WIO=FOA8V@`1&%T
M=6T@<')O(&MO;F5C('!L871N;W-T:0!%>'!O;F5N=`!"87)V82!P;W#X963M
M`%#X96YO<R!K;VYF:6=U<F%C92!P;VUO8^T@1E10`%-E;&AA;&\@>NUS:^%N
M[2!M;[YN;W-T[2X`3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E<G9E<G4N
M`$YE;'IE('-E('#X:7!O:FET(&L@4TU"('-E<G9E<G4N`%-E;&AA;&\@:V]P
M[7)O=N%N[2!Z("(E<R(N`%-E;&AA;&\@:V]P[7)O=N%N[2!D;R`B)7,B+@!3
M96QH86QO('IA;&^^96[M(&YO=NEH;R!305-,('-P;VIE;NTN`%-E;&AA;&\@
M</AE<W5N=73M(&1O("(E<R(N`$1O8G+I`$9A;&ML86YD<VOI(&]S=')O=GD@
M*$UA;'9I;GDI`$9A<FEJ<VOI(&]S=')O=GD`6N%V8;YNX2!C:'EB83H`1F%X
M`-IN;W(`0^UT:70@<V4@:F%K;P!#[71I="!S92!J86MO.@!$<F]B;ND@</AE
M:.'R:WD`1')O8F[I('-N[&AO=ND@</AE:.'R:WD`36%T:6-E('!O;&4`1FEJ
M:0!0;^AE="!S;W5B;W+Y.B`E<R!S;W5B;W(`4&_H970@<V]U8F]R^3H@)7,@
M<V]U8F]R^0!3<'+A=F-E('-O=6)O<OD`3N%Z978@<V]U8F]R=0!6_6+L<B!S
M;W5B;W)U`%#X96[I<W0@<V]U8F]R`%#X96YO<R!S;W5B;W+Y(&YE;NT@<&]D
M<&]R;W;A;BX`1FEL=')Y`$9I;G-K;P!0<G9N[2!P;VQO=FEN80!0<G9N[2#H
M='9R=&EN80!0979NZ2!M[/CM=&MO`%#X96AO9&ET`%!L;W9O=6/M`$UL:&$`
M4VQOOFMA("5S(&YE97AI<W1U:F4`0F%R=F$@<.US;6$`2NUD;&\`4')O('!R
M;VAL[;YEZ&4@;F5P;V1P;W)U:NUC[2!O8G+A>FMY`%#X961P;W;L[R`H5$%&
M*0!0^&5D<&]V[.\@<&_H87/M('!R;R!D;GD@*'!O>F[A;6MA.B!P^&5D<&]V
M[.\@:F4@<')O(&1N>2!I(&YO8VD[('1O=&\@;?F^92!V>71V;_AI="!P;VWL
M<F[L(&]B<^%H;/T@<V5Z;F%M+@!:87!O;6[L;&D@:G-T92!68;EE(&AE<VQO
M/P!&;W)M=6SA^&4`J73L<W3M`%1Y<""Y=.QS=.T`J73L<W3M`*ET['-T[2`R
M`$;S<F$`4/AE<&]S;.%N[0!0X0!2X6UY`$9R86YC:64`1G)A;F-I92P@;65T
M<F]P;VQI=&[M`$9R86YC;W5S:^$@1W5A:>%N80!&<F%N8V]U<VOA(%!O;'EN
MZ7-I90!&<F%N8V]U<VOA(&IIOF[M('1E<FET;W)I80!/9`!/9`!0;V1R;V)N
M_2!P;W!I<P#:<&QN[&L`0V5LZ2!J;>EN;P!'86)O;@!'86QE<FEE('!R;R!V
M_6+L<B!O8G+A>FOY`$=A;&5R:64Z`$=A;6)I90!6>71V;_AI="`E<R!K;VYF
M:6=U<F%C:0!6>6=E;F5R;W9A;OT@:_-D`$=R=7KM;G-K;P!.[&UE8VMO`$=H
M86YA`$=I8G)A;'1A<@!+^&5S=&[M(&IMZ6YO`$ID:2!N80!';V5D96P`5GEH
M;&5DX7;A;NT@<&]M;V/M($=O;V=L=0!3='5P;NP@N65D:0#896-K;P#896-K
MZ2`H25-/+3@X-3DM-RD`1W+S;G-K;P!'<F5N861A`$%D;6EN:7-T<F%C92!P
M<F\@<VMU<&EN>0!-=7/M(&+]="!Z863A;F\@:FWI;F\@<VMU<&EN>0!3:W5P
M:6YY`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4'+A=F$@
M:&]S=/D`2VYI:&$@:&]S=/D`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA
M`$A434P`2%1-3$%R96$@>F)A8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M
M(&)U\FMU(&YA(/CA9&MU+@!(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S;6%Z
M870@<&]S;&5D;NT@8G7R:W4@=F4@<VQO=7!C:2!T86)U;&MY+@!(5$U,07)E
M82!Z8F%B[&QE(&]D;>UTX2!S;6%Z870@<&]S;&5D;NT@^.%D96L@=B!T86)U
M;&-E+@!/=NSX;W;A;NT@<&]M;V/M($A45%`@;F5B>6QO(&YA;&5Z96YO+@!(
M86ET:0!(87-H+6%L9V]R:71M=7,`36QH879O`$AL879IZ&MA`$AE87)D($ES
M;&%N9"!A($UC1&]N86QD($ES;&%N9',`2&5B<F5JN71I;F$@*$E33RTX.#4Y
M+3@M22D`5OVY:V$`3N%P;W;L9&$`3N%P;W;L9&$@<')O(&5D:71O<@!0;VUO
M8V[M:P!(96UI<V;I<F$`6F1E(&IE('IAZ.%T96L@<V]U8F]R=3H`5GES;VOA
M`%](;W)D90!3=F%TZ2!-['-T;R`H5F%T:6OA;BD`2&]R9&4`061R97-A(&1O
M;?D`5&5L969O;B!D;VWY`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@3F5P;&%T;ND@)7,@6$U,(&1A=&$@=F4@>G!RX7;L("5S`$AO
M<F1E+TMO;&%B.B"NX61NX2!Z<'+A=F$@<V4@;F5S:&]D=6IE(',@;V)J96MT
M96T@)7,`2&]R9&4O2V]L86(Z($YE8GEL(&YA;&5Z96X@ON%D;OT@;V)J96MT
M('1Y<'4@)7,@=F4@>G!RX7;L("5S`$AO<F1E+TMO;&%B.B#:<W#LN6[I(&]D
M<W1R86[L;NT@)7,@(B5S(@!(;W)D92]+;VQA8CH@26YT96=R8>AN[2!NX7-T
M<F]J('!O=/AE8G5J92!02%`@</CM<&]N=2`G9&]M>&UL)P!(;W)D92]+;VQA
M8CH@3F5L>F4@=GET=F_X:70@;F]V_2!S=')O;2!834P@<')O(&]B:F5K="`E
M<P!(;W)D92]+;VQA8CH@3F5L>F4@;V1S=')A;FET("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!.96QZ92!Z[7-K870@34E-12!)1"!P<F\@Z.%S="!T>7!U
M("5S`$AO<F1E+TMO;&%B.B!.96QZ92!S>6YC:')O;FEZ;W9A="`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@3F5L>F4@<WEN8VAR;VYI>F]V870@<V3M;&5N
MZ2!O8FIE:W1Y.B`E<P!(;W)D92]+;VQA8CH@3F5Z;N%M_2!S9.UL96[](&]B
M:F5K="`B)7,B`%9O9&]R;W9NZ2!P<F%V[71K;P!(;W)I>F]N=.%L;NT@;V1S
M='5P`$AO<FEZ;VYTX6QN[3H`2F%K(&IS=&4@<V4@<V5M(&1O<W1A;&D_("A:
M8;EL971E('!R;W/M;2!Z<'+A=G4A*0!+;VQI:R!S;&]U<&/Y(&-H8V5T92!S
M<&]J:70_`$MO;&EK(&IE('1A;2!P;VSM("AS;&]U<&/Y*3\`2V]L:6L@^.%D
M:_D@8VAC971E('-P;VII=#\`5FQH:V]S=`!6;&AK;W-T.@!(=6UO<F[I`$UA
M[V%R<VMO`%-E;&AA;&\@=GET=F_X96[M($E-05!O=ND@<V-H<N%N:WDZ("5S
M`%-E;&AA;&\@<VUA>N%N[2!)34%0;W;I('-C:'+A;FMY.B`E<P!396QH86QO
M(&YA<W1A=F5N[2!K=O-T>2!P<F\@24U!4&]V;W4@<V-H<N%N:W4Z("5S`$E0
M(&%D<F5S80!)4"!A9')E<V$@;F5N[2!D;W-T=7!NX2X`25`@861R97-A(&YE
M;NT@=B!P;W9O;&5NZ6T@0TE$4B!R;WIS86AU+@!0;W)UN65N[2!I;G1E9W)I
M='D@25`N`%9?;&^^=&4@^.%D96L@</AE9`!)<VQA;F0`4&]U>F4@:6MO;GD`
M26MO;GD@<')O("5S`$EK;VYY(',@=&5X=&5M`$[A>F5V(&ED96YT:71Y.@!0
M;VMU9"!Z;V)R87IE;NT@;F5N[2!V('!O^.%D:W4L("5S(&]T97;X[70@=B!N
M;W;I;2!O:V[L+@!0;VMU9"!P;W6^[7;A=&4@26YT97)N970@17AP;&]R97(@
M82!N979I9.UT92"^X61NZ2!I:V]N>2P@>OAE:FWL('!O=/AE8G5J971E(&]Z
M;F'H:70@=&5N=&\@<N%M9>AE:R!P<F\@=GEP;G5T[2!03D<@=')A;G-P87)E
M;F-E+@!0;VMU9"!V:63M=&4@='5T;R!Z<'+A=G4@;>US=&\@;V)RX7IK=2P@
M;V)RX7IE:R!K=&5R_2!C:&-E=&4@</AE;NES="!N96QZ92!68;GM;2!P<F]H
M;.V^9>AE;2!Z;V)R87II="X`3N%H;&5D(&]B<N%Z:W4Z`%523"!O8G+A>FMU
M`%523"!O8G+A>FMU.@!/8G+A>F5K('H@9V%L97)I90!/8G+A>F5K('H@9V%L
M97)I93H`4/AE;F]S(&]B<N%Z:W4`3V)RX7IK>0!);7!O<G0L(&MR;VL@)60`
M26UP;W)T;W9A;ND@<&]L93H@)7,`26UP;W)T;W9A;N$@<&]L93H`5FQOOFET
M(/CA9&MU('IA`$)Y;"!Z863A;B!N97-P<N%V;OT@86OH;NT@:_-D+@!.97-P
M<N%V;NP@>F%D86[I('6^:79A=&5L<VOI(&IMZ6YO(&$O;F5B;R!H97-L;RX`
M3F5S<'+A=F[I('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@86QT97)N871I=F[M
M(&%D<F5S82X@6FMU<W1E(&IEN73L(&IE9&YO=2!N96)O(&MO;G1A:W1U:G1E
M(%9AN65H;R!S>7-TZ6UO=NEH;R!A9&UI;FES='+A=&]R82X`6G;L=+EI="!O
M9'-A>F5N[0!);F1I90!*961N;W1L:7;M('6^:79A=&5LZ0!);F1O;NES:64`
M26YF;W)M86-E`$EN9F]R;6%C90!6;&^^:70@<U]L;W5P96,@>F$`5FQOOFET
M(&]B<N%Z96L`5FQOOFET('1A8G5L:W4`5FQOOFET('=E8F]V_2!O9&MA>@!6
M;&^^:70@7W-L;W5P96,@</AE9"``5FQOOFET(&YO=OT@<VQO=7!E8R!Z82!S
M;W7H87-N_0!6;&^^:70@;F]V_2!S;&]U<&5C('#X960@<V]UZ&%S;OT`5FQO
MOFET(&YO=OT@^.%D96L@>F$@<V]UZ&%S;OT`5FQOOFET(&YO=OT@^.%D96L@
M</AE9"!S;W7H87-N_0!6;&^^:70@;V1S=&%V96,@>F$@<V]UZ&%S;OT@=7IE
M;`!6;&^^:70@;V1S=&%V96,@</AE9"!S;W7H87-N_2!U>F5L`%9L;[YI="!A
M;'1E<FYA=&EV;NT@=GIO<@!6;&^^=&4@96UA:6QO=F]U(&%D<F5S=2P@;F$@
M:W1E<F]U(&]B9'*^[71E(&YO=ND@:&5S;&\Z`%9L;[YI="!B=?)K=2!Z80!6
M;&^^:70@8G7R:W4@</AE9`!6;&^^:70@<VQO=7!E8R!Z80!6;&^^:70@<VQO
M=7!E8R!P^&5D`%9L;[YI="!Z<'+A=GD`5FQOOFET(&]D<W1A=F5C('IA`%9L
M;[YI="!O9'-T879E8R!P^&5D`%9L;[YI="#XX61E:R!Z80!6;&^^:70@^.%D
M96L@</AE9`!6;&^^=&4@<&^^861O=F%N;W4@;V1P;W;L[R!N82!B97IP9>AN
M;W-T;NT@;W3A>FMU.@!6;&^^:70O=7!R879I="!O8G+A>F5K`%9L;[YI="]U
M<')A=FET(&]D:V%Z`$YE9&]S=&%T9>AN_2!K<F5D:70@:R!O9&5S;.%N[2!Z
M<'+A=GD@;F$@9&ES=')I8G7H;NT@<V5Z;F%M+@!.961O<W1A=&7H;OT@:W)E
M9&ET+@!#96SI(.CM<VQO`%-E>FYA;2!C96S]8V@@Z.US96P`3F5S<'+A=F[I
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!.97!L871NX2!A<&QI:V%C92X`
M3F5P;&%T;ND@:61E;G1I9FEK8>AN[2#H[7-L;R`H240I(&3A=FMY+@!">6QA
M('IA9.%N82!N97!L871NX2!D871A`$YE<&QA=&[A(&%D<F5S82!P^.UJ96UC
M92X`3F5P;&%T;OT@9F]R;>%T('-O=6)O<G4`3F5P;&%T;OT@;7-G7W1Y<&4N
M`$YE<&QA=&[I(&YE8F\@8VAY8NQJ[6/M(&%P:5]I9"X`3F5P;&%T;ND@;F5B
M;R!C:'EB[&KM8^T@<&%R86UE=')Y+@!.97!L871NX2!V;&%S=&YI8VOA('!R
MX79A+@!.97!L871N_2!P<F]T;VMO;"X`3F5P;&%T;OT@<V3M;&5N_2!O8FIE
M:W0`3F5P;&%T;N$@861R97-A(&]D97/M;&%T96QE+@!.97!L871NX2!D871A
M('5N:6-O9&4N`$EN=F5N=.'X`,URX6XL($ES;.%M<VOA(')E<'5B;&EK80!)
M<N%K`$ER<VMO`$]S=')O=B!M=;YE`$]J961I;NQLZ2!B;W7X:WD`27-R865L
M`%!O<VMY=&]V871E;`!+=7)Z[79A`$ETX6QI90!*86UA:FMA`$QE9&5N`$IA
M<&]N<VMO`$IA<&]NN71I;F$@*$E33RTR,#(R+4I0*0!4<FEK;W0`2F]R9.%N
M<VMO`,AE<G9E;F5C`,AE<G9E;@!:87)O=FYA=`!:87)O=FYA="!N82!S=/AE
M9`!:87)O=FYA="!V>7!L;NQN[6T`6F%R;W9N870@9&]L979A`%IA<F]V;F%T
M(&1O<')A=F$`2V%Z86-H<W3A;@!58VAO=F%T(&]R:6=I;N%L/P!+9?)A`$ME
M<F)E<F]S('-E<G9E<B!Z86WM=&YU;"!O=NSX96[M+@!.;W;AZ&-I(&ME<FYE
M;'4`5GET=F_X96[M(&ML[>AE`%9Y='9O^&5N[2!O=&ES:W4@:VSMZ&4`1.EL
M:V$@:VSMZ&4`5'EP(&ML[>AE`%6^:73M(&ML[>AE`$ML[>@@:FF^(&5X:7-T
M=6IE(&YA('9E^&5J;NEM(&ML[>AO=NEM('-E<G9E<G4N`$3L=&D`2VER:6)A
M=&D`2TQ$4@!+;W)E80!+;W)E:G-K>2`H155#+4M2*0!+=79A:G0`2WER9VEZ
M<W3A;@!?4F]Z;&^^96[M`$IA>GEK`$QA;W,L($QI9&]V["!$96UO:W)A=&EC
M:V$@4F5P=6)L:6MA`$1R=6CA('!O;&]V:6YA`%!O<VQE9&[M(.AT=G)T:6YA
M`%!O<VQE9&[M(&%K='5A;&EZ86-E.@!0;W-L961N[2!P^&EH;.&Y96[M.B`E
M<P!0;W-L961N[2!P^&EH;.&Y96[M.B`E<R!Z("5S`%!O<VQE9&[M('#X:6AL
MX;EE;NTZ($YI:V1Y`$QI='9A`%!RX79O`%)O>FQOOF5N[0!.96-H870@<'+A
M>F1NZ2!B97H@;VMR86IE`$QI8F%N;VX`1&]L979A`$QE=N$@:&QA=FGH:V$`
M2&]D;F]T>2!N86QE=F\`3&5S;W1H;P!,:6+I<FEE`$QI8FEE`$QI8VAT96ZY
M=&5J;G-K;P!,96AKZ2!M<FAO;&5N[0!,96AK_2!DZ;F[`$)R>FO](&QE:&O]
M(&3IN;L`4&]Z9.QJ:2!L96AK_2!DZ;F[`$QE:&OI(&1EN;MO=ND@<W+AOFMY
M`$QE:&O](&3IN;L@<R!H^&WL;NUM`$QE:&OI('-N[+YE;NT`3&5H:^D@<V[L
M:&]VZ2!P^&5HX?)K>0!,:6UE<FEC:P!/9&MA>@!/9&MA>GD@=6MA>G5J[2!N
M83H`4&]UONUT(&]D:V%Z>2!N82!E;6%I;&]VZ2!A9')E<WD@</AI('IO8G)A
M>F]VX6[M('-T<N%N:WD@<')O('!S86[M('IP<N%V`$]D:V%Z>0!,:6YU>&]V
MZ2!C;V]K:64`4V5Z;F%M("T@=;YI=F%T96P@;?F^92!V:63L="!S;&^^:W4`
M4V5Z;F%M(&1A=&%BX7KM`%-E>FYA;2!TZ6UA="!NX7!O=NQD>0!397IN86T@
M=&%B=6QE:P!397IN86TM07)C:&EV`%-E>FYA;2U.X7!O=NQD80!397IN86TM
M260`4V5Z;F%M+59L87-T;NUK`%-E>FYA;2U/9&5S;.%N[0!397IN86TM4/AI
M:&SAN65N[0!397IN86TM3V1H;.&Y96[M`%;]<&ES('6^:79A=&5L^2!N96[M
M(&1O<W1U<&[]+@!,:71E<F%T=7)A`$QO='FY<VMO`$YA:'+A=N%N[2XN+@!-
M[7-T;NT@Z&%S.B``3&]C86QE(&$@Z&%S`$WM<W1O`%#X:6ALX7-I="!S90!/
M9&ALX;EE;NT`VFMO;'D@<')O=N%D[&[I('#X:2!P^&EH;.&Y96[M`%-E;&AA
M;&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU+B!0<F%V9.QP;V1O8F[L(%9AN64@
M=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO(&YE8GEL;R!S<'+A=F[L
M('IA9.%N;RX`4/AI:&SAN65N[2!S96QH86QO+@!$;&]U:/T@=&5X=`!,X7-K
M80!.[7IKX0!-86SA(/AE8VOA('#M<VUE;F$`36%LX2!T:7-K86/M('#M<VUE
M;F$`36%LZ2#X[6US:^D@Z.US;&EC90!,=6-E;6)U<G-K;P!-30!:<'+A=F$@
M9&YE`%#X:7!O:F5N_2!S;W5B;W(@35,M3E1%1B!N96]B<V%H=6IE(+[A9&[A
M(&1A=&$N`$U31P!-86MA;P!-86ME9&]N:64L(&+]=F%LX2!297!U8FQI:V$@
M2G5G;W-LX79I90!-861A9V%S:V%R`$UA9VEE`%!ON71A`$%D;6EN:7-T<N%T
M;W(@<&^Y='D`5GET=F_X:70@;V1?:V%Z+BXN`$UA;&%W:0!-86QA:G-I90!-
M86QD:79Y`$UA;&D`36%L=&$`4')O('5M;[YN[&[M(&]V;.%DX6[M(&MA=&5G
M;W)I[2!J92!Z87!O=/AE8NT@;WIN8>AI="!P;VQOOFMY(&)A<G9A;6DL(&MT
M97+I(&IS;W4@</AI^&%Z96YY(&L@=.QM=&\@:V%T96=O<FGM;2X`36%P82!-
M87`R-`!-87!A($UA<%%U97-T`$+X97IE;@!/:W)A:@!/>FYAZ&ET('IN8>AK
M;W4@4')O:&SI9&YU=&\O3F5P<F]H;.ED;G5T;P!/>FYAZ&ET(&II;OUM:2!Z
M;F'H:V%M:2`H:F%K;R!$^6QEOFETZ2]/9'!O=NQZ96[I*0!-87*Y86QS:^D@
M3W-T<F]V>0!-87)T:6YI<75E`%-H;V1U:NUC[2!S92!P;VQE`$UA=7)E=.%N
M:64`36%U<FEC:75S`$UA>&EM86QN[2!P;W9O;&5N_2!K<F5D:70`0GEL82!P
M^&5K<F_H96YA(&UA>&EM86QN[2!DZ6QK82!Z<'+A=GDN`$YE:G9YN;GM('1E
M<&QO=&$@>F$@<&]S;&5D;NUC:"`R-"!H;V1I;CH@`$YE:G9YN;GM('1E<&QO
M=&$@>F$@<&]S;&5D;NUC:"`V(&AO9&EN.B``36%X:6WA;&[M(&3I;&MA`$MV
M['1E;@!-87EO='1E`$UE9&EC[6YA`,AL96YO=ND`3?-D>2!P<F\@;65N=3H`
M4W!O:FET(&)U\FMY`%IP<N%V80!:<'+A=F$@8GEL82!O=NSX96YA('8@<&_X
MX61K=2P@86QE(&YE;'IE(&]V[/AI="!P;V1P:7-O=OT@8V5R=&EF:6OA="X`
M6G!RX79A('!R;W!A9&QA+@!4>7`@>G!RX79Y`%!OZ&%S[0!";&]K(&\@<&_H
M87/M(&YE;NT@9&]S='5P;OTN`$)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T=7!N
M_2X@4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!P<F\@<WES=.EM;W;I
M:&\@861M:6YI<W1RX71O<F$@9&\@;&]G=2X`365T;V1A`$UE=')I8VO]`$UE
M>&EK;P!-:6MR;V[I<VEE+"!&961E<F%C90!5<')O<W3X960`5'EP($UI;64`
M3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``3F5J
M;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!:<F-A9&QO
M=NP`4OEZ;ND`4')O9W)A;6]V_2!B86SM:R!(5%107U)E<75E<W0@8VAY8NT@
M=B!014%2+@!#:'EB[&KM8^T@:V]N9FEG=7)A8V4N(%!O:W5D('-I('#X96IE
M=&4@<&]UONUV870@='5T;R!A<&QI:V%C:2P@;75S[71E('9Y9V5N97)O=F%T
M(&MO;F9I9W5R8>AN[2!S;W5B;W(N`$-H>6+L:NUC[2!)1"!Z<'+A=GD@*&ED
M96YT:69I:V'H;NT@Z.US;&\I`%!OOF%D;W9A;OT@<')O9W)A;6]V_2!B86SM
M:R!-86EL(&-H>6+M('8@4$5!4BX`0VAY8NQJ[6/M($E$('!R;R!R96QA8VDN
M`%!O`$UO8FEL;NT@<&^Y=&$`3>UR;OT`1&%T=6T@<&]S;&5D;NT@>FWL;GD`
M6FWL\FET(%523`!-;V1U;`!-;VQDX79I90!-;VYA:V\`36]N9V]L<VMO`$WL
M<^UC(&$@<F]K`$WL<^WH;NP`36]N<V5R870`1N%Z92!-['/M8V4`36%R;VMO
M`%#X97;AOF[L(&IA<VYO`%#X97;AOF[L(&]B;&'H;F\`4/AE=N&^;NP@<VQU
M;F7H;F\`4&]S=6YO=70@9&]L^0!0;W-U;F]U="!D;VQE=F$`4&]S=6YO=70@
M9&]P<F%V80!0;W-U;F]U="!N86AO<G4`4&]S=6YO=70@9&]L^0!0;W-U;F]U
M="!N86AO<G4`36]S86UB:6L`5NUC92WZ<F]V\F]VZ2!R;VQE=&]VZ2!S97IN
M86UY`%;M8V5NX7-O8F[A('-E;&5K8V4`3?EJ(/KH970`3?EJ('!O<G3A;`!-
M;VIE(')O>FQOOF5N[2!P;W)TX6QU`$UY86YM87(`3D4L($Y%4T]52$Q!4\U-
M`$IMZ6YO`$YA;6EB:64`3F%U<G4`3F5PX6P`3FEZ;WIE;>T`3FEZ;WIE;7-K
MZ2!!;G1I;'D`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE
M=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!*;>EN;R!.971S8V%P
M92!34TP@<V5R=F5R=0!0;WINX6UK82!K(&-E<G1I9FEKX71U($YE='-C87!U
M`%1Y<"!C97)T:69I:^%T=2!.971S8V%P=0!3[;L`3FEK9'D`3F]VX2!+86QE
M9&]N:64`3F]VX2!K871E9V]R:64`3>QS[6,@=B!P<G9N[2#H='9R=&EN[`!.
M;W;I('6^:79A=&5L<VOI(&IMZ6YO("AN97!O=FEN;NDI`$YO=OT@6NEL86YD
M`$YO=ND@;VMN;R`H7W!RX7ID;NDI`$YO=FEN:WD`3F5W<V=R;W5P<P!$86RY
M[0!$86RY[2!M;[YN;W-T:0!.:6MA<F%G=6$`3FEG97(`3FEGZ7)I90!.;V,`
M3FEU90!.90"N861NX2!K;VYF:6=U<F'H;NT@9&%T82!N96IS;W4@9&]S='5P
M;N$@<')O('IO8G)A>F5N[2!R;WID[6SY+@!.96[M(&1O<W1U<&[A(+[A9&[A
M('-T<F%T96=I92!P<F\@='9O<F)U($E33R!O8G)A>ODN`$)E>B!DX79K;W;I
M:&\@=GIO<G4N`$YA('!OOF%D;W9A;ND@<&]Z:6-I(&YE97AI<W1U:F4@ON%D
M;OT@8FQO:P!.96)Y;&\@<&]S:WET;G5T;R"^X61NZ2!J;>EN;R!P<F\@:V%L
M96YDX?@@</AI(&]V[/AO=N%N[2!P;VUO8^T@34-!3"X`0F5Z('IM[&YY+@!.
M96QZ92!P^&ED870@ON%D;N$@<&]D+7!RX79A(&L@=.QM=&\@<'+A=OEM+@!.
M96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R
M;R`E<RX`3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R
M;6%C92!P<F\@1E10(%9&4RX`3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG
M=7)AZ&[M(&EN9F]R;6%C92!P<F\@4U%,(%9&4RX`3F5B>6QY('5V961E;GD@
MON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@4U%,+49I;&4@5D93
M+@!.96WA=&4@ON%D;OT@:W)E9&ET+@!.96)Y;"!P;W-K>71N=70@ON%D;OT@
M8^UL+@"NX61N_2!S;W5B;W(@;F5B>6P@</AE;F5S96X`3F5B>6QY(&YA;&5Z
M96YY(+[A9&[I(&EK;VYY+@!.96)Y;&\@=GEB<N%N;R"^X61NZ2!M[7-T;RX`
M3F5B>6QY('!O<VMY=&YU='D@ON%D;ND@>G!RX79Y+@!.96)Y;&\@=79E9&5N
M;R"^X61NZ2!J;>EN;RX`3F5B>6QO('5V961E;F\@ON%D;ND@Z.US;&\N`$)E
M>B!N97-L=;EN_6-H`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX
M96[M('!O;6]C[2!(5%10+@!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@
M;W;L^&5N[2!P;VUO8^T@24U!4"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@
M<')O(&]V[/AE;NT@<&]M;V/M($ME<F)E<F]S+@!.96)Y;&\@<&]S:WET;G5T
M;R!H97-L;R!P<F\@;W;L^&5N[2!P^&EH;.&Y96[M('-E(&1O('-Y<W3I;74N
M`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!0
M05-35T0N`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O
M;6]C[2!334(N`$YE8GEL82!P;W-K>71N=71A(&-E<W1A(&L@8FENX7)N[6UU
M('-O=6)O<G4@3W!E;E-33"X@0FENX7)N[2!S;W5B;W(@3W!E;E-33"!J92!Z
M87!O=/AE8NT@<')O('!RX6-I(',@4$M#4R`Q,B!D871Y+@"NX61NZ2!N979Y
M^.UZ96[I(+[A9&]S=&D@;R!P^&EH;.&Y96[M+@!"97H@<')A=FED96P`0F5Z
M(&]K<F%J^0"NX61N_2!Z(&1OZ&%S;OUC:"!A9')E<^'X^2!N96[M(&1O<W1U
M<&[]('!R;R!C86-H92X`3F5B>6QO(&]D97-LX6YO(+[A9&[I('6^:79A=&5L
M<VOI(&IMZ6YO(&$O;F5B;R!H97-L;RX`3F5B>6QA(&YA=G+A8V5N82"^X61N
MX2!P;&%T;N$@6$U,(&1A=&$N`*[A9&[I(&AO9&YO='D`5B!O<FEG:6[A;&[M
M(&MO;F9I9W5R86-I(&YE8GEL82!N86QE>F5N82!V97)Z92X@3V)N;W9T92!K
M;VYF:6=U<F%C:2X`5F4@5F&Y[2!K;VYF:6=U<F%C:2!N96)Y;&$@;F%L97IE
M;F$@=F5R>F4N($]B;F]V=&4@:V]N9FEG=7)A8VDN`*[A9&[]`*[A9&[]("AP
M;W6^:6IT92!I;7!L:6-I=&[M*0!3979E<G-K_2`H25-/+3@X-3DM,3`I`$YO
M<F9O;&MS:^D@;W-T<F]V>0!3979E<F[M('!O;&]K;W5L90!3979E<F[M($UA
M<FGA;G-KZ2!O<W1R;W9Y`$YO<G-K;P!.96[M('!O`$YE;NT@</AE9`!.96[M
M(&%D<F5SX?AE;0!.96[M(&EM<&QE;65N=&]VX6YO+@!.96[M(&YA<W1A=F5N
M;P!.96[M('!O9'!O<F]VX6YO+@!0;WINX6UK80!.:6,@:R!P<F]H;.ED;G5T
M[2P@8NR^=&4@>G#L="X`3&ES=&]P860`R.US;&\`4&_H970@>FYA:_D`4&_H
M970@<VQO=7!C^0!0;^AE="#XX61K^0!.96)Y;&$@>F%DX6YA(.CM<VQA('!R
M;R!A:W1U86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA;74N`$]+`$]B:F5K
M=`!4=OER8V4@;V)J96MT^0!/<VUIZ&MO=OT`V.UJ96X`1FEL=')O=F%T(&YE
M<VQUN6[I`$MA;F-E;.'X`$]MX6X`4V3M;&5NZ2!S;&^^:WD@:G-O=2!P;W-K
M>71O=N%N>2!P;W5Z92!)34%0('-E<G9E<GDN`%!O=7IE(&YE<VQUN6[I`$IE
M('!O=F]L96YA('!O=7IE(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N`%!O=7IE
M('9L87-T;NUK(&YE8F\@<WES=.EM;W;](&%D;6EN:7-T<N%T;W(@;?F^92!M
M[&YI="!P<N%V82!P<F\@<V3M;&5N_2!O8FIE:W0N`$]T97;X[70@=B!N;W;I
M;2!O:V[L+@!#:'EB82!/<&5N4U-,.B!.96QZ92!Z[7-K870@9&%T82!Z('!O
M9&5P<V%NZ2#HX7-T:2!3+TU)344N`$]T97;X[70@=&5N=&\@;V1K87H@=B!N
M;W;I;2!O:V[L`$]P97)AZ&[M('-Y<W3I;0!-;[YN;W-T:0!-;[YN;W-T:2!P
M<F\@)7,`4V7X87IE;OT@<V5Z;F%M`$]R9V%N:7IA8V4`3W)G86YI>F'H;NT@
M:F5D;F]T:V$`3W)G86YI>F]VX6[M`$]R:6=I;N%L;NT@=GIO<B!P<F\@ON%D
M;W-T`$]R:6=I;N%L;NT@=GIO<B!V("5S.@!/<W1A=&[M`$]S=&%T;NT@:6YF
M;W)M86-E`%6^:79A=&5L<VOA('!RX79A`$]V[/AE;NT@<&]M;V/M(%!!32!N
M96[M(&1O<W1U<&[I+@!01U`@9&EG:73A;&[M('!O9'!I<P!01U`@N6EF<F]V
M86[A(&1A=&$`5F7X96IN_2!01U`@:VSMZ`!$871A('!O9&5P<V%NX2^Y:69R
M;W9A;N$@<&]M;V/M(%!'4`!02%`@:_-D`%!(4"!K;VYZ;VQA`$]D<&]L961N
M[2!L96AK_2!DZ;F[`$]D<&]L961N[2!P^&5HX?)K>0!/9'!O;&5D;NT@<V[L
MOF5N[0!/9'!O;&5D;NT@<V[L:&]VZ2!P^&5HX?)K>0!/9'!O;&5D;NT@8F]U
M^&MY`%!?2%`@:V]N>F]L80!/9'-T=7!Y`%#A:VES=.%N`%!A;&%U`%!A;&5S
M=&EN<VOI('1E<FET;W)I=6TL(&]K=7!O=F%NZ0!086YA;6$`4&%P=6$@3F]V
MX2!'=6EN96$`4&%R86=U87D`3>US='D@>F%T8;YE;F\`2&5S;&\`3F5S<'+A
M=F[I(&AE<VQO`%!R;R!O=NSX96[M('!O;6]C[2!2041525,@:F4@;G5T;F\@
M>F%D870@:&5S;&\N`$AE<VQO(',@<&]T=G)Z96[M;0!(97-L;SH`2&5S;&\Z
M(`!(97-L82!S92!M=7/M('-H;V1O=F%T+@!6;&^^:70`5FQOOFET('IE('-C
M:'+A;FMY`$-E<W1A`*[A9&]S=&D@;R!P^&EH;.&Y96[M.@!,:63I`%!R;V-E
M;G0`4')O=NES="!O<&5R86-E(/ID<KYB>0!0<F]VZ7-T(&]P97)A8V4@^F1R
MOF)Y('#X:2!P^&EH;.&Y96[M(&1O('-Y<W3I;74_`%!RX79A`$%D;6EN:7-T
M<F'H;NT@<'+A=F$`3W-O8F[M(&EN9F]R;6%C90!097)U`$1O;>%C[2!Z=NWX
M871A`$9I;&EP[6YY`%1E;&5F;VX`1F]T;V=R869I90!0:71C86ER;@!0:7AE
M;/D`1G+A>F4`4')O<^UM(&ML:6MN['1E(&YA(&[L:F%K;W4@8G7R:W4`4')O
M<^UM('!O='9R[W1E+""^92!S:2!P^&5J971E(&]D<W1R86YI="!T96YT;R!P
M<G9E:SH`4')O<^UM('!O='9R[W1E+""^92!S:2!P^&5J971E(&]D<W1R86YI
M="!T96YT;R!P<G9E:RX`4')O<^UM('IA9&5J=&4@;>QS[6,@82!R;VLN`%!R
M;W/M;2!Z861E:G1E(&[A>F5V(&YO=ND@:V%T96=O<FEE.@!0<F]S[6T@>F%D
M96IT92!S<'+A=FYO=2!)4"!A9')E<W4N+@!0<F]S[6T@>F%D96IT92!S<'+A
M=F[](&1A='5M(&$@>FMO;G1R;VQU:G1E('!OZ&5T(&1N[2!V(&WL<^UC:2X`
M4')O<^UM('IA9&5J=&4@<W!RX79N_2#H87,N`%!R;W/M;2!U=F7O=&4@<VAR
M;G5T[2!68;EE:&\@<')O8FSI;74N`%!R;W/M;2!Z861E:G1E(%9AN64@=;YI
M=F%T96QS:^D@:FWI;F\@82!H97-L;P!0<F]S[6T@>F%D96IT92!N;W;](&[A
M>F5V(&MA=&5G;W)I93H`4&]L<VMO`%!O;&ET:6MA`$AL87-O=N%N[0!0;W)T
M=6=A;'-K;P!5;>US=.QN[2!T;VAO=&\@;V)RX7IK=0!5;>US=.QN[2!T86)U
M;&MY`%IA<VQA="!D;R!TZ71O('-L;[YK>2`H;F5N[2!P;W-K>71N=71O($E-
M05!E;2D`4W+AOFMY('IA('!O<VQE9&[M*&-H*2`E<R!H;V1I;BAU*3H@`%!R
M969S7VQD87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@
M3$1!4"X`4')E9G-?<V5S<VEO;CH@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A
M;N$@</CM<&]N82!S96MC92X`0F%R;VUE=')I8VO]('1L86L`0F%R;VUE=')I
M8VO]('1L86L@;F$@^G)O=FYI(&UO^&4Z(`!"87)O;65T<FEC:_T@=&QA:SH`
M3N%H;&5D`$[A:&QE9"!O8G+A>FMU('8@;F]VZ6T@;VMN[`!0^&5D8VAO>NT@
M;6^^;F]S=&D`5&ES:VYO=70@9&]K=6UE;G0`4')I=N%T;NT@:VSMZ`!0<F]B
M;.EM`%!O<&ES('!R;V)LZ6UU`%!R;VIE:W1Y`%!R;VUP="!T97AT`%9E^&5J
M;OT@:VSMZ`!!;&=O<FET;75S('!R;R!V9?AE:F[](&ML[>@`5F7X96IN_2]P
M<FEVX71N[2!K;.WH;W;]('#A<B!N96)Y;"#Z<W#LN6[L('9Y='9O^&5N+@!0
M;W)T;W)I:V\`2V%T87(`5GEH;&5DX6[M`%)302!V9?AE:F[](&ML[>@@*"5D
M(&)I=/DI`%-P^&&^96[I('1L8>CM=&MO`$3IN;L`0G)Z:_T@9.FYNP!0;WID
M;NT@9.FYNP!$9;F[;W;I('#X96CA\FMY`$3IN;L@<V4@<V[L:&5M`$3IN;L@
M8;X@<V[M:`!.X6AO9&[L('9Y8G)A;ND@N73L<W3M`%!O;>QR`,AT96/M`%#X
M9>AT96[I('IP<N%V>0!/<')A=F1U('-M87IA="`E<S\@5&%T;R!O<&5R86-E
M(&IE(&YE=G)A=&[A+@!/<')A=F1U('-M87IA="!UOFEV871E;'-KX2!D871A
M('!R;R!UOFEV871E;&4@)7,_(%1A=&\@;W!E<F%C92!J92!N979R871NX2X`
M3W!A:V]V870@<&]S;&5D;NT@86MC:0!/8FYO=FET(&1Y;F%M:6-KZ2!P<G9K
M>2!M96YU.@!/8FYO=F$@>F]B<F%Z96[M('!O<G3A;'4Z(`!296=E>`!0<F]H
M;.V^9>@@=GIT86CY`$AO9&YO='D`5GIDX6QE;ND@<V5R=F5R>2X`5GIDX6QE
M;N$@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`3V1S=')A
M;FET`$]D<W1R86YI="!B;&]K`$]D<W1R86YI="!S;&]U<&5C`$]D<W1R86YI
M="!F;W)MX71O=N%N[0!/9'-T<F%N:70@<.%R`$]D<W1R871I="!U;&^^96[]
M('-K<FEP="!Z(&1OZ&%S;NEH;R!A9')E<^'X92!N82!S97)V97)U+@!/9'-T
M<F%N:70`3V1S=')A;FET('1U=&\@Z.%S="!D;VMU;65N='4`3V1S=')A;FET
M('6^:79A=&5L90!/9'-T<F%N:70@=;YI=F%T96QE.B`E<P!.96QZ92!O9'!O
M=NQD['0@;F$@<&^^861A=F5K+B!#:'EB;W;I(&ALX;EE;NTZ(`!0;[YA9&]V
M86[I('!O;&4`5OUC:&]Z[2!N87-T879E;NT`5OUC:&]Z[2!N87-T879E;NT@
M:&5S;&$`5OUC:&]Z[2!N87-T879E;NT@5F&Y96AO(&AE<VQA`%;]<VQE9&MY
M`$[A=G)A="!D;R!M;[YN;W-T[0!2975N:6]N`%#X97!N;W5T(&MO;F9I9W5R
M86-I`$UOOFYO<W1I(%)I8V@@5&5X="!E9&ET;W)U`$CA9&%N:WD`1&]P<F%V
M80!(;&%V:>AK82!N87!R879O`$AO9&YO='D@;F%P<F%V;P!6;&%S=&YO<W1I
M(/CA7V1K=0#:;&]H80!2=6UU;G-K;P!/=&_H:70@;R`Q.#"P`$]T;^AI="!D
M;VQE=F$`3W1OZ&ET(&1O<')A=F$`5FQA<W1N;W-T:2#XX61K=0!6;&%S=&YO
M<W1I(/CA9&MU`-CA9&MY.@!0<F%V:61L80!0<F%V:61L82!S92!U<&QA=&[M
M(&UE>FD@=KEE;6D@^.%D:WD@82!S;&]U<&-I`%!R879I9&QA('-E('5P;&%T
M;NT@<&]U>F4@;65Z:2!S;&]U<&-I`%!R879I9&QA('-E('5P;&%T;NT@<&]U
M>F4@;65Z:2#XX61K>0!0<F]VZ7-T`%)U<VOA(&9E9&5R86-E`%)W86YD80!3
M+TU)344@N6EF<F]V86[]('!O9'!I<P!3+TU)344@N6EF<F]V86[A('IP<N%V
M80!/=NSX96[M('!O;6]C[2!305-,(&YE;NT@9&]S='5P;NDN`%--4R!Z<'+A
M=GD`4U%,(&MO;GIO;&$`4U-(`-I34,Q#2`!37U%,(&MO;GIO;&$`4V\`4W9A
M=.$@2&5L96YA`%-V873]($MI='1S(&$@3F5V:7,`4V%I;G0@3'5C:6$`4V%I
M;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<P!3=&5J;OT@<N%M("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN
M;P!386\@5&]M92!A;F0@4')I;F-I<&4`5FQA<W1N[6L@<V%T96QI='4`4V%U
M9'-KX2!!<N%B:64`56QOOFET`%5L;[YI="`E<P!5;&^^96[M(&UOOFYO<W3M
M`%5L;[YI="!V>71V;_AE;OT@:V]N9FEG=7)AZ&[M(%!(4"!S:W)I<'0@9&\@
M9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E<G9E<G4N`$MO;F9I9W5R86-E("5S
M('5L;[YE;F$N`%;L9&$`5GEH;&5D870`5GEH;&5DX79A8^T@;N%S=')O:F4`
M5GEB<F%T('-O=6)O<GD`5GEB<F%T(&1A='5M`%9Y8G)A="!S:W5P:6YU+"!K
M=&5RX2!B=61E('#X:63A;F$`5GEB<F%T(&YO=NEH;R!V;&%S=&[M:V$`5GEB
M<F%T('-E<G9E<@!6>6)R870@=;YI=F%T96QE+"!K=&5R_2!B=61E('#X:63A
M;@!6>6)R870@=KEE8VAN>2#HX7-T:2!D871U;74N`%9Y8G)A="!O8FIE:W0`
M5GEB97)T92!P;W3X96)NZ2!Z;F%K>2!Z(&[MOF4@=79E9&5N_6-H(&)O>/DN
M(%!O=.D@:F4@;?F^971E(&MO<.UR;W9A="!A('9L;[YI="!Z('1E>'1O=ND@
M;V)L87-T:2X`5GEB97)T92!O9&3L;&]V86/M('IN86L@<')O(&1A='5M.@!6
M>6)E<G1E(&9O<FWA="!D871U;74Z`%9Y8F5R=&4@:61E;G1I='4L(&MT97)O
M=2!S:2!P^&5J971E('IM[&YI=#H`5GEB97)T92!O9&3L;&]V86/M('IN86L@
M<')O(.AA<SH`5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB97)T92!D=NP@;V1P
M;W;M9&%J[6/M('!O;&4N`%9Y8F5R=&4@8F%R979N_2!M;W1I=BX`5GEB97)T
M92!6X6UI('!R969E<F]V86[](&IA>GEK.@!0;W-L870@>G!RX79U(&\@<')O
M8FSI;74`4&]S;&%T(%--4P!396YE9V%L`%-E;G-O<CH`6N'X[0!3<F)S:V\@
M82#(97)NX2!(;W)A`%/I<FEO=ND@Z.US;&\`240@<V5K8V4@>F%N:6ML;RX`
M3F%S=&%V:70`3F%S=&%V:70@;6^^;F]S=&D@<')O('!O=F]L96[M(')E<V5T
M=2!H97-L82P@<&]K=60@:&\@>F%P;VUE;F5T92X`3F%S=&%V:70@=GIDX6QE
M;ND@<V5R=F5R>2!T86LL(+YE(&)U9&]U('#X[7-T=7!NZ2!Z('!O<G3A;'4N
M`$YA<W1A=F5N[2!6X6UI('!R969E<F]V86[I:&\@:F%Z>6MA+"#H87-O=NEH
M;R!PX7-M82!A('1Y<'4@9&%T=6UU+@!.87-T879E;NT@<&_HX71EZ&[M(&%P
M;&EK86-E+"!B87)E=F[I:&\@;6]T:79U+"!O8FYO=F]VX6[M('-T<N%N96L@
M82!D86RY[6-H(&UOOFYO<W3M('IO8G)A>F5N[2X`3F%S=&%V96[M`$YA<W1A
M=F]V86/M(&MO;F9I9W5R8>AN[2!S:W)I<'1Y('!R;R!A:W1U86QI>F%C:2!J
M<V]U(&1O<W1U<&[I`$[L:W1E<N$@;>US=&$@;'IE(&YA<W1A=FET(',@=.UM
M=&\@<&%R86UE=')E;3H@`%-E>6-H96QL97,`3F%K=7!O=N%N[0!+<N%T:^D@
M<VAR;G5T[0!-[&QY(&)Y(&+]="!P^.US='5P;W;I(&ML[>AE(&1E9FEN;W;A
M;GD@<')O(';L=+EI;G4@;V1K87KY/P!:;V)R87II=`!:;V)R87II="!R;WID
M[6QY(&UE>FD@<V]UZ&%S;F]U(&$@</AE9&-H;WKM(&MO;F9I9W5R86/M+@!:
M;V)R87II="#H87,@<&]S;&5D;NUH;R!P^&EH;.&Y96[M(&1O('-Y<W3I;74_
M`%IO8G)A>FET(&UOOFYO<W0@=61ROF5N[2!O<FEG:6[A;'4`6F]B<F%Z:70@
M<V+L<F'H`%IO8G)A>FET(&UE;G4@;W!E<F'H;NT@;&FY='4@<')O('1A8G5L
M:WD_`%IO8G)A>FET("5S(&UE;G4@;F%L979O/P!:;V)R87II="!D:6%L;V<@
M<')O('9L87-T;F]S=&D@8G5N[&L@=B!T86)U;&OA8V@`6F]B<F%Z:70@9&EA
M;&]G('9L87-T;F]S=.T@=&%B=6QE:P!:;V)R87II="!D:6%L;V<@=FQA<W1N
M;W-T[2#XX61E:R!T86)U;&5K`%IO8G)A>FET(&1I86QO9R!V;&%S=&YO<W3M
M(&]B<N%Z:_D`6F]B<F%Z:70@</AE;F]S`%#X96CA\FMY`$)R>FOI('#X96CA
M\FMY`%!O>F1N[2!P^&5HX?)K>0!0^&5HX?)K>2!V(&]K;VSM`%IM96ZY:70`
M6FUE;KEI="!N96)O('!O<W5N;W5T(&1O('-O=7-E9&[M:&\@8FQO:W4H^2DL
M('H@8V5S='D@<')V;NUM=0!3:65R<F$@3&5O;F4`4F5G:7-T<F]V870@<V4`
M4&]D<&ES`$%L9V]R:71M=7,@<')O('!O9'!I<P!3:6YG87!U<@!696QI:V]S
M=`!6>6YE8VAA="#Z9'*^8G4`4VQO=F5N<VMO`%-L;W9I;G-K;P!3;NR^96[M
M`%-N[&AO=N$@</AE:.'R:V$`4V[L:&]VZ2!P^&5HX?)K>0!286YN[2!S;NQH
M;W;I('#X96CA\FMY`%!O>F1N[2!S;NQH;W;I('#X96CA\FMY`%-N[&AO=N$@
M<&]K<OUV:V$Z`%9O9&[M(&5K=FEV86QE;G0@<')O('-N[6@Z(`"I86QA;6]U
M;F]V>2!O<W1R;W9Y`%-O;>%L<VMO`%#M<V[L(&$@8N%S;NP`4VWL<B!T^.UD
M[&[M`%ID<F]J;W;A(&%D<F5S80!*:;YN[2!!9G)I:V$`2FEH;V5V<F]P<VO]
M("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<P!*:;YN[2!P;VQO:V]U;&4`4')O<W1O<B!M97II('-O
M=7-E9&[M;6D@8G7R:V%M:0!0<F]S=&]R(&UE>FD@;V)S86AE;2!A(&AR86YI
M8V5M:2!V(&)U\F-E`$UE>F5R;NUK`$UE>F5R>0!/9'-T=7!Y(&$@;65Z97)Y
M`*EP86[L;'-K;P!3<&%M`%9S='5P('!R;R!Z=FSAN71N[2!Z;F%K>0!2;WID
M[&QI="!B=?)K=0!2;WID[&QI="!S;&]U<&5C`%)O>F3L;&ET(/CA9&5K`%-P
M;W)T`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4F]K('IAZ.%T:W4`
M4W3A="#H:2!P<F]V:6YC:64`4W1A=@!&;W)MX70@=6QOOF5N[0!5;&EC90!0
M^&6Y:W)T;G5T_0!397IN86T@^&5T['IC90!/9'-T<F%N:70@9&]MZ6YO=ND@
M:FWI;F\@>B!A9')E<WD`4W1Y;"!;0U-370!.90!0^&5D;>QT`%!O9&%T`$1O
M;&[M(&EN9&5X`-IS<.RY;NP`2V]N9FEG=7)A8V4@8GEL82#Z<W#LN6[L('IM
M[&[L;F$N($]B;F]V=&4@<W1RX6YK=2X`VG-P[+ENZ2!U;&^^96[M('KA;&^^
M;NT@:V]N9FEG=7)A8V4N`-IS<.RY;ND@=6QOOF5N[2!ZX6QO:'D@:V]N9FEG
M=7)AZ&[M:&\@<V]U8F]R=2`E<RX`)7,@8GEL;R#Z<W#LN6[L('IA<'/A;F\`
M4W5DX6X`4VAR;G5T[0!3=NUTX6[M`%KA<&%D(%-L=6YC90!3;'5N9>AN;P!6
M_6-H;V0@4VQU;F-E`%;]8VAO9"]ZX7!A9"!3;'5N8V4`5OUC:&]D(%-L=6YC
M93H@`%KA<&%D(%-L=6YC90!:X7!A9"!3;'5N8V4Z(`!(;W)N[2!I;F1E>`!0
M;V1P;W)A`%-U<FEN86UE`%#X[6IM96[M`%-V86QB87)D(&%N9"!*86X@36%Y
M96X`4W=A>FEL<VMO`*EVZ61S:V\`J7;]8V%R<VMO`%-Y;G1A>&]VX2!C:'EB
M82!V(&AL961A;NEM('1E>'1U`%/]<FEE`$)O=?AK80!";W7X:WD`5%-6('-O
M=6)O<@!486)U;&MA`%9L87-T;F]S=&D@=&%B=6QK>0!6;&%S=&YO<W1I('1A
M8G5L:WD`5&%I=V%N`%1A:7=A;BP@<')O=FEN8VEE(,CM;GD`5&%DOFEK:7-T
MX6X`5&%N>N%N:64L(%-P;VIE;N$@<F5P=6)L:6MA`$/M;#H`VFMO;'D`5&5L
M969O;F[M(.CM<VQO`%1E<&QO=&$@>F$@<&]S;&5D;NT@:&]D:6YU.B``5&5P
M;&]T80!497!L;W1A.B``5GIO<B!P<F\@861M:6YI<W1R86-I`%1E>'0`4&]U
M>F4@=&5X=`!:87)O=F[A;NT@=&5X='4`5G)C:"!T97AT=0#(=`!4:&%J<VMY
M("A425,M-C(P*0!4:&%J<VMO`$3L:W5J96UE('IA('!O=;[M=N%N[2!S>7-T
MZ6UU+@!0^.UP;VYA('!R;R!&5%`@;F5N[2!D;W-T=7!NX2X`26YT96=R8>AN
M[2!A;&=O<FET;7D@=B!(;W)D92]+;VQA8B!N97!O9'!O<G5J[2`B)7,B`$YE
M^G-P[+ENZ2!N8>AT96[M('3X[61Y($UA:6YT96YA;F-E.CH`0GEL;R!U>F%V
M^&5N;R!O:VYO(',@;6^^;F]S=&UI+B!5:V]NZ&5N;RX`061M:6YI<W1R[71O
M<B!P;W3X96)U:F4@;F%K;VYF:6=U<F]V870@=')V86SA('!RX79A('8@<WES
M=.EM=2P@<&]K=60@<VD@</AE:F5T92!P;W6^[70@<'+A=F$N`%!O=7IE('-P
M;V1N[2!S=')A;F$`3F5B>6QO('5V961E;F\@240@<')O(&MO;G1A:W0L(&YE
M8GEL;R!N86QE>F5N;R!V(&1A=&%BX7II(&YE8F\@8GEL;R#Z<&QN["!V>6YE
M8VCA;F\N`$MO;G1A:W0@8GEL(/IS<.RY;NP@</AI9.%N(&1O(%9AN65H;R!A
M9')E<^'X92X`2R!O=NSX96[M('!O9&5P<V%NZ2!Z<'+A=GD@:F4@=/AE8F$@
M;V1D[&QE;OT@8FQO:R!S(%!'4"!P;V1P:7-E;2X`3F5B>6QO('5V961E;F\@
M240@9&ES=')I8G7H;NUH;R!S97IN86UU+"!N96)Y;&\@;F%L97IE;F\@=B!D
M871A8N%Z:2!N96)O(&)Y;&\@^G!L;NP@=GEN96-HX6YO+@!.96)Y;"!U=F5D
M96X@9&ES=')I8G7H;NT@<V5Z;F%M+@"I:69R;W9A8^T@;6^^;F]S=&D@;'IE
M('9Y=;[M="!P;W5Z92!P^&D@8F5Z<&7H;NEM('-P;VIE;NT@<R!W96)E;2`H
M:'1T<',I+@!3;W5B;W(@)7,@8GD@;>QL(&]B<V%H;W9A="!N87-T879E;NT@
M)7,N`%-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T(&[L:W1E<N$@>B!N87-T
M879E;NT@)7,N`%-O=6)O<B!N96QZ92!K;W#M<F]V870@<^%M(&1O('-E8F4N
M`%-O=6)O<B!N96]B<V%H=6IE(+[A9&[A(&1A=&$N`$[A<VQE9'5J[2!H;&%V
M:>AK>2!P<F\@;65S<V%G92]R9F,X,C(@>G!RX79U`$IE('INX6WI+""^92!M
M\V0@</AE<R!C96QO=2!O8G)A>F]V:W4@=B!);G1E<FYE="!%>'!L;W)E<G4@
M</ES;V+M('!R;V)LZ6UY+"!P<F]T;[YE('-E('8@;NQM('9Y<VMY='5J92!C
M:'EB82P@:W1E<ND@<V4@;F5L>F4@=GEH;F]U="X@2F%K;R!NX7-L961E:R!M
M^;YE(&+]="!NX6AO9&[I('IH<F]U8V5N[2!T;VAO=&\@<')O9W)A;74L(&-H
M>6+L:NUC[2!F=6YK8V4@961I=&]R=2!N96)O(&YE<W!RX79NZ2!Z;V)R87IO
M=N%N[2X@4&]K=60@:F4@5N&Y('-Y<W1E;>EM(%=I;F]D=W,@.7@L(&IE('9E
M;&UI('!R879D['!O9&]B;NDL(+YE('-E(&]B:F5V[2!C:'EB;W;I(&ALX;EE
M;NT@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@82!B=61E=&4@;75S970@
M<F5S=&%R=&]V870@<&_H[71AZ"Y<;EQN0GEL:2!J<W1E('9A<F]VX6YI+B!0
M<F]S[6T@<W1I<VMN['1E($]+('!O:W5D('-I('#X96IE=&4@<&]K<F'H;W9A
M="!V(&WS9'4@</AE<R!C96QO=2!O8G)A>F]V:W4N`$ED96YT:71A("(E<R(@
M8GEL82!S;6%ZX6YA+@!0;W5Z92!N82!L97;I('-T<F%N[`!5;>US=.QN[2!B
M:6[A<F[M:&\@<V]U8F]R=2!';G501R!M=7/M(&+]="!Z863A;F\@9&\@=/CM
M9'D@0W)Y<'1?<&=P.CHN`%IP<N%V82!Z87-L86[A('8@)7,@:R`E<R!S('#X
M961M['1E;2`B)7,B(&)Y;&$@>F]B<F%Z96YA+@I4;W1O(&YE>F%R=>AU:F4L
M(+YE('IP<N%V82!B>6QA('#X9>AT96YA(&YE8F\@OF4@:NT@861R97/A="AK
M82D@<F]Z=6WL;"AA*2X`3N%Z978L(&MT97+](&)U9&4@<&]UOFET('#X:2!O
M9&MA>F]VX6[M(&YA('-T<N%N8V4@='9O<F)Y('IP<N%V`%3X[61A($AO<F1E
M7T-R>7!T7W-M:6UE.CH@=GF^861U:F4@;6]D=6P@;W!E;G-S;"X`3F5L>F4@
M=6QOOFET(&YA<W1A=F5N[2`B)7,B+"!P<F]T;[YE(&IE:&\@=F5L:6MO<W0@
M</AE<^%H;&$@<&]V;VQE;OT@;&EM:70N`$YE8GEL82!N86QE>F5N82!A<&QI
M:V%C92!P<F\@Z'1E;NT@=&]H;W1O('1Y<'4@9&%T("@E<RDN`%!O=7IE(&YA
M('!R87;I(&$@;&5VZ2!S=')A;NP`4&]U>F4@;F$@<')A=ND@<W1R86[L`%-E
M<G9E<B`B)7,B(&)Y;"!V>6UA>N%N+@!397)V97(@(B5S(B!B>6P@=6QOOF5N
M+@!">6QA(&]D<W1R86[L;F$@ON%D;W-T(&\@</AI:&SAN65N[2!P<F\@)7,N
M`%!OOF%D;W9A;OT@^.%D96L@;F5E>&ES='5J92X`1&_H87-N_2!S;W5B;W(@
M(B5S(B!N965X:7-T=6IE+@!0;W5Z92!N86AO^&4@82!D;VQE`%!O=7IE(&YA
M:&_X90!:=')A=&EL82!S92!P^&5N97-E;N$@9&%T82!Z('#X961C:&]Z[6AO
M(&MR;VMU+@!0^&5N97-E;OT@<V]U8F]R(&YE;'IE('5L;[YI="X`0FQO:R!W
M96%T:&5R+F-O;2!N96[M(&1O<W1U<&[]+@"NX61NZ2!Z(&UOOFYO<W3M(&YE
M:G-O=2!D;W-T=7!NZ2X`3F5B>6QY(&YA;&5Z96YY(+[A9&[I(.CA<W1I+"!K
M=&5RZ2!B>2!B>6QO(&UOOFYO('IO8G)A>FET('8@^.%D:W4N`%#X[6QIN2!M
M;F]H;R!Z;F%K^2!V('!O;&DN(%IA9&%L:2!J<W1E("5S('IN86OY.R!M=7/M
M=&4@>F%D870@;>EN["!N9;X@)7,@>FYA:_DN`$YA<W1A;&$@8VAY8F$@</AI
M('#X96YO<W4@<V]U8F]R=3H@)7,@;F5B>6P@</AE;F5S96XN`$YA<W1A;&$@
M8VAY8F$@</AI('#X96YO<W4@<V]U8F]R=2X@)7,@;F5M^;YE(&+]="!V['2Y
M[2!N9;X@;6%X:6WA;&[M('!O=F]L96[A('9E;&EK;W-T("@E9"!B>73Y*2X`
M3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U.B!B>6QA('#X96YE
M<V5N82!J96X@Z.%S="!S;W5B;W)U("5S+@!$;[EL;R!K(&-H>6+L('#X:2!Z
M;V)R87IO=N%N[2!TZ71O(.CA<W1I('IP<N%V>0!.87-T86QA(&-H>6)A('#X
M:2!I;7!O<G1O=N%N[2!K;VYT86MT=2X`4/AI(&EM<&]R=&]VX6[M(&E#86QE
M;F1A<B!D870@9&^Y;&\@:R!C:'EB["X`0VAY8F$@=B!K;VYF:6=U<F'H;NUM
M(&9O<FUU;.'X:2X@6OAE:FWL(&IS=&4@=GEN96-H86QI('!OOF%D;W9A;ND@
M<&]L92X`3F%S=&%L82!C:'EB82!P^&D@<')O=N%D[&[M('IA9&%NZ2!O<&5R
M86-E('8@861R97/A^&DN(%!R;W/M;2!Z:W5S=&4@=&\@<&]Z9.QJ:2X`3F%S
M=&%L82!C:'EB82!P^&D@86MT=6%L:7IA8VD@:V]N=&%K='4N(%!R;W/M;2!Z
M:W5S=&4@=&\@<&]Z9.QJ:2X`3F%S=&%L82!C:'EB82!P^&D@86MT=6%L:7IA
M8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+B!0<F]S[6T@>FMU<W1E('1O('!O
M>F3L:FDN`%1E;G1O($E-05`@<V5R=F5R(&YE<&]D<&]R=6IE('-D[6QE;NT@
M<VQOOF5K+@!4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[](')A<B!A<F-H:78N
M`%1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;OT@>FEP('-O=6)O<BX`5&]T;R!N
M979Y<&%DX2!J86MO('!L871NZ2#H[7-L;R!K87)T>2X`5&5N=&\@;W9L861A
MZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO8^T@0VQI8VMA=&5L;"`H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2!B<N%N>2!P^&D@<&]UOFET[2!(5%10
M($%020!496YT;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP<N%V('!O
M;6]C[2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!B<N%N>2!P
M^&D@<&]UOFET[2!(5%10($%020!496YT;R!O=FQA9&'H('5M;[[R=6IE('!O
M<^ULX6[M('IP<N%V('!O;6]C[2!33510(&1O(%9O9&%F;VYE($ET86QY(&)R
MX6YY('!O=7IE('!R;R#H[7-L82!P;W-K>71N=73I(%9O9&%F;VYE;2X@375S
M[71E(&WM="!E;6%I;&]V_2#ZZ&5T('4@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`5&]T;R!P;VQE(&IE(&YU=&[I('9Y<&QN:70N`%1O
M=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!C96SA(.CM<VQA+@!4;W1O
M('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L82!A(&1V;VIT
M9>AK=2X`5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&]S;6GH:V]V
MZ2#H[7-L82X`5&]T;R!P;VQE(&UU<^T@8OUT('-E>FYA;2!C96S]8V@@Z.US
M96P@;V1D[&QE;OUC:"#HX7)K;W4@;F5B;R!M97IE<F]U`%1O=&\@<&]L92!M
M=7/M(&+]="!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M('!B<V%H;W9A
M="!B87)E=F[](&OS9"!V(+EE<W1NX6-K;W;I;2!21T(@9F]R;>%T=2P@;F%P
M^"X@)R,Q,C,T868G+@!496YT;R!F;W)M=6SA^"!J:;X@8GEL('IP<F%C;W;A
M;BX`5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L86(@1W)O=7!W87)U
M+B!+('IH;.ED;G5T[2!T;VAO=&\@;V)J96MT=2!J92!Z87!O=/AE8NT@;>UT
M('!ON71O=F[M:&\@:VQI96YT82P@:W1E<OT@<F]Z=6WM(&9O<FWA='4@2V]L
M86(@1W)O=7!W87)U+B!0<F\@<V5Z;F%M('1A:V]V_6-H(&ML:65N=/D@<')O
M<^UM(&YA=KET:79T92`E<P!4871O('IP<N%V82!B>6QA(&YA<'/A;F$@=B!J
M:6[I('IN86MO=ND@<V%D["`H)7,I(&YEOB!68;GM+B``5&]T;R#H[7-L;R!M
M=7/M(&+]="!N96IMZ6[L(&IE9&YA+@!397)V97(@;F5M^;YE(')O>F)A;&ET
M('II<"!A(&=Z:7`@<V]U8F]R>2X`5&5N=&\@<WES=.EM(&IE('8@<V]UZ&%S
M;F]S=&D@9&5A:W1I=F]V86[]+@!4871O(&AO9&YO=&$@;75S[2!B_70@Z.US
M;&\N`%1O=&\@;VMN;R!M=;YE(&+]="!V;VSA;F\@<&]U>F4@>B!O:VYA(&UO
MOFYO<W3M`$CX;>QN[0!,[7-T:WD`R&%S`%-L961O=N%N[2#H87-U`$9O<FWA
M="#H87-U`%;]8NQR(.AA<W4`5&EM;W(M3&5S=&4`5&ET=6P`5&ET=6P@*'1I
M<"DZ`$MO;74`4&]K=60@<VD@</AE:F5T92!V>6)R870@=NUC92!P;VQOOF5K
M+"!Z;>'H:V[L=&4@:VSA=F5S=2!#;VYT<F]L("A00RD@;F5B;R!#;VUM86YD
M("A-86,I(&$@:VQI:V[L=&4@;F$@<&]L;[YK=2X`1&YE<P!0^&5P;F]U="!N
M82!(5$U,('ID<F]J`%1O9V\`5&]K96QA=0!:[71R80!4;VYG80!6<F-H`$AO
M<F[M('+A;2`H7W1O<"D`4/AE:VQA9'D`5')I;FED860@82!4;V)A9V\`4W!R
MX79N["!N96)O(+EP871N[`#:=`!4=6YI<VMO`%1U<F5C:V\`5'5R96-K>2`H
M25-/+3@X-3DM.2D`5'5R:VUE;FES=.%N`%1U<FMS(&$@0V%I8V]S(&]S=')O
M=GD`5'5V86QU`$YA<&FY=&4@5F&Y:2!V;VQB=3H`52Y6+B!I;F1E>#H@`%52
M3`!54DP@<')O('IP<N%V=2!O('-T879U('IA<VQA;NEH;R!S:W)I<'1U`%52
M3#H`56=A;F1A`%5K<F%J:6YA`%9&4R!A9')E<^'X(&IE(&YE</CM<W1U<&[]
M+@!0^&D@<F5G:7-T<F%C:2!N96QZ92!P^&ED870@97AT<F$@=;YI=F%T96QS
M:^D@^F1A:F4N`$YE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B`B
M)7,B+@!.96QZ92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@)7,O)7,N
M`$YE;'IE('IM[&YI="!N82`E<RX`3F5L>F4@<V4@</AI<&]J:70@:R!344P@
M<V5R=F5R=2X`3F5L>F4@<V4@</AI<&]J:70@<&]M;V/M(%-33"X`3F5L>F4@
M:V]P[7)O=F%T(%9&4R!S;W5B;W(N`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E
M<^'X("(E<R(N`$YE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X+@!.96QZ92!V
M>71V;_AI="!61E,@<V]U8F]R+@!.96QZ92!V>71V;_AI="!P<N%Z9&[](%9&
M4R!S;W5B;W(N`$YE;'IE(')O>F)A;&ET(&1A=&$N`$YE;'IE('9Y;6%Z870@
M(B5S(BP@<')O=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2X`3F5L>F4@=GEM
M87IA="`E<RP@<')O=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2X`3F5L>F4@
M<F5K=7)Z:7;L(&]D<W1R86YI="!61E,@861R97/A^"X`3F5L>F4@=GEM87IA
M="!61E,@861R97/A^"X`3F5L>F4@=GEM87IA="!61E,@861R97/A^#H@)7,N
M`$YE;'IE('9Y;6%Z870@5D93('-O=6)O<B`B)7,B+@!.96QZ92!V>6UA>F%T
M(%9&4R!S;W5B;W(N`$YE;'IE(')E:W5R>FEV;NP@;V1S=')A;FET(%9&4SH@
M)7,N`$YE;'IE('5RZ&ET(&%K='7A;&[M(&%D<F5SX?@N`$YE;'IE('IJ:7-T
M:70@<&]D<F]B;F]S=&D@;R!C97)T:69I:^%T=2X`1&5F:6YI8V4@)7,@;F5N
M[2!D;W-T=7!NX2X`3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(N`$YE;'IE
M('#X97-U;F]U="!61E,@<V]U8F]R("(E<R(N`%9&4R!S;W5B;W(@;F5L>F4@
M;W1E=OCM="!P<F\@>N%P:7,N`$YE;'IE(&]T97;X[70@5D93('-O=6)O<BX`
M3F5L>F4@;W1E=OCM="!A<F-H:79O=F%N_2!S;W5B;W(N`$YE;'IE(.CM<W0@
M>B!V9G-R;V]T(&%D<F5SX?AE+@!.96QZ92!P^&5J;65N;W9A="`E<R!N82`E
M<SH@8^UL;W;A('-L;[YK82!J:;X@97AI<W1U:F4`5D93(&%D<F5SX?@@;F5L
M>F4@</AE:FUE;F]V870N`%9&4R!A9')E<^'X(&YE;'IE('#X96IM96YO=F%T
M.B`E<RX`3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<B`B)7,B+@!.96QZ
M92!P^&5J;65N;W9A="!61E,@<V]U8F]R("5S+R5S+@!.96QZ92!P^&5J;65N
M;W9A="!61E,@<V]U8F]R+@!.96QZ92!P<F]VZ7-T("=M:VES;V9S)RX`5&5N
M=&\@9&]K=6UE;G0@5V]R9"!N96QZ92!P^&5L;[YI=`!.96QZ92!Z87!S870@
M9&\@5D93('-O=6)O<G4@(B5S(BX`3F5L>F4@>F%P<V%T(&1A=&$@9&\@5D93
M('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2X`3F5L>F4@>F%P<V%T(&1A=&$@
M9&\@5D93('-O=6)O<G4`4&]D=')H;G5TZ0!3=&]R;F\@>FWL;@!3=&]R;F]V
M870@<&]S;&5N[2!A:V-I`$YE;^AE:^%V86[A(&]D<&]V[.\@<V5R=F5R=2!N
M82!S<&]J96[M.B``3F5OZ&5KX79A;N$@;V1P;W;L[R!S97)V97)U.B``3F5V
M>7!L;NQN;P!5;FEC;V1E("A55$8M."D`4W!O:F5NZ2!!<F%B<VOI($5M:7+A
M='D`5F5L:^$@0G)I=.%N:64`4W!O:F5NZ2!3=.%T>2!!;65R:6-KZ0!3<&]J
M96[I(%-TX71Y($UE;KEI;F]V_6-H(&]S=')O=OD`2F5D;F]T:WD`3F5Z;N%M
MZ0!.97INX6WI(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`$YE>F[A;>D@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`3F5Z;N%MZ2!UOFEV871E
M;'-KZ2!J;>EN;R!N96)O(&AE<VQO+@!/9'!O:FET('-O=>AA<V[]('!R=F5K
M`$)E>F4@:FWI;F$`3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M;VAO=2!V
M>76^[79A="!F=6YK8V$@5GEJ;6]U="]+;W#M<F]V870O5FQOOB!Z(&)E>G!E
MZ&YO<W1N[6-H(&3Y=F]D^2X@2VQI:V[L=&4@;F$@3TL@86)Y<W1E('9I9.QL
M:2!T96-H;FEC:V]U('IP<N%V=2!Z(&UO>FEL;&$N;W)G+"!K=&5RX2!V>7-V
M['1L=6IE+"!J86L@;F%S=&%V:70@<VMR:7!T('!R;R!P^.US='5P(&ME('-C
M:'+A;F-E+@!.96YA<W1A=F5NX2!B87)V80!.97!O9'!O<F]V86[A('#X[7!O
M;F$`06MT=6%L:7IO=F%T`$%K='5A;&EZ;W9A="`E<P!!:W1U86QI>F]V870@
M=;YI=F%T96QE`%-K<FEP="!P<F\@86MT=6%L:7IA8VD@8GEL('9Y;6%ZX6XN
M`%#X96YO<P!6N65C:&YY('-O=6)O<GD@<')O(&YA<W1A=F5N[2!A<&QI:V%C
M[2!B>6QY('#X96YE<V5N>2!N82!S97)V97(N`%9E;&OA('1I<VMA8^T@<.US
M;65N80!696QKZ2#X[6US:^D@Z.US;&EC90!5<G5G=6%Y`%!O=;[M="!A:W1U
MX6QN[3H@)7,`4&]UONUT(%-33`!0;W6^[70@<&]K=60@:FWI;F\O:&5S;&\@
M:G-O=2!J:6[I(&YEOB!P<F\@24U34"!S97)V97(N`%6^:79A=&5L("5S(&YE
M;NT@;W!RX79N[&X@:R!P;W6^[7;A;NT@)7,N`$%D;6EN:7-T<F%C92!UOFEV
M871E;/D`5;YI=F%T96QS:^D@;6^^;F]S=&D`4F5G:7-T<F%C92!UOFEV871E
M;/D`3F$@=&]M=&\@<V5R=F5R=2!N96[M(&UOOF[A(')E9VES=')A8V4@=;YI
M=F%T96SY+@!5OFEV871E;'-KZ2!J;>EN;P!5OFEV871E;'-KZ2!J;>EN;SH`
M5;YI=F%T96QS:^D@:FWI;F\Z(`!397IN86T@=;YI=F%T96SY.@!5>F)E:VES
M=.%N`%9&4R!A9')E<^'X(&YE97AI<W1U:F4N`$1O=F]L96[A`$YA;&5Z96[A
M('!L871NX2!M[7-T82!Z86AR;G5J[3H@`%!L871N;W-T`$AO9&YO=&$@=B!M
M:6YU=.%C:"X`2&]D;F]T>0!6>6)R86[I(&AO9&YO='D@>@!686YU871U`%!R
M;VWL;F[I`%9E;F5Z=65L80!396QH86QA('9E<FEF:6MA8V4@+2!T871O('IP
M<N%V82!M;VAL82!B_70@>F9A;+EO=N%N82X`5F5R>F4`5F5R<VEO;B!#;VYT
M<F]L`%9E<G1I:^%L;NT@>F%R;W9NX6[M`%9E<G1I:^%L;NT@;V1S='5P`%9E
M<G1I:^%L;NTZ`%9E;&UI('9Y<V]KX0!6:65T;F%M`%9I971N86US:WD@*%9)
M4T-)22D`6F]B<F%Z:70@)7,`6F]B<F%Z:70@97AT97)N[2!W96)S='+A;FMU
M`%IO8G)A>FET(&IA:V\@)7,`4&%N;F5N<VOI($]S=')O=GDL($)R:71S:^D`
M4&%N;F5N<VOI($]S=')O=GDL(%4N4RX`5FED:71E;&YO<W0`5FED:71E;&YO
M<W0Z`%9O9&%F;VYE($ET86QY('#X97,@4TU44`!54$]:3U).250`55!/6D]2
M3LQ.S2$A(2!/1%-44D'25$4@4TM225!4(%)5R$[,(%H@)7,N`%=A;&QI<R!A
M;F0@1G5T=6YA`%5P;WIO<F[L;NT`4W0`4/AE9'!O=NSO('!OZ&%S[0!$871A
M(&\@<&_H87/M('!O<VMY='5J90!796%T:&5R+F-O;0!796(`5V5B('-E<G9E
M<@!4_61N[`!6[71E:G1E`%;M=&5J=&4@=B`E<P!6[71E:G1E+"`E<P!:X7!A
M9&[M("A)4T\M.#@U.2TQ*0!:X7!A9&[M("A)4T\M.#@U.2TQ-2D`6N%P861N
M[2!386AA<F$`2W1E<F]U(&%P;&EK86-I(&WA("5S('IO8G)A>FET('!O('#X
M:6ALX;EE;NT@9&\@<WES=.EM=3\`2F%K_2!J92!O9&3L;&]V86/M('IN86L_
M`$IA:_T@:F4@>FYA:R!P<F\@8VET86-I/P!+=&5RZ2!FX7IE`%9O;&)A(')O
M>KGM^&5N[2!P<F\@4FEC:"!497AT(&5D:71O<BX`J>WX:V$`J>WX:V$@=B!#
M4U,@:F5D;F]T:^%C:`"I[?AK82`E<R!M96YU('9L979O("AZ;>QN82!S92!O
M8FIE=NT@</AI(&1A;+GM;2!P^&EH;.&Y96[M*3H`J>WX:V$@=&%B=6QK>0!*
M961N;W1K82"Y[?AK>0"I[?AK83H`5VEK:0!6[71R`%)A;F[M(';M='(`4GEC
M:&QO<W0@=NQT<G4@=B!U>FQE8V@`5NUT<CH`5NUT<CH@`$UO=61R;W-T`%!R
MX6-E`$%D<F5S82!D;R!Z86WL<W1NX6[M`%1E;&5F;VX@9&\@>F%M['-T;N%N
M[0!8+5)E9@!8-3`Y=C,@>N%K;&%D;NT@;VUE>F5N[0!8-3`Y=C,@<F]ZN>WX
M96[I('!O=;YI=.T@:VSMZ&4`6#4P.78S(&%L=&5R;F%T:79N[2!J;>EN;R!O
M<V]B>0!8-3`Y=C,@:61E;G1I9FEKX71O<B!K;.WH90!8-3`Y=C,@<F]ZN>WX
M96[M`%)2`%)24E(`36%P82!986AO;R$`4F_H;NP`2F5M96X`06YO`$%N;RP@
M<V]U:&QA<^UM`$IS=&4@=B!415A43U;)32!-TT15+B!0;W6^:6IT92!;/#Y=
M('1L8>CM=&MA(&L@>G#L=&[I;74@</AE<&YU=.T@9&\@5UE325=91RX`3F5B
M>6QI(&IS=&4@<W!RX79N["!O=NSX96YI+@!:;F%K("=<)R!N96WYOF4@8OUT
M('-O=>CA<W3M(%9AN65H;R!J;>EN82X`0GEL82!Z863A;F$@;F5P;&%T;N$@
M92UM86EL;W;A(&%D<F5S82X`3F5M87!O=F%L:2!J<W1E(+[A9&[A('!O;&4@
M>B!I;7!O<G1O=F%NZ6AO('-O=6)O<G4@:R!O9'!O=NUD86KM8^UM('!O;.UM
M('8@)7,N`$)Y;&D@:G-T92!O9&ALX;EE;FD@>F4@<WES=.EM=2X`5FQOOG1E
M(.CM<VQO(&UO8FEL;NUH;R!T96QE9F]N=2P@<&]UOFEJ=&4@:F5N(.CM<VQI
M8R!N96)O('#X[7!A9&[L("<K)R!P<F\@;65Z:6[A<F]D;NT@Z&ES;&$N`$UU
M<^UT92!Z861A="!P;&%T;F]U(&AO9&YO='4N`$UU<^UT92!K;VYF:6=U<F]V
M870@9&%T86+A>FD@9&%T+"!P;VMU9"!S:2!P^&5J971E('!O=;[M=F%T(%)E
M9VES=')A8V4N`$UU<^UT92!K;VYF:6=U<F]V870@5D93(&)A8VME;F0N`$UU
M<^UT92!N96ID^.UV92!P;W!S870@<')O8FSI;2!A('!O=.D@:&\@;V1E<VQA
M="X`375S[71E('IA9&%T(%523"!N82!K=&5RZ2!B=61E('1E;G1O(&]D:V%Z
M('5K87IO=F%T`$UU<^UT92!V>6)R870@<V5R=F5R+"!K=&5R_2!B=61E('-M
M87KA;BX`375S[71E('9Y8G)A="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@
M8G5D92!S;6%ZX6YO+@!-=7/M=&4@>F%D870@=;YI=F%T96QS:^D@:FWI;F\L
M(&MT97+I(&)U9&4@;V1S=')A;NQN;RX`3F5U=F5D;&D@:G-T92!UOFEV871E
M;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!P^&EDX6YO+@!.975V961L:2!J<W1E
M('6^:79A=&5L<VOI(&IMZ6YO('!R;R!A:W1U86QI>F%C:2X`375S[71E('IA
M9&%T(&%K8VDL(&MT97+A(&)U9&4@<')O=F5D96YA+@!-=7/M=&4@>F%D870@
M:FWI;F\@;F]VZ2!K871E9V]R:64N`%9AN64@)7,@<F5L86-E(&)Y;&$@=6MO
M;NAE;F$N($]P['0@<V4@</AI:&QAN71E+"!P<F]S[6TN`%9AN64@96UA:6QO
M=N$@861R97-A`%9AN64@3V0M:V]H;SH@861R97-A.@!68;EE(&EN9F]R;6%C
M90!6(')E;&%C:2`E<R!S92!Z;>QN:6QA(%9AN64@:6YT97)N971O=N$@861R
M97-A+B!:(&)E>G!EZ&YO<W1N[6-H(&3Y=F]D^2!S92!M=7/M=&4@;W#L="!P
M^&EH;.%S:70N`%9AN64@:FWI;F\`5N&Y(&]V[/AO=F%C[2!S>7-TZ6T@;F5P
M;V1P;W)U:F4@=OUP:7,@=;YI=F%T96SY(&%N96)O('1A=&\@;6^^;F]S="!N
M96[M('#X[7-T=7!NX2!Z(&II;OUC:"!D^79O9/DN`%IDX2!S92P@OF4@=B!P
M<OEB[&AU(')E;&%C92`E<R!S92!Z;>QN:6P@5N&Y('!R;VAL[;YEZ"X@6B!B
M97IP9>AN;W-T;NUC:"!D^79O9/D@<V4@;75S[71E(&]P['0@</AI:&SA<VET
M+@!6X;D@<')O:&SMOF7H(&YE<&]D<&]R=6IE('1U=&\@;6^^;F]S="X`5F&Y
M92!S;W7H87-NZ2#H87-O=ND@<.%S;6\Z`%9AN64@:6UP;&EC:71N[2!I9&5N
M=&ET80!68;EE(/IP;&[I(&IMZ6YO.@!68;EE(&YO=ND@:&5S;&\@<')O("5S
M(&IE.B`E<P!68;EE(&YA<W1A=F5N[2!B>6QO(&%K='5A;&EZ;W;A;F\@<')O
M('1R=N%N[2!TZ71O(')E;&%C92X`5F&Y92!N87-T879E;NT@8GEL;R!A:W1U
M86QI>F]VX6YO+@!68;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RX`5F&Y92!H
M97-L;R!B>6QO(')E<V5T;W;A;F\L('IK;VYT<F]L=6IT92!S:2!Z<'+A=GD@
M96QE:W1R;VYI8VOI('!ON71Y(&$@</AI:&QAN71E('-E(',@5F&Y[6T@;F]V
M_6T@:&5S;&5M+@!68;EE('9Z9.%L96[I('-E<G9E<GDZ`$IU9V]S;.%V:64`
M6F%I<@!:86UB:64`6FEM8F%B=F4`6FEP<'D`6U5K<OUT(&-I=&]V86[]('1E
M>'1=`%M(;.&Y96[M('!R;V)LZ6UU70!;6F]B<F%Z:70@8VET;W9A;OT@=&5X
M="`M`%M:;V)R87II="!C:71O=F%N_2!T97AT("T@)7,@^.%D:_E=`%OXX61E
M:R`E<R!Z("5S70!?061M:6YI<W1R86-E`%]#3$D`7T1A=&%4<F5E`%]3;6%Z
M870@^.%D96L`7U-K=7!I;GD`7T[A<&]V[&1A`%]6;&%S=&YO<W1I(&]B<N%Z
M:W4N+BX`7U#X:6ALX;EE;NT`7T]D:&SAN65N[0!?36]D:69I:V]V870@;V1K
M87HN+BX`7TUOOFYO<W1I`%]0<N%V80!?3V1S=')A;FET(&]D:V%Z+BXN`%].
M87-T879E;NT`7U9L87-T;F]S=&D@=&%B=6QK>2XN+@!?5;YI=F%T96SI`&%D
M<F5SX?@`:V%L96YDX?@`8F5Z=NQT^.T`:VQI:VYO=70@>F1E`'-RX;YK>0!S
M;W5B;W(`>B`E<R`H)7,I(')Y8VAL;W-T[2`E<R`E<P!H.@!O:V%MOFET[`!V
M(/AA9.P`^.%D:_E=`&-H>6)O=OT@:_-D(&UK:7-O9G,@)60@</AI('9Y=';A
M^&5N[2!)4T\N`&IMZ6YO`&YE;NT@:6UP;&5M96YT;W;A;F\`;F5N[2!D;W-U
M9"!I;7!L96UE;G1O=N%N;P!ZX7!I<V[M:P!P<F]C96YT`'!I>&5L^0!S=&]U
M<&%J[6/M`'IO8G)A>FET(')O>F3M;'D`<VUS,F5M86EL('IA('!O=;YI=.T@
M2%144`!V>71R=F%LZ0!S97IN86T@^FMO;/D`<')O('!O='9R>F5N[2!N87!I
MN71E(&AE<VQO(&1V86MRX70`<VIE9&YO8V5N_0!B97H@;N%Z=G4`=GEB<F%T
M('6^:79A=&5L90!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]C<U]#6B]H96QP+GAM;```````````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,R-C$`,3`U,34T,S$P-C$`,#(P,S(Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3(B/SX*/"$M+2`D2&]R
M9&4Z(&AO<F1E+VQO8V%L92]C<U]#6B]H96QP+GAM;"QV(#$N-B`R,#`T+S`X
M+S$X(#`X.C0R.C4Q(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED
M/2)S=6UM87)Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-CAC83,S9C=F,&,Y
M86%E-&,Q,#-E8C0W-#DR8V1C,34B/@H\=&ET;&4^4&]R=.%L/"]T:71L93X*
M(#QP87)A/@H@(%-T<N%N:V$@4&]R=.%L=2!P;W-K>71U:F4@<W1R=>AN_2!P
M^&5H;&5D(':Y96-H(&3Y;&6^:73]8V@@:6YF;W)M86/M+@H@($YA</CM:VQA
M9"!M^;YE('IO8G)A>F]V870@<&_H970@96UA:6SY+"!I;F9O<FUA8VD@;R!S
M8VCY>FOA8V@@=F4@5F'L96T@:V%L96YDX?AI+`H@(/IK;VQE8V@L(&%T9"X@
M5NQTN6EN82!T[&-H=&\@:6YF;W)M8^T@<&]S:WET=6KM(&QI;FMY(&L@8NR^
M;OUM(&9U;FMC[6TL(`H@(&IA:V\@;F%P^.UK;&%D('9Y='9O^&5N[2!N;W;I
M(&5M86EL;W;I('IP<N%V>2P@=GET=F_X96YM[2!N;W;I('-C:/EZ:WDL(&%T
M9"X*(#PO<&%R83X*(#QP87)A/@H@(%)O>G9ROF5N[2!TZ71O('-T<N%N:WD@
M<&]R=.%L=2!L>F4@;F%S=&%V:70@<&]M;V/M('1L8>CM=&MA(%)O>FQOOF5N
M[2X*("!.87#X[6ML860L(&WYOF5T92!S:2!V>6)R870L(&MT97+I('!R=FMY
M('-I('#X96IE=&4@>F]B<F%Z:70@82!T86OI('8@:F%KZ6T*("!P;_AA9.TN
M(`H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W
M.#)F-#<B/@H\=&ET;&4^3F%V:6=AZ&[M($QIN71A('!R;R!!<&QI:V%C93PO
M=&ET;&4^"B`\<&%R83X*("!.879I9V'H;NT@;&FY=&$@:F4@=6WM<W1N[&YA
M('9L979O(&YA('=E8G-T<N%N8V4N($ML:6MN['1E(&YA(&EK;VYK>0H@('3I
M=&\@;&FY='D@<&]S:WET=6KM8^T@</AE:&QE9&[L:KGM(&$@<GEC:&QE:KGM
M('#X97#M;N%N[2!M97II(&%P;&EK86-E;6DN"B`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P
M=&]D871E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P
M(CX*("`@(#QT:71L93Y.87-T879E;NTZ(-ID<KYB83H@4')O=NES="#:9'*^
M8G4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!/>FYAZ'1E('1E;G1O('+A;67H
M96LL('!O:W5D('-I('#X96IE=&4@<')O=NES="!O<&5R86-E(/ID<KYB>2!P
M^&D*("`@('#X:6ALX;EE;NT@9&\@<WETZ6UU+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@
M<W1A=&4](G5P=&]D871E(B!M9#4](F$R,3$V,F-D9F8S8C%D.&9A96%D8C<R
M.38R-#`P,S9E(CX*("`@(#QT:71L93Y.87-T879E;NTZ(-ID<KYB83H@4&]T
M=G)D:70@VF1ROF)U/"]T:71L93X*("`@(#QP87)A/@H@("`@3WIN8>AT92!T
M96YT;R!RX6UEZ&5K+"!P;VMU9"!S:2!P^&5J971E('!O='9R9&ET(':Y96-H
M;GD@;W!E<F%C92#Z9'*^8GD*("`@(&YEOB!S92!P<F]V961O=2X@4&]K=60@
M=&5N=&\@<N%M9>AE:R!Z^7-T86YE(&YE;WIN8>AE;OTL('!O=/AE8F[I(&]P
M97)A8V4@"B`@("!S92!P<F]V961O=2!A=71O;6%T:6-K>2!B97H@;6^^;F]S
M=&D@<W1O<FYA+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O96Q?1U(O````````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8S-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]E;%]'4B],0U]-15-304=%4R\`````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`
M,#(P-#(T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5L7T=2+TQ#
M7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,U
M-S<Q,0`Q,#4Q-30S,3`V,0`P,C(P-S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````WA($E0`````+!@``'````'0P```/"```
MS&`````````(@0``)0````F!``!(````+X$```X```!X@0``#P```(>!```-
M````EX$```@```"E@0``"P```*Z!```,````NH$```0```#'@0``#````,R!
M```/````V8$```L```#I@0``$0```/6!```.````!X(``"@````6@@``"```
M`#^"```*````2((``!4```!3@@``$@```&F"```+````?((``!0```"(@@``
M)@```)V"```G````Q((``"8```#L@@``#@```!.#```*````(H,``"<````M
M@P``(````%6#```.````=H,``!<```"%@P``(@```)V#```U````P(,``!$`
M``#V@P``#0````B$```,````%H0```T````CA```&P```#&$```M````380`
M`!T```![A```)````)F$```I````OH0``!D```#HA```#P````*%```8````
M$H4```P````KA0``#@```#B%```.````1X4```@```!6A0``(@```%^%```:
M````@H4``#(```"=A0``.````-"%``!4````"88``%$```!>A@``6@```+"&
M``!7````"X<``#0```!CAP``!0```)B'```1````GH<```@```"PAP``"0``
M`+F'```)````PX<```X```#-AP``"````-R'```E````Y8<``"`````+B```
M$````"R(```/````/8@```H```!-B```!P```%B(```#````8(@```\```!D
MB```%````'2(```)````B8@```T```"3B```$@```*&(```9````M(@``!X`
M``#.B```#P```.V(```*````_8@```\````(B0``"````!B)```D````(8D`
M`!<```!&B0``%````%Z)```6````<XD```@```"*B0``3@```).)```M````
MXHD``!D````0B@``!P```"J*```,````,HH``"P````_B@``#@```&R*```.
M````>XH``!8```"*B@``!0```*&*```%````IXH```H```"MB@```P```+B*
M```7````O(H```H```#4B@``#P```-^*```.````[XH``!@```#^B@``(P``
M`!>+```.````.XL``!0```!*BP``%P```%^+```7````=XL``!<```"/BP``
M$P```*>+```/````NXL``!\```#+BP``$0```.N+```1````_8L```\````/
MC```!@```!^,```+````)HP``!`````RC```%0```$.,```5````68P```<`
M``!OC```!0```'>,```.````?8P``!$```",C```#````)Z,```[````JXP`
M`#@```#GC````P```""-```)````)(T``#D````NC0``$@```&B-```/````
M>XT``#D```"+C0``)P```,6-```L````[8T``"H````:C@``)0```$6.```)
M````:XX```H```!UC@``!@```(".```5````AXX``!D```"=C@``*0```+>.
M```D````X8X``!$````&CP``$0```!B/```*````*H\``!`````UCP``%@``
M`$:/```6````78\```0```!TCP``)P```'F/```(````H8\```@```"JCP``
M*0```+./```.````W8\```H```#LCP``!````/>/```'````_(\```0````$
MD```!@````F0```-````$)```!<````>D````P```#:0```3````.I````@`
M``!.D```$````%>0```)````:)````0```!RD```00```'>0```@````N9``
M``8```#:D```%0```.&0```8````]Y```"(````0D0``+@```#.1```=````
M8I$``"$```"`D0``5````**1```I````]Y$```<````AD@``%0```"F2```*
M````/Y(```\```!*D@``#0```%J2```/````:)(```T```!XD@``"0```(:2
M```&````D)(``!,```"7D@``%````*N2```,````P)(```8```#-D@``#P``
M`-22``!4````Y)(```0````YDP``#@```#Z3``!$````39,```T```"2DP``
M$P```*"3```1````M),``!$```#&DP``$0```-B3```<````ZI,``"H````'
ME```$P```#*4```A````1I0```4```!HE```$P```&Z4```2````@I0```H`
M``"5E```#P```*"4```1````L)0```H```#"E```$0```,V4```,````WY0`
M`!````#LE```$0```/V4```%````#Y4```P````5E0``$````"*5```%````
M,Y4```T````YE0``!@```$>5```'````3I4```T```!6E0``!P```&25```+
M````;)4```<```!XE0``"0```("5```4````BI4```D```"?E0``"@```*F5
M```9````M)4``#T```#.E0``'0````R6```=````*I8```P```!(E@``$```
M`%66```2````9I8``!,```!YE@``*P```(V6```[````N98``"````#UE@``
M#@```!:7```V````)9<``!````!<EP``&P```&V7```(````B9<```0```"2
MEP``#@```)>7```>````II<``!L```#%EP``(0```.&7```>`````Y@``!D`
M```BF```'@```#R8```;````6Y@``"X```!WF```)@```*:8```;````S9@`
M`!X```#IF```'`````B9```F````)9D``"L```!,F0``,P```'B9```F````
MK)D``"L```#3F0``.````/^9```=````.)H``!4```!6F@``+P```&R:```2
M````G)H``"````"OF@``*0```-":```>````^IH``!(````9FP``H@```"R;
M```6````SYL``",```#FFP``*`````J<```I````,YP``"@```!=G```'P``
M`(:<```5````IIP``"````"\G```)0```-V<```H`````YT``"T````LG0``
M,````%J=``"2````BYT``"$````>G@``%@```$">```<````5YX``"8```!T
MG@``*@```)N>``!!````QIX``$0````(GP``#````$V?```'````6I\```<`
M``!BGP``!@```&J?```-````<9\``!````!_GP``$@```)"?```3````HY\`
M`!(```"WGP``!P```,J?```-````TI\```P```#@GP``#@```.V?```/````
M_)\``!,````,H```#0```""@```H````+J````,```!7H```#0```%N@```"
M````::````4```!LH```!````'*@```0````=Z```!8```"(H```!````)^@
M```-````I*````X```"RH````P```,&@```.````Q:````@```#4H```#P``
M`-V@```(````[:````\```#VH```!P````:A```-````#J$``!`````<H0``
M$P```"VA```3````0:$```L```!5H0``$0```&&A```)````<Z$```8```!]
MH0``#````(2A```1````D:$``!D```"CH0``"P```+VA```-````R:$``"(`
M``#7H0``&P```/JA```T````%J(```H```!+H@``&````%:B```9````;Z(`
M`!8```")H@``+P```*"B```B````T*(```T```#SH@``#`````&C```F````
M#J,``!0````UHP``"P```$JC```B````5J,``"\```!YHP``"P```*FC```)
M````M:,``!D```"_HP``"P```-FC```7````Y:,``!<```#]HP``"0```!6D
M```6````'Z0```\````VI```%@```$:D```.````7:0``!@```!LI```#0``
M`(6D```F````DZ0``$,```"ZI```"````/ZD```+````!Z4``"\````3I0``
M#@```$.E```%````4J4```0```!8I0``"@```%VE```*````:*4```\```!S
MI0``$````(.E```7````E*4``!$```"LI0``%P```+ZE```9````UJ4```\`
M``#PI0``"@````"F```%````"Z8```T````1I@``&P```!^F```7````.Z8`
M``D```!3I@``#@```%VF```-````;*8``!(```!ZI@``.````(VF```@````
MQJ8```,```#GI@``"````.NF```.````]*8``'L````#IP``&````'^G```%
M````F*<``!@```">IP``&0```+>G```3````T:<```8```#EIP``!@```.RG
M```0````\Z<```\````$J```$````!2H```/````):@```L````UJ```#P``
M`$&H```,````4:@```\```!>J```!P```&ZH```&````=J@```X```!]J```
M(````(RH```=````K:@```P```#+J```*````-BH```/`````:D```@````1
MJ0``"````!JI```3````(ZD``!X````WJ0``(0```%:I```@````>*D``!D`
M``"9J0``%P```+.I```E````RZD``!<```#QJ0``0@````FJ```$````3*H`
M``P```!1J@```P```%ZJ```(````8JH```H```!KJ@``#````':J```+````
M@ZH``!````"/J@``#````*"J```3````K:H``!0```#!J@``#````-:J```)
M````XZH```X```#MJ@``"P```/RJ```;````"*L```<````DJP``"@```"RK
M```-````-ZL```D```!%JP``!````$^K```%````5*L```,```!:JP``&```
M`%ZK```*````=ZL```0```""JP``)@```(>K```5````KJL```4```#$JP``
M!P```,JK```,````TJL```@```#?JP``"@```.BK```&````\ZL```@```#Z
MJP```@````.L```&````!JP``!4````-K```#P```".L```1````,ZP``!H`
M``!%K```!````&"L```)````9:P``!````!OK```$0```("L```)````DJP`
M``D```"<K```&@```*:L```(````P:P```H```#*K```#@```-6L```"````
MY*P```8```#GK```$@```.ZL```4`````:T``!T````6K0``$0```#2M```&
M````1JT``!$```!-K0``$0```%^M```)````<:T``!X```![K0``!@```)JM
M```$````H:T``!$```"FK0``!@```+BM```*````OZT``!$```#*K0``(@``
M`-RM```$````_ZT``"4````$K@``!0```"JN```$````,*X```P````UK@``
M"@```$*N```%````3:X```L```!3K@``#````%^N```.````;*X``"````![
MK@``#P```)RN```2````K*X```L```"_K@``)@```,NN```I````\JX``"0`
M```<KP``)@```$&O```(````:*\```H```!QKP``"0```'RO```@````AJ\`
M`"````"GKP``)@```,BO```%````[Z\```H```#UKP``&0````"P```I````
M&K```!8```!$L```!@```%NP```2````8K````H```!UL```#````("P```/
M````C;```!````"=L```0````*ZP``!P````[[```&8```!@L0``#@```,>Q
M```)````UK$``!(```#@L0``$P```/.Q```,````![(```8````4L@``!@``
M`!NR```.````(K(```\````QL@``$@```$&R```0````5+(```H```!EL@``
M$0```'"R```<````@K(``",```"?L@``:@```,.R```/````+K,``!`````^
MLP``!````$^S```+````5+,``!0```!@LP``#````'6S```,````@K,```\`
M``"/LP``%0```)^S```I````M;,``"H```#?LP``)@````JT```G````,;0`
M`"D```!9M```*@```(.T```9````KK0``$(```#(M```$0````NU```2````
M';4``!,````PM0``%````$2U```/````6;4``!8```!IM0``%P```("U```0
M````F+4``!$```"IM0``-````+NU```3````\+4``!(````$M@``-0```!>V
M```4````3;8```<```!BM@``#````&JV```K````=[8``"````"CM@``%```
M`,2V```1````V;8``!<```#KM@``'`````.W```3````(+<``!$````TMP``
M&@```$:W```>````8;<``!H```"`MP``$0```)NW```7````K;<``!0```#%
MMP``%P```-JW```5````\K<```D````(N```!@```!*X```'````&;@```0`
M```AN```!````":X```'````*[@```X````SN```#````$*X```,````3[@`
M``T```!<N```$````&JX```1````>[@``!````"-N```#@```)ZX```1````
MK;@``"@```"_N```#P```.BX```.````^+@```P````'N0``#P```!2Y```*
M````)+D```@````ON0``"0```#BY```K````0KD```0```!NN0``"P```'.Y
M```.````?[D```<```".N0``#@```):Y```)````I;D```P```"ON0``#0``
M`+RY```.````RKD``!8```#9N0``$0```/"Y```#`````KH```8````&N@``
M&0````VZ```$````)[H```L````LN@``"P```#BZ```(````1+H```X```!-
MN@``!````%RZ```/````8;H``#H```!QN@``!0```*RZ```,````LKH``!X`
M``"_N@``#@```-ZZ```0````[;H```L```#^N@``&@````J[```*````);L`
M``P````PNP``#P```#V[```(````3;L```8```!6NP``!P```%V[```+````
M9;L``%P```!QNP``#0```,Z[```&````W+L```D```#CNP``!````.V[```#
M````\KL``!,```#VNP``$P````J\```3````'KP```(````RO```!0```#6\
M```$````.[P```H```!`O```#0```$N\``!H````6;P```8```#"O```&```
M`,F\```1````XKP```4```#TO```!@```/J\```;`````;T``"\````=O0``
M#P```$V]```3````7;T``!L```!QO0``&````(V]```7````IKT```X```"^
MO0```P```,V]```4````T;T``!,```#FO0``$````/J]```-````"[X```X`
M```9O@``%@```"B^```'````/[X```4```!'O@``"@```$V^```+````6+X`
M``<```!DO@``40```&R^```0````OKX```P```#/O@``#0```-R^```:````
MZKX``$H````%OP``!@```%"_```:````5[\```8```!ROP``!@```'F_```)
M````@+\``!@```"*OP``%P```*._```&````N[\```T```#"OP``(@```-"_
M``!7````\[\``!,```!+P```(P```%_````3````@\````(```"7P```"P``
M`)K````(````IL````T```"OP```"@```+W````*````R,````X```#3P```
M!P```.+````3````ZL````L```#^P```"0````K!```)````%,$```H````>
MP0``!P```"G!```)````,<$```<````[P0``&P```$/!```2````7\$```H`
M``!RP0``"0```'W!```0````A\$```H```"8P0``$````*/!```2````M,$`
M``0```#'P0``#````,S!```'````V<$```4```#AP0``#````.?!```(````
M],$```P```#]P0``%`````K"```7````'\(``!,````WP@``!````$O"```*
M````4,(```0```!;P@``"0```&#"```*````:L(```P```!UP@```@```(+"
M```X````A<(``"P```"^P@``$@```.O"```I````_L(``#(````HPP``"@``
M`%O#```V````9L,``"P```"=PP``+@```,K#```S````^<,``#P````MQ```
M.@```&K$```[````I<0``#,```#AQ```/@```!7%```X````5,4```\```"-
MQ0``&````)W%```0````ML4```\```#'Q0``$P```-?%```4````Z\4``!(`
M````Q@``%````!/&```5````*,8``!,````^Q@``'0```%+&```(````<,8`
M``@```!YQ@``*P```(+&```A````KL8``!H```#0Q@``"0```.O&``!%````
M]<8``$$````[QP``#P```'W'```$````C<<``!,```"2QP``$P```*;'```)
M````NL<```H```#$QP``#P```,_'```0````W\<```<```#PQP``#@```/C'
M```%````!\@```T````-R```!P$``!O(```&````(\D``!L````JR0``!@``
M`$;)```C````3<D```@```!QR0``!@```'K)```4````@<D``!$```"6R0``
M)@```*C)```.````S\D``#@```#>R0``!@```!?*```.````'LH``!H````M
MR@``!0```$C*```'````3LH```X```!6R@``!@```&7*```,````;,H``"D`
M``!YR@``%P```*/*```?````N\H``%P```#;R@``%````#C+```^````3<L`
M`!\```",RP``$````*S+```4````O<L```<```#2RP``"P```-K+```.````
MYLL```P```#URP``#`````+,```3````#\P```H````CS```'0```"[,```9
M````3,P```4```!FS```$0```&S,```1````?LP``"0```"0S```%0```+7,
M```2````R\P```X```#>S```&0```.W,```(````!\T```D````0S0``"@``
M`!K-```'````)<T```@````MS0``*P```#;-```2````8LT``"P```!US0``
M&@```*+-```)````O<T```H```#'S0``%0```-+-```0````Z,T```4```#Y
MS0``%````/_-```$````%,X``!`````9S@``!@```"K.```'````,<X``!X`
M```YS@``*````%C.```*````@<X``!P```",S@``&@```*G.```/````Q,X`
M`!0```#4S@``!````.G.```%````[LX```8```#TS@``!@```/O.```*````
M`L\``!L````-SP``-````"G/```T````7L\``"````"3SP``*0```+3/```@
M````WL\``$$```#_SP``&@```$'0```=````7-```"@```!ZT```'````*/0
M```<````P-```"D```#=T```*0````?1``!1````,=$``%<```"#T0``+```
M`-O1```B````"-(``!\````KT@``&0```$O2```9````9=(``"H```!_T@``
M*P```*K2```C````UM(``"X```#ZT@``-````"G3```-````7M,```@```!L
MTP``%P```'73```*````C=,```<```"8TP``(0```*#3```-````PM,``!``
M``#0TP``#@```.'3```+````\-,```<```#\TP``$P````34```(````&-0`
M``L````AU```"@```"W4```4````.-0``#(```!-U```!0```(#4```7````
MAM0```\```">U```#@```*[4```%````O=0```0```##U```#0```,C4```R
M````UM0``$4````)U0``%P```$_5```>````9]4``!0```"&U0``%0```)O5
M```%````L=4``!0```"WU0``!P```,S5```C````U-4```X```#XU0``*@``
M``?6```&````,M8```P````YU@``#0```$;6```1````5-8``!<```!FU@``
M"P```'[6```V````BM8```H```#!U@``(@```,S6```+````[]8```\```#[
MU@``"P````O7```@````%]<``"<````XUP``*P```&#7```)````C-<``#(`
M``"6UP``,````,G7```Q````^M<``"T````LV```0````%K8```]````F]@`
M`$(```#9V```/@```!S9```_````6]D``$(```";V0``/@```-[9```_````
M'=H``$(```!=V@``/@```*#:```_````W]H``$$````?VP``/0```&';```^
M````G]L``#\```#>VP``.P```![<```\````6MP``#T```"7W```.@```-7<
M``!"````$-T``#X```!3W0``/P```)+=```.````TMT``!0```#AW0``!0``
M`/;=```.````_-T``!,````+W@``!P```!_>```1````)]X```X````YW@``
M!P```$C>```4````4-X```X```!EW@``&````'3>```'````C=X```4```"5
MW@``#````)O>```,````J-X``!(```"UW@``!````,C>```*````S=X```L`
M``#8W@``#````.3>```.````\=X```X`````WP``!0````_?```%````%=\`
M`"X````;WP``)@```$K?```C````<=\```,```"5WP``'@```)G?```8````
MN-\``"4```#1WP``#0```/??```)````!>````<````/X```"@```!?@```"
M````(N```!(````EX```#0```#C@```2````1N````0```!9X```!P```%[@
M```)````9N````P```!PX```4@```'W@```7````T.```"0```#HX```!P``
M``WA```&````%>$```X````<X0``"P```"OA```.````-^$```P```!&X0``
M#0```%/A```5````8>$``!(```!WX0``#P```(KA```4````FN$``!L```"O
MX0``$````,OA``!H````W.$``!H```!%X@``%P```&#B```G````>.(``!H`
M``"@X@``%P```+OB```;````T^(``!D```#OX@``'P````GC```7````*>,`
M`!,```!!XP``"````%7C```(````7N,```D```!GXP``#0```''C```3````
M?^,```,```"3XP``1@```)?C```_````WN,``#0````>Y```)````%/D```W
M````>.0``%<```"PY```!0````CE```?````#N4``"\````NY0``"````%[E
M```-````9^4```X```!UY0``+0```(3E```$````LN4``$\```"WY0``)0``
M``?F```<````+>8```L```!*Y@``'P```%;F```=````=N8``"4```"4Y@``
M(````+KF```D````V^8``"``````YP``"P```"'G```&````+><``#D````T
MYP``!P```&[G```9````=N<```D```"0YP``$P```)KG```$````KN<``!``
M``"SYP``,````,3G```4````]><```T````*Z```#@```!CH```3````)^@`
M`!P````[Z```*````%CH```&````@>@```<```"(Z```$P```)#H```$````
MI.@``!<```"IZ```"@```,'H```,````S.@```D```#9Z```!@```./H```%
M````ZN@```H```#PZ```$0```/OH```&````#>D```X````4Z0``#@```"/I
M```-````,ND```L```!`Z0``'0```$SI```+````:ND```(```!VZ0``'```
M`'GI```'````END``!<```">Z0``!@```+;I``!E````O>D```D````CZ@``
M!P```"WJ```F````->H``#@```!<Z@``&@```)7J```J````L.H``#L```#;
MZ@``*````!?K```T````0.L``!D```!UZP``%0```(_K```'````I>L```@`
M``"MZP``!P```+;K```'````ONL```X```#&ZP``"0```-7K```&````W^L`
M``@```#FZP``"P```._K```'````^^L```<````#[```$`````OL```&````
M'.P``!P````C[```!0```$#L```0````1NP``!````!7[```#P```&CL```'
M````>.P```4```"`[```#0```(;L```0````E.P``!0```"E[```"P```+KL
M```-````QNP``!@```#4[```%P```.WL```:````!>T``!0````@[0``!```
M`#7M```)````.NT```H```!$[0``!P```$_M```"````5^T``!\```!:[0``
M(P```'KM```X````GNT``#$```#7[0``)P````GN``!D````,>X``!0```"6
M[@``'````*ON``!5````R.X``#@````>[P``2@```%?O``!;````HN\``"@`
M``#^[P``.````"?P```J````8/```"@```"+\```+````+3P```G````X?``
M`!L````)\0``/@```"7Q``"I`0``9/$``",````.\P``%P```#+S``!(````
M2O,``",```"3\P``A0```+?S```P````/?0``$$```!N]```6P```+#T``!,
M````#/4``(\```!9]0``'0```.GU```8````!_8``"$````@]@``'P```$+V
M```K````8O8``"$```".]@``*0```+#V```G````VO8``!T````"]P``$0``
M`"#W```S````,O<``"4```!F]P``.````(SW```@````Q?<``!\```#F]P``
M,`````;X``!I````-_@``#(```"A^```,0```-3X``!!````!OD``#,```!(
M^0``)0```'SY```]````HOD``&4```#@^0``30```$;Z```O````E/H``"X`
M``#$^@``*P```//Z```P````'_L``"H```!0^P``/@```'O[``!4````NOL`
M`%H````/_```2````&K\``!*````L_P``!0```#^_```,@```!/]```=````
M1OT``",```!D_0``+P```(C]```L````N/T``"T```#E_0``<0```!/^``!O
M````A?X``+,```#U_@``%P```*G_```E````P?\``#(```#G_P``*0```!H`
M`0`^````1``!`"(```"#``$`4@```*8``0#-````^0`!`)L```#'`0$`I@``
M`&,"`0`E````"@,!``L````P`P$`L0```#P#`0")````[@,!`$4```!X!`$`
M(0```+X$`0"7````X`0!`#````!X!0$`)0```*D%`0`<````SP4!``<```#L
M!0$`!````/0%`0`-````^04!``L````'!@$`#@```!,&`0`%````(@8!`!``
M```H!@$``@```#D&`0!9````/`8!``4```"6!@$`$@```)P&`0`(````KP8!
M``,```"X!@$`$````+P&`0`,````S08!`!````#:!@$`#0```.L&`0`"````
M^08!``X```#\!@$`$@````L'`0`#````'@<!`"H````B!P$`!````$T'`0`?
M````4@<!`#4```!R!P$`+@```*@'`0`O````UP<!`!<````'"`$`(````!\(
M`0`;````0`@!`!@```!<"`$`)````'4(`0`?````F@@!`!H```"Z"`$`(```
M`-4(`0`:````]@@!`#(````1"0$`+P```$0)`0`:````=`D!`"L```"/"0$`
M'P```+L)`0`C````VPD!`!\```#_"0$`&@```!\*`0`E````.@H!`"8```!@
M"@$`)0```(<*`0`D````K0H!`!@```#2"@$`'0```.L*`0`D````"0L!`!@`
M```N"P$`(@```$<+`0`E````:@L!`"H```"0"P$`/````+L+`0`?````^`L!
M`",````8#`$`'P```#P,`0`@````7`P!`!H```!]#`$`&````)@,`0`F````
ML0P!`!X```#8#`$`*0```/<,`0`>````(0T!``D```!`#0$`#````$H-`0`7
M````5PT!`!<```!O#0$`+P```(<-`0`D````MPT!``<```#<#0$`'P```.0-
M`0`%````!`X!``<````*#@$`(@```!(.`0`E````-0X!`!T```!;#@$`&@``
M`'D.`0`'````E`X!`,<```"<#@$`"P```&0/`0`5````<`\!``8```"&#P$`
M"0```(T/`0`8````EP\!``L```"P#P$`#0```+P/`0`7````R@\!``8```#B
M#P$`,P```.D/`0`3````'1`!`!,````Q$`$`#P```$40`0`1````51`!``<`
M``!G$`$`,@```&\0`0`A````HA`!`!,```#$$`$`#````-@0`0`1````Y1`!
M`#(```#W$`$`%````"H1`0`0````/Q$!``@```!0$0$`'0```%D1`0`)````
M=Q$!``H```"!$0$`!0```(P1`0`4````DA$!`!T```"G$0$`"````,41`0`?
M````SA$!``@```#N$0$`&@```/<1`0`&````$A(!`!4````9$@$`"````"\2
M`0`_````.!(!``<```!X$@$`#P```(`2`0`.````D!(!`!````"?$@$`"0``
M`+`2`0`)````NA(!``<```#$$@$`&0```,P2`0`*````YA(!``H```#Q$@$`
M"0```/P2`0`*````!A,!``P````1$P$`%P```!X3`0`$````-A,!`"H````[
M$P$`!P```&83`0`"````;A,!``8```!Q$P$`!P```'@3`0`-````@!,!``L`
M``".$P$`+P```)H3`0`R````RA,!`"````#]$P$`'````!X4`0`,````.Q0!
M`#$```!(%`$`!0```'H4`0`2````@!0!`#\```"3%`$`$@```-,4`0`*````
MYA0!``8```#Q%`$`$P```/@4`0`%````#!4!``8````2%0$`!@```!D5`0`)
M````(!4!``0````J%0$`#````"\5`0`*````/!4!``4```!'%0$`&````$T5
M`0`9````9A4!`!\```"`%0$`'0```*`5`0`1````OA4!``(```#0%0$`!```
M`-,5`0`&````V!4!``,```#?%0$`#````.,5`0!%````\!4!`!H````V%@$`
M-0```%$6`0`H````AQ8!`%,```"P%@$`&0````07`0`^````'A<!`"````!=
M%P$`-0```'X7`0`A````M!<!`$4```#6%P$`,````!P8`0`H````31@!`"D`
M``!V&`$`)@```*`8`0`E````QQ@!`"@```#M&`$`*````!89`0`B````/QD!
M`#````!B&0$`$@```),9`0`3````IAD!`!,```"Z&0$`$````,X9`0!Y````
MWQD!``D```!9&@$`<@```&,:`0!S````UAH!`'P```!*&P$`*P```,<;`0!3
M````\QL!`!<```!''`$`%@```%\<`0`/````=AP!`!\```"&'`$`0````*8<
M`0`?````YQP!`!P````''0$`40```"0=`0`;````=AT!`!0```"2'0$`$@``
M`*<=`0`0````NAT!`!,```#+'0$`'0```-\=`0`/````_1T!``\````-'@$`
M"P```!T>`0`'````*1X!``4````Q'@$`%````#<>`0`'````3!X!``@```!4
M'@$`#P```%T>`0`(````;1X!``P```!V'@$`#P```(,>`0`&````DQX!`!0`
M``":'@$`!@```*\>`0`,````MAX!``@```##'@$`!````,P>`0`*````T1X!
M``0```#<'@$`&0```.$>`0`"````^QX!``D```#^'@$`!@````@?`0`&````
M#Q\!`"<````6'P$`!````#X?`0`/````0Q\!`!,```!3'P$`!P```&<?`0`'
M````;Q\!``8```!W'P$`$````'X?`0`2````CQ\!``8```"B'P$`"0```*D?
M`0`%````LQ\!`"(```"Y'P$`!P```-P?`0`'````Y!\!``L```#L'P$`!0``
M`/@?`0!G`0``_A\!`"L```!F(0$`70```)(A`0`5````\"$!`!8````&(@$`
M#P```!TB`0`)````+2(!``@````W(@$`!P```$`B`0`&````2"(!``P```!/
M(@$`$````%PB`0`-````;2(!``T```![(@$`%@```(DB`0`G````H"(!`!(`
M``#((@$`"@```-LB`0`.````YB(!``\```#U(@$`"P````4C`0`0````$2,!
M`"8````B(P$`(@```$DC`0`J````;",!`!0```"7(P$`"````*PC`0`I````
MM2,!`",```#?(P$`#P````,D`0`@````$R0!`"4````T)`$`-P```%HD`0`5
M````DB0!``\```"H)`$`$0```+@D`0`2````RB0!`!X```#=)`$`.````/PD
M`0`M````-24!`"<```!C)0$`*P```(LE`0`;````MR4!``\```#3)0$`&```
M`.,E`0`-````_"4!``L````*)@$`"P```!8F`0`'````(B8!`"8````J)@$`
M&P```%$F`0!#````;28!`$P```"Q)@$`7P```/XF`0!?````7B<!`&(```"^
M)P$`8@```"$H`0!&````A"@!``4```#+*`$`'````-$H`0`'````[B@!``T`
M``#V*`$`#`````0I`0`1````$2D!``X````C*0$`.````#(I`0`V````:RD!
M`!,```"B*0$`%0```+8I`0`)````S"D!``D```#6*0$`"````.`I`0`2````
MZ2D!`"P```#\*0$`#0```"DJ`0`4````-RH!`!0```!,*@$`&P```&$J`0`O
M````?2H!`!4```"M*@$`#P```,,J`0`4````TRH!`!````#H*@$`)0```/DJ
M`0`A````'RL!`!T```!!*P$`(````%\K`0`/````@"L!`%4```"0*P$`.0``
M`.8K`0`H````("P!``D```!)+`$`$````%,L`0`O````9"P!``H```"4+`$`
M$@```)\L`0`9````LBP!``D```#,+`$`#````-8L`0`-````XRP!``,```#Q
M+`$`%P```/4L`0`.````#2T!`!$````<+0$`&P```"XM`0`E````2BT!`"\`
M``!P+0$`"P```*`M`0`8````K"T!`!D```#%+0$`'0```-\M`0`;````_2T!
M`!,````9+@$`%````"TN`0`B````0BX!`!4```!E+@$`%P```'LN`0`@````
MDRX!``@```"T+@$`"````+TN`0`/````QBX!`!@```#6+@$`)P```.\N`0`'
M````%R\!``@````?+P$`$@```"@O`0`=````.R\!`!H```!9+P$`/````'0O
M`0!$````L2\!``4```#V+P$`"P```/PO`0`Z````"#`!``X```!#,`$`$@``
M`%(P`0!#````93`!`"@```"I,`$`+0```-(P`0`P`````#$!`#,````Q,0$`
M#P```&4Q`0`)````=3$!``D```!_,0$`&0```(DQ`0`=````HS$!`#0```#!
M,0$`*@```/8Q`0`0````(3(!`!0````R,@$`"````$<R`0`/````4#(!`!<`
M``!@,@$`'````'@R`0`%````E3(!`"T```";,@$`#0```,DR`0`(````US(!
M`"T```#@,@$`$@````XS`0`.````(3,!``8````P,P$`!````#<S`0`*````
M/#,!``@```!',P$`$````%`S`0`3````83,!`"@```!U,P$`$P```)XS`0`*
M````LC,!`!0```"],P$`"P```-(S`0`&````WC,!`$P```#E,P$`*````#(T
M`0`'````6S0!`!P```!C-`$`)````(`T`0`F````I30!`#0```#,-`$`)```
M``$U`0`I````)C4!`(````!0-0$`-P```-$U`0`+````"38!`!<````5-@$`
M#P```"TV`0`0````/38!``\```!.-@$`$````%XV`0`/````;S8!``\```!_
M-@$`!@```(\V`0`;````EC8!`!<```"R-@$`"````,HV`0`&````TS8!``X`
M``#:-@$`6@```.DV`0`*````1#<!`!,```!/-P$`6P```&,W`0`0````OS<!
M`!(```#0-P$`#P```.,W`0`5````\S<!`!8````).`$`+````"`X`0`O````
M33@!`!<```!].`$`(@```)4X`0`(````N#@!`"0```#!.`$`%0```.8X`0`1
M````_#@!`!L````..0$`%P```"HY`0`1````0CD!`!L```!4.0$`$@```'`Y
M`0`;````@SD!`!8```"?.0$`!0```+8Y`0`2````O#D!`!````#/.0$`!P``
M`.`Y`0`-````Z#D!``8```#V.0$`!@```/TY`0`/````!#H!``8````4.@$`
M"P```!LZ`0`(````)SH!``P````P.@$`%@```#TZ`0`+````5#H!``@```!@
M.@$`&0```&DZ`0`^````@SH!`"L```#".@$`)P```.XZ`0`2````%CL!`!,`
M```I.P$`$@```#T[`0`3````4#L!`#0```!D.P$`1````)D[`0`C````WCL!
M`!`````"/`$`-P```!,\`0`4````2SP!`!L```!@/`$`"````'P\`0`)````
MA3P!`!(```"//`$`+0```*(\`0`H````T#P!`#````#Y/`$`*P```"H]`0`E
M````5CT!`"0```!\/0$`'P```*$]`0`^````P3T!`"@`````/@$`*0```"D^
M`0`L````4SX!`!T```"`/@$`)@```)X^`0`N````Q3X!`#,```#T/@$`+P``
M`"@_`0`N````6#\!`#4```"'/P$`)````+T_`0`B````XC\!`$8````%0`$`
M%@```$Q``0`D````8T`!`"P```"(0`$`(P```+5``0`8````V4`!`,````#R
M0`$`,0```+-!`0`G````Y4$!`"8````-0@$`)@```#1"`0`P````6T(!`!X`
M``",0@$`*````*M"`0`D````U$(!`#(```#Y0@$`-0```"Q#`0`U````8D,!
M`#0```"80P$`M0```,U#`0`J````@T0!`!P```"N1`$`(P```,M$`0`K````
M[T0!`"L````;10$`3@```$=%`0!+````ED4!`!$```#B10$`!````/1%`0`'
M````^44!``H````!1@$`&0````Q&`0`4````)D8!`!4````[1@$`&@```%%&
M`0`9````;$8!``L```"&1@$`#0```))&`0`,````H$8!`!,```"M1@$`#0``
M`,%&`0`2````ST8!``L```#B1@$`/P```.Y&`0`'````+D<!`!`````V1P$`
M`@```$='`0`(````2D<!``@```!31P$`&P```%Q'`0`G````>$<!``H```"@
M1P$`%````*M'`0`3````P$<!``4```#41P$`#P```-I'`0`*````ZD<!`!$`
M``#U1P$`#0````=(`0`1````%4@!``X````G2`$`$P```#9(`0`7````2D@!
M`!\```!B2`$`'P```()(`0`'````HD@!`!$```"J2`$`#P```+Q(`0`(````
MS$@!``\```#52`$`%P```.5(`0`?````_4@!``\````=20$`#P```"U)`0`I
M````/4D!`"$```!G20$`/0```(E)`0`/````QTD!`!<```#720$`&0```.])
M`0`:````"4H!`#X````D2@$`*````&-*`0`*````C$H!`!````"72@$`+P``
M`*A*`0`9````V$H!``D```#R2@$`.@```/Q*`0`U````-TL!``@```!M2P$`
M#@```'9+`0`F````A4L!`!````"L2P$`)0```+U+`0`H````XTL!``D````,
M3`$`'0```!9,`0`2````-$P!`!D```!'3`$`#P```&%,`0`2````<4P!``T`
M``"$3`$`0````)),`0`^````TTP!``D````230$`#````!Q-`0`P````*4T!
M`!````!:30$`$0```&M-`0`+````?4T!`!$```")30$`$@```)M-`0`:````
MKDT!`!L```#)30$`(@```.5-`0`9````"$X!`"(````B3@$`)````$5.`0`5
M````:DX!``L```"`3@$`#````(Q.`0`/````F4X!`"8```"I3@$`$P```-!.
M`0`)````Y$X!``P```#N3@$`'@```/M.`0`:````&D\!`#\````U3P$`)P``
M`'5/`0`%````G4\!``L```"C3P$`%P```*]/`0".````QT\!`"````!64`$`
M!0```'=0`0`@````?5`!`!8```">4`$`%0```+50`0`&````RU`!``8```#2
M4`$`#0```-E0`0`,````YU`!`!0```#T4`$`#`````E1`0`D````%E$!``T`
M```[40$`"@```$E1`0`6````5%$!``@```!K40$`"````'11`0`9````?5$!
M`"(```"740$`(P```+I1`0`/````WE$!`#@```#N40$`$````"=2`0`'````
M.%(!`!````!`4@$`&````%%2`0`W````:E(!`"P```"B4@$`(@```,]2`0`=
M````\E(!`!P````04P$`(P```"U3`0`;````45,!`$T```!M4P$`!P```+M3
M`0`2````PU,!``,```#64P$`"P```-I3`0`+````YE,!``T```#R4P$`#```
M``!4`0`2````#50!``X````@5`$`&@```"]4`0`:````2E0!`!0```!E5`$`
M#0```'I4`0`/````B%0!`!(```"85`$`)0```*M4`0`&````T50!``H```#8
M5`$`#0```.-4`0`.````\50!``0`````50$`!0````55`0`&````"U4!`!@`
M```250$`#P```"M5`0`%````.U4!`"H```!!50$`&````&Q5`0`&````A54!
M``@```",50$`#P```)55`0`*````I54!``P```"P50$`!@```+U5`0`*````
MQ%4!``(```#/50$`!P```-)5`0`:````VE4!`!<```#U50$`%0````U6`0`A
M````(U8!``,```!%5@$`!P```$E6`0`3````458!`!0```!E5@$`#0```'I6
M`0`,````B%8!`"X```"55@$`"````,16`0`+````S58!`!````#95@$`"```
M`.I6`0`&````\U8!`!4```#Z5@$`$0```!!7`0`N````(E<!`!8```!15P$`
M!@```&A7`0`/````;U<!``\```!_5P$`"0```(]7`0`L````F5<!``0```#&
M5P$`!P```,M7`0`F````TU<!``8```#Z5P$`"@````%8`0`5````#%@!`!T`
M```B6`$`!````$!8`0`L````15@!``T```!R6`$`#0```(!8`0`1````CE@!
M`!````"@6`$`#0```+%8`0`O````OU@!``\```#O6`$`$````/]8`0`M````
M$%D!`!(````^60$`$P```%%9`0`*````95D!`#P```!P60$`(P```*U9`0`?
M````T5D!`"0```#Q60$`!P```!9:`0`(````'EH!``P````G6@$`+0```#1:
M`0`K````8EH!`$$```".6@$`"P```-!:`0`,````W%H!`"$```#I6@$`+0``
M``M;`0`6````.5L!``L```!06P$`%0```%Q;`0`.````<EL!`!````"!6P$`
M%0```));`0`1````J%L!`#P```"Z6P$`C````/=;`0!V````A%P!`!8```#[
M7`$`"P```!)=`0`2````'ET!`!,````Q70$`$````$5=`0`'````5ET!``@`
M``!>70$`&0```&==`0`1````@5T!`!4```"370$`%0```*E=`0`.````OUT!
M`!4```#.70$`'P```.1=`0`A````!%X!`'(````F7@$`$0```)E>`0`2````
MJUX!``L```"^7@$`"P```,I>`0`4````UEX!`!````#K7@$`#P```/Q>`0`5
M````#%\!`!0````B7P$`)@```#=?`0`J````7E\!`"<```")7P$`)P```+%?
M`0`J````V5\!`"L````$8`$`'@```#!@`0!,````3V`!`!0```"<8`$`%```
M`+%@`0`4````QF`!`!0```#;8`$`$@```/!@`0`8`````V$!`!@````<80$`
M%0```#5A`0`5````2V$!`#L```!A80$`&0```)UA`0`:````MV$!`#0```#2
M80$`%`````=B`0`(````'&(!``X````E8@$`+P```#1B`0`>````9&(!`!,`
M``"#8@$`#P```)=B`0`9````IV(!`!L```#!8@$`%P```-UB`0`3````]6(!
M`!H````)8P$`(0```"1C`0`:````1F,!`!4```!A8P$`&P```'=C`0`A````
MDV,!`!L```"U8P$`&P```-%C`0`4````[6,!``8````"9`$`"@````ED`0`'
M````%&0!``<````<9`$`#````"1D`0`7````,60!`!,```!)9`$`%0```%UD
M`0`2````<V0!`!4```"&9`$`%````)QD`0`5````L60!`!@```#'9`$`%@``
M`.!D`0`M````]V0!`!0````E90$`#@```#IE`0`3````264!`!(```!=90$`
M#@```'!E`0`.````?V4!``X```".90$`.0```)UE`0`&````UV4!``X```#>
M90$`$P```.UE`0`'`````68!`!,````)9@$`#@```!UF`0`1````+&8!`!0`
M```^9@$`(P```%-F`0`J````=V8!`"4```"B9@$`!0```,AF`0`'````SF8!
M`"D```#69@$`"`````!G`0`4````"6<!``\````>9P$`"@```"YG`0`2````
M.6<!``<```!,9P$`%P```%1G`0`U````;&<!``D```"B9P$`#````*QG`0`H
M````N6<!`!8```#B9P$`%@```/EG`0`-````$&@!`#$````>:`$`"@```%!H
M`0`,````6V@!``T```!H:`$`"0```'9H`0`'````@&@!``8```"(:`$`$@``
M`(]H`0!'````HF@!`!````#J:`$`!@```/MH`0`.`````FD!``4````1:0$`
M!@```!=I`0`7````'FD!`!<````V:0$`%@```$YI`0`"````96D!``8```!H
M:0$`#````&]I`0`0````?&D!`!8```"-:0$`/0```*1I`0`*````XFD!`!H`
M``#M:0$`#P````AJ`0`'````&&H!``0````@:@$`,@```"5J`0`V````6&H!
M`!0```"/:@$`&@```*1J`0`9````OVH!`"@```#9:@$`)P````)K`0`-````
M*FL!``4````X:P$`$@```#YK`0`6````46L!`!4```!H:P$`%@```'YK`0`7
M````E6L!`!\```"M:P$`!````,UK`0`*````TFL!`!````#=:P$`$0```.YK
M`0`&`````&P!`&(````';`$`$````&IL`0`/````>VP!`!````"+;`$`&@``
M`)QL`0!*````MVP!``<````";0$`&P````IM`0`'````)FT!``8````N;0$`
M"0```#5M`0`J````/VT!`"D```!J;0$`"0```)1M`0`'````GFT!`"(```"F
M;0$`9````,EM`0`;````+FX!`",```!*;@$`&@```&YN`0`"````B6X!`!@`
M``",;@$`!P```*5N`0`7````K6X!``\```#%;@$`#0```-5N`0`.````XVX!
M``<```#R;@$`%P```/IN`0`.````$F\!``L````A;P$`#P```"UO`0`,````
M/6\!``L```!*;P$`"P```%9O`0`+````8F\!`"<```!N;P$`$````)9O`0`1
M````IV\!`!@```"Y;P$`)0```-)O`0`/````^&\!`!4````(<`$`#P```!YP
M`0`%````+G`!`!,````T<`$`!@```$AP`0`$````3W`!``T```!4<`$`"@``
M`&)P`0`,````;7`!`!,```!Z<`$`'@```(YP`0`3````K7`!``,```#!<`$`
M&P```,5P`0`'````X7`!``X```#I<`$`#````/AP`0`1````!7$!``,````7
M<0$`.@```!MQ`0`[````5G$!`!X```"2<0$`)0```+%Q`0`I````UW$!`!4`
M```!<@$`0@```!=R`0!"````6G(!`"L```"=<@$`,````,ER`0`^````^G(!
M`#X````Y<P$`/P```'AS`0`O````N',!`$0```#H<P$`-````"UT`0`3````
M8G0!`!0```!V=`$`%````(MT`0`6````H'0!`!<```"W=`$`$0```,]T`0`3
M````X70!`!4```#U=`$`(@````MU`0`6````+G4!`"0```!%=0$`%````&IU
M`0`4````?W4!`"T```"4=0$`)@```,)U`0`D````Z74!`!(````.=@$`0```
M`"%V`0!$````8G8!`!(```"G=@$`!@```+IV`0`>````P78!`!$```#@=@$`
M"````/)V`0`(````^W8!`!,````$=P$`%0```!AW`0`.````+G<!`!$````]
M=P$`"@```$]W`0`5````6G<!`$\!``!P=P$`"P```,!X`0`?````S'@!``P`
M``#L>`$`/P```/EX`0`)````.7D!``<```!#>0$`$@```$MY`0`.````7GD!
M`"L```!M>0$`#P```)EY`0`W````J7D!``L```#A>0$`%P```.UY`0`G````
M!7H!``D````M>@$`"0```#=Z`0`0````07H!``<```!2>@$`#@```%IZ`0`W
M````:7H!`!H```"A>@$`)0```+QZ`0"#````XGH!`!<```!F>P$`2@```'Y[
M`0`J````R7L!`!,```#T>P$`%P````A\`0`(````('P!``P````I?`$`#P``
M`#9\`0`2````1GP!``H```!9?`$`$````&1\`0`(````=7P!`!L```!^?`$`
M&````)I\`0`$````LWP!`!$```"X?`$`&0```,I\`0`J````Y'P!`!0````/
M?0$`'````"1]`0`2````07T!`"H```!4?0$`"P```']]`0`+````BWT!``L`
M``"7?0$`!P```*-]`0`'````JWT!`#,```"S?0$`#0```.=]`0`N````]7T!
M`!8````D?@$`"````#M^`0`)````1'X!`!X```!.?@$`&@```&U^`0`*````
MB'X!`!L```"3?@$`"````*]^`0`6````N'X!``@```#/?@$`!P```-A^`0`?
M````X'X!`#``````?P$`#0```#%_`0`E````/W\!`!H```!E?P$`$P```(!_
M`0`6````E'\!``H```"K?P$`"````+9_`0`+````OW\!``X```#+?P$`"P``
M`-I_`0`B````YG\!`$`````)@`$`0@```$J``0`=````C8`!`"X```"K@`$`
M)P```-J``0!,`````H$!`!H```!/@0$`(````&J!`0`L````BX$!`!T```"X
M@0$`'@```-:!`0`J````]8$!`#4````@@@$`<0```%:"`0!9````R((!`#4`
M```B@P$`+````%B#`0`G````A8,!`!8```"M@P$`'````,2#`0`Z````X8,!
M`#@````<A`$`+````%6$`0`S````@H0!`#L```"VA`$`#````/*$`0`%````
M_X0!`"`````%A0$`!P```":%`0`-````+H4!`"H````\A0$`$@```&>%`0`5
M````>H4!`!$```"0A0$`$````**%`0`(````LX4!`!4```"\A0$`#@```-*%
M`0`1````X84!``X```#SA0$`'`````*&`0!!````'X8!``<```!AA@$`&P``
M`&F&`0`,````A88!``\```"2A@$`!0```**&`0`(````J(8!`!(```"QA@$`
M/P```,2&`0!9````!(<!`"@```!>AP$`*P```(>'`0`B````LX<!`"````#6
MAP$`!0```/>'`0`0````_8<!``8````.B`$`*0```!6(`0`;````/X@!`#<`
M``!;B`$`"````).(`0`.````G(@!``\```"KB`$`%0```+N(`0`>````T8@!
M`!````#PB`$`20````&)`0`,````2XD!`"@```!8B0$`#P```(&)`0`3````
MD8D!`!(```"EB0$`)0```+B)`0!$````WHD!`#8````CB@$`#````%J*`0!!
M````9XH!`#D```"IB@$`.@```..*`0`V````'HL!`$P```!5BP$`2P```**+
M`0!.````[HL!`$@````]C`$`30```(:,`0!.````U(P!`$@````CC0$`30``
M`&R-`0!.````NHT!`$@````)C@$`30```%*.`0!-````H(X!`$<```#NC@$`
M3````#:/`0!+````@X\!`$4```#/CP$`2@```!60`0!)````8)`!`$@```"J
MD`$`3@```/.0`0!(````0I$!`$T```"+D0$`$0```-F1`0`7````ZY$!``D`
M```#D@$`#@````V2`0`6````')(!``P````SD@$`%P```$"2`0`;````6)(!
M``D```!TD@$`%P```'Z2`0`1````EI(!`"P```"HD@$`"0```-62`0`%````
MWY(!`!$```#ED@$`#````/>2`0`4````!),!``4````9DP$`#P```!^3`0`3
M````+Y,!`!````!#DP$`$0```%23`0`1````9I,!``@```!XDP$`!P```(&3
M`0!!````B9,!`#$```#+DP$`,@```/V3`0`(````,)0!`!X````YE`$`'0``
M`%B4`0`K````=I0!``P```"BE`$`"P```*^4`0`(````NY0!``P```#$E`$`
M`@```-&4`0`4````U)0!`!$```#IE`$`$0```/N4`0`*````#94!``T````8
ME0$`#P```":5`0`3````-I4!`&8```!*E0$`'@```+&5`0`U````T)4!``@`
M```&E@$`"0````^6`0`2````&98!`!,````LE@$`%P```$"6`0`/````6)8!
M`!<```!HE@$`&P```("6`0`6````G)8!`!0```"SE@$`'````,B6`0`=````
MY98!`!D````#EP$`A0```!V7`0`C````HY<!`"P```#'EP$`+0```/27`0`<
M````(I@!`"0````_F`$`(@```&28`0`>````AY@!`!<```"FF`$`)@```+Z8
M`0`=````Y9@!``P````#F0$`#````!"9`0`+````'9D!`!$````IF0$`&0``
M`#N9`0`$````59D!`&````!:F0$`0````+N9`0!(````_)D!`"(```!%F@$`
M0@```&B:`0!X````JYH!``<````DFP$`+````"R;`0`V````69L!``8```"0
MFP$`$````)>;`0`1````J)L!`$$```"ZFP$`"````/R;`0!1````!9P!`$``
M``!7G`$`+P```)B<`0`1````R)P!`"L```#:G`$`(P````:=`0`M````*IT!
M`"8```!8G0$`+@```'^=`0`G````KIT!`!H```#6G0$`"@```/&=`0`Q````
M_)T!`!`````NG@$`*````#^>`0`(````:)X!`!0```!QG@$`!P```(:>`0`2
M````CIX!`#<```"AG@$`'P```-F>`0`2````^9X!``\````,GP$`$````!R?
M`0`A````+9\!`"\```!/GP$`$P```'^?`0`'````DY\!`!,```";GP$`!```
M`*^?`0`;````M)\!``\```#0GP$`#P```."?`0`0````\)\!``@````!H`$`
M!@````J@`0`,````$:`!`!(````>H`$`"0```#&@`0`1````.Z`!``X```!-
MH`$`#@```%R@`0`,````:Z`!`"0```!XH`$`"@```)V@`0`"````J*`!`!T`
M``"KH`$`!````,F@`0`D````SJ`!``@```#SH`$`;````/R@`0`*````::$!
M``@```!TH0$`(P```'VA`0!`````H:$!`!<```#BH0$`)@```/JA`0!1````
M(:(!`"P```!SH@$`.P```*"B`0`7````W*(!`!,```#TH@$`$0````BC`0`'
M````&J,!``0````BHP$`!P```">C`0`,````+Z,!``D````\HP$`!````$:C
M`0`&````2Z,!``L```!2HP$`"@```%ZC`0`'````::,!`"P```!QHP$`!@``
M`)ZC`0`E````I:,!``<```#+HP$`$````-.C`0`0````Y*,!`!0```#UHP$`
M!P````JD`0`(````$J0!`!,````;I`$`$0```"^D`0`?````0:0!``L```!A
MI`$`#0```&VD`0`;````>Z0!`!,```"7I`$`&P```*ND`0`2````QZ0!``<`
M``#:I`$`#````.*D`0`1````[Z0!``\````!I0$``@```!&E`0`P````%*4!
M`"D```!%I0$`*P```&^E`0`J````FZ4!`"4```#&I0$`>0```.RE`0`2````
M9J8!`"@```!YI@$`3````**F`0`T````[Z8!`%<````DIP$`4@```'RG`0`A
M````SZ<!`#H```#QIP$`*0```"RH`0`O````5J@!`#4```"&J`$`,0```+RH
M`0`@````[J@!`$`````/J0$`\`$``%"I`0`<````0:L!`!8```!>JP$`1P``
M`'6K`0`I````O:L!`(````#GJP$`0P```&BL`0`^````K*P!`&H```#KK`$`
M:0```%:M`0":````P*T!`"$```!;K@$`$P```'VN`0`>````D:X!`!\```"P
MK@$`)````-"N`0`A````]:X!`"P````7KP$`)0```$2O`0`<````:J\!`!(`
M``"'KP$`.0```)JO`0`K````U*\!`#4`````L`$`)````#:P`0`A````6[`!
M`$````!]L`$`:P```+ZP`0`P````*K$!`#````!;L0$`1````(RQ`0`O````
MT;$!`"0````!L@$`-````":R`0!\````6[(!`%4```#8L@$`2````"ZS`0!"
M````=[,!`#D```"ZLP$`/0```/2S`0`X````,K0!`$8```!KM`$`50```+*T
M`0!R````"+4!`'````![M0$`60```.RU`0`8````1K8!`#L```!?M@$`(@``
M`)NV`0`M````OK8!`"P```#LM@$`+````!FW`0`Q````1K<!`&@```!XMP$`
M90```.&W`0"S````1[@!`!D```#[N`$`+````!6Y`0!(````0KD!`#8```"+
MN0$`70```,*Y`0`S````(+H!`%H```!4N@$`R````*^Z`0#=````>+L!`(,`
M``!6O`$`(P```-J\`0`.````_KP!`,`````-O0$`KP```,Z]`0!)````?KX!
M`#````#(O@$`F@```/F^`0!#````E+\!`"4```#8OP$`)````/Z_`0`)````
M(\`!``,````MP`$`%````#'``0`*````1L`!``P```!1P`$`!@```%[``0`1
M````9<`!``0```!WP`$`=0```'S``0`&````\L`!`!<```#YP`$`!0```!'!
M`0`&````%\$!`!,````>P0$`"P```#+!`0`4````/L$!``\```!3P0$``@``
M`&/!`0`<````9L$!`"````"#P0$`%0```*3!`0!,````NL$!`!8````'P@$`
M)0```!["`0!#````1,(!`#@```"(P@$`.0```,'"`0`8````^\(!`"X````4
MPP$`(@```$/#`0`@````9L,!`"@```"'PP$`(P```+##`0`A````U,,!`"<`
M``#VPP$`(````![$`0`S````/\0!`#````!SQ`$`'````*3$`0`_````P<0!
M`"$````!Q0$`-0```"/%`0`H````6<4!`",```""Q0$`.@```*;%`0`N````
MX<4!`"P````0Q@$`(0```#W&`0`D````7\8!`"@```"$Q@$`+P```*W&`0`C
M````W<8!`"D````!QP$`-0```"O'`0!&````8<<!`#H```"HQP$`*````./'
M`0`L````#,@!`"L````YR`$`+````&7(`0`F````DL@!`"$```"YR`$`+P``
M`-O(`0`F````"\D!`#(````RR0$`*P```&7)`0`.````D<D!``\```"@R0$`
M(@```+#)`0`A````T\D!`#D```#UR0$`,0```"_*`0`1````8<H!`"$```!S
MR@$`!P```)7*`0`'````G<H!`"(```"ER@$`)0```,C*`0`?````[LH!`!X`
M```.RP$`!P```"W+`0`'`0``-<L!`!$````]S`$`&@```$_,`0`)````:LP!
M``P```!TS`$`(````(',`0`0````HLP!`!$```"SS`$`)````,7,`0`(````
MZLP!`#4```#SS`$`&@```"G-`0`9````1,T!`!,```!>S0$`)@```'+-`0`)
M````F<T!`#8```"CS0$`+P```-K-`0`2````"LX!``\````=S@$`#@```"W.
M`0`W````/,X!`!4```!TS@$`%@```(K.`0`,````H<X!`"$```"NS@$`#0``
M`-#.`0`.````WLX!``<```#MS@$`%````/7.`0`<````"L\!``@````GSP$`
M-````##/`0`*````9<\!`!<```!PSP$`!0```(C/`0`:````CL\!``D```"I
MSP$`.P```+//`0`&````[\\!``\```#VSP$`$P````;0`0`.````&M`!``<`
M```IT`$`"0```#'0`0`+````.]`!`!\```!'T`$`#P```&?0`0`2````=]`!
M`!$```"*T`$`"0```)S0`0`*````IM`!`!H```"QT`$`!P```,S0`0`S````
MU-`!``T````(T0$``@```!;1`0`+````&=$!``L````ET0$`$@```#'1`0`/
M````1-$!`#\```!4T0$`.P```)31`0`G````T-$!`"4```#XT0$`#````![2
M`0!3````*](!``8```!_T@$`%0```(;2`0!%````G-(!`!$```#BT@$`#@``
M`/32`0`'`````],!`!@````+TP$`!P```"33`0`(````+-,!``4````UTP$`
M#P```#O3`0`'````2],!`!(```!3TP$`$0```&;3`0`%````>-,!`!H```!^
MTP$`(0```)G3`0`?````N],!`",```#;TP$`$0```/_3`0`"````$=0!``0`
M```4U`$`!@```!G4`0`#````(-0!``P````DU`$`90```#'4`0`;````E]0!
M`#@```"SU`$`(0```.S4`0!3````#M4!`!(```!BU0$`1@```'75`0`A````
MO-4!`#X```#>U0$`(P```!W6`0!!````0=8!`#@```"#U@$`,0```+S6`0`P
M````[M8!`#`````?UP$`,````%#7`0`Q````@=<!`"P```"SUP$`,````.#7
M`0!!````$=@!`!L```!3V`$`'````&_8`0`1````C-@!`!(```">V`$`?0``
M`+'8`0`,````+]D!`'<````\V0$`=````+39`0"(````*=H!`#$```"RV@$`
M8@```.3:`0`5````1]L!`!\```!=VP$`%````'W;`0`C````DML!`$0```"V
MVP$`(0```/O;`0`4````'=P!`%0````RW`$`'@```(?<`0`C````IMP!`"$`
M``#*W`$`%0```.S<`0`B`````MT!`"X````EW0$`$@```%3=`0`*````9]T!
M`!````!RW0$`!@```(/=`0`'````BMT!`!0```"2W0$`!P```*?=`0`&````
MK]T!`!@```"VW0$`"````,_=`0`/````V-T!`!4```#HW0$`"0```/[=`0`3
M````"-X!``<````<W@$`$````"3>`0`*````-=X!``8```!`W@$`"P```$?>
M`0`&````4]X!`!D```!:W@$``@```'3>`0`%````=]X!``P```!]W@$`"```
M`(K>`0`Q````D]X!``4```#%W@$`%0```,O>`0`;````X=X!``T```#]W@$`
M"@````O?`0`.````%M\!`!$````EWP$`%@```#??`0`(````3M\!``X```!7
MWP$`!0```&;?`0`K````;-\!``L```"8WP$`!P```*3?`0`.````K-\!``T`
M``"[WP$``0```-H$``"#`@``2P(``*H!``!.`@``KP4`````````````@@0`
M`#<`````````=`,``(,```!N`@``%P4```````!H`@``?@4``-8%``#S!```
MF@```((%````````D````*D!``".!```Z````&P%```6`P``I0(``)X$````
M```````````````@!0``2`0``.`#``#C````E`$``/@%`````````````$<`
M``"G````X0,``(4#``#O````F`4``'4%``#^!0``RP$``#("``"'`0``)P$`
M```````_`P``T`(``*D%``![````:P$``"\$```5`P``.0```)X!``!5!0``
M`````*T!```O`P``6P`````#```2`0``J@(``.(!`````````````*<!``#7
M!0``NP```*@``````````````.H`````````R`$``*L$```)!@``Y0$``/`!
M```W!0```````.T$```7`P````````````"X`P``Y````"`#````````@P$`
M`"0#```*!0``3P$``"L%````````.P,``+L"``":!0````````````"V`0``
M``````````#$!0```````(X!``#J!0``Q0(``(8!````````R`(``,D$````
M`````````.\#```^!````````'4!``";`0``HP,``'P%``#-`0```````!L`
M````````/0$```````#G!0```````!T$``"[!```.P0``*D"````````````
M`+8#````````W`4``#H````V!```)00``,8$``"Z`@``7`$``.H!``!0````
M]04``/(%``".!0``G`4``(L!```B!````````-L"```@`@```````#,$``"X
M`0``<@4``.X%``!Y!0``:0,``.($``#^`````````.@#````````R@,``!$#
M````````K00``+$!``"@`@```P0```X!``!4`P``-@(```````!W`0``I@(`
M`%,$``"4!```BP0``,L```#6`P``I````/@!``"\`@```````!H"``#/`P``
M<@,````````-`P```````)4!``!'`0``(0(`````````````H@4``!L!``"5
M`P```````.@%``!I`@````````````!2!```]@0``$P"```Q!0```````&X`
M````````L`(``$`#``!R!```B`0``'H"```\`@```````&<#``#'!0``(P,`
M`,(```"1`P``W@```-0$``#?!0````````\%``!%!0``400```````#A````
MQ@$````````]!```4P,`````````````S0```.L#````````KP$``.\%``"F
M````U0(``*H#````````A@(``$4````%`0```````&4%``#)`@```````$X$
M``!>!0```````,H`````````90(``-L#``"7`P``5`0``,P#``"/`P``(@``
M``````#W`@```````'@```#.`@``U@(``,H%```?!```K`$`````````````
MX0$``)\!``````````````````!B````RP(``*`%```.`````````)4"```5
M````)@,``(T%``!S!```)0``````````````2@(```````#T`````````%,!
M``!O`0``Q`$``/L```"1`0``<````!,````I!```K@$```````!G!```N`0`
M```````/`P```````%T```"+`P``^@(``%$```#F`P``Q`(``,`#````````
M^04``!4%``"5!0```````+D#````````"@$``-L%``#(`P``?@,```````"Q
M`P``804``.L$``!A````K`,```````#3!```U`(``'L!``!>!```````````
M``"K`P``H@````````"?`@``8@,```````!#````A@,``#4$``!J!0``"0``
M`)($``#!````30(```````#3`````````#<!`````````````%`%```F!```
M`````&H```!&`@``/@4```@%``"9`P``8P```+D$``#X!```*`0```````!H
M`0``;04``,8"``#T`@``Q@```),$``"9!```2P4``'`"``!;`@``<P,``.D!
M```/`@````````````!'!````````&,"``!)`P``N04``%L%``#L!```````
M`+4"``":`0``E``````````*!@``3`````````#.!0``[0(``"H%``#R`0``
M\04``&<````N!0``(@$``$T%``#E`@``CP$``+\$```D`0``J@0```````#8
M`0```````%,"````````W@4```@!````````:@,``+\%```W`@``=`(``%<#
M```M!````````.,%``!M`@``V@4``$D````<!0`````````````C`@``````
M`'0$``#^!```9P4```````#>`0``3P,```````!N!0``M`$```P#``!<`@``
M$P0```8%``"W!```"`8``#H%``"R`P``G`0``!($``#!!```V0,``'<"````
M````U@```$L```#N`0``\P$````````E`0``*`$``%`#``"Y`0``P`0``&@$
M```-````0`$``,4#``"+`@``W@,``-0%``!9`0``9@,```<#```M`0``````
M`(4`````````Q0$``+H#```[````-0$````````M`P``#0(``$D!```+!```
M1@0``'`#``````````````````#0`0``MP4``-4%```:`0``L`$``-X"``!_
M!0``C0(``)(#``#_!```K0,``!(``````````````/P#``#/`0``(0,``'T`
M```%`P``T@4``+\```"9!0``8P0```````",`0``LP$``#(#``!7`0``B0(`
M`'8"``#-`@``0P,```````#I!```3@```*T"``!P!````````(("``!U`@``
M*0,```````!L`0``%@$``-(```#F!0``@00``(X"````````@0$``&L#````
M````Q0```!4!``#4````A`(``,P$```````````````````>`0``/@(`````
M``!,!```,`$``.(```#3`0```````'L$``"=`@``]@$```````##!```80$`
M``````"A!0``.00```4%````````@04``*4```!Y!```Y`,````````X`@``
M```````````-!0``JP```+L!``!+!```1````+("```E`P``!`8``*,$``"P
M!```_P``````````````C`0``!`#``#7````+`,```````!4!0```````/,#
M```!!@``4P4``,("``"<`@``R@$``,$!``#L`0``,@4``!L#````````Z`$`
M``````#_`0``M``````````*!```6@0``$D"``#+!0``>0(````````H`@``
MH@(````````#`@``O0,``*X"``#_`@```````````````0``O`````````#0
M!```X@,``"L"```O!0``J@4```````#9`@```````'L#``"``P``+@```$@"
M``"G`@``\P```)(%````````_04``,P%``"`!0``````````````````_`4`
M`'@#````````\`0``%8$``!T!0``-`0```````"9`@```````&@```")`0``
M````````````````=@$``*<%``#Y````#@(``.T```"]!0``^P,``*4%``#.
M`P```````(4!``#=`0``;`(``'T#``"Q!```-`(``"<#`````````````.4`
M``"4`@``'`0``"0"``#"`0```@```,0#``#@!0``F0$```````#J`@``,P$`
M`"0$``!]`0``2@4``````````````````%P$````````40,``+($````````
M]00```````!!````K@4``)$"```/`````````-4#`````````````/`%```0
M!0``*P0```````!C`0```````*P"``!X!````````-T#``""`0```@8`````
M``"X````PP```*(!````````?P```````````````````%H"``!4`0``````
M`/0#``"=!```J@```!X#```]````^P$``$<#```!!0``LP,``%<%``#=````
M`````.<!````````-`$``'@"``"?!```B`(```````#Z!0``2`,```$!``"<
M`0```````.L%``#S`@``VP$``$H#```O`@```````-4$``#<`P``````````
M``"$`P``>@0```````#)`P``$P,``"H!``!7`@```````#`"``#C`0``'0``
M`-\"````````R0```)L"````````^0$``"@#````````*0````\$````!0``
M_@$``+8$```.!0``MP,``!@!``"A`0``>`$```````!$`@``N0(``.L"````
M````]P```,4%````````%P```-P"``!D`@``=P```'H```#\!````````+X`
M````````GP``````````````$0```.4#```9!0``````````````!@``,`0`
M`(H```#]!```/`4``%@%``!R`@``,00`````````````K0```.(%````````
M7@```%(%````````Y@0``)X#```)`P``A`4``%L$``!?`@``*P$```8```"B
M!```Y@(```D$````````B@4``(,#``!\`@``N@````````#5````````````
M``````````````````#D`0``4@````````!>`@``'`$``)H$``#0!0``````
M`-\```!J!```60(``'$#````````]0``````````````Z0,``$L#```R!```
M]@,``#8%````````&00``/8"``"?!0```````'L%``#_!0``UP0``%$!````
M````J00``&@%``![`@``(`0``$,"``"?`P``EP$````````]!0``3P0``.T%
M``!C`P``60,``%@#``!;`P``@0```&L````L````)@$```L%``!M`0``````
M`&L%````````E@$````````U`P```````&T#``#$````XP,``+P$````````
M_@,````````J!```(````"X"````````*0(``"<"````````?@$``+<!``#D
M!0```````#`%````````G`,```````!L`````````#D%``##`@``704`````
M``!Y`P``=@,``'P```!]`@``X````/D#````````3`4``+$%``"S!```I`,`
M````````````;@$``-L$```*````\0```+H%````````T0,`````````````
M]`0```````"'````J`0```8$````````)@(``,,!``!4````%@(``!8$``!?
M!0``)P```%0"``"^`0``A`0``&0%```+!@``!@(``%\!``!?!```````````
M``!S````$@4``)H#``"(!0``$@(``$8```"S`@``*P,`````````````````
M`&8```!1!0``N@0``,($````````'@```&D%``!6`P``AP(``.D```!\`0``
MO@4``.$%``"V`````````(H!``#'`@``?P(``#P#``#P````B@0``*0$```9
M`P``[@```%D%```?`@```````*,!``"]!```]@````````"2````````````
M``!@!```8P4```````````````````````#U`P``?P$``",```!D`P``A```
M``````"O`````````%("``!6`````00```````!.`P``204`````````````
M`````$`````X`P``#`(``#0#`````````````)<````E!0````````0%```M
M````.P4``#\```";!0``=@```",%```_`@``H`,``(4"`````````````.,"
M``#,`0```````,X!``#6!```V00```````!%`0```````,D!``!2`P``````
M`($#``#F``````````4&``#?!```ZP```*`$`````````@0``!@#````````
M```````````H````'@4``.@"````````Z04``#H!``"^!```90,``$$!```V
M`0```````#P!``#<`0```````,4$```X!```\00``#\!```(`@``!P8``.T#
M```Y`P``$`$``!<!```W`P``\@```#$!``!0!````P$``#H#````````````
M`&\%``"]`````````.P%``"H`P```````/<$``";`P``-@,```````"\!0``
M?P,``(````".`P``_````)`$``#Q`0```````/H!````````0@0```````#=
M!0``.`4``%8"``"R`0```````*@%``#:````D00``*$"``"'!`````````D"
M````````Z@,``&@#``#1`@``<0$``!T#````````P0,``'$%```#`P``&@4`
M`,<#`````````````)X```#>!```=0```/T"``!2`0``HP4``-\!````````
M#@,``/$"```'``````````````"+`````````%H#``"U``````````````#O
M`0````````````!8`@``6@4``.,$```_!```$`0``)D```#/````.0(``!,%
M```I!0```````*$$```&!@```````'P#``"W````%`$``'0!``!W!```````
M``````!&!0``,````!X"````````J0,``.<#```+`@````````````!D`0``
M``````0"`````````````!D!``#W`P``A@4``'$"```<`@``N@$``&(%``!"
M````<`$``-@%```Z!````````.X#``#R`@``_0$``',%``"N````:0$``"\!
M``!,`P``I0$``*@"````````Y`0```L```!5`````````-@$```(`P``,P(`
M``````!@!0``M@(```````")!0``M`0``!L$``!]!```3P```"$!```<````
M(@4``*L%````````/@```)T!``!Z`P``[`(``)@#```+`P``<P(``)("``#Y
M`@```````*<#```B`P``:0````,&``#@`@```````"P%```A`````````!``
M````````;P(``,P"```"!0````````````"(`P``!P(```````"\`P``V```
M``8!```Q`````````&4!````````T@0``'P$``!I!```G@(``(\$``"&!```
M4`$```````#5`0````````````!B!````````%X!``"F`0``L`4`````````
M```````````````Q`P``S`````````#7`P``=@4``-@"````````M00``/8%
M```<`P``7@,`````````````#`4``",!```8`@``JP$``$0%``!A`@``O0(`
M`)8#```M!0```````',!```R````+`$``#@````4!```6P$`````````````
M,@$``,L#``"Q``````````4$```4!0``````````````````$00```````#4
M`P``%00``&\#````````0@$``(,$``##!0``KP,``)4```"3`````````"0`
M````````@`(``&8$``!M!````````"("``"A````/P4``-$%``"G!```"04`
M`*P$``"(````5P```/,%````````8@$```8#``!?`P``#``````````;!0``
M;P```"X!``!^````/0(```````#`````^@````````#X`P``^00````````-
M`0``.`$``)T`````````L````(L%```L!```6@$``,0$``"[!0```````,T$
M``!*!```;`,``$@%````````%`(``#0```!G`@``K@,```````"1!0``J`$`
M``````#1`0``YP(``+D```"C`@``_0```(T!``!<`P```````-P$``"3!0``
MEP(``(4%``":`@``&`0``-,"````````UP(``$<%```J````PP,``-$$``#!
M`@``9P$``"\`````````.0$``(`$``"T`@``QP```-<!``#/!0``C```````
M```\!````````,`"``!D````!`$```("``#]`P``+`(``%4#```$!```C@``
M`-$```"F!0`````````````4`P``G````&`#``!<````#00``$$#````````
M>@4``````````````````(P#``!P!0``&@0``!\```#<````;P0``/`"````
M````9@$```````"=`P``%P0``$P!``!-````YP```)4$````````#P$`````
M````````=`````H"``"C````V04```````!Q``````0``+4#```J`@``````
M`)`%``"/`````````(\"```=`0``'P4```````"W`@```````$H!``"T`P``
MTP,``#L!``#T`0```````&`!``"D`0``$@,``#0%``"!`@``000``*4#``#E
M!0``5@$``*````!F!0```````"0%``#Q`P``NP,`````````````KP(`````
M``!/`@``V@(``.<$`````@```````"X#```(!```1@,``",$````````Z@0`
M``````"$`0``X00``/P!````````30,``#T#``!^!```10,```<!``!%`@``
M"P$``%8%```.!```^`(````````#!0``\@,``%T$``#P`P``I@,``$\%``!=
M`P``&@,``$T$``"=!0``"@,``'4#```#````RP0```````#!!0``7P``````
M```=`@``P@,````````;`@```````+(%``#(!0``T@$```````"3`0``KP0`
M```````U````9`0``)8``````````````+\!``!A`P``[P0````````S````
M[P(``%D$``"3`@``/@,``,8#``#Z`P``]P$``+(`````````50(``,@````4
M````H@,``'(`````````0P4``%H``````````````+,%``!1`@``%P(`````
M``""`P``5P0``$("````````EP0``-L``````````0(``'$$``#=`@``````
M```````G!0``]P4``&L"```'!```T@,``)L```!E!`````````````#@`0``
M`````,`%``!Z`0``QP$``$`"`````````````(<%`````````````$<"````
M````#`0``````````````````,X`````````8```````````````M0$``/($
M``"_`P``````````````````=P,``%@!```^`0```````,T#````````````
M`!$!``"X`@``QP0``,T%`````````````-,%````````2`$``$4$``"0`@``
M@P4``*4$``!3````E`4``"X$```U!0``500``/L"````````X@(``+X#````
M````Z0(``,8%``",!0``,P,``/X"``!$`0```````-````"8`0``M04``(H#
M````````'@0``)8$````````M`4``"$$``#=!````````)@"````````````
M``````!L!```Y00``(8```"-!````````$$"```[`@``200``,H"``!A!```
M-0(``$T!```8````9@(```````"7!0``70(``,(%``#K`0```````.X"```%
M````O`$``,\"``"8````2````$H````6!0``C`(```````"A`P```````!@%
M``"``0```0,```````````````````````#*!```Y`(```(!````````````
M``````!V!```>0$``#<$``#.!```B@(``*T%````````1`0``,\$```1`@``
M`````%4!``!]!0``=00``"<$``!<!0```````#$"````````B0````````!=
M`0``)0(``!\!``#:`P````````@```````````````````"/!0```````&H!
M````````*P````````!Y````#`$``$0#```"`P```````!T%``!`!```````
M`*0"```P`P``F`0``%@```";!````````/4"``!`!0``3@4``"8```"F!```
M8@(``"`!```Z`@```````+`#``!@`@```````(@!``#@!`````````````#\
M`@``0@,``!4"`````````````.X$``!M````!`,```````#?`P``N`4``$X!
M``#8`P``O0$````````1!0``JP(``)0#``"I`````````-H!````````M@4`
M`*`!````````````````````````<@$``"$%````````D`$````````I`0``
MK`4``!,"```)`0``A00``"8%``"'`P`````````````:````^P4``*P```"0
M`P``,P4``)X%```?`P``[`,``&4`````````````````````````````````
M``!N`P``[````(D#``!#!````````+$"``"2`0``^@0```````#_`P``````
M`-D````M`@```````+,```#A`@``O@(````````0`@``[0$```````#T!0``
M`````&X$```\````OP(```0```#X````R04``'X"`````````````"H#````
M`````````(T#``!9````@@```-("``!0`@``:P0``)$```"6`@``004``$(%
M``#H!`````````````#``0``U`$``(T```!X!0``I`4``&H"```%`@``E@4`
M`%@$``#[!```$P$``'<%```9````Y@$```````")!```]0$``#8````6````
M?P0```````#6`0```````-`#````````0P$``$L!```H!0``!P4``$8!``#9
M`0``&0(``),#````````R`0``*X$````("!4:&4@;6%I;&)O>"!T<F%S:"!I
M<R!A;')E861Y(&5M<'1Y+@`@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O
M<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX`
M("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`
M("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``)60@)7,@
M86YD("5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!!9&UI;FES
M=')A=&EO;@`E<R!&:6YG97)P<FEN=``E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R
M;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E
M<P`E<R!H87,@8V%N8V5L;&5D("5S+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R
M964O8G5S>2!R97%U97-T+@`E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A
M=&EO;B!T;R`E<RX`)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BX`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!R97%U97-T<R!Y
M;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P
M<F5S96YC92!A="`E<RX`)7,@=&\@)7,@;V8@)7,`)7,@=VES:&5S('1O(&%D
M9"!T;R`E<RX`)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E
M<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B
M;W5T("5S+@`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"<E<R<@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+@`G)7,G(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2X`)R5S)R!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`)R5S)R!W87,@
M861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"<E<R<@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"<E<R<@=V%S(&YO="!C<F5A=&5D
M.B`E<RX`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`
M,C0@:&]U<G,`/&(^02!F871A;"!E<G)O<B!H87,@;V-C=7)R960Z/"]B/@!!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32]030!!
M8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE
M`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N
M=&EN9P!!8W1I;VYS`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E
M<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M
M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("<E<R<`061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R`G)7,G`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN
M`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@
M82!-;WII;&QA(%-I9&5B87(`061D('1H:7,@=&\@;7D@8V%L96YD87(`061D
M('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@
M=7-E<@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@
M)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M
M:6YI<W1R871I;VX`06MT:6]N($%I<G!O<G0`06QE>&%N9')O=7!O;&D@06ER
M<&]R=`!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC
M871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U
M<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!;F-H:6%L;W,@06ER<&]R=`!!;F1R879I
M9&$@06ER<&]R=`!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%P<&QI8V%T:6]N
M`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY
M('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL`$%R87AO<R!!:7)P;W)T
M`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("<E<R<@86YD(&%N
M>2!S=6(M9W)O=7!S/P!!<G0`07-C:6D@07)T`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I
M9VYM96YT(&-O;'5M;G,`071H:6YA:2!!:7)P;W)T`$%T=&%C:&5D(&ES(&%N
M(&E#86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD965S`$%T=')I
M8G5T97,`075G=7-T`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A
M=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!=V%I=&EN9R!297-P;VYS90!"86-K
M9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A<F4`0F%S92!G<F%P:&EC<R!D
M:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`$)A<V5L:6YE`$)I<G1H9&%Y`$)L
M;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K
M(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";W)D97)S`$)O=&@`0F]T=&]M
M`$)U;&QE=&5D($QI<W0`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U93`$-?
M96QL(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%L96YD87(@4W5M;6%R>0!#
M86QE;F1A<CH`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!T:6]N`$-A
M=&5G;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96YT97(`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!0;VQI8VEE<P!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG92!087-S
M=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#
M:&EO<R!!:7)P;W)T`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR>7-O=7!O;&D@06ER<&]R=`!#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@
M35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#
M;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@2&5L<`!#
M;&]S92!(96QP(%=I;F1O=P!#;&]S92!7:6YD;W<`0V]L;&%P<V4@4VED96)A
M<@!#;VQL87!S960@8F]R9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R
M('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD
M`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUP86YY`$-O
M;7!L971E9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET
M:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)A=&EO
M;B!N965D<R!U<&1A=&EN9RX`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O
M<F0`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T(%-E87)C:`!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N=',@;V8@)R5S)P!#;VYT
M96YT<R!O9B!T:&4@4D%2(&%R8VAI=F4`0V]N=&EN=64`0V]P>0!#;W!Y('-E
M;&5C=&EO;@!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP
M="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U
M;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,`0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A
M+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C
M;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@)R5S)RX`0V]U;&0@;F]T(&UK9&ER("<E<R<N`$-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W
M<FET:6YG+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`G
M)7,G+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`G)7,G+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`G)7,G.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`G)7,G.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R961I=',`0W5R<F5N="!0:&%S90!#
M=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U
M<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N
M`$1$`$1A:6QY`$1A=&$`1&%T851R964@0G)O=W-E<@!$871A8F%S92!Q=65R
M>2!F86EL960N`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$
M87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E
M8VQI;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$969A=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@
M<&5R;6ES<VEO;G,`1&5F:6YI=&EO;G,`1&5L96=A=&4@<&]S:71I;VX`1&5L
M96=A=&5D`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`G)7,G`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES('!E<FUI
M<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@)R5S)RX`1&5L:79E<GD@=&EM90!$96YY(')E<75E
M<W0`1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E
M8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`
M1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VX`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R
M=6=S`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO
M;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("<E<R<`16QE9G-I<R!!:7)P;W)T`$5L96UE;G0N
M+BX`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y
M(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N
M9`!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5R<F]R
M`$5R<F]R('-E;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N`$5R<F]R('=R:71I;F<@)R5S)RX`171H;FEC`$5U<F]P90!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S
M`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%
M>'!A;F0@4VED96)A<@!%>'!E8W1E9"`B0D5'24XB(&EN('1H92!L:6YE("5D
M+@!%>'!E8W1E9"`B14Y$.B5S(B!I;B!L:6YE("5D+@!%>'!E8W1E9"`G*2<`
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I
M<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S
M971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D
M('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL=7)E(&EN
M(&-H86YG:6YG('!A<W-W;W)D(&9O<B!U<V5R("5S(&9R;VT@8VQI96YT("5S
M+"!R96%S;VX@)7,`1F%I<@!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E
M96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H
M;W=E<G,`1FEE;&0@;6%T<FEX`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#
M;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E
M;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"X`1FEL=&5R<P!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO
M`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R
M='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S
M`$9R`$9R86UE<P!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E92]"=7-Y(%)E
M<&QY`$9R964O0G5S>2!297%U97-T`$9R964O0G5S>2!297%U97-T(%)E<W!O
M;G-E`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!$97-C
M<FEP=&EO;CH`1G5L;"!-;V]N`$9U;&P@3F%M90!'86QL97)Y('1O('1A:V4@
M:6UA9V4@9G)O;0!'86QL97)Y.@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS
M`$=O`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)O=7`@061M:6YI<W1R
M871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R
M;6ES<VEO;G,`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI
M<W-I;VYS`$=U97-T8F]O:P!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N
M9"X`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES
M<&AE<F4`2&5R86ML:6]N($%I<G!O<G0`2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.@!(:6=H`$AI<W1O<GD@96YT<GD@;F%M97,@;75S="!B
M92!N;VXM96UP='D`2&]?;64`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N
M90!(;W)D90!(;W)D92!,;V=I;@!(;W)D92!3>7-T96T`2&]R9&4@5VER96QE
M<W,`2&]R9&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960`2&]R:7IO;G1A
M;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24Y"3U@`25`@061D<F5S<P!)4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N8F]X`$E?;G-E
M<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W
M:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R
M979I97<Z`$EM86=E(%523`!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O
M;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R=`!);7!O<G0@
M17)R;W(Z(`!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O=R!!9G1E<@!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@
M26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF;P!);F9O<FUA=&EO;@!);G-E
M<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN
M<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H
M92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E
M<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@
M=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E
M;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B
M969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`
M26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E
M<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T
M:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS
M97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N
M`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D
M(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)
M1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y
M<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES
M<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!)
M;G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@)R5S)P!);G9A
M;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ET86QI8P!*86YU87)Y`$IU
M;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*
M=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+86QA;6%T82!!:7)P;W)T`$MA
M<G!A=&AO<R!!:7)P;W)T`$MA<W1O<FEA($%I<G!O<G0`2V5E<"!O<FEG:6YA
M;#\`2V5F86QH;FEA($%I<G!O<G0`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D
M(&%U=&AE;G1I8V%T:6]N+@!+97)K>7)A($%I<G!O<G0`2V5R;F5L($YE=V)I
M97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N`$MI9',`2V]S($%I<G!O<G0`2V]Z86YI($%I<G!O
M<G0`3&%?>6]U=`!,87)I<V$@06ER<&]R=`!,87-T($AA;&8`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87<`3&%Y;W5T`$QE879E
M(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5F=`!,969T(&AE861E<@!,969T('9A
M;'5E<P!,:6UE<FEC:P!,:6UN;W,@06ER<&]R=`!,:6YK`$QI;FL@<&]I;G1S
M('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(
M96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`
M3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I
M;&5D(&9O<B!S;VUE(')E87-O;BX@36]S="!L:6ME;'D@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,;V=O=70`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$U-`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N`$UA;G5A;`!-87`@1&%T92!A;F0@5&EM92!&:65L9',`
M36%P($EM<&]R="!&:65L9',`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*0!-871C:&EN9R!F:65L9',`36%X(&%L;&]W960@
M8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM
M=6T@;&5N9W1H`$UA>0!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN
M9F]R;6%T:6]N`$UE971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T
M:6YG(%5P9&%T90!-965T:6YG(%5P9&%T92!297%U97-T`$UE;6)E<G,`365M
M;W,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE
M<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-
M971H;V0@)R5S)R!I<R!N;W0@9&5F:6YE9`!-971R:6,`36ED9&QE`$UI;64@
M5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V
M(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG
M(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@
M240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D
M:69Y(%523`!-;VYT:"!6:65W`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N
M=&AL>2!%=F5N=',@3&ES=`!-;V]N(%!H87-E<P!-;W9E($1O=VX`36]V92!,
M969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY
M($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37D@4W5M;6%R
M>0!->71I;&EN:2!!:7)P;W)T`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YE
M961S($%C=&EO;@!.971W;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.97<@36]O
M;@!.97<@4&%S<W=O<F0`3F5W(%!A<W-W;W)D("AA9V%I;BD`3F5W(%5S97)N
M86UE("AO<'1I;VYA;"D`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G
M<F]U<',`3F5X=`!.97AT(%!A9V4`3F5X="!0:&%S90!.97AT(&]P=&EO;G,`
M3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA
M;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG
M92X`3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W
M('1H:7,@;&5V96PN`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES
M('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!,1$%0(%!R969E<F5N8V5S+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,($-A=&5G
M;W)I97,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@4')E9F5R96YC97,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(&%U=&AE;G1I8V%T:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO
M(&QO8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M
M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV
M92!F;W)T=6YE<P!.;R!P96YD:6YG('-I9VYU<',N`$YO('!R969E<F5N8V5S
M(&%R92!A=F%I;&%B;&4N`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R
M;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F]N(%!A<G1I8VEP86YT`$YO;F4`3F]N92`H=7-E
M(&EM<&QI8VET*0!.;W)T:&5R;B!(96UI<W!H97)E`$YO="!!9G1E<@!.;W0@
M0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S
M970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T97,@4W5M;6%R>0!.;W1E<R!I
M<R!A;B!A<'!L:6-A=&EO;B!W:&EC:"!A;&QO=W,@>6]U('1O(&-R96%T92!T
M:&4@8V]M<'5T97(@97%U:79A;&5N="!O9B!S=&EC:WD@;F]T97,N($YO=&5S
M(&-A;B!B92!C<F5A=&5D+"!M;V1I9FEE9"P@9&5L971E9"P@86YD('!R:6YT
M960N(%EO=2!C86X@86QS;R!S96%R8V@@;VX@>6]U<B!N;W1E<R!T;R!L;V-A
M=&4@:6YF;W)M871I;VXN(%-U<'!O<G0@9F]R(&EM<&]R=&EN9R!A;F0@97AP
M;W)T:6YG(&YO=&5S(&ES(&%L<V\@879A:6QA8FQE+@!.;W1E<SH`3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EC90!.;W1I9FEC871I;VX@;&ES
M=&5N97(@)7,@;F]T(&9O=6YD+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F
M(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(&-O;'5M
M;G,@:6X@=&AE('-U;6UA<GD@=FEE=SH`3G5M8F5R(&]F(')O=W,`3G5M8F5R
M<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@
M;&ES="X`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E
M<FUI<W-I;VYS`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E
M`$]L9"!087-S=V]R9`!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W
M`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA;"!087)T:6-I<&%N=`!/
M<'1I;VYS`$]P=&EO;G,@9F]R`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES
M=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R
M;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4%](4"!3:&5L;`!0861D:6YG`%!A<W-W;W)D`%!A<W-W
M;W)D(&-H86YG960@9F]R('5S97(@)7,@9G)O;2!C;&EE;G0@)7,`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T($5V
M96YT<R!,:7-T`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N
M9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@)R5S)R!N;W0@9&5L
M971E9"X`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R;6ES<VEO;G,@
M9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E=',`4&AO;F4`4&AO=&]S`%!I
M>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A
M<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R
M;W9I9&4@82!N97<@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('!A<W-W;W)D
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!W:71H($!D;VUA:6X`4&QE87-E(')E860@=&AE(&9O;&QO
M=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@
M=7-E('1H92!S>7-T96TN`%!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I
M;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H
M92!M96YU(&)E;&]W+@!0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H
M92!M96YU(&)E;&]W+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z`%!L96%S92!V97)I9GD@>6]U<B!N97<@<&%S<W=O<F0`4&]S:71I;VYI
M;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C
M961E('EO=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_`%!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO
M;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S
M96YT871I;VYS`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R
M97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<`4')E=FEO=7,@4&%G90!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I
M`%)A9&EO('-E;&5C=&EO;@!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E
M860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!2969R97-H(%-U;6UA<GD@
M5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UE
M;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!296UO=&4@4V5R=F5R
M<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
M4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M
M871T:6YG`%)E;6]V92!F<F]M(&UY(&-A;&5N9&%R`%)E;6]V92!P86ER`%)E
M;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@
M9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<&QY(%-E
M;G0N`%)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E`%)E<&QY('=I
M=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+@!297!L>2!W:71H(')E
M<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E<&QY.B`E<P!297%U
M97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z
M(`!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I
M;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G8F%S
M961N)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!A=71H
M96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G9&%T86)A<V4G
M(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC
M97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E
M8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("=H;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P96-I9FEE
M9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S
M<W=O<F0G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN
M(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D
M)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I
M8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P:'!T>7!E)R!N;W0@
M<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN
M(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=T86)L
M92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=6ED)R!N;W0@<W!E8VEF:65D
M(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U
M:60G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE
M;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U<V5R;F%M92<@
M;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297%U:7)E9"!087)T
M:6-I<&%N=`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W
M;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T=7)N('1O(&UA:6P`
M4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:&]D97,@06ER<&]R=`!2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H
M96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O
M=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T
M:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3
M:&5L;`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M92`H7W-E;&8I
M`%-A;6]S($%I<G!O<G0`4V%T96QL:71E(%!R;W9I9&5R`%-A=F4`4V%V92`E
M<P!3879E("<E<R<`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N`%-C:65N8V4`4V5A
M<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:"!-86EL`%-E87)C:"!297-U;'1S
M`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O
M(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C
M="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!3
M96QE8W0@86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E
M9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD
M('!A<W1E('1H96T@9G)O;2!T:&4@=&5X=&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I
M;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@3&%T97-T
M($EN9F]R;6%T:6]N`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N
M<V]R.B``4V5P=&5M8F5R`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I
M<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"X`4V5T('EO=7(@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3970@>6]U<B!P<F5F97)R960@9&ES<&QA>2!L
M86YG=6%G92X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z(`!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W)T(%-U
M;6UA<GDZ`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAR:6YK`%-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M=`!3:6=N('5P`%-I9VX@=7`@:68@;F]T(')E9VES=&5R960`4VEG;F%T=7)E
M`%-I9VYA='5R92!!;&=O<FET:&T`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-O
M;64@;V8@2&]R9&4G<R!C;VYF:6=U<F%T:6]N(&9I;&5S(&%R92!M:7-S:6YG
M.@!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5D82!!:7)P;W)T`%-O=7)C92!A
M9&1R97-S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A
M;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-T87)T`%-T87)T('EE87(`4W1A=&4@
M;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R
M97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("<E
M<R<@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FIE8W0@4'5B;&EC($ME>2!);F9O
M`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@)R5S)R!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T
M(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S
M9G5L;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+@!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`G)7,G(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D
M(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S
M<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L
M;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U
M8V-E<W-F=6QL>2!U<&1A=&5D("<E<R<`4W5C8V5S<V9U;&QY('=R;W1E("5S
M`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YR:7-E`%-U;G)I<V4O4W5N
M<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P
M<&]R=`!3=7)N86UE`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!4
M86)L92!P<F]P97)T:65S`%1A;F%G<F$@06ER<&]R=`!487)G970Z`%1A<VMS
M`%1A=&]I($%I<G!O<G0`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T
M(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E("<E
M<R<@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!496YT871I
M=F5L>2!!8V-E<'0@<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA;FL@>6]U(&9O
M<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@
M8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F
M;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A
M;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R
M96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RX`5&AE(&UA:6QB;W@@=')A<V@@:7,@86QR96%D>2!E;7!T>2X`5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H
M87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!M97-S86=E('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN`%1H92!R96=I<W1R>2!I<R!H;W<@2&]R9&4@87!P;&EC871I
M;VYS(&9I;F0@;W5T(&AO=R!T;R!T86QK('1O(&5A8V@@;W1H97(N(%EO=2!S
M:&]U;&0@;&ES="!A;GD@:6YS=&%L;&5D($AO<F1E(&%P<&QI8V%T:6]N<R!T
M:&%T('EO=2!H879E(&AE<F4N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&%S
M:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=&5M<&]R
M87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U
M<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('5S97(G<R!F
M<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`
M5&AE;65S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;2X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E
M;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H
M)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E
M<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ
M("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E
M+V)U<WD@:6YF;W)M871I;VXZ("5S+@!4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI
M;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5S<V%L;VYI:VD@
M06ER<&]R=`!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4
M:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`G(S$R,S1A9B<N`%1H:7,@9FEL92!C;VYT<F]L<R!T:&4@9VQO8F%L
M('-E="!O9B!-24U%(&1R:79E<G,@9F]R('1H92!(;W)D92!F<F%M97=O<FLL
M(&%L;&]W:6YG(&%P<&QI8V%T:6]N<R!T;R!M86ME('5S92!O9B!P<F]G<F%M
M<R!S=6-H(&%S(&5N<V-R:7!T(&]R(&US=V]R9'9I97<@=&\@<F5N9&5R(&-O
M;G1E;G0@:6YT;R!(5$U,(&9O<B!V:65W:6YG(&EN(&$@8G)O=W-E<BX`5&AI
M<R!F:6QE(&-O;G1R;VQS('1H92!S='EL97-H965T('1H870@:7,@=7-E9"!T
M;R!S970@8V]L;W)S(&%N9"!F;VYT<R!F;W(@=&AE($AO<F1E(&9R86UE=V]R
M:R!A;F0@86QL(&%P<&QI8V%T:6]N<R!T:&%T(&1O(&YO="!P<F]V:61E('1H
M96ER(&]W;B!S971T:6YG<RX`5&AI<R!F:6QE(&UA<',@9FEL92!E>'1E;G-I
M;VYS('1O(&QO9VEC86P@34E-12!T>7!E<RP@96YA8FQI;F<@2&]R9&4@87!P
M;&EC871I;VYS('1O(&9I9W5R92!O=70@:&]W('1O(&AA;F1L92!S;VUE(&-O
M;G1E;G0@<W5C:"!A<R!E;6%I;"!A='1A8VAM96YT<R!O<B!#5E,@8VAE8VMO
M=71S+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H
M:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4
M;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI
M96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M
M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V
M:7-I="`E<P!4:&ES(&ES('1H92!M86EN($AO<F1E(&-O;F9I9W5R871I;VX@
M9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD(&)A<VEC(&ET96US('1H870@
M87!P;'D@=&\@=&AE(&-O<F4@9G)A;65W;W)K(&%N9"!A;&P@2&]R9&4@87!P
M;&EC871I;VYS+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<')O8FQE;2!R97!O<G0@
M=V%S(')E8V5I=F5D(&9R;VT@)7,N(%1H92!U<V5R(&-L:6-K960@=&AE('!R
M;V)L96T@<F5P;W)T(&QI;FL@9G)O;2!T:&4@9F]L;&]W:6YG(&QO8V%T:6]N
M.B5S(&%N9"!I<R!U<VEN9R!T:&4@9F]L;&]W:6YG(&)R;W=S97(Z)7,`5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:6-K971S`%1I;64`5&EM92!4<F%C
M:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:71L90!4:71L92`H
M=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI
M;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;VUO<G)O
M=P!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I<&]L:7,@
M06ER<&]R=`!4<G5E(&]R(&9A;'-E`%1U`%1Y<&4@;6ES;6%T8V@N`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R
M>2!S=&%T=7,@<F5P;W)T`%523#H`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92`G
M)7,G.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@
M=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E9VES=&5R
M('!R969E<F5N8V5S(&EN('-E<W-I;VXN`%5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(&5N9"!O9B!F:6QE+@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FAA;F1L
M960@8V]M<&]N96YT(&]F('1Y<&4Z("5S`%5N:71S`%5N:VYO=VX`56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T
M=7,`57!D871E('5S97(`57!D871E9"`G)7,G+@!5<&=R861E('-C<FEP="!D
M96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P
M97(@<F]M86X@;G5M8F5R<P!5<V4@0W5R<F5N=#H@)7,`57-E($1E9F%U;'0@
M5F%L=64`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E
M<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92X`57-E<B!P87-S=V]R9"!C:&%N9V4`57-E
M<B!P97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M92`G)7,G(&%L<F5A9'D@
M97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<P!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A
M=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y
M`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@
M<V5L96-T(&9R;VT`5F%R:6%B;&4`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A
M9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65W("5S`%9I97<@86X@97AT
M97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:65W(&5V96YT`%9I97<@=&%S
M:P!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+@!787)N:6YG`%=E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@2&]R
M9&4@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC
M:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I
M9'1H.@!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`
M5VES:&QI<W1S`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2968`
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!9
M65E9`%EE87)L>0!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO
M="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E
M96X@;&]G9V5D(&]U="X`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+CQB<B`O
M/E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T
M851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!%;6%I;"!!
M9&1R97-S.@!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S
M<R!#;VYT<F]L+T]P=&EO;B`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@
M>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F1S(&1O(&YO="!M871C
M:`!9;W5R(')E;6]T92!S97)V97)S.@!;2&ED92!1=6]T960@5&5X=%T`6U!R
M;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R
M871I;VX`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R
M=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B
M;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R
M`&-A;&T`8VQI8VL@:&5R90!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,`:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C
M;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D
M`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!S
M:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S
M:R!L:7-T`'1R87-H`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`%!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4Z(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#(M,3$M,#<@,3(Z,#8K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`T
M+3(V(#$Q.C$S*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!+;VYS=&%N=&EN;W,@
M0RX@36EL;W-I<R`\:VUI;&]S:7-`>6%H;V\N8V]M/@I,86YG=6%G92U496%M
M.B!'<F5E:R`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y
M+3<*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`@QR#C\>'L
M[.'T[^CU\=_DX2`GZMSD[_(G(.7?[>'I(-[DYR#<Y.7IX2X`("8C,34Q.R`E
M<R#%W^WAZ2#G(//TZ>/LWB#MX2#CW^WO]>T@[^D@Z^7I]._U\>/?Y?(@\_7M
M]-[QY_/G\B#P[_4@Y=_MX>D@Y?#IZ^7C[-WMY?(@\.'QX>K<]/DN`"`H\/'I
M[2#A\/P@)7,@Y^S=\>7R*0`@*,KKY>GDWR#P\?SSXN'SY_(@)7,I`"`H\^4@
M)7,@Y^S=\>7R*0`@*//>[.7QX2D`("CA_?'I[RD`("CWZ.7R*0`@\_3I\B``
M)60@)7,@ZN'I("5S`"5D+>SE\><@\/'\XNOE^.<`)7,@+2#3Y^SEW_GSYP`E
M<RW$Z>'WY=_QZ?/G`"5S(,3AZO3UZ^GJ_"#A\._T_?#Y[.$`)7,@R^7I]._U
M\>/?Y?(@T_7M]-[QY_/G\B`M(,7PZ>+EXN'?^?/G`"5S+=#A\>'LY?3Q[_#O
MW^?SYP`E<R#%X^/QX?;>`"5S(,_Q[^D@]_'>\^?R`"5S(-[DYR#U\-SQ]^7I
M+@`E<R#SY2`E<R`E<P`E<R#AZO7Q_NCGZN4@)7,N`"5S(.'PW.WTY_/E(//E
M(.7Q_O3G[.$@Y.GAZ.7SZ>S\].?TX?(N`"5S(.'PW.WTY_/E(//TY^T@\/'\
M\^KKY_/G(./IX2`E<RX`)7,@\^'R(-WS].7IZ^4@\.OG\>_V[_'?Y?(@Y.GA
MZ.7SZ>S\].?TX?(N`"5S(.7?[>'I(.'PX>GT[_WLY>WO`"5S(.OE\/3<`"5S
M(//A\B#FWO3G\^4@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(N`"5S(.;>
M].?SY2#TY^T@\.'Q[_7SW^$@\^'R(//TZ?(@)7,N`"5S(/GR("5S(.'P_"`E
M<P`E<R#E\.GH]>SEWR#TY^T@\/'O\^C>ZN<@\_3O("5S+@`E<R#E\.GH]>SE
MWR#MX2#SX?(@Y>WG[.7Q_O/EZ2#CZ>$@)7,N`"5S(.7PZ>CU[.7?(.WA(.O<
MXN7I(/3I\B#TY>OE]?3AW^7R(/#KY_'O]N_QW^7R(./IX2`E<RX`)7,G<R#$
MZ>7UZ/7M\^GOX_'<]N_R`"5S)W,@Q^SE\>_K_./I[P`E<W,@T^?LY>GY[.'T
MW/'I[P`E<W,@R]_S].$@Q?'CX?/I_NT`)R5S)R#DY>T@Y=_MX>D@W>/J]?'G
M(.7PZ>OOX]XN`"<E<R<@Y.7M(-WWY>D@\?7H[.GS].7?(//T[R!R96=I<W1R
M>2#TY_(@Y?;A\>SOX][R($AO<F1E`"5S(.'MX?#A\>'S]-STY_(@Y.7MY/'I
MZM[R(.3O[-[R(.3E[2#B\=WHY^KE+@`G)7,G(/#Q[_/TW>CGZN4@\_3I\B#O
M[-SDY?(@\_7S]-[LX?3O\BX`)R5S)R#P\>_S]-WHY^KE(//TZ?(@W.3EZ>7R
M(/3O]2#S]?/TWNSA]._R+@`G)7,G(.3E[2#DY^SI[_7QX][HY^KE.B`E<RX`
M+"!G=7-T:6YG("5S("5S`"P@[.7TX>+KY_3>(.'P_"`E<R#SY2`E<P`M+2#E
M\.GK[^/>("TM`#$R^?'G(.SO\?;>`#(T^?'G(.SO\?;>`#(T(/[QY?(`/&(^
MT.'Q[_7SZ=SS].?JY2#=[>$@\^_BX?'\(.O<Z._R.CPO8CX`T.'Q[_7SZ=SS
MZ.?JY2#J\=_SZ>SO(.O<Z._R`,'PX>GTY=_TX>D@Y.?L_//I[R#JZ^7IY-\@
M4$=0(./IX2#TY^T@ZO'U\/3OX_'<]N?SYR#E[?SR(.SG[?WLX?3O\BX`P?#A
MZ?3EW_3AZ2#DY^S\\^GO(.KKY>GDWR!01U`@X^GA(.7PZ>+EXN'?^?/G(.7M
M_/(@]?#OX^7C\>'L[-WM[_4@[.?M_>SA]._R+@#!\.'I].7?].'I(.3G[/SS
MZ>\L(/#Q[_/Y\.GJ_"!01U`@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA
M(.WA(.'P[^KQ]?#T[^/QX?;>\^7TY2#=[>$@[-[M]>SA+@#!\.'I].7?].'I
M(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!01U`@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ
M_/(@X^GA(.WA(/7P[^/QW/CE].4@^.?VZ>'JW"#=[>$@[-[M]>SA+@#!\.'I
M].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!3+TU)344@ZNOEZ>3?(.KAZ2#K
MW>[G+>KYY.GJ_/(@X^GA(.WA(.'P[^KQ]?#T[^/QX?;>\^7TY2#=[>$@[-[M
M]>SA+@#!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!3+TU)344@ZNOE
MZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA(/7P[^/QW/CE].4@^.?VZ>'J
MW"#=[>$@[-[M]>SA+@#!\.'I].7?].'I(.3G[/SSZ>\@ZNOEZ>3?(%,O34E-
M12#CZ>$@].?M(.KQ]?#T[^/QW/;G\^<@Y>W\\B#LY^W][.'T[_(N`/#L+^SL
M`-#E\=\@X?7T[_T@]._U(,KEZ>SE[>_C\=SV[_4`T.7QWRXN+@#!\/SK]?3O
M(/3=Z^_R`,'P_.OU].<@S-WSYP#!\._D[_?>(.'I]-[LX?3O\@#%X^GMY2#A
M\._DY>KT_`#'(/#Q_//BX?/G(.'P[_'QW_;HY^KE(.KA]-P@].<@Y.?LZ>_U
M\>/?X2!61E,@ZN'TX>O\X^_U+@#'(/#Q_//BX?/G(.'P[_'QW_;HY^KE(.KA
M]-P@].<@Y.?LZ>_U\>/?X2!61E,@X?'WY=_O]2X`ROGDZ>K\\B#+[^/A\>GA
M\^SO_0#/(.OOX^'QZ>'S[/SR(/#<X_GSY2X`RN'TX>/QX?;>`,7MW?'CY>GE
M\@#0\>_SZ-[JYP#0\>_SZ-[JYR#U\._O[-SDX?(`T/'O\^C>ZN<@W.3EZ>'R
M(/7P[^_LW.3A\B`H8VAI;&0@<&5R;6ES<VEO;BD`T/'O\^C>ZN<@Y>3^.@#0
M\>_SZ-[JYR#-W>'R(,_LW.3A\@#0\>_SZ-[JYR#MW>'R(-SDY>GA\@#0\>_S
MZ-[JYR#U\._O[-SDX?(@\_3O("<E<R<`T/'O\^C>ZN<@W.3EZ>'R("AP97)M
M:7-S:6]N*2#U\._O[-SDX?(@\_3O("<E<R<`T/'O\^C>ZN<@[=WO]2#W\=[S
M].<Z`-#Q[_/HWNKG(//TWNOG\@#0\>_SZ-[JYR#MW>_U(.S=Z^_U\@#0\>_S
MZ-[JYR#FY?WC[_7R`-#Q[_/HWNKG(/3O]2`E<R#S].\@[.7M[_T@]._U($UO
M>FEL;&$`T/'O\^C>ZN<@X?7T[_T@\_3O(.?LY?'OZ_SCZ?P@[._U`-#Q[_/H
MWNKG(//T[R#$Z>7UZ/7M\^GOX_'<]N\Z`-#Q[_/HWNKG(//T[R#$Z>7UZ/7M
M\^GOX_'<]N\@[._U`-#Q[_/HWNKG(/?QWO/TYP#0\>_S]-WHY^KE("<E<R<@
M\_3O(//]\_3G[.$L(.'KZ]P@Y.7M(.SP_/'E\^$@[>$@\/'O\^C=\_D@\_7L
M\.OG\?GLX?3IZMWR(/#KY_'O]N_QW^7R`-#Q[_/TW>CGZN4@)R5S)R#S].\@
M\_WS].?LX2X@S/#O\>7?].4@[>$@\_7MY.7HY=_TY2#T_O'A+@#'(/#Q[_/H
MWNKG(/?QY_/T_NT@W??EZ2#A\.7MY?'C[_#OZ>?HY=\N`,3IY?WH]>WSYP#$
MZ>7UZ/7M\^GOX_'<]N_R`,3IX??EW_'I\^<@+2#$_O/TY2#DZ>KAZ?[LX?3A
M(//E(-SKZ^_U\B#W\=[S].7R`,3IX??EW_'I\^<`P>7Q[^OI[-WMX?(@P>KT
MW^_U`,'E\>_KZ>S>[2#!Z^7NX>WD\>_]\._KY_(`V.7UY/[M]>SO`,7UZ/7C
M\=SL[.GSY0#%]>CUX_'<[.SI\^<Z`,_KX0#/Z^_I(._I(-WCZO7Q[^D@]_'>
M\_3E\@#/Z^7R(._I(,_LW.3E\@#/Z^$@].$@Y.GJX>G^[.'TX0#*X>D@[^D@
M]-WS\^7QZ?(@*#0I(/#KY?7QW?(`S>$@Y?#I]/'=\._M].'I(/#OZ^OA\.O=
M\B#DZ>7UZ/WM\^7I\@#-X2#E\.GT\=WP[^WTX>D@\?7H[-_SY>GR(/3A[NGM
M[^SI[-WM^>T@Z^GS]/[M.P#'Y.<@]?#<\??EZ0#%[>'KZ^'J].GJWB!)35-0
M(,7?\^_D[_(`Q>WAZ^OAZO3IZOSR($E-4U`@ROGDZ>K\\@#%[>'KZ^'J].GJ
M_"!)35-0(+SM[^SA(-?QWO/TYP#%[>'KZ^'J].GJWB#DZ>7]Z/7M\^<@96UA
M:6P`Q>WAZ^OAZO3IZMP@\/'\]/7PX0#%[>'KZ^'J].GJ_"#JY=_LY>WO.@#/
M\=_S].?JY2#LW^$@[.<@Y?#I]/'E\/SLY>WG(/3I[-XN`,'E\>_KZ>S=[>'R
M(,'C]]_AZ^_U+@#!Y?'OZ^GLW>WA\B#![>3QX>+?Y.'R+@#![?[M]>SO\B#$
MZ>'L[.7S[^OAXN?TWO(@*%!R;WAY*0#!\-SM].?SYP#%]N'Q[._CW@#+W_/T
MX2#%]N'Q[._CWO(`QR#E]N'Q[._CWB#EW^WAZ2#=]._I[.<N`,7VX?'L[^/>
M(.KAZ2#S].$@Y>[A\?3^[.7MX2#J[^GM_/?QY_/TX0#%X^KQW^WY`,'P\=_K
MZ>_R`,'E\>_KZ>S=[>'R(,'QW.[O]0#,W>/EZ._R(.'Q]^7?[_4@X?'WY>GO
MZ-WTY_/G\@#/[>_LX2#A\??EW^_U(.'Q]^7IZ-WTY_/G\@#%W_/TY2#SW^/O
M]?'G(./IX2#TYR#DZ>'C\>'VWB#TY_(@X=_TY_/G\B#U\._C\>'VWO(@X^GA
M("5S(#\`Q=_S].4@\]_C[_7Q[^D@_/3I(.C=Z^7TY2#MX2#DZ>'C\=SXY?3E
M("<E<R<@ZN'I(/SKY?(@].GR(/7P[^_LW.3E\C\`U-WW[><`05-#24D@U-WW
M[><`S>$@YN?TY=_TY2#E\.GBY>+AW_GSYR#P\=_M(.'P_"#JW.CE(.7MW?'C
MY>GA(.3IX??EW_'I\^?R.P#![=SHY?/G(//TY^O^[0#!Y?'OZ^GLW>WA\B#!
MZ.?M_NT`U.\@\_7MY^SLW>WO(.7?[>'I(-WMX2#A\??EW^\@Y^SE\>_K[^/?
M[_4@\^4@X?#<[?3G\^<@X>GTWNSA]/SR(//A\@#0\>_S\-SHY>GA(.3IX>/Q
MX?;>\B#LYR#U\.'QZO3>\B#O[-SDX?(N`-#Q[_/PW.CEZ>$@Y.GAX_'A]M[R
M(.SG(/7PX?'J]._](.3IZN'I_NSA]._R+@#0\>_S\-SHY>GA(.7PY>[E\>/A
M\]_A\B#LYR#U\.'QZO3O_2#DZ>KAZ?[LX?3O\BX`T/'O\_#<Z.7IX2#E\.7N
MY?'CX?/?X?(@[.<@]?#A\>KT[_T@Y.GA[._I\>'S[-WM[_4N`-#A\>7U\>GS
MZOSLY>WOZ0#)Y.G\].?TY?(`P?WC[_7S]._R`,<@X?7HY>WTZ>KO\._?Y_/G
M(.'PW?3U]^4`QR#A]>CE[?3IZN_P[]_G\^<@X?#=]/7WY2X@)7,`QR#A]>CE
M[?3IZN_P[]_G\^<@X?#O\?'?]NCGZN4@X?#\(/3O[2!2041)55,@<V5R=F5R
M+@#'(.'UZ.7M].GJ[_#OW^?SYR#S]._M($944"U397)V97(@X?#=]/7WY2X`
MQ.GAZ-WSZ>SA(-#EY-_A.@#![>'LW>WO[?3A\B#A\-SM].?SYP#5\/SBX>CQ
M[P#7\?[LX2#U\/SBX>CQ[_4`R]SH[_(@2V5R8F5R;W,MZOGDZ>K\\BX`R]SH
M[_(@2V5R8F5R;W,MO.WO[.$@U_'>\_3G+@#!Y.7I[P#/(.K]\>GO\B#JX?3<
MZ^_C[_(@X_'A]NGJ_NT@)R5S)R#DY>T@XO'=Z.?JY2X`PN'SZ>K>(./QX>SL
MW@##Y>W=Z.OIX0#4[R#T[-[LX2`B)7,B(/3G\B#E]N'Q[._CWO(@(B5S(B#D
MY>T@XO'=Z.?JY2X`T?7H[-_SY>GR(/3LWNSA]._R`-3]\._R(/3LWNSA]._R
M`+CM]._MX0"\\>GA`,KAZ2#TX2#D_>\`RN'T_O3A].\`R]_S].$@[.4@].7K
MY=_E\@#3Y^SEW^$@Y.GA[>_LWO(@0U),`,'Q]^7?[R#JY>GLW>WO]2#W^?'I
M\^S=[>\@[.4@ZOSL[.$@*$-64RD`R>3I_/3G].7R(,KEZ^G^[2XN+@#'[.7Q
M[^O\X^GO`-#E\=_KY_CG(,?LY?'OZ_SCZ>_U`,?LY?'OZ_SCZ>\Z`,?QY>S?
MX0#!Y/WMX?3G(.<@X?'WZ>KO\._?Y_/G(/3O]2#J^>3IZN_](.'U]/SLX?3A
M+"#E\.GJ[^GM^>W>\_3E(.SE(/3O(.3IX??EZ?'I\_3>`,'D_>WA].<@YR#S
M_>WDY?/G(.SE(/3O[2!)34%0+5-E<G9E<CH@)7,`P>K]\?GSYP#!ZOWQ^?/G
M(,'MX?;O\=SR(-#Q[^+KWNSA]._R`,'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@
MX?'WY=_O]2`B)7,B+@#$Y2#B\=_SZOD@\/'O\_GQZ>W\(/;<ZN7K[R`H=&5M
M<"!D:7(I+@#!Y/WMX?3G(.<@\_7MW??EZ>$@]_GQW_(@].?M(/#A\=SLY?3Q
M[R`B=&%R9V5T1FEL92(N`,'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@]N'JW>OO
M]2`B)7,B+@#!Y/WMX?3G(.<@Y.GAX_'A]MXL("5D(/7P]MSJY>OO\B#U\-SQ
M]^7I+@#!Y/WMX?3G(.<@Y?#A[>'TX>[I[?SLY_/G+"#O(.'QZ>CL_/(@]/GM
M(.7CX_'A]O[M(/#O]2#D_O/A].4@X^GA(.7PX>WA].'NZ>W\[.?SYRP@Y.7M
M(/3AZ?'IW.;EZ2#LY2#T[^T@X?'IZ.S\(/3Y[2#A\._HY^KE]>S=[?GM+@#$
MY2#L\._Q_B#MX2#D\>_L[^OOX][S^2#LWNWU[.$@\_3O[2#A\>GH[/P@\._U
M(._QW_/A].4N`,7PZ>KE]N'KW^3A`,KA].?C[_'?Y?(@ZN'I(,7TZ>K=].7R
M`,KI[>?T_"#4Y^O=]OGM[P#)Y.G\].?TY?(@RN7KZ>_]`,/=[.GS[.$@RN7K
MZ>_].@#)Y.G\].?TY?(@RN7KZ>_]`,3IW.KE[>\@RN7KZ?[M.@#*Z>WG]/P@
MU.?KW?;Y[>\`RMWM]/'O`,OE\/3O[-WQY>GE\B#0Z?/T[_#OZ>?TZ>KO_0#0
M[^OI].GJWB#0Z?/T[_#OZ>?TZ>KO_0#0\?SEY/'O\@#!Z^OAX]X`P>OKX>/>
M(.KYY.GJ[_T`P>OKW.[TY2#T[R#\[>_LX2#JX>D@].<@Y.GE_>CU[?/G(/#O
M]2#HX2#BZ]WP[_7M(/STX>T@Y.GAXMSF[_7M(-X@X?#A[?3O_>T@\^4@[.?M
M_>SA]-P@\^'R`-?A\>'J]-[QX?(`N.OEX_?O\B#S_>WDY?/G\BXN+@#3Y^SE
MZ?[S].4@].\@].7T\>'C^>W?Y.GO(./IX2#O\._IX>3>\._TY2#E\>/A\]_A
M*.7R*2#HW>OE].4@[>$@Y>KTY>OE\_3O_>T@X?7TWB#TYR#S].GC[-XN`,'E
M\>_KZ>S=[>'R(-??[_4`Q?#IZ]WN].4@Q?;A\>SOX]XZ`,7PZ>O=[O3E(.KY
MY.GJ_`#%\.GKW>[TY2#\[>_LX2#W\=[S].<`Q?#IZ]WN].4@[.GA(.7MW?'C
MY>GA.@#%\.GKW>[TY2#P^?(@Z.$@Y>SVX>W?YN_M].'I(._I(.?LY?'O[.?M
MW^7R.@#%\.GKW>[TY2#T_?#O(.O?\_3A\B`HX^GA(/3A[NGM[^SG[-WMY?(@
MZ]_S].7R*0#!Y?'OZ^GLW>WA\B#7\?7S[_WP[^OG\@#$Y>T@XO'=Z.?JY2#O
M\>GS[/SR(.KKW//G\B#T[_4@)7,N`,KAZ-SQZ?/E`,KAZ.'QZ?/L_/(@Y?3I
MZN7T_NT@*'1A9W,I($U3+4]F9FEC90`GP>3EZ>'S[.$G(-?QWO/TYSH@)7,`
MRN'HX?'I\^S\\B#7\=[S].<`RN'HX?'I\^S\\B#DY>3O[-WM^>T@]_'>\_3G
M`,K<[?3E(.KKZ>H@X^GA(//U[=WWY>GA`,KKY=_SZ>SO(,+OWNCEZ>'R`,KK
MY=_SZ>SO(-#A\=SH]?'O]2#"[][HY>GA\@#*Z^7?\^GL[R#0X?'<Z/7Q[_4`
MP>WAY-_PZ_GSYR#0Z^7U\>GJWO(@S/#<\>'R`,'MX>3I\.OY[-WMX2#0Y?'I
MZ/[QZ>$`U_'^[.$`Q?#IZ]WJ].?R(-?Q_NSA]._R`,7PZ>OOX]X@U_'^[.'T
M[_(`T_3>Z^7R.@#4W_3K[^D@T_3GZ_[M`$-O;6EC<P#%[?3OZ]X`RMWK]?;O
M\B#%[?3OZ_[M`-/W_.OI[P#*[^GM_""\[>_LX0#%].'I\>7?X0#/Z^_JZ^?Q
M_NCGZN4`T_WMZ.7SYR#,Y^W][.'T[_(@*"5S*0#5\._K[^/I\_3=\@#3]>WH
MWNKE\@#$Z>'V[_'=\B#0X?'A[.7T\>_P[]_G\^?R`,7PZ>OOX]WR(./IX2#S
M]>/W\>_MZ?/L_"#LY2!01$%S+"#=[O7P[>$@U.?KW?;Y[>$@ZN'I($]U=&QO
M;VLN`$1I92!+;VYF:6=U<F%T:6]N(&UU<W,@86MT=6%L:7-I97)T('=E<F1E
M;BX`QR#PX?'A[.7T\>_P[]_G\^<@]_'EZ=SFY?3AZ2#E[>?LW?'Y\^<N`-#A
M\>'LY?3Q[_#OW^?SYR`E<P#%\.GBY>+AW_GSYR#*^>3IZN_]`,<@\_WMY.7S
MYR#A\-WT]??E+@#'(//][>3E\^<@X?#=]/7WY3H@`,'Q[>?SYR#S_>WDY?/G
M\B#A\/P@].\@Y.?L_//I[R#E[O7PY_'E].?TWB#JZ^7IY.G^[2X`P?'MY_/G
M(//][>3E\^?R(.'P_"#T[R#DY^S\\^GO(.7N]?#G\>7TY_3>(.KKY>GDZ?[M
M+B#+_./O\B`Z("5S("@E<RD`QR#S_>WDY?/G(.SE(/3O($944"U397)V97(@
MX?#=]/7WY2X`P>WAYM[TY_/G(,7PX?;>\@#/Z2#E\.'VW?(@\/'O\_3=Z.?J
MX>T@Y?#I]/7W_O(@\_3O(,3IY?7H]>WSZ>_C\=SV[R#SX?(N`-#E\>GE]_SL
MY>WA(/3O]2`G)7,G`-#E\>GE]_SLY>WA(/3Y[2#A\??EW_GM(%)!4@#3]>W=
M]^7IX0#![?3IX_'A]MX`P>WTZ>/QX?;>(,7PZ>OOX][R`,'D_>WA].<@YR#J
M\?7P]._C\=SVY_/G(/3O]2#LY^W][.'T[_(@[.4@4$=0+@#!Y/WMX?3G(.<@
M]?#OX_'A]MX@]._U(.SG[?WLX?3O\B#LY2!01U`N`,'D_>WA].<@YR#J\?7P
M]._C\=SVY_/G(/3O]2#LY^W][.'T[_(@[.4@4R]-24U%+@#!Y/WMX?3G(.<@
M]?#OX_'A]MX@]._U(.SG[?WLX?3O\B#LY2!3+TU)344N`,3E[2#L\/SQY?/A
M(.WA(/#Q[_/HW?/Y(/3G[2#E\.'VWBX@)7,`P>3][>'TYR#G(//][>3E\^<@
M[.4@].\@3$1!4"U397)V97(N`,'D_>WA]._R(.\@W>OEX^_R(/7P[^OOW_#O
M]2X@)7,`P>3][>'TYR#G(//][>3E\^<@\_3O[2#E[O7PY_'E].?TWB`G)7,G
M(/?QY_/I[/#OZ?[M].'R($944#H@)7,`P>3][>'TYR#G(.3G[.GO]?'CW^$@
MZ]_S].'S(.3IX>WO[-[R+B`E<P#!Y/WMX?3G(.<@X?#OZO'U\/3OX_'<]N?S
MYR!01U`@Y.7D[^S=[?GM+@#!Y/WMX?3G(.<@X?#OZO'U\/3OX_'<]N?SYR!3
M+TU)344@Y.7D[^S=[?GM+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@Y?#A]M[R+B`E
M<P#!Y/WMX?3G(.<@Y.GAX_'A]MX@Z]_S].'R(.3IX>WO[-[R+B`E<P#!Y/WM
MX?3G(.<@Y.GAX_'A]MX@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)R`N`,3E
M(.SP[_'^(.WA(.3IY?7J\>GMWO/Y(/3G(.3IY?WH]>WSYR#T[_4@\.'QX>O>
M\/3G+@#!Y/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G(/3O]2#$Z>7UZ/7M\^GO
MX_'<]N_U+@#!Y/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G(/3G\B#KW_/TX?(@
MY.GA[>_LWO(N`,'D_>WA].<@YR#PZ][QY_(@\/'\\^+A\^<@Z]_S].'R(.'P
M_"#KW_/TY?(@Y.GA[>_LWO(N`,'D_>WA].\@].\@]OSQ]/GLX2#S]/'A].?C
MZ>K>\B`B)7,B+@#!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2#VX>K=Z^_U("(E<R(N
M`,'D_>WA].<@YR#A[=SJ].?SYR#DY^S\\^GO]2#JZ^7IY.GO_2#A\/P@]._M
M(.7N]?#G\>7TY_3>(,3G["[*Z^7IY.G^[2X`P>3][>'T[R#T[R#<[>_IX^SA
M("5S+@#!Y/WMX?3O(/3O(-SM[^GC[.$@(B5S(B#CZ>$@Y>/C\>'VWBX`P>3]
M[>'T[R#T[R#<[>_IX^SA(/3O]2#LW?'O]?(@Q.GA]^7?\>GSY_(@)7,`Q.7M
M(.SP[_'^(.WA(.'M[]_N^2#T[R#VW.KEZ^\@(B5S(BX`Q.7M(.SP[_'^(.WA
M(.3IX>+<\_D@)7,N`,'D_>WA].<@YR#A\??IZN_P[]_G\^<@]._U(.KYY.GJ
M[_T@X^GA(/3O[2#AZ?3O_>SE[>\@]_'>\_3G+B#*W/#OZ>$@WB#\Z^7R(._I
M(.OE\/3O[-WQY>GE\B#DY>T@Y=_MX>D@\_GS]-WR+B#.X>WAY._JZ>S<\_3E
M(-X@Y?#IZN_I[?GMWO/TY2#LY2#T[R#DZ>'WY>DM\>GS]-X@X>T@]_'EZ=SS
MY?/HY2#PY?'I\_/\].7QYR#B[][HY>GA+@#!Y/WMX?3G(.<@X>W<ZO3G\^<@
MR]_S].'R(,KA[?SM^>T@T/'\\^+A\^?R("A!0TPI`,'D_>WA].<@YR#A[=SJ
M].?SYR#$Z>7UZ/7M\^GOX_'<]N_U+B`E<P#!Y/WMX?3G(.<@X>W<ZO3G\^<@
MR]_S].'R(,3IX>WO[-[R+B`E<P#!Y/WMX?3G(.<@X>W<ZO3G\^<@R^GS]/[M
M(,3IX>WO[-[R+B`E<P#!Y/WMX?3G(.<@X>W<ZO3G\^<@]/GM(.GDZ>_TWO3Y
M[2#T[_4@Y>[U\.?QY?3G]-X`P>3][>'TYR#G(.7PX>WA]N_QW"#Q]>CLW_/E
M^>TN`,'D_>WA].<@YR#DZ>'C\>'VWB#VX>K=Z^_U("AR;61I<BD@(B5S(BX`
MQ.4@[/#O\?X@[>$@X?#OZ.?JY?WS^2`E<R#Q]>CLW_/EZ?(N`,3E(.SP[_'^
M(.WA(.K<[?D@Y?;EY/'IZOP@X>WTW^/QX?;O(/3Y[2#Q]>CLW_/E^>TN`,3E
M(.SP[_'^(.WA(.K<[?D@Y?;EY/'IZOP@X>WTW^/QX?;O(/3Y[2#Q]>CLW_/E
M^>TZ("5S`,3E(.SP[_'^(.WA(.'P[^CGZN7]\_D@\/'\X_'A[.SA(.7MY^S=
M\?GSY_(@\_3O("<E<R<N`,3E(.SP[_'^(.WA(.'P[^CGZN7]\_D@Y?;EY/'I
MZOP@X?'WY=_O(/'UZ.S?\^7Y[2`E<RX`Q.4@[/#O\?X@[>$@X?#OZ.?JY?WS
M^2#T[R#A\??EW^\@\?7H[-_SY?GM("5S+B#,\._QY=_TY2#EW_3E(.WA(/?Q
MY_/I[._P[^G>+?/E].4@[.GA(.'P_"#TZ?(@Y?#IZ^_CW?(@X^GA(.WA(.'P
M[^CGZN7]\^7TY2#PW_/Y(//T[R`E<R#>(.'M].GC\=SX].4@[.4@].\@]]WQ
MZ2#T[^T@ZO[DZ>KA(/#?\_D@\_3O("5S+@#!Y/WMX?3G(.<@X>WAYM[TY_/G
M(//T[^T@Y>[U\.?QY?3G]-X@3$1!4"X`Q.4@[/#O\?X@[>$@X?#O\_7MY-WS
M^2`B)7,B+@#$Y2#L\._Q_B#MX2#E[>?LY?'^\_D@].?M(.7PX?;>+B`E<P#$
MY2#L\._Q_B#MX2#E[>?LY?'^\_D@].<@R]_S].$@Q.GA[>_LWO(N("5S`,3E
M(.SP[_'^(.WA(./QW/CY(/3I\B#Q]>S?\^7I\B#CZ>$@)R5S)SH@)7,`Q.4@
M[/#O\?X@[>$@XO'^(/3G(/#KY?7QZ>K>(.SPW/'A(/3O]2!-;WII;&QA+B#"
MY>+AZ?GHY=_TX>D@_/3I(.7?[>'I(.'M[^GJ]-XN`,3E(.SP[_'^(.WA(.3^
M\_D@\_3O(/?QWO/TYR`G)7,G(/3A(/#A\>'JW/3Y(.3IZN'I_NSA].$@\_3O
M(/;<ZN7K[R`G)7,G.B`E<P#,Y?3QY^S=[>\@ZN7?[.7M[P#7_O'A`-#O\>7?
MY?(`Q.?LZ>_U\>/?X0#$Y^SI[_7QX]_A(.7M_/(@\_7MY-WS[._U`,3G[.GO
M]?'CW^$@[.GA\B#MW>'R`,3G[.GO]?'CW^$@]?#O]N'JW>OY[0#%[N_U\^GO
MY._TWO/EZ?(@Q.?LZ>_U\>/O_0#!\>GH[/SR(-#I\_3Y].GJWO(@RMSQ].'R
M`,7U]^'QZ?/TW^7R`-3QW??O]?/A(-;<\^<`U/'=]^_U\^$@_O'A`-3O(/3Q
MW??O[2!54DP@Y=_MX>D`U/'=]^_M(,KAZ?'\\@#4\=WW[_7SX2#S]>WHWNKG
M.B``U/'=]_GM(//T_>L`T.'QX>SE]/'O\._?Y_/G(.3IX>3IZN'SZ?[M(/#O
M]2#EZO3EZ^_][?3AZ2#JX?3<(/3G[2#EW_/OY.\@)7,N`,'P[^KO\-X`P?#O
MZN_PWB#E\.GK[^/>\@#,S`#'[.7QWO/IX0#$Y>3O[-WMX0#%[/;<[>GSYR`H
M0G)O=W-E<BD@1&%T851R964`QR#A[>'FWO3G\^<@\_3G(,+<\^<@Q.7D[^S=
M[?GM(.'PW?3U]^4N`,?LY?'O[.?MW^$`Q^SE\>_LY^W?X2#PX?'AZ^'BWO(`
MQ?#IZ^_CWB#'[.7Q[^SG[=_A\@#'[-WQX0#$Z>'C\>'VWB#3]-[KY_(`Q.7J
MW>SB\>GO\@#$Y>KAY.GJ[]\@X?'IZ.SOWP"X]^_U[2#A\>WGZ.7?`,SEW_GS
MYR#0Y?'IZ/GQW^_U`-#Q[^KAZ._QZ?/LW>WO`-#Q[^7PZ>OEX^S=[>\@U_'^
M[.$`T/'OY?#IZ^7C[-WMYR#4X?7T_/3G].$`T/'OZN'H[_'I\^S=[>7R(,7N
M[_7SZ>_D[_3>\^7I\@#0\>_JX>CO\>GS[-WMY?(@Q>[O]?/I[^3O]-[SY>GR
M`,_QZ?/L[]\`R-WSYR#A[?3I\/'O\_[P[_4`P>WTZ?#Q[_/Y\.?LW>WO`,3I
MX>/QX?;>`,3IX>/QX?;>(,_LW.3A\@#$Z>'C\>'VWB#%[N_U\^GOY/STY_/G
M\@#$Z>'C\>'VWB#JX>D@Y>KJW>WY\^<@[.?M]>S<]/GM`,3IX>/QX?;>(.KE
MZ^GO_0#$Z>'C\>'VWB#3]-[KY_(`Q.GAX_'A]MX@]?#<\??O[?3O\B#E[>'K
MZ^'J].GJ[_T@\/'O]/WP[_4`Q.GAX_'A]MX@Y>[O]?/I[^3O]-[SY?GM(./I
MX2`G)7,G`,3IX>/QX?;>(.7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)R5S)R#JX>D@
MZMSHY2#U\.\MY>[O]?/I[^3\].?SYSL`Q.GAX_'A]MX@\_3>Z^?R`-#Q[^7P
MZ>OEX^S=[><@U.'U]/STY_3A`,3IX>/QX?;>(/3QW??O]?/A\B#S]-[KY_(`
MQ.GAX_'A]MX@]/'=]^_U\^'R(./QX>SLWO(`Q.GAX_'A]MX@X?7TWO(@].?R
M(.7N[_7SZ>_D_/3G\^?R(.KAZ2#JW.CE(/7P[RWE[N_U\^GOY/STY_/G\CL`
MQ.GAX_'<]N?JY2#T[R!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@"_\>$@
MW/;I[N?R`,'Q[>?SYR#AZ?3>[.'T[_(`P?'MY_/G(.'I]-[LX?3O\B#CZ>$@
M\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(`T.7QZ>/QX?;>(/3O]2#0\>_B
MZ][LX?3O\@#0Y?'IX_'A]MX`R^7P]._LW?'EZ>7R("CE\-_SY_(@ZN'I(//T
M[R#A\??EW^\@ZN'TX>/QX?;>\B#T[_4@2&]R9&4I.@#/Z2#KY?#T[^S=\>7I
MY?(@W??O]>T@ZN'TX>/QX?;EWR#CZ>$@]._M(.3IX??EZ?'I\_3>+@#![=SP
M]/7NYP#3Y^SEW^\@Q/'O\^G<\@#3Y^SEW^\@Q/'O\^G<\B#CZ>$@].?M(/3E
MZ^7U].'?X2#^\>$Z(`#3Y^SEW^\@Q/'O\^G<\CH@`,KA].7]Z/7M\^<@X?#\
M(.'QZ?/TY?'<(/#Q[_(@].$@Y.7NZ=P`RN'TY?WH]>WSYR#A\/P@].$@Y.7N
MZ=P@\/'O\B#TX2#A\>GS].7QW`#*X?3<Z^_C[_(`Q>SVW.WI\^<@_O'A\B#S
MY2`R-/GQYR#L[_'VWCL`Q?#IZ^_CW?(@Q>SVW.WI\^?R`,7L]MSMZ?/G(/#Q
M[^+KW?CE^>T@*%1!1BD`S._Q]MX@Q>SVW.WI\^?R`,7MY^S=\?GSYR#$Z=ST
MX>[G\@#,YR#DZ>'C\=SVY>GR`,SG[2#E\.GWY>GQWO/E].4@[>$@X>WOW^[E
M].4@X?#E]>CEW^'R(/3O(.'Q]^7?[R!M86EN=&5N86YC92YP:'``T.7QZ=WW
MY>D@YR#P\?[TYR#C\>'L[-X@[^W\[.'TX2#PY>3?^>T[(,'M(.WAZ2#T\^7J
MW/'E].4@X?7T_#H`RN'TW>+A\^SA`,KA]-WBX?/LX2`E<P#*X?3=XN'S[.$@
M]._U(.'Q]^7?[_4@\.'QX>S=]/'Y[2#SX>T@4$A0+7-C<FEP="X`R]_S].$@
MRN'TX?'<ZO3G\@#6W/'LX>KA+>WA\>KY].GJW`#%\.7NY?'CX?/?X0#%\.7N
MY?'CX?/?X2!";&]C:P#%\.7NY?'CX?/?X2#/[-SDX?(`Q?#E[N7QX^'SW^$@
MQ>[O]?/I[^3\].?SY_(`Q?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM`,7P
MY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)7,`Q?#E[N7QX^'SW^$@
MY?#IZ^_C_NT@X^GA.@#%\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E^>T@X^GA
M("5S`,7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)R5S)P#!Y?'O
MZ^GLW>WA\B#%Z^7U\]_MX?(`T_3OZ??EW^\N+BX`P>OKY^OOX_'A]M_A`,3I
MY?WH]>WSYR!%;6%I;`#'(.3IY?WH]>WSYR!%;6%I;"#P\=WPY>D@[>$@].'I
M\>G<YN7I+@#,WNWU[.$@[.4@\?7H[-_SY>GR`,'I\^C>[.'TX0#*Y>W\(.S>
M[?7LX2X`Q.7M(.7PZ?/T\=SVY^KA[2#!\._TY>O=\^SA].$N`,'DY>GE\B#S
M]>WHWNKE\B#A[>'FWO3G\^?R`,7MY?'C[_#OW^?SYR#EZ?/AX_GCWO(@Y>GJ
M_.WY[2#A\.\@4&AO=&\@0V%L;&5R:65W(//T[R#JY=_LY>WO.P#-X2#E[>7Q
MX^_P[^GGZ.7?(/3O(.SE[>_](.SE(.3E[M\@ZNOIZCL`U-WK[_(`N/3O\B#4
MW>OO]?(`S.7CW>WH]?/G(,KEZ>SE[>_C\=SV[_4`Q/[S].4@[.GA(.7Q_O3G
M\^<@X?/VX>OEW^'R+"#G(._P[]_A(.CA(//A\B#FY_3GZ.7?(.'M(/?QY>GA
M\^CEWR#MX2#AZ^O<[N4M].4@]._M(.KYY.GJ_"#SX?(L(/`N]RX@)]#OZ?P@
MY=_MX>D@].\@_.WO[.$@]._U(.KA]._IZNGDW^_U(//A\CLG.@#$_O/TY2#T
MYR#S_>WDY?/G(/3G\B#EZ>K\[>'R(.7D_@#+W.CO\@#+W.CO\B#A\._S]-WK
MZ^_M].'R(.'PW.WTY_/G.B`E<P#+W.CO\B#LY2#LWNWU[.$@96UA:6PN`,O<
MZ._R(./QW/;O[?3A\B`B)7,B+@#%Z.WIZOP`Q?7Q_O#G`,K<Z.4@,34@Z^7P
M]-P`RMSHY2`R(,OE\/3<`,K<Z.4@,S`@Y.7U].7Q_.OE\/3A`,K<Z.4@-2#K
MY?#TW`#*W.CE(/;O\=P@\._U(.SPX=_MY?3E(//TY^T@]?#G\>7SW^$`RMSH
MY2#LZ?/>(/[QX0#*W.CE(.OE\/3\`-#A\>'DY>GC[.'TZ>K=\B#TZ>S=\CH`
MQ>KTW>OE\^<`Q?#=ZO3A\^<`Q?#=ZO3A\^<@T.OE]?'IZM[R(,SPW/'A\@#!
M[>'LY>W\[.7M[R`B0D5'24XB(//TYR#C\>'L[-X@)60N`,'MX>SE[?SLY>WO
M(")%3D0Z)7,B(//TYR#C\>'L[-X@)60N`,'MX>S=[>_M].'M("<I)P#![>'L
MW>WO[?3A[2#A\.O>(.O=[N<@WB#S]>WHWNKG(.'MX>;>].?SY_(@\^4@Y>GS
MX>/YX^GJW`#'[.7Q[^SG[=_A(,O>[N?R`,7JZ-WTY_(`U_'^[.$@\/'O\^K>
M[>GO]0#1]>CLW_/EZ?(@X^GA($944"!U<&QO860`P?#O]/7WW^$@ZN'TW"#T
MY^T@\/'O\_#<Z.7IX2#A[=SJ].?SY_(@]/GM(/#Q[_3I[-[SY?GM+@#!\._T
M]???X2#S_>WDY?/G\B#S]._M(.3IX>KO[.GS]-X@RN'TX>O\X^_U+@#!\._T
M]???X2#S_>WDY?/G\B#S]._M(%--0BU397)V97(N`,'P[_3U]]_A(.'M].GC
M\>'VWO(@X?#\("(E<R(N`,'P[_3U]]_A(.'M].GC\>'VWO(@\^4@(B5S(BX`
MP?#O]/7WW^$@Y.?LZ>_U\>/?X?(@\_WMY.7SY_(@4T%33"X`P?#O]/7WW^$@
M[.7TX?;O\=SR(//E("(E<R(N`,'P[_3U]]_A(.KA]-P@].?M(.'KZ^'CWB#J
M^>3IZN_](./IX2#T[^T@]_'>\_3G("5S(.'P_"#T[R#S].'H[/P@)7,L(.O\
MX^_R("5S`,'?Z/'I[_(`T._K_2#S[^+A\?P@R]SH[_(Z`-;!S@#6Y>+Q[_7<
M\>GO\@#$Z=SHY?/G(./IX0#$Z=SHY?/G(./IX3H@`,O?X^7R(.+Q[_?=\@#+
MW^/E\B#WZ>_M[_#T_O/EZ?(`T-_MX>KA\B#0Y>3?[_4`P?'IZ.S\\B#A\??E
MW^_U.B`E<R#A\??EW^\`P?'IZ.S\\B#A\??EW^_U.B`E<R#A\??EW^$`Q.GA
M]^7I\>GS]-[R(,'Q]^7?^>T`O.WO[.$@P?'WY=_O]0#%\.GK[^/>(,'Q]^7?
M[_4`)\'MW>+A\^SA)R#!\??EW^_U`"?![=WBX?/LX2<@P?'WY=_O]2#DY>T@
M]?#O\_3G\=_FY?3AZ2X`UM_K]/'A`-#Q_O3O(,SI\_P`T/'^].\@U-WTX?'T
M[P#3].'HY?'\\B#K_./O\@!&;&EP`$9L;V%T`,_LW_?KYP#/(/;<ZN7K[_(@
M)7,@Y.7M(/7PW/'WY>D`U_'^[.$@X_'<[.SA]._R`-3Q[_;>`,/IX2!"<F]W
M<V5R<RP@\._U(.3E[2#U\._S].?QW^;O]>T@Y>GJ_.WE\@#.Y??<\^'TY2#T
M[^T@ZOGDZ>K\(//A\CL`UOSQ[.7R`-#Q_.+KY?CG`-3]\._R(-#Q_.+KY?CG
M\@#0\>_BZ]WXY>GR`-#Q[^+KW?CEZ?(@,@!&;W)U;7,`T/'O^>C>\^7I\@#0
MX0#0Z^'?\^GA`-#KY_'O]N_QW^7R(,3IX>CE\^GL_/3G].'R`,'PW.WTY_/G
M(,3IX>CE\^GL_/3G].'R`,'?].?LX2#$Z>'HY?/I[/STY_3A\@#!\-SM].?S
MYR#SY2#AW_3G[.$@Q.GAZ.7SZ>S\].?TX?(`P?#\`,'P_"#T[R``P>WAZ_7T
MZ>K>(-#E\>GC\>'VW@#![>'K]?3IZMX@T.7QZ>/QX?;>.@#0Z][QY_(@T^7K
MWNWG`-#KWO'E\B"\[>_LX0!'86QL97)Y(.'P_"#TY^T@[_#OW^$@Z.$@\.'?
M\>WO[?3AZ2#OZ2#EZ>K\[>7R`$=A;&QE<GDZ`,SIZO'\(+SM[^SA`,/E[>GJ
MW?(@Q?#IZ^_CW?(`S.7TW.+A\^<`Q>OKW.3A`,7KZ^?MZ>K<("A)4T\M.#@U
M.2TW*0#$Z>'WY=_QZ?/G(,_LW.3Y[0#4X2#O[?SLX?3A(/3Y[2#O[-SD^>T@
MY.7M(/#QW?#EZ2#MX2#EW^WAZ2#JY>W<`,7N[_7SZ>_D[_3>\^7I\B#/[-SD
M^>T`S^S<Y.7R`,GDZ?STY_3E\B!'=65S=`#)Y.G\].?TY?(@1W5E<W0`1W5E
M<W1B;V]K`-3O(//]\_3G[.$@X?7HY>WTZ>KO\._?Y_/G\B!(5%10(.3E(.+Q
MW>CGZN4N`+[X[_(`PN_>Z.7IX0#"[][HY>GA(./IX2#TYR#W\=[SYR#T[_4@
MZN7I[.7M[^/QW/;O]0#"[^?H_/(`Q^SI\_;AW_'I[P#!Y?'OZ^GLW>WA\B#'
M\>'JZ^7?[_4`Q>3^(.7?[>'I(.<@X?'WWB#T[_4@X?'WY=_O]3H`V.?KW`#'
M(.7CX_'A]MX@Z?/T[_'IZN_](.3E[2#P\=WPY>D@[>$@Y=_MX>D@ZN7MW@#!
M\??IZMX@T^7KW^3A`,'Q]^GJWB#3Y>O?Y.$`Q.GE_>CU[?/G(-/PZ?3I[_T`
MU.?KW?;Y[>\@T_#I].GO_0#!\??IZMX@T^7KW^3A`,7?\^_D[_(@\_3G[2#5
M\.?QY?/?X2#'R^7J]/'O[>GJ[_T@U.'W]>3Q[^SEW^_U`-/]\_3G[.$@)TAO
M<F1E)P`G2&]R9&4G(,'S_?'LX?3G`-3O(/#Q_./QX>SLX2`G2&]R9&4G(.3E
M[2#=]^7I(/'UZ.SI\_3EWR#S^?/TW`#/\>GF_.WTZ>_R(,KA[?SMX?(`S_'I
MYOSM].GO("?CW>SI\^SA)P#/\>GF_.WTZ>\Z`-#Y\B#VZ-SSX?3E(.7D_CL@
M*/#A\>'JX>O^(.WA(/3O(.'MX?;=\>7TY2#S].\@Y.GA]^7I\>GS]-XA*0#0
M_//E\B#S]-[KY?(@Z-WKY?3E(.WA(.7M[_#OZ=[SY?3E.P#0_//A(/#EY-_A
M("CS]-[KY?(I(.7?[>'I(.7JY=\[`-#\\^7R(./QX>SLW?(@Z-WKY?3E(.WA
M(.7M[_#OZ=[SY?3E.P#5X_'A\]_A`-7C\>'SW^$Z`-?I[_7L[_'?\_3A\@#'
M(,3G[.GO]?'CW^$@X_'A[.SA]._H]?'?Y.'R($E-05`@X?#=]/7WY3H@)7,`
MQR#DZ>'C\>'VWB#C\>'L[.'T[^CU\=_DX?(@24U!4"#A\-WT]??E.B`E<P#'
M(,3G[.GO]?'CW^$@\.7I\>_QZ?/L_NT@*'%U;W1A*2#C\>'L[.'T[^CU\=_D
MX?(@24U!4"#A\-WT]??E.B`E<P#%Z?/E\??\[.7MX0!)4"W$Z>7]Z/7M\^<`
M25`MQ.GE_>CU[?/G(.3E[2#EW^WAZ2#DZ>'HW?/I[.<N`$E0+<3IY?WH]>WS
MYR#LYR#E\.GT\>7P]-X@[-WSX2#SY2!#2412+4)L;V-K+@#*Z^7?Y/GLX2W0
MX?'AXM_A\^<@25`N`,7I\^7Q]_SLY>WA`,7I\^'C^>/>(,/QX>SLWO(@T/'I
M[0#,_.WO(,7IZN_MW^3IX0#%Z>KO[=_DZ>$@X^GA("5S`,7IZN_MW^3IX2#J
MX>D@RN7?[.7M[P#/[>_LX2#TX?7T_/3G].'R.@#![2#DY>T@Y>SVX>W?YN7T
MX>D@\_GS]-PL("5S(./IX2#MX2#A[>_?[N7I(//E(.W=[R#PX?'<Z/7Q[RX`
MP>T@Y.4@XNO=\.7TY2#JX>W=[>$@Y>GJ[^W?Y.GO(/?QY_/I[._P[^G^[?3A
M\B#T[^T@26YT97)N970@17AP;&]R97(L(-_S^?(@\/'=\.7I(.WA(/3SY>K<
M\>7TY2#EY/X@X^GA(.WA(.'PY>WE\>/O\._IWO/E].4@].<@Y.GA]MSMY>GA
M(%!.1RX`P>T@XNO=\.7TY2#A]?3\(/3O(.S>[?7LX2#W^?'?\B#EZ>K\[>$L
M(.<@Y>GJ_.WA(/#O]2#HW>OE].4@[>$@ZN'TY>+<\^7TY2#DY2#L\._QY=\@
M[>$@Y>SVX>WI\^CEWR#A\/P@]._M(&)R;W=S97(@\^'R+@#0\>_E\.GSZOSP
MZ?/G(,7IZOSMX?(Z`%523"#%Z>K\[>'R`,7IZOSMX2#A\/P@1V%L;&5R>0#%
MZ>K\[>$@X?#\($=A;&QE<GDZ`,'P[_/T[^O>(,7IZOSMX?(`Q>GJ_.WE\@#%
MZ?/AX_GCW@#+W.CO\B#JX?3<(/3G[2#%Z?/AX_GCWCH@`,7I\^'C^>/>+"#"
MWNSA("5D`-#EY-_O(/#O]2#EZ?/>]^CG.B`E<P#0Y>3?X2#P[_4@Y>GSWO?H
MY_/A[3H`T^4@Q?#E[N7QX^'SW^$`Q>GSX>/YX]X@P_'A[.S>\B#,Y?3<`,3\
MZ.?JY2#KW.CO\B#J^>3IZOSR(.7MW?'CY>GA\BX`R]SH[_(@_.WO[.$@]_'>
M\_3G(-XOZN'I(.KYY.GJ_/(N`,O<Z._R(/SM[^SA(/?QWO/TYR#>(.7MX>OK
MX>KTZ>K>(.3IY?WH]>WSYRX@SN'MX>3OZNGLW//TY2#>(.7PZ>KOZ>WY[=[S
M].4@[.4@].\@Y.GA]^7I\>GS]-X@X^GA(/#E\>'I]-WQ^2#B[][HY>GA+@#!
M_>[G\^<@T.7QZ>CY\=_O]0#)Y.GAW_3E\>_I(-?QWO/TY?(`T.OG\>_V[_'?
MY?(`T.OG\>_V[_'?Y?(`Q>GSX>/YX]X@T_3>Z^?R(,SE]-P`Q>GSX>/YX]X@
MQ>GJ_.WA\@#%Z?/AX_GCWB#0W^WAZN$`Q>GSX>/YX]X@\_WMY.7SY_(@5V5B
M`,7I\^'C^>/>(-/TWNOG\B#0\>GM`,7I\^'C^>/>(.W=X?(@\_3>Z^?R(.SE
M]-P@].?M(/3QW??O]?/A`,7I\^'C^>/>(.W=X?(@\_3>Z^?R(/#QZ>T@X?#\
M(/3G[2#T\=WW[_7SX0#%Z?/AX_GCWB#MW>'R(./QX>SLWO(@[.7TW"#TY^T@
M]/'=]^_U\^$`Q>GSX>/YX]X@[=WA\B#C\>'L[-[R(.SE]-P@].?M(/3QW??O
M]?/A`,7IX>/YX]X@\.'QX>/QW/;O]2#LY?3<(/3O[2#T\=WW[^WTX2#J_.SB
M[P#%Z?/AX_GCWB#PX?'AX_'<]N_U(/#QZ>T@]._M(/3QW??O[?3A(.K\[.+O
M`,7I\^'C^>/>(.7MX>OKX>KTZ>KO_2#P\>_T_?#O]0#$_O/TY2!E;6%I;"#D
MZ>7]Z/7M\^<@\_3G[2#O\._?X2#E\.GH]>SEW_3E(.WA(/#A\>'KW.+E].4@
M].\@[=WO(//A\B#J^>3IZOPZ`,7I\^'C^>/>(.KEZ^GO_2#LY?3<`,7I\^'C
M^>/>(.KEZ^GO_2#P\>GM`,7I\^'C^>/>(//TWNOG\B#LY?3<`,7I\^'C^>/>
M(//TWNOG\B#P\>GM`,7I\^'C^>/>(.SG[?WLX?3O\@#%Z?/AX_GCWB#PX?'A
MX_'<]N_U(.SE]-P`Q>GSX>/YX]X@\.'QX>/QW/;O]2#P\>GM`,7I\^'C^>/>
M(./QX>SLWO(@[.7TW`#%Z?/AX_GCWB#C\>'L[-[R(/#QZ>T`Q>GSX>/YX]X@
M].?R(.'PX>GT[_WLY>WG\B#A\-SM].?SY_(@\_3G[2#E\?[TY_/G(.'S]N'K
MY=_A\CH`Q>GSX>/YX]XOQ.G\\>CY\^<@Q>GJ_.WA\@#%Z?/AX_GCWB_$Z?SQ
MZ/GSYR#3_>WDY?/G\@#,YR#E\.'QZMWR(/7P_.OOZ?#O(./IX2#A\._S]._K
MWB#S].<@Z]_S].$@Y.GA[>_LWO(N`,SG(.7PX?'JW?(@]?#\Z^_I\.\N`,'J
MW?'AZ>_R`,O?\_3A(,'JY?'AW_GM`,7PZ>O=[N'TY2#+W.CO\B#%[=WQX^7I
MX2#CZ2<@X?7T_"#T[R#S]?/TX?3IZOPN`,'J]?'O(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+@#,YR#=X^KU\><@Y?;A\>SOX]XN`,'J]?'O($)A=&-H+4E$
M+@#3]-SKZ.?JX>T@Z]SH[_(@Y.7D[^S=[>$N`,'J]?'G(.3IY?WH]>WSYR#P
M\>_O\>GS[._]+@#,YR#=X^KU\><@[._Q]MX@X?'WY=_O]0#,YR#=X^KU\>\@
M;7-G7W1Y<&4N`,SG(-WCZO7Q[R#>(.OEW_#EZ2!A<&E?:60N`,SG(-WCZO7Q
MY?(@WB#EZ^OI\.7?\B#PX?'<[.7T\>_I+@!);G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+@#,YR#=X^KU\>\@\/'Y]/SJ[^OK[RX`S.<@W>/J]?'O\B#PX?'A
MZ][P].?R.B`G)7,G`,SG(-WCZO7Q[R#J[^GM_/?QY_/T[R#A[?3IZN7?[.7M
M[P#,YR#=X^KU\><@X?'WZ>K>(.3IY?WH]>WSYRX`S.<@W>/J]?'A(.3EY._L
MW>WA(%5N:6-O9&4N`,KA]-SK[^/O\B#5\.'Q]_SM]/GM`-#KX>/IX0#)X>WO
M]=SQZ>_R`,GO_>OI[_(`R>_][>GO\@#%]>CUX_'<[.SI\^<`Q?7H]>/QW.SL
MZ?/G(//T[R#*W>WT\>\`T.O>\>?R(,7UZ/7C\=SL[.GSYP#%]>CUX_'<[.SI
M\^<@P?'I\_3E\=P`Q?7H]>/QW.SLZ?/G(,3E[NG<`,'E\>_KZ>S=[>'R(,KA
MZ^'LW/3A\@#!Y?'OZ^GLW>WA\B#*X?'PW.CO]0#!Y?'OZ^GLW>WA\B#*X?/T
M[_'IW/(`S>$@ZO'A]-[S^2#T[R#A]>CE[?3IZOP[`,'E\>_KZ>S=[>'R(,KE
M]N'K[^WIW/(`2V5R8F5R;W,M4V5R=F5R(.'Q[=[HY^KE(/3G[2#A]>CE[?3I
MZN_P[]_G\^<N`,'E\>_KZ>S=[>'R(,K=\>KU\>'R`,W=X2#A\/P@2V5R;F5L
M`,3G[.GO]?'CW^$@RNOEZ>3I[_T`P?#O]/WP^>SA(,KKY>GDZ>_]`,S>ZN_R
M(,KKY>GDZ>_]`-3]\._R(,KKY>GDZ>_]`-?QWO/G(,KKY>GDZ>_]`-3O(.KK
MY>GDWR#U\-SQ]^7I(-[DYR#S]._M(.7N]?#G\>7TY_3>(.3G[/SSZ?GM(.KK
MY>GDZ?[M+@#0X>GDZ=P`P>7Q[^OI[-WMX?(@ROD`P>7Q[^OI[-WMX?(@RN_F
MW.WG\@#$Z=STX>[G`,'E\>_KZ>S=[>'R(,O<\>GSX?(`U.7KY?7TX=_O(,SI
M\_P`U.7KY?7TX=_O(-3=].'Q].\`U.7KY?7TX=_A(,7MY^S=\?GSYSH`U.7K
MY?7TX=_A(,7?\^_D[_(@\_3G[2#U\.?QY?/?X3H@)7,`U.7KY?7TX=_A(,7?
M\^_D[_(@\_3G[2#U\.?QY?/?X3H@)7,@X?#\("5S`-3EZ^7U].'?X2#%W_/O
MY._R(//TY^T@]?#G\>7SW^$Z(-#O]-T`S?SL[_(`Q.G<].'NYP#!]M[S].4@
MZN7M_"#CZ>$@[>$@[.?M(/7PW/'W[_7M(/#E\>GH_O'IX0#!\>GS].7QW`#!
M\>GS].7QWB#%\.GJY?;AZ]_DX0#!\>GS].7QW?(@U.GLW?(`T.7M]-SS].GW
M[P#!Y?'OZ^GLW>WA\B#+WNSM[_4`T_WMY.7SYP#3_>WDY?/G(/#O]2#DY=_W
M[>7I(//E.@#3_>WDY?/G(/3G\B#DZ>7]Z/7M\^<@X^GA(-SM[^GC[.$@\.'Q
MX>C]\>_U(//][>CE\^?R.P#3]>WDW?/EZ?(`3&EN=7@M0V]O:VEE`$QI<W0@
M+2#/(/?QWO/TY_(@[/#O\>7?(.WA(.3EWR#T[R#VW.KEZ^\`R]_S].$@PMSS
MY?GM(,3EY._LW>WY[0#+W_/TX2#HY>S<]/GM(,+OWNCEZ>'R`,O?\_3A(-#I
M[=SJ^>T`QR#DY^SI[_7QX]_A(.O?\_3A\B#W\>?S]/[M(-WWY>D@X?#E[>7Q
MX^_P[^GGZ.7?+@#6_/'T^?/G+BXN`-3O\.GJWB"_\>$Z(`#4_/#O\B#JX>D@
M_O'A`-3\\._HY?/?X0#%W_/OY._R`+CN[^3O\@#$Z>7QX^'SW^7R(.7I\_SD
M[_4`QR#EW_/OY._R(,'PW?3U]^4N(-#IZ.'M_/3A].$@Y/SHY^KE(.O<Z._R
M(/3O(+SM[^SA(-?QWO/TYR#>(.\@ROGDZ>K\\BX`Q=_S[^3O\B#!\-WT]??E
M+@"X[N_D[_(`S.7CW.OO(,KEW^SE[>\`P>/<\.<`U^'LY^O\`,SIZO'<(,7K
MZ^?MZ>K<(./QW.SLX?3A`,SIZO'<(.OA].GMZ>K<(./QW.SLX?3A`,SIZO'<
M(-'Y[.'ZZMX@P?'?Z.SG\^<`S,P`S.'CZ>K\`,'KZ^?K[^/QX?;?X0#$Z>'W
MY=_QZ?/G($5M86EL`,3G[.GO]?'CW^$@T_WMY.7SY_(N+BX`Q.GA]^7?\>GS
MYR#JX?3GX^_QZ?[M(.KAZ2#W\?GLW/3Y[2#P[_4@Z.$@Y>SVX>W?YN_M].'I
M(.'U]-WR+@#%X_?EZ?'?Y.GO`-#EY-_A(,?LY?'O[.?MW^'R(.KAZ2"_\>'R
M`-#EY-_A(.7I\^'C^>/>\@#,W/'TZ>_R`+SQZ>\`S.'QZMSQZ?/LX2#LY2#=
M[>3EZ>[G(,'MX>/M^?/LW>WO]2_,YR#A[>'C[?GS[-WM[_4`S.'QZMSQZ?/L
MX2#LY2#<Z^OG(-WMY.7I[N<@*/`N]RX@T^?LX>WTZ>K\+\'PX>WTY^S=[>\I
M`-#EY-_A(/#O]2#TX>GQZ=SF[_7M`,S=X^GS].<@Y?#I]/'E\/3>(/#?\_3Y
M\^<N`-7PW?'BX?/G(._QW^_U(.SG[?WLX?3O\BX`S-WCZ?/TYR#HY?'L[^KQ
MX?/?X2#TY>OE]?3AW_GM(#(T(/GQ_NTZ(`#,W>/I\_3G(.CE\>SOZO'A\]_A
M(/3EZ^7U].'?^>T@-B#Y\?[M.B``S-WCZ?/T[R#LWNKO\@#,W.GO\@#!ZOWQ
M^?/G(-/U[=SM].?SY_(`T.OG\>_V[_'?Y?(@T_7MW.WTY_/G\@#0\?STX?/G
M(./IX2#3]>W<[?3G\^<`P?#<[?3G\^<@X^GA(-/U[=SM].?SYP#%[>?LW?'Y
M\^<@X^GA(-/U[=SM].?SYP#!W_3G[.$@Y>WG[-WQ^?/G\B#CZ>$@T_7MW.WT
MY_/G`,S=Z^<`T^?LY>G^\^7I\@#*X?3<\_3A\^<@S.7M[_TZ`-/UX_?^[>7U
M\^<@ZN7KZ?[M`,S>[?7LX0#4[R#LWNWU[.$@Y?#IXN7BX>G^Z.?JY2#E\.GT
M]??^\BP@X>OKW"#T[R#PZ?/T[_#OZ>?TZ>K\(/3O]2#U\._C\=SV[^WTX2#D
MY2#L\._QY=\@[>$@Y?#IXN7BX>GYZ.7?+@#4[R#LWNWU[.$@W>OG[N4N`-3]
M\._R(.SG[?WLX?3O\@#*X>GQ_/(@X?#\($UE=&%R`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`,S=
MZ._D[_(`QR#,W>COY._R("<E<R<@Y.7M(._QW_/HY^KE`,SE]/'IZOP`S.7S
MX=_O`$UI;64@5'EP90#,Z>KQ_/3E\><@Z.7Q[._J\>'SW^$@].7KY?7TX=_Y
M[2`R-"#Y\?[M.B``S.GJ\?STY?'G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@
M-B#Y\?[M.B``RN'H\=WP].?R`,3IW/;O\>$`36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+@#+Y=_PY>D@].\@8V]N9FEG=7)A=&EO;BX@T/'=
M\.7I(.WA(/3O(.3G[.GO]?'CWO/E].4@X>T@Z-WKY?3E(.WA(/?QY_/I+>SO
M\._IWO/E].4@X?7TWB#TY^T@Y?;A\>SOX]XN`,OEW_#EZ2#T[R!)1"#T[_4@
M[.?M_>SA]._R+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL
M+@#+Y=_PY>D@].\@240@].?R(//][>3E\^?R+@#$Y0!%;6%I;"#*Z>WG]-[R
M(-3GZ^7V^>W?X?(`S-WT\>GO\@#'[.7Q[^SG[=_A(/3Q[_#O\._?Y_/G\@#4
M\>_P[_#OW^?SYR!54DP`Q>SVW.WI\^<@S-[MX0#,WNWA\B#JX>D@W?3O\@#,
MY^WIX=_A`,SG[>GAW^$@R]_S].$@P^7C[^W\]/GM`-;<\^7I\B#3Y>O>[>?R
M`,K?[>?SYR#JW/3Y`,K?[>?SYR#A\>GS].7QW`#*W^WG\^<@Y.7NZ=P`RM_M
MY_/G(/#<[?D`RM_MY_/G(.K<]/D`RM_MY_/G(/#<[?D`T._KZ^'PZ]WR(.O?
M\_3E\B#E\.GK[^/>\B`HZN'TX?'QW.KTY?(I`-#OZ^OA\.O>(.7PZ>OOX]X`
MSR#+[^/A\>GA\^S\\B#L[_4`SR#I\_3\]._P_/(@[._U("AP;W)T86PI`,<@
MY>SVW.WI\^<@]._U(.GS]/ST[_#O_2#L[_4@*'!O<G1A;"D`QR#0Y?'?Z^?X
MYR#L[_4Z`,'E\>_KZ>S=[>'R(,SU].?KWNWG\@#/U\DL(,3%(//U[/;Y[?X`
MO.WO[.$`P?#AZ?3EW_3AZ2#E[=WQX^7IX0#$W^KT]>\`T._TW0#-W>$@RN'T
MY^/O\=_A`,W=X2#3Y>O>[><`S=WO\B#*^>3IZOSR`,W=[_(@ROGDZ>K\\B`H
M[N'MW"D`S=WO(/SM[^SA(-?QWO/TYR`H\/'OX>GQY?3IZOPI`,W=[R#PX?'<
MZ/7Q[R`HZN7M_"D`S=WA`,_LW.3E\B#CZ>$@[=WA("AN97=S9W)O=7!S*0#%
M\/SLY>WO`,7P_.SE[><@T^7KW^3A`,7P_.SE[><@UMSSYP#%\/SLY>WE\B#%
M\.GK[^/=\@#/]^D`Q.7M(/7PW/'WY>D@Y.GAZ-WSZ>SO(&-O;F9I9W5R871I
M;VX@X^GA(.WA(.3EW^[Y(.3IX?;O\=WR+@#$Y>T@]?#<\??EZ2#DZ>'HW?/I
M[.<@\_3QX?3GX^GJWB#CZ>$@Y.?LZ>_U\>/?X2!)4T\@:6UA9V5S+@#$Y>T@
M]?#<\??EZ2#P\?ST]?#O(./IX2!"871C:"X`Q.7M(/7PW/'WY>D@0FQO8VL@
M\_3G[2#AZ?3O_>SE[><@Z-WSYP#$Y2#D_.CGZN4@_.WO[.$@X^GA(.'UZ.7M
M].GJ[_#OW^?SYR!-0T%,+@#$Y>T@]?#<\??O]>T@X>OKX>/=\BX`Q.4@[/#O
M\>_][2#MX2#P\>_S].7H[_WM(.7N[_7SZ>_D[_3>\^7I\B#JW/3Y(.'P)R#A
M]?3\(/3O(.7PW_#EY.\N`,3E[2#L\._Q[_WM(.WA(/#Q[_/TY>CO_>T@]?#O
MZN'TY^/O\=_E\B#SY2#A]?3>(/3G[2#E[N_U\^GOY/STY_/G+@#$Y>T@[_'?
M\^CGZN'M(/#KY_'O]N_QW^7R(/'UZ.S?\^7Y[2#CZ>$@)7,N`,3E[2#O\=_S
MZ.?JX>T@\.OG\>_V[_'?Y?(@\?7H[-_SY?GM(./IX2!&5%`@5D93+@#$Y>T@
MW??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2#TY^T@]?#G\>7S
MW^$@RN'TX>O\X^_U+@#$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_Q
MW^7R(./IX2#TZ?(@ZN'TY^/O\=_E\B#TY_(@4U%,+@#$Y>T@W??O]>T@\?7H
M[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2#TZ?(@\/'O].GLWO/EZ?(@].?R
M(%-13"X`Q.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@
M4U%,(%9&4RX`Q.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#C
MZ>$@].?M(.'UZ.7M].GJ[_#OW^?SYR#S].?M(%-13"X`Q.7M(-WW[_7M(/'U
MZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@4U%,+49I;&4@5D93+@#$Y>T@
MW>SEZ>WE(/#?\_3Y\^<N`,3E(.3^\^'TY2#P\>_O\>GS[/PN`,3E(/;O\?3^
MZ.?JX>T@X?'WY=_A`,3E(.+QW>CGZN'M(.7IZN_MW^3IX2X`Q.7M(._QW_/H
MY^KE(/3O\._HY?/?X2X`Q.4@Y/[SX?3E(.S>[?7LX2X`Q.7M(._QW_/HY^KE
M(/SM[^SA+@#$Y>T@[_'?\^CGZN4@X?'IZ.S\\BX`Q.7M(/7PW/'W[_7M(.3U
M\]SQY?/TY?(@\/'OXNO=^.7I\@#$Y>T@Y>KJ\>7L[_WM(.7?\^_D[^DN`,_I
M(/#Q[_3I[-[SY>GR(.3E[2#EW^WAZ2#DZ>'HW?/I[.7R+@#$Y>T@]?#<\??O
M]>T@ZN'M_.WE\@#$Y>T@]?#<\??O]>T@\.OE]?'=\@#$Y>T@]?#<\??EZ2#P
M\>_S^?'I[?SR(/?^\>_R(./IX2#L[=[LYR!C86-H92X`Q.7M(.3\Z.?JY2#\
M[>_LX2#W\=[S].<@WB_JX>D@ZOGDZ>K\\BX`Q.7M(.7PZ?/T\=SVY^KA[2#=
MX^/U\>$@6$U,(.3EY._LW>WA`,3E[2#U\-SQ]^_U[2#TZ>S=\@#$Y2#B\=WH
MY^KE(-WJY._SYR#S].\@X?'WZ>K\(&-O;F9I9W5R871I;VXN(,[A[>'DY^SI
M[_7QX][S].4@].\N`,3E(.+QW>CGZN4@W>KD[_/G(//T[R#A\??IZOP@\^'R
M(&-O;F9I9W5R871I;VXN(,[A[>'DY^SI[_7QX][S].4@].\N`,KA[=WMX?(@
MT_7L[.7TW??Y[0#*X>SLW^$`RN'MW>WA("C7\=[SYR#P\>_JX>CO\>GS[-WM
M[_4I`,+\\>7I[R#'[.GS]N'?\>GO`+SWZ2#,Y?3<`+SWZ2#0\>GM`,3E[2#E
MW^WAZ2#JX?3<Z^_C[_(`Q.7M(-WWY>D@[^OOZNOG\?GHY=\N`,3E[2#=]^GE
M(/3EZ.7?`,3E[2#U\._S].?QW^;E].4N`-/G[.7I_O/EZ?(`T^?LY>G^\^7I
M\B`M(-#E\=_KY_CG`,_I(//G[.7I_O/EZ?(@Y=_MX>D@[.GA(.7VX?'L[^/>
M(/#O]2#SX?(@Y?#I]/'=\.7I(.WA(.3G[.GO]?'CWO/E].4@].\@X>WTW_/T
M[^GW[R#T^>T@ZM_T\>GM^>T@[.GJ\?[M(/?A\?3I_NT@\_3O[2#U\._K[^/I
M\_3>+B#,\._QY=_TY2#MX2#DY^SI[_7QX][SY?3E+"#MX2#T\>_P[_#OZ=[S
MY?3E+"#MX2#DZ>'C\=SXY?3E(.KAZ2#MX2#T]?#^\^7TY2X@S/#O\>7?].4@
MY?#?\^?R(.WA(/C<[N7TY2#S].GR(//G[.7?^?/EZ?(@\^'R(./IX2#MX2#E
M[?3O\-_SY?3E(.SIX2#PZ^?Q[_;O\=_A+B#5\._S].?QW^;E].'I(.KAZ2#E
MZ?/AX_GCWB`M(.7NX>/YX]X@]/GM(//G[.7I_O/E^>TN`-/G[.7I_O/EZ?(Z
M`-3?\._TX2#CZ>$@Y>SVW.WI\^<L(.7PZ?/T\>_VWBX`P>WAZN_I[?[SY>GR
M`-3O(/#Q_./QX>SLX2#P[_4@Y.GA]^7I\=_FY?3AZ2#TZ?(@Y>GD[_#OZ=[S
MY>GR("5S(.3E[2#B\=WHY^KE+@#-[]WLXO'I[_(`P?'IZ.S\\@#!\>GH[/SR
M(/?A\>'J]-[Q^>T`P?'IZ.S\\B#S].?K_NT`P?'IZ.S\\B#S].?K_NT@\_3G
M[2#E[/;<[>GSYR#TY_(@\.7QW^OG^.?R.@#!\>GH[/SR(./QX>SL_NT`Q.7M
M(._QW_/HY^KE(.'QZ>CL_/(@X^GA(.7MY^S=\?GSYR#T^>T@Z^GS]/[M(.3I
MX>WO[-[R+@#![?3IZN7?[.7M[P#$Y^SI[_7QX_SR(,'M].GJY>GLW>WO]0#%
M[N_U\^GOY._TWO/EZ?(@Q.?LZ>_U\>/O_2#![?3IZN7I[-WM[_4`S^KTX>3I
MZOSR`,_J]/[B\>GO\@#6W^OT\>\@\/'O\^+OZ_[M`,/QX?;EW^\`T.'KZ?SR
M(,KYY.GJ_/(`S/SM[R!)34%0+5-E<G9E<G,@]?#O\_3G\=_F[_7M(.KO]>W\
M]_'G\_3O]?(@]N'JW>OK[_7R+@#,_.WO(.3U\]SQY?/TY?(@\/'OXNO=^.7I
M\@#,_.WO(.SIX2!%;6%I;"#DZ>7]Z/7M\^<@Y?#I]/'=\.7TX>DN`,S\[>\@
M[R#IY.GOZO3>].?R(-X@[R#DZ>'WY>GQZ?/TWO(@\_7S]-[LX?3O\B#L\._Q
MY=\@[>$@X>OKW.[EZ2#TY^T@Z>3I[^KTY_/?X2#>(/3I\B#E[N_U\^GOY._T
MWO/EZ?(@]._U(.GDZ>_J]-[TYR#CZ>$@ZN_I[=X@]_'>\^<N`,'M[^GC[.$@
M\^4@[=WO(/#A\=SH]?'O`$]P96Y34TPMR]SH[_(Z(,3E[2#L\._Q_B#MX2#B
MX]SK^2#DY>3O[-WMX2#A\/P@4R]-24U%(/7P[^/EX_'A[.S=[>\@[-WQ[_(N
M`,'M[^GC[.$@X?7TWO(@].?R(//][>3E\^?R(//E(.W=[R#PX?'<Z/7Q[P#+
MY>GT[_7QX^GJ_"#3_?/TY^SA`-#Q[^7QX>GTZ>K\\B#3]>SLY?3=]_GM`,7P
MZ>OOX]WR`,7PZ>OOX]WR(./IX0#%\.GK[^/=\B#CZ>$@)7,`U.'NZ>WO[.?L
MW>WG(,O?\_3A`,_QX^'MZ?/L_/(`U.S>[.$@S_'CX>WI\^SO_0#/\>/<[?GS
MYP#!]>CE[?3IZOP@\/'\]/7P[R#E]N'Q[._CWO(`P?7HY>WTZ>K<(/#Q_/3U
M\.$@\V4@)7,Z`,'KZ^\`P>OKY?(@T.OG\>_V[_'?Y?(`Q>[O]?/I[^3O]-[S
MY>GR(,GDZ>_J]-[TYP#'(,'UZ.7M].GJ[_#OW^?SYR!004T@Y.7M(.7?[>'I
M(.3IX>C=\^GLYRX`V.?VZ>'JWB#5\._C\>'VWB!01U``RO'U\/3OX_'A]N?L
MW>WA(.3EY._LW>WA(%!'4`#$Y^S\\^GO(,KKY>GDWR!01U``U?#OX^7C\>'L
M[-WMX2_*\?7P]._C\>'VY^S=[>$@4$=0(.3EY._LW>WA`%!(4"#*_N3IZN'R
M`%!(4"#*W>OU]N_R`%!(4"#*W>OU]N_R`,/=[.GS[.$`ROGDZ>K\\@#/(.KY
MY.GJ_/(@W.OKX>[E(./IX2#T[^T@]_'>\_3G("5S(.'P_"#T[R#S].'H[/P@
M)7,`R]SH[_(@ZOGDZ>K\\@#!\.'I].7?].'I(.KYY.GJ_/(@X^GA(.'UZ.7M
M].GJ[_#OW^?SYR!2041)55,N`,KYY.GJ_/(@[.4@Y?#IXN7BX=_Y\^<`ROGD
MZ>K\\CH`ROGDZ>K\\CH@`,\@ZOGDZ>K\\B#P\=WPY>D@[>$@].'I\>G<YN7I
M+@#+W_/TX2#0Y?'A\^S=[?GM(./EX^_M_/3Y[0#%\.GJ_.OKY_/G`,7PZ>K\
MZ^OG\^<@X?#\(/3O(&-L:7!B;V%R9`#$Z>'D\>_LW@#%W_/OY._I(/#O]2#E
MZNKQY>SO_>TZ`,'MZ/'Y\._I`-#O\^_S]/P`Q>KTW>OE\^<@R^7I]._U\>/I
M_NT@T_7M]-[QY_/G\@#%ZO3=Z^7SYR#+Y>GT[_7QX^G^[2#3]>WTWO'G\^?R
M(.KA]-P@].?M(.7?\^_D[SL`Q>[O]?/I[^3\].?SYP#%[N_U\^GOY/STY_/G
M(./IX2`G)7,G(.3E(.3IX>/QW/;GZN4N`,3IX??EW_'I\^<@Q>[O]?/I[^3O
M]-[SY?GM`,7N[_7SZ>_D[_3>\^7I\B#CZ>$`T/'O\_GPZ>K=\B#PZ^?Q[_;O
M\=_E\@#*X?3OZ>K?Y.GA`-3GZ]WV^>WO`-;Y]._C\>'VW^7R`,7IZN_M[_/T
M[^GWY=_A`,KOZ>WO]/7PW^7R`-#A\>'JX>O^(.K<[?3E(.KKZ>H@\^4@ZMSP
M[^GO(.KEZ]\`T.'QX>KAZ_X@Y?#IXN7BX>G^\_3E(/STZ2#HW>OE].4@[>$@
MY.GAX_'<^.7TY2#A]?3\(/3O(//T[^GWY=_O.@#0X?'AZN'K_B#E\.GBY>+A
MZ?[S].4@_/3I(.C=Z^7TY2#MX2#A\._S]>WDW?/E].4@X?7T_"#T[R#S]._I
M]^7?[RX`T.'QX>KAZ_X@Y/[S].4@[-[MX2#JX>D@W?3O\BX`T.'QX>KAZ_X@
MY/[S].4@W>WA(/SM[^SA(./IX2#TYR#MW>$@ZN'TY^/O\=_A.@#0X?'AZN'K
M_B#D_O/TY2#LZ>$@W>/J]?'G($E0(.3IY?WH]>WSYRX`T.'QX>KAZ_X@Y/[S
M].4@[.GA(-WCZO7QYR#G[.7Q[^SG[=_A+"#EZ]WN].4@]._M(.'QZ>CL_"#T
M^>T@Y^SE\?[M(/3O]2#LWNWA+@#0X?'AZN'K_B#D_O/TY2#=X^KU\><@_O'A
M+@#0X?'AZN'K_B#D_O/TY2#T[R#MW>\@ZOGDZ>K\(//A\@#0X?'AZN'K_B#D
M_O/TY2#LZ>$@\.7QW^OG^.<@]._U(/#Q[^+KWNSA]._R+@#0X?'AZN'K_B#D
M_O/TY2#T[^T@ZOGDZ>K\(//A\@#0X?'AZN'K_B#D_O/TY2#T[R"\[>_LX2#7
M\=[S].<`T.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@ZN'I(/3O[2#J^>3IZOP@
M\^'R`-/U[/#KY_'^\_3E(/3O(/SM[^SA(/?QWO/TYR#LY2#T[^T@]._LW>$@
M*$!E<FUI<RYY9'0I`-#A\>'JX>O^(.3IX>+<\_3E(/3O(.'J_.OO]>CO(.KE
MW^SE[^TN(-#QW?#EZ2#MX2#S]>SV^>WEW_3E(.SE(/3O]?(@_/'O]?(@X^GA
M(.WA(/?QY_/I[._P[^G>\^7TY2#A]?3\(/3O(//]\_3G[.$N`-#A\>'JX>O^
M(.3EW_3E(/3I\B#AZOSK[_7HY?(@\.OG\>_V[_'?Y?(@ZN'I(.7PZ>O=[O3E
M(.SIX2#E[=WQX^7IX2#A\/P@].\@\.'QX>K<]/D@[.7M[_TN`-#A\>'JX>O^
M(.7PZ>O=[O3E(.SIX2#E[=WQX^7IX2#A\/P@].\@\.'QX>K<]/D@[.7M[_TN
M`-#A\>'JX>O^(.3^\_3E(/3O(/SM[^SA(/3G\B#MW>'R(.KA].?C[_'?X?(Z
M`-#A\>'JX>O^(.7PZ>+EXN'I_O/TY2#T[R#MW>\@ZOGDZ>K\(//A\@#(W?/G
M(.'U]-[R(/3G\B#EZ>K\[>'R`-3O\._HY?3^[?3A\B#A]?3\(/3O[2#PW^WA
MZN$`P?#O\_3OZ]X@\^4@X?7T_"#T[R#VW.KEZ^\@*.3E[2#U\._S].?QW^;E
M].'I(.'P_"#T[R!)34%0*0#-X2#P\>_TW//S[^WTX>D@Y/WO(/#A_>OE\B#P
M\=_M(/3G[2#U\._C\>'VWB#SX?(@*"<M+2<I.P#*X?3AZO'>[.WI\^<@X^GA
M(/3I\B#TY>OE]?3AW^7R("5S(/[QX2CE\BDZ(`!0<F5F<U]L9&%P.B#$Y2#B
M\=WHY^KE(.<@X?#AZ?3O_>SE[><@Y?#=ZO3A\^<@3$1!4"X`4')E9G-?<V5S
M<VEO;CH@Q.4@XO'=Z.?JY2#G(.'PX>GT[_WLY>WG(.7PW>KTX?/G(//U[>7D
M\=_A\BX`T.'Q[_7SZ=SSY>GR`-#?Y?/G`-#?Y?/G(//T[R#E\-_PY>3O(/3G
M\B#HW.OA\_/A\CH@`-#?Y?/G.B``T/'OY?#I\^K\\.GSYP#0\>_E\.GSZOSP
MZ?/G(/3G\B#EZ>K\[>_A\B#SY2#MW>\@\.'QW.CU\>\`T/'OY^/O_>SE[><@
MT^7KW^3A`-#Q[^?C[_WLY>WE\B#%\.GK[^/=\@#%ZO3]\/GSYR#EX^/QW/;O
M]0#0\>_S^?#IZOP@RNOEZ>3?`-#Q_.+KY^SA`-#E\>GC\>'VWB#0\>_BZ][L
MX?3O\@"X\>/O("AP<F]J96-T*0#*Y=_LY>WO(/#Q[_3Q[_#>\@#$Y^S\\^GO
M(,KKY>GDWP#!Z^/\\>GH[._R(,3G[/SSZ>_U(,KKY>GDZ>_]`-3O(.;E_>/O
M\B#$Y^S\\^GO]2_0\>_S^?#IZN_](.KKY>GDZ>_](.3E(.3G[.GO]?'CWNCG
MZN4@Y?#I]/7W_O(N`,7Q_O3G\^<`Q.?L_//I[R#*Z^7IY-\@4E-!("@E9"!"
M:70I`,7PZ>OOX]\@Y>W\\@#4]??AW^$@T/'\XNOE^.<`R_SC[_(`P>W<X^WY
M\^<`P>W<X^WY\^<@[.?M_>SA]._R`,7?\_3E(.+=XN'I[_(@X^GA(/3G(.3I
MX>/QX?;>("5S.R#!]?3\(.3E[2#L\._QY=\@[>$@Y?#A[=WKZ.7I+@#%W_/T
MY2#SW^/O]?'O\B#CZ>$@].<@Y.GAX_'A]MX@]/GM(.3EY._LW>WY[2#T[_4@
M]_'>\_3G("5S.R#!]?3\(.3E[2#L\._QY=\@[>$@Y?#A[=WKZ.7I+@#%\.'M
MY>KTW>OE\^<@].?R(/3EZ^7U].'?X?(@Y?'CX?/?X?(@\^'R`,'MX>W=^?/G
M(/3Y[2#D]>WA[.GJ_NT@\_3OZ??EW_GM(/3O]2#,Y>WO_3H`P>WA[=WY\^<@
M].?R(.7L]MSMZ?/G\B#T[_4@4&]R=&%L.@#![>'MW?GSYR#TY_(@T/'OXN_K
MWO(@T.7QW^OG^.?R.@!296=E>`#%[/;<[>GSYR#3]]WSY?GM`-/W_.OIX0#!
M\._L[>?L_.WE]?/G(/#KY_'O]N_QZ?[M(.3IX>CE\^GL_/3G].'R+@#!\._L
MX>KQ]?/LW>WOZ2#%[O7PY_'E].?TW?(`P?#O[.'J\?7S[-WMYR#DZ>7]Z/7M
M\^<@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@#!]N'?\>7SYP#!
M]N'?\>7SYR#,\.O\Z@#!]N'?\>7SYR#3]-[KY_(`P?;AW_'E\^<@[._Q]N_P
M[]_G\^?R`,'VX=_QY?/G(.'P_"#T[R#G[.7Q[^O\X^G\(.SO]0#!]N'?\>7S
MYR#FY?WC[_7R`,'VX=_QY?/G(.'P[^CGZN7U[-WM[_4@<V-R:7!T(.'P_"#T
M[^T@\/'O\_GQZ>W\(.KA]-SK[^/O(/3O]2#E[O7PY_'E].?TWBX`P?;AW_'E
M\^<@]._U`,'VX=_QY?/G(.'U]._](/3O]2#J_.SB[_4@X?#\(/3O(-WCX_'A
M]N\`Q.GAX_'A]MX@]_'>\_3G`,3IX>/QX?;>(-?QWO/TYSH@)7,`T_3<Z^CG
MZN4@P?#<[?3G\^<N`,'PW.WTY_/G(.SE(,S'(/7P[_/TY_'IYOSLY>WO(.S>
M[?7LX2X`P?#<[?3G\^<@[.4@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(@
MX^GA(/3O]?(@Y?#\[.7M[_7R(.3][R#LWNWE\BX`P?#<[?3G\^<@[.4@].GR
M(.;G]._][.7MY?(@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(N`,'PW.WT
MY_/G.B`E<P#4[R#AW_3G[.$@Y.4@[/#O\>7?(.WA(.'PX>WTY^CEWRX@Q?#I
M\_3QY?;\[.7M[_(@ZOGDZ>K\\B#KW.CO]?(Z(`#4[R#A\.'I]._][.7M[R`G
M)7,G(.3E[2#JX>CO\=_SZ.?JY2#S].\@)7,@8V]N9FEG=7)A=&EO;BX`U.\@
MX?#AZ?3O_>SE[>\@)R5S)R#DY>T@ZN'H[_'?\^CGZN4@\_3O(%9&4R!C;VYF
M:6=U<F%T:6]N+@#4[R#A\.'I]._][.7M[R`G)7,G(.3E[2#JX>CO\=_SZ.?J
MY2#S].\@8V]N9FEG=7)A=&EO;BX`U.\@X?#AZ?3O_>SE[>\@)V)A<V5D;B<@
MY.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P
M[]_G\^?R+@#4[R#A\.'I]._][.7M[R`G8F%S961N)R#DY>T@W??EZ2#JX>CO
M\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#A
MZ?3O_>SE[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@
M\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=D
M871A8F%S92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#J
MX?3GX^_QZ?[M+@#4[R#A\.'I]._][.7M[R`G9&%T86)A<V4G(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#4
M[R#A\.'I]._][.7M[R`G:&]S='-P96,G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@
M\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O_>SE
M[>\@)VAO<W1S<&5C)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_S
MY>GR(.KA].?C[_'I_NTN`-3O(.'PX>GT[_WLY>WO("=H;W-T<W!E8R<@Y.7M
M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E
M^>TN`-3O(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M(-WWY>D@ZN'H[_'I
M\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+@#4[R#A\.'I
M]._][.7M[R`G<&%S<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q
M]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`U.\@X?#AZ?3O_>SE[>\@)W!A<W-W;W)D
M)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_T
MZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)W!H<'1Y<&4G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@
MX?#AZ?3O_>SE[>\@)W!H<'1Y<&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I
M\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`U.\@X?#AZ?3O_>SE[>\@)W!H<'1Y
M<&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q
M[_3I[-[SY?GM+@#4[R#A\.'I]._][.7M[R`G=&%B;&4G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@
MX?#AZ?3O_>SE[>\@)W1A8FQE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@
M\?7H[-_SY>GR(.KA].?C[_'I_NTN`-3O(.'PX>GT[_WLY>WO("=T86)L92<@
MY.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GL
MWO/E^>TN`-3O(.'PX>GT[_WLY>WO("=U:60G(.3E[2#=]^7I(.KAZ._QZ?/T
MY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O
M_>SE[>\@)W5I9"<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I
M\B#T^>T@\/'O].GLWO/E^>TN`-3O(.'PX>GT[_WLY>WO("=U<V5R;F%M92<@
MY.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P
M[]_G\^?R+@#4[R#A\.'I]._][.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`U.\@X?#AZ?3O
M_>SE[>\@)W5S97)N86UE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`P?#AZ?3O_>SE[>\@T.7DW^\`P?#A
MZ?3O_>SE[>_R(-/U[.SE]-WW^>T`Q?#A[>'V[_'<`,'KZ^'CWB#*^>3IZN_]
M`,'KZ]SN].4@]._M(,KYY.GJ_"#SX?(`P?#O].7KW?/LX?3A`,7PZ?/T\>_V
MWB#S].GR(,7PZ>OOX]WR`,7PZ?/T\>_VWB#S].?M(.'KZ^?K[^/QX?;?X0#%
M\.'MW>WY\^<`Q?#A[>'V[_'<($-O;F9I9W5R871I;VX`P>7Q[^OI[-WMX?(@
MT?SD[_4`Q?#IZ^_CW?(@Y?#E[N7QX^'S]-X@Y>SPZ^_U].GS[-WM[_4@ZN7I
M[-WM[_4`P>GMW^/LX?3A`,3E[NG<`,3E[NG<(.7PZ>KE]N'KW^3A`,3E[NG=
M\B#TZ>S=\@#)Y.G\].?TY?(@X_'A[.S>\BXN+@#1_.OO\@#0Y?'I\_3Q[_;>
M(#$X,+``T.7QZ?/T\>_VWB#!\>GS].7QW`#0Y?'I\_3Q[_;>(,3E[NG<`,GD
MZ?STY_3E\B##\>'L[-[R`,GDZ?STY_3E\B##\>'L[-[R`,/QX>SLW?(Z`,KA
M[?SMY?(`S^D@ZN'M_.WE\B#HX2#E[/;A[=_F[^WTX>D@[.7TX>[](/SK^>T@
M]/GM(./QX>SL_NT@ZN'I(/3Y[2#S].?K_NT`S^D@ZN'M_.WE\B#HX2#E[/;A
M[=_F[^WTX>D@[.7TX>[](/3Y[2#S].?K_NT@[/SM[P#/Z2#JX>W\[>7R(.CA
M(.7L]N'MW^;O[?3AZ2#LY?3A[OT@]/GM(./QX>SL_NT@[/SM[P#%ZO3=Z^7S
MYP#5\._C\>'VWB#*\?7P]._C\=SVY_/G\B!3+TU)344`RO'U\/3OX_'A]N?L
MW>WO(.S>[?7LX2!3+TU)344`QR#A]>CE[?3IZN_P[]_G\^<@4T%33"#DY>T@
MY=_MX>D@Y.GAZ-WSZ>SG+@#,Y^W][.'TX2!335,`4U%,(,K=Z_7V[_(`Q=#)
MU-77V=,`4U]13"#*W>OU]N_R`-/A`+KDZ>\@\.OAW_/I[R`H7W-E;&8I`,'E
M\>_KZ>S=[>'R(-/<[._U`-#<\>_W[_(@Q._Q]?;\\>_U`,'P[^C>ZN7U\^<`
MP?#OZ-[JY?7SYR`E<P#!\._HWNKE]?/G("<E<R<`P?#OZ-[JY?7SYR#%\.GK
M[^/^[0#!\._HWNKE]?/G(/3O]2!C;VYF:6=U<F%T:6]N(/#O]2#DY^SI[_7Q
MX][HY^KE(//A[2!02%`@4V-R:7!T(//T[^T@\/'O\_GQZ>W\(.KA]-SK[^/O
M(/3O]2#E[O7PY_'E].?TWBX`P?#OZ.?JY?7LW>WO("5S(&-O;F9I9W5R871I
M;VXN`-3O('-C<FEP="#E[>?LW?'Y\^?R(/3O('-E='5P(.'P[^CGZN7]Z.?J
MY2#S].\Z("<E<R<N`,7PZ?/TWNSG`,'MX>;>].?SYP#,Y_?A[=WR(,'MX>;>
M].?SY_(`P>WAYM[TY_/G(,SG[?7LW/3Y[0#!\._TY>O=\^SA].$@P>WAYM[T
MY_/G\@#%\.GK[^/>(,'Q]^7?^>T`Q?#IZ]WN].4@[.GA(.?LY?'O[.?MW^$`
MQ?#IZ]WN].4@[^S<Y.$@X^GA(/#Q[_/HWNKG`,7PZ>O=[O3E(.W=[R#)Y.GO
MZO3>].<`Q?#IZ]WN].4@Y>[U\.?QY?3G]-X`Q?#IZ]WN].4@]_'>\_3G(./I
MX2#P\>_SZ-[JYP#%\.GK[^/>(/SK^>T@]/GM(.?LY?'O[.?MZ?[M+@#%\.GK
M[^/>(.7M_/(@X>WTZ>KEZ>S=[>_U`,7PZ>O=[O3E(/3O]?(@]^'QX>KTWO'E
M\B#P[_4@Z-WKY?3E(.'P_"#TZ?(@\.'QX>K<]/D@Z]_S].7R+B#*X?3\\.GM
M[/#O\>7?].4@[>$@].$@X>WTZ>/QW/CE].4@ZN'I(.WA(/3A(.7PZ>KOZ^O>
M\^7TY2#S].\@[-[M]>SA(//A\BX`Q?#IZ^_CWB#T[_4@Y.GA]_GQZ?/TWB#G
M[.7Q[^SG[=_A\CH`Q?#IZ^_CWB#TY_(@[._Q]M[R(/#O]2#HX2#=]^7I(.<@
MY^SE\>_LY^W?X3H`Q?#IZ]WN].4@].<@].'U]/STY_3A(/#O]2#HW>OE].4@
M[>$@X>OKW.[E].4Z`,7PZ>O=[O3E(/3O(.3IX??Y\>GS]-X@_O'A\CH`Q?#I
MZ]WN].4@].<@[._Q]MX@\._U(.CA(-WWY>D@YR#^\>$Z`,7PZ>O=[O3E(.3]
M[R#PY>3?X2#P[_4@].'I\>G<YN_U[2X`Q?#IZ]WN].4@].\@]_'Y[.'TZ>K\
M("?S]][LX2<N`,7PZ>O=[O3E(/3G(./K_O/SX2#SX?(Z`,'P[_/T[^O>(/3Y
M[2#PZ>\@\/'\\_;A]/GM(/#KY_'O]N_QZ?[M`,'P[_/T[^O>(,'MX?;O\=SR
M(-#Q[^+KWNSA]._R`,'P[_/T[^O>(%--4P#!Z?/HY_3>\>'R.B``T^7P]-WL
MXO'I[_(`T^7I\>GAZOSR(,'QZ>CL_/(`U.\@240@].?R(//][>3E\^?R(-WK
MY^[E+@#(W?/E`,C=\_3E(.7PZ>OOX]WR(/#O]2#HX2#SX?(@Y?#I]/'=\._U
M[2#MX2#AZ^O<YN7TY2#T[^T@ZOGDZ>K\(//A\BP@X>K\[.<@ZN'I(.'M(/3O
M[2#=]^7TY2#NY??<\^7I+@#0X?'A[.7T\>_P[]_G\^<@X?#O[.'J\?7S[-WM
M^>T@Y>[U\.?QY?3G]/[M(/#O]2#HW>OE].4@\/'\\^+A\^<N`-'UZ.S?\_3E
M(.3IW/;O\>7R(.7PZ>OOX]WR(.7L]MSMZ?/G\B#JX>D@].\@]_'\[>\@X>WA
M[=WY\^?R(/3Y[2#SY>O?Y/GM+@#%\.GK[^/>(/3G\B#P\>_TZ>SO_>SE[>?R
M(./K_O/SX?(N`,KAZ._QW_/TY2#TY^T@\/'O].GL_NSE[><@X^O^\_/A+"#F
M_NWG(/[QX?(@ZN'I(.SO\?;>(.?LY?'O[.?MW^'R+@#*X>CO\=_S].4@].?M
M(.7VX?'L[^/>(.7JZM_MY_/G\BP@].$@\/'O].GL_NSE[>$@]_'^[.'TX2P@
M].<@\.7QW^_D[R#A[>'MW?GSY_(@].?R(//EZ]_DX?(@ZN'I(-SKZ^7R(.7P
MZ>OOX]WR(.7L]MSMZ?/G\BX`T?WH[.GSYP#%W^WAZ2#DZ>'HW?/I[.$@4V-R
M:7!T<R#E[>?LW?'Y\^?R(/'UZ.S?\^7Y[0#0[^OKW?(@]._P[^CE\]_E\B#E
MW^WAZ2#PZ>CA[=WR(.SE(.'U]-X@].<@\.'QW.SE]/'O.B``P>/O\=WR`-/]
M[?3O[.<@T.7QW^OG^.<`T_WM]._LYR#0Y?'?Z^?XYSH`T/'=\.7I(/3O(.KK
MY>GDWR#P\?SSXN'SY_(@[>$@[_'I\^CEWR#CZ>$@\.7QZ?/S_/3E\>7R(//U
M[>3=\^7I\CL`Q>SVW.WI\^<`Q>SVW.WI\^<@Y.GA]N_Q_NT@[.7TX>[](/3O
M]2#A\._HY^KE]>S=[>_U(.KAZ2#T[_4@Y.?LZ>_U\>/GZ-WM]._R(&-O;F9I
M9W5R871I;VXN`,7L]MSMZ?/G(/3G\B#^\>'R(/3EZ^7U].'?X?(@Y>GS_.3O
M]2#\].'M(.SPX=_M[_7LY2#S].\@\_WS].?LX3L`Q>SVW.WI\^<@Y?#IZ^_C
MWO(@X^GA(.'P[^C>ZN7U\^<@]._U(.'UZ.7M].GJ[_T`Q>SVW.WI\^<@\_7K
MZ]WJ].<`S>$@Y>SVX>W?YN7TX>D@].\@[.7M[_T@[.4@Y?'CX?/?Y?(@\-_M
MX>KA.P#%[/;<[>GSYR#T[_4@)7,@S.7M[_T@\_3A(.'QZ?/TY?'<.P#%[/;<
M[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,KEZ^G^[2#0W^WAZN$`Q>SV
MW.WI\^<@]._U(.3IX>O\X^_U(,GDZ>_TWO3Y[2#0W^WAZN$`Q>SVW.WI\^<@
M]._U(.3IX>O\X^_U(,GDZ>_TWO3Y[2##\>'L[/[M(-#?[>'JX0#%[/;<[>GS
MYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,7IZOSMX?(`Q>SVW.WI\^<@]OSQ
M]/GSY_(@*'5P;&]A9"D`T_7Q\=_J[?GSYP#0\?[TX2#S]?'QW^KM^?/G(-X@
M[.7TX>K?[>?SYR#CY>GT[^WIZO[M(/3LY^S<]/GM`,7?\^_D[_(MU?#OX_'A
M]MX`QR#%W_/OY._R+=7P[^/QX?;>(.3E[2#=]^7I(.KA].'W^?'GZ.7?+@#5
M\._C\>'VW@#!Z^/\\>GH[._R(-7P[^/QX?;>\@#,W>/EZ._R`,'J_?'Y\^<@
MT_7M]-[QY_/G\@#,Y?'IZMP@X?#\(/3A(.'Q]^7?X2#DZ>'WY=_QZ?/G\B#T
M[_4@2&]R9&4@W??O]>T@]^'HY=\Z`,7PZ>OOX]X@ZN'TY?WH]>WSY_(@].'N
MZ>W\[.?SY_(`P>7Q[^OI[-WMX?(@T^_]Y.'R`,3IY?WH]>WSYR#0Y^/>\@#-
M_/3I[R#'[.GS]N'?\>GO`,3IW//TY^SA(.SE].'N_2#CY>GT[^WIZO[M(.KE
MZ^G^[0#$Z=SS].?LX2#LY?3A[OT@\.7QZ>7W[^S=[>_U(.KAZ2#C\>'L[-[R
M(.KEZ^G^[0#0Z][J]/'O(,3IX?/TWNSA]._R`,'QX=_Y\^<`P?'AW_GSYR#J
MX>D@X]WLZ?/LX0!3<&%M`,7I\^'C^>/>(,7IY.GJ_NT@U^'QX>KTWO'Y[0#$
MZ>'?\>7SYR#JY>OI[_T`Q.GAW_'E\^<@\_3>Z^?R`,3IX=_QY?/G(./QX>SL
MWO(`P>CKWNSA].$`N.WA\>[G`+CT[_(@N.WA\>[G\@#0[^OI].7?X2#>(,7P
MX?'WW^$`RN'TW//TX?/G`,SO\?;>(.'P[^C>ZN7U\^?R`,3IY?WH]>WSYRW/
MY/SR`,3IX>/QX>SLZ?/LW>WA`,O?\_3A(.O=[N7Y[0#!]N'?\>7SYR#T[_4@
M9&]M86EN(.'P_"#TYR#DZ>7]Z/7M\^<`T_3]ZR!;0U-370#*]0#/(/7P[_;<
MZN7K[_(@)R5S)R#DY2#B\=WHY^KE+@#(W>SA`,C=[.$@)]#KY_'O]N_QW^7R
M(,3G[/SSZ>_U(,KKY>GDZ>_])P#!\._S]._KW@#4[R#AW_3G[.$@X^GA(/#Q
M[_/HWNKG("<E<R<@\_3O(//]\_3G[.$@X?#E\_3<Z^<N(,3E(.SP[_'EW_3E
M(.WA(.[A[>'L\.7?].4@[-WW\>D@[>$@Y>/J\>GHY=\@].\@X=_TY^S<(//A
M\BX`U?#OY.7?ZO3G\@#%\.GT]???X0#%\.GT]??>\B#P\>_SZ-[JYR`G)7,G
M(//T[R#S_?/TY^SA+@#4X2#DY>3O[-WMX2#T[_4@]_'>\_3G("<E<R<@Y.GA
MX_'<]N?JX>T@Y?#I]/7W_O(@X?#\(/3O(//]\_3G[.$N`,7PZ?3U]][R(.3I
MX>/QX?;>("<E<R<N`,7PZ?3U]][R(.3IX>/QX?;>("<E<R<@X?#\(/3O(//]
M\_3G[.$N`,_I(/'UZ.S?\^7I\B#E\.'MX?;=\>CGZN'M(.7PZ?3U]_[R+B#*
MW.WTY2#E\.'MX?;\\?3Y\^<@X^GA(.WA(.3EW_3E(/3I\B#AZ^OAX]WR+@#%
M\.GT]??>\B#E\._HWNKE]?/G(.7VY>3QZ>KO_2!C;VYF:6=U<F%T:6]N+@#%
M\.GT]??>\B#A\._HWNKE]?/G(/3O]2#E]N7D\>GJ[_T@X?'WY=_O]2!C;VYF
M:6=U<F%T:6]N("5S+@#%\.GT]??>\B#E[>?LW?'Y\^<@)R5S)P#%\.GT]??>
M\B#EX^/QX?;>("5S`-/][>_XYR`M(-#E\=_KY_CG`,'MX?3OZ]X`Q/WSYP#!
M[>'T[^O>`,'MX?3OZ]XOQ/WSYP#![>'T[^O>.B``Q/WSYP#$_?/G.B``U?#E
M\>3EW^KTY?(`U?#O\_3>\>GNYP#%\-_HY?3O`-3O(.'Q]^7?[R#JX?3AX_'A
M]M[R(//UX_?Q[^WI\^SO_2#DZ>'C\=SVY^KE`%-Y;F--3`#+W.CO\B#S_>WT
MX>[G\B#S]._U\B#\\>_U\B#A[>'FWO3G\^?R`-#?[>'JX?(`R>3I_/3G].7R
M(-#?[>'JX0#)Y.G\].?TY?(@T-_MX>KA`,'E\>_KZ>S=[>'R(-3A[=SC\>'R
M`-/T_/?O\CH`Q?'CX?/?Y?(`P>7Q[^OI[-WMX?(@U.'T[_KO]0#!\>GH[/SR
M(-3GZ^7V_NWO]0#(Y?'L[^KQX?/?X2#TY^T@].7KY?7TX=_A(/[QX3H@`,CE
M\>SOZO'A\]_A`,CE\>SOZO'A\]_A.B``U.\@\/'\]/7P[R`G)7,G(.3E(.+Q
MW>CGZN4N`,3IX??EW_'I\^<@T/'O]/WP[_4`T/'O\_GQZ>W>(,'P[^3O]]X@
MX>GTWNSA]._R`-#Q[_/Y\>GMW"#!\._DY>KT_`#*Y=_LY>WO`,S\[>\@RN7?
M[.7M[P#3]._?]^?SYR#JY>GLW>WO]0#*[_'U]MX@ZN7I[-WM[_4`U.4`Q?7W
MX?'I\_3O_>SE(/#O]2#W\>?SZ>SO\._IWO/A].4@].\@T_WS].?LW"#LX?(N
M`,<@Y?#=ZO3A\^<@1E10(.3E[2#EW^WAZ2#AZOSLYR#DZ>'HW?/I[.<N`-3O
M(//]\_3G[.$@2&]R9&4O2V]L86(@Y.7M(/7P[_/TY_'?YN7I("(E<R(`Q.GA
M]^7?\>GSYSHZ(,<@ZNO<\^<@Y.4@]N_Q]/[HY^KE(.7PZ?3U]_[R`-3O(/#A
M\=SH]?'O(.7PZ>OOX_[M(-WJZ^7I\^4N(+CN[^3O\BX`SR#DZ>'WY>GQZ?/T
MWO(@\/'=\.7I(.WA(/'UZ.S?\^7I(-WMX2#L_.WI[.\@\.OAW_/I[R#%[N_U
M\^GOY._TWO/E^>TL(./IX2#MX2#L\._QY=_TY2#MX2#W\>?SZ>SO\._IWO/E
M].4@Y>[O]?/I[^3O]-[SY>GR+@#'(.K<]/D@\.OE]?'<(.S\[>\`U.$@Y.7D
M[^S=[>$@Y^SE\>_K[^/?[_4@Y.7M(.7?[>'I(-WCZO7QX0#4[R!)1"#TY_(@
MY?#A]M[R(.3E[2#JX>CO\=_SZ.?JY2P@WO3A[2#JY>W\(-X@Y.4@XO'=Z.?J
MY2#S].<@XMSSYR#DY>3O[-WM^>TN`,<@Y?#A]MX@\/'O\_3=Z.?JY2#E\.GT
M]??^\B#S].\@Q.GE]>CU[?/I[^/QW/;O(//A\BX`U.\@].S>[.$@4$=0(/#O
M]2#A\._S\-SSZ.?JY2#A\.'I].7?].\@X^GA(/3G[2#E\.'KWNCE]?/G(/3O
M]2#U\._CY>/QX>SLW>WO]2#LY^W>[.'T[_(N`-3O($E$(/3G\B#KW_/TX?(@
MY.GA[>_LWO(@Y.7M(._QW_/HY^KE+"#>].'M(.KE[?P@WB#DY2#B\=WHY^KE
M(//TYR#BW//G(.3EY._LW>WY[2X`QR#KW_/TX2#DZ>'M[^S>\B#DY>T@ZN'H
M[_'?\^CGZN4N`,_I(.3U[>'T_/3G].7R(.KQ]?#T[^/QW/;G\^?R(.'PX>GT
M[_WM(.'S]N'KWB#S_>WDY?/G(%=%0BX`U.\@X^7C[^W\\B#P\>_S]-WHY^KE
M(//T[R#G[.7Q[^O\X^G\(//A\BX`U.\@X?'WY=_O("5S(/#QW?#EZ2#MX2#P
MY?'IW??EZ2#LZ>$@)7,@\?WH[.GSYRX`U.\@X?'WY=_O("5S(/#QW?#EZ2#M
MX2#PY?'IW??EZ2#JW/#OZ>7R("5S(/'UZ.S?\^7I\BX`U.\@X?'WY=_O(.3E
M(.SP[_'EWR#MX2#A[?3IX_'A]N7?(//T[^T@Y>'U]/P@]._U+@#4[R#A\??E
MW^\@Y.7M(/#E\>G=]^7I(.3EY._LW>WA+@#4X2#PX?'AZMST^2#EW^WAZ2#E
M\.GJY?;AZ]_DY?(@X^GA(.'U]/P@].\@[-[M]>SA+W)F8S@R,B#LWNWU[.$N
M`,<@ZN'TW//TX?/G(/#KWO'O]?(@[^C\[>?R(.7?[>'I(./M^?/T_"#\].D@
MY.?LZ>_U\>/EWR#P\?SBZ^?LX2#LY2#T[^T@26YT97)N970@17AP;&]R97(L
M(.7NX>GTW^'R(/#Q[^+KY^S<]/GM("AB=6=S*2#T[_4@8G)O=W-E<BP@].$@
M[_#OW^$@Y.7M(.7?X>D@Y/7MX?3\(.WA(.[E\.7QX?/H[_WM+B#,\._QY=\@
M[>$@Y.7?].4@)_/J[_7PW^3IX2<@\_3G[2#OZ/SMYRP@\/'OXNO>[.'TX2#S
M].<@Z^7I]._U\>/?X2#T[_4@8G)O=W-E<B#>(.KAZ2#J_.OG[-P@]._U+B#!
M[2#T[R#S_?/TY^S<(//A\B#EW^WAZ2!7:6YD;W<@.7@@Y=_MX>D@\._K_2#P
MZ>CA[?P@[>$@Y.7?].4@)\/E[>GJWB#!\._T]???X2#0\>_S].'SW^'R)R#J
MX>D@[>$@\/'=\.7I(.WA(.7PX>WEZNKI[=[SY?3E("AR96)O;W0I+EQN7,'U
M]-X@Y=_MX>D@\/'OY>GD[_#OW^?SYRX@T.'TWO/TY2#/RB#A[2#HW>OE].4@
MX>K\[.<@[>$@Y._UZ]WXY?3E(//E(.KA]-SS].'SYR#PZ][Q[_7R(._H_.WG
M\BX`QR#TX?7T_/3G].$@(B5S(B#DZ>'C\=SVY^KE+@#'(.'QZ?/TY?'>(/#K
MY?7QW"#L_.WO`,<@Z-WSYR#T[_4@\/'OX_'<[.SA]._R($=N=5!'(/#QW?#E
MZ2#MX2#D[^CEWR#CZ>$@].<@0W)Y<'1?<&=P.CH@ZNO<\^<N`,<@X_'A[.SA
M]._H]?'?Y.$@)^K<Y._R)R#EW^WAZ2#>Y.<@W.3EZ>$N`-3O(.S>[?7LX2#P
M[_4@\_3<Z^CGZN4@\_3I\B`E<R#S]._M("5S(.SE(.C=[.$@)7,@Y>SVX>W?
M\^CGZN4N"L'U]/P@Y.7M(.'P[_3EZ^7?(.7PZ>+EXN'?^?/G(/STZ2#DZ>'B
MW//HY^KE(.KAZ2#=X^GMY2#JX?3A[>_G]/PN`-3O(/SM[^SA(/#O]2#HX2#W
M\>?SZ>SO\._IY=_TX>D@_/3A[2#S]>WDW>7S].4@\_3G(//EZ]_DX2#S_>WH
MY?/G\BX`QR#BZ>+KZ>_HWNKG($]P96Y34TP@X?#AZ?3EW_3AZ2#CZ>$@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B#JZ]SSYRX`QR#P\>_TW^SG\^<@(B5S(B#DY>T@
M[/#\\>7SY2#MX2#A\._HY^KE]>CEWR#CZ>'TWR#TX2#DY>3O[-WMX2#TY_(@
M]?#E\>+AW^WO]>T@].\@[-WCZ?/T[R#E\.GT\>7P]/P@[-WCY>CO\@#4[R#P
M\?SC\>'L[.$@\._U(/?QY_/I[._P[^GEW_3E(./IX2#TY^T@Y>SVW.WI\^<@
MX?7T[_T@]._U(.7?Y._U\B#LY^WU[-ST^>T@*"5S*2#DY>T@XO'=Z.?JY2#S
M].\@\_WS].?LX2X`QR!R96=I<W1R>2#EW^WAZ2#O(/3Q_/#O\B#LY2#T[^T@
M[_#OW^\@[^D@Y?;A\>SOX]WR(/3O]2!(;W)D92#E\.GJ[^GM^>WO_>TN(.SE
M].'N_2#T[_7R+B#%Y/X@\/'=\.7I(.WA(./QW/CE].4@_/3I(.7VX?'L[^/=
M\B#T[_4@2&]R9&4@W??E].4@Y>/JX?3A\_3>\^7I+@#'(.'QZ?/TY?'>(.KA
MZ2#DY>[IW"#PZ^7U\=WR(.S\[>\`QR#DY>[IW"#PZ^7U\=P@[/SM[P#/(.7N
M]?#G\>7TY_3>\B`B)7,B(.3IX>/QW.?JY2X`SR#E[O7PY_'E]-[R("(E<R(@
MX?#OZ.?JY?WHY^KE+@#4[R#AW_3G[.$@Y>GS_.3O]2#CZ>$@)7,@Y.GAX_'<
M]N?JY2X`QR#C\>'L[-X@\._U(._QW_/A].4@Y.7M(/7PW/'WY>DN`,<@Y?'C
MX?/?X2#P\>_S]-WHY^KE(//TYR#KW_/TX2#E\>/A\^G^[2#SX?(N`-3O(/#Q
M[_/Y\>GM_"#A\??EW^\@(B5S(B#DY>T@]?#<\??EZ2X`QR#PW.WY(.KAZ2#J
MW/3Y(/#KY?7QW?(@[/SM[P#'(/#<[?D@\.OE]?'<(.S\[>\`U.$@Y.7D[^S=
M[>$@\._U(//TW>OMX?3E(/?<Z.?JX>T@X?#\(/3O(/#Q[^?C[_WLY>WO(.+>
M[.$N`-3O(.'Q]^7?[R#P[_4@\_3EW^OA].4@Y.4@[/#\\>7SY2#MX2#S^>CE
MWRX`S^D@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(@X?#OZ.?JY?WHY^KA
M[2#E\.GT]??^\BX`SR#JX?3<Z^_C[_(@Z.7LW/3Y[2`G)7,G(.3E(.+QW>CG
MZN4N`,3E[2#U\-SQ]^_U[2#%\.GK[^/=\B#DZ>'HW?/I[.7R+@#$Y>T@]?#<
M\??O]>T@].S>[.'TX2#P[_4@Y.4@[/#O\>_][2#MX2#E[/;A[>GSZ._][2#E
M[?/Y[.'T^>S=[>$N`-7PW/'W[_7M(/#OZ^OOWR#WX?'AZO3>\>7R(//E(.'U
M]/P@].\@\.7DW^\N(,7I\^'CW./A].4@)7,@]^'QX>KTWO'E\BP@\/'=\.7I
M(.WA(/7PW/'W[_7M(.OIX_STY?'OZ2#A\/P@)7,N`-#Q_.+KY^SA(.KA]-P@
M].?M(/#Q[_/HWNKG("<E<R<@\_3O(//]\_3G[.$N("5S+@#0\?SBZ^?LX2#J
MX?3<(/3G[2#P\>_SZ-[JYR`G)7,G(//T[R#S_?/TY^SA.B`E<RX`T/'\XNOG
M[.$@ZN'TW"#TYR#DZ>'C\>'VWB#DY>3O[-WM^>T@]._U(/?QWO/TYR`G)7,G
M(.'P_"#T[R#S_?/TY^SA.B``T/'\XNOG[.$@ZN'TW"#TYR#DZ>'C\>'VWB`G
M)7,G(.'P_"#T[R#S_?/TY^SA.B``T/'\XNOG[.$@ZN'TW"#TY^T@Y>WG[-WQ
M^?/G("<E<R<Z("5S`-#Q_.+KY^SA(.KA]-P@].?M(.'P[_/T[^O>(.'Q]^7?
M[_4Z(,3E[2#S]-SKZ.?JY2`E<RX`T.'Q[_7SZ=SSZ.?JY2#P\?SBZ^?LX2#J
MX?3<(/3G[2#A\._S]._KWB#T[_4@X?'WY=_O]3H@U.\@)7,@Y=_MX>D@[.7C
MX>O]].7Q[R#A\/P@].\@[-WCZ?/T[R#E\.GT\>7P_.SE[>\@[-WCY>CO\B`H
M)60@0GET97,I+@#0X?'O]?/IW//HY^KE(/#Q_.+KY^SA(.KA]-P@].?M(.'P
M[_/T[^O>(/3O]2#A\??EW^_U.B#3]-SKZ.?JY2#L_.WO(-WMX2#T[-[LX2#T
M[_4@)7,N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7L]MSMZ?/G
M(.'U]._](/3O]2#T[-[LX?3O\B#T[_4@[.?M_>SA]._R+@#0X?'O]?/IW//H
MY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#DY>3O[-WM^>T@Q.GE]>CU
M[?/I[^/QW/;O]2X`T.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GS
MX>/YX]X@]._U(./EX^_M[_3O\CH@)7,N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA
M(.KA]-P@].?M(.7I\^'C^>/>(.3EY._LW>WY[2#G[.7Q[^OOX]_O]2X`T.'Q
M[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@].?R(.7QX^'S
MW^'R.B`E<RX`T.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/Y
MX]X@\.OG\>_V[_'I_NT@Y.GAZ.7SZ>S\].?TX?(Z("5S+@#0X?'O]?/IW//H
MY^KE(//VW.OLX2#S].<@]OSQ[.$@\?7H[-_SY?GM+B"Z\_GR(.'VWO/A].4@
MZN7M_"#JW/#OZ>\@X?#AZ?3O_>SE[>\@\.7DW^\N`-#A\>_U\^G<\^CGZN4@
M\_;<Z^SA(//TY^T@Y>KTW>OE\^<@].?R(.KAZ._QZ?/LW>WG\B#KY>GT[_7Q
MX]_A\B#T[_4@Q.GE]>CU[?/I[^/QW/;O]2X@T.'QX>KAZ_X@Y._JZ>S<\_3E
M(.'QX_STY?'A+@!"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!+;VYT86MT
M9&5T86EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@=F5R
M<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`-#A\>_U\^G<\^CG
MZN4@\_;<Z^SA(.KA]-P@].?M(.7MY^S=\?GSYR#TY_(@Z]_S].'R(.3IX>WO
M[-[R+B#0X?'AZN'K_B#D[^KI[-SS].4@X?'C_/3E\>$N`,'E\>_KZ>S=[>'R
M(,CE\_/AZ^_MW^KG\@#/(.7N]?#G\>7TY_3>\B!)34%0(.3E[2#U\._S].?Q
MW^;EZ2#J[^GM_/?QY_/T[_7R(/;AZMWK[_7R+@#!]?3>(.<@Y>W=\>/EZ>$@
MY.7M(/7P[_/TY_'?YN7TX>DN`,'U]-X@YR#KY>GT[_7QX]_A(.3E[2#=]^7I
M(._K[^KKY_'YZ.7?(.'J_.SG+@#!]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I
M(-WCZO7Q[R#A\??EW^\@<F%R+@#!]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I
M(-WCZO7Q[R#A\??EW^\@>FEP+@#!]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I
M(-WCZO7Q[_(@X?'IZ.S\\B#JW/'TX?(N`,'U]/SR(.\@[^3GX_SR(//A\B#E
M\.GT\=WPY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS^2!#;&EC:V%T96QL
M+2AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(.S=\_D@2%144"U!4$DN`,'U]/SR
M(.\@[^3GX_SR(//A\B#E\.GT\=WPY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@
M[-WS^2!S;7,R96UA:6PM*&AT='`Z+R]S;7,R;6%I;"YC;VTI(.S=\_D@2%14
M4"U!4$DN`,'U]/SR(.\@[^3GX_SR(//A\B#E\.GT\=WPY>D@[>$@\_3=Z^WE
M].4@[.?M_>SA].$@[-WS^2!33510("#JX>D@].?R(%9O9&%F;VYE+4ET86QY
M(.S\[>\@\^4@X?'IZ.SO_?(@5F]D869O;F4N(,'PX>GTY=\@W>WA(.OOX^'Q
MZ>'S[/P@96UA:6P@\_3G(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN`-3O(/#EY-_O(.'U]/P@X?#AZ?3EW_3AZ2X`U.\@\.7DW^\@X?7T
M_"#L\._QY=\@[>$@W??EZ2#L_.WO(.'JW?'AZ>_U\BX`P?7T_"#T[R#PY>3?
M[_4@[/#O\>7?(.WA(/#E\>G=]^7I(.S\[>\@X?'IZ.SO_?(@ZN'I(-SM^2#J
MW/3Y(/3EZ^7?X2`H.BDN`,'U]/P@].\@\.7DW^\@[/#O\>7?(.WA(/#E\>G=
M]^7I(.S\[>\@[^KTX>3IZMWR(/3I[-WR+@#!]?3\(/3O(/#EY-_O(.SP[_'E
MWR#MX2#PY?'IW??EZ2#L_.WO(.O?\_3A(.'QZ>CL_NT@]_GQZ?/LW>WY[2#L
MY2#JY>W\(-X@Y>OKY^WIZOP@Y?'Y].?LX?3IZOP`P?7T_"#T[R#PY>3?[R#P
M\=WPY>D@[>$@Y=_MX>D@W>WA\B#=X^KU\>_R(.'QZ>CL_/(N`,'U]/P@].\@
M\.7DW^\@\/'=\.7I(.WA(/#E\>G=]^7I(.KYY.GJ_"#W\?[LX?3O\B#SY2!2
M1T(@Y.7JX>7NX>3IZMX@[._Q]MXL(/`N]RX@)R,Q,C,T868G+@#!]?3\(/3O
M(.'Q]^7?[R#PY?'IW??EZ2#T[_7R($U)344@9')I=F5R<R#P[_4@]_'G\^GL
M[_#OZ>_][?3AZ2#A\/P@].?M(/7PY_'E\]_A(.7PZ?3QW?#O[?3A\B#DZ=SV
M[_'A(/#Q[^/QW.SLX?3A(.WA(.3IX??EZ?'?YN_M].'I(/3A(/#E\>GE]_SL
MY>WA(/3Y[2!E;6%I;"#JX>D@[>$@].$@Y>SVX>W?YN_U[2#LY2#T[^T@ZN'T
MW.OKY^OO(/3Q_/#O+@#!]?3\(/3O(.'Q]^7?[R#EZ]WC]^7I(/3I\B#Q]>CL
MW_/EZ?(@]/GM(/?Q^>S<]/GM(.KAZ2#T^>T@X_'A[.SA]._SY>GQ_NT@X^GA
M(/SKX2#T[R#P\?SC\>'L[.$@]._U($AO<F1E+"#JX>D@X^GA(/3I\B#E]N'Q
M[._CW?(@\._U(.7?[>'I(.7CZN'TY?/TY^S=[>7R(//E(.'U]/P@ZN'I(.3E
M[2#PX?'=]^_U[2#DZ>K=\B#T[_7R(.7PZ>OOX]WR(./IX2#A]?3=\B#TZ?(@
M\?7H[-_SY>GR+@#!]?3\(/3O(.'Q]^7?[R#JX?3AX_'<]N7I(/3I\B#E\.7J
M]-SSY>GR(/3Y[2#T_?#Y[2#,R<S%+"#^\_3E(/3A(/#E\>GE]_SLY>WA(._Q
MZ?/LW>WY[2!M86EL(.WA(.7L]N'MW^;O[?3AZ2#LY2#T[^T@ZN'TW.OKY^OO
M(/3Q_/#O+@#!]?3>(.<@]OSQ[.$@W??EZ2#>Y.<@Y?#E[N7QX^'SZ.7?+@#!
M]?3\(.7?[>'I("5S+@#!]?3\(.7?[>'I($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(,/IX2#MX2#DY=_TY2#T[R#A[?3IZN7?[.7M[R#A]?3\(/?QY>G<YN7S
MZ.4@W>WA(/#Q_./QX>SLX2!E;6%I;"#P[_4@ZN'TX>OAXN'?[>7I(.'U]-X@
M].<@[._Q]MXN(,/IX2#KW_/TX2#TW?3OZ?GM(/#Q[^/QX>SLW/3Y[2#L\._Q
MY=_TY2#MX2#E\.GSZN7UZ.7?].4@].\@)7,`P?7T_"#EW^WAZ2#T[R#BX?/I
MZOP@X?'WY=_O(/'UZ.S?\^7Y[2#T[_4@\/'OX_'<[.SA]._R("=(;W)D92<N
M(-#E\>G=]^7I(/3A(.SO[>_PW/3IX2#JX>D@].$@XN'SZ>K<(.S=\><@\._U
M(/?QY_/I[._P[^GO_>WTX>D@X?#\(/3O[2#P]?'>[>$@ZN'I(/3I\B#E]N'Q
M[._CW?(@]._U(//U\_3>[.'T[_(N(`#4[R#LWNWU[.$@X?7T_"#C\=SVZ.?J
MY2#LY2#J^>3IZN_SY>O?Y.$@*"5S*2#DZ>'V[_'E].GJWB#A\/P@].<@Y.GJ
MWB#SX?(N`,'U]/SR(.\@X?'IZ.S\\B#P\=WPY>D@[>$@Y=_MX>D@]._UZ]SW
MZ?/T[^T@W>WA+@#4[R#P\?SBZ^?LX2#A]?3\(.'MX?;=\>CGZN4@X?#\("5S
M+B#/(/?QWO/TY_(@ZMSKY?/E(/3G[3QB<B\^X>WA]N_QW"#P\>_BZ][LX?3O
M\B#A\/P@].\@\.'QX>K<]/D@55),.CQB<B\^)7,@ZN'I(/?QY_/I[._P[^GE
MWR#T[^T@X>K\Z^_UZ.\@8G)O=W-E<CH\8G(O/B5S`,'U]/SR(.\@Y>[U\.?Q
MY?3G]-[R(.3E(.SP[_'EWR#MX2#A\._S]>SPZ=WSY>D@>FEP(.KAZ2!G>FEP
M(.'Q]^7?X2X`U.\@\_WS].?LX2#A]?3\(-WWY>D@X?#E[>7QX^_P[^GGZ.7?
M+@#!]?3>(.<@].GLWB#P\=WPY>D@[>$@Y=_MX>D@X?'IZ.S\\BX`Q>GSZ?3>
M\>GA`-GQX0#)]^WGZ^'T_NWTX?(@].?M(/[QX0#,[_'VWB#^\>'R`,7PZ>OO
MX]X@_O'A\@#4W_3K[_(`U-_TZ^_R("A4;V]L=&EP*3H`T/'\\@##Z>$@[>$@
MZO'A]-[SY?3E(/#OZ^OA\.O<(.'M].GJY=_LY>WA+"#J\>'TWO/TY2#PX?3G
M[-SM[R#T[R!#;VYT<F]L("A00RD@WB#T[R!#;VUM86YD("A-86,I(/#KWNKT
M\>\L(.7M_B#JW.WE].4@ZNOIZBX`T][LY?'A`,7MX>OKX>/>(//E(/#GX^'?
M[R!(5$U,`,']\>GO`,KO\?7VW@#0W.WY(/#KX=_SZ>\@*%]T;W`I`,SE].'V
M\=SSY>GR`,'E\>_KZ>S=[>'R(-3QW_#OZ^?R`,'KY^C=\B#>(/CE]>3=\@#4
M\0#+X>WHX?/LW>WO\B#T_?#O\B#DY>3O[-WM^>TN`-#KY^KT\>_K[^/>\_3E
M(/3G[2#E\.GK[^/>(//A\CH@`,?KY>KT\>_MZ>K>(,3IY?WH]>WSYP#'Z^7J
M]/'O[>GJWB#$Z>7]Z/7M\^<@X^GA(.7PZ?/T\>_VWB#A[>'V[_'<\B#JX?3<
M\_3A\^?R(/3O]2#P\>_C\=SL[.'T_/(@\^'R`,?KY>KT\>_MZ>K>(,3IY?WH
M]>WSYSH`P>3][>'TYR#G(/#Q_//BX?/G(//T[^T@5D93(.KA]-SK[^/O+@#!
MY/WMX?3G(.<@\/'O\^C>ZN4@Y?#I\.O=[^T@\.OG\>_V[_'I_NT@ZN'TW"#T
MY^T@Y=_S[^3O(/3O]2#W\=[S].<N`,'D_>WA].<@YR#AZ^OAX]X@Y>[O]?/I
M[^3O]-[SY?GM(./IX2#T[R!61E,@X?'WY=_O("(E<R(N`,'D_>WA].<@YR#A
MZ^OAX]X@Y>[O]?/I[^3O]-[SY?GM(./IX2#T[R!61E,@X?'WY=_O("5S+R5S
M+@#!Y/WMX?3G(.<@X>OKX>/>(/3O]2`E<RX`Q.7M(.7?[>'I(.3U[>'TWB#G
M(//][>3E\^<@\_3O(.3IX>KO[.GS]-X@4U%,+@#$Y>T@Y=_MX>D@Y/7MX?3>
M(.<@\_WMY.7SYR#LY2!34TPN`,'D_>WA].<@YR#A[?3IX_'A]MX@5D93(.'Q
M]^7?[_4N`,'D_>WA].<@YR#DY^SI[_7QX]_A(.KA].'K_./O]2!61E,@(B5S
M(BX`P>3][>'TYR#G(.3G[.GO]?'CW^$@ZN'TX>O\X^_U(%9&4RX`P>3][>'T
MYR#G(.3G[.GO]?'CW^$@5D93(.'Q]^7?[_4N`,'D_>WA].<@YR#DY^SI[_7Q
MX]_A(.KE[>_](%9&4R#A\??EW^_U+@#!Y/WMX?3G(.<@X?#O\_7L\-_E\^<@
MY.7D[^S=[?GM+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@(B5S(BP@[R#VW.KEZ^_R
M(.3E[2#EW^WAZ2#JY>W\\BX`P>3][>'TYR#G(.3IX>/QX?;>("5S+"#O(/;<
MZN7K[_(@Y.7M(.7?[>'I(.KE[?SR`,'D_>WA].<@YR#DZ>'C\>'VWB`G)7,G
M.B`E<RX`P>3][>'TYR#G(.3IX>/QX?;>(.KA].'K_./O]2!61E,@Y?#A[>'K
M[.+A[?SLY>WA("AR96-U<G-I=F5L>2DN`,'D_>WA].<@YR#DZ>'C\>'VWB#J
MX?3AZ_SC[_4@5D93+@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XZ("5S+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U
M(%9&4R#A\??EW^_U("(E<R(N`,'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@5D93
M(.'Q]^7?[_4N`,'D_>WA].<@YR#DZ>'C\>'VWB!61E,@Y?#A[>'KX>SBX>W\
M[.7MX2`H<F5C=7)S:79E;'DI.B`E<RX`Q.4@[/#O\?X@[>$@\/'O\^3I[_'?
M\_D@]._M(/3QW??O[?3A(.KA]-SK[^/O+@#$Y2#L\._Q_B#MX2#E[MSC^2#P
MZ^?Q[_;O\=_E\B#PZ?/T[_#OZ>?TZ>KO_0#!Y/WMX?3G(.<@]OSQ]/GSYR#O
M\>GS[._](/3O]2`E<RX`P>3][>'TYR#G(.SE].'JW^WG\^<@]._U(%9&4R#A
M\???[_4N`,'D_>WA].\@].\@W.WOZ>/LX2#T[_4@5D93(.'Q]^7?[_4@(B5S
M(BX`P>3][>'T[R#T[R#<[>_IX^SA(/3O]2!61E,@X?'WY=_O]2#CZ>$@X_'<
M^.GL[RX`P>3][>'T[R#T[R#<[>_IX^SA(/3O]2!61E,@X?'WY=_O]2X`Q.4@
M[/#O\?X@[>$@X>WOW^[Y(/3O(//U[/#IY?/LW>WO(.'Q]^7?[RX`Q.4@[/#O
M\?X@[>$@Y.GAXMSS^2#T[^T@ZOWQZ>\@ZN'TW.OOX^\@5D93("AV9G-R;V]T
M*2X`Q.7M(.7?[>'I(.3U[>'T_.T@[>$@ZN'TX??Y\>?H[_WM(._I(/#Q[_3I
M[-[SY>GR(./IX2#A]?3>(/3G[2#S_>WDY?/G+@#!Y/WMX?3G(.<@[.7T[^WO
M[.'SW^$@]._U("5S(//E("5S.B#O(/;<ZN7KZ^_R(/7PW/'WY>D@WN3G`,'D
M_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.KA].'K_./O]2X`P>3][>'T
MYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@ZN'TX>O\X^_U.B`E<RX`P>3][>'T
MYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@X?'WY=_O]2`B)7,B+@#!Y/WMX?3G
M(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U("5S+R5S+@#!Y/WMX?3G
M(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U+@#!Y/WMX?3G(.<@Y>KT
MW>OE\^<@]._U(")M:VES;V9S(BX`Q.7M(.SP_/'E\^4@[>$@[.7TX?;QX?/T
MY=\@X?7T_"#T[R#=X^/QX?;O(%=O<F0`Q.4@[/#O\?X@[>$@X_'<^/D@\_3O
M(%9&4R#A\??EW^\@(B5S(BX`Q.4@[/#O\?X@[>$@X_'<^.<@\_3O(%9&4R#A
M\??EW^\@*&-O<'DH*2#A\-WT]??E*2X`Q.4@[/#O\?X@[>$@X_'<^/D@Y.7D
M[^S=[>$@]._U(%9&4R#A\??EW^_U+@#5\._C\>'L[.GS[-WMX0#!ZOWQ^?/G
M(,'KZ^'C_NT`P>KU\?[MY>D@].<@].7KY?7TX=_A(//A\B#E[=WQX^7IX0#,
MYR#A[>'LY>W\[.7M[R#TW>OO\B#T[_4@X?'WY=_O]2X`S.<@X>WA[.7M_.SE
M[><@X?#<[?3G\^<@X?#\(/3O[2#E[O7PY_'E].?TWB#S].<@\_WMY.7SYSH@
M`,SG(.'MX>SE[?SLY>WG(.'PW.WTY_/G(.'P_"#T[^T@Y>[U\.?QY?3G]-X@
M\_3O.B``S.<@P?'WY>GOZ.7TY^S=[>\`S.<@]^7I\>GF_.SE[>\@\_3OZ??E
MW^\@]/WP[_4Z("5S`,SO[=SDY?(`P>/M^?/T[P!5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`P>/M^?/T[R#\[>_LX2#W\=[S].<@WB#J^>3IZOSR+@#!
M\._S_>WDY?/G(/3QW??O[?3O\B#S]._I]^7?[_4`P>W^[?7L[P#,YR#E[N_U
M\^GOY._TY^S=[>$@\/'OX_'<[.SA].$@Y.4@[/#O\>_][2#MX2#=]^_U[2#P
M\?SSXN'SYR#SY2#KY>GT[_7QX]_E\B#A\._J[_#>\B_A[?3IX_'A]M[R+^7P
MZ>K\Z^?SY_(@X^GA(.O\X^_U\B#A\_;AZ^7?X?(N(-#A]-[S].4@S\H@X^GA
M(.WA(.3EW_3E(/3E]^WIZMWR(//G[.7I_O/EZ?(@\_3O(&UO>FEL;&$N;W)G
M(/#O]2#SX?(@Y.7?]^WO]>T@\/GR(.WA(.7PZ?3QW?CE].4@\^4@\/'OX_'<
M[.SA].$@].<@\/'\\^+A\^<@\_3O(&-L:7!B;V%R9`#,YR#O\>GS[-WM[R#W
M\?[LX0#,YR#U\._S].?QZ>;\[.7MYR#E\-WJ].'SYP#%[>?LW?'Y\^<`Q>WG
M[-WQ^?/G("5S`,7MY^S=\?GSYR#JX?3<\_3A\^?R(.'PX>WTY^S=[>_U`,7M
MY^S=\?GSYR#W\=[S].<`)R5S)R#%[>?LY?'^Z.?JY2X`U.\@\/'\X_'A[.SA
M(.'MX>+<Z.SI\^?R(.3IX>/QW/;GZN4N`,'P[_/T[^O>`,'P[_/T[^O>(/SK
M^>T@]/GM(.'Q]^7?^>T@\?7H[-_SY?GM(//T[^T@Y>[U\.?QY?3G]-XN`,KE
M]N'KX=_A(.OA].GMZ>K<(./QW.SLX?3A`-'Y[.'ZZN_?(.'QZ>CL[]\MRN7V
MX>OAW^$`U_'>\^<@]/'=]^_M]._R.B`E<P#-X2#W\>?SZ>SO\._IY^CEWR#G
M(/#Q[^7PZ>OEX^S=[><@].GLW@#7\=[SYR!34TP`U_'G\^GL[_#OZ>7?].'I
M(.'M(/3O(/SM[^SA+^KYY.GJ_/(@Y=_MX>D@Y.GA]N_QY?3IZMPN`,\@]_'>
M\_3G\B`E<R#DY>T@Y=_MX>D@Y>[O]?/I[^3O].?LW>WO\B#CZ>$@)7,N`,3I
MX??EW_'I\^<@U_'G\_3^[0#%\.GK[^/=\B#7\=[S].<`Q>/C\>'VWB#7\=[S
M].<`QR#EX^/QX?;>(/?QWO/TYR#=]^7I(.'PY>WE\>/O\._IY^CEWR#CZ2<@
MX?7T_"#T[R!S:71E+@#!Z^OAX]X@ZOGDZ>KO_2#W\=[S].<`Q>[O]?/I[^3O
M]-[SY>GR(-?QWO/TYP"\[>_LX2#7\=[S].<`U.\@_.WO[.$@]_'>\_3G("<E
M<R<@]?#<\??EZ2#>Y.<N`+SM[^SA(-?QWO/TYSH`O.WO[.$@U_'>\_3G.B``
MU_'>\_3E\@#7\=[S].7R(//T[R#3_?/TY^SA.@#/(.KA]-SK[^/O\B!61E,@
MY.7M(/7PW/'WY>DN`,3IX>KO\-WR`+CCZO7QY?(@]._P[^CE\]_E\B#P[_4@
MXO'=Z.?JX>T@\_7L\.7QZ>OA[.+<[>_M].'I.B``Q>/J]?'\].?TX0#4Z>S>
M(//E(.OE\/3<(.'P_"#T_O'A+@#4Z>S=\@#$_O/TY2#TZ>S=\B#CZ>$@[>$@
MY?#IZ]WN^0#,Y?3AXNOG]-X`QR#E\.GBY>+AW_GSYR#A\-WT]??E("T@X?7T
M_"#T[R#LWNWU[.$@[/#O\>7?(.WA(-SKZ^'NY2#LY2X`N.KD[_/G`+CKY>/W
M[_(@N.KD[_/G\@#*W.CE].<@Q?7H]>/QW.SLZ?/G`,K<Z.7T[R#CW>SI\^SA
M`,K<Z.7TX3H`T._K_2#XY^O>`,7L]MSMZ?/G("5S`,7L]MSMZ?/G(.7N^?3E
M\>GJWO(@Z?/T[_/EZ]_DX?(`Q>SVW.WI\^<@\^'M("5S`,7L]MSMZ?/G(./E
MX^_M_/3O\@#%[/;<[>GSYR#E\>/A\]_A\@#/\>'T_/3G].$`S_'A]/STY_3A
M.@!6;V1A9F]N92#)].'KW^'R(.S=\_D@4TU44`#0T<_3S]?'`-#1S]//U\<A
M(2$@P=;!R='%T]3%(-3/(-#1S\/1P<S,P2#,S\W/R2#3P=,@P=#/("5S+@#0
M\>_EZ>3O\._?Y_/G`-3E`,7BY._LX>3IX=_A`,KAZ_GSWNOHX?3E`,KAZ_GS
MWNOHX?3E(//T[R`E<P#*X>OY\][KZ.'TY2P@)7,`T._IW"#E]N'Q[._CWB#H
MX2#E[/;A[-_FY>D@].\@)7,@X?;O_2#S]>WDY>CEW_3E(//TY^T@]?#G\>7S
MW^$[`-#OZ>$@Y?;A\>SOX]X@[>$@Y>SVX>W?YN7TX>D@X?;O_2#S]>WDY>CE
MW_3E(//TY^T@]?#G\>7SW^$[`-#OZ?SR(.7?[>'I(.\@Y.GA]_GQZ?/TZ>K\
M\B#WX?'AZO3>\>'R.P#0[^G\\B#EW^WAZ2#O(/?A\>'J]-[QX?(@Y>GSX>/Y
MX^GJ_NT[`-#OZ=WR(-;<\^7I\@#*X>CO\=_S].4@\._IW"#P\?SSZ.7TX2#H
MX2#E[>7QX^_P[^GGZ._][2#S]._M(.7PY>[E\>/A\_3>(.7L\.OO]?3I\^S=
M[>_U(.KEZ>S=[>_U+@#0Z]ST[_(`T.O<]._R(//E(.SO[=SDY?(@0U-3`-#K
MW/3O\B#T[_4@)7,@[.7M[_T@\_3A(.'QZ?/TY?'<("CHX2#E]N'Q[._SZ.7?
M(//TY^T@Y?#\[.7MYR#EW_/OY.\I.@#0Z]ST[_(@]._U(/#?[>'JX0#,[^W<
MY.$@\.O<]._U\@#0Z]ST[_(Z`+CM].'SYR#A[=WL[_4@\^4@ZOSLXN_U\@#!
M[>7L[_(Z`,'MY>SO\CH@`-/O]M_A`,O?\_3A(.7PZ>CU[.G^[0#%\>/A\]_A
M`,3IY?WH]>WSYR#%\>/A\]_A\@#4Y^O=]OGM[R#%\>/A\]_A\@!8+5)E9@!8
M-3`Y=C,@PN'SZ>KOWR#0Y?'I[_'I\^SOWP!8-3`Y=C,@U_'>\^<@Y?#EZO3A
M[-WM[_4@ZNOEZ>3I[_T`6#4P.78S(,7MX>OAZO3IZOP@O.WO[.$@R-WLX?3O
M\@!8-3`Y=C,@P>WAX^WY\>GS].GJ_"#*Z^7IY-\@R-WLX?3O\@!8-3`Y=C,@
MQ?#EZO3<\^7I\@#%Q0#%Q<7%`,7TWO/IX0#-X=\`S>'I+"#3]>SV^>W^`,7?
M\_3E(//E(.KA]-SS].'SYR#*Q<G,Q<W/U2X@U_'G\^GL[_#OZ>7?\_3E(/3O
M(%L\/ET@\.O>ZO3Q[R#CZ>$@[>$@Y?#I\_3QW?CE].4@\^4@ZN'TW//TX?/G
M(%=94TE724<N`,3E[2#=]^7TY2#A]>CE[?3IZN_P[^GGZ.7?+@#$Y>T@Y?#I
M]/'=\.7TX>D@[>$@W??E].4@].\@]^'QX>KTWO'A("=<)R#S].\@O.WO[-P@
M\^'R+@#$Y2#D_O/A].4@W>/C]?'G(.3IY?WH]>WSYR!E;6%I;"X`Q.7M(.'M
M].GS]._I]]_SX?3E(.KA[=WMX2#PY>3?[R#A\/P@].\@X?'WY=_O(.7I\^'C
M^>/>\B#SY2#A[?3?\_3OZ??A(/#EY-_A(//T[R`E<RX`N/?E].4@X?#O\_7M
MY.7HY=\N`+CWY?3E(.'P[_/U[>3EZ.7?+CQB<B`O/L7U]^'QZ?/T[_WLY2#P
M[_4@]_'G\^GL[_#OZ=[SX?3E(/3G[2#U\.?QY?/?X2X`T/'=\.7I(.WA(.3^
M\^7TY2#LZ>$@W>/J]?'G(/3I[-XN`-#QW?#EZ2#MX2#Q]>CLW_/E].4@].\@
M1&%T851R964@X^GA(.WA(/?QY_/I[._P[^GEW_3E(%-I9VYU<',N`-#QW?#E
MZ2#MX2#Q]>CLW_/E].4@].\@5D93+4)A8VME;F0N`-#QW?#EZ2#MX2#PY?'I
MX_'<^.7TY2#T[R#P\?SBZ^?LX2#P\>GM(//TY=_KY?3E(.'MX?;O\=P@X^GA
M(.'U]/PN`-#QW?#EZ2#MX2#S]>SPZ^?Q_O/E].4@].\@55),(/#O]2#DY=_W
M[>7I(.'U]-X@YR#S_>WDY?/G`-#QW?#EZ2#MX2#E\.GKW>[E].4@]._M(.7N
M]?#G\>7TY_3>(./IX2#DZ>'C\>'VWBX`T/'=\.7I(.WA(._QW_/E].4@W>WA
M(/SM[^SA(/?QWO/TYR#CZ>$@Y.GAX_'A]MXN`-#QW?#EZ2#MX2#O\=_SY?3E
M(-WMX2#\[>_LX2#W\=[S].<@X^GA(.3IX>/QX?;>+@#0\=WPY>D@[>$@[_'?
M\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#P\>_SZ-[JYRX`T/'=\.7I(.WA
M(._QW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#CZ>$@Y>WG[-WQ^?/G+@#0\=WP
MY>D@[>$@[_'?\^7TY2#LZ>$@Y>W=\>/EZ>$@X^GA(.7J]-WKY?/G+@#0\=WP
MY>D@[>$@Y/[SY?3E(-WMX2#\[>_LX2#CZ>$@].<@[=WA(.KA].?C[_'?X2X`
MQR#S_>WDY?/G(//A\B`E<R#DZ>'J_/#GZN4N(-#A\>'JX>O^(.3OZNGLW//T
MY2#MX2#NX>WA\_7MY.7HY=_TY2X`QR#'Z^7J]/'O[>GJWB#SX?(@Q.GE_>CU
M[?/G`,<@Q^OEZO3Q[^WIZMX@\^'R(,3IY?WH]>WSYSH`QR#!\/PZ(,3IY?WH
M]>WSYSH`S^D@T.OG\>_V[_'?Y?(@\^'R`,<@26YT97)N970@Y.GE_>CU[?/>
M(//A\B#<Z^OA[N4@X?#\(/3G[2#=[>'Q[N<@].?R("5S(//][>3E\][R(//A
M\BX@P^GA(/3G[2#P\>_S].'SW^$@].?R(.'S]MSKY>GA\B#P\=WPY>D@[>$@
M[N'MX?/U[>3EZ.7?].4N`-3O(/SM[^S<(//A\@#4[R#S_?/TY^SA(.'UZ.7M
M].GJ[_#OW^?SY_(@Y.7M(/7P[_/TY_'?YN7I(/#Q[_/HWNKG(/?QY_/T_NTL
M(-X@YR#KY>GT[_7QX]_A(.'U]-X@W??EZ2#A\.7MY?'C[_#OZ>?HY=\@X^GA
M(.K<\._I[R#K_./O+@#4[R#S_?/TY^SA(.'UZ.7M].GJ[_#OW^?SY_(@Y.7M
M(/7P[_/TY_'?YN7I(.O?\_3A(/?QY_/T_NTL(-X@YR#KY>GT[_7QX]_A(.'U
M]-X@W??EZ2#A\.7MY?'C[_#OZ>?HY=\@X^GA(.K<\._I[R#K_./O+@#/($)R
M;W=S97(@\^'R(/;AW^WE].'I(.WA(-WWY>D@X>OKW.[EZ2#A\/P@].?M(-WM
MX?'NYR#TY_(@)7,@\_WMY.7SWO(@\^'R+B##Z>$@].?M(/#Q[_/TX?/?X2#T
MY_(@X?/VW.OEZ>'R+"#HX2#P\=WPY>D@[>$@[N'MX?/U[>3EZ.7?].4N`,\@
M0G)O=W-E<B#SX?(@Y.7M(/7P[_/TY_'?YN7I(.'U]-X@].<@Z^7I]._U\>/?
MX2X`SR!"<F]W<V5R(//A\B#DY>T@]?#O\_3G\=_FY>D@X?7TWB#TY^T@Y?#I
MZ^_CWB#EZO3]\/GSY_(N(-#A]-[S].4@0V]N=')O;"]/<'1I;VX@*R!0(./I
MX2#EZO3]\/GSYRX`QR#T\=WW[_7SX2#F_NWG(/[QX?(Z`,<@\/'OZN'H[_'I
M\^S=[><@\^'R(/3A]?3\].?TX3H`U.\@\.O>\>7R(/SM[^S<(//A\CH`SR#M
MW>_R(//A\B#J^>3IZOSR(./IX2`E<R#EW^WAZ3H@)7,`S^D@Y?#IZ^_CW?(@
M\^'R(-WW[_7M(.7MY^SE\?GHY=\@X^GA(/3G(.3IW/'JY>GA(.'U]-[R(/3G
M\B#S_>WDY?/G\BX`S^D@Y?#IZ^_CW?(@\^'R(-WW[_7M(.7MY^SE\?GHY=\N
M`,\@ZOGDZ>K\\B#SX?(@W.OKX>[E`,\@ZOGDZ>K\\B#SX?(@W.OKX>[E+"#E
MZ]WC[O3E(/3A(.SG[?WLX?3<(//A\B#JX>D@ZMSM].4@Y=_S[^3O(.SE(/3O
M(.W=[R#SX?(@ZOGDZ>K\+@#/Z2#MW>_I(.KYY.GJ[]\@Y.7M(/3AZ?'IW.;O
M]>T`S^D@X?#O[.'J\?7S[-WM[^D@\^'R(.7N]?#G\>7TY_3=\CH`6\'P_.KQ
M]?CG(.KEZ>S=[>_U(//E(.7I\^'C^>/IZMQ=`%O![>'V[_'<(-#Q[^+KWNSA
M]._R70!;Q>SVW.WI\^<@ZN7I[-WM[_4@\^4@Y>GSX>/YX^GJW"`M`%O%[/;<
M[>GSYR#JY>GLW>WO]2#SY2#EZ?/AX_GCZ>K<("T@)7,@X_'A[.S=\ET`6^/Q
MX>SLWB`E<R#A\/P@)7-=`,3IX??EW_'I\^<`Q.GAX_'A]MX@P_'A[.S>\@#/
M[-SDY?(`PN_>Z.7IX0#)Y.G\].?TY?(@Q>GJ_.WA\BXN+@#%W_/OY._R`,7N
M[^3O\@#4\>_P[_#OW^?SYR#3_>WDY?/L[_4N+BX`Q?#IZ^_CW?(`Q>[O]?/I
M[^3O]-[SY>GR`,3IX>/QX?;>(-/U[>3=\^SO]2XN+@#1]>CLW_/EZ?(`R>3I
M_/3G].7R(-#?[>'JX2XN+@#7\=[S].7R`,3IY?7H]>WSZ>_C\=SV[_(`Q^SE
M\>_K_./I[P#G\>7LW^$`\.'TWO/TY2#EY/X`X?'WY=_O`.'P_"#T[R`E<R`H
M)7,I(//TZ?(@)7,@)7,`:#H`W.SE\^$`Y>WS^>SA]/GLW>WO`./QX>SLW?)=
M`&UK:7-O9G,MZOGDZ>K\\B#KW.CO]?(@)60@ZN'TW"#TYR#DY^SI[_7QX]_A
M($E33RX`_.WO[.$`Y.7M(-WWY>D@Y>/JX?3A\_3AZ.7?`.3E[2#=]^7I(.7C
MZN'TX?/TX>CEWR#AZOSLYP#SY^SEZ?GLX?3<\>GO`/3OZ?(@Y>KA]/P`Y>GJ
M[^WO\_3OZ??EW^$`Y>SVW.WI\^<@Y.GA]N_Q_NT`<VUS(//E(&5M86EL(.S=
M\_D@2%144`#S].'HY?'\\@#KW_/TX2#E\>/A\^G^[0#JW.3O\@##\=SX].4@
M]._M(.KYY.GJ_"#D_>\@]N_QW?(@X^GA(.7PZ>+EXN'?^?/G`.7M[_#OZ>?L
MW>WA`.'M_NWU[.$`Y?#IZ^_CWB#W\=[S].<`V.?VZ>'JWB#*W/'TX0``````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O
M:&5L<"YX;6P`````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S,S(P`#$P-3$U-#,Q,#8Q`#`R,#,P-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*
M/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]E;%]'4B]H96QP+GAM;"QV(#$N
M,B`R,#`T+S`U+S(W(#(P.C(R.C$V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@
M/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0
M;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E
M('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A
M;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@
M:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO
M=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T
M87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L
M96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S
M90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O
M(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@
M;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O
M<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@
M;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@
M3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@
M=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S
M"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE
M=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I
M=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W
M96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@
M0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@
M<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL
M86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC
M93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O
M('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE
M8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I
M;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@
M;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@
M=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K
M960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B
M92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO
M(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"CPO:&5L<#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V9A7TE2+P``````
M````````````````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`V,0`P,38V,C<`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O9F%?25(O3$-?34534T%'15,O````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`R,#0Q-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F85])4B],0U]-15-304=%4R]H;W)D
M92YM;P``````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S-3<W,3<`,3`U,34T,S$P
M-C$`,#(R,#<S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````IP4``!P```!4+0``BP<``(Q:````````N'@```X`
M``"Y>```#P```,AX```-````V'@```@```#F>```"P```.]X```,````^W@`
M``0````(>0``)`````UY```I````,GD``!D```!<>0``)@```'9Y```,````
MG7D``"0```"J>0``#P```,]Y```+````WWD```X```#K>0``!0```/IY```H
M`````'H```@````I>@``"@```#)Z```5````/7H``!(```!3>@``"P```&9Z
M``"%````<GH```X```#X>@``"@````=[```-````$GL```X````@>P``$0``
M`"][```-````07L```P```!/>P``#0```%Q[```&````:GL```H```!Q>P``
M#P```'Q[```8````C'L```P```"E>P``#@```+)[```.````P7L```@```#0
M>P``+@```-E[```:````"'P``#(````C?```.````%9\``!4````CWP``%$`
M``#D?```6@```#9]``!7````D7T``#0```#I?0``#0```!Y^```'````+'X`
M``H````T?@``#P```#]^```%````3WX``!$```!5?@``"````&=^```)````
M<'X```D```!Z?@``)0```(1^```@````JGX``!,```#+?@``$````-]^```/
M````\'X```H`````?P```P````M_```/````#W\``!0````??P``"0```#1_
M```-````/G\``!(```!,?P``'@```%]_```/````?G\```H```".?P``#P``
M`)E_```(````J7\``"0```"R?P``%````-=_```6````['\```@````#@```
M&0````R````'````)H````P````N@```+````#N````.````:(````,```!W
M@```!0```'N````%````@8````H```"'@````P```)*````7````EH````H`
M``"N@```#P```+F````.````R8```!@```#8@```(P```/&````.````%8$`
M`!0````D@0``%P```#F!```7````48$``!<```!I@0``$P```(&!```/````
ME8$``!\```"E@0``#P```,6!```&````U8$```L```#<@0``$````.B!```5
M````^8$``!4````/@@``!P```"6"```0````+8(```4````^@@``%0```$2"
M```1````6H(```P```!L@@``.P```'F"```4````M8(```,```#*@@``.0``
M`,Z"```2````"(,``"<````;@P``+````$.#```J````<(,``"4```";@P``
M"@```,&#```&````S(,``"\```#3@P``-P````.$```N````.X0``%4```!J
MA```+0```,"$```M````[H0``"T````<A0``0````$J%```C````BX4``",`
M``"OA0``+0```-.%```S`````88``!4````UA@``&0```$N&```I````988`
M`"0```"/A@``$0```+2&```*````QH8``!````#1A@``%@```.*&```6````
M^88``!0````0AP``"````"6'```I````+H<```X```!8AP``"@```&>'```$
M````<H<```D```!WAP``!@```(&'```1````B(<```<```":AP``!````**'
M```&````IX<```T```"NAP```P```+R'```#````P(<``!<```#$AP``$P``
M`-R'```(````\(<```0```#YAP``00```/Z'```:````0(@``"````!;B```
M%0```'R(```&````DH@``!4```"9B```&````*^(```B````R(@``"X```#K
MB```'0```!J)```A````.(D``%0```!:B0``*0```*^)```'````V8D```<`
M``#AB0``%0```.F)```*````_XD```\````*B@``#0```!J*```/````*(H`
M``T````XB@``"0```$:*```4````4(H```8```!EB@``'0```&R*```3````
MBHH``!0```">B@``!@```+.*```4````NHH``%0```#/B@``9````"2+```$
M````B8L```X```".BP``!0```)V+```;````HXL``!H```"_BP``$0```-J+
M```1````[(L``!P```#^BP``*@```!N,```A````1HP```4```!HC```$P``
M`&Z,```2````@HP```H```"5C```#P```*",```1````L(P``!,```#"C```
M#````-:,```&````XXP```8```#JC```$````/&,```1`````HT```4````4
MC0``#````!J-```0````)XT```4````XC0``#0```#Z-```&````3(T```<`
M``!3C0``#0```%N-```'````:8T```L```!QC0``!P```'V-```)````A8T`
M``D```"/C0``"@```)F-```9````I(T```P```"^C0``$````,N-```2````
MW(T``!,```#OC0``*P````..```[````+XX``"````!KC@``"````(R.```V
M````E8X```@```#,C@``!@```-6.```$````W(X```X```#AC@``'@```/".
M```;````#X\``"$````KCP``'@```$V/```9````;(\``!X```"&CP``'0``
M`*6/```;````PX\``"````#?CP``)@````"0```;````)Y```!X```!#D```
M'````&*0```F````?Y```#,```"FD```)@```-J0```K`````9$``#@````M
MD0``+P```&:1```2````EI$``"D```"ID0``$@```-.1``"B````YI$``!8`
M``")D@``(P```*"2```H````Q)(``"D```#MD@``*````!>3```?````0),`
M`"````!@DP``)0```(&3```H````IY,``#````#0DP``D@````&4```A````
ME)0``!P```"VE```)@```-.4``!!````^I0```P````\E0``!P```$F5```'
M````494```8```!9E0``#0```&"5```0````;I4``!(```!_E0``$P```)*5
M```2````II4```P```"YE0``#@```,:5```/````U94``!,```#EE0``#0``
M`/F5```H````!Y8```,````PE@``#0```#26```1````0I8``!<```!4E@``
M&P```&R6```"````B)8```4```"+E@``$````)&6```$````HI8```T```"G
ME@``#@```+66```#````Q)8```X```#(E@``"````->6```/````X)8```\`
M``#PE@``!P````"7```-````")<``!`````6EP``#0```">7```+````-9<`
M``8```!!EP``#````$B7```1````59<``!D```!GEP``"P```(&7```-````
MC9<``"(```";EP``&P```+Z7```T````VI<```H````/F```&````!J8```9
M````,Y@``!8```!-F```#0```&28```4````<I@```L```"'F```(@```).8
M```O````MI@```L```#FF```"0```/*8```9````_)@```L````6F0``%P``
M`"*9```7````.ID```D```!2F0``%@```%R9```/````<YD``!D```"#F0``
M%@```)V9```.````M)D``!@```##F0``#0```-R9```F````ZID``$,````1
MF@``"````%6:```+````7IH``"\```!JF@``#@```)J:```%````J9H```8`
M``"OF@```P```+::```$````NIH```H```"_F@``"@```,J:```/````U9H`
M`!````#EF@``%P```/::```1````#IL``!D````@FP``%P```#J;```)````
M4IL```H```!<FP```@```&>;```%````:IL```T```!PFP``&P```'Z;```7
M````FIL```D```"RFP``#@```+R;```-````RYL``!(```#9FP``.````.R;
M```@````)9P```@```!&G```#@```$^<``![````7IP``!@```#:G```!0``
M`/.<```8````^9P``!D````2G0``&P```"R=```9````2)T```8```!BG0``
M!@```&F=```0````<)T```\```"!G0``$````)&=```/````HIT```L```"R
MG0``#P```+Z=```,````SIT```\```#;G0``!P```.N=```&````\YT```X`
M``#ZG0``#`````F>```/````%IX```@````FG@``"````"^>```3````.)X`
M`!X```!,G@``(0```&N>```@````C9X``!D```"NG@``%P```,B>```E````
MX)X``!<````&GP``!````!Z?```,````(Y\```,````PGP``"````#2?```+
M````/9\``!````!)GP``$P```%J?```4````;I\```P```"#GP``"0```)"?
M```.````FI\```L```"IGP``&P```+6?```'````T9\```H```#9GP``#0``
M`.2?```)````\I\```4```#\GP```P````*@```8````!J````H````?H```
M!````"J@```F````+Z````X```!6H```%0```&6@```%````>Z````<```"!
MH```#````(F@```(````EJ````H```"?H```!@```*J@```(````L:````(`
M``"ZH```!@```+V@```$````Q*````D```#)H```$````-.@```)````Y*``
M``D```#NH```&@```/B@```(````$Z$``!D````<H0``#@```#:A```*````
M1:$```(```!0H0``#0```%.A```)````8:$``!(```!KH0``%````'ZA```=
M````DZ$```8```"QH0``$0```+BA```)````RJ$```0```#4H0``.0```-FA
M```]````$Z(``#H```!1H@``'@```(RB```.````JZ(```0```"ZH@``!@``
M`+^B```5````QJ(```8```#<H@``!````..B```1````Z*(```8```#ZH@``
M"@````&C```B````#*,```0````OHP``!0```#2C```$````.J,```P````_
MHP``#@```$RC```*````6Z,```4```!FHP``.@```&RC```P````IZ,``#4`
M``#8HP``*0````ZD```X````.*0``"D```!QI```/P```)ND```N````VZ0`
M`"T````*I0``'P```#BE```/````6*4``!(```!HI0``"P```'NE```F````
MAZ4``"D```"NI0``)````-BE```F````_:4```@````DI@``"@```"VF```@
M````.*8``"````!9I@``)@```'JF```*````H:8``!D```"LI@``*0```,:F
M```2````\*8```H````#IP``#`````ZG```/````&Z<``!`````KIP``0```
M`#RG``!P````?:<``&8```#NIP``#@```%6H```)````9*@```H```!NJ```
M$@```'FH```3````C*@```P```"@J```!@```*VH```/````M*@``!(```#$
MJ```$````->H```1````Z*@``!P```#ZJ```(P```!>I``!J````.ZD```\`
M``"FJ0``$````+:I```$````QZD```L```#,J0``(````-BI```4````^:D`
M``P````.J@``#````!NJ```/````**H``!4````XJ@``*0```$ZJ```J````
M>*H``"8```"CJ@``)P```,JJ```I````\JH``"H````<JP``&0```$>K``!"
M````8:L``!$```"DJP``$@```+:K```3````R:L``!0```#=JP``#P```/*K
M```6`````JP``!<````9K```$````#&L```1````0JP``#0```!4K```$P``
M`(FL```2````G:P``#4```"PK```%````.:L```'````^ZP```P````#K0``
M(````!"M```4````,:T``!$```!&K0``%P```%BM```<````<*T``!,```"-
MK0``$0```*&M```:````LZT``!X```#.K0``&@```.VM```1````"*X``!<`
M```:K@``%````#*N```7````1ZX``!4```!?K@``"0```'6N```0````?ZX`
M`!$```"0K@``!@```**N```&````J:X```<```"PK@``%@```+BN```&````
MSZX```0```#6K@``!````-NN```'````X*X```X```#HK@``#````/>N```,
M````!*\```T````1KP``#@```!^O```H````+J\```P```!7KP``#P```&2O
M```*````=*\```@```!_KP``"0```(BO```K````DJ\```0```"^KP``#P``
M`,.O```'````TZ\```@```#;KP``"0```.2O```4````[J\```P````#L```
M#0```!"P```.````'K```!8````ML```$0```$2P```#````5K````8```!:
ML```!````&&P```+````9K````L```!RL```#0```'ZP```*````C+```!``
M``"7L```#P```*BP```1````N+```!<```#*L```"@```.*P```1````[;``
M``0```#_L```#P````2Q```Z````%+$```4```!/L0``#````%6Q```>````
M8K$```X```"!L0``$````)"Q```+````H;$```P```"ML0``"0```+JQ```'
M````Q+$```H```#,L0``"0```->Q```.````X;$``!````#PL0``&@````&R
M```*````'+(```H````GL@``#````#*R```/````/[(```@```!/L@``!@``
M`%BR```'````7[(```4```!GL@``"P```&VR``!'````>;(```T```#!L@``
M"0```,^R```$````V;(```,```#>L@``$P```.*R```3````]K(``!,````*
MLP```@```!ZS```$````(;,``"4````FLP```P```$RS```%````4+,```0`
M``!6LP``"@```%NS```-````9K,``&@```!TLP``"0```-VS```,````Y[,`
M``4```#TLP``!@```/JS```;`````;0``"\````=M```#P```$VT```3````
M7;0``!L```!QM```&````(VT```7````IK0```X```"^M````P```,VT```(
M````T;0```<```#:M```"@```.*T```+````[;0```<```#YM```40````&U
M```0````4[4```P```!DM0``#0```'&U```:````?[4``$H```":M0``!@``
M`.6U```&````[+4```8```#SM0``"0```/JU```8````!+8``!<````=M@``
M!@```#6V```-````/+8``%<```!*M@``$P```**V```3````MK8```(```#*
MM@``"P```,VV```(````V;8```T```#BM@``"@```/"V```.````^[8```<`
M```*MP``"P```!*W```,````'K<```T````KMP``#````#FW```)````1K<`
M``D```!0MP``"@```%JW```'````9;<```D```!MMP``!P```'>W```;````
M?[<``!(```";MP``"@```*ZW```6````N;<```D```#0MP``$````-JW```2
M````Z[<```0```#^MP``$0````.X```:````%;@``!8````PN```%````$>X
M```7````7+@``!P```!TN```&0```)&X```'````J[@```4```"SN```#```
M`+FX```(````QK@``!<```#/N```#````.>X```?````]+@``!H````4N0``
M$P```"^Y```$````0[D```H```!(N0``!````%.Y```,````6+D```4```!E
MN0```@```&NY```X````;KD``"P```"GN0``$@```-2Y```I````Y[D``#(`
M```1N@``"@```$2Z```L````3[H``"X```!\N@``,P```*NZ```S````W[H`
M`#@````3NP``#P```$R[```8````7+L``!````!UNP``#P```(:[```3````
MEKL``!0```"JNP``$@```+^[```4````TKL``!4```#GNP``+0```/V[```M
M````*[P``#$```!9O```+@```(N\```O````NKP``"P```#JO```$P```!>]
M```(````*[T``!<````TO0``"````$R]```K````5;T``"$```"!O0``&@``
M`*.]```)````OKT``$4```#(O0``00````Z^```$````4+X``!,```!5O@``
M%````&F^```3````?KX```D```"2O@``"@```)R^```/````I[X``!````"W
MO@``!P```,B^```.````T+X```4```#?O@``&P```.6^```(`````;\```8`
M```*OP``%````!&_```1````)K\```X````XOP``.````$>_```"````@+\`
M``8```"#OP``#@```(J_```%````F;\```<```"?OP``#@```*>_```&````
MMK\``"@```"]OP``#````.:_```<````\[\``"D````0P```%P```#K````?
M````4L```%P```!RP```%````,_````?````Y,```!`````$P0``!P```!7!
M```.````'<$```P````LP0``#````#G!```3````1L$```H```!:P0``'0``
M`&7!```9````@\$```4```"=P0``$0```*/!```1````M<$``"0```#'P0``
M%0```.S!```2`````L(```X````5P@``&0```"3"```(````/L(```D```!'
MP@``#0```%'"```*````7\(```<```!JP@``#P```'+"```+````@L(``!H`
M``".P@``"@```*G"```'````M,(```T```"\P@``"````,K"```>````T\(`
M`!(```#RP@``+`````7#```:````,L,```D```!-PP``"@```%?#```5````
M8L,```4```!XPP``%````'[#```$````D\,``!````"8PP``!@```*G#```'
M````L,,``!X```"XPP``*````-?#```*`````,0``!P````+Q```"P```"C$
M```:````-,0``!0```!/Q```!````&3$```%````:<0```8```!OQ```!@``
M`';$```;````?<0``#0```"9Q```-````,[$```@`````\4``"D````DQ0``
M(````$[%``!!````;\4``!H```"QQ0``*````,S%```I````]<4``%`````?
MQ@``(@```'#&```(````D\8```4```"<Q@``&0```*+&```9````O,8``"H`
M``#6Q@``(P````''```N````)<<``#0```!4QP``"````(G'```7````DL<`
M``H```"JQP``!P```+7'```A````O<<``!````#?QP``#@```/#'```+````
M_\<```<````+R```$P```!/(```(````)\@```L````PR```"@```#S(```4
M````1\@``#(```!<R```!0```(_(```%````E<@``!<```";R```#P```+/(
M```$````P\@```H```#(R```"0```-/(```+````W<@```T```#IR```#```
M`/?(```.````!,D```4````3R0``!````!G)```-````'LD``#(````LR0``
M10```%_)```7````I<D``!X```"]R0``%````-S)```4````\<D```<````&
MR@``#@````[*```J````'<H```8```!(R@``#````$_*```-````7,H``!$`
M``!JR@``"P```'S*```V````B,H```H```"_R@``(@```,K*```+````[<H`
M``\```#YR@``,@````G+```.````/,L```4```!+RP``#@```%'+```3````
M8,L```<```!TRP``$0```'S+```3````CLL```<```"BRP``%````*K+```8
M````O\L```<```#8RP``!0```.#+```,````YLL```P```#SRP``$@````#,
M```$````$\P```H````8S```"P```"/,```,````+\P```X````\S```#@``
M`$O,```%````6LP```4```!@S```+@```&;,```F````E<P``",```"\S```
M`P```.#,```8````Y,P``"4```#]S```#0```"/-```)````,<T```,````[
MS0``!P```#_-```*````1\T```(```!2S0``$@```%7-```$````:,T```<`
M``!MS0``#````'7-``!2````@LT``!<```#5S0``!P```.W-```&````]<T`
M``X```#\S0``#`````O.```-````&,X``!4````FS@``$@```#S.```/````
M3\X``!0```!?S@``"@```'3.```;````?\X``!````";S@``"P```*S.``!I
M````N,X``!H````BSP``%P```#W/```G````5<\``!H```!]SP``%P```)C/
M```;````L,\``!D```#,SP``'P```.;/```3````!M````@````:T```"```
M`"/0```)````+-````T````VT```$P```$30```#````6-```$8```!<T```
M/P```*/0```W````X]```%<````;T0``!0```'/1```?````>=$``"\```"9
MT0``"````,G1```-````TM$``"T```#@T0``!`````[2``!/````$](``"4`
M``!CT@``'````(G2```+````IM(``!\```"RT@``'0```-+2```E````\-(`
M`"`````6TP``)````#?3```@````7-,```L```!]TP``!P```(G3```-````
MD=,```P```"?TP``!@```*S3```Y````L],```<```#MTP``"0```/73```3
M````_],```0````3U```$````!C4```$````*=0```L````NU```#````#K4
M```2````1]0``!$```!:U```#````&S4```:````>=0```T```"4U```%```
M`*+4```.````M]0``!L```#&U```$P```.+4```<````]M0``"@````3U0``
M!@```#S5```'````0]4``!,```!+U0``!````%_5```7````9-4```H```!\
MU0``#````(?5```)````E-4```8```">U0``"````*75```)````KM4```H`
M``"XU0``$0```,/5```&````U=4```X```#<U0``#@```.O5```+````^M4`
M``L````&U@```@```!+6```'````%=8```8````=U@``"0```"36```'````
M+M8``!H````VU@``.P```%'6```H````C=8``#0```"VU@``%0```.O6```'
M`````=<```@````)UP``!P```!+7```%````&M<```<````@UP``#@```"C7
M```)````-]<```8```!!UP``"````$C7```+````4=<```<```!=UP``!P``
M`&77```<````;=<```<```"*UP``"````)+7```(````F]<```4```"DUP``
M$````*K7```0````N]<```<```#,UP``!0```-37```0````VM<``!0```#K
MUP``"P````#8```-````#-@``!<````:V```!````#+8```)````-]@```H`
M``!!V```!P```$S8```"````5-@```X```!7V```'P```&;8```C````AM@`
M`#$```"JV```)P```-S8``!D````!-D``!0```!IV0``50```'[9```X````
MU-D``$H````-V@``6P```%C:```H````M-H``#@```#=V@``*````!;;```L
M````/]L``"<```!LVP``&P```)3;``"I`0``L-L``",```!:W0``%P```'[=
M``"%````EMT``#`````<W@``)0```$W>``!;````<]X``$D```#/W@``'0``
M`!G?```8````-]\``"L```!0WP``(0```'S?```?````GM\``"L```"^WP``
M(0```.K?```G````#.```!T````TX```$0```%+@```S````9.```"4```"8
MX```)P```+[@```?````YN```#`````&X0``:0```#?A```]````H>$``&4`
M``#?X0``30```$7B```O````D^(``"X```##X@``,````/+B``!4````(^,`
M`%H```!XXP``2````-/C``!*````'.0``#(```!GY```+P```)KD```L````
MRN0``"T```#WY```%P```"7E```E````/>4``#(```!CY0``*0```);E```^
M````P.4``"(```#_Y0``"P```"+F``!%````+N8``"$```!TY@``,````);F
M```E````Q^8``!P```#MY@``,0````KG```'````/.<```<```!$YP``!```
M`$SG```-````4><```L```!?YP``#@```&OG```%````>N<``!````"`YP``
M`@```)'G``!9````E.<```4```#NYP``"````/3G```#````_><``!`````!
MZ```#````!+H```-````'^@```(````MZ```%````##H```2````1>@```P`
M``!8Z````P```&7H```$````:>@``!\```!NZ```-0```([H```N````Q.@`
M`"\```#SZ```%P```"/I```@````.^D``!L```!<Z0``&````'CI```D````
MD>D``!\```"VZ0``&@```-;I```@````\>D``!H````2Z@``,@```"WJ```:
M````8.H``"\```![Z@``*P```*OJ```?````U^H``",```#WZ@``'P```!OK
M```:````.^L``"4```!6ZP``)@```'SK```E````H^L``"0```#)ZP``&```
M`.[K```=````!^P``"0````E[```&````$KL```B````8^P``"4```"&[```
M/````*SL```?````Z>P``",````)[0``'P```"WM```@````3>T``!H```!N
M[0``&````(GM```F````HNT``!X```#)[0``*0```.CM```>````$NX```D`
M```Q[@``#````#ON```7````2.X``"\```!@[@``)````)#N```'````M>X`
M``\```"][@``!0```,WN```'````T^X``!T```#;[@``&@```/GN```'````
M%.\``,<````<[P``"P```.3O```5````\.\```8````&\```"0````WP```+
M````%_````T````C\```%P```#'P```&````2?```#,```!0\```$P```(3P
M```3````F/````\```"L\```!P```+SP```R````Q/```"$```#W\```$P``
M`!GQ```,````+?$``!$````Z\0``,@```$SQ```6````?_$```@```"6\0``
M"0```)_Q```*````J?$``!0```"T\0``'0```,GQ```(````Y_$``!\```#P
M\0``"````!#R```:````&?(``"<````T\@``!@```%SR```5````8_(```@`
M``!Y\@``!P```(+R```/````BO(```X```":\@``$````*GR```)````NO(`
M``D```#$\@``$P```,[R```'````XO(``!D```#J\@``"@````3S```*````
M#_,```P````:\P``*@```"?S```'````4O,```(```!:\P``$````%WS```8
M````;O,```L```"'\P```P```)/S```(````E_,```8```"@\P``!P```*?S
M```-````K_,```L```"]\P``%````,GS```5````WO,``"\```#T\P``(```
M`"3T```<````1?0```P```!B]```,0```&_T```%````H?0``!(```"G]```
M/P```+KT```2````^O0```H````-]0``!@```!CU```$````'_4```0````D
M]0``"@```"GU```3````-/4```4```!(]0``!@```$[U```&````5?4```0`
M``!<]0``#````&'U```*````;O4```(```!Y]0``!````'SU```&````@?4`
M``,```"(]0``#````(SU``!%````F?4``!H```#?]0``-0```/KU```H````
M,/8``%,```!9]@``&0```*WV``!R````Q_8``"`````Z]P``-0```%OW```A
M````D?<``$4```"S]P``,````/GW```H````*O@``"D```!3^```)@```'WX
M```E````I/@``"@```#*^```*````//X```B````'/D``#`````_^0``$@``
M`'#Y```3````@_D``!````"7^0``>0```*CY```)````(OH``',````L^@``
M?````*#Z```K````'?L``!<```!)^P``%@```&'[```/````>/L``!<```"(
M^P``'P```*#[``!`````P/L``!\````!_```'````"'\``!1````/OP``!H`
M``"0_```%````*O\```2````P/P``!````#3_```$P```.3\```=````^/P`
M``\````6_0``#P```";]```$````-OT```D````[_0``"P```$7]```'````
M4?T```4```!9_0``%````%_]```'````=/T```@```!\_0``#P```(7]```(
M````E?T```P```">_0``#P```*O]```&````N_T``!0```#"_0``!@```-?]
M```,````WOT```@```#K_0``!````/3]```*````^?T```0````$_@``&0``
M``G^```'````(_X```(````K_@``"0```"[^```&````./X```8````__@``
M!````$;^```/````2_X``!,```!;_@``!P```&_^```'````=_X```8```!_
M_@``!@```(;^```0````C?X```8```">_@``"0```*7^```B````K_X```<`
M``#2_@``!P```-K^```+````XOX```4```#N_@```@```/3^```+````]_X`
M`'$!```#_P``$P```'4``0`:````B0`!`!````"D``$`#0```+4``0`+````
MPP`!``T```#/``$`!@```-T``0`X````Y``!`#8````=`0$`)````%0!`0`Z
M````>0$!``L```"T`0$`.@```,`!`0`<````^P$!``T````8`@$`%````"8"
M`0`3````.P(!`"L```!/`@$`'P```'L"`0`0````FP(!`!8```"L`@$`(```
M`,,"`0`-````Y`(!`,,```#R`@$`&P```+8#`0`-````T@,!`!(```#@`P$`
M$@```/,#`0`:````!@0!``T````A!`$`#````"\$`0`8````/`0!``8```!5
M!`$`"0```%P$`0`/````9@0!`!\```!V!`$`#@```)8$`0`8````I00!`!@`
M``"^!`$`#P```-<$`0!2````YP0!`"D````Z!0$`70```&0%`0!O````P@4!
M`)0````R!@$`C@```,<&`0"2````5@<!`)$```#I!P$`6P```'L(`0`@````
MUP@!`!D```#X"`$`&0```!()`0`7````+`D!``T```!$"0$`)````%()`0`/
M````=PD!`!,```"'"0$`#P```)L)`0`X````JPD!`#P```#D"0$`%P```"$*
M`0`6````.0H!`!,```!0"@$`$````&0*`0`3````=0H!`"4```")"@$`*```
M`*\*`0`;````V`H!`"4```#T"@$`)0```!H+`0`T````0`L!`"T```!U"P$`
M'````*,+`0`G````P`L!`!H```#H"P$`5`````,,`0`Q````6`P!`#4```"*
M#`$`'@```,`,`0`T````WPP!``@````4#0$`&````!T-`0!,````-@T!``X`
M``"##0$`#@```)(-`0`*````H0T!`!$```"L#0$`"0```+X-`0`&````R`T!
M`#@```#/#0$`%@````@.`0`6````'PX!`!@````V#@$`'````$\.`0!)````
M;`X!`!T```"V#@$`'````-0.`0`A````\0X!`"<````3#P$`,0```#L/`0`@
M````;0\!`!8```".#P$`-0```*4/`0`,````VP\!``@```#H#P$`(````/$/
M`0`O````$A`!`!X```!"$`$`,@```&$0`0`*````E!`!`!D```"?$`$`"@``
M`+D0`0`5````Q!`!`"0```#:$`$`$0```/\0`0!T````$1$!`!0```"&$0$`
M!@```)L1`0!<````HA$!`!D```#_$0$`1````!D2`0!$````7A(!`$H```"C
M$@$`3@```.X2`0`1````/1,!``H```!/$P$`.@```%H3`0!=````E1,!`#8`
M``#S$P$`-@```"H4`0`W````810!`#@```"9%`$`.````-(4`0!W````"Q4!
M`#$```"#%0$`/````+45`0`X````\A4!`#X````K%@$`*P```&H6`0`O````
MEA8!`$@```#&%@$`0@````\7`0`E````4A<!`!$```!X%P$`&````(H7`0`C
M````HQ<!`"<```#'%P$`%````.\7`0`-````!!@!`$4````2&`$`%P```%@8
M`0`/````<!@!``@```"`&`$`#0```(D8`0`&````EQ@!`!(```">&`$`#0``
M`+$8`0`)````OQ@!``H```#)&`$`&@```-08`0`#````[Q@!``,```#S&`$`
M%P```/<8`0`:````#QD!``H````J&0$`"````#49`0"6````/AD!`#$```#5
M&0$`3P````<:`0`V````5QH!``P```".&@$`)P```)L:`0`X````PQH!`#@`
M``#\&@$`4P```#4;`0`R````B1L!`$,```"\&P$`P0`````<`0!1````PAP!
M``H````4'0$`"````!\=`0`A````*!T!``P```!*'0$`%P```%<=`0`3````
M;QT!`!<```"#'0$`(````)L=`0`,````O!T!`!0```#)'0$`"````-X=`0`=
M````YQT!`!@````%'@$`&P```!X>`0`+````.AX!`"T```!&'@$`D````'0>
M`0"D````!1\!``H```"J'P$`&````+4?`0`#````SA\!`!L```#2'P$`&@``
M`.X?`0`?````"2`!`"4````I(`$`,````$\@`0!*````@"`!`"8```#+(`$`
M!@```/(@`0`C````^2`!`!\````=(0$`&@```#TA`0`E````6"$!`"<```!^
M(0$`'0```*8A`0`3````Q"$!``H```#8(0$`"````.,A`0`A````["$!`!L`
M```.(@$`!@```"HB`0`>````,2(!`!,```!0(@$`#0```&0B`0`9````<B(!
M``@```",(@$`"@```)4B`0`5````H"(!``H```"V(@$`$0```,$B`0`(````
MTR(!`!,```#<(@$`!@```/`B`0`*````]R(!`"$````"(P$`$P```"0C`0`8
M````.",!`"````!1(P$`(````'(C`0`Z````DR,!`$T```#.(P$`-@```!PD
M`0`,````4R0!`%\```!@)`$`"@```,`D`0`(````RR0!``P```#4)`$`-@``
M`.$D`0`]````&"4!`#D```!6)0$`0````)`E`0`\````T24!`#@````.)@$`
M-````$<F`0`S````?"8!`#(```"P)@$`-@```.,F`0`_````&B<!`#X```!:
M)P$`00```)DG`0`S````VR<!`$(````/*`$`7@```%(H`0!'````L2@!`$<`
M``#Y*`$`5@```$$I`0!7````F"D!`"<```#P*0$`3````!@J`0`D````92H!
M`"@!``"**@$`.0```+,K`0!1````[2L!`%$````_+`$`40```)$L`0!5````
MXRP!`#H````Y+0$`/````'0M`0!$````L2T!`$D```#V+0$`5````$`N`0`B
M`0``E2X!`#H```"X+P$`/@```/,O`0!,````,C`!`(,```!_,`$`&`````,Q
M`0`(````'#$!``\````E,0$`"@```#4Q`0`:````0#$!`!H```!;,0$`(```
M`'8Q`0`D````ES$!`"(```"\,0$`$0```-\Q`0`3````\3$!`!D````%,@$`
M%0```!\R`0`/````-3(!`#P```!%,@$`"@```((R`0`7````C3(!`!$```"E
M,@$`%P```+<R`0`;````SS(!``(```#K,@$`#````.XR`0`>````^S(!``H`
M```:,P$`'@```"4S`0`7````1#,!``8```!<,P$`#P```&,S`0`,````<S,!
M`!4```"`,P$`'````)8S`0`-````LS,!`!0```#!,P$`&````-8S`0`:````
M[S,!``P````*-`$`!@```!<T`0`/````'C0!``\````N-`$`)P```#XT`0`/
M````9C0!``\```!V-`$`*P```(8T`0`B````LC0!`$<```#5-`$`#0```!TU
M`0`E````*S4!`!@```!1-0$`%@```&HU`0`3````@34!``\```"5-0$`"@``
M`*4U`0`/````L#4!`$4```#`-0$`"@````8V`0`1````$38!`#`````C-@$`
M$P```%0V`0`>````:#8!`!X```"'-@$`"````*8V`0`Z````KS8!`!X```#J
M-@$`*`````DW`0`;````,C<!`!,```!.-P$`$0```&(W`0`/````=#<!`$``
M``"$-P$`A````,4W`0`.````2C@!`!$```!9.`$`4@```&LX`0`<````OC@!
M``P```#;.`$`'0```.@X`0`#````!CD!``P````*.0$`%0```!<Y`0`5````
M+3D!`!4```!#.0$`&0```%DY`0`E````<SD!`"$```"9.0$`*@```+LY`0`H
M````YCD!``X````/.@$`"P```!XZ`0`"````*CH!`!T````M.@$`*````$LZ
M`0!2````=#H!`"\```#'.@$`#@```/<Z`0`=````!CL!`!P````D.P$`)P``
M`$$[`0!5````:3L!`$L```"_.P$`$P````L\`0`B````'SP!`+L```!"/`$`
M,````/X\`0`&````+ST!`!X````V/0$`(````%4]`0`Q````=CT!`#8```"H
M/0$`"@```-\]`0`*````ZCT!`!P```#U/0$`%````!(^`0`4````)SX!`!8`
M```\/@$`$@```%,^`0`4````9CX!``\```![/@$`%@```(L^`0`(````HCX!
M``\```"K/@$`(@```+L^`0`9````WCX!`!<```#X/@$`#@```!`_`0`:````
M'S\!`!,````Z/P$`,@```$X_`0`X````@3\!`#@```"Z/P$`-@```/,_`0`W
M````*D`!`#\```!B0`$`+0```*)``0`(````T$`!`!$```#90`$`!@```.M`
M`0`*````\D`!`!,```#]0`$`#P```!%!`0`H````(4$!`"@```!*00$`%0``
M`'-!`0`3````B4$!`!D```"=00$`%P```+=!`0`Z````ST$!``X````*0@$`
M#P```!E"`0`-````*4(!`!$````W0@$`#````$E"`0`/````5D(!`"````!F
M0@$`#0```(="`0`&````E4(!`%<```"<0@$`$````/1"`0`]````!4,!``H`
M``!#0P$`"````$Y#`0`/````5T,!``P```!G0P$`#P```'1#`0`.````A$,!
M``X```"30P$`"````*)#`0`0````JT,!``0```"\0P$`!0```,%#`0`/````
MQT,!``\```#70P$`#P```.=#`0`L````]T,!``L````D1`$`'@```#!$`0`6
M````3T0!`!8```!F1`$`!@```'U$`0`5````A$0!`!<```":1`$`$@```+)$
M`0`7````Q40!`"P```#=1`$`%`````I%`0`9````'T4!`!L````Y10$`!```
M`%5%`0!)````6D4!`$D```"D10$`20```.Y%`0`L````.$8!`!4```!E1@$`
M#P```'M&`0`*````BT8!`!4```"61@$`"@```*Q&`0`,````MT8!`#,```#$
M1@$`$0```/A&`0`/````"D<!`#@````:1P$`"````%-'`0`(````7$<!``@`
M``!E1P$`$0```&Y'`0`3````@$<!`!P```"41P$`"````+%'`0!:````ND<!
M`$<````52`$`3@```%U(`0`V````K$@!`%H```#C2`$`,@```#Y)`0!<````
M<4D!`$(```#.20$`2P```!%*`0`O````74H!`!,```"-2@$`(````*%*`0`)
M````PDH!`%````#,2@$`/@```!U+`0`N````7$L!`#P```"+2P$`"@```,A+
M`0`,````TTL!`#P```#@2P$`.````!U,`0!-````5DP!``L```"D3`$`*@``
M`+!,`0!+````VTP!`"@````G30$`%0```%!-`0`:````9DT!`!H```"!30$`
M$@```)Q-`0!X````KTT!`)@````H3@$`X````,%.`0`=````HD\!``X```#`
M3P$`#P```,]/`0`:````WT\!`!L```#Z3P$`%0```!90`0`,````+%`!`!T`
M```Y4`$`)0```%=0`0`K````?5`!`"@```"I4`$`-0```-)0`0`U````"%$!
M`-T````^40$`&P```!Q2`0`5````.%(!``X```!.4@$`#@```%U2`0`P````
M;%(!`!L```"=4@$`$0```+E2`0`/````RU(!`!8```#;4@$`*````/)2`0!$
M````&U,!`$0```!@4P$`0````*53`0!`````YE,!`$$````G5`$`00```&E4
M`0`@````JU0!`&8```#,5`$`%@```#-5`0`6````2E4!`!8```!A50$`%@``
M`'A5`0`1````CU4!`!X```"A50$`'@```,!5`0`5````WU4!`!0```#U50$`
M40````I6`0`<````7%8!`!P```!Y5@$`2@```)96`0`9````X58!``\```#[
M5@$`&@````M7`0`2````)E<!`"P````Y5P$`&@```&97`0`K````@5<!`"``
M``"M5P$`)@```,Y7`0`@````]5<!`$`````66`$`.@```%=8`0`>````DE@!
M`!L```"Q6`$`(P```,U8`0`]````\5@!`"0````O60$`)0```%19`0`,````
M>ED!`!\```"'60$`"````*=9`0`5````L%D!``T```#&60$`#````-19`0`6
M````X5D!`!0```#X60$`"@````U:`0`(````&%H!`!@````A6@$`&````#I:
M`0`:````4UH!`!8```!N6@$`&P```(5:`0`C````H5H!`#T```#%6@$`$P``
M``-;`0`:````%UL!``\````R6P$`#P```$);`0`5````4EL!`$L```!H6P$`
M$````+1;`0`/````Q5L!``X```#56P$`"````.1;`0`1````[5L!`",```#_
M6P$`#0```"-<`0`>````,5P!`!<```!07`$`(````&A<`0`=````B5P!``@`
M``"G7`$`#@```+!<`0`$````OUP!``\```#$7`$`$0```-1<`0`6````YEP!
M`!4```#]7`$`)@```!-=`0`F````.ET!`",```!A70$`*````(5=`0`-````
MKET!`!L```"\70$`"@```-A=`0`9````XUT!`(````#]70$`$0```'Y>`0`5
M````D%X!`$(```"F7@$`'@```.E>`0`D````"%\!`!4````M7P$`%0```$-?
M`0`7````65\!``T```!Q7P$`$P```']?`0`3````DU\!`!<```"G7P$`'@``
M`+]?`0`T````WE\!``P````38`$`$0```"!@`0`3````,F`!`!@```!&8`$`
M#````%]@`0`(````;&`!``@```!U8`$`"````'Y@`0`3````AV`!`'0```";
M8`$`'P```!!A`0`/````,&$!``8```!`80$`"@```$=A`0`>````4F$!`!P`
M``!Q80$`(````(YA`0`"````KV$!`!$```"R80$`0````,1A`0`#````!6(!
M``@````)8@$`'0```!)B`0`5````,&(!`!@```!&8@$`@P```%]B`0`)````
MXV(!``P```#M8@$`"````/IB`0`*`````V,!`$X````.8P$`7````%UC`0`>
M````NF,!`"(```#98P$`-````/QC`0`S````,60!`#$```!E9`$`$P```)=D
M`0`$````JV0!``H```"P9`$`"@```+MD`0`6````QF0!`!<```#=9`$`"@``
M`/5D`0"&`````&4!`!H```"'90$`$0```*)E`0`6````M&4!`"L```#+90$`
M<0```/=E`0`&````:68!`!,```!P9@$`!@```(1F`0`+````BV8!`"\```"7
M9@$`+0```,=F`0`(````]68!``P```#^9@$`KP````MG`0`B````NV<!`"$`
M``#>9P$`#`````!H`0`1````#6@!`!,````?:`$`(````#-H`0`.````5&@!
M`!````!C:`$`#````'1H`0`3````@6@!`!$```"5:`$`$P```*=H`0`7````
MNV@!`!P```#3:`$`&@```/!H`0`:````"VD!`!H````F:0$`'````$%I`0`:
M````7FD!`"P```!Y:0$`%0```*9I`0`-````O&D!`!P```#*:0$`#P```.=I
M`0`>````]VD!`"$````6:@$`!@```#AJ`0`5````/VH!`!H```!5:@$`%@``
M`'!J`0`4````AVH!`!<```"<:@$`'@```+1J`0`:````TVH!``@```#N:@$`
M"````/=J`0`1`````&L!``L````2:P$`+0```!YK`0`6````3&L!`"T```!C
M:P$`,@```)%K`0`>````Q&L!``H```#C:P$`&@```.YK`0`(````"6P!`!P`
M```2;`$`!````"]L`0`$````-&P!`&D````Y;`$`3P```*-L`0`E````\VP!
M`$8````9;0$`60```&!M`0`3````NFT!`%H```#.;0$`0@```"EN`0!'````
M;&X!`$<```"T;@$`3````/QN`0`I````26\!`",```!S;P$`+@```)=O`0`F
M````QF\!`"4```#M;P$`)0```!-P`0`?````.7`!`"T```!9<`$`)````(=P
M`0!.````K'`!`$X```#[<`$`4@```$IQ`0!2````G7$!`%````#P<0$`30``
M`$%R`0!"````CW(!`!,```#2<@$`,P```.9R`0`/````&G,!`#D````J<P$`
M1````&1S`0!%````J7,!`!,```#O<P$`<@````-T`0!Y````=G0!`!$```#P
M=`$`-`````)U`0`4````-W4!`!@```!,=0$`"P```&5U`0`+````<74!`!8`
M``!]=0$`'@```)1U`0`3````LW4!`!D```#'=0$`$@```.%U`0`\````]'4!
M``P````Q=@$`!@```#YV`0`<````178!`!<```!B=@$`%0```'IV`0!2````
MD'8!``H```#C=@$`!@```.YV`0`<````]78!``P````2=P$`"@```!]W`0`<
M````*G<!``\```!'=P$`40```%=W`0`8````J7<!`"T```#"=P$`8P```/!W
M`0`@````5'@!`$(```!U>`$`G@```+AX`0`K````5WD!`#T```"#>0$`$P``
M`,%Y`0`6````U7D!`!8```#L>0$`&`````-Z`0`,````''H!`!<````I>@$`
M$@```$%Z`0`Q````5'H!`"````"&>@$`"````*=Z`0`7````L'H!`!H```#(
M>@$`.````.-Z`0`B````''L!`"8````_>P$`&````&9[`0`V````?WL!``@`
M``"V>P$`#@```+][`0`D````SGL!`!D```#S>P$`%0````U\`0`7````(WP!
M``@````[?`$`*P```$1\`0`.````<'P!`!<```!_?`$`$P```)=\`0`.````
MJWP!`#@```"Z?`$`(@```/-\`0!"````%GT!`!X```!9?0$`#P```'A]`0`0
M````B'T!`#,```"9?0$`#@```,U]`0`C````W'T!``@`````?@$`(@````E^
M`0`(````+'X!``@````U?@$`)@```#Y^`0!+````97X!``@```"Q?@$`'```
M`+I^`0`,````UWX!`!L```#D?@$`%P````!_`0`9````&'\!``@````R?P$`
M"@```#M_`0`.````1G\!`#4```!5?P$`70```(M_`0!K````Z7\!`#@```!5
M@`$`00```(Z``0`U````T(`!`'0````&@0$`-0```'N!`0!#````L8$!`$X`
M``#U@0$`AP```$2"`0`[````S((!``X````(@P$`"````!>#`0`K````((,!
M`"D```!,@P$`&P```':#`0`L````DH,!`#D```"_@P$`/P```/F#`0`(````
M.80!`!\```!"A`$`"@```&*$`0`3````;80!`#T```"!A`$`'````+^$`0`-
M````W(0!`!$```#JA`$`"````/R$`0`3````!84!`!$````9A0$`$0```"N%
M`0`3````/84!`"0```!1A0$`30```':%`0`/````Q(4!``H```#4A0$`)```
M`-^%`0`7````!(8!``H````<A@$`&P```">&`0`;````0X8!`!@```!?A@$`
M%````'B&`0`6````C88!`!4```"DA@$`"````+J&`0`,````PX8!`!P```#0
MA@$`2@```.V&`0!V````.(<!`"T```"OAP$`.@```-V'`0`C````&(@!`",`
M```\B`$`#@```&"(`0`B````;X@!``,```"2B`$`!@```):(`0`/````G8@!
M``\```"MB`$`&````+V(`0`-````UH@!`%$```#DB`$`!@```#:)`0`@````
M/8D!`!$```!>B0$`%0```'")`0!7````AHD!`"````#>B0$`$````/^)`0`>
M````$(H!`#,````OB@$`"@```&.*`0`C````;HH!`"X```"2B@$`$````,&*
M`0`E````THH!`"L```#XB@$`#````"2+`0`(````,8L!`!,````ZBP$`%0``
M`$Z+`0`8````9(L!``8```!]BP$`&````(2+`0`2````G8L!`!8```"PBP$`
M%0```,>+`0`5````W8L!``L```#SBP$`"@```/^+`0!2````"HP!`$L```!=
MC`$`20```*F,`0`(````\XP!`"L```#\C`$`.0```"B-`0`.````8HT!``X`
M``!QC0$``P```("-`0`0````A(T!``X```"5C0$`"````*2-`0`@````K8T!
M``\```#.C0$`$@```-Z-`0`8````\8T!`($````*C@$`'P```(R.`0`&````
MK(X!``\```"SC@$`$````,..`0`@````U(X!`!P```#UC@$`-P```!*/`0`C
M````2H\!`!X```!NCP$`.0```(V/`0`3````QX\!`#0```#;CP$`%@```!"0
M`0`>````)Y`!`/````!&D`$`)0```#>1`0`A````79$!`$<```!_D0$`)0``
M`,>1`0`?````[9$!`"4````-D@$`(0```#.2`0`M````59(!`!4```"#D@$`
M#@```)F2`0`*````J)(!``X```"SD@$`%P```,*2`0`D````VI(!``H```#_
MD@$`D@````J3`0"1````G9,!`%(````OE`$`@````(*4`0`:`````Y4!`%,`
M```>E0$`/@```'*5`0`(````L94!`!4```"ZE0$`9````-"5`0`*````-98!
M`&L```!`E@$`5P```*R6`0`[````!)<!`"(```!`EP$`5````&.7`0!#````
MN)<!`#T```#\EP$`+P```#J8`0`V````:I@!`#$```"AF`$`%0```-.8`0`(
M````Z9@!`!L```#RF`$`&P````Z9`0`-````*ID!`#D````XF0$`#0```'*9
M`0`*````@)D!`!L```"+F0$`#````*>9`0`@````M)D!``8```#5F0$`"```
M`-R9`0`(````Y9D!`!L```#NF0$`&P````J:`0`/````)IH!`!T````VF@$`
M&@```%2:`0`E````;YH!`!4```"5F@$`&P```*N:`0`8````QYH!`"T```#@
MF@$`-@````Z;`0`5````19L!``H```!;FP$`*P```&:;`0`.````DIL!`",`
M``"AFP$`$P```,6;`0`3````V9L!`!$```#MFP$`"@```/^;`0`2````"IP!
M``H````=G`$`#P```"B<`0`:````.)P!``T```!3G`$`'````&&<`0`5````
M?IP!`!,```"4G`$`#@```*B<`0`,````MYP!``H```#$G`$`"@```,^<`0`.
M````VIP!`!````#IG`$`)@```/J<`0"0````(9T!`$$```"RG0$`40```/2=
M`0`H````1IX!``H```!OG@$`$P```'J>`0`3````CIX!``P```"BG@$`"```
M`*^>`0`1````N)X!``H```#*G@$`"````-6>`0`*````WIX!`!````#IG@$`
M$````/J>`0`7````"Y\!`"P````CGP$`"````%"?`0`(````69\!`!````!B
MGP$`"````'.?`0`7````?)\!`!<```"4GP$`!P```*R?`0`*````M)\!`!,`
M``"_GP$`'````-.?`0`3````\)\!`!4````$H`$`&0```!J@`0`&````-*`!
M``T````[H`$`#P```$F@`0`1````6:`!``X```!KH`$`#@```'J@`0!)````
MB:`!`"<```#3H`$`/0```/N@`0`V````.:$!`)\```!PH0$`&@```!"B`0!E
M````*Z(!`%0```"1H@$`;P```.:B`0!A````5J,!`#````"XHP$`9````.FC
M`0`Z````3J0!`#P```")I`$`20```,:D`0`T````$*4!``X!``!%I0$`)```
M`%2F`0`4````>:8!`+P```".I@$`;0```$NG`0`X````N:<!`'P```#RIP$`
MLP```&^H`0`@````(ZD!`!@```!$J0$`,P```%VI`0`F````D:D!`"8```"X
MJ0$`10```-^I`0`L````):H!`#````!2J@$`)@```(.J`0`8````JJH!`$T`
M``##J@$`0````!&K`0`Q````4JL!`#(```"$JP$`4@```+>K`0#*````"JP!
M`%(```#5K`$`BP```"BM`0""````M*T!`$@````WK@$`40```("N`0!5````
MTJX!`(@````HKP$`E````+&O`0!V````1K`!`'@```"]L`$`5````#:Q`0!&
M````B[$!`$@```#2L0$`2@```!NR`0`H````9K(!`$4```"/L@$`3````-6R
M`0!.````(K,!`(@```!QLP$`.````/JS`0`9````,[0!`(\```!-M`$`+P``
M`-VT`0!1````#;4!`#\```!?M0$`*@```)^U`0!9````RK4!``8````DM@$`
M#````"NV`0`(````.+8!`!4```!!M@$`$0```%>V`0`7````:;8!``H```"!
MM@$`(P```(RV`0`$````L+8!`(\```"UM@$`"@```$6W`0`(````4+<!``@`
M``!9MP$`(````&*W`0`1````@[<!`!T```"5MP$`#0```+.W`0`4````P;<!
M`"L```#6MP$`$`````*X`0`#````$[@!``0````7N`$`,@```!RX`0!J````
M3[@!`%````"ZN`$`5@````NY`0`K````8KD!`#0```".N0$`*````,.Y`0!&
M````[+D!`#P````SN@$`-P```'"Z`0`[````J+H!`$````#DN@$`+@```"6[
M`0`Z````5+L!`"X```"/NP$`.````+Z[`0!0````][L!`#,```!(O`$`.```
M`'R\`0`\````M;P!`#<```#RO`$`3````"J]`0`\````=[T!`$8```"TO0$`
M-0```/N]`0`[````,;X!`#P```!MO@$`20```*J^`0`W````]+X!`#H````L
MOP$`,@```&>_`0!L````FK\!`#P````'P`$`00```$3``0!%````AL`!`$8`
M``#,P`$`0````!/!`0`R````5,$!`#T```"'P0$`-P```,7!`0`R````_<$!
M`#L````PP@$`$P```&S"`0`A````@,(!`"L```"BP@$`1@```,["`0`T````
M%<,!``\```!*PP$`#P```%K#`0`,````:L,!`!D```!WPP$`.````)'#`0`C
M````RL,!``L```#NPP$`DP$``/K#`0`:````CL4!`"````"IQ0$`$@```,K%
M`0`5````W<4!`!T```#SQ0$`'````!'&`0`T````+L8!`!,```!CQ@$`<P``
M`'?&`0`<````Z\8!`"`````(QP$`'````"G'`0`7````1L<!`&0```!>QP$`
M0````,/'`0`9````!,@!`!X````>R`$`&````#W(`0!,````5L@!`",```"C
MR`$`$0```,?(`0`2````V<@!`!,```#LR`$`'`````#)`0`@````'<D!``X`
M```^R0$`1````$W)`0`,````DLD!`"@```"?R0$`00```,C)`0`,````"LH!
M`"<````7R@$`#````#_*`0`(````3,H!`!,```!5R@$`$P```&G*`0`B````
M?<H!``L```"@R@$`$0```*S*`0`3````OLH!``L```#2R@$`)@```-[*`0`:
M````!<L!`!D````@RP$`&P```#K+`0!/````5LL!``P```"FRP$`$````+/+
M`0`8````Q,L!`#T```#=RP$`"P```!O,`0`$````)\P!``T````LS`$`"@``
M`#K,`0`1````1<P!`!D```!7S`$`%@```'',`0`4````B,P!`!4```"=S`$`
M6@```+/,`0`C````#LT!`"@````RS0$`#P```%O-`0!L````:\T!``8```#8
MS0$`'````-_-`0!=````_,T!`!,```!:S@$`$0```&[.`0`)````@,X!``0`
M``"*S@$`!P```(_.`0`9````E\X!`"\```"QS@$`!P```.'.`0`(````Z<X!
M``8```#RS@$`!@```/G.`0`6`````,\!`!8````7SP$`!0```"[/`0`$````
M-,\!``P````YSP$`!@```$;/`0`5````3<\!`'(```!CSP$`)P```-;/`0!B
M````_L\!`%,```!AT`$`C````+70`0`8````0M$!`+$```!;T0$`20````W2
M`0!Z````5](!`%,```#2T@$`2@```";3`0!H````<=,!`%(```#:TP$`4P``
M`"W4`0!1````@=0!`%<```#3U`$`7@```"O5`0!1````BM4!`#\```#<U0$`
M5@```!S6`0`D````<]8!`"````"8U@$`%0```+G6`0"]````S]8!``T```"-
MUP$`V@```)O7`0"Y````=M@!`$P````PV0$`-P```'W9`0`@````M=D!`!<`
M``#6V0$`*````.[9`0`U````%]H!`%P```!-V@$`.P```*K:`0`T````YMH!
M`*$````;VP$`+@```+W;`0`M````[-L!`#$````:W`$`%@```$S<`0`I````
M8]P!`#(```"-W`$`$P```,#<`0`.````U-P!``,```#CW`$`$0```.?<`0`-
M````^=P!`!0````'W0$`#````!S=`0`<````*=T!``@```!&W0$`"````$_=
M`0`8````6-T!`!$```!QW0$`#````(/=`0`4````D-T!`!H```"EW0$`&@``
M`,#=`0`.````V]T!`!@```#JW0$`"@````/>`0`(````#MX!`"$````7W@$`
M#````#G>`0`7````1MX!``8```!>W@$``@```&7>`0`*````:-X!``@```!S
MW@$`"0```'S>`0`&````AMX!`!P```"-W@$`+````*K>`0`'````U]X!``@`
M``#?W@$`#@```.C>`0`(````]]X!`!D`````WP$`#P```!K?`0`5````*M\!
M`$,```!`WP$`$0```(3?`0`+````EM\!`!<```"BWP$`!0```+K?`0`"````
MP-\!``L```##WP$``0```"X````^````W`0``,(`````````T`0```````#M
M`@``````````````````*P$```````!%!0``C`4``.,"``!D!0``#0```+``
M``!(`0``````````````````F0$```\$``"@!````````-T$```7!0``````
M`)D"``!Y````Y`$```````"1`P```````(D$````````H@0``,,#``#R!```
M`````#4"``#J!```TP(`````````````9@$``!H#```0`P```````/@$``!;
M`P``!P$``+,!``#3`P```````````````````````$4#```4`@``G04``'`$
M``!_`P``>P,```````"%`@`````````````.````F`(```````"*`P``````
M`'X!``#]!```+P(````````:`@``?`0``)\%``"2!```J0$``+L#``"S````
MLP,``.X!````````?0,````````V````F`0``*T!``#J`@``.@,`````````
M````I@4``%<"```G!0``^P```(P#``"2`````````+`$``#G`@``V`(`````
M``"<`@``WP````````!X!0``5P,``#@#````````.`(```H```!\`P``%04`
M```#``#W`P```````&<!```\`0``100``#T%``"?`0``?@`````````?````
M=@```+\!`````````````!D#````````+P,``-``````````U@,``(@!```U
M`P```P$``/@!``"C`0```````/4$``#Q`@``K@0``,`````;````2`,`````
M``#``P``F@(``/P$````````K@```&$```!I`0```````-(#``!7!0``'P4`
M``````!$`@``[```````````````)`0``````````````````,H"``!8!```
M%0`````````S````OP(``),```!4`P``ZP,``)D%```Q!```>`(``'X"``!=
M````N`0``*````````````````<$````````]`(```````#S`P``7P(``%@#
M````````#`$``%L!``!R`P``"0$```````"&`@``````````````````_`(`
M`(L#````````V@0``$L!``#:`0```````'8!``"O!```-@$``"@#````````
M.0,``*X!``#G`0``I0(``$$!``#S`0``%`4``&D%``!Z`0``,0`````````.
M!0``S00``'D!``"(````MP```(("```8!````````)$$``!E`P``````````
M````````)P```-X$``!F!0``@00``!<#``#``0``_P$````````?`P``)```
M`#(!`````````````)X!```+````]`,```````"T`P````````````!R!0``
M``````````"!`@``(`$````````#````[P$``+X!``"'````Z00``.8````<
M`@```````)<%``#(!```I@$``$\#````````500``"(#``#7````+04``+0`
M````````N`$``.(#``"_`P``%0$``#8#```!`P``\0$``!<```"G!```PP$`
M`%D````J``````````T%```F!```%@4```````#@!```*P(```````"U`@``
MA@4``%D#``!-!0``D`4``````````````````'`!```&`@``50(```````")
M`P````````````"\!```$04``)`!``!)`0``^`(``"D`````````#P,``'("
M````````YP0``(D```#8`0``\0```,4$``"/`0``9P(``)T$````````/P4`
M`(T```!S`0````````````"%!```:P,``*4#````````.0```&\!``#'!```
MU@````````!T`````````#X%``!8`0`````````````C!0``*`4``!D%``!\
M`0``#`(``"0"``"=````>`````````"A````Z0```.$"``!Z!```(@0``*(!
M``"*`0```````((```"/!0``O@````D"``"&!``````````````*!```W`(`
M`.8!``"C````>P0``&4%```\````)`$``#(%```>`P``<```````````````
M)`,``(@"``!2!0``%`,``#,$``"X`P``4P4``!P%`````````````&0#``!6
M!0``2P0``+(!```1`````````(\$``"6!```3P(``````````````````&T$
M``"3`@``^P0``/L!``">`@``>@4``/0`````````F0```-D#````````````
M`.8#``"*!````````.("``#>`0``3@,``(T!`````````````*L$````````
M6P4```````"O`0`````````````/`@``5P0``,8```#]````H04``*4%````
M````UP,``(,```!N`@``.@$``.\#``!)!0``7@,``)(%``"+!0``LP0```D#
M```3`@``````````````````R`(``-$````]`0``>0,``-D!``"4!0``````
M``````"]`0````````````!U`P``A````.$!``"6````3@```)`"``!O`P``
MEP```*<"```]`P```````.L```!G`````````"P!``"M`P```````(($``!5
M`````````+<#``!(!```@04``!H`````````:`$``(8#``"$!0``````````
M``"J`0``Y`(``/8`````````````````````````B`,``!8"``"D`0``[@,`
M`,D"``#R`@```00``%4!``!.`0```````,H$``"H`````````+\$``#.`@``
ME@,``+0$``!B`P``2@0``!T%````````'P0``.4#```^`@```````'$$``!9
M`@```````&`$``#?`@``.`4``*0%````````!P(``%(!``!0!````````!,`
M``#&`P``L`(``.P"````````%`$``#<```#<````HP4```````#K`0``#@,`
M`"L$``````````````````#^`0``4@(``'0"``"[`0```````'4"````````
M4P$``%T%``".`0``J@```'\```#*`0``&00``)$!``"U````A`(``%P#````
M`````````$L#``#)!```XP$```T"``#>`@``#@0```````#9!```!@0``&@"
M``#Y`0``X00````````,`````````#("``#M`0``7`(``-`#``"H`@``7P4`
M`.L"``#$`@``'0$``!@!``#3`0``\@,``$X%``"2`0```````*,$```;!```
MN````&(!```(!0``"@(````"```1`0``````````````````Z`,```P$``!&
M`P``Z@```!(%```@`@``(04``+X"``!J````+00````````J!```T@0``)@%
M````````+````%H!``"A`0``I@,``.`!``"O`@``FP4``#L"```K!0``2@4`
M`"<$```<`0``E0,```````"Z````KP,```````"2`@``-P4```@$````````
M``````@!````````'@```'X#``"8````10```,T!``#S````^@0``(\```")
M`@``F@,```````!)`P``F`$``(L$``#\`0``#P```#<!```^`P``P0(``#L`
M````!0``L0$``,(!```E!0``=`0``+P#``!,`@``$P4``(T"``!1`@``````
M``````#\`P```@,``-L"``"Z!````````)<!``!K!0```````%0"````````
M!P,``%$$``!Y!0```````)D#``!'````70(````````Q!0``R0``````````
M````3@0``)\"```\!0``AP0```D%``##`````````$\```"#`P``Q0,``!T$
M``#I`@``6@,```````!\````XP0``#\````N`@```````#$#```A````@P0`
M`)8"``"U`0```````!<"````````.P$```````!C`@``#0,``',#``"=`P``
M)@```+H!```I`@``Z@$``!@"````````JP$```````"L`@``QP,``-P#``"B
M`P```````'T!``#>`````````!4"``"U!```004`````````````7`$``&@%
M```?`@``"`(``#0#``#Z`@```````($#``#-`@``1P0```````#:`@``D0``
M``````#,`P``^0,``&$!````````&@$```````"4!````````.4````3`P``
M%@$``$(#``!9`0``J0```)<$```6`P``/0(``'($````````K`,``&8````7
M`0``5@,``&@#````````'@4``+,"``!=`P``(@(```````!,`P``+0```)``
M``#$`P``XP,``-$$``!T`0``=`,``&X`````````(@```+(```#F!```FP,`
M``````!6`@``S0,``.P!```-!```?@4``-0`````````AP$``)L!``!-````
M%P0``(\#``!8`@```````"$$``!C````U0,``(``````````_@,``',%```E
M`0``%0,``$\!``!2!````````.$```#T!```.`0``````````````````/\#
M```U`0``8`(```````#&`@``Z`0``&H$`````````````#`!``"1`@``C```
M`"`````2`0``C0,```````!'`P``\00``#T$``"=`0``+@4`````````````
M_P```',$``#H````,0$``((%``!@`P``:P```'T%````````V@,``"4#``!B
M!```+@,``!($``![!0``@P(``(4!``#=`0``D`,```````#S!````````.T`
M``"3`0``-`$``*T``````````````&<$``!(````!04`````````````B`0`
M``````!C`P```````````````````````%X%``!8!0````````````"$`0``
M`````-4"````````UP(``,P```"G`P``S@,```````#Z`P``6@(````````Z
M!0```````)P$``"Y`@``U@(``%`%````````$P0``$(````#`P```````!$$
M``#P`P``W@,```4"````````K`$``-@```#O!```9@0``(X$````````SP``
M`%8````H!```K0(```P#```X````T@(``!`!``#K!````````+D!````````
M`````*8```"J!`````````($``"^!```'P$``/D```#2````-`4``,L```#L
M`P``M@$```````"@!0``"@4``*H"````````;0,```````"M!````````,,"
M``!1````8@````````#&!```"P4``&0```!^!```S`0```````"6`0``!@$`
M`.($``#A`P``RP(``'T$``!3`@``I0$```````"1!0``(0$``&\```!P`@``
M^0(```0```"A`@``MP0```4!````````T0$``!4$``!0````&`4``*<!````
M````.P0``)D$````````>@(```````!>`@``KP```$$#````````)@,```("
M````````I`,``!X"````````[`0``&P!````````````````````````D`0`
M`$4"``#H`0``7`4`````````````EP(``(L!``":!0``CP(```````#+`P``
M9`(```````"R`@````````````"4`@``6P0```````"Q`@````$``/`"``"B
M`````````-8!``!S`@```````$0%``!O!0``;0```$L%``!:````O`$``&<#
M``#^!```@`$```````!<````K`0``,8!```2````!00``+H#``!]`@``(P``
M`#L#````````@`(``(D!````````V`,``,`"``#_!`````````````!M`0``
M_0$```D````@`P```````````````````@```!H%``!,````1`0``&\"````
M````5`0``)4%````````2`4``#<$``!,`0``0@4``&X%``"^`P``80,``(,%
M`````````````!H$``#5````Y0(``+P````/`0``*P```!8````!!0``4P``
M`#,!``#4`P``:@,``#````#+!```Z0$``(H```!F`P``)`4`````````````
M:@4``-0"``!&!0``4P0``'@#``#M`P``E0`````````1`P``?P(``#D$```+
M`@``)P(``'\$````````]@,``#L%````````SP$``#4$``!C!```````````
M``!C!0``A0```+L$```-`0``=04``.@"``!=!```7`0```````!?````````
M`'<```!@`0``+@0``&4$``#I`P``*`$```````"D`@``^`,`````````````
M^00``'<!``!E````V0(`````````````R0,`````````````NP````````!Q
M!0``<0,``,("````````;`,``-8$``#<`0```````"T#```B`0```P0``,0!
M``!Q`````````%H%``!-`0``E@4``)X$``!N!```T@$``%L````C!```````
M```````=````N0,``,X$``#*````WP$``-4!`````````````+L"````````
M`````($`````````U`0``),#``!U````U`$``)P```!P!0``R````*D"```L
M`@``A@```.````",!```Q0```-\$``#P````F@```*X#``#N!```S@$``*0$
M```L!0``*@(```8```!4`0``!`,``.X"``!\!0``:@(``,4"````````6@0`
M```````F!0``^`````````#7`0``L0```'@$``!G!0``0`,``,$#```_!```
M(P(``"$#````````;04``.0````+`P``C@```*`"```F`0``5`4``#<#``#T
M`0``20````````!E`@``>00````````T!````````"P#````````>@,``#4%
M````````7P$``&P```#F`@```````(D%``!&`@```````(8!```S!0``````
M`*D#```O`0``*04``(P"``#%`0``SP(``#X!``#,`@``C@(``'4!``#@`P``
M``````H#```0!````````*$$`````````````$D$````````2`(``!@```!0
M`@``[P```*8"`````````````$H"```0!0````````(%```\`@```````'8"
M``!'`@````````````````````````````!"`0``,`0``+T"``!N`P``,@``
M``@`````````30,```L!``!/!```X@````````!Q`0``(0(``"8"``#U````
M_````$0```"R!```4@````````#$````QP(```@#``"U`P``J`$``'L"````
M````````````````````GP```!$"``!H!```+`0``"\````R!```0`4``.(!
M```$`@```````!("``"C`P``?0````0$```C`0`````````````'!0``&0(`
M``````"]````]@0``"`%````````404``&4!````````V0```*0```#`!```
MM`$``)X%``"K`P``V@```'D"````````FP0``(@%``!!!````````*H#``!I
M!````````*X"````````T0(``(T$``";````M@0``(H"````````````````
M```$!0``;`0```````!"`@````````````!+`@``^P,``(L"```#`@``]P$`
M`+8#``!2`P``E`,``)X```!0`P``?`(``(`$`````````````!L#````````
M#@(`````````````A`,``,<```#3```````````````S`@`````````````J
M!0``B@4``'<"```\!`````````H!```0`@```````/4#``!X`0``7@$``&T"
M```O!```$@,`````````````EP,``.T$````````9`0``,$$``![````\`0`
M``8%````````(@4``!P$``!&!`````````````"F!```P0$````````>`0``
M7@0``+T$```Q`@``7@```&("``#8!```H`,``*4`````````00(```````!,
M!```5P$``/T"``!@!0``\`$```````"3!`````````````!#`P``;P0`````
M````````[P(``-L!````````VP```/,"```T````N0```(4#``!?!```RP$`
M`#\"``!I`@``30(``#0"``#R````G`,``%L"``#;`P``N@(````$``"]`P``
M@0$````````_`P``?P4``%`!```O!0``300``-,$``">`P``!`$```````#-
M````.@```)\#``!K`@``*0$``+D$```@!```0`0```````"Q!````````/<`
M``!,!0```````'<#``"\`@``/@0``'`#```X`0```@$````````P!0``'```
M`$H`````````)0(``$,!```N`0``*P,``$,"``"?!```IP4``)4!``#7!```
M`````-L$``#!`````````````````````````",#````````0P4``$($``!5
M!0```````/T#```8`P```````!,!````````````````````````*```````
M``#D`P```````)4$``!W!```@@,``"<!```=`@``BP```#`#``"'!0``````
M````````````:0,``(T%```Y!0``N`(```````"W`0````````````"V````
M`````&$%``##!```;`(``&P%````````:P0``!X$````````````````````
M````0````)(#````````Z@,```````!K`0```````.4!```6!```-@(`````
M``!9!```!0,``)4"```S`P``/0``````````````,`(````````;`0``"P0`
M`.,```"H!````````%\#``!)`@``F`,``#D!```9````G`$``$H!```'````
M<@$``/X```!.`@```0$``#(#```U````3P4``"@"```J`0``C@4``!T#````
M`````````#D"````````DP4``%,#``!Q`@```````$0#``!4`````````&0!
M````````]P(``&8"``",`0``QP$``'<%``!7```````````````%````````
M``````!&`0``E`$``&H!``````````````````!6`0``40$``(`#````````
M=@,`````````````F@0``*L````4!````````*4$````````K````%D%``!*
M`P``=`4```````!H````````````````````AP,``/4!``"H`P``F@$``&,!
M```Z!```$````'(```!&`````````-$#``#(`P``#@$``&X!```\`P``OP``
M`-T```!U!````````(0$``#V`0``-P(``)0````M`0``>@````````"G````
MJ00```````#[`@```````*,"```/!0``=@0``"T"```;!0``@`4``$0!``"A
M`P``Y`0``#\!``"R`P``T`$``+8"``#(`0```````(4%```Z`@``40,`````
M```9`0``2P```&(%``!I``````````````#@`@``6````%4#````````WP,`
M`/\"```V!```L`,``"D$``!'`0``_@(``'\!```&`P``[@```-4$``#=`P``
M`0(``+0"``!#!```FP(``*`!`````````````$,```#=`@``G0(``$<%```I
M`P``10$```D$``!``0```````/4"``!6!```R0$``)P%```J`P``'`,``&``
M``#/!````````$$```"Q`P``C@,``&$"``!S````&P(```````#/`P``AP(`
M`((!``"W`@```````'L!```#!0``YP,`````````````0`(``+`!```V!0``
M`````/(!``#W!````````/$#```G`P````````````#V`@``@P$```````!=
M`0```````,0$`````````````/H!``#,`0``YP````````#*`P``JP(``,($
M``!A!```#`4``!0``````````````'8%``"B!0````````````#0`@``````
M`,X```#Z````H@(`````````````P@,```````#E!```)0```"4$````("@E
M<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT
M;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!W87,@
M861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D
M.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`
M)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N
M=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E
M9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G
M<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G
M<R!487-K;&ES=``E<SH@)7,`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`
M+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R
M($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($QI9VAT(%)A:6X`04T@
M4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!8F]U="!T
M:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O
M=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!
M9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z
M`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M
M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S
M(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T
M;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!
M9',`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T
M960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@
M<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"X`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!<'!L
M:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y
M+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3
M:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@
M4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)M96YI86X@*$%2
M35-#24DM."D`07)T`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G
M=7-T`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`0F%C:V=R
M;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`
M0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M87-E;&EN90!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O
M=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]O:VUA<FMS
M`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O=&@`0F]T=&]M
M`$)U;&QE=&5D($QI<W0`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;&T`0V%N(&YO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E
M<R(N`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T
M92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N
M9"!,86)E;',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`
M0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@
M4&]L:6-I97,`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H
M87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F5S92!3:6UP;&EF:65D("A'
M0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A
M<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A
M<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC
M:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O
M;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@
M4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#
M;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA
M;64`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!0
M87-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z
M(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT:6YU90!#;V]K:64`0V]P>0!#
M;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G
M92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T
M;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T
M('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I
M8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E
M860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S
M879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@
M8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T
M:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@
M;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E
M871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R
M<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#=7)R
M96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E
M;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*0!$1`!$86EL>0!$871A5')E92!"<F]W
M<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E
M($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@1W)O
M=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E
M<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`
M1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@
M<F]W`$1E;&EV97)Y('1I;64`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#H`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`
M1')U9W,`12U-86EL`$524@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%
M9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%
M;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S
M<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I
M8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C
M:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E
M`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD
M(%-I9&5B87(`17AP96-T960@)RDG`$5X<&ER871I;VX@1&%T90!%>'!O;F5N
M=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:7(`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R
M>0!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I;&4@0V]U;G0Z("5S
M(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@
M3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@
M;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:7)S="!(86QF`$9I<G-T(%%U87)T
M97(`1FEX(')A=&EO`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F=O="!Y;W5R('!A<W-W
M;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T
M=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)O;0!&<F]M('1H
M92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=E;F5R871E("5S($-O
M;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1VEV96X@3F%M90!';P!';V]G
M;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E:R`H25-/+3@X-3DM-RD`1W)O=7`@
M061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`
M1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!(5$U,`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA<V@M06QG;W)I=&AM`$AA>F4`
M2&5A9&5R`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP
M('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;W)D90!(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L
M(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M
M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H
M8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$E-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)7VYS97)T
M(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET
M:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)
M9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L
M;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V
M:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`
M26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R
M="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R
M<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E<G,`
M26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T
M(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`
M26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T
M(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A
M<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A
M9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@
M26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N
M="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H
M57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L
M:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A
M;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A
M;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z
M("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D
M<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@
M<V5L96-T:6]N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<W5E<@!)=&%L:6,`2F%N
M=6%R>0!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*=6QY`$IU;F4`
M2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,
M969T`$IU<W1I9GD@4FEG:'0`2V5E<"!O<FEG:6YA;#\`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y
M($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED
M<P!+;W)E86X@*$550RU+4BD`3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`
M3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E
M9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T
M(&QO9VEN.B!.979E<@!,87<`3&%Y;W5T`$QE9G0`3&5F="!H96%D97(`3&5F
M="!V86QU97,`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@
M16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W
M97(`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S
M<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,
M:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI
M<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES
M="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0
M;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,;V%D:6YG+BXN`$QO8V%L
M('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O
M=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E
M96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU
M;6)E<G,`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N`$U31P!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN
M+@!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<F-H
M`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%T8VAI
M;F<@9FEE;&1S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R
M=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87D`365D:6-I;F4`
M365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E
M9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T
M:&]D`$UE=')I8P!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L
M;&%N96]U<P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG('-E<W-I;VX@240N
M`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y
M(%523`!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;VX@4&AA<V5S`$UO<W1L
M>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`
M36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U
M<`!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T
M:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T
M86P`37D@4&]R=&%L($QA>6]U=`!.3RP@22!$;R!.3U0@06=R964`3F%M90!.
M971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.
M971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE
M='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R
M`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L
M*0!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X
M+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA
M;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.:6=H=`!.
M;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N
M`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO
M(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@
M<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF
M:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&5N
M9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D
M+@!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.
M;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N
M92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C
M=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`
M3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU
M;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.
M=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R
M96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD
M(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S
M<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R
M("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@
M56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E
M`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M
M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3
M:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%0M4W1O<FUS`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!0
M87)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S
M<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@
M9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@
M;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN
M9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E
M9"X`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R
M<V]N86P@26YF;W)M871I;VX`4&5T<P!0:&]N90!0:&]T;W,`4&EX96QS`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO
M=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M
M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&ET:6-S
M`%!O;&QS`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@
M`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV
M871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`
M4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I
M;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H
M;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N
M90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!2
M96QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S
M<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N
M9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2
M:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE
M<RXN+@!2;VQE`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT
M`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%,O34E-12!%;F-R
M>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?
M44P@4VAE;&P`4V$`4V%M92!F<F%M92`H7W-E;&8I`%-A=F4`4V%V92`E<P!3
M879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A
M(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E`%-E87)C:`!3
M96%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE
M8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A
M('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T
M`%-E;F0@4TU3`%-E;G-O<CH@`%-E<'1E;6)E<@!397)I86P@3G5M8F5R`%-E
M<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P
M9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S
M<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4VAO<'!I;F<`4VAO<G0@4W5M
M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN
M`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L
M>0!3:&]W97)S($QA=&4`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U
M<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I>F4`4VMI<"!-86EN=&5N
M86YC90!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E
M<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@
M97%U:79A;&5N="!I;B!W871E<CH@`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E
M<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET
M(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-T86YD87)D`%-T87(@5')E:P!3
M=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O
M<FUA=`!3=')E970@061D<F5S<P!3=')I;F<@;&ES=`!3='EL92!;0U-370!3
M=0!3=6)J96-T`%-U8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U
M;&QY('=R;W1E("5S`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3
M=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T
M.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)N86UE`%-Y;G1A>"!E<G)O<B!I
M;B!S96%R8V@@=&5R;7,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L
M90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%R9V5T.@!4
M87-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E
M;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R871I
M;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@
M*%1)4RTV,C`I`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE
M($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4
M:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I
M;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@
M<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG
M;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D
M(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE
M(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@
M=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F
M=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD
M(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L
M96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&UE<W-A9V4@
M<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D
M:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A
M9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E
M<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@<')E9F5R96YC92`B
M)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E
M9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`
M5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R
M>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A
M9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@
M<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A
M9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I
M9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E
M9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N
M=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@
M;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T
M('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G
M97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@
M=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@
M=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@
M82!V86QI9"!N=6UB97(N`%1H:7,@:7,@)7,N`%1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4
M:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`
M5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;VUO<G)O=P!4;W``
M5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')U92!O<B!F86QS90!4
M=0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4>7!E('EO=7(@8VAO:6-E.B``52Y6
M+B!I;F1E>#H@`%523`!54DPZ`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D
M96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@
M)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=',`56YK;F]W;@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES
M=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`
M57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@
M:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N
M`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU
M97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A<FEA8FQE`%9E<G-I;VX`5F5R
M<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`
M5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T;F%M97-E("A625-#24DI`%9I97<@
M)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<VEB
M:6QI='D`5FES:6)I;&ET>3H@`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-
M04Y504Q,62!&4D]-("5S+@!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@
M4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I
M9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@
M=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A
M<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7
M;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%E965D`665A<FQY`%EE
M<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY
M(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P
M;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@
M8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@
M5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S
M="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U
M(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S
M.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U
M<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO
M=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U
M;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI
M;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?
M1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN
M`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]0
M97)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C
M;&EC:R!H97)E`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T
M:6YG`&@Z`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&YA;64`;F]T(&EM<&QE
M;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I
M>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S=&5A9'D`=&%S:R!L:7-T
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,R`*4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`W+3`X
M(#$U.C(W*S`R,#`*3&%S="U4<F%N<VQA=&]R.D%M:7)K86)I<B!-971A;F5T
M=V]R:VEN9R!L=&0N(#QP97)S:6%N+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O
M;3X*3&%N9W5A9V4M5&5A;3H@4&5R<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U55$8M.`I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET"@`@*-BQV8C8LB#9@MBHV80@)7,I`"C:J=F$VXS8KR#8K]BSV*K8L=BS
MVXP@)7,I`"C8K]BQ("5S(-BQV8C8LBD`("C8I]F%V+'9B-BR*0`@*-F!V+'8
MK]BG*0`@*-BOVXS8L=F(V+(I`"#8K]BQ(``B)7,B(-BHV8<@VJ_8L=F(V8?B
M@(S9A]BGVXP@V+/8I]F%V*?9AMF'(-BGV+;8I]F!V8<@V+38KP`B)7,B(-BH
MV8<@V+/8I]F%V*?9AMF'(-F%V*S9B-BRXH",V8?8IR#8I]BVV*?9@=F'(-BT
MV*\`(B5S(B#8I]N,V*S8I]BO(-F&V+38K]F'(-BHV8C8KSH@)7,N`"4N,F9-
M0B#8I]BSV*K9@=BGV*_9AR#8M-BOV8<@V*?8LB`E+C)F34(@V878K-BGV+(@
M*"4N,F9-0BD`)60@)7,@V8@@)7,`V*?8L]F%(-BQV878LB#8M-F%V*<@)60@
MV+'9B-BR(-BOVXS:K]BQ(-F%V+G8JMBHV+$@V*?8L]BJ+@#9OMN,V+3"K=BH
MVXS9AMN,("5D+=BQV8C8LMF'`"5S("T@V*K9B-BLV8<`V*?8J]BQ(-BGV8;:
MK]BTV*H@)7,`VJG;C-F$V8C8J-BGVXS8JB`E<P`E<R#8N=F%V83;C-BGV*H@
MV8;:K]F'V*_8I]BQVXP@+2#8JMBCVXS;C-BO`"#8L=BGV8<F(W@R,#!C.]BG
MV8;8K]BGV++;C"`E<R``)7,@V*O8J-BJ(-F&V*?9A0#8M-BQV8C8MR#8JMF(
MV*?9@=F"("5S`"5S(-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ`"5S
M(-BOV+$@)7,@)7,`)7,@V*+9A=BGV*_9AR#8I]BLV+'8I]N,(-BYV879A-N,
MV*?8JB#9AMJOV8?8K]BGV+';C"#8I]F&V*K8KMBGV*@@V+38K]F'(-BGV+/8
MJBX@V*S8N=BHV8<@V8?8L2#8N=F%V83;C-BGV*K;C"#8L=BG(-JIV8<@V8?9
MA2#8I]JIV8;9B-F&(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8K-BQV*<@VJG9
MAMN,V*\@V+G9A-BGV878JB#8J-BRV8;;C-BO`"5S(-F%V8C8L=BO(-F&VXS8
MI]BR(-BGV+/8J@`E<R#8K]F"VXS9@MF'`"5S(-F^VXS8K]BG(-F&V+38KP`E
M<R#8J-F'("5S(-BGV+(@)7,`VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@)7,`
MV*K9@MF(VXS9A2`E<P`E<R=S($YO=&5P860`V8'9A]BQV+/8JB#9B-BXV*?;
MC-F!("5S`"5S.B`E<P#8C"#8J-BGV*\`V(P@V*C8I]BO("5S("5S`-B,(-F%
MV*K8NMN,VXS8L2#8I]BR("5S(-BHV8<@)7,`(-BGV8;8JMBNV*?8J"``V8+8
MI]F$V*@@V[';LB#8L]BGV+G8JMN,`-F"V*?9A-BH(-NRV[0@V+/8I]BYV*K;
MC`#;LMNT(-BSV*?8N=BJV8<`VXS:J2#9OMBTV*K;C-BHV*?9AB#8K]BGV*_:
MK]BGV88@V*C8L=BGVXP@V*?;C-F&(-BHV838I]JI(-F%V8C8L=BO(-F&VXS8
MI]BR(-BGV+/8J@#;C-JI(-BNV+?8I]N,(-BLV*_;C"#8L=BN(-BOV*?8K]F'
M(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,
M(-BQV878LMBHV8;8K]N,(-N,VJD@V;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,
MV*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4"#8J-BQ
MV*?;C"#8J-BGV++8J-N,V8;;C"#;C-JI(-F^VXS8NMBGV84@V*?9A=BVV*?8
MH2#8M-BOV8<@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,
MV*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!01U`@
MV8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8L=F%V++:K]BT
MV*?;C-N,(-N,VJD@V;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BS
MV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@VXS:J2#:J=F$VXS8KR#8
MKMBUV8C8M=N,(%!'4"#9B"#;C-JI(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8
MI]N,(-BGV878MMBGV*$@VXS:J2#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8
MI]BR(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JI
MV83;C-BO(-BNV+79B-BUVXP@4R]-24U%(-F((-N,VJD@V+G8J-BGV+'8JB#:
MK]BPV+$@V*C8L=BGVXP@V+'9A=BRVJ_8M-BGVXS;C"#9OMN,V+K8I]F%(-F%
MV8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BYV879B-F%
MVXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@4R]-24U%(-F((-N,VJD@
MV+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V*?9A=BVV*?8H2#;C-JI(-F^
MVXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,
MV*\@V+G9A=F(V87;C"!3+TU)344@V*C8L=BGVXP@V+'9A=BRV*C9AMBOVXP@
MV;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`V*C8I]BQV*?9
MAB#8L]BHVJD@V+78J-BMVJ_8I]F'VXP`V*C8I]BQV*?9AB#8M=BHV*W:K]BG
MV8?;C`#8L=JOV*C8I]BQ(-BUV*C8K=JOV*?9A]N,`-BJVJ_8L=JO(-BUV*C8
MK=JOV*?9A]N,`-BUV*C8K2_8N=BUV+$`V*_8L=BHV*?8L=F'(-BGVXS9AB#9
MB-N,V+'8I]BSV*K8I]BQ`-BOV+'8J-BGV+'9ARXN+@#9OMBGVXS;C-F&(-F%
MV+?9A-F"`-F(V+/8MR#9A=BWV839@@#8I]N,V*S8I]BO(-BTV*?8KMF'(%9&
M4R#9A=BLV8C8LB#8K]BSV*K8L=BSVXP@V8;8K]BGV+'8KP#8I]N,V*S8I]BO
M(-F^V+'9B-F&V*_9AR!61E,@V878K-F(V+(@V*_8L]BJV+'8L]N,(-F&V*_8
MI]BQV*\`V*?8M]F$V*?8N=BGV*H@V*W8L]BGV*@`V*?8L]F%(-BQV878LB#8
MK=BSV*?8J`#8K=BSV*?8J"#9A=BSV*_9B-BO`-BMV+/8I]BHV*_8I]BQVXP`
MV*?8MMBGV8'9AR#:J=BQV*_9A@#8I]BVV*?9@=F'(-JIV+'8K]F&(-JOV+'9
MB-F'(-F!V+'8N=N,`-BGV+;8I]F!V8<@VJG8L=BOV88@V878K-F(V+(@V8'8
ML=BYVXSB@(P`V*?;C-F&V*S8IR#8I]BVV*?9@=F'(-JIV88Z`-BGV+;8I]F!
MV8<@VJG8L=BOV88@VJ_8L=F(V8<@V*S8K]N,V*\`V*?8MMBGV8'9AR#:J=BQ
MV*_9AB#9A=BLV8C8LB#8K-BOVXS8KP#8I]BVV*?9@=F'(-JIV+'8K]F&(-N,
MVJD@V878K-F(V+(@V8'8L=BYVXP@V*C9AR`B)7,B`-BGV+;8I]F!V8<@VJG8
ML=BOV88@VXS:J2#:J=BGV+'8J-BQ(-BLV*_;C-BO.@#8I]BVV*?9@=F'(-JI
MV+'8K]F&(-BSV*K9B-F&`-BGV+;8I]F!V8<@VJG8L=BOV88@V*?8N=BVV*?;
MC"#8K-BOVXS8KP#8I]BVV*?9@=F'(-JIV+'8K]F&(-BRV8C8K``@V*?8MMBG
MV8'9AR#:J=BQV*_9AB#:K]BRVXS9AMJOV*?9AB`E<R#8J-BYV8;9B-BGV88@
MV8;9B-BGV+$@V*S8I]F&V*C;C"#9A=F(V++;C-F$V*<`V*?8MMBGV8'9AR#:
MJ=BQV*_9AB#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS.@#8I]BVV*?9
M@=F'(-JIV+'8K]F&(-BHV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V879
MA@#8I]BVV*?9@=F'(-F#V+'8K]F&(-JIV*?8L=BHV+$`V*?8MMBGV8'9AR#:
MJ=BQV*_9AB#:J=BGV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMN,V+/8J@#8HMBO
MV+'8LP#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR``V+/8L=F^V+'8L]BJ(-BS
MV*?9A=BGV8;9ART@V*K8N=N,VXS9AB#9A=BLV8C8LMF'V*?;C"#:J=BGV+'8
MJ-BQV*?9AB#8K]N,VJ_8L0#8L]BQV;[8L=BSV*K;C`#8JMBHV83;C-BZV*?8
MJ@#9A=BYV*?8K]F$`-BJV+'8I]BR(-JIV+'8K]F&`-BJV+'8I]BR.@#9A]F%
MV8<`V*K9A=BGV87;C"#:J=BGV+'8J-BQV*?9AB#8JMBCVXS;C-BO(-BUV838
MI]BMVXS8JB#8M-BOV8<`V8?9A=F'(-JOV+'9B-F'XH",V8?8IP#9A]F%V8<@
MV878K-F(V++B@(S9A]BG`-F'V879A]F4(-J&V8?8I]BQ(-BSV878J@#8I]BL
MV*?8LMF'(-J&V8;8KR#8HMBOV+'8L]N,`-BBVXS8IR#8I]BLV*?8LMF'(-BJ
MV8;8N-N,V84@V8;9B-BY(-F!V8?8L=BSV*H@V878L=BJV*@@V*_8I]BOV8<@
MV+39B-BOV)\`V*?8LB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*H`V8C8L=F(
MV*\@24U34"#8K-BGVXS:K]BRVXS9A@#8I]BSV84@V+'9A=BR($E-4U`@V*S8
MI]N,VJ_8LMN,V88`V8;8I]F%(-JIV*?8L=BHV+';C"!)35-0(-BLV*?;C-JO
MV++;C-F&`-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V*S8
MI]N,VJ_8LMN,V88`V*?9A-JOV8CB@(S9A]BGVXP@V*S8I]N,VJ_8LMN,V88`
MV878JMF&(-BLV*?;C-JOV++;C-F&.@#;C-JI(-F%V8+8K]BGV+$@V8;8I]BO
MV+'8L]BJ(-BJV+G;C-N,V88@V+38K]F'(-BHV8C8KP#9OMN,V+3:J=BGV+$`
MV;[8I]BSV*X`V*C8L=F&V*?9A=F'V93B@(P@VJG8I]BQV*C8L=BOVXP`V8'9
MA]BQV+/8JB#8J-BQV8;8I]F%V8?B@(S9A]BGVXP@VJG8I]BQV*C8L=BOVXP`
MV*C8L=F&V*?9A=F'(-BBV878I]BOV8<@V*?8L]BJ`-BGV+G9A=BGV80@V*C8
ML2#8L=F(VXP@V*?8M-BJV+'8I]JIV8?8I]N,(-F!V+'8N=N,`-BJV+79B-N,
MV*@`V*?9AMBOV*?8LMF'(-BJV8+8L=N,V*C;C`#8HMF(V+';C-F$`$%R86)I
M8R`H5VEN9&]W<RTQ,C4V*0#8I]F&V*_8I]BRV8<@V;[8L=F(V8;8K]F'(-BB
MV+'8M-N,V8@`V8;8I]F%(-BBV+'8M-N,V8@`V*+;C-BG(-BTV878IR#9A=BW
MV878IMF&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8M]F$V*?8
MN=BGV*H@V*?9@=BJV*K8I]BM(-BMV+/8I]BH("5S(-BQV*<@V;[8I]JI(-JI
MV8;;C-BOV)\`07)M96YI86X@*$%235-#24DM."D`V8?9AMBQ`-BBVXS8IR#9
M@MBHV80@V*?8LB#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@V*C8L=BG
MVXP@V*K8H]N,VXS8KR#8HMF&(-BSV*;9B-BGV80@V+39B-BOV)\@`-BGV8;8
MJMBSV*?8J"#8L]BJV8C9AMF'V*<`V+/8N=N,(-BOV+$@V*W8L-F!(-JOV+'9
MB-F'VXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`
MV+/8N=N,(-BOV+$@V*W8L-F!(-F%V*S9B-BRVXP@V+38K]F'(-BGV+/8JB#:
MJ=F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V+/8N=N,(-BOV+$@V8C;C-BQV*?;
MC-BT(-F%V*S9B-BRVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@
MV8;;C-BSV*H`V+/8N=N,(-BOV+$@V8C;C-BQV*?;C-BT(-BGV+38JMBQV*?:
MJ=N,(-BTV*_9AR#8I]BSV*H@VJG9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ`.*`
MC-F(VXS:F-JOVXS9A]BG`-BBVJ_9B-BSV*H`075T:%]C>7)S<6PZ(-BHV+/8
MMR#9A=F(V+'8KR#9AMN,V*?8LB!)34%0(-F^VXS8K]BG(-F&V+38KP!!=71H
M7V-Y<G-Q;#H@V+/8I]F%V*?9AMF'(-F^V+38JMN,V*C8I]F&(-F"V*?8J-F$
MVXS8JMF'V*?;C"#9A=F(V+'8KR#9AMN,V*?8LB#8L=BG(-F&V*_8I]BQV*\`
M075T:&EM<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;C-BO
MV*<@V8;8M-BO`$%U=&A?9G1P.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@
M1E10(-F^VXS8K]BG(-F&V+38KP!!=71H7VEM<#H@V*C8L]BW(-F%V8C8L=BO
M(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?:W)B-3H@V*C8
ML]BW(-F%V8C8L=BO(-F&VXS8I]BR(&MR8C4@V;[;C-BOV*<@V8;8M-BO`$%U
M=&A?;&1A<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($Q$05`@V;[;C-BO
MV*<@V8;8M-BO`$%U=&A?;&1A<#K8I]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8
ML=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*HN(-BGVXS9AB#:AMN,V++;C"#8
MI]BSV*H@VJG9AR#:J=BGV+'8L]BGV+(@VJ_9@=BJV8<@V*?8L]BJ`$%U=&A?
M;&1A<#K8K=BPV8$@VJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,V+/8JB``
M075T:%]L9&%P.MBHV+'9B-BRV+'8L]BGV8;;C"#:J=BGV+'8J-BQ("5S(-F%
MV87:J=F&(-F&VXS8L]BJ`$%U=&A?;6-A;#H@V*C8L]BW(-F%V8C8L=BO(-F&
MVXS8I]BR($U#04P@V;[;C-BOV*<@V8;8M-BO`$%U=&A?<VUB875T:#H@V*C8
ML]BW(-F%V8C8L=BO(-F&VXS8I]BR('-M8F%U=&@@V;[;C-BOV*<@V8;8M-BO
M`-BJV+78K]N,V8(@V8?9B-N,V9'8JB#9AMBGV879B-F!V9'9@B#8J-F(V*\`
MV*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8KRX@
M)7,`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BGV+(@V+?8L=F!(-JIV*?8L=BS
MV*?8LB!2041)55,@V+'8KR#8M-BOV8<@V*?8L]BJ`-BJV+78K]N,V8(@V8?9
MB-N,V9'8JB#8K]BQ(-JIV*?8L=BSV*?8LB!&5%`@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO(`#9@=N,V838K]F'V*?;C"#9@MBGV*C9A"#8K]BSV*K8L=BSVXPZ
M`-F^V+/B@(S8LMF%VXS9AMF'`-BQV8;:KR#9OMBSXH",V++9A=N,V8;9AP#8
MI]BSV84@V+'9A=BR(-F&V*?8K]BQV+/8JB!K97)B97)O<P#9AMBGV84@VJG8
MI]BQV*C8L2#9AMBGV*_8L=BSV*H@:V5R8F5R;W,`0F%L=&EC("A)4T\M.#@U
M.2TQ,RD`V*[8MR#9A=BHV8;8IP#8J-F$V8C:J2`B)7,B(-BGV+(@V*C8L=F&
MV*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@(B5S(B#;C-BGV8'8JB#9AMBTV*\`
MV*K9AMBXVXS9A=BGV*H@V*C9A-F(VJD`V8;9B-BY(-BHV839B-JI`-BSVXS8
MI]F'`-J&V8C8J"#8I]F$V8$`V838J-F'`-F^V8?9AMBGVXP@V838J-F'.@#9
MA-BHV8?B@(S9A]BG`-F'V+$@V*_9B`#9OMBGVXS;C-F&`-F$VXS8L]BJ(-BH
MV8C9A-BJXH",V*_8I]BQ`$--4P!#4D,`V8;9@MBGV+<@V*K9B-BRVXS8N2!#
M4DP`V*[8M=F(V+7;C-BGV*H@V+/9A-F(V80N+BX`V*K9@MF(VXS9A0#8HMBQ
MV*?9A0#9AMF%VXSB@(S8JMF(V*?9AB#8I]BSV84@V+'9A=BR(-BQV*<@V*C8
MM]F(V+$@V*[9B-BOVJG8I]BQ(-BOV8C8J-BGV+'9AR#8J-BGV++9AMBTV*?9
MAMBOV(P@V*C8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BNV8C8KR#8
MJMF%V*?8LR#8J-JOVXS8L=N,V*\`V8;9A=N,XH",V*K9B-BGV88@V*_8L2#9
MOMBQV8C9AMBOV8<@(B5S(B#9AMF(V+38J@#9AMF%VXSB@(S8JMF(V*?9AB#8
MJ-F'(-JIV*?8L=BSV*?8LB#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-F%
MV*K8M=F$(-BTV*\Z("5S`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9
MAR`B)7,B(-BQV*<@V*C8I]BR(-JIV+'8KP#8I]F&V+78L=BGV8$`V*?9AMBU
MV+'8I]F!(-BGV+(@V*?8L=BSV*?9A"#:K]BRV*?8L=BT`-F&V87;C.*`C-BJ
MV8C8I]F&(-F^V+'9B-F&V*_9AR`B)7,B(-BQV*<@V*W8L-F!(-JIV+'8KR`@
M`-F&V87;C.*`C-BJV8C8I]F&(-N,VJD@V+38I]BNV8<@V879B-F"V*H@V;[;
MC-BOV*<@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-BHV*_9B-F&(-F^V*?8
ML=BGV878JMBQ("?9OMBQV8C9AMBOV8<@V879@MBUV*\G(-BGV*_8I]F%V8<@
MV*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'("(E<R+8L=BG(-BM
MV+#9@2#:J=BQV*\@`-F&V87;C.*`C-BJV8C8I]F&(-BMV+#9@2#9AMF%V8C8
MK]B,("5D(-F!V+'8LMF&V*\@V879B-BLV8C8KR#8I]BSV*H`V8;9A=N,XH",
MV*K9B-BGV88@V*_9B-BHV*?8L=F'(-F%V+'8JMBH(-F&V879B-BOV(P@V*C8
ML=BNVXP@V*?8LB#9B-BQV8C8K]N,V8?8I]N,(-F!V+'8I]F'V84@V+38K]F'
M(-BHV+'8I]N,(-F%V+'8JMBH(-BSV*?8LMN,(-BHV*<@V+39A=BGV+'9A^*`
MC-F'V*?;C"#8L-BNVXS8L=F'(-BTV*_9A]B,(-BSV*?8LMJOV*?8L2#9AMN,
MV+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#9OMN,V+K8I]F%(-BQV*<@V*C9AR#8
MM-F%V*?8L=F'(-BJV+G;C-N,V88@V+38K]F'(-JOV+#8L2#8K]BGV*\`V+G9
MAMF(V*?9A@#8K=BGV879A`#:K]BQV8C9A^*`C-F'V*<@V8@@V*C8L=J&V+/8
MJ-F'V*<`V879B-BHV*?;C-F$`-BNV+79B-BUVXS8I]BJ(-BSV839B-F$`-F!
MV*?8M=F$V8<@V+/9A-F(V80`V*[8M=F(V+7;C-BGV*H@V+/9A-F(V80`V8'8
MI]BUV839A^*`C-JOV+#8I]BQVXP@V+/9A-F(V80`V879B-BHV*?;C-F$`$-E
M;'1I8R`H25-/+3@X-3DM,30I`-F%V+':J=BR`$-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I`-BLV++8IMN,V*?8JB#:K]F(V*?9A]N,(`#8L]N,V*?8
ML]BJV8?8I]N,(-JOV8C8I]F'VXP`V*K8NMN,VXS8L2``V*?8L]F%(-BQV878
MLB#8KMF(V*\@V+'8IR#8JMBZVXS;C-BQ(-BOV8?;C-BO`-BJV+K;C-N,V+'8
MK]BGV*_9AB#9AMBGV84@V8@@V*+8K]BQV+/;C"#:J=F'(-BGV8'8L=BGV*\@
MV8?9AMJOV*?9A2#8KMF(V*?9AMBOV88@V8@@V;[8I]BSV*X@V*_8I]BOV88@
MV*C9AR#9AMBGV879A]F4(-BTV878IR#8KMF(V*?9A]F&V*\@V*_;C-BO(`#8
MJMBZVXS;C-BQV*_8I]BOV88@V*?8L]F%(-BQV878LB#8M-F%V*<@V*_8L2#9
MOMN,VJG8L=BHV8;8K]N,(-F!V+G9A-N,(-F^V+38JMN,V*C8I]F&VXP@V8;9
MA=N,XH",V+39B-BO+B#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@
MV*[9B-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8KP#9AMF(VXS8L]F'`-BHV+'8
ML=BSVXP@V;[;C-F(V8;8KRXN+@#B@(P`0VAI;F5S92!3:6UP;&EF:65D("A'
M0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`-BGV8;8JMBNV*?8
MJ"#;C-JI(-BGV+/9A2#8L=F%V+(`V*?9AMBJV*[8I]BH(-N,VJD@V8;8I]F%
M(-JIV*?8L=BHV+';C`#8I]F&V*K8KMBGV*@@VH;:K]F(V8;:K]N,(-F&V878
MI]N,V+0@V*K8I]BQVXS8KCH`V*?9AMBJV*[8I]BH(-F&V8C8N2#8L]BHVJD@
MV8'9A]BQV+/8JB`HV*C8L=BGVXP@V8'9A]BQV+/8JMF'V*?;C"#9A=BQV*K8
MJ"D`V*K8N=BQVXS9@2#:J=F$V*?8LR`E<R#;C-BGV8'8JB#9AMBTV*\`V+78
MI]F!`-F^V*?:J2#:J=BQV*_9AB#8JMJOV8?8I]N,($U33V9F:6-E`-F^V*?:
MJ2#:J=BQV*_9AB#:J=BGV+'8J-BQ(#H@)7,`V;[8I]JI(-JIV+'8K]F&(-JI
MV*?8L=BHV+$`V;[8I]JI(-JIV+'8K]F&(-BOV*?8K]F'V90@VJG8I]BQV*C8
ML0#8J-BQV*?;C"#8I]BOV*?9A=F'V(P@VJG9A-N,VJD@VJG9AMN,V*\`0VQI
M8VMA=&5L;"#8I]BR(-BWV+';C-F"($A45%``V*C8L]BJV88@V;[9AMBLV+'9
MAP#8I]BHV+'9A]BG`-BGV*C8L=N,`-BLV878N2#8M-BOV88@V8;9B-BGV+$@
MVJG9AMBGV+';C`#:AMF%V+D@V+38K]F&(-F$V*C9A^*`C-F'V*<`V+'9AMJO
M`-BGV8;8JMBNV*?8J"#:J=F&V8;8K]F'(-BQV8;:KP#8I]F&V*K8KMBGV*@@
MV+'9AMJO`-BSV*K9B-F&V8?8ISH`V+G9AMBGV8C;C-F&(-BSV*K9B-F&V8?8
MIP#9A=BVV*W:J0#9@=BQV878I]F&`-F^V8C8L]BJV8<@V8'8L=F%V*?9A@#8
MJMF(V+;;C-BM`-F&V*?9A2#8N=F%V8C9A=N,`-BTV+':J=BJ`-BQV*?;C-BG
MV8;9A^*`C-F'V*<`V+38L=BW`-BTV+'8I]N,V+<`V*K9@=BGV8C8JMF'V*?;
MC"#9OMN,VJG8L=BHV8;8K]N,`-F^VXS:J=BQV*C9AMBOVXP@)7,`V*K8H]N,
MVXS8KR#8I]BSV84@V+'9A=BR`-BGV*K8M=BGV80@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO`-BGV*K8M=BGV80@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-BGV*K8
MM=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@VJG9A-N,V*\@V+G9A=F(V87;C"#8
ML=BO(-BTV*\`V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB#:J=F$VXS8
MKR#8N=F%V8C9A=N,(-BQV*\@V+38KRX@V*_9A-N,V80Z("5S("@E<RD`V*?8
MJMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB!&5%`@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO`-F&V878I]BSV8?8IP#8JMF%V*?8L]F'V*<@V*C8IR#9A=F(V8'9
MD=F"VXS9D=BJ(-BHV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+39A=BG
M(-BGV+;8I]F!V8<@V+38K]F'(-BHV8C8KP#8I]BOV*?9A=F'`-JIV8C:J=N,
M`-BQV8C9AMF(V+38J@#8L=F(V8;9B-BTV*H@V*C8L=BOV*?8M-BJV88@V*?8
MLB#8J-BNV+0@V*?9AMBJV*[8I]BHVXP`V8;9A=N,XH",V*K9B-BGV8;8KR#9
MOMN,V+K8I]F%(-BQV*<@V+'9A=BRV*C9AMBOVXP@VJG9AMBO(%!'4`#9AMF%
MVXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8I]F%V+;8I]BA(-JI
MV8;8KR!01U``V8;9A=N,XH",V*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@
MV+'9A=BRV*C9AMBOVXP@VJG9AMBO(%,O34E-10#9AMF%VXSB@(S8JMF(V*?9
MAMBO(-F^VXS8NMBGV84@V+'8IR#8I]F%V+;8I]BA(-JIV8;8KR!3+TU)344`
MV8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+/9A]BG(-BQV*<@V*?8MMBGV8'9
MAR#:J=BQV*\@)7,`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BG
MV+(@3$1!4"#9OMN,V8C8L]BJ(`#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JI
MV*?8L=BSV*?8LB!L9&%P(-F^VXS9B-BSV*H`V8;9A=N,XH",V*K9B-BGV88@
MV*C8I]F$V*?9AMBS(-BQV*<@VH;:J2#:J=BQV*\@)7,`V8;9A=N,XH",V*K9
MB-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@;&1A<"#9A=BJV+79A"#8M-BO`-F&
MV87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BGVXS8
MK-BGV*\@VJG8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR!0
M1U`@V+'8IR#8L=F%V++:K]BTV*?;C-N,(-F&V879B-BO(`#9AMF%VXSB@(S8
MJMF(V*?9AB#8K]BGV*_9AR!3+TU)344@V+'8IR#8L=F%V++:K]BTV*?;C-N,
M(-F&V879B-BO(`#9AMF%VXSB@(S8JMF(V*?9AB#8JMF%V*?8LR#8L=BG(-BM
MV+#9@2#9AMF%V8C8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8
MJB#8JMF(V++;C-BYVXP@V+'8IR#8K=BPV8$@V8;9A=F(V*\N("5S`-F&V87;
MC.*`C-BJV8C8I]F&(-BBV*_8L=BS(-JOVXS8L=F&V*_9AR#9AMBGV879A]F4
M(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BQV*<@V*K8M-BNVXS8M2#8K]BGV*\`
MV8;9A=N,XH",V*K9B-BGV88@VJG9A"#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8
MLR#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@
MVJG9A"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-F(V*?:J=BTVXP@
MV8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#:J=BGV879
MA"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-F(V*?:J=BTVXP@V8;9
MA=F(V*\`V8;9A=N,XH",V*K9B-BGV88@VJG9A-N,V*\@V+G9A=F(V87;C"#8
ML=BG(-BGV+(@VJG8I]BQV+/8I]BR(-JIV83;C-BO(-BHV*_8L]BJ(-BBV8C8
ML=BO`-F&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*C8I]BR(-JIV+'8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#9A=BOV8C9A"#9B-BXV*?;C-F!(-F&VJ_9A]BO
MV*?8L=N,("5S(-BQV*<@V*C8I]BR(-F&V879B-BO`-F&V87;C.*`C-BJV8C8
MI]F&("5S(-BQV*<@V*[9B-BGV8;8KP#9AMF%VXSB@(S8JMF(V*?9AB#8I]BS
MV84@V+'9A=BR(-BQV*<@V*C8L=BGVXP@VJG8I]BQV*C8L2#9A=F(V+'8KR#9
MAMBXV+$@V*C8I]BRV8;8M-BGV8;8KRX@V*C8N=BVVXP@VXS8IR#9A]F%V8<@
MV*S8LMBFVXS8I]BJ(-F%V+'8J-F(V+<@V*C9AR#8HMF&(-F&V*?8K]BQV+/8
MJB#9A=N,XH",V*C8I]BTV*\N(-BOV8C8J-BGV+'9AR#8L]BYVXP@VJG9AMN,
MV*\@VXS8IR#8J-BQV*?;C"#:J=F%VJD@V*C;C-BTV*K8L2#8J-BG(-BSV+'9
MOMBQV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO(-BJV878I]BS(-BHVJ_;C-BQ
MVXS8KP#9AMF%VXSB@(S8JMF(V*?9AB!!0TP@V+'8IR#8K]F(V*C8I]BQV8<@
MV*C8K]BSV*H@V*+9B-BQV*\`V8;9A=N,XH",V*K9B-BGV88@VJG8JMBGV*C:
MAMF'V90@V*+8K]BQV+,@V+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9
MB-BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BR
MVXS8N=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO+B`E
M<P#9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8
ML=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,`V8;9A=N,
MXH",V*K9B-BGV88@V8+8I]BHV83;C-BJV8?8I]N,(-JIV*?8L=BSV*?8LB#8
ML=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KP#9AMF%VXSB@(S8
MJMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@V*C8I]BRVJ_8L=BOV*?9
MAMBO`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8
MIR#8K]BNVXS8L=F'(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8
ML=BHV8;8K]N,(-F^V+38JMN,V*C8I]F&(-BQV*<@V*W9@=BX(-JIV+'8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-F^V+38JMN,V*C8
MI]F&(-BQV*<@V*W9@=BX(-JIV+'8KSH@)7,@`-F&V87;C.*`C-BJV8C8I]F&
M(-F^V+'9B-F&V*_9AR#9OMBTV*K;C-BHV*?9AB#9OMN,VJG8L=BHV8;8K]N,
M("5S(-BQV*<@V*W9@=BX(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQ
MV8C9AMBOV8<@V;[;C-JIV+'8J-F&V*_;C"`E<R#8L=BG(-BMV8'8N"#9AMF%
MV8C8KRX@V+39A=BG(-F%VXP@V*K9B-BGV8;;C-BO(-BGV+(@VXS:J=N,(-BG
MV+(@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L=BGVXP@V*W9@=BX(-JIV*\@V*C8
ML2#8L=F(VXP@)7,@V*?8L]BJV8'8I]BOV8<@V8;9A=BGVXS;C-BO(-F((-N,
MV*<@V*?;C-F&VJG9AR#8I]BR(-JIV*\@V*C9AR#8M=F(V+'8JB#8K]BSV*K;
MC"#8K]BQ)7,@V+'9B-F&V8C8M-BJ(-BJV8?;C-F'(-F&V878I]N,VXS8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#:J=BGV+'8L]BGV+(@3$1!4"#8L=BG(-BLV+/8
MJMBLV8@@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-BJV878I]BS("#8L=BG
M(-BHV+'9B-BRV+'8L]BGV8;;C"#:J=BQV*\N("5S`-F&V87;C.*`C-BJV8C8
MI]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*C8L=F(V++8L=BS
MV*?9AMN,(-JIV+'8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V8;9B-BGV+$@
MV*S8I]F&V*C;C"#9A=F(V++;C-F$V*<@V+'8IR#9OMN,V*_8IR#:J=BQV*\N
M(-F%V+?9A=BFV88@V+39B-N,V*\@VJG9AR#9AMF(V*?8L2#8K-BGV8;8J-N,
M(-BHV*?8LB#8I]BSV*H`V878JMF&(-BTV878I]BQV+0@V+38K]F'`-JIV+39
MB-BQ`-BOV8C8L=F'XH",V8?8IP#8I]N,V*S8I]BO`-BGVXS8K-BGV*\@VXS:
MJ2#9OMN,V8C9AMBO`-BGVXS8K-BGV*\@VXS:J=N,(-BLV*_;C-BO`-BGVXS8
MK-BGV*\@V++;C-BQV;[9B-BTV8?B@(S9A]BG`-F%V*S9B-BRV8?8I]N,(-BG
MVXS8K-BGV*\@VJG9AMF&V*_9AP#8M-F%V*?8L=F'(-JIV*?8L=BJ(-BGV+G8
MJMBHV*?8L=N,`-BSV*?8N=BJ(-F!V+G9A-N,`%523"#9@=BYV83;C"#9A]BS
MV*H`V*+8J"#9B"#9A]F(V*?;C"#9@=BYV83;C`#8M-BQV*?;C-BW(-F!V+G9
MA-N,.B``V+/8J-JI(-F!V+G9A-N,`-BSV8'8I]BQV+3;C"#:J=BQV*_9AB#9
MB-BXV*?;C-F!(-F'V8;:K]BGV84@V8C8L=F(V*\@V*C9AR`E<P#8J-BQVXS8
MK]F&`-BHV+';C-BOV88@V*?9AMBJV*[8I]BH`$-Y<FEL;&EC("A+3TDX+5(I
M`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*0!$1`#8L=F(V++8I]F&V8<`V878L=F(V+':K]BQ(-BOV+'8KMBJ
M(-BOV*?8K]F'`-BJV*?8L=N,V*X`V*K8I]BQVXS8KB#8K]BQVXS8I]F!V*H@
MV+38K]F'`-BJV*?8L=N,V*X@V*?9AMBJV*[8I]BH`-BQV8C8L@#8K=BPV8$@
MV+/8JMF(V88`V*_8L]BGV878J-BQ`-BGV+G8K]BGV*\@V*_9A]BOV8?;C`#:
MJ=F%(-JIV+'8K]F&(-BJV8C8L=F!V*K:K]N,`-F^VXS8M"#9@=BQV+8`V+'9
MAMJO(-F^VXS8M"#9@=BQV+8`V8?9B-N,V9'8JB#9OMN,V+0@V8'8L=BV`-F^
MV8C8L]BJV8?9E"#9OMN,V+0@V8'8L=BV`-BJV+G8I]BQVXS9@0#8K=BPV8$`
MV*W8L-F!(-JOV+'9B-F'`-BMV+#9@2#9A=BLV8C8L@#8K=BPV8$@V8@@V;[8
MI]JIV+/8I]BRVXP@V;[;C-BZV*?9A=F'V*<`V*W8L-F!(-BSV839B-F$`-BM
MV+#9@2#8L]BJV8C9A@#8K=BPV8$@V*?9A-JOV8C;C"#8K-BGVXS:K]BRVXS9
MAB#9A=F(V*S9B-BO`-BMV+#9@2#9A=BLV8C8LMF'V*<@V*C8L=BGVXP@("(E
M<R(`V*+;C-BG(-F%V*S9B-BRV8?8IR#9B"#8LMN,V+'9A=BLV8C8LMF'V*<@
MV*C8L=BGVXP@(B5S(B#8K=BPV8$@V+39B-BOV)\`V*W8L-F!(-BSV+?8L0#8
MK=BPV8$@V8?9B-N,V9'8JB#8I]F&V*K8KMBGV*@@V+38K]F'`-BMV+#9@2#8
ML]BJV8C9AB#9@=BYV83;C`#8K=BPV8$@V+/8M]BQ(-F!V+G9A-N,`-BRV878
MI]F&(-BGV+'8L]BGV80`V+38L=BM(-F%V+3:J=F$`-BJV8C8MMN,V*T`V*S8
MLMF0V*;;C-BGV*HZ`"#8K-BRV*;;C-BGV*H@V*C8L=BGVXP@V+/8L=F^V+'8
ML]BJ(-BSV*?9A=BGV8;9AR#8J]BHV*H@V+38K]F'(-BGV+/8J@#:K]BSV*K8
ML=BT`-F&V8+8M]F'(-BTV*C9AMF%`-F&V8+8M]F'(-BTV*C9AMF%(-BHV+'8
MI]N,(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z(`#9AMF"V+?9AR#8M-BHV8;9A3H@
M`-BLV8?8JB#8I]BR(-J&V;X@V*C9AR#8L=BGV+/8J@#8K-F'V*H@V*?8LB#8
ML=BGV+/8JB#8J-F'(-J&V;X`V+38I]BNV8<`V*+;C-BG(-BRV878I]F&(#(T
M(-BSV*?8N=BJV8<@V8;9A=BGVXS8M"#8K]BGV*_9AR#8M-F(V*_8GP#:K]BR
MVXS9AMF'XH",V8?8I]N,(-F&V878I]N,V+0`V8;9A=BGVXS8M"#8K-BRV*;;
MC-BGV*H@V;[;C-BTPJW8J-N,V8;;C`#9AMF%V*?;C-BT(-F^VXS8M,*MV*C;
MC-F&VXP`V8;9A=BGVXS8M"#9@MBGV838J`#8K=BGV838JB#8JMBPVJG8L0#8
MK=BPV8$@V8;8M-F(V*\`V*_8L]BJV+'8L]N,(-F%V+/8JMF"VXS9A2#8J-F'
M(&UA:6YT96YA;F-E+G!H<"#9A=F%VJG9AB#9AMN,V+/8J@#8HMN,V*<@V+/8
MM]BQ(-BGV8C9A"#8M-BGV879A"#9@=N,V838KR#9AMBGV84@V87;C.*`C-BH
MV*?8M-BOV)\@V*?:K]BQ(-J&V8;;C-F&(-BGV+/8JMB,(-BGVXS9AB#8K-BY
MV*C9AR#8L=BG(-BYV838I]F%V*H@V*C8LMF&VXS8KSH`V*?8L]BJV8+8L=BG
MV+$`V*?8L]BJV8+8L=BGV+$@)7,`V*?8L]BJV8+8L=BGV+$@V;[;C-JIV+'8
MJ-F&V*_;C"#8JMF(V83;C-BO(-BTV*_9AR#8J-BYV8;9B-BGV88@V*_8L]BJ
M(-F&V8C;C-BS(%!(4`#9@=F'V+'8L]BJ(-F^V*?;C-N,V8;B@(S9OMBQ`-BO
MV*?8L=F(V8?8IP#9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C`!%4E(`
MV8C;C-BQV*?;C-BT`-F(VXS8L=BGVXS8M"#8J-F$V8C:J0#9B-N,V+'8I]N,
MV+0@VJ_8L=F(V8<`V8C;C-BQV*?;C-BT(-F%V*S9B-BR`-F(VXS8L=BGVXS8
MM"#9A=BLV8C8LMF'V*<`V8C;C-BQV*?;C-BT(-F%V*S9B-BRV8?8IR#8J-BQ
MV*?;C"`E<P#:K]BRVXS9AMF'XH",V8?8I]N,(-F(VXS8L=BGVXS8M#H`V8C;
MC-BQV*?;C-BT(-F%V*S9B-BRXH",V8?8IR#8J-BQV*?;C"`B)7,B`-F(VXS8
ML=BGVXS8M"#9A=BLV8C8LN*`C-F'V*<@V*C8L=BGVXP@)7,`V*K8K=BUVXS9
MA-BGV*H`V+G9AMBUV+$N+BX`16T`V8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;
MC-JIVXP`V*+8K]BQV+,@V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;
MC`#8HMBOV+'8L]F'V*?;C"#9AMBGV879A^*`C-F'V*?;C"#8I]F$VJG8JMBQ
MV8C9AMN,VJG;C"#8J-BGVXS8KR#9A=F&V+?8J-F"(-BHV*?8M-BO`-F&V*?9
MA=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V*C8IR#8JMBCVXS;C-BO`-BG
MV*W8L]BGV+/8I]BJ`-BNV*?9A-N,(-JIV+'8K]F&(-F^VXS8NMBGV84@`-BN
MV*?9A-N,(-JIV+'8K]F&(-F&V*K;C-BLV8<`V*[8I]F$VXP@VJG8L=BOV88@
MV879B-BGV+'8KR#8K-BSV*K8K-F(`-BBVXS8IR#8K]BQV*P@V*K8M=BGV8C;
MC-BQ(-BGV+(@VJ_8I]F$V+';C-F'V*?;C"#8N=JIV+,@V*_8L2#9A=BJV88@
MV8'8N=BGV80@V+39B-BOV)\`V*+;C-BG(-JOV++;C-F&VJ_8I]F&(-BRV87;
MC-F&V8<@V+'9B-N,(-JIV83;C-JI(-BQV*?8L]BJ(-F!V+G8I]F$(-BTV8C8
MK]B?`-BGV8;8JMF'V*?;C"#8L]BGV80`V*C8LMBQVJ\@VJG8L=BOV88@V8C;
MC-BQV*?8L]BJV*?8L0#;C-JI(-BSV*;9B-BGV80@V*?9A=F&VXS8JMN,(-BH
MV+'8I]N,(-F^V+'8L]BT(-BGV+(@V+39A=BG(-BHV8<@V8?9AMJOV*?9A2#8
MJ-BGV++9AMBTV*?9AMBOV88@V*?8L]F%(-BQV878LB#9B-BGV+'8KR#:J=F&
MVXS8K]B,(-F%V*O9A-BGV9(@)]F&V*?9A2#8K=N,V8C8I]F&(-BNV*?9AMJO
MVXP@V+39A=BG(-J&VXS8L]BJV)\G`%523"#8JMBUV8C;C-BQ(-BQV*<@V*?;
MC-F&V*S8IR#9B-BGV+'8KR#:J=F&VXS8KP#8KMBWV*<`V*C9A-F(VJD@V*?;
MC-BLV*?8KR#8KMBWV*<Z("5S`-BNV+?8IR#8K]BQ(-JIV+/8J"#9A=BMV*K9
MB-BG.B5S`-BNV+?8IR#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#8I]BSV84@
MV+'9A=BR(#H@)7,`V*[8M]BG(-BHV*<@V;[;C-BZV*?9A2#9AMBGV879A]F4
M(-BGV83:J=BJV+'9B-F&VXS:J=N,`-BYV*K;C-F"V8<`V*?8L=F(V;[8IP#9
MA]BQ(-F^V*?9AMBRV*_9AR#8K]F"VXS9@MF'`-F'V+$@V*_9B"#8K]F"VXS9
M@MF'`-F'V+$@V+/;C"#8K]F"VXS9@MF'`-F'V+$@V;[9AMBL(-BOV8+;C-F"
MV8<`V*_8L2#9A]BQ(-F(V+'9B-BO`-F'V+$@V8;;C-F%(-BSV*?8N=BJ`-F'
MV+$@V*_9@MN,V8+9AP#9A=F"V*?8K]N,V+$@V878J]BGV80Z`-BGV*S8L=BG
M`-BHV*?8LB#:J=BQV*_9A@#8J-BGV++:J=BQV*_9AB#9AMF(V*?8L2#:J=F&
MV*?8L=N,`-BGV8;8JMBXV*?8L2#8J-BQV*?;C"`G*"<`V*K8I]BQVXS8KB#8
MI]F&V8+8MMBGV*$`V8;9A=BGVXS9AMBOV8<`V+'9AMJO(-F^VXS8M.*`C-BR
MV87;C-F&V8<`1E10('5P;&]A9"!O9B!S971U<``@V*C8I]BRVXS8I]BHVXP@
MV*K9@MBOV878I]BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP`@V*?8JMBUV*?9
MA"#8J-F'(-JIV*?8L=BSV*?8LB!,1$%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKP`@V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB!334(@V8;8I]F%V8C9
M@=F1V8(@V*C9B-BO(``@V*K9A]N,V8<@V+'9B-F&V8C8M-BJ(-BGV+(@(B5S
M(B#9AMBGV879B-F!V9'9@B#8J-F(V*\`V*?;C-BLV*?8KR#8L=F(V8;9B-BT
MV*H@V*_8L2`B)7,B(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP`@V*?;C-BLV*?8
MKR#;C-JI(-BGV*K8M=BGV80@V*S8K]N,V*\@4T%33"#9AMBGV879B-F!V9'9
M@B#8J-F(V*\`(-BGV8;8JMF"V*?9A"#8J-F'("(E<R(@V8;8I]F%V8C9@=F1
MV8(@V*C9B-BO`-F$V+?;C-F!`-BNV+?8I]N,(-BLV*_;C#H@`-F!VJG8LP#9
M@=F(V+';C-F'`-BQVJ_8J-BGV+$@V*[9@=N,V8$`VJG9A=N,(-BJVJ_8L=JO
M`-BTV878I]BQV+0@V;[8L=F(V8;8K]F'.B`E<R#9OMBQV8C9AMBOV8<`V+39
MA=BGV+'8M"#9OMBQV8C9AMBOV8<Z("5S(-F^V+'9B-F&V*_9AP#9A=BOVXS8
ML2#9OMBQV8C9AMBOV8<`V8;8I]F%(-F^V+'9B-F&V*_9AP#8I]F&V*K8KMBG
MV*@@V;[8L=F(V8;8K]F'`-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'`-BGV+'8
ML]BGV80@V;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",
MV+39B-BO+BX`V8';C-F$V*K8L=F'V*<`V8;;C-F%V8<@V*?9B-F$`-BQV*C8
MN2#8I]F(V80`V8;8L]BHV*H@V*O8I]BHV*H`V*?8N=BTV*?8L=N,`-F%V8?B
M@(S8HMF$V8C8KP#9OMF(V+39AR`E<R#9A=F(V*S9B-BO(-F&VXS8L]BJ(`#8
ML=F&VJ\@V8+9A-F%`-BZV+#8IP#8J-BQV*?;C"#9A=BQV8C8L=JOV+'9A]BG
MVXS;C"#:J=F'(-BJV+78I]F(VXS8L2#8L=BG(-F^V+38JMN,V*C8I]F&VXP@
MV8;9A=N,XH",VJG9AMF&V*\`V;[;C-BTPJW8J-N,V8;;C`#8I]BSV84@V+'9
MA=BR(-BNV8C8KR#8L=BG(-F!V+'8I]F%V8C8M"#:J=BQV*_9A^*`C-BGXH",
MVXS8K]B?`-F!V+'9A=F'V*<`V+?8I]F$V+D`V8;9B-BY(-BWV*?9A-BY`-BW
MV*?9A-BYV8?8IP#8M]BGV838N=F'V*<@V[(`V*?9AMBLV879AMF'V*<`V*?8
ML=BLV*?8N=F'V*<`V*S9A=BYV8<`VH;8I]BQVH;9B-BHV8?8IP#8I]BR`-BG
MV+(@`-BTV+'8K2#:J=BGV879A`#9A=BGV8<@VJG8I]F%V80`V8;8I]F%(-JI
MV*?9A=F$`-JOV*?9A-BQVXP@V*C8L=BGVXP@V*_8L=N,V*?9@=BJ(-BJV+79
MB-N,V+$@`-JOV*?9A-BQVXPZ`-BJV8C9A-N,V*\@V;[;C-JIV+'8J-F&V*_;
MC"`E<P#:J=BO(-BJV8C9A-N,V*\@V+38K]F'`-F&V*?9A2#8K]BGV*_9AR#8
MM-BOV8<`V*C8L=F(`-BLV+/9AMBLV8C;C"#:K]F(VJ_9A`#8K]BQV*S9AR#8
MKMBGVJG8L]BJV+';C`!'<F5E:R`H25-/+3@X-3DM-RD`V+/8L=F^V+'8L]BJ
MVXP@VJ_8L=F(V8<`V8;8I]F%(-JOV+'9B-F'(-F&V*C8I]N,V*\@V*[8I]F$
MVXP@V*C8I]BTV*\`VJ_8L=F(V8<F(W@R,#!C.]F'V*<`V878K-F(V++9A]BG
MVXP@V879A]F%V*?9A@#:J=BJV*?8J-J&V8?9E"#;C-BGV*_8J-F(V*\`2%1-
M3`!(5$U,07)E82#8K=BPV8$@V*+8KMBQVXS9AB#8L]F$V8C9A"#8L=BG(-BO
MV+$@V+'8K]N,V8$@V+'8KR#9A=N,XH",VJG9AMBO`$A434Q!<F5A(-BMV+#9
M@2#8HMBNV+';C-F&(-BSV*K9B-F&(-BQV*<@V*_8L2#8K-BOV8C9A"#8L=BO
M(-F%VXSB@(S:J=F&V*\`2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+'8
MK]N,V8$@V+'8IR#8K]BQ(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JIV8;8KP#8
MJMBUV*_;C-F"(-F'V8C;C-F1V*H@2%144"#;C-BGV8'8JMF'(-F&V+38KP#8
MI]F$VJ_9B-BQVXS8JMF%($AA<V@`V879A^*`C-BBV839B-BO`-BSV+'8HMF%
MV*\`2&5B<F5W("A)4T\M.#@U.2TX+4DI`-BHV839AMBOVXP`V+'8I]F'V8;9
MA=BG`-BQV*?9A]F&V878I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V8C;C-BQ
MV*?;C-BTVJ_8L0#:J=F%VJD@VJG9AMF&V*_9AP#9AMN,V87B@(S:J=BQV8<`
MV*?;C-F&V*S8IR#8I]BHV*K8K]BGVXP@V;[8L=F(V8;8K]F'XH",(-F%VXSB
M@(S8J-BGV+38KSH`V*C8I]F$V*<`V*[8I]F&V8<`V*[8I]F&V8<`V*+8K]BQ
MV+,@V*[8I]F&V8<`V+38I]BNV8?9E"#8I]BUV83;C`#8M-F%V*?8L=F'(-BJ
MV839@=F&(-F%V8;8LMF$`-F'V8C8L=BO`$AO<F1E+TMO;&%B.B`E<R#8J-BG
M(-BOV*?8K]F'(-F&V*?8K]BQV+/8JB!834P@V*_8L2#9OMN,V+K8I]F%("5S
M(-F%V8C8I]BLV8<@V+38K]F'(-BGV+/8J@!(;W)D92]+;VQA8CH@V8?;C-J&
M(-F^VXS8NMBGV87;C"#9A=BWV*?8J-F"V*H@V*C8IR#8M-N,V*$@)7,@V8;8
MK]BGV+'8KP!(;W)D92]+;VQA8CH@V8?;C-J&(-BTVXS8IMN,(-BGV+(@V8;9
MB-BY("5S(-BOV+$@V;[;C-BZV*?9A2`E<R#;C-BGV8'8JB#9AMBTV*\`2&]R
M9&4O2V]L86(Z(-BHV*<@V879B-F!V9'9@MN,V9'8JB`E<R`B)7,B(-BMV+#9
M@2#8M-BO`$AO<F1E+TMO;&%B.B#8JMF(V83;C-BO(-N,VJD@V*_8L=BNV*H@
MV*S8K]N,V*\@6$U,(-BHV+'8I]N,(-BTVXS8H2`E<R#9A=F"V*_9B-BQ(-F&
MVXS8L]BJ(`!(;W)D92]+;VQA8CH@V*W8L-F!("5S("(E<R(Z)7,@V879@MBO
MV8C8L2#9AMN,V+/8J@!(;W)D92]+;VQA8CH@V*C8I]BRVXS8I]BHVXP@($U)
M344@240@V*C8L=BGVXP@V8+8L]F%V*K;C"#8I]BR(-F&V8C8N2`E<R#9A=F"
MV*_9B-BQ(-F&VXS8L]BJ(`!(;W)D92]+;VQA8CH@V+/9AMJIV+'9B-F&(-JI
MV+'8K]F&("5S("(E<R(Z("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H`2&]R9&4O
M2V]L86(Z(-BSV8;:J=BQV8C9AB#:J=BQV*_9AB#8I]BTV*K8L=BGVJG9A]BG
M(-F%V8+8K]F(V+$@V8;;C-BSV*HZ("5S`$AO<F1E+TMO;&%B.B#8I]BTV*K8
ML=BGVJD@V8;8I]BTV8;8I]BNV*K9AR`B)7,B`-F"V*?9AMF(V88@V*?9@=F"
MVXP`V8'8I]BUV839A^*`C-JOV+#8I]BQVXP@V*?9@=F"VXP`.MBGV8'9@MN,
M`-J&VJ_9B-F&V8<@V*C8IR#8I]N,V8;8K-BG(-BBV+39AMBG(-BTV*_;C-BO
MV)\@*-F$V+?9@=BGV8L@VJ_8LMBGV+'8M"#8K]F'VXS8KRDA`-J&V8;8KR#8
ML]BJV8C9AB#8L=BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8K]BZV*?9A2#:
MJ=F&VXS8K]B?`-J&V8;8KR#9@=N,V838KR`HV+/8JMF(V88I(-F(V*S9B-BO
M(-BOV*?8L=BOV)\`VH;9AMBO(-BSV+?8L2#8L=BG(-F%VXSB@(S8KMF(V*?9
MA]N,V*\@V*?8K]BZV*?9A2#:J=F&VXS8K]B?`-BQV+?9B-BHV*H`V+'8M]F(
MV*C8JCH@`-BGVXS8K-BGV*\@V8;8I]F%V8?B@(S8K]BGV88@24U!4"#9AMBG
MV879B-F!V9'9@B#8J-F(V*\Z("`E<P#8K=BPV8$@V8;8I]F%V8?B@(S8K]BG
MV88@24U!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\@.B`E<P#8I]N,V*S8I]BO
M(-F%V*W8K]F(V*_;C-F1V*H@V8;8I]F%V8?B@(S8K]BGV88@24U!4"#9AMBG
MV879B-F!V9'9@B#8J-F(V*\@.B`E<P#8HMBOV+'8LR!)4`#8HMBOV+'8LR!)
M4"#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*H`V*+8K]BQV+,@25`@
MV*_8L2#8K]BGV*[9A"#8J-F$V8C:J2!#2412(-BGV*S8I]BRV8<@V*_8I]BO
MV8<@V8;9A=N,XH",V+39B-BO`-BGV*C8JMBOV*<@V+/8M]BQ(-BQV*<@V8C8
MI]BQV*\@VJG9AMN,V*\`V8'9@MBW(-BBVXS:J=F(V8;9A]BG`-BBVXS:J=F(
MV8;9A]BG(-BHV+'8I]N,("5S`-BBVXS:J=F(V8;9A]BG(-BHV*<@V878JMF&
M`-F&V*?9A2#9A]F(VXS9D=BJ.@#8I]JOV+$@V*+9AB#8J-F'(-BOV+'8L]BJ
MVXP@V8;9A=BGVXS8M"#8K]BGV*_9AR#9AMBTV*_8C"`E<R`@V*C8L=BGVXP@
MV*C8I]BR(-JIV+'8K]F&(-BBV88@V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8
MK]N,V*\`V*?:K]BQ(-BTV878IR#9A]N,VH8@V*+;C-JIV8C9AMN,(-BQV*<@
MV*_8L2#9A=BQV8C8L=JOV+$@V8;8J-N,V8;;C-BOV(P@V879A=JIV88@V*?8
ML]BJ(-F$V*?8LMF%(-BHV*?8M-BO(-JIV8<@4$Y'(%1R86YS<&%R96YC>2#8
ML=BG(-BNV*?9A=F(V+0@VJG9AMN,V*\`V*?:K]BQ(-BTV878IR#8I]N,V88@
MV;[;C-BZV*?9A2#8L=BG(-F%V+38I]F'V*_9AR#:J=F&VXS8KR#8I]F%V*<@
MV*K8M=F(VXS8L=N,(-BQV*<@V878M-BGV8?8K]F'(-F&VJG9AMN,V*_8C"#8
MI]N,V88@V*C9AR#8I]N,V88@V+G9A-BJ(-BNV8C8I]F'V*\@V*C9B-BO(-JI
MV8<@V878L=F(V+':K]BQ(-BTV878IR#9@=BGV*_8L2#8J-F'(-F&V878I]N,
MV+0@V*K8M=F(VXS8L2#9AMN,V+/8JB``V;[;C-BTXH",V8;9A=BGVXP@V*K8
MM=F(VXS8L3H`55),(-BJV+79B-N,V+$`55),(-BJV+79B-N,V+$Z`-BJV+79
MB-N,V+$@V*?8LB#:K]BGV838L=N,`-BJV+79B-N,V+$@V*?8LB#:K]BGV838
ML=N,.@#8I]BQV+/8I]F$(-BJV+79B-N,V+$`V*K8M=BGV8C;C-BQ`-BOV+'9
MB-F&XH",V*C8L=BOV(P@VJ_8I]F%("5D`-F!VXS9A-BO(-BOV+'9B-F&XH",
MV*C8L=BO(-BTV*_9ASH@)7,`V8';C-F$V*_B@(S9A]BGVXP@V*_8L=F(V8;B
M@(S8J-BQV*\@V+38K]F'.@#8J-BYV*_8I]F+(-BSV+?8L2#8L=BG(-F(V*?8
ML=BO(-JIV8;;C-BO`-JIV*\@V+G9A=F$VJG8L=BO(-F&V*?8K]BQV+/8JB#8
MK]BGV*_9AR#8M-BOV8<@V*?8L]BJ`"#9AMBGV84@VJG8I]BQV*C8L2_8I]BS
MV84@V+'9A=BR("#9AMBGV*_8L=BSV*H@V*?8L]BJ`-F&V*?9A2#:J=BGV+'8
MJ-BQ(-N,V*<@V*+8K]BQV+,@V*S8I]N,VJ_8LMN,V88@V8;8I]BOV+'8L]BJ
M(-F%VXSB@(S8J-BGV+38KRX@V838M]F!V*<@V878K-BOV*_8I]F2(-BSV+G;
MC"#:J=F&VXS8KR#9B"#;C-BG(-BOV+$@V+79B-BQV*H@V8;;C-BGV+(@V*C9
MAR#:J=F%VJD@V*C;C-BTV*K8L2#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878
MI]F&V8<@V*K9A=BGV+,@V*C:K]N,V+';C-BO`-BGV8'8LMBGVXS8M"#8JMF(
MV+'9@=BJVJ_;C`#:J=BGV+'8J-BQV*?9AB#8KMBGV+4`V*?8M]F$V*?8N=BG
MV*H`V*?8M]F$V*?8N=BGV*H`V*?8M]F$V*?8N=BGV*H@V*_;C-JOV+$@V*_8
ML2#8K]BSV*K8L=BS(-F&VXS8L]BJ`-BOV+'8K"#8L]BJV8C9AB#8J-BYV*\@
MV*?8L@#8K]BQV*P@V*K8M=F(VXS8L0#8K]BQV*P@V*S8K]F(V80`V*_8L=BL
M(-F^VXS9B-F&V*\@V8C8J`#8I]BHV*K8K]BG(-BSV*K9B-F&(-BQV*<@V*_8
ML=BL(-JIV8;;C-BO`-N,VJD@V+/8JMF(V88@V*S8K]N,V*\@V*C8N=BO(-BG
MV+(@V+/8JMF(V88@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO`-N,VJD@V+/8
MJMF(V88@V*S8K]N,V*\@V8+8J-F$(-BGV+(@V+/8JMF(V88@V8'8N=F$VXP@
MV*_8L=BL(-JIV8;;C-BO`-N,VJD@V+/8M]BQ(-BLV*_;C-BO(-BHV+G8KR#8
MI]BR(-BSV+?8L2#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\`VXS:J2#8L]BW
MV+$@V*S8K]N,V*\@V8+8J-F$(-BGV+(@V+/8M]BQ(-F!V+G9A-N,(-BOV+'8
MK"#:J=F&VXS8KP#;C-JI(-F^V*?8L=BGVJ_8L=BGV8$@V*C8N=BO(-BGV+(@
MVJ_8L=F'(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KP#;C-JI(-F^V*?8L=BG
MVJ_8L=BGV8$@V8+8J-F$(-BGV+(@VJ_8L=F'(-F!V+G9A-N,(-BOV+'8K"#:
MJ=F&VXS8KP#8K]BQV*P@V*?9A-JOV8C;C"#8K-BGVXS:K]BRVXS9A@#;C-JI
M(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V*C8L=BGVXP@
MV*_8L=N,V*?9@=BJ(-BGV+/9A2#8L=F%V+(@(-BLV*_;C-BO(-BOV+'8K"#:
MJ=F&VXS8KR``V*_8L=BL(-BSV839B-F$(-BHV+G8KP#8K]BQV*P@V+/9A-F(
MV80@V8+8J-F$`-BOV+'8K"#8L]BJV8C9AB#8J-BYV*\`V*_8L=BL(-BSV*K9
MB-F&(-F"V*C9A`#8K]BQV*P@V;[;C-BZV*?9A0#8K]BQV*P@V;[8I]BQV*?:
MK]BQV*?9@2#8J-BYV*\`V*_8L=BL(-F^V*?8L=BGVJ_8L=BGV8$@V8+8J-F$
M`-BOV+'8K"#8L]BWV+$@V*C8N=BO(`#8K]BQV*P@V+/8M]BQ(-F"V*C9A`#9
MOMBGV+/8KB#9A=F(V+'8KR#9AMN,V*?8LB#8L=BG(-BHV+'8I]N,(-BSV*;9
MB-BGV80@V*?9A=F&VXS8JMN,(-BOV+'8K"#:J=F&VXS8KSH`V*_8L=BL+]BJ
MV+K;C-N,V+$@V*K8M=F(VXS8L0#8K]BQV*POV*K8NMN,VXS8L2#9OMN,V8C9
MAMBO`-BGV+G8JMBHV*?8L2#9AMBGVJG8I]F!VXP@V*C8L=BGVXP@V*?8L=BS
MV*?9A"#8J-F'(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,`-BGV+G8JMBHV*?8
ML2#9AMBGVJG8I]F!VXP`V+G8K]BO(-BUV*W;C-BM`-F!V8?8L=BSV*H@V+G8
MK]BO(-BUV*W;C-BM`%5$2"#9AMBGV878N=BJV*C8L0#8J-BQV8;8I]F%V8?9
ME"#:J=BGV+'8J-BQV*_;C"#9AMBGV878N=BJV*C8L0#8K]BSV*K9AR!)1"#9
MAMBGV878N=BJV*C8L0#8K]BGV*_9A]F4(-F&V*?9A=BYV*K8J-BQ(-BGV+'8
MI]BFV8<@V+38K]F'`-BBV*_8L=BS(-F%V8+8M=BO(-F&V*?9A=BYV*K8J-BQ
M`-F"V*?9A-BH(-F^V+'9B-F&V*_9A]F4(-F&V*?9A=BYV*K8J-BQ`-F&V8C8
MN2#9OMN,V+K8I]F%(-F&V*?9A=BYV*K8J-BQ`&%P:5]I9"#9AMBGV878N=BJ
MV*C8L2#8I]BSV*H@V8@@VXS8IR#8I]BR(-BHVXS9AB#8L=F!V*K9AR#8I]BS
MV*H`V;[8I]BQV*?9A=BJV+$@V8;8I]F%V+G8JMBHV+$@V8@@VXS8IR#8I]BR
M(-BHVXS9AB#8L=F!V*K9AP#9A=BLV8C8LB#9OMBOV+$@V8;8I]F%V+G8JMBH
MV+$`V;[8L=F(V*K:J=F$(-F&V*?9A=BYV*K8J-BQ`-JOVXS8L=F&V*_9A]F4
M(-F&V*?9A=BYV*K8J-BQ.B`B)7,B`-BTVXS8H2#8J-F'(-BGV+38JMBQV*?:
MJ2#:K]BPV*?8M-BJV8<@V+38K]F'V90@V8;8I]F%V+G8JMBHV+$`V*+8K]BQ
MV+,@V+/8L=J&V+39A=F'(-F&V*?9A=BYV*K8J-BQ`-BOV*?8K]F'(-N,V8C9
MAMN,VJG8KR#9AMBGV878N=BJV*C8L2``V879B-BLV8C8K]N,`-BHV+':K]BQ
MV*_8I]F&V*_9AB#8I]F&V*K8KMBGV*@`5"U3=&]R;7,`V879AMBJV+38L2#:
MJ=F&V8;8K]F'`-BMV+'9B-F!(-JIV*P`VIC8I]F&V8C;C-F'`$IA<&%N97-E
M("A)4T\M,C`R,BU*4"D`V++;C-BQV;[;C-BQV*?9A]F&VXP`VIC9B-BFVXS9
MAP#:F-F(V*;9A@#9A]F%XH",V*K8L=BGV+(@VJG8L=BOV88`V8?9A>*`C-BJ
MV+'8I]BRVXP@V8C8L]BW`-F'V87B@(S8JMBQV*?8LMN,(-JIV*?9A=F$`-F'
MV87B@(S8JMBQV*?8LMN,(-J&V;X`V8?9A>*`C-BJV+'8I]BRVXP@V+'8I]BS
MV*H@`-BGV+79A-N,(-F&VJ_9AR#8K]BGV+38JMF'(-BTV8C8K]B?`-JIV*?8
ML=BSV*?8LB!K97)B97)O<V4@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BQV*<@
MV+'8KR#:J=BQV*\`V*?;C-BLV*?8KR#:J=F$VXS8KP#8I]BKV+$@V*?9AMJO
MV+38JB#:J=F$VXS8KP#8M]F(V80@VJG9A-N,V*\`V8;9B-BY(-JIV83;C-BO
M`-JIV*?8L=BHV+'8KR#:J=F$VXS8KP#:J=F$VXS8KR#9@MBHV838I]F+(-BO
MV+$@VJG8I]BQV+/8I]BR(-BYV879B-F%VXP@VJG9A-N,V*\@V879B-BLV8C8
MKR#8I]BSV*H`XH",V*C:AMF'XH",V8?8IP!+;W)E86X@*$550RU+4BD`V*S8
MI]F&V878I]N,VXP`V++8J-BGV88`V8;;C-F%V8?9E"#8HMBNV+$`V*K8NMN,
MVXS8L2#8HMBNV+';C-F&(-BGV+/9A2#8L=F%V+(`V+'8J-BY(-BBV*[8L0#8
MHMBNV+';C-F&(-BHV+'9B-BRV+'8L]BGV8;;C#H`V*+8KMBQVXS9AB#9B-BQ
MV8C8KSH@)7,`V*+8KMBQVXS9AB#9B-BQV8C8KR`Z("5S(-BGV+(@)7,`V*+8
MKMBQVXS9AB#9B-BQV8C8KSH@V8?8L=JOV+(`V*W9@MF(V8(`V*S8I]F&V878
MI]N,VXP`VH;9O@#8L]BQV*+9A=BO(-J&V;X`V879@MBGV*_;C-BQ(-J&V;X`
MV8;9A>*`C-F&V84@V*C8I]BQV*?9A@#8J-BGV+'9AMBOVJ_;C"#8L]BHVJD`
MV*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BRV8C8K]F'V8;:K]BGV84`V*C8I]BQ
MV8;8K]JOVXP@V+/8J-JI(-BOVXS8L=F'V8;:K]BGV84`V*C8I]BQV8;8K]JO
MVXP@V8@@V+':K]BHV*?8L2#8L]BHVJD`V*C8I]BQV*?9AB#8L]BHVJD@V*C9
MAR#9A]F%V+'8I]F'(-BQV+G8KP#8J-BQV8$@V+/8J-JI`-BHV+'9@2#9B"#8
ML=JOV*C8I]BQ(-BSV*C:J0#9OMN,V8C9AMBO`-F&V8+8I]BW(-F^VXS9B-F&
MV*\@V*C9ASH`V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8
ML=BG(-BHV8<@V+79@=BMV8<@V*?;C-BLV*?8KR#9OMN,V+K8I]F%V(P@V*C9
MAR#9A]F&VJ_8I]F%(-F%V+38I]F'V*_9A]B,(-F^VXS9B-F&V*\@V*_9A]N,
MV*\`V;[;C-F(V8;8K^*`C-F'V*<`VJG9B-JIVXP@V83;C-F&V8C:J=BS`-F!
MV8?8L=BSV*H@+2#:J=BGV+'8J-BQ(-F%VXSB@(S8JMF(V*?9AMBO(-F^V8C8
MM-F'(-BQV*<@V*C8J-N,V8;8KP#9@=F'V+'8L]BJ(-BOV*?8K]JOV*?9AMF'
MV*?B@(P`V8'9A]BQV+/8JB#8N=F&V*?9B-N,V88@V+'8I]F'V8;9A=BG`-F!
MV8?8L=BSV*H@V*S8K]BGV8C9A`#9@=F'V+'8L]BJ(-BBV+'8M-N,V8@`V8'9
MA]BQV+/8JB#8L=BGV8?9AMF%V*<`V8'9A]BQV+/8JB!)9`#9@=F'V+'8L]BJ
M(-F%V*?9A-JI`-F!V8?8L=BSV*H@V;[8L]BJVXP`V8'9A]BQV+/8JB#8N=BV
MV8C;C-F1V*H`V8'9A]BQV+/8JB#8N=BOV84@V+G8MMF(VXS9D=BJ`-F!V8?8
ML=BSV*H@VJG8I]BQV*C8L=BGV88@V8'8N=BGV80@V8;9A=N,XH",V*C8I]BT
MV*\`V*?8K]BHVXS8I]BJ`-BHV*?8L=JIV+'8K]F&+BXN`-BSV*?8N=BJ(-F%
MV*W9A-N,.B``V878K=F$VXS9D=BJ(-F((-BSV*?8N=BJ`-F%V8C9@MBYVXS8
MJ@#9B-BQV8C8KP#8KMBQV8C8K`#9B-BQV8C8KP#9B-BXV*?;C-F!(-F(V+'9
MB-BO`-F(V+'9B-BO(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR#8LMN,V+'8IR#9
MAMBGV84@VJG8I]BQV*C8L2#9B"#;C-BG(-BGV+/9A2#8L=F%V+(@V8C8I]BQ
MV*\@V+38K]F'(-BGV+38JMBHV*?9AR#8J-F(V*\@`-F(V+'9B-BO(-F&V*?9
MA=F(V8'9D=F"(-BHV8C8KRX`V878JMF&(-BHV839AMBO`-BYV+39@@#9OMBG
MVXS;C-F&`-BMV+'9B-F!(-JIV8C:AMJI(-N,V8C9AMBGV8;;C`#8K=BQV8C9
M@2#:J=F(VH;:J2#9A-BGV*K;C-F&`-BGV+G8K]BGV*\@VJG9B-J&VJD@VXS9
MB-F&V*?9AMN,`$U-`-F^VXS8NMBGV84@V+'9B-BR`-F^VXS9B-BSV*H@35,M
M5$Y%1B#8M-BGV879A"#9A]N,VH8@V*_8I]BOV8?B@(S8I^*`C-N,VXP@V8;;
MC-BSV*H`35-'`-BLV*?8K]F(`-F&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:
MJ=N,`-BSV+'9OMBQV+/8JB#9AMBGV879AP#8L]BGV*[8JMF&(-F^VXS9B-F&
MV*\N+BX`V878K]N,V+';C-BJ(-F((-BJV+G;C-N,V88@V+'9AMJO(-BOV+/8
MJMF'XH",V8?8I]N,VXP@VJG9AR#8M-F%V*<@V879B-BGV+'8KR#8L=BG(-BH
MV*<@V*+9AMF'V*<@V8;8I]F%XH",VJ_8L-BGV+';C"#9A=N,XH",VJG9AMN,
MV*\`36%P,C0@;6%P`$UA<%%U97-T(&UA<`#9A=BGV+'8LP#8K=BGV+3;C-F'
M`-BYV838I]F%V*H@VJ_8L-BGV+';C"#8J-BG(-F^V+':AMF%(-F%V+38I]F'
MV*_9AR#8M-BOV8<O(-F%V+38I]F'V*_9AR#9AMBTV*_9AP`@V+G9A-BGV878
MJB#:K]BPV*?8L=N,(-BHV*<@V+G9A-BGV*;9A2#8K]N,VJ_8L2`HV878I]F&
MV8;8KR#9A=F'V84OV;[8I]BSV*X@V*_8I]BOV8<@V+38K]F'*0#9@=N,V838
MK^*`C-F'V*?;C"#8I]F&V+?8J-BGV8(`V*C;C-BTVXS9AMF'(-BGV+G8JMBH
MV*?8L2#9A=BLV*?8L@#8JMBNV+?;C"#8I]BR(-BHVXS8M-N,V8;9AR#9@MBS
MV878JMF'V*?;C"#9OMN,V+K8I]F%`-BHVXS8M-N,V8;9AR#8K]F%V*<@V*_8
ML2#;LMNT(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z(`#8J-N,V+3;C-F&V8<@V*_9
MA=BG(-BOV+$@V[8@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@`-BHVXS8M-N,V8;9
MAR#8M]F(V80`V87;C`#9OMBRV+3:J=N,`-BGV+G8MMBGV*$`V878KR#:K]BR
MVXS9AMJOV*?9AMN,.@#8I]BOV+K8I]F%(-BSV839B-F$V8?8IP#9OMN,V+K8
MI]F%`-F^VXS8NMBGV84@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV*?8LMBH
MVXS9AMN,(-BTV*\@V*?9A=BG(-JOV8C8I]F'VXP@V*?9A=BVV*?8H2#:J=F&
MV8;8K]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*C8I]BRV*C;C-F&VXP@V+39
MB-BO`-F^VXS8NMBGV84@V879AMF"V+;;C"#8M-BO`-F&V8C8N2#9OMN,V+K8
MI]F%`-BBV*@@V8@@V8?9B-BGVXP@365T87(`V*C9A-F(VJD@365T87(@V8+8
MI]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8J@#8J-F$V8C:J2!-971A<B#9@MBG
MV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ+B#8K-BRV*;;C-BGV*H@V*C8L=BG
MVXP@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8J]BHV*H@V+38K]F'(-BG
MV+/8J@#8L=F(V+0`V*?9AMBOV*?8LMF'XH",V*?;C`#9B-BSV+<`V8;9B-BY
M($UI;64`(-JIV87;C-F&V8<@V*_9A=BGVXP@V[+;M"#8L]BGV+G8JB#:K]BP
MV+38JMF'.B``(-JIV87;C-F&V8<@V*_9A=BGVXP@V[8@V+/8I]BYV*H@VJ_8
ML-BTV*K9ASH@`-BBVXS9AMF'`-F%V*K9@=BQV8+9AP#9OMN,VJG8L=BHV8;8
MK]N,(-F%V8C8K-F(V*\@V8;;C-BSV*HN(-BTV878IR#8I]JOV+$@V87;C.*`
MC-BNV8C8I]F'VXS8KR#8I]BR(-BGVXS9AB#8J-BQV8;8I]F%V8?9E"#:J=BG
MV+'8J-BQV*_;C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KR#8J-BGVXS8KR#8
MHMF&V+'8IR#8JMF(V83;C-BO(-JIV8;;C-BO`-BGV+(@V*C;C-F&(-BQV8'8
MJMF&($E$(-F^VXS8NMBGV84`V*?8LB#8J-N,V88@V+'9@=BJV88@240@V8;8
MM-BSV*H@`-BOV8C8M-F&V*C9AP#9OMBSV*H@V+/9A-F(V83;C`#9A=BYV*K8
MK]F$(-JIV+'8K]F&`-BJV*?8L=N,V*X@V*K8NMN,VXS8L2#;C-BGV8'8JMF'
M`-BJV+K;C-N,V+$@55),`-F%V*?9AR#9B"#8L]BGV80`V878I]F'V*?9AMF'
M`-F!V*?8LMF'V*?;C"#9A=BGV8<`V*C;C-BTV*K8L2#8M=BGV8$`V*C;C-BT
MV*K8L2#8I]BHV+';C`#8J-N,V+38JMBQ(-BBV8'8JMBGV*C;C`#8I]F&V*K9
M@MBGV80@V*C9AR#9OMBGVXS;C-F&`-BGV8;8JMF"V*?9A"#8J-F'(-BHV*?9
MA-BG`-BGV8;8JMF"V*?9A"#8J-F'(-BQV*?8L]BJ`-BGV8;8JMF"V*?9A"#8
MJ-F'(-BHV*?9A-BG`-BGV8;8JMF"V*?9A"#8J-F'(-F^V*?;C-N,V88`V*?9
MAMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<`V8'9A]BQV+/8JB#9OMBGVXS;C-F&
MXH",V;[8L2#:AMF&V*\@V+/8M]BMVXP`VH;9AMBO(-BGV8;8JMBNV*?8J-N,
M`-BMV+/8I]BH(-F%V88`V*?8M]F$V*?8N=BGV*H@V*W8L]BGV*@@V879A@#8
MK]BQVJ_8I]F'(-F%V88`V*S8I]F&V878I]N,VXP@V*_8L=JOV*?9AR#9A=F&
M`-F&V8?8C"#9A=F&(-F%V8C8I]F!V8(@V8;;C-BSV*K9A0#9AMBGV84`55),
M(-F^V*?;C-F'($YE='-C87!E`$YE='-C87!E($-!(%)E=F]C871I;VX@55),
M`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`
M3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`V*K9B-BVVXS8K2#:K]F(V*?9A]N,
M($YE='-C87!E`-F&V8C8N2#:K]F(V*?9A]N,($YE='-C87!E`-BTV*C:J=F'
M`-F'V+':K]BR`-BOV+/8JMF'(-BLV*_;C-BO`-F%V*?9AR#9AMF(`-F&V*?9
MA2#:J=BGV+'8J-BQVXP@V*S8K]N,V*\@*-BGV*[8JMN,V*?8L=N,*0#8I]BS
MV84@V+'9A=BR(-BLV*_;C-BO`-BGV+/9A2#8L=F%V+(@V838NMF((-BNV8C8
MI]F'V*\@V+38KR#8K]BQ("5X(`#8I]BSV84@V+'9A=BRV8?8I]N,(-BLV*_;
MC-BO(-BJV+?8I]BHV8(@V8;8K]BGV+'8KP#9OMF&V*S8L=F'(-BLV*_;C-BO
M("C8KMBGV83;C"D`V*?8KMBHV*?8L0#:K]BQV8C9A^*`C-F'V*?;C"#8KMBH
MV+';C`#8J-BYV*_;C`#:K]BRVXS9AMF'XH",V8?8I]N,(-BHV+G8K]N,`-BT
MV*@`V8;9AP#8K]BGV*_9AR#9OMN,VJG8L=BHV8;8K]N,(-BOV+$@V*_8L]BJ
MV+'8L]N,(-BHV+'8I]N,(-F&V+38I]F&(-BOV*?8K]F&(-BJV8'8I]F(V*K9
MA]BG(-F(V*S9B-BO(-F&V*_8I]BQV*\`25-/(-F&VXS8L]BJ(-BGV+/8JMBQ
MV*?8JMJ8VXP@V*_8L2#8K]BSV*K8L=BSVXP@V*C8L=BGVXP@V+/8I]BNV*K9
MAB#8JMBUV8C;C-BQ(`#8I]F$VJ_9B-N,(-BOV+/8JMF'XH",V*?;C-N,(-F&
MVXS8L]BJ`-BHV838I]JIVXP@V*_8L2#9A=F(V8+8N=N,V*H@V*_8L=BNV8C8
MI]BSV*H@V+38K]F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V8?;C-J&(-F&V*?9
MA2#8JMF"V8C;C-F%VXP@V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M($U#04P@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8K]F(V88@V*K8
MNMN,VXS8L0#9A]N,VH8@V878K-F(V+(@V8'8L=BYVXSB@(S8I]N,(-F&V87;
MC.*`C-BJV8C8I]F&V*\@V*C9AR#8I]N,V88@V878K-F(V+(@V*?8MMBGV8'9
MAR#8M-F(V*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBO
MVXP@V*C8L=BGVXP@)7,@V878M-BNV+4@V8;8M-BO`-F'VXS:AB#8I]BWV838
MI]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,($944"!61E,@V878
MM-BNV+4@V8;8M-BO`-F'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BH
MV8;8K]N,(-BHV+'8I]N,(%-13"!61E,@V878M-BNV+4@V8;8M-BO`-F'VXS:
MAB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,(%-1
M3"U&:6QE(%9&4R#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BGV+G8JMBHV*?8
ML=N,(-BHV*?9@MN,(-F&V878I]F&V*\`V8?;C-J&(-F%V8+8M=BOVXP@V8'8
ML=BGV8?9A2#9AMBTV*\`V8?;C-J&(-F^V+'9B-F&V*_9A^*`C-BGVXS;C"#8
MI]BQV+/8I]F$(-F&V+38KP#9A]N,VH8@V*+;C-JIV8C9AMN,XH",(-F^VXS8
MK]BG(-F&V+38KP#9A]N,VH8@V87:J=BGV8;;C"#8JMF&V+C;C-F%(-F&V+38
MK]F'`-F'VXS:AB#9OMN,V+K8I]F%VXP@V8'8L=BGV8?9A2#9AMBTV*\`V8?;
MC-J&(-F&V*?9A=N,(-F%V+38KMBU(-F&V+38KP#9A]N,VH8@V+39A=BGV+'9
MA^*`C-BGXH",VXS;C"#9A=BTV*[8M2#9AMBTV*\`V*+;C-F&V*_9AR#9AMBG
MV878M]BHV8C8N=N,(-F&VXS8L]BJ`-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9
MB-N,V9'8JB!(5%10(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38
MK]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@24U!
M4"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`
MV*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($ME<F)E<F]S(-BGV+/9
MA2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;
MC"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V8C8L=F(V*\@V*?8L]F%(-BQV878
MLMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8I]N,(-BJV+78
MK]N,V8(@V8?9B-N,V9'8JB!005-35T0@V*?8L]F%(-BQV878LMN,(-F!V+'8
MI]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9
MB-N,V9'8JB!334(@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BO
MV8<@V*?8L]BJ`-BJV8+8I]BVV*?;C"#8J]BHV*H@V8;8I]F%VXP@V*_8L2#8
MI]F&V*K8N-BGV+$@V*K8H]N,VXS8KR#9AMN,V+/8J@#8J-BOV8C9AB#9@MF(
MV*?8N=BO`-F'VXS:AB#8K-BOV*?:J=F&V8;8K]F'XH",V*?B@(S;C-N,(-F%
MV+38KMBU(-F&V+38KP#8J-BOV8C9AB#8L]F%V*H`V+38I]BNV8<@V879B-F"
MV*K;C"#8J-BQV*?;C"#:J=BGV+39AR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F'
MVXS:AB#9AMBGV84@VJG8I]BQV*C8L=N,(-F((-N,V*<@V*?8L]F%(-BQV878
MLMN,(-BGV+'8L]BGV80@V8;8M-BO`-F'VXS:AB#8K]BGV*_9AR!834P@V878
MN=BJV*C8L=N,(-BHV*?8LMJOV+'8K]BGV8;8K]F'(-F&V+38K]F'(-BGV+/8
MJ@#8J-BOV8C9AB#9A=F"V*_8I]BQ`-F&V+/8KMF'XH",(-BOV+$@V;[;C-JI
MV+'8J-F&V*_;C"#8I]BUV83;C"#9OMN,V*_8IR#9AMBTV*\N(-F^VXS:J=BQ
MV*C9AMBOVXP@V+'8IR#8K]F(V*C8I]BQV8<@V*K9B-F$VXS8KR#:J=F&VXS8
MKP#9AMBSV*[9A^*`C"#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@V+39A=BG(-F^
MVXS8K]BG(-F&V+38K]F'(-BGV+/8JBX@V;[;C-JIV+'8J-F&V*_;C"#8L=BG
M(-BOV8C8J-BGV+'9AR#8JMF(V83;C-BO(-JIV8;;C-BO`-F'VXS:AN*`C-JI
MV*_8I]F%`-F'VXS:AN*`C-JIV*_8I]F%("C8MMF%V8;;C"#8I]BSV*K9@=BG
MV*_9AR#:J=F&VXS8KRD`3F]R9&EC("A)4T\M.#@U.2TQ,"D`V8;;C-F%(-JI
MV+'9AR#8M-F%V*?9A-N,`-F&V8<@V*C8N=BO`-F&V8<@V8+8J-F$`-N,VJD@
MV+38I]BNV8<@V8;;C-BSV*H`V;[;C-BGV*_9A^*`C-BSV*?8LMN,(-F&V+38
MK]F'`-BJV8;8N-N,V84@V8;8M-BOV8<`V;[8M-BJVXS8J-BGV8;;C"#9AMBT
MV*_9AP#;C-BGV*_8K]BGV+38JMF'V*<`VH;;C-BRVXP@V*C8L=BGVXP@V878
ML=F(V+$@V8;;C-BSV*K8C"#8J-F'(-BYV8+8J"#8J-BQVJ_8L=BO`-F&V8C8
MI]F%V*C8L0#8N=BOV*\`V*K8N=BOV*?8KR#9AMF(VXS8L]F'XH",V8?8IP#8
MJMBYV*_8I]BO(-BSV*K9B-F&V8?8IP#8JMBYV*_8I]BO(-BSV+?8L=F'V*<`
MV*?8N=BOV*?8KR#8J-BQV*?;C"#8J-BQV8C8LMBQV+/8I]F&VXP@V8'9A]BQ
MV+/8JB#8JMF(V++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8;8KP#8JMBCVXS;
MC-BO`-BTVXS8H0#8I]N,V*S8I]BO(-JIV8;9AMBOV8<@V+3;C-BA`-F'V+38
MJMBGVXS;C`#8I]JIV*K8J-BQ`-F!VXS9A-BJV+$@V*C;C.*`C-BMV+'9A=BJ
MVXP`V*_9@=BJV+$@VJG8I]BQ`-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\@V8@@
MV*?8L]F%(-BQV878LB#9@=BYV83;C"#8J-BGVXS8KR#9A=BJV8'8I]F(V*H@
MV*C8I]BTV8;8KP#8I]BSV84@V+'9A=BR(-F"V*_;C-F%VXP`V*?8L]F%(-BQ
MV878LB`@V8+8K]N,V87;C"#9AMBGV*_8L=BSV*H@V*?8L]BJ`-BJV8;9A]BG
M(-JIV*?8L=BSV*?8LMF'V*?;C"!)34%0V;[9B-BTV8?B@(S9A]BGVXP@V878
MM-BJV+':J2#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V87;C.*`C-JIV8;9AMBO
M(`#9@=F"V+<@V*+;C-F&V*_9AR#9AMBGV878M]BHV8C8N0#8JMF&V8?8IR#;
MC-JI(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJG;C"#9A=BL
MV*?8LB#8I]BSV*H`V*K9AMF'V*<@V878I]F$VJD@VXS8IR#8L]BQV;[8L=BS
MV*H@V+/8I]F%V*?9AMF'(-F%VXSB@(S8JMF(V*?9AMBO(-F%V*?9A-JIVXS8
MJB#;C-BG(-F%V*S9B-BRV8?8I]N,(-F%V*?9A-JI(-BQV*<@V*C8L=BGVXP@
MVXS:J2#8I]BTV*K8L=BGVJD@V*K8NMN,VXS8L2#8K]F'V*\`V*_8L2#;C-JI
M(-F^V8;8K-BQV8<@V*S8K]N,V*\@V*C8I]BR(-BTV8C8KP#8I]N,V88@V;[;
MC-F(V8;8KR#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KR#8J-BGV+(@
MV+39B-BO`-BSVXS8L]BJV84@V+G8I]F%V80`VJ_8LMN,V8;9AR8C>#(P,&,[
MV8?8IP#:K]BRVXS9AMF'XH",V8?8I]N,("5S`-F$VXS8L]BJ(-F%V+'8JMBH
M(-BTV*_9AP#8L]BGV++9A=BGV88`V8C8I]BMV*\@V+/8I]BRV878I]F&VXP`
MV+/8I]BRV878I]F&V*_9A]N,`-BGV83:K]F(VXP@V*?8M=F$VXP@V*C8L=F&
MV*?9A=F'V90@VJG8I]BQV*C8L=BOVXP`V*?9A-JOV8C9A]BGVXP@V*?8M=F$
MVXP@V*_8L2`E<SH`V*_;C-JOV+$`V*?8M]F$V*?8N=BGV*H@V*_;C-JOV+$`
MV878K-F(V++B@(S9A]BGVXP@V878I]F$VJD`V*K8M=BOVXS9@B#9A]F(VXS9
MD=BJ(%!!32#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*H`V*?9A=BV
MV*?8H>*`C"#8K]N,V*S;C-BJV*?9A-N,(%!'4`#9OMN,V+K8I]F%(-BQV878
MLMBHV8;8K]N,(-BTV*_9A]F4(%!'4``@VJG9A-N,V*\@V+G9A=F(V87;C"!0
M1U``V;[;C-BZV*?9A2#8L=F%V++8J-F&V*_;C"#8M-BOV8<OV*?9A=BVV*?8
MH2#8M-BOV8<@4$=0`-JIV*\@4$A0`-F^V8C8L]BJV8<@4$A0`-BHV*?8L=F&
MV*_:K]N,(-BSV*C:J2#8N=BUV+':K]BGV8?;C`#8L=JOV*C8I]BQ(-BYV+78
ML=JOV*?9A]N,`-BHV+'9@2#8N=BUV+':K]BGV8?;C`#8JMJOV+':KR#8N=BU
MV+':K]BGV8?;C`!4+5-T;W)M<P#8J-BSV+<@4$]325@@V*?8LB#8J-N,V88@
MV+'9@=BJV8<@XH",V*?8L]BJ`-F^V8C8L]BJV8<@4$A0`-F!V*?8M=F$V8?B
M@(S:K]BPV*?8L=N,`-F"V+/9A=BJVXP@V*?8J-BQVXP`V*?8L]F%(-BQV878
MLB``V*?8L]F%(-BQV878LB#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*K8NMN,
MVXS8L2#;C-BGV8'8JBX`V*?8L]F%(-BQV878LB`@V8;8I]BOV+'8L]BJ(-BG
MV+/8J@#8I]BSV84@V+'9A=BR("#8J-F'(-BJV+78K]N,V8(@V8?9B-N,V9'8
MJB!2041)55,@V8;;C-BGV+(@V*_8I]BQV*\`V*?8L]F%(-BQV878LB`@V*C8
MIR#8JMBCVXS;C-BO`-BGV+/9A2#8L=F%V+(@.@#8I]BSV84@V+'9A=BR(#H@
M`-BGV+/9A2#8L=F%V++B@(S9A]BG(-BHV*?;C-BO(-F%V8;8M]BHV8(@V*C8
MI]BTV8;8KP#:AMBSV*C8I]F&V*_9A@#:AMBSV*C8I]F&V*_9AB#8I]BR(-BJ
MV*[8JMF'(-BQV+/9A0#9A=BSVXS8L0#8J]BHV*H@V8;8I]F%V8?8I]N,(-F&
MV*?9A=BYV839B-F%`-F%V+'8K]F%`-BOV+'8M=BO`-BGV*S8L=BGVXP@V+G9
MA=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,`-BBVXS8IR#8N=F%V83;C-BGV*H@
MV8;:K]F'V*_8I]BQVXP@V*_8L2#9A-BMV+C9AR#9B-BQV8C8KR#8I]BLV+'8
MIR#8M-F(V*_8GP#9A=BLV8C8L@#9A=BLV8C8LB`@(B5S(B#8K=BPV8$@V8;8
MM-BO`-F%V*S9B-BRV8?8IP#8L]BQV;[8L=BSV*K;C"#9A=BLV8C8LMF'V*<`
MV*?8M]F$V*?8N=BGV*H@V+38KMBUVXP`V*W;C-F(V*?9AMBGV*H@V*[8I]F&
MVJ_;C`#8JMF$V8'9A@#8N=JIV+/9A]BG`-F^VXS:J=BSV839A]BG`-F$V+?9
M@=BGV8L@V*_8I]BNV80@VH;9AMBO(-BSV839B-F$(-JIV83;C-JI(-JIV8;;
MC-BO`-F$V+?9@=BGV8L@V*K8H]N,VXS8KR#:J=F&VXS8KR#:J=F'(-F%VXSB
M@(S8KMF(V*?9A]N,V*\@V*?;C-F&(-BYV8;8M=BQ(-BQV*<@V*W8L-F!(-JI
MV8;;C-BO.@#9A-BWV8'8I]F+(-BJV*/;C-N,V*\@VJG9AMN,V*\@VJG9AR#9
MA=N,XH",V*[9B-BGV8?;C-BO(-F^VXS9B-F&V*\@V*?;C-F&(-BYV8;8M=BQ
MV8?8IR#8L=BG(-F"V+?8N2#:J=F&VXS8KP#9A-BWV8'8I]F+(-N,VJD@V878
MI]F'(-F((-N,VJD@V+/8I]F$(-F(V*?8L=BO(-JIV8;;C-BO+@#9A-BWV8'8
MI]F+(-F&V*?9A=N,(-BHV+'8I]N,(-BOV+/8JMF'(-BLV*_;C-BO(-F(V*?8
ML=BO(-JIV8;;C-BO.@#9A-BWV8'8I]F+(-BBV*_8L=BS($E0(-F%V+G8JMBH
MV+';C"#9B-BGV+'8KR#:J=F&VXS8KP#9A-BWV8'8I]F+(-N,VJD@V*K8I]BQ
MVXS8KB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BOV(P@V*K8N=BOV*?8
MKR#8L=F(V++9A]BG(-BOV+$@V878I]F'(-BQV*<@VJG9AMBJV+'9A"#:J=F&
MVXS8KP#9A-BWV8'8I]F+(-N,VJD@V++9A=BGV88@V878N=BJV*C8L2#9B-BG
MV+'8KR#:J=F&VXS8KP#9A-BWV8'8I]F+(-BNV838I]BUV8?B@(S8I^*`C-N,
MVXP@V*?8LB#9A=BTVJG9A"#8L=BG(-BHV8;9B-N,V+/;C-BO`-F$V+?9@=BG
MV8L@V8;8I]F%(-JIV*?8L=BHV+$@V8@@V*?8L]F%(-BQV878LB`@V*[9B-BO
M(-BQV*<@V*+9A=BGV*_9AR#:J=F&VXS8KP#9A-BWV8'8I]F+(-F%V*K9AB#8
MLMN,V+$@V+'8IR#8J-BNV8C8I]F&VXS8KRX@V+39A=BG(-BHV+'8I]N,(-BG
MV+/8JMF!V*?8K]F'(-BGV+(@V+/8I]F%V*?9AMF'(-BHV*?;C-BO(-BTV+'9
MB-BW(-BQV*<@V8+8J-F(V80@VJG9AMN,V*\`V838M]F!V*?9BR#9AMBGV84@
MV*_8L]BJV8<@V*S8K]N,V*\@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KSH`V+/;
MC-BGV+/8JMF'V*<`V*+8L=BGV*$`V878K=F$(-F"V+'8I]BQVJ_8L=F!V*K9
MAB#8I]N,V88@V*K8M=F(VXS8L0#9A=BMV80@V8+8L=BGV+':K]BQV8'8JMF&
M(-BGVXS9AB#8K-BOV8C9A`#9OMBSV*H@V*C9AR#8I]N,V88@V;[9B-BTV8<`
MV*_8L=BUV*\@V+'8M]F(V*C8JB#8K]BQ("5S(-BSV*?8N=BJ(-F"V*C9A#H`
M4')E9G-?;&1A<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($Q$05`@V;[;
MC-BOV*<@V8;8M-BO`%!R969S7W-E<W-I;VXZ(-BHV+/8MR#9A=F(V+'8KR#9
MAMN,V*?8LB!S97-S:6]N(-F^VXS8K]BG(-F&V+38KP#9@=BTV*?8L0#9@=BT
MV*?8L2#8K]BQ(-BSV+?8K2#8K]BQVXS8ISH@`-F!V+38I]BQ.B``V;[;C-BT
MXH",V8;9A=BGVXS8M`#9OMN,V+3B@(S9AMF%V*?;C-BT(-BJV+79B-N,V+$@
MV*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@`-JOV++;C-F&V8?B@(S9
MA]BGVXP@V8+8J-F$VXP`VH;8I]F^(-BSV8;8KP#:J=F$VXS8KR#8M-BNV+7;
MC`#9A=BTVJG9A`#8JMF(V+;;C-BM(-F%V+3:J=F$`-F^V+'9B-J8V8?B@(S9
MA]BG`-F%V*K9AB#8I]BYV838I]F&`-JIV83;C-BO(-BYV879B-F%VXP`V*?9
MA-JOV8C8L=N,V*K9A2#:J=F$VXS8KR#8N=F%V8C9A=N,`-BLV8'8JB#:J=F$
MVXS8KR#8N=F%V8C9A=N,+]BNV+79B-BUVXP@V*C8IR#9A=F(V8'9D=F"VXS9
MD=BJ(-BJV8C9A-N,V*\@V8;8M-BO`-F^V+'8L^*`C-F(V*S9B`#8L]F'V87;
MC-F'`"#:J=F$VXS8KR#8N=F%V8C9A=N,(%)302`H)60@V*C;C-BJ*0#8I]F&
MV*K8KMBGV*@@V+'8I]BOVXS9B`#8J-BGV+'8I]F&`-BHV*?8L=BGV88@V++9
MB-BOV8?9AMJOV*?9A0#8J-BGV+'8I]F&(-BOVXS8L=F'V8;:K]BGV84`V*C8
MI]BQV*?9AB#9B"#8L=JOV*C8I]BQ`-BHV*?8L=BGV88@V8@@V*C8L=F!`-BH
MV*?8L=BGV88@V*C9AR#8J-BQV8$`V+?8I]F$V+D@V*K8M=BGV*_9@=N,`-F&
MV+/8J-BJ`-BNV8C8I]F&V*_9A@#8KMF(V*?9AMBOV88@V;[;C-BZV*?9A=F'
MV*<@`-F(V*?9@MBYV*?9DB`E<R#8K=BPV8$@V+39B-BOV)\@V*?;C-F&(-BY
MV879A"#9@MBGV*C9A"#9B-BGVJ_8L=BO(-F&VXS8L]BJ`-F(V*?9@MBYV*?9
MBR#8K]BGV*_9A]F4(-JIV*?8L=BHV+';C"#8J-BQV*?;C"#:J=BGV+'8J-BQ
M("5S(-BMV+#9@2#8M-F(V*_8GR#8I]N,V88@V+G9A=F$(-F"V*?8J-F$(-F(
MV*?:K]BQV*\@V8;;C-BSV*H`V*?9AMBLV*?9A2#8HMBNV+';C-F&(-BYV879
MA"#8M-F%V*<@V*?8LB#9AMF(`-BHV*?8LMBBV8C8L=N,(-BYV8;8I]BUV+$@
MVJ_8LMN,V8;:K]BGV88@V*_;C-F&V*?9A=N,VJG;C#H`V*C8I]BRV*+9B-BQ
MVXP@V8;9A=BGVXP@V*_8L=JOV*?9ASH`V878L=F(V+':K]BQ(-BQV*?8J-BW
MV8?B@(S8I^*`C-N,VXP`V*K9B-BVVXS8K=BGV*H`VJG8I]BQV+/8I]BRV8?8
MI]N,(-BQV*?9A^*`C-BOV8C8L0!54DP`V*W8L-F!`-BMV+#9@2#8J-F$V8C:
MJ0#8K=BPV8$@V+/8JMF(V88`V*W8L-F!(-F"V*?9A-BH(-BHV8;8K]N,`-BM
MV+#9@2#8LMF(V*P`V*W8L-F!(-BOV+/8JB#B@(S9AMF(VXS8L]F'V*?;C"#8
MK=F!V+@@V+38K]F'(-BOV+$@V+38I]BNV8<@V879B-F"V*H@VJG8I]BQV+/8
MI]BR`-BMV+#9@0#8K=BPV8$@V*?;C-F&(-JOV+'9AR#8I]BR(-BSV8;8KP#8
MK=BPV8$@VJG8I]BQV*C8L0#8K=BPV8$@VJG8I]BQV*C8L3H@)7,`V*K9@MBG
MV+;8IR#9@MBGV*C9A"#9OMBGV+/8KMJOV8C;C-N,(-F&VXS8L]BJ+B#:J=BO
M(-BNV+?8I]N,(-BHV+':K]BQV*_8I]F&V*_9AR#8M-BOV8<Z`-F!VXS9A-BO
MV8?8I]N,(-F%V8C8L=BO(-F&VXS8I]BR`-BHV*?8LMF&V+38I]F&VXP`V*C8
MI]BRV8;8M-BGV8;;C"#8I]BSV84@V+'9A=BR`-BGV+/9A2#8L=F%V+(@V*[9
MB-BO(-BQV*<@V*C8I]BRV8;8M-BGV8;;C"#:J=F&VXS8KP#9AMBJV*?;C-BL
M`-BHV*?8LMJOV+38JB#8J-F'(-JOV++;C-F&V8?B@(S9A]BG`-BJV*?;C-F^
M(-BOV8C8J-BGV+'9AR#8I]BSV84@V+'9A=BR("#8K-BOVXS8KR``VJ_8L=BO
MV8?9A=BGVXS;C`#8J-BGV++:K]BQV*_8I]F&V*_9AB#9OMN,VJG8L=BHV8;8
MK]N,`-JOV++;C-F&V8?B@(S9A]BGVXP@V8C;C-BQV*?;C-BTVJ_8L2#9A=BJ
MV88`V878N=F%V*?9A]BG`-BQV*?8L]BJ`-BSV+'8HMF%V*\@V+'8I]BSV*H`
MV879@MBGV*_;C-BQ(-BQV*?8L]BJ`-BNV+79B-BUVXS8I]BJ(-BSV+?8L2XN
M+@#9AMF"V+0`VH;8L=BNV+0@V[';N-NP(-BOV+'8K-F'`-J&V+'8KMBT(-BH
MV8<@VH;9O@#:AMBQV*[8M"#8J-F'(-BQV*?8L]BJ`-BNV+79B-BUVXS8I]BJ
M(-BSV+?8L0#8KMBUV8C8M=N,V*?8JB#8L]BWV+$`V+/8M]BQV8?8ISH`V8+9
MB-BGV+G8KP#9@MF(V*?8N=BO(-BHVXS9AB#8JMF%V*?9A2#8L]BWV+'9A]BG
M(-F((-BSV*K9B-F&V8?8IR#9AMF%V*?;C-BGV88@V*[9B-BGV8?8KR#8M-BO
M`-F"V8C8I]BYV*\@V8'9@MBW(-BHVXS9AB#8JMF%V*?9A2#8L]BJV8C9AMF'
MV*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38KP#9@MF(V*?8N=BO(-F!
MV8+8MR#8J-N,V88@V*K9A=BGV84@V+/8M]BQV8?8IR#9AMF%V*?;C-BGV88@
MV*[9B-BGV8?8KR#8M-BO`-BGV*S8L=BG`-F^VXS8NMBGV84@V+'9A=BRV*C9
MAMBOVXP@(-BTV*_9A]F4(%,O34E-12``V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M(%-!4TP@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&VXS8L]BJ`-F^VXS8NMBG
MV84@4TU3`-F^V8C8L]BJV8<@4U%,`%-32`#9A=F(V8'9D=F"VXS9D=BJ`-F^
MV8C8L]BJV8<@4U%,`-BTV8;8J-F'`-F'V878I]F&(-J&V*?8L=J&V8C8J"`H
MV*[9B-BOV+0I`-BMV8'8N"#:J=BQV*_9A@#8K=F!V+@@VJG8L=BOV88@)7,`
MV*W9@=BX(-JOV++;C-F&V8?B@(S9A]BG`-F^VXS:J=BQV*C9AMBOVXP@V*K9
MB-F$VXS8KR#8M-BOV8<@V*C8N=F&V8C8I]F&(-BOV+/8JB#B@(S9AMF(VXS8
MLR!02%`@V*_8L2#8M-BGV*[9A]F4(-F%V8C9@MBJ(-JIV*?8L=BSV*?8LB#8
MM-F%V*<@V*W9@=BX(-BTV8C8KP#9OMN,VJG8L=BHV8;8K]N,("5S(-BMV8'8
MN"#8M-BO`-BYV839A0#8K-BSV*KB@(S9B-BLV8@`V*S9B-N,V+3:K]BQV8?8
MIP#8I]F&V*K8KMBGV*@@V;[8L=F(V8;8K]F'XH",V8?8IP#8I]F&V*K8KMBG
MV*@@VXS:J2#8JMBGV+';C-BN`-BGV8;8JMBNV*?8J"#;C-JI(-JOV+'9B-F'
M(-BHV+'8I]N,(-BGV+;8I]F!V8<@VJG8L=BOV88`V*?9AMBJV*[8I]BH(-N,
MVJD@V878I]F$VJD@V*S8K]N,V*\`V*?9AMBJV*[8I]BH(-N,VJD@VJG8I]BQ
MV+/8I]BR`-BGV8;8JMBNV*?8J"#;C-JI(-JIV*?8L=BHV+$@V*C8L=BGVXP@
MV*?8MMBGV8'9AR#:J=BQV*_9A@#8I]F&V*K8KMBGV*@@V8?9A=F'`-BGV8;8
MJMBNV*?8J"#8JMF%V*?9A2#9A=BDV839@=F'XH",V8?8I]N,(-BJV*?8L=N,
MV*X`V*?9AMBJV*[8I]BH(-N,VJD@V+38I@#8I]F&V*K8KMBGV*@@V8?;C-J&
MXH",VJG8K]BGV84`V8;9B-N,V+/9A^*`C-F'V*?;C-N,(-JIV8<@V838I]BR
MV84@V*_8I]BQVXS8KR#8L=BG(-BGV+(@V*S8N=BHV8<@V++;C-BQ(-BGV8;8
MJMBNV*?8J"#:J=F&VXS8KRX@V+/9OMBS(-BTV878IR#9A=N,XH",V*K9B-BG
MV8;;C-BO(-BGV+(@V*+9AMF'V*<@V*_8L2#9A=F&V+?9@MF'(-F%V*K9AB#9
MAMBSV*[9A^*`C-BHV+'8K]BGV+';C"#:J=BQV*_9AR#9B"#8K]BQ(-F%V*W9
MA"#8K]N,VJ_8L2#8J-J&V+/8J-BGV8;;C-BO`-BGV8;8JMBNV*?8J"#9A=BM
MV*_9B-BOV8<@V*K8I]BQVXS8KCH`V*?9AMBJV*[8I]BH(-F"V*?9A-BH(-BJ
MV*?8L=N,V*XZ`-BGV8;8JMBNV*?8J"#9A]F(VXS9D=BJVXP@VJG9AR#9A=N,
MXH",V*[9B-BGV8?;C-BO(-BJV+K;C-N,V+$@V*_9A]N,V*\Z`-BGV8;8JMBN
MV*?8J"#9A=BMV*_9B-BOV8?9E"#8LMF%V*?9ACH`V*?9AMBJV*[8I]BH(-F"
MV*?9A-BH(-BRV878I]F&.@#8I]F&V*K8KMBGV*@@V*_9B"#9@=N,V838KR#9
MA=F&V+?8J-F"`-BGV8;8JMBNV*?8J"#8M]BQV*T@V+'9AMJO(-BTV878IP#8
MI]F&V*K8KMBGV*@@V++8J-BGV88@V879B-BQV*\@V8;8N-BQ(-BTV878ISH`
MV*?8L=BSV*?9A"#:K]BRV*?8L=BT`-BGV+'8L]BGV80@4TU3`-BMV+/:K]BQ
M.B``V+/9OMBJV*?9A=BHV+$`V*?8N=BOV*?8KR#8JMBQV*K;C-BHVXP`240@
MV8;8M-BSV*H@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ`-BJV8;8N-N,V84`
MV*K9AMBXVXS9A2#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;C"#8I]BLV*?8
MLMF'(-BOV*?8K]F&(-BHV8<@V+39A=BG(-BHV+'8I]N,(-BHV*?8LMF&V+38
MI]F&VXP@V*?8L]F%(-BQV878LB#8J-F'(-F'V8;:K]BGV84@V8'8L=BGV879
MB-BTVXP@V*+9AB``V*K9AMBXVXS9A2#:J=BGV+'8L]BGV++9A]BGVXP@V+'8
MI]F'(-BOV8C8L=N,(-JIV8<@V+39A=BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@
MV*?8LB#8K]BQVJ_8I]F'(-BNV8C8KR#8J-F'(-BBV88@V*_8L]BJV+'8L]N,
M(-BOV*?8M-BJV8<@V*C8I]BTVXS8KP#8I]F&V*K8KMBGV*@@V++8J-BGV88@
MV879B-BQV*\@V8;8N-BQV(P@V+/8I]BYV*H@V8@@VJ_8LMN,V8;9A^*`C-F'
MV*?;C"#8JMBGV+';C-BN`-BGV8;8JMBNV*?8J"#8J-BQV8;8I]F%V8<@V++9
MA=BGV88@V+38L=F(V+G8C"#8M]BQV*T@V+'9AMJOV(P@V*C8I]BRV*+9B-BQ
MVXP@V+79@=BMV8<@V8@@V*C9@MN,V8<@VJ_8LMN,V8;9A^*`C-F'V*?;C"#9
MAMF%V*?;C-BT`-BQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,`-BOV+/8JB#B
M@(S9AMF(VXS8LR`@V*C8L=F(V++8L=BSV*?9AMN,(-BQV*?9A^*`C-BGV8;8
MK]BGV++;C"#8K]BQ(-BOV+/8JMBQV+,@V*?8L]BJ`-J&V8;8K]N,V88@V879
MB-F"V+G;C-F1V*H@V*C8IR#9OMBGV+'8I]F%V*K8L2#9A=F%VJG9AB#8I]BS
MV*HZ`-BNV+';C-BO`-BNV838I]BUV8<@VJG9B-BJV*?9AP#8HMN,V*<@VJG9
MA-N,V*_9A]BGVXP@V*_8L]BJV+'8L]N,(-BHV*?;C-BO(-BHV+'8I]N,(-BH
MVXS8M-BJV+$@V;[;C-F(V8;8K]F'V*<@V*K8N=BQVXS9@2#8M-F(V8;8K]B?
M`-F&V878I]N,V+0`(-F&V878I]N,V+0@V*K9@=BGV8C8JMF'V*?;C"#9A=N,
MV*?9AB#9OMN,VJG8L=BHV8;8K]N,(-BMV8'8N"#8M-BOV8<@V8'8N=F$VXP@
MV8@@V*K9B-F$VXS8KR#8M-BOV8<@V*S8K]N,V*\`V*+;C-BG(-BRV878I]F&
M(-BBV*[8L=N,V88@V8C8L=F(V*\@V*C9AR#9A]F&VJ_8I]F%(-F(V+'9B-BO
M(-F&V+38I]F&(-BOV*?8K]F'(-BTV8C8K]B?`-F&V878I]N,V+0@VJ_8LMN,
MV8;9A^*`C-F'V*<@V*C8L=BGVXP@V8;:K]F'V*_8I]BQVXP@V*?8M=F$`-BG
MV8;8JMBNV*?8J"#9@]F&V8;8K]F'(-F&V878I]N,V+0`V*+;C-BG(-F%VXS9
MA-F'(-JOV++;C-F&VJ_8I]F&(-BYV879A-N,V*?8JB#8K-BOV8C9A.*`C"#9
MAMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8K]B?`-BBVXS8IR#:K]BRVXS9AMJO
MV*?9AB`E<R#8L]F%V*H@V+'8I]BSV*H@V8;8M-BGV88@V*_8I]BOV8<@V+39
MB-BOV)\`V8;9A=BGVXS8M"#:K]F!V*KB@(S9B-JOV8C;C"#8KMBUV8C8M=N,
MV*?8JB#8L]F$V8C9A"#8K-BOV8C9A`#9AMF%V*?;C-BT(-JOV8'8JMJOV8C;
MC"#8KMBUV8C8M=N,V*?8JB#8K-BOV8C9A`#9AMF%V*?;C-BT(-JOV8'8JMJO
MV8C;C"#8KMBUV8C8M=N,V*?8JB#8L]BWV+$@V*S8K]F(V80`V8;9A=BGVXS8
MM"#:K]F!V*K:K]F(VXP@V*[8M=F(V+7;C-BGV*H@V*K8M=F(VXS8L0#9AMF%
MV*?;C-BT(-BGV+'8L]BGV80`V*K:K]BQVJ\`V+':K]BHV*?8L2#8LMF(V*_9
MA]F&VJ_8I]F%`-BQVJ_8J-BGV+$@V*_;C-BQV8?9AMJOV*?9A0#8K-F%V+D@
MV+38K]F&`-BLV878N2#8M-BOV88@VXS8IR#8I]F&V*K9@MBGV80@V*C9A-F(
MVJG9A]BGVXP@V878K-BGV8C8L0#8J]BHV*H@V8;8I]F%`-BGV878MMBGV*$`
MV*?9A-JOV8C8L=N,V*K9A2#8I]F%V+;8I]BA`-BGV8;8K]BGV++9AP#8M=BQ
MV8'9AMBXV+$@V*?8LB#9AMJOV8?8K]BGV+';C`#8J-BQV8$`V*K:K]BQVJ\`
MV*K:K]BQVJ\`V+':K]BHV*?8L2#8LMF(V*_9A]F&VJ_8I]F%`-BQVJ_8J-BG
MV+$@V*_;C-BQV8?9AMJOV*?9A0#8N=F%V8(@V*C8L=F!.B``V878N=BGV*_9
MA"#8J-BQV8$@V*_8L2#8HMBH.B``V+38N=BQV8?8IR#9B"#8HMF(V*?8LMF'
MV*<`V*?9AMBJV*[8I]BH(-BLV8?8JB#9A=BQV*K8J"#8L]BGV++;C`#8HMBO
MV+'8LR#8L]BQVH;8M-F%V8<`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`-F&VXS9A2#:J=BQV8<@V*S9AMF(V*C;C`#9@=BGV+79A-F'V90@V*C;C-F&
M(-BSV839B-F$V8?8I]N,(-F%V*S8I]F(V+$`V8'8I]BUV839A]F4(-BHVXS9
MAB#9A=BMV*K9B-BG(-F((-F$V*C9AR#8K]BQ(-BSV839B-F$`-F!V*?8M=F$
MV8?B@(S:K]BPV*?8L0#9@=BGV+79A-F'`-F!V*?8M=F$V8?B@(S:K]BPV*?8
ML=N,(-F((-BOV+'8LMJOV+#8I]BQVXP`V8?8L=BRV8;8I]F%V8<`VJG8I]BQ
MV*?:J=BJV+$@V*[8I]BU(-F(V*?8L=BO(-BTV*\`V*K9@MBSVXS9A2#8L]F$
MV8C9A`#8JMF"V+/;C-F%(-BSV*K9B-F&`-BJV8+8L]N,V84@V+/8M]BQ`-F(
MV+'8LMBTVXP`V*?8L]BJV*?9AMBOV*?8L=BO`-BSV*K8I]BQV8<`V+/8I]F$
M(-BTV+'9B-BY`-F(V+;8N=N,V*H@V*W9B-BRV8?B@(S9A]BG`-F(V+;8N=N,
MV*KB@(P`V8+8I]F$V*@@V+#8KMN,V+'9AR#8L]BGV++;C`#8HMBOV+'8LR#8
MKMN,V*?8J-BGV88`V8'9A]BQV+/8JB#8L=BTV*K9AP#8M-N,V8C9AR!;0U-3
M70#;C-JIV+39AMBHV8<`V+G9AMF(V*?9A@#8I]BQV+/8I]F$`-BRVXS8L=F&
MV8C;C-BS`-F%V8C9@=F1V8+;C-F1V*H`(B5S(B#8J-BG(-F%V8C9@=F1V8+;
MC-F1V*H@V*W8L-F!(-BTV*\`V;[;C-JIV+'8J-F&V*_;C"#8J-BG(-F%V8C9
M@=F1V8+;C-F1V*H@V*C8I]BRVJ_8L=BOV*?9AMBOV8<@V+38KRX@V*C8L=BG
MVXP@V878M-BGV8?8K]F'(-BJV+K;C-N,V+'8I]BJ(-F%V*S8K]BOV*?9DB#8
MHMF&V+'8IR#8J-BGV+$@V8;9A=BGVXS;C-BO`-F^VXS:J=BQV*C9AMBOVXP@
MV;[8M-BJVXS8J-BGV88@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BMV8'8N"#8
MM-BO`-F^V+'9B-F&V*_9AR#9OMBTV*K;C-BHV*?9AB#9OMN,VJG8L=BHV8;8
MK]N,("5S(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=F!V+@@V+38KP`E<R#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V8;9B-BTV*K9AR#8M-BO`-BNV838I]BU
MV8<`V+?9A-F(V+D@V*+9@=BJV*?8J`#8NMBQV8C8J"#8HMF!V*K8I]BH`-BB
MV8'8JMBGV*C;C`#8M]F$V8C8N0#8M]F$V8C8N2_8NMBQV8C8J`#8M]F$V8C8
MN3H@`-BZV+'9B-BH`-BZV+'9B-BH.B``V*C8I]F$V*?9AMF(VXS8LP#9OMBT
MV*K;C-BHV*?9AMN,`-F&V*?9A2#8KMBGV8;9B-BGV*_:K]N,`-BNV+?8I]N,
M(-F&V*W9B-N,(-BOV+$@V879B-BGV+'8KR#8K-BSV*K8K-F(`%0M4W1O<FUS
M`%0M4W1O<FUS`-F^V+'9B-F&V*_9AR!44U8`V*S8K]F(V80`V*[8M=F(V+7;
MC-BGV*H@V*S8K]F(V80`V*[8M=F(V+7;C-BGV*H@V*S8K]F(V80`V8?8K]F!
M.@#9B-BXV*?;C-F!`-BTV878I]BQV8<@V*K9A-F!V88`V*_9A=BGVXP@V+/8
MI]BYV*H@V*?8KMN,V+$Z(`#8K]BQV*S9AR#8K=BQV*?8L=BJ`-BOV+'8K-F'
M(-BMV+'8I]BQV*HZ(`#8I]F$VJ_9B-N,(-BSV+'9OMBQV+/8JMN,`-F%V*K9
MA@#9@=F"V+<@V878JMF&`-BJV+'8I]BR(-F%V*K9A@#8J-BGV838I]N,(-F%
MV*K9A@#9OMF&V*S8M-F&V*C9AP!4:&%I("A425,M-C(P*0#8I]BR(-BTV878
MIR#8J-F'(-BNV*?8M]BQ(-BGV+/8JMF!V*?8K]F'(-BGV+(@V+/8I]F%V*?9
MAMF'(-F%V*K8M-JIV+';C-F%`-BHV+/8MR!&5%`@V8+8I]BHV80@V*_8L]BJ
MV+'8LR#9AMN,V+/8J@#9AMJOV8?8K]BGV+';C#HZ(-JIV838I]BS(-BHV*<@
MV879B-F!V9'9@MN,V9'8JB#8J-BGV+$@V8;8M-BO`-F^V8;8K-BQV8?9E"#:
MK]BRVXS9AMF'XH",V8?8IR#8J-BSV*K9AR#8M-BO+B#8KMBQV8C8K`#8L]BQ
MV;[8L=BSV*H@V*C8I]N,V*\@VXS:J2#9OMBTV*K;C-BHV*?9AB#9A=BLV8C8
MLMF'V*<@V+'8I]B,("#8K]BQ(-BUV8C8L=BJ(-BJV878I]N,V80@V+39A=BG
M(-BHV8<@V*?8L]BJV8'8I]BOV8<@V*?8LB#9A=BLV8C8LMF'V*?8C"#9OMN,
MVJG8L=BHV8;8K]N,(-JIV8;8KRX`V*K9AMF'V*<@V+/9A=BJ(-F^V*?;C-N,
MV88`V+39A=BGV+'9AR!)1"#8JMF%V*?8LR#9A=BTV*[8M2#9AMBTV*_9AR#8
MI]BSV*K8C"#8I]N,V88@V+39A=BGV+'9AR#8K]BQ(-BOV*?8K]JOV*?9AB#;
MC-BGV8'8JB#9AMBTV*\`V*K9A=BGV+,@("5S(-BHV*<@V879B-F!V9'9@MN,
MV9'8JB#8J-F'(-JIV*K8I]BHVH;9AR#8HMBOV+'8LR#8M-F%V*<@V*?8MMBG
MV8'9AR#8M-BO`-N,VJD@V*C9A-F(VJD@V*?9A=BVV*?;C"!01U`@V*C8L=BG
MVXP@V*C8I]BRV*C;C-F&VXP@VXS:J2#9OMN,V+K8I]F%(-BGV878MMBGV*$@
MV+38K]F'(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@!)1"#9@=F'V+'8L]BJ
M(-BJV8C8LMN,V+G;C"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*H@V8@@VXS8
MIR#8K]BQ(-BOV*?8K]JOV*?9AB#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F!V8?8
ML=BSV*H@V*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8J@#9
MA=BTV*[8M=F'XH",XH",V8?8I]N,(-BQV878LMBHV8;8K]N,(-F&VXS8I]BR
MV879AMBO(-N,VJD@V*?8L=BJV+78I]F$(-BGV879AB#9B-BH(-F%VXSB@(S8
MJ-BGV+39AMBO`-F^V+'9B-F&V*_9AR`E<R#8J-BGVXS8KR#8K]BGV+'8I]N,
M(-BJV8;8N-N,V84@)7,@V*C8I]BTV*\`V;[8L=F(V8;8K]F'("5S(-BHV*?;
MC-BO(-BMV*?9B-N,(-BJV8;8N-N,V878I]BJ("5S(-BHV*?8M-BO`-F^V+'9
MB-F&V*_9AR#8J-BQ(-BQV8C;C"#8KMF(V*_8M"#9AMF%VXSB@(S8JMF(V*?9
MAMBO(-BQV8C9AMF(V+38JB#8M-F(V*\`V;[8L=F(V8;8K]F'(-BMV*?9B-N,
M(-BOV*?8K]F'XH",V*?B@(S;C-N,(-F&VXS8L]BJ(`#9A=BO(-BJV878I]F%
M(-BUV8'8K=F'(-BHV*<@244@V878M-JIV80@V*_8I]BQV*\@V8@@V*?;C-F&
M(-BGV+(@V878M-JIV838I]BJ(-F%V+'9B-BQVJ_8L2#9A=N,XH",V*C8I]BT
MV*\N(-BGVJ_8L2#9A]F&V8C8LB#9A=N,XH",V*[9B-BGV8?;C-BO(-BMV*?9
MA-BJ(-F(VXS8L=BGVXS8M-JOV+$@V*K9A=BGV84@V+79@=BMV8<@V+'8IR#8
MI]F%V*K8K=BGV88@VJG9AMN,V*_8C"#9A-BWV8'8I]F+(-JIV83;C-BO(-BJ
MV*/;C-N,V*\@V+'8IR#9@=BTV*?8L2#8K]F'VXS8KR``V8?9B-N,V9'8JB`B
M)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`-BJV8;9A]BG(-BSV878JB#:AMF^
M`-F^VXS8NMBGV84@V8'8L=BSV*K8I]BOV8<@V+38K]F'(-BQV8C;C"`E<R#8
MJ-F'("5S(-BHV*<@V879B-BVV8C8N2`B)7,B(-F&V878I]N,V+0@V*_8I]BO
MV8<@V+38K]F'(-BGV+/8JBX*V*K8MMF%VXS9AMN,(-BHV+'8I]N,(-BNV8C8
MI]F&V*_9AR#8M-BOV88@V8@@VXS8IR#8K]BQVJD@V*+9AB#9B-BLV8C8KR#9
MAMBOV*?8L=BO`-F&V*?9A=N,(-JIV8<@V*C9AR#9A]F&VJ_8I]F%(-F^VXS9
MB-F&V*_8K]F'VXP@V*C9AR#8M=F!V*W9AR#8I]N,V*S8I]BO(-F&V*?9A=F'
M(-BGV+/8JMF!V*?8K]F'(-F%VXSB@(S8M-F(V*\`V*K8N=BOV*?8KR#9@=N,
MV838K^*`C-F'V*<@V*C8I]N,V*\@VXS:J2#8N=BOV*\@V*C8I]BTV*\`V*?9
MB-F$V8C;C-BJ("(E<R(@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@VJ_8
ML=BOV*\@V++;C-BQV*<@V879@MBOV*?8L2#8K]BGV*_9AR#8HMF&(-BGV+(@
MV*W8KR#9A=BLV*?8LB#8J-N,V+38JMBQ(-BGV+/8J@#8J-BQV8;8I]F%V8?B
M@(S8I^*`C-N,VXP@VJG9AR#8J-BQV*?;C"#9A=BTV*?9A]BOV8<@V*?;C-F&
M(-F&V8C8N2#8K]BGV*_9AR`H)7,I(-F"V*C9A-BGV8L@V879B-BQV*\@V*?8
ML]BJV8'8I]BOV8<@V8+8L=BGV+$@V87;C.*`C-JOV+'9@=BJV(P@V*_8L2#8
ML]BGV878I]F&V8<@V879B-BLV8C8KR#9AMN,V+/8J@#8JMF&V8?8IR#8L]F%
MV*H@V+'8I]BSV*H@V8@@VH;9O@#8JMF&V8?8IR#8L]F%V*H@V+'8I]BSV*H`
MV*S8K]BG(-JIV8;9AMBOV8<@V*C8I]N,V*\@VXS:J2#9AMF(VXS8L]F'(-BH
MV*?8M-BO`-JIV*?8L=BSV*?8LB`B)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ
M`-JIV*?8L=BSV*?8LB`B)7,B(-BMV8'8N"#8M-BOV8<@V*?8L]BJ`-BOV+'8
MKMF(V*?8L]BJ(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"#8J-BQV*?;C"`E<R#8
MK=BPV8$@V+38K]F'(-BGV+/8J@#8L=BOVXS9@2#9A=BTV*[8M2#8M-BOV8<@
MV8C8K-F(V*\@V8;8K]BGV+'8KP#9OMBQV8C9AMBOV8<@V879B-F"V*K;C"`@
M(B5S(MF%V8C8K-F(V*\@V8;;C-BSV*H`V*K9AMF'V*<@V+/9A=BJ(-BHV*?9
MA-BG(-F((-F^V*?;C-N,V88`V*K9AMF'V*<@V+/9A=BJ(-BHV*?9A-BG`-BO
MV*?8K]F'V90@V*?8L=BSV*?9A"#8M-BOV8<@V*?8LB#:K]BGV84@V8+8J-F$
MVXP@V*?8LB#8K]BSV*H@V+'9@=BJV8<@V*?8L]BJ`-F^V+'9B-F&V*_9AR#8
MI]BQV+/8I]F$(-BTV*_9AR#9AMF%VXSB@(S8JMF(V*?9AMBO(-BMV8'8N"#8
MM-F(V*\`V*C9A-F(VJD@=V5A=&AE<BYC;VT@V8+8I]BHV80@V*_8L]BJV+'8
MLR#9AMN,V+/8J@#:K]BRVXS9AMF'XH",V*?B@(SB@(S;C-N,(-BOV+$@V*_8
ML]BJV+'8LR#9AMN,V+/8J@#8J-BNV+3;C"#:J=F'(-BHV*K9B-BGV8;8KR#8
MJ-BQV*[8MR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8KR#9A=F(V*S9B-BO
M(-F&VXS8L]BJ`-F&V8C;C-BSV8?B@(S9A]BGVXP@V++;C-BGV*_;C"#8K]BQ
M(-BGVXS9AB#9@=N,V838KR#9@MBQV*?8L2#8K]BGV+'8KRX@V+39A=BG("5S
M(-F&V8C;C-BSV8<@V8C8I]BQV*\@VJG8L=BOV8?B@(S8I^*`C-N,V*\@V*_8
ML2#8K=BGV83;C"#:J=F'(-BTV878IR#8J-BGVXS8KR#:J=F%V*K8L2#8I]BR
M("5S(-F&V8C;C-BSV8<@V8C8I]BQV*\@VJG9AMN,V*\`V878M-JIV83;C"#8
MK]BQ(-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ.B`E<R#8I]BQV+/8I]F$(-F&V+38KP#9A=BTVJG9A-N,(-BOV+$@V*?8
ML=BSV*?9A"#9OMBQV8C9AMBOV8<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ(-BG
MV8;8K]BGV++9AR`E<R#8J-N,V+38JMBQ(-BGV+(@V*W8KR#9A=BLV*?8LB#8
MJ-F(V*_9AR#8I]BSV*H@*"`E9"#8J-BGVXS8JBDN`-F%V+3:J=F$VXP@V*_8
ML2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#9B-BLV8C8KR#8K]BGV+38JMF'
M(-BGV+/8JCH@("5S(-BHV8<@V+79B-BQV*H@V*K:J=F'XH",V*?B@(S;C-N,
M(-BGV+'8L]BGV80@V+38K]F'(-BGV+/8JB``V*[8M]BGVXS;C"#8K]BQ(-F&
MV878I]N,V+0@V*?;C-F&(-BHV*[8M"#9OMN,V+K8I]F%(-BQV*X@V*_8I]BO
MV8<@V*?8L]BJ`-BNV+?8I]N,VXP@V*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#:
MJ=BQV*_9AB#8K]BGV*_9AR#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8
MJ@#8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B@(S8J-BQV*\@VJG8L=BOV88@
MV*_8I]BOV8?9E"#8JMF"V8C;C-F%(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-BN
MV+?8I]N,VXP@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-F!V+'9A2#8L=BN(-BO
MV*?8K]F'(-BGV+/8JBX@V+38I]N,V*\@V8';C-F$V*\@V879B-BQV*\@V8;;
MC-BGV++;C"#8L=BG(-BLV*<@V*?9AMBOV*?8KMBJV8?B@(S8I^*`C-N,V*\`
MV*[8M]BGVXS;C"#8K]BQ(-BGV*S8L=BG(-JIV+'8K]F&(-BYV879A-N,V*?8
MJB#9A=BTV*[8M2#8M-BOV8?9E"#:J=BJV*?8J-J&V8<@V*+8K]BQV+,@V+'8
MKB#8K]BGV*_9AR#8I]BSV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BS
MV+G;C"#:J=F&VXS8KP#8KMBWV*?;C-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9
MAMN,(-BLV++8IMN,V*?8JB#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8
MJBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;C-BO`-BN
MV+?8I]N,VXP@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V8'9A]BQV+/8JB#8
MJMF(V++;C-BYVXP@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$V+?9@=BGV8L@
MV*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KP`@VJG8I]BQV+/8I]BR($E-
M05#9OMF(V+39A^*`C-F'V*?;C"#9A=BTV*K8L=JI(-BQV*<@V;[8M-BJVXS8
MJ-BGV8;;C"#9AMF%VXSB@(S:J=F&V*\`(-BHV8<@V8;8N-BQ(-F&V87;C.*`
MC-BQV+/8KR#:J=F'(-BBV+'8M-N,V8@@<F%R(-F%V+G8JMBHV+';C"#8J-BG
MV+38KP`@V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V;[8L=F(
MV8;8K]F'('II<"#9A=BYV*K8J-BQVXP@V*C8I]BTV*\`V*C9AR#9AMBXV+$@
MV8;9A=N,XH",V+'8L]BO(-JIV8<@V+39A=BGV+'9AR#:J=BGV+'8JB#9A=BY
MV*K8J-BQVXP@V*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-F%V8C8L=BO(-F&
MVXS8I]BR(-BGV+/8J@#8I]N,V88@V8';C-F$V*\@V879A=JIV88@V*?8L]BJ
M(-BTV*?9A=F$(-BGV+G8K]BGV*\@V+78K=N,V*T@V*C8I]BTV*\`V*?;C-F&
M(-F!VXS9A-BO(-F%V87:J=F&(-BGV+/8JB#8M-BGV879A"#8I]BYV*_8I]BO
M(-F((-F(VXS8L=JOV8C9A"#8J-BGV+38KP#8I]N,V88@V8';C-F$V*\@V879
MA=JIV88@V*?8L]BJ(-BTV*?9A=F$(-F%V8+8I]BOVXS8L2#9A]BTV*H@V8?8
MM-BJVXP@V*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-BHV*?;C-BO(-BMV*?9
MB-N,(-JIV*?9A=BG(-F((-N,V*<@V8'9A]BQV+/8JMN,(-BGV+(@V*?8N=BO
MV*?8KR#8M=BMVXS8K2#8K-BOV*<@V+38K]F'(-BHV*<@V8;9B-N,V+/9AR#8
MKMBGV83;C"#8J-BGV+38KP#8I]N,V88@V8';C-F$V*\@V*C8I]N,V*\@VXS:
MJ2#8N=BOV*\@V878N=BJV*C8L2#8J-BGV+38KP#8I]N,V88@)7,@V87;C.*`
MC-BHV*?8M-BO`-BGVXS9AB#9OMN,V+K8I]F%(-BHV*<@V878K-F%V8C8N=F'
M(-JIV*?8L=BGVJG8JMBQ("5S(-F&V8C8M-BJV8<@V+38K]F'(-BGV+/8JB#:
MJ=F'(-BHV*<@V878K-F%V8C8N=F'(-JIV*?8L=BGVJG8JMBQ(-BTV878IR#9
MA=BJV8'8I]F(V*H@V*?8L]BJ`-BGVXS9AB#8N=BOV*\@V*W8K]BGV8+9A"#8
MJ-BGVXS8KR#;C-JI(-BHV*?8M-BO`-BGVXS9AB#:J=BGV+'8L]BGV+(@V;[8
ML=F(V8;8K]F'XH",V8?8I]N,('II<"#9B"!G>FEP(-BQV*<@V*C8I]BR(-F&
MV87;C.*`C-JIV8;8KP#8I]N,V88@V+/8I]F%V*?9AMF'(-BOV+$@V*W8I]F$
M(-BMV*?8MMBQ(-BZVXS8L2#9@=BYV*?9A"#8I]BSV*H`V*?;C-F&(-F%V8+8
MK]BGV+$@V*C8I]N,V*\@V+G8K]BO(-BHV*?8M-BO`-BGVXS9AB#9OMF&V*S8
ML=F'(-BHV*?;C-BO(-BGV+(@V;[9AMBLV+'9A]F4(-JOV++;C-F&V8?B@(SB
M@(S9A]BG(-F!V+'8I]BNV8C8I]F&VXP@V+39B-BO`-BQV+G8KP#8J-F$VXS8
MM]F'V*<`V++9A=BGV88`V+'8K]N,V*?8J-N,(-BRV878I]F&`-F"V*?9A-BH
M(-BRV878I]F&`"#8I]F&V*K8KMBGV*@@V++9A=BGV88@`-BYV8;9B-BGV88`
MV+G9AMF(V*?9AB`HV+'8I]F'V8;9A=BGVXP@V*+9AMN,*3H`V*C9AP#8J-BQ
MV*?;C"#8I]F&V*K8KMBGV*@@VH;9AMBO(-F!VXS9A-BOV(P@V*_:J=F%V8<@
M0W1R;"#8L=F(VXP@*%!#*2#;C-BG($-O;6UA;F0@V+'9B-N,("A-86,I(-BQ
MV*<@V*_8L2#9A=BOV*H@VJG9A-N,VJD@VJG8L=BOV88@V8;:K]F'V*_8I]BQ
MVXS8KP#8I]F%V+'9B-BR`-F!V+'8K]BG`-BHV*?9A-BG`-J&V*?8L=J&V8C8
MJ"#8J-BGV838IR`HV*C8I]F$V*<I`-BJV+'8K-F%V8?B@(S9A]BG`-BOV+'8
ML]BJ(-F((-N,V*<@V8;8I]BOV+'8L]BJ`-BSV8<@V+39AMBHV8<`5'5R:VES
M:"`H25-/+3@X-3DM.2D`V*?9AMBJV*[8I]BH(-BNV8C8KR#8L=BG(-BJV*?;
MC-F^(-JIV8;;C-BO.@#8M-BGV*[8M2!5+E8N(#H@`%523`!54DPZ`-BGV87:
MJ=BGV88@V*_8L]BJV+'8L]N,(-BHV8<@V+38I]BNV8<@5D93(-F&VXS8L]BJ
M`-BGV87:J=BGV88@V*?8MMBGV8'9AR#:J=BQV*_9AB#8I]BWV838I]BYV*?8
MJB#8I]BVV*?9@=N,(-JIV*?8L=BHV+$@V*C9AR#9A]F&VJ_8I]F%(-BKV*C8
MJB#9AMBGV84@V8;;C-BSV*H`V8;9A=N,XH",V*K9B-BGV88@V878K-F(V++9
MA]BG(-BQV*<@V*C8L=BGVXP@V;[8L=F(V8;8K]F'("(E<R(@V*K8NMN,VXS8
ML2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V878K-F(V++9A]BG(-BQV*<@
MV*C8L=BGVXP@V;[8L=F(V8;8K]F'("5S+R5S(%9&4R`@V*K8NMN,VXS8L2#8
MK]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V*_8L2`E<R#8JMBZVXS;C-BQ(-BO
MV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!344S9
MA=BJV+79A"#8M-BO`-F&V87;C.*`C-BJV8C8I]F&(-BHV*<@4U-,(-F%V*K8
MM=F$(-BTV*\`V8;9A=N,XH",V*K9B-BGV88@V*?8LB#9OMBQV8C9AMBOV8<@
M5D93(-BQV8C9AMF(V+38JB#8JMF'VXS9AR#9AMF%V8C8KP#9AMF%VXSB@(S8
MJMF(V*?9AB#8M-BGV*[9AR!61E,@(B5S(B#8L=BG(-BGVXS8K-BGV*\@V8;9
MA=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*?;
MC-BLV*?8KR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBO
MV8<@5D93(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(
MV*?9AB#9OMBQV8C9AMBOV8<@V*[8I]F$VXP@5D93("#8I]N,V*S8I]BO(-F&
MV879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(-BQV*<@V*C8I]BR
M(-JIV+'8KR``V*W8L-F!("(E<R(@V879A=JIV88@V8;;C-BSV*K8C"#8M-BG
MV*[9AR#8KMBGV83;C"#9AMN,V+/8J@#9AMF%VXSB@(S8JMF(V*?9AB`B)7,B
M(-BQV*<@V*W8L-F!(-JIV+'8KSH@)7,N`-BMV+#9@2`E<R#9A=F%VJG9AB#9
MAMN,V+/8JMB,(-BTV*?8KMF'(-BNV*?9A-N,(-F&VXS8L]BJ`-F&V87;C.*`
MC-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BHV8<@V+79B-BQV*H@V*K9
MB"#8K]BQ(-BJV8@@V*W8L-F!(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&
M(-BTV*?8KMF'(%9&4R#8L=BG(-BMV+#9@2#9AMF%V8C8KP#9AMF%VXSB@(S8
MJMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\Z("5S
M+@#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93("(E<R(@V+'8
MIR#8K=BPV8$@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8
MK]F'(%9&4R#8L=BG(-BMV+#9@2#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9
MAB!61E,@V+'8IR#8J-F'(-BUV8C8L=BJ(-BJV8@@V*_8L2#8JMF((-BMV+#9
M@2#9AMF%V8C8KSH@)7,N`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'V90@
MV8'8N=F$VXP@V+'8IR#8JMBTV*[;C-BU(-BOV*?8KP#9AMF%VXSB@(S8JMF(
MV*?9AB#8K-BRV*;;C-BGV*H@VJ_9B-BGV8?;C"#8L=BG(-BGV+/8JMBNV+'8
MI]BL(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BJV+G8L=N,V8$@)7,@
M(-BQV*<@V*C8I]BQ(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9
MB-F&V*_9AR!61E,@V+'8IR#8I]F&V*K9@MBGV80@V*_8I]BO`-F&V87;C.*`
MC-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@(B5S(B#8L=BG(-BHV*?8LB#9
MAMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQ
MV*<@V*C8L=BGVXP@V8;9B-BTV*K9AB#8J-BGV+(@VJG8L=BO`-F&V87;C.*`
MC-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8J-BGV+(@V8;9A=F(
MV*\`V8;9A=N,XH",V*K9B-BGV88@V*+8L=BTVXS9B"#9@=BTV+'8K]F'(-BQ
MV*<@V*C8I]BR(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!V
M9G-R;V]T(-BQV*<@V*[9B-BGV8;8KP#9AMF%VXSB@(S8JMF(V*?9AB`E<R#8
ML=BG(-BHV8<@)7,@(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KSH@V;[9B-BT
MV8<@V879@MBUV*\@V*?8LB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*H`V8;9
MA=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9
MAMBGV84@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8
ML=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KSH@)7,N`-F&V87;C.*`C-BJ
MV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@(B5S(B#8L=BG(-BJV+K;C-N,V+$@
MV8;8I]F%(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@
M5D93("5S+R5S(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO`-F&V87;
MC.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8JMBZVXS;C-BQ
M(-F&V*?9A2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@)VUK:7-O9G,G(-BQ
MV*<@V*?8K-BQV*<@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V*?;C-F&
M(-BSV8;8KR!7;W)D(-BQV*<@V*K8L=BLV879AR#9AMF%V8C8KP`@V8;9A=N,
MXH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@(B5S(B!61E,@(-F&V8C8
MM-BJ`"#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!61E,@
MV8;9B-BTV*HN`-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'
MV90@V*_8I]BOV8<@5D93(-F&V8C8M-BJ`-BRVXS8L=BNV+?B@(S8K]BGV+$`
MV8C8I]JOV+'8K]BGV8;8K]F&(-BJV+K;C-N,V+'8I]BJ`-F(V*?:K]BQV*_8
MI]F&V*_9AB#8HMBNV+';C-F&(-BYV879A"#8M-F%V*<`V;[8I]BSV*X@V+K;
MC-BQ(-F%V8;8JMBXV+'9AR#8I]BR(-JIV*?8L=BSV*?8LB#8J-BQ(-BQV8C;
MC"#8I]BJV+78I]F$.@#9OMBGV+/8KB#8NMN,V+$@V879AMBJV+C8L=F'(-BG
MV+(@VJG8I]BQV+/8I]BR(-BHV8<Z`-BZVXS8L2#8K=F(V++9AP!5;FEC;V1E
M("A55$8M."D`V8C8I]BMV*_9A]BG`-BOV*?8K]F'(-F&V*?8M-F&V*?8KMBJ
MV8<`V8;8I]F%(-JIV*?8L=BHV+$@V8@@VXS8IR#8I]BSV84@V+'9A=BR(-F&
MV*?8M-F&V*?8KMBJV8<`V8+8M]BY(-F^VXS9B-F&V*\@V+G9AMBUV+$@V8'8
MN=F$VXP`V*C;C"#9AMBGV84`V*_8L]BJ(.*`C-F&V8C;C-BSV8?8I]N,(-BH
MV*_9B-F&(-BGV878JMN,V*?8LB#8J-F'(-BOV83;C-F$(-BGV879AMN,V*K;
MC"#9AMF%VXSB@(S8JMF(V*?9AMF&V*\@V*?8LB#8M]BQVXS9@B#8J-BQV8;8
MI]F%V8<@V8;9B-N,V+/;C"#8J-BQVXS8K]F'+]BQV8C9AMF(V+38JB#:K]BQ
MV8'8JMF'+]J&V+/8J-N,V*_9AR#8M-F(V8;8KRX@VJG9A-N,V*\@V*K8H]N,
MVXS8KR#8L=BG(-F!V+38I]BQ(-BOV8?;C-BO(-BJV*<@V878JMF&(-F!V8;;
MC.*`C-BGXH",VXS;C"#8L=BG(-BOV+$@;6]Z:6QL82YO<F<@V*C8IR#8N=F&
MV8C8I]F&(-J&VJ_9B-F&VJ_;C"#8K]BSV*K8L=BSVXP@VXS:J2#8K]BSV*H@
MXH",V8;9B-N,V+,@V*C9AR#8JMBNV*K9A]F4(-BQV+/9A2#8L=BG(-F%V+38
MI]F'V*_9AR#:J=F&VXS8KP#8L=F&VJ\@V*K9AMBXVXS9A2#9AMBTV*_9AP#8
MJ-BSV+<@V*C8K]F(V88@V;[8M-BJVXS8J-BGV8;;C`#8J-BQV8C8LMBQV+/8
MI]F&VXP`V*C8L=F(V++8L=BSV*?9AMN,("5S`-BHV+'9B-BRV+'8L]BGV8;;
MC"#:J=BGV+'8J-BQ`"(E<R(@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*\`V*_8
ML]BJXH",(-F&V8C;C-BS(-BHV8?;C-F&V8?B@(S8L]BGV++;C"#8K=BPV8$@
MV+38KP#8I]BQV+/8I]F$(-JIV+'8K]F&`-BJV878I]F%(-F^V+'9B-F&V*_9
MA^*`C.*`C-F'V*?;C"#8JMF&V+C;C-F%(-BHV+'9AMBGV879A^*`C-F'V*?;
MC"#:J=BGV+'8J-BQV*_;C"#8J-F'(-JIV*?8L=BSV*?8LB#8I]BQV+/8I]F$
M(-BTV*\`V*W8L=F(V8$@V*C8LMBQVJ\@V838I]BJVXS9A@#8I]BYV*_8I]BO
M(-N,V8C9AMBGV8;;C"#8J-BRV+':KP`@V*?8L]BJV8'8I]BOV8<@V8'8N=F$
MVXPZ("5S`-BGV+/8JMF!V*?8K]F'(-BGV+(@4U-,`-BGVJ_8L2#9AMBGV84O
MV*?8L]F%(-BQV878LB#8J-BQV*?;C"#:J=BGV+'8L]BGV+(@24U34"#9A=BJ
MV8'8I]F(V*H@V*?8L]BJV(P@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\`VJG8
MI]BQV*C8L2`E<R`@V*C8L=BGVXP@)7,@V*?8K=BQV*?8LB#9A]F(VXS9D=BJ
M(-F&V+38K]F'(-BGV+/8J@#8L]BQV;[8L=BSV*K;C"#:J=BGV+'8J-BQ`-JO
MV++;C-F&V8?B@(S9A]BGVXP@VJG8I]BQV*C8L0#8J]BHV*H@V8;8I]F%(-JI
MV*?8L=BHV+$`V*O8J-BJ(-JIV*?8L=BHV+$@V*C8L=BGVXP@V*?;C-F&(-F^
MV*?;C-JOV*?9AR#8NMN,V+$@V8'8N=BGV80@V+38K]F'(-BGV+/8J@#8K=BS
MV*?8J"#:J=BGV+'8J-BQ(-F^VXS8K]BG(-F&V+38KP#9AMBGV84@VJG8I]BQ
MV*C8L0#9AMBGV84@VJG8I]BQV*C8L3H`V8;8I]F%(-JIV*?8L=BHV+$Z(`#:
MJ=BGV+'8J-BQV*?9AB#8L]BGV878I]F&V8<Z`-BTV*?8KMF'(%9&4R#9B-BL
MV8C8KR#9AMBOV*?8L=BO`-BJV+G8M]N,V838I]BJ`-F%V8C9@MBYVXS8JMF'
MV*?;C"#9A=BYV*K8J-BQ(-N,V*?9@=BJV8<@V+38K]F'(-BYV*C8I]BQV*K9
MAMBO(-BGV+(Z`-BGV+G8JMBHV*?8L0#9A=F"V*_8I]BQ(-BHV8<@V*_9@MN,
MV8+9AR#8I]BR(-BMV*?9A-BG`-F%V8+8K]BGV+$@V*?8LB#8J-N,V+3;C-F&
MV8<@V+?9B-F$(-F%V*S8I]BR("5S(-BHVXS8M-BJV+$@V*?8L]BJ`-F%V8+8
MI]BOVXS8L0#9A=F"V*?8K]N,V+$@V*C8L=BGVXP@V*?9AMBJV*[8I]BH(-BG
MV+(`V878JMBZVXS;C-BQ`-F&V+/8KMF'`-JIV8;8JMBQV80@V8;8L]BNV8<`
MV*K8L=BGV+(@V+G9A=F(V*_;C`#9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8
MN=F%V8C8K]N,`-BYV879B-BOVXPZ`-BNVXS9A-N,(-BHV*?9A-BG`%9I971N
M86UE<V4@*%9)4T-)22D`V8;9A=BGVXP@)7,`V8;9A=BGVXP@VXS:J2#8M=F!
MV*W9AR#9B-BH(-BNV*?8L=BLVXP`(-F&V878IR#8J-F'(-BYV8;9B-BGV88@
M)7,`V8+8I]BHV83;C-BJ(-F%V+38I]F'V*_9AP#9@MBGV*C9A-N,V*H@V878
MM-BGV8?8K]F'.B``V*?8KMBWV*?8L2$A(2#8K]BSV*H@XH",V8;9B-N,V+,@
MV+'8IR#8J-BWV8C8L2#8K]BSV*K;C"#8I]BR("5S(-BMV+#9@2#:J=F&VXS8
MKP#8I]BNV+?8I]BQ.B``VH;9A]BGV+'8M-F&V*C9AP#9OMN,V+3B@(S8J-N,
MV8;;C"#9A]F(V*<`V*_8I]BOV8<@V*+8J"#9B"#9A]F(V*?;C-N,(-F!V+'8
MI]F'V84@V+38K]F'(-BHV8<@V8C8L]N,V839AP!W96%T:&5R+F-O;0#9B-BH
M`-F(V*CB@(S:K]BGV8<`V8?9@=BJVJ_;C`#8KMF(V+0@V*+9A=BOVXS8KP#8
MJ-F'("5S(-BNV8C8M"#8HMF%V*_;C-BO`"5SV(P@V*[9B-BT(-BBV878K]N,
MV*\`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`-J&V8<@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@V+'8IR`E<R#8
MJ-BGVXS8KR#8J-BYV*\@V*?8LB#9B-BQV8C8KR#9AMBTV*?9AB#8K]F'V*_8
MGP#9AMF(VXS8L]F'V93B@(P@V*W8I]BFV80@VH;;C-BSV*K8GP#9AMF(VXS8
ML]F'XH",VXP@V8;9@MF$(-F"V8C9A"#:AMN,V+/8JMB?`-JIV*_8I]F%(-F!
MV*?8L@#:J=BOV*?9A2#8J-BQV8;8I]F%V8?B@(S9A]BGVXP@V878JMBUV83B
M@(S:J=F&V8;8K]F'(.*`C-BHV+'8I]N,(-F(VXS8L=BGVXS8M-JOV+$@V878
MJMF&(-F!V+G8I]F$(-BHV*?8M-F&V*\`V+G8L=BV`"#9OMF'V8;8IR#8K]BQ
M(-F(V*?8K=BO($-34R``V;[9A]F&V*?;C"#:K]BRVXS9AMJOV*?9AB`E<R#8
MK]BQ(-BQV*?8L]BJ("C8K]BQ(-F(V+'9B-BO(-BHV+G8K]N,(-F%V8C8J]BQ
M(-F%VXSB@(S:K]BQV*_8KRDZ`-F^V8?9AMBGVXP@V*S8K]F(V80`V8C8I]BM
MV*\@V;[9A]F&V*<`V;[9A]F&V*<Z`%=I:VD`V*C8I]BO.@#8J-BGV*\@V++9
MB-BOV8?9AMJOV*?9A3H@`-BSV+'8N=BJ(-BHV*?8KR#8J-BQV*W8L]BH(-F!
MV8C8JB#8J-BQ(-BSV*?8N=BJ`-BHV*?8KSH`V*C8I]BO.B``V+G9@MF$`-JI
MV*?8L0#8HMBOV+'8LR#9A=BMV80@VJG8I]BQ`-BJV839@=F&(-F%V*W9A"#:
MJ=BGV+$`XH",65D`65E960#8L]BGV838I]F&V8<`V*+8L=N,`-BHV839A]B,
M(-F%V8C8I]F!V8+9A0#8M-F%V*<@V*_8L2#9A=BO(-F%V*K9AB#9A]BSV*K;
MC-BO+B#8I]BR(-BOVJG9A=F'("!;/#Y=(-BHV+'8I]N,(-BHV+':K]BTV*K9
MAB#8J-F'(%=94TE764<@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\`V+39A=BG
M(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#9AMBTV*_;C-BO`-BTV878IR#9AMF%
MVXSB@(S8JMF(V*?9AMN,V*\@V8;9B-N,V+/9AR`G7"<@V+'8IR#8K]BQ(-F&
MV*?9A2#:J=BGV879A"#8KMF(V*\@V*_8I]BTV*K9AR#8J-BGV+3;C-BO`-BT
MV878IR#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-F%V+G8
MJMBHV+';C"#9B-BGV+'8KR#9AMJIV+'8K]F'XH",V*?;C-BO`-BTV878IR#9
MA]N,VH8@V8';C-F$V*_;C"#8L=BG(-BOV+$@V;[8L=F(V8;8K]F'(-BOV+'9
MB-F&XH",V*C8L=BO(-BTV*_9AR#8J-F'(-F!VXS9A-BO(-F%V*K9@MBGV*C9
MA-N,(-BOV+$@)7,@V8;:K]BGV+38JB#9AMJIV+'8K]F'XH",V*?;C-BO`-BT
MV878IR#8KMBGV+'8K"#8M-BOVXS8KP#8M-F%V*<@V878K-BHV8C8L2#9A]BS
MV*K;C-BO(-N,VJD@V+39A=BGV+'9AR#8JMF$V8'9AB#9A=BYV*K8J-BQ(-F(
MV*?8L=BO(-JIV8;;C-BOV(P@V*?8LB#8N=F$V*?9A=BJ("<K)R#8J-BQV*?;
MC"#8M-F%V*?8L=F'XH",V8?8I]N,(-BHVXS9AB#8I]F$V879A-F$VXP@V*?8
ML]BJV8'8I]BOV8<@VJG9AMN,V*\`V+39A=BG(-F%V*S8J-F(V+$@V8?8L]BJ
MVXS8KR#;C-JI(-F%V8+8K]BGV+$@V878N=BJV*C8L2#9B-BGV+'8KR#:J=F&
MVXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#9OMBTV*K;C-BHV*?9AB#8K]BQ
MV*[8JB#8K]BGV*_9AR#8J-BQV*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-BK
MV*C8JB#9AMBGV84@V;[;C-JIV+'8J-F&V*_;C"#:J=F&VXS8KP#8M-F%V*<@
MV*C8I]N,V*\@VXS:J2#8L]BGV878I]F&V8<@V;[8M-BJVXS8J-BGV88@5D93
M(-BQV*<@V;[;C-JIV+'8J-F&V*_;C"#:J=F&VXS8KP#9@MBHV80@V*?8LB#8
MI]BQV+/8I]F$(-JOV++8I]BQV+38C"#8J-BGVXS8KR#9A=BTVJG9A"#8L=BG
M(-BTV+'8K2#8K]F'VXS8KP#8M-F%V*<@V*C8I]N,V*\@55),V*?;C"#:J=F'
M(-BGVXS9AB#9OMN,V8C9AMBO(-BHV8<@V*+9AB#8I]BTV*?8L=F'(-F%VXSB
M@(S:J=F&V*\@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,
MV*\@VXS:J2#:J=BGV+'8L]BGV++8C"#8J-BQV*?;C"#8K=BPV8$@VJG8L=BO
MV88@V*?9AMBJV*[8I]BH(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI
M(-F&V*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*W8L-F!(-JIV+'8K]F&
M(-F%V+38KMBU(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9
MA2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*W8L-F!(-BTV*_9AB#9A=BTV*[8
MM2#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#9AMBGV84@VJG8I]BQ
MV*C8L=B,(-BHV+'8I]N,(-BGV+;8I]F!V8<@VJG8L=BOV88@V878M-BNV+4@
MVJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,VJD@V+39AMBGV+/9AR#:J=BG
MV+'8J-BQV(P@V*C8L=BGVXP@V*C8L=F(V++8L=BSV*?9AMN,(-BGV8;8JMBN
MV*?8J"#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@V878M-BNV+4@VJG9AMN,
MV*\@VJG9AR#:AMF'(-BYV879A-N,(-BHV*?;C-BO(-BGV8;8K-BGV84@VJ_;
MC-BQV*\`V+39A=BG(-BHV*?;C-BO(-F&V*?9A2#8K-BOVXS8KR#8K]BSV*K9
MAR#8L=BG(-BJV*?;C-F^(-JIV8;;C-BO`-F&V+38L]BJ("5S(-BTV878IR#9
MA=F&V8+8MMN,(-BTV*_9AR#8I]BSV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8
ML=F'(-F(V*?8L=BO(-BTV8C;C-BO`-BBV*_8L=BS(-BGV83:J=BJV+'9B-F&
MVXS:J=N,(-BTV878IP#8HMBOV+'8LR#9@=BQV+/8JMF&V*_9ASH@V+39A=BG
M.@#8I]BWV838I]BYV*?8JB#8M-F%V*<`V*+8K]BQV+,@V*?;C-F&V*K8L=F&
MV*K;C"#8M-F%V*<@V8;8L]BHV*H@V*C9AR#8I]BHV*K8K]BGVXP@V8;8M-BS
MV*H@)7,@V+39A=BG(-BJV+K;C-N,V+$@VJG8L=BOV8<@V*?8L]BJ+MBHV+'8
MI]N,(-BQV+G8I]N,V*H@V878L]BGV*;9A"#8I]F%V8;;C-BJVXP@V*C8I]N,
MV*\@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C;C-BO`-F&V*?9A2#8M-F%
MV*<`V+/8I]F%V*?9AMF'(-F^V+38JMN,V*C8I]F&(-BJV+78K]N,V8(@V8?9
MB-N,V9'8JB#8M-F%V*<@V8'9A]BQV+/8JB#:J=BQV*_9AB#:J=BGV+'8J-BQ
MV*?9AB#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMBOV(P@
MVXS8IR#8M-BGVXS8KR#8J-F&V*<@V*C9AR#8K]F$VXS9A"#8K]N,VJ_8L=N,
M(-BGVXS9AB#:J=BGV+$@V*?9AMBLV*?9A2#9AMF%VXSB@(S8M-F(V*\`V+C8
MI]F'V+$@V878L=F(V+':K]BQ(-BTV878IR#9AMBSV*C8JB#8J-F'(-BGV*C8
MJMBOV*?;C"#9AMBTV+/8JB`E<R#8M-F%V*<@V*K8NMN,VXS8L2#:J=BQV*_9
MAR#8I]BSV*HNV*C8L=BGVXP@V+'8N=BGVXS8JB#9A=BSV*?8IMF$(-BGV879
MAMN,V*K;C"#8J-BGVXS8KR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,
MV*\`V878L=F(V+':K]BQ(-BTV878IR#8I]N,V88@V878M-BNV+79AR#8L=BG
M(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMBO+@#8LMF%V*?9AB#9
M@=BYV83;C"#9A=F&V+?9@MF'(-BLV+K8L=BGV8';C-BGVXS;C"#8M-F%V*<Z
M`-F'V8C;C-F1V*H@V;[;C-BT(-F!V+'8MB#8M-F%V*<Z`-F&V*?9A2#:J=BG
MV879A"#8M-F%V*<Z`-F(V+'9B-BO(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9
MAR#8I]BSV*H`V*?8L]F%(-BQV878LB`@V*S8K]N,V*\@V+39A=BG(-BHV+'8
MI]N,("5S(-F'V+/8JCH@)7,`VJ_8LMN,V8;9A^*`C-F'V*?;C"#8M-F%V*<@
MV*C8L=BGVXP@V+?9B-F$(-BGVXS9AB#9AMBTV+/8JB#8J-BQV8C8LMBQV+/8
MI]F&VXP@V+38K]F'(-BGV+/8JB``VJ_8LMN,V8;9A^*`C-F'V*?;C"#8M-F%
MV*<@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*_9AR#8I]BSV*H`V*?8L]F%(-BQ
MV878LB`@V+39A=BG(-BHV*?8LMF&V+38I]F&VXP@V+38K]F'(-BGV+/8J@#8
MI]BSV84@V+'9A=BR(-BTV878IR#8J-BGV++9AMBTV*?9AMN,(-BTV*_9AR#8
MI]BSV*K8C"#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BNV8C8KR#8L=BG
M(-J&VJD@VJG9AMN,V*\@V8@@V*C8IR#8I]BSV84@V+'9A=BR(-BLV*_;C-BO
M(-BNV8C8KR#9B-BGV+'8KR#8M-F(VXS8KP#8I]BSV84@V+'9A=BR("#8M-F%
MV*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ`-JIV*?8L=BSV*?8LN*`C-F'
MV*?;C"#8L=BGV8?B@(S8K]F(V+$@V+39A=BG.@!;V;[9AMF'V*?9AB#:J=BQ
MV*_9AB#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8==`%O:K]BRV*?8L=BT
M(-F%V+3:J=F$72``6]F&V878I]N,V+0@V878JMF&(-F&V8+9A"#9@MF(V80@
MV+38K]F'("T`V8;9A=BGVXS8M"#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BO
MV8=;("T@)7,@V*[8MUT`6]BNV+<@)7,@V*?8LB`E<R!=(`#8L]BQV;[8L=BS
MV*K;C`!#3$D`V*_8L=BNV*H@V*_8I]BOV8<`V*W8L-F!(-BSV+?8L0#:K]BQ
MV8C9AR8C>#(P,&,[V8?8IP#8L=BGV8?9AMF%V*<`V*[8M=F(V+7;C-BGV*H@
MV*K8M=F(VXS8L2XN+@#9B-BQV8C8KP#8KMBQV8C8K`#8JMBZVXS;C-BQ(-F^
MVXS9B-F&V*\N+BX`VJ_8LMN,V8;9A^*`C-F'V*<`V878K-F(V++9A]BG`-BM
MV+#9@2#9OMN,V8C9AMBO+BXN`-BQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,
M`-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$+BXN`-JIV*?8L=BHV+'8I]F&`-JI
MV*K8I]BHVH;9A]F4(-BBV*_8L=BS(`#8JMF"V8C;C-F%`-BBV+'8I]F%`-BG
MVXS9AMBLV*<@V+'8IR#9@=BTV*?8L2#8K]F'VXS8KP#9OMBQV8C9AMBOV8<`
MV*?8LB`E<R`H)7,I(-BOV+$@)7,@)7,`V*C8I]BO`&@Z`-F!V8C8L=BGV8L`
MV*_8L=BNV+<`V*[8M]F(V+==`-F&V*?9A0#9OMN,V*?8K]F'(-BSV*?8LMN,
M(-F&V+38K]F'`-F'V8;9B-BR(-F^VXS8I]BOV8<@V+/8I]BRVXP@V8;8M-BO
MV8<@V*?8L]BJ`&YO=&5P860`V*_8L=BUV*\`V;[;C-JIV+/9A-F'V*<`V+?9
MA-F(V+D`V8;9A=BGVXS8M"#8JMF!V*?9B-BJV8?8IP#9OMN,XH",V*_8L=F^
MVXP`V8'9A]BQV+/8JB#9B-BXVXS9@=F'`-BGV+/9A2#8L=F%V+(@V+'8IR#8
MJ-BQV*?;C"#8JMBCVXS;C-BO(-BOV8C8J-BGV+$@V8C8I]BQV*\@VJG9AMN,
MV*\`VXS:K]BGV8;9AR#8M-BOV8<`V*C;C"#9AMBGV84`V*?9AMBJV*[8I]BH
M(-JIV*?8L=BHV+$`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V9A7TE2+VAE;'`N>&UL````````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8Q-``Q,#4Q-30S
M,3`V,0`P,C`S,#,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]X;6P@=F5R<VEO;CTB,2XP(B`_/B`-"CQH96QP/@T*(#QE
M;G1R>2!I9#TB<W5M;6%R>2(@;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B
M-#<T.3)C9&,Q-2(@<W1A=&4](G5P=&]D871E(CX-"B`@/'1I=&QE/MBOV+':
MK]BGV8<\+W1I=&QE/B`-"B`@/'!A<F$^V*?9BMF&(-BOV+':K]BGV8<@V*[9
MA-BGV+79A^*`C-BGV8K9BB#8I]BR(-BGV+?9A-BGV+G8I]BJ(-F%V8?9A2#8
MM-F%V*<@V+'8IR#8K]BQ(-BGV*[8JMF*V*?8L2#9@MBQV*?8L2#9A=F*XH",
MV*_9A]BO+B#8J-BQV*?;C"#9A=BKV*?9A"#8I]F*V88@V*_8L=JOV*?9AR#9
MAMBTV*?9AB#9A=F*XH",V*_9A]BO(-JIV8<@VH;9AMBO(-F&V*?9A=F'V90@
MV*?9A-JIV*K8L=F(V8;9BMJIVXP@V*K8I]BRV8<@V*_8L2#9AMBGV879A^*`
MC-BOV*?9AB#8M-F%V*<@V879B-BLV8C8KR#8I]BSV*K8C"#:AMF'(-F(V8+8
MI]F*V+G;C"#8M]BHV8(@V*K9@MF(V8K9A2#8M-F%V*<@V+'8KB#8K]BGV*_9
MAR#8I]BSV*K8C"#:AMF'(-F(V+C8I]F*V8';C"#8M]BHV8(@V839BMBSV*H@
MV8C8N-BGV8K9@2#8M-F%V*<@V*C9AR#8N=F'V*_9A^*`C-BGV*K8I]F&(-BG
MV+/8JMB,(-BSV+'8JMF*V*K8L=F'V*?;C"#8L]BQV8C9BMBSV8?8I]N,(-BN
MV*C8L=N,(-BGV8;8JMBNV*?8J-N,(-BTV878IR#:AMF*V+/8JB#9B"`N+BXN
M/"]P87)A/B`-"B`@/'!A<F$^V878K=BJV8C8I]N,(-BGV8K9AB#8K]BQVJ_8
MI]F'(-BGV+(@V+?8L=F*V8(@V*_:K]F%V8?9E"#8K-BGV8;9A=BGV*;;C"#9
MA=N,XH",V*K9B-BGV8;8KR#8J-F'(-BTVJG9A"#8K]F$V*[9B-BGV8<@V+39
MA=BG(-BOV+'8J-F*V*?9BMBO+B#8J-BQV*?;C"#9A=BKV*?9A"#8M-F%V*<@
MV87;C.*`C-BJV8C8I]F&V8K8KR#9A=F(V*?8L=BO(-BOV838KMF(V*?9AR#8
MKMF(V*\@V+'8IR#8J-BQV*?;C"#9AMF%V*?9BMBT(-BOV+$@V*_8L=JOV*?9
MAR#9B"#9A]F%VH;9AMF*V88@V*K8L=BJV8K8J"#9AMF%V*?9BMBT(-BBV8;9
MA]BG(-BQV*<@V8;9BMBR(-BJV+G9BMF*V88@V8;9A=BGV8K9BMBO+CPO<&%R
M83X@#0H@/"]E;G1R>3X-"B`\96YT<GD@:60](FYA=F)A<B(@;60U/2)B.&-F
M,&%E,3EE-3=D9F$P8S)B.38R934Q-C<X,F8T-R(@<W1A=&4](G5P=&]D871E
M(CX-"B`@/'1I=&QE/MJOV++;C-F&VJ_8I]F&(-F%V+'9B-BQVJ_8L2#8J-BQ
MV8;8I]F%V8?B@(S9A]BG/"]T:71L93X@#0H@(#QP87)A/MBOV+$@V+/9A=BJ
M(-BQV*?8L]BJ(-BGV8K9AB#8K]BQVJ_8I]F'(-JOV++;C-F&VJ_8I]F&(-F%
MV+'9B-BQVJ_8L2#8J-BQV8;8I]F%V8?B@(S9A]BGVXP@VJG8I]BQV*C8L=BO
MVXP@V8+8L=BGV+$@V*_8I]BQV*\@VJG9AR#8J-BG(-F!V+38L=BOV88@V*_:
MK]F%V8<@V879B-BS(-BHV+$@V+'9B-N,(-F'V+$@V8K:J2#8I]BR(-BGV8K9
MAB#8J-BQV8;8I]F%V8?B@(S9A]BG(-BHV8<@V+'8I]BMV*K;C"#9A=N,XH",
MV*K9B-BGV8;9BMBO(-BGV+(@V*+9AMF'V*<@V*?8L]BJV8'8I]BOV8<@V8;9
MA=BGV8K9BMBO+CPO<&%R83X@#0H@/"]E;G1R>3X-"B`\96YT<GD@:60](G!R
M969S+61O7VUA:6YT96YA;F-E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E
M83DQ.3(X.&(R9#`P(B!S=&%T93TB=7!T;V1A=&4B/@T*("`\=&ET;&4^V*K8
ML=BLV8K8K=BGV*H@.B#9AMJOV8?8K]BGV+';C"`Z(-BGV8;8K-BGV84@V8;:
MK]F'V*_8I]BQVXP\+W1I=&QE/B`-"B`@/'!A<F$^V*?:K]BQ(-BTV878IR#9
MA=BGV8K9A"#8J-F'(-BGV8;8K-BGV84@V+G9A=F$V8K8I]BJ(-F&VJ_9A]BO
MV*?8L=N,(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#9A=N,XH",V*C8I]BT
MV8K8KR#8I]F*V88@VJ_8LMF*V8;9AR#8L=BG(-BHV*?9BMBO(-BGV8;8JMBN
MV*?8J"#:J=F&V8K8KRX\+W!A<F$^(`T*(#PO96YT<GD^#0H@/&5N=')Y(&ED
M/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!M9#4](F$R,3$V,F-D9F8S
M8C%D.&9A96%D8C<R.38R-#`P,S9E(B!S=&%T93TB=7!T;V1A=&4B/@T*("`\
M=&ET;&4^V*K8L=BLV8K8K=BGV*H@.B#9AMJOV8?8K]BGV+';C"`Z(-BJV*/8
MIMF*V*\@V8;:K]F'V*_8I]BQVXP\+W1I=&QE/B`-"B`@/'!A<F$^V*?:K]BQ
M(-BTV878IR#9A=BGV8K9A"#9A]BSV*K9BMBO(-JIV8<@V+G9A=F$V8K8I]BJ
M(-F&VJ_9A]BOV*?8L=N,(-BQV*<@V8+8J-F$(-BGV+(@V*?9AMBLV*?9A2#8
MHMF&V8?8IR#8JMBCV*;9BMBO(-JIV8;9BMBOV(P@V*?9BMF&(-JOV++9BMF&
MV8<@V+'8IR#8I]F&V*K8KMBGV*@@VJG9AMF*V*\N(-BOV+$@V+K9BMBQ(-BG
MV8K9AB#8M=F(V+'8JB#8JMF%V*?9A2#8N=F%V839BMBGV*H@V8;:K]F'V*_8
MI]BQVXP@V*C9AR#9A]F&VJ_8I]F%(-F(V+'9B-BO(-BGV8;8K-BGV84@V8K8
MI]F!V*K9AR#9B"#8M-F%V*<@V+38I]F&V+/;C"#8J-BQV*?;C"#9A=F$V+K;
MC"#:J=BQV*_9AB#8HMF&(-F&V*[9B-BGV8?9BMBO(-BOV*?8M-BJ+CPO<&%R
M83X@#0H@/"]E;G1R>3X-"CPO:&5L<#X`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5N7U53+P``
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,3`V,0`P,38V-C``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O96Y?55,O:&5L<"YX;6P`````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S,3$T`#$P-3$U-#,Q,#8Q`#`R,#,R-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/WAM;"!V
M97)S:6]N/2(Q+C`B/SX*/&AE;'`^"@H\96YT<GD@:60](G-U;6UA<GDB/@H\
M=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@
M<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y
M;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@
M;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@
M(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@
M8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN
M97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-
M86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S
M:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O
M<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N
M9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H
M92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B
M;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@
M8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R
M=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E
M('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)N879B87(B
M/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L
M93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B
M('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L
M:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U
M:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B
M;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED
M/2)P<F5F<RUD;U]M86EN=&5N86YC92(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](G!R969S+6-O;F9I<FU?
M;6%I;G1E;F%N8V4B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA
M;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X
M+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O
M;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*"CPO:&5L<#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+V5S7T53+P``````````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,0`P,38V-#4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O97-?15,O3$-?34534T%'15,O````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q
M`#`R,#0S,@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E<U]%4R],
M0U]-15-304=%4R]H;W)D92YM;P``````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T
M,C$W,S0`,3`U,34T,S$P-C$`,#(R,3`P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````B@<``!P```!L/```$PH`
M`+QX````````"*$```X````)H0``#P```!BA```-````**$```@````VH0``
M"P```#^A```,````2Z$```0```!8H0``&````%VA```;````=J$``"T```"2
MH0``'0```,"A```D````WJ$``"D````#H@``&0```"VB```F````1Z(```P`
M``!NH@``)````'NB```/````H*(```L```"PH@``#@```+RB```%````RZ(`
M`"@```#1H@``"````/JB```*`````Z,``!4````.HP``$@```"2C```+````
M-Z,``(4```!#HP``#@```,FC```*````V*,```T```#CHP``#@```/&C```1
M`````*0```T````2I```#````""D```-````+:0```8````[I```E````$*D
M```*````UZ0```\```#BI```&````/*D```,````"Z4```X````8I0``#@``
M`">E```(````-J4```D````_I0``+@```$FE```:````>*4``#(```"3I0``
M.````,:E``!4````_Z4``%$```!4I@``6@```*:F``!7`````:<``#0```!9
MIP``"0```(ZG```-````F*<```<```"FIP``"@```*ZG```/````N:<```4`
M``#)IP``!@```,^G```1````UJ<```@```#HIP``"0```/&G```)````^Z<`
M`"4````%J```(````"NH```3````3*@``!````!@J```#P```'&H```*````
M@:@```,```",J```#P```)"H```4````H*@```D```"UJ```#0```+^H```2
M````S:@``!D```#@J```'@```/JH```/````&:D```H````IJ0``#P```#2I
M```(````1*D``"0```!-J0``%````'*I```6````AZD```@```">J0``3@``
M`*>I```M````]JD``!D````DJ@``!P```#ZJ```,````1JH``"P```!3J@``
M#@```("J```#````CZH```L```"3J@``!P```)^J```'````IZH```4```"O
MJ@``!0```+6J```*````NZH```,```#&J@``%P```,JJ```*````XJH```\`
M``#MJ@``#@```/VJ```8````#*L``",````EJP``#@```$FK```4````6*L`
M`!<```!MJP``%P```(6K```7````G:L``!,```"UJP``#P```,FK```.````
MV:L``!\```#HJP``'0````BL```'````)JP```8````NK```"````#6L```/
M````/JP```8```!.K```"@```%6L```3````8*P```L```!TK```$````("L
M```5````D:P``!4```"GK```!P```+VL```0````Q:P```4```#6K```%0``
M`-RL```1````\JP```P````$K0``.P```!&M```X````3:T```D```"&K0``
M!P```)"M```4````F*T```,```"MK0``!0```+&M```0````MZT```D```#(
MK0``$P```-*M```Y````YJT``!(````@K@``)P```#.N```L````6ZX``"H`
M``"(K@``)0```+.N```*````V:X```8```#DK@``"0```.NN```'````]:X`
M`"\```#]K@``-P```"VO```N````9:\``%4```"4KP``+0```.JO```M````
M&+```#T```!&L```/P```(2P```M````Q+```$````#RL```(P```#.Q```C
M````5[$``$````![L0``+0```+RQ```S````ZK$``"4````>L@``%0```$2R
M```9````6K(``"D```!TL@``)````)ZR```H````P[(``!$```#LL@``"@``
M`/ZR```,````";,```H````6LP``$````"&S```6````,K,``!8```!)LP``
M!P```&"S```'````:+,``!0```!PLP``"@```(6S```(````D+,``"<```"9
MLP``"````,&S```'````RK,```<```#2LP``!@```-JS```%````X;,```<`
M``#GLP``!@```.^S```(````]K,``"D```#_LP``#@```"FT```*````.+0`
M``0```!#M```!P```$BT```)````4+0```8```!:M```$0```&&T```'````
M<[0``!8```![M```!````)*T```(````E[0```8```"@M```#0```*>T```&
M````M;0``!X```"\M```$0```-NT```(````[;0```T```#VM```#`````2U
M```'````$;4```,````9M0```P```!VU```7````(;4``!,````YM0``'0``
M`$VU```(````:[4```0```!TM0``"````'FU```(````@K4``#L```"+M0``
M-````,>U``!!````_+4``!H````^M@``*P```%FV```@````A;8``!4```"F
MM@``!@```+RV```&````P[8``!4```#*M@``&````."V```B````^;8``"X`
M```<MP``'0```$NW```A````:;<``%0```"+MP``*0```."W```*````"K@`
M``<````5N```!P```!VX```5````);@```X````[N```"@```$JX```/````
M5;@```T```!EN```#P```'.X```-````@[@```D```"1N```%````)NX```&
M````L+@``!@```"WN```'0```-"X```3````[K@``!$````"N0``%````!2Y
M```$````*;D```8````NN0``%````#6Y``!4````2KD``&0```"?N0``!```
M``2Z```.````";H```4````8N@``!0```!ZZ```;````)+H``!H```!`N@``
M$P```%NZ```1````;[H``!$```"!N@``'````).Z```J````L+H``!````#;
MN@``(0```.RZ```%````#KL``!,````4NP``"P```"B[```2````-+L```H`
M``!'NP``#P```%*[```-````8KL``!$```!PNP``$P```(*[```,````EKL`
M``8```"CNP``#````*J[```&````M[L``!<```"^NP``$````-:[```1````
MY[L```@```#YNP``!0````*\```,````"+P``!`````5O```!0```":\```-
M````++P```8````ZO```!P```$&\```-````2;P```<```!7O```"P```%^\
M```'````:[P```<```!SO```"0```'N\```)````A;P```H```"/O```&0``
M`)J\```]````M+P``!T```#RO```#````!"]```0````';T```4````NO0``
M)0```#2]```2````6KT``!,```!MO0``*P```(&]```[````K;T``"````#I
MO0``"`````J^```V````$[X``"$```!*O@``$````&R^```(````?;X```P`
M``"&O@``!@```).^```$````FKX```\```"?O@``#@```*^^```'````OKX`
M``H```#&O@``#0```-&^```?````W[X``!P```#_O@``(0```!R_```>````
M/K\``!D```!=OP``'@```'>_```;````EK\``"$```"ROP``+@```-2_```F
M`````\```!P````JP```'@```$?````<````9L```"8```"#P```*P```*K`
M```S````UL```"8````*P0``*P```#'!```X````7<$``!T```"6P0``%0``
M`+3!```O````RL$``"````#ZP0``$@```!O"```I````+L(``!X```!8P@``
M(````'?"```2````F,(``*(```"KP@``%@```$[#```C````9<,``"@```")
MPP``*0```++#```H````W,,``!\````%Q```%0```"7$```@````.\0``"4`
M``!<Q```*````(+$```M````J\0``#````#9Q```D@````K%```A````G<4`
M`!8```"_Q0``'````-;%```F````\\4``"H````:Q@``00```$7&``!$````
MA\8```P```#,Q@``!P```-G&```'````X<8```8```#IQ@``#0```/#&```0
M````_L8``!(````/QP``$P```"+'```2````-L<```<```!)QP``!````%''
M```0````5L<``!````!GQP``#````'C'```.````A<<```T```"4QP``#P``
M`*+'```3````LL<```T```#&QP``*````-3'```#````_<<```T````!R```
M!@````_(```1````%L@``!<````HR```&P```$#(```.````7,@```(```!K
MR```20```&[(```%````N,@``!````"^R```#P```,_(```$````W\@```T`
M``#DR```#@```/+(```#`````<D```X````%R0``"````!3)```/````'<D`
M``\````MR0``!P```#W)```-````1<D``!````!3R0``#0```&3)```+````
M<LD```8```!^R0``"P```(7)```,````D<D```H```">R0``$0```*G)```9
M````N\D```L```#5R0``#0```.')```B````[\D```\````2R@``&P```"+*
M```T````/LH```H```!SR@``&````'[*```2````E\H``!D```"JR@``%@``
M`,3*```B````V\H```T```#^R@``!P````S+```4````%,L```L````IRP``
M(@```#7+```O````6,L```L```"(RP``"0```)3+```9````GLL```L```"X
MRP``%P```,3+```7````W,L```D```#TRP``%@```/[+```/````%<P``!D`
M```ES```%@```#_,```.````5LP``!@```!ES```"````'[,```-````A\P`
M`"8```"5S```0P```+S,```(`````,T``!(````)S0``'P```!S-```(````
M/,T```L```!%S0``+P```%'-```.````@<T```4```"0S0``!@```);-``!%
M````G<T```,```#CS0``!P```.?-```$````[\T```H```#TS0``"@```/_-
M```/````"LX``!`````:S@``%P```"O.```1````0\X``!D```!5S@``%P``
M`&_.```)````A\X```4```"1S@``"P```)?.```*````H\X```(```"NS@``
M!0```+'.```-````M\X``!L```#%S@``%P```.'.```4````^<X```D````.
MSP``#@```!C/```-````)\\``!(````USP``.````$C/```@````@<\```@`
M``"BSP``#@```*O/``![````NL\``!@````VT```&````$_0```1````:-``
M``<```!ZT```!0```(+0```8````B-```!X```"AT```&P```,#0```9````
MW-```!L```#VT```&0```!+1```3````+-$```<```!`T0``"````$C1```&
M````4=$```8```!8T0``$````%_1```/````<-$``!````"`T0``#P```)'1
M```+````H=$```\```"MT0``#````+W1```/````RM$```<```#:T0``!@``
M`.+1```.````Z=$```P```#XT0``*`````72```/````+M(```@````^T@``
M"````$?2```3````4-(``!X```!DT@``(0```(/2```@````I=(``!D```#&
MT@``%P```.#2```E````^-(``!<````>TP``%@```#;3```$````3=,``!L`
M``!2TP``#0```&[3```,````?-,```,```")TP``!0```(W3```(````D],`
M``H```"<TP``#````*?3```+````M-,``!````#`TP``#````-'3```.````
MWM,```L```#MTP``!````/G3```$````_M,``!,````#U```%````!?4```,
M````+-0```D````YU```#@```$/4```+````4M0``!L```!>U```!P```'K4
M```'````@M0```H```"*U```#0```)74```)````H]0```0```"MU```!0``
M`++4```#````N-0``!@```"\U```"@```-74```$````X-0``"8```#EU```
M#@````S5``!\````&]4``!4```"8U0``!0```*[5```'````M-4```P```"\
MU0``"````,G5```*````TM4```8```#=U0``"````.35```"````[=4```8`
M``#PU0``!@```/?5```4````_M4```T````3U@``$````"'6```;````,M8`
M``0```!.U@``"0```%/6```0````7=8```D```!NU@``"0```'C6```%````
M@M8``!H```"(U@``"````*/6```&````K-8``!D```"SU@``#@```,W6```'
M````W-8```<```#DU@``!0```.S6```)````\M8```H```#\U@``#@````?7
M```"````%M<```8````9UP``"P```"#7```-````+-<```D````ZUP``!@``
M`$37```2````2]<```D```!>UP``!P```&C7```4````<-<``!T```"%UP``
M0@```*/7```E````YM<``"4````,V```!@```#+8```*````.=@```0```!$
MV```"0```$G8```(````4]@``!$```!<V```"0```&[8```&````>-@```T`
M``!_V```!@```(W8```$````E-@``#D```"9V```/0```-/8```Z````$=D`
M`!X```!,V0``!0```&O9```.````<=D```0```"`V0``!@```(79```'````
MC-D``"$```"4V0``#0```+;9```5````Q-D```8```#:V0``!````.'9```1
M````YMD```8```#XV0``"@```/_9```B````"MH```0````MV@``!0```#+:
M```=````.-H```0```!6V@``#````%O:```.````:-H```H```!WV@``"```
M`(+:```)````B]H```4```"5V@``.@```)O:```P````UMH``#4````'VP``
M*0```#W;``!'````9]L``#@```"OVP``*0```.C;```_````$MP``"X```!2
MW```+0```('<```?````K]P```\```#/W```$@```-_<```+````\MP``"8`
M``#^W```*0```"7=```D````3]T``"8```!TW0``"````)O=```*````I-T`
M``D```"OW0``!P```+G=```@````P=T``"````#BW0``)@````/>```*````
M*MX``!D````UW@``*0```$_>```6````>=X``!(```"0W@``!P```*/>```*
M````J]X```P```"VW@``#P```,/>```0````T]X``$````#DW@``<````"7?
M``!F````EM\```X```#]WP``"0````S@```*````%N```!(````AX```$P``
M`#3@```,````2.````8```!5X```#P```%S@```2````;.```!````!_X```
M$0```)#@```<````HN```",```"_X```:@```./@```/````3N$```4```!>
MX0``$````&3A```)````=>$```0```!_X0``"P```(3A```@````D.$``!0`
M``"QX0``#````,;A```,````T^$```\```#@X0``%0```/#A```I````!N(`
M`"H````PX@``)@```%OB```G````@N(``"D```"JX@``*@```-3B```9````
M_^(``$(````9XP``$0```%SC```2````;N,``!,```"!XP``%````)7C```/
M````JN,``!8```"ZXP``%P```-'C```0````Z>,``!$```#ZXP``-`````SD
M```3````0>0``!(```!5Y```-0```&CD```4````GN0```<```"SY```#```
M`+OD```@````R.0``!````#IY```%````/KD```1````#^4``!<````AY0``
M'````#GE```3````5N4``!0```!JY0``&@```'_E```1````FN4``!H```"L
MY0``'@```,?E```:````YN4``!,````!Y@``%0```!7F```1````*^8``!<`
M```]Y@``%````%7F```7````:N8``!4```""Y@``"0```)CF```0````HN8`
M`!D```"SY@``!````,WF```'````TN8```L```#:Y@``$0```.;F```&````
M^.8```8```#_Y@``!@````;G```%````#><```<````3YP``!P```!OG```%
M````(^<``!8````IYP``!@```$#G```&````1^<```0```!.YP``!````%/G
M```'````6.<```X```!@YP``#````&_G```,````?.<```T```")YP``"@``
M`)?G```.````HN<```4```"QYP``*````+?G```.````X.<```P```#OYP``
M#P```/SG```*````#.@```@````7Z```"0```"#H```K````*N@```0```!6
MZ```"````%OH```F````9.@``!(```"+Z```#P```)[H```&````KN@```H`
M``"UZ```!P```,#H```(````R.@``"````#1Z```"0```/+H```4````_.@`
M``P````1Z0``#0```![I```.````+.D``!8````[Z0``$0```%+I```&````
M9.D```,```!KZ0``!@```&_I```9````=ND```<```"0Z0``!````)CI```+
M````G>D```L```"IZ0``!P```+7I```%````O>D```<```##Z0``%@```,OI
M```-````XND```T```#PZ0``"@```/[I```0````">H```\````:Z@``$0``
M`"KJ```7````/.H```H```!4Z@``$0```%_J```(````<>H```0```!ZZ@``
M#P```'_J```Z````C^H```4```#*Z@``#````-#J```>````W>H```X```#\
MZ@``$`````OK```+````'.L```P````HZP``"0```#7K```'````/^L```H`
M``!'ZP``"0```%+K```.````7.L``!````!KZP``&P```'SK```8````F.L`
M`!H```"QZP``"@```,SK```)````U^L```H```#AZP``#````.SK```/````
M^>L```@````)[```!@```!+L```<````&>P```<````V[```!0```#[L```+
M````1.P``$<```!0[```#0```)CL```)````INP```0```"P[````P```+7L
M```3````N>P``!,```#-[```$P```.'L```*````]>P```(`````[0``!```
M``/M```E````".T```,````N[0``!0```#+M```J````..T```H```!C[0``
M!0```&[M```$````=.T```H```!Y[0``#0```(3M```&````DNT```@```"9
M[0``"````*+M```$````J^T```4```"P[0``:````+;M```)````'^X```P`
M```I[@``$````#;N```%````1^X```8```!-[@``&P```%3N```O````<.X`
M`!````"@[@``"@```+'N```/````O.X```H```#,[@``"0```-?N```3````
MX>X``!L```#U[@``&````!'O```7````*N\``!\```!"[P``#@```&+O```#
M````<>\```<```!U[P``"````'WO```'````AN\```H```".[P``"P```)GO
M```'````I>\``%$```"M[P``$````/_O```,````$/````T````=\```&@``
M`"OP``!*````1O```!D```"1\```!@```*OP```:````LO```"4```#-\```
M!@```//P```&````^O```!\````!\0``!@```"'Q```)````*/$``!@````R
M\0``%P```$OQ```H````8_$```8```",\0``#0```)/Q```B````H?$``%<`
M``#$\0``$P```!SR```C````,/(``!,```!4\@```@```&CR```+````:_(`
M``@```!W\@``#0```(#R```*````CO(```<```"9\@``%````*'R```&````
MMO(```@```"]\@``#@```,;R```'````U?(```H```#=\@``"P```.CR```R
M````]/(```<````G\P``#````"_S```-````//,``!<```!*\P``#````&+S
M```)````;_,```D```!Y\P``"@```(/S```'````CO,```D```"6\P``!P``
M`*#S```*````J/,``!L```"S\P``#P```,_S```2````W_,```H```#R\P``
M%@```/WS```)````%/0``!`````>]```!P```"_T```2````-_0```0```!*
M]```!P```$_T```%````5_0```4```!=]```"P```&/T```4````;_0``!$`
M``"$]```&@```);T```6````L?0``!0```#(]```%P```-WT```8````]?0`
M`!P````.]0``&0```"OU```'````1?4```4```!-]0``#0```%/U```,````
M8?4```@```!N]0``%P```'?U```+````C_4```P```";]0``'P```*CU```:
M````R/4``!,```#C]0``!````/?U```*````_/4```0````']@``#0````SV
M```,````&O8```4````G]@``"0```"WV```%````-_8```<````]]@``!0``
M`$7V```$````2_8```(```!0]@``.````%/V```L````C/8``!(```"Y]@``
M*0```,SV```R````]O8```H````I]P``+````#3W```N````8?<``#,```"0
M]P``,P```,3W```X````^/<```\````Q^```&````$'X```0````6O@```\`
M``!K^```$P```'OX```5````C_@``!0```"E^```$@```+KX```4````S?@`
M`!4```#B^```+0```/CX```M````)OD``#$```!4^0``+@```(;Y```O````
MM?D``"P```#E^0``8@```!+Z```3````=?H```T```")^@``"````)?Z```7
M````H/H```@```"X^@``#````,'Z```K````SOH``"$```#Z^@``&@```!S[
M```)````-_L``$4```!!^P``00```(?[```$````R?L``!,```#.^P``%```
M`.+[```.````]_L``!,````&_```&````!K\```&````,_P```D````Z_```
M"@```$3\```/````3_P``!````!?_```!P```'#\```.````>/P```4```"'
M_```&P```(W\```(````J?P```8```"R_```%````+G\```1````SOP```X`
M``#@_```.````._\```"````*/T```8````K_0``#@```#+]```%````0?T`
M``<```!'_0``#@```$_]```&````7OT``"@```!E_0``#````([]```<````
MF_T```0```"X_0``*0```+W]```7````Y_T``!\```#__0``7````!_^```4
M````?/X``#X```"1_@``'P```-#^```0````\/X```<````!_P``#@````G_
M```,````&/\```P````E_P``$P```#+_```*````1O\``!T```!1_P``&0``
M`&__```%````B?\``!$```"/_P``$0```*'_```D````L_\``!(```#8_P``
M%0```.O_```2`````0`!``X````4``$`&0```",``0`(````/0`!``D```!&
M``$`#0```%```0`'````7@`!``H```!F``$`!P```'$``0`/````>0`!``8`
M``")``$`"P```)```0`:````G``!``H```"W``$`!P```,(``0`(````R@`!
M``4```#3``$`'P```-D``0`&````^0`!`!```````0$`"````!$!`0`-````
M&@$!``@````H`0$`'@```#$!`0`2````4`$!`"P```!C`0$`&@```)`!`0`)
M````JP$!``H```"U`0$`%0```,`!`0`%````U@$!`!0```#<`0$`!````/$!
M`0`0````]@$!``8````'`@$`!P````X"`0`>````%@(!`"@````U`@$`"@``
M`%X"`0`<````:0(!`!$```"&`@$`"P```)@"`0`:````I`(!`!0```"_`@$`
M!````-0"`0`$````V0(!``L```#>`@$`!0```.H"`0`&````\`(!``@```#W
M`@$`!@`````#`0`*````!P,!`!L````2`P$`-````"X#`0`T````8P,!`"``
M``"8`P$`*0```+D#`0`@````XP,!`$$````$!`$`&@```$8$`0`H````800!
M`"D```"*!`$`4````+0$`0`B````!04!``8````H!0$`"````"\%`0`%````
M.`4!``@````^!0$`&0```$<%`0`9````804!`"H```![!0$`(P```*8%`0`9
M````R@4!`"X```#D!0$`-````!,&`0`(````2`8!`!<```!1!@$`"@```&D&
M`0`'````=`8!`"$```!\!@$`$````)X&`0`.````KP8!``L```"^!@$`!P``
M`,H&`0`3````T@8!``@```#F!@$`"P```.\&`0`*````^P8!`!0````&!P$`
M#P```!L'`0`R````*P<!``L```!>!P$`#@```&H'`0`%````>0<!``4```!_
M!P$`!0```(4'`0`7````BP<!``\```"C!P$`!````+,'`0`*````N`<!``D`
M``##!P$`"P```,T'`0`-````V0<!``P```#G!P$`#@```/0'`0`%`````P@!
M``0````)"`$`#0````X(`0`R````'`@!`$4```!/"`$`%P```)4(`0`'````
MK0@!`!X```"U"`$`%````-0(`0`%````Z0@!`!0```#O"`$`!@````0)`0`'
M````"PD!``X````3"0$`*@```"()`0`&````30D!``P```!4"0$`#0```&$)
M`0`1````;PD!``L```"!"0$`-@```(T)`0`*````Q`D!`"(```#/"0$`"P``
M`/()`0`/````_@D!`#(````."@$`)0```$$*`0`P````9PH!`#$```"8"@$`
M+0```,H*`0`.````^`H!``4````'"P$`#@````T+`0`3````'`L!`!(````P
M"P$`!P```$,+`0`1````2PL!`!,```!="P$`!P```'$+`0`4````>0L!`!@`
M``"."P$`!P```*<+`0`%````KPL!``P```"U"P$`#````,(+`0`2````SPL!
M``0```#B"P$`!P```.<+`0`*````[PL!``L```#Z"P$`#`````8,`0`.````
M$PP!``X````B#`$`!0```#$,`0`%````-PP!`"X````]#`$`)@```&P,`0`C
M````DPP!``,```"W#`$`$@```+L,`0`&````S@P!`!X```#5#`$`&````/0,
M`0`E````#0T!``T````S#0$`"0```$$-`0`?````2PT!``,```!K#0$`!P``
M`&\-`0`*````=PT!``(```""#0$`#````(4-`0`5````D@T!``L```"H#0$`
M&0```+0-`0`@````S@T!`!(```#O#0$`!0````(.`0`*````"`X!`!4````3
M#@$`$@```"D.`0`,````/`X!``0```!)#@$`"0```$X.`0`'````6`X!``P`
M``!@#@$`4@```&T.`0`7````P`X!`"0```#8#@$`$@```/T.`0`'````$`\!
M``8````8#P$`#@```!\/`0`,````+@\!``T````[#P$`%0```$D/`0`2````
M7P\!``\```!R#P$`%````((/`0`*````EP\!`!L```"B#P$`$````+X/`0`+
M````SP\!`&D```#;#P$`&@```$40`0`7````8!`!`"<```!X$`$`&@```*`0
M`0`7````NQ`!`!L```#3$`$`&0```.\0`0`?````"1$!`!,````I$0$`"```
M`#T1`0`'````1A$!``@```!.$0$`"0```%<1`0`5````81$!``T```!W$0$`
M(P```(41`0`-````J1$!`!,```"W$0$`"````,L1`0`#````U!$!`$8```#8
M$0$`/P```!\2`0`W````7Q(!`%<```"7$@$`!0```.\2`0`?````]1(!`"\`
M```5$P$`"@```$43`0`(````4!,!``T```!9$P$`+0```&<3`0`$````E1,!
M`$\```":$P$`)0```.H3`0`<````$!0!``L````M%`$`'P```#D4`0`=````
M610!`"4```!W%`$`(````)T4`0`D````OA0!`"````#C%`$`"P````05`0`'
M````$!4!``T````8%0$`#````"85`0`7````,Q4!``8```!+%0$`.0```%(5
M`0`,````C!4!``<```"9%0$`"0```*$5`0`3````JQ4!``D```"_%0$`!```
M`,D5`0`0````SA4!``@```#?%0$`"````.@5`0`$````\14!``L```#V%0$`
M#`````(6`0`2````#Q8!`!$````B%@$`#````#06`0`:````018!``\```!<
M%@$`!P```&P6`0`-````=!8!`!0```""%@$`#@```)<6`0`,````IA8!`!L`
M``"S%@$`+````,\6`0`3````_!8!`!P````0%P$`*````"T7`0`&````5A<!
M``<```!=%P$`$P```&47`0`%````>1<!``0```!_%P$`%P```(07`0`*````
MG!<!``P```"G%P$`"0```+07`0`&````OA<!``D```#%%P$`"````,\7`0`)
M````V!<!``H```#B%P$`$0```.T7`0`&````_Q<!``X````&&`$`#@```!48
M`0`-````)!@!``L````R&`$`'0```#X8`0`+````7!@!``(```!H&`$`'```
M`&L8`0`'````B!@!``8```"0&`$`9````)<8`0`)````_!@!``<````&&0$`
M)@````X9`0`X````-1D!`!H```!N&0$`*@```(D9`0`[````M!D!`"@```#P
M&0$`-````!D:`0`9````3AH!`!4```!H&@$`!0```'X:`0`'````A!H!``@`
M``",&@$`!P```)4:`0`%````G1H!``<```"C&@$`#@```*L:`0`)````NAH!
M``8```#$&@$`"````,L:`0`+````U!H!``<```#@&@$`"````.@:`0`'````
M\1H!`!8```#Y&@$`"0```!`;`0`&````&AL!``L````A&P$`$````"T;`0`&
M````/AL!`!P```!%&P$`%````&(;`0`'````=QL!`!$```!_&P$`"````)$;
M`0`.````FAL!``@```"I&P$`$````+(;`0`)````PQL!`!````#-&P$`!@``
M`-X;`0`9````Y1L!``H```#_&P$`'`````H<`0`'````)QP!``4````O'`$`
M$````#4<`0`4````1AP!``L```!;'`$`#0```&<<`0`H````=1P!`!@```">
M'`$`%P```+<<`0`$````SQP!``D```#4'`$`"@```-X<`0`'````Z1P!``(`
M``#Q'`$`#@```/0<`0`(`````QT!`",````,'0$`'P```#`=`0`X````4!T!
M`"8```")'0$`,0```+`=`0`G````XAT!`&0````*'@$`%````&\>`0!5````
MA!X!`#@```#:'@$`2@```!,?`0!;````7A\!`"@```"Z'P$`.````.,?`0`H
M````'"`!`"P```!%(`$`&P```'(@`0`^````CB`!`*D!``#-(`$`(P```'<B
M`0`7````FR(!`$@```"S(@$`A0```/PB`0`P````@B,!`"4```"S(P$`00``
M`-DC`0!;````&R0!`$D```!W)`$`,0```,$D`0`=````\R0!`!@````1)0$`
M*P```"HE`0`A````5B4!`!\```!X)0$`*P```)@E`0`F````Q"4!`"<```#K
M)0$`.@```!,F`0`=````3B8!`!$```!L)@$`,P```'XF`0`E````LB8!`"<`
M``#8)@$`(``````G`0`?````(2<!`#````!!)P$`:0```'(G`0`Q````W"<!
M`$$````.*`$`,P```%`H`0`E````A"@!`#T```"J*`$`90```.@H`0!-````
M3BD!`"\```"<*0$`+@```,PI`0`P````^RD!`%0````L*@$`6@```($J`0!(
M````W"H!`$H````E*P$`,@```'`K`0`O````HRL!`"P```#3*P$`+0`````L
M`0!Q````+BP!`&8```"@+`$`;P````<M`0"S````=RT!`!<````K+@$`)0``
M`$,N`0`R````:2X!`"D```"<+@$`/@```,8N`0`B````!2\!`%(````H+P$`
M)0```'LO`0`+````H2\!`+$```"M+P$`10```%\P`0`A````I3`!`#````#'
M,`$`)0```/@P`0`<````'C$!`#$````[,0$`!P```&TQ`0`'````=3$!``0`
M``!],0$`#0```((Q`0`+````D#$!``X```"<,0$`"P```*LQ`0`%````MS$!
M`!````"],0$``@```,XQ`0!9````T3$!``4````K,@$`$@```#$R`0`$````
M1#(!``<```!),@$`"````%$R`0`%````6C(!`#````!@,@$``P```)$R`0`0
M````E3(!``P```"F,@$`$P```+,R`0`-````QS(!``(```#5,@$`!P```-@R
M`0`&````X#(!`!0```#G,@$`#````/PR`0`8````"3,!``8````B,P$`$@``
M`"DS`0`,````/#,!``,```!),P$`*@```$TS`0`$````>#,!``8```!],P$`
M!P```(0S`0`?````C#,!`#4```"L,P$`+@```.(S`0`O````$30!`!<```!!
M-`$`(@```%DT`0`E````?#0!`"````"B-`$`&P```,,T`0`8````WS0!`"0`
M``#X-`$`'P```!TU`0`:````/34!`"$```!8-0$`(````'HU`0`:````FS4!
M`#(```"V-0$`&@```.DU`0`O````!#8!`"L````T-@$`'P```&`V`0`C````
M@#8!`!\```"D-@$`&@```,0V`0`A````WS8!`"4````!-P$`)@```"<W`0`E
M````3C<!`"0```!T-P$`&````)DW`0`=````LC<!`"0```#0-P$`&````/4W
M`0`B````#C@!`"P````Q.`$`+P```%XX`0`5````CC@!`"4```"D.`$`/```
M`,HX`0`?````!SD!`",````G.0$`'P```$LY`0`@````:SD!`!H```",.0$`
M&````*<Y`0`I````P#D!`!X```#J.0$`*0````DZ`0`>````,SH!`#$```!2
M.@$`"0```(0Z`0`,````CCH!`!<```";.@$`+P```+,Z`0`D````XSH!``<`
M```(.P$`#P```!`[`0`4````(#L!``X````U.P$`#0```$0[`0`D````4CL!
M``4```!W.P$`!P```'T[`0`B````A3L!`"4```"H.P$`&@```,X[`0`=````
MZ3L!`!H````'/`$`!P```"(\`0#'````*CP!``L```#R/`$`%0```/X\`0`&
M````%#T!``D````;/0$`"P```"4]`0`-````,3T!`!<````_/0$`!@```%<]
M`0`S````7CT!`!,```"2/0$`$P```*8]`0`'````NCT!``\```#"/0$`!P``
M`-(]`0`R````VCT!``0````-/@$`(0```!(^`0`3````-#X!``P```!(/@$`
M$0```%4^`0`R````9SX!`!8```":/@$`"````+$^`0`=````NCX!``D```#8
M/@$`"@```.(^`0`4````[3X!``H````"/P$`'0````T_`0`(````*S\!`!\`
M```T/P$`"````%0_`0`:````73\!`"<```!X/P$`!@```*`_`0`5````IS\!
M``<```"]/P$`"````,4_`0`)````SC\!`#\```#8/P$`!P```!A``0`/````
M($`!``X````P0`$`$````#]``0`)````4$`!``D```!:0`$`"````&1``0`3
M````;4`!``<```"!0`$`&0```(E``0`*````HT`!`!<```"N0`$`%````,9`
M`0`*````VT`!``P```#F0`$`%P```/-``0`$````"T$!`"H````000$`#```
M`#M!`0`1````2$$!``<```!:00$``@```&)!`0`0````94$!`!@```!V00$`
M"P```(]!`0`#````FT$!``@```"?00$`!@```*A!`0`'````KT$!``T```"W
M00$`"P```,5!`0`4````T4$!`!4```#F00$`#@```/Q!`0`O````"T(!`"``
M```[0@$`'````%Q"`0`5````>4(!``P```"/0@$`,0```)Q"`0`%````SD(!
M`!(```#40@$`/P```.="`0`2````)T,!``H````Z0P$`!@```$5#`0`$````
M3$,!``0```!10P$`"@```%9#`0`3````84,!``4```!U0P$`!@```'M#`0`&
M````@D,!``@```")0P$`!````))#`0`,````ET,!``H```"D0P$`.0```*]#
M`0`N````Z4,!`"D````81`$`!0```$)$`0`8````2$0!`!D```!A1`$`'P``
M`'M$`0`=````FT0!`!$```"Y1`$``@```,M$`0`$````SD0!``H```#31`$`
M!@```-Y$`0`%````Y40!``,```#K1`$`#````.]$`0!%````_$0!`#(```!"
M10$`&@```'5%`0`T````D$4!`"@```#%10$`4P```.Y%`0`9````0D8!`'(`
M``!<1@$`(````,]&`0`U````\$8!`"$````F1P$`10```$A'`0`P````CD<!
M`"@```"_1P$`*0```.A'`0`F````$D@!`"4````Y2`$`*````%](`0`H````
MB$@!`"(```"Q2`$`*P```-1(`0`P`````$D!`!(````Q20$`$P```$1)`0`0
M````6$D!`'D```!I20$`"0```.-)`0"A````[4D!`',```"/2@$`?`````-+
M`0`K````@$L!`%0```"L2P$`%P````%,`0`G````&4P!`!8```!!3`$`#P``
M`%A,`0`7````:$P!`!\```"`3`$`0````*!,`0`?````X4P!`!P````!30$`
M40```!Y-`0`:````<$T!`!0```"+30$`"@```*!-`0`%````JTT!``8```"Q
M30$`"````+A-`0`%````P4T!`!(```#'30$`$````-I-`0`3````ZTT!`!T`
M``#_30$`#P```!U.`0`/````+4X!``0````]3@$`"0```$).`0`+````3$X!
M``<```!83@$`!0```&!.`0`4````9DX!``<```![3@$`"````(-.`0`/````
MC$X!``@```"<3@$`#````*5.`0`/````LDX!``8```#"3@$`%````,E.`0`&
M````WDX!``P```#E3@$`$0```/).`0`(````!$\!``0````-3P$`&0```!)/
M`0`1````+$\!``H````^3P$`&````$E/`0`3````8D\!`!P```!V3P$`$0``
M`)-/`0`$````I4\!``\```"J3P$`!P```+I/`0`$````PD\!`!D```#'3P$`
M!P```.%/`0`"````Z4\!``(```#L3P$`$0```.]/`0`)`````5`!``8````+
M4`$`$@```!)0`0`7````)5`!``8````]4`$`)P```$10`0`"````;%`!``0`
M``!O4`$`#P```'10`0`3````A%`!``<```"84`$`!P```*!0`0`1````J%`!
M``8```"Z4`$`&````,%0`0`&````VE`!`!,```#A4`$`$````/50`0`2````
M!E$!``(````940$`!@```!Q1`0`,````(U$!``D````P40$`$0```#I1`0`B
M````3%$!``<```!O40$`!P```'=1`0`+````?U$!``4```"+40$``@```)%1
M`0`+````E%$!`'T!``"@40$`#P```!Y3`0`2````+E,!``T```!!4P$`!@``
M`$]3`0`)````5E,!``<```!@4P$``P```&A3`0`9````;%,!`!\```"&4P$`
M,@```*93`0`O````V5,!`"@````)5`$`+0```#)4`0`9````8%0!`"L```!Z
M5`$`"@```*94`0`N````L50!`!8```#@5`$`"@```/=4`0`4`````E4!``4`
M```750$`+@```!U5`0`3````3%4!``L```!@50$`&@```&Q5`0`-````AU4!
M``X```"550$`F0```*15`0`-````/E8!``H```!,5@$`%P```%=6`0`.````
M;U8!`!$```!^5@$`#````)!6`0`6````G58!``P```"T5@$`!@```,%6`0"=
M````R%8!``H```!F5P$`#P```'%7`0`5````@5<!`!$```"75P$`$P```*E7
M`0`3````O5<!``@```#15P$`"0```-I7`0`V````Y%<!`"0````;6`$`.```
M`$!8`0!#````>5@!`&4```"]6`$`8@```"-9`0!K````AED!`&@```#R60$`
M.@```%M:`0`/````EEH!`!4```"F6@$`#@```+Q:`0`3````RUH!`!D```#?
M6@$`!0```/E:`0`)````_UH!`!$````)6P$`#````!M;`0`-````*%L!``T`
M```V6P$`-````$1;`0`Q````>5L!``D```"K6P$`%````+5;`0`4````REL!
M``P```#?6P$`!@```.Q;`0`9````\UL!`!X````-7`$`#````"Q<`0`,````
M.5P!`!$```!&7`$`(P```%A<`0`H````?%P!`!(```"E7`$`#@```+A<`0`/
M````QUP!``H```#77`$`+P```.)<`0`9````$ET!`!D````L70$`#@```$9=
M`0!<````55T!`#H```"R70$`*@```.U=`0`)````&%X!``L````B7@$`-```
M`"Y>`0`.````8UX!``@```!R7@$`"@```'M>`0`'````AEX!``<```".7@$`
M!0```)9>`0`'````G%X!``L```"D7@$`!0```+!>`0`A````MEX!`!````#8
M7@$`%0```.E>`0`/````_UX!`!L````/7P$`-````"M?`0`)````8%\!`!<`
M``!J7P$`%@```()?`0`8````F5\!`"$```"R7P$`%P```-1?`0`1````[%\!
M``\```#^7P$`'P````Y@`0`E````+F`!``<```!48`$`!@```%Q@`0`'````
M8V`!``T```!K8`$`"0```'E@`0`)````@V`!`!(```"-8`$`"@```*!@`0`5
M````JV`!`!D```#!8`$`+````-M@`0`'````"&$!`!$````080$`!0```")A
M`0`6````*&$!`!(````_80$`$@```%)A`0`^````96$!`#X```"D80$`"0``
M`.-A`0`'````[6$!`!,```#U80$`!`````EB`0`%````#F(!``X````48@$`
M#@```"-B`0`7````,F(!`$<```!*8@$`%@```))B`0`F````J6(!`"L```#0
M8@$`+````/QB`0`T````*6,!``D```!>8P$`!@```&AC`0`)````;V,!``<`
M``!Y8P$`.````(%C`0`Z````NF,!`#<```#U8P$`7````"UD`0`V````BF0!
M`#8```#!9`$`1P```/AD`0!+````0&4!`#8```",90$`3@```,-E`0`L````
M$F8!`"X````_9@$`30```&YF`0`V````O&8!`#P```#S9@$`+@```#!G`0`8
M````7V<!`!P```!X9P$`,P```)5G`0`M````R6<!`"T```#W9P$`$P```"5H
M`0`*````.6@!``P```!$:`$`!0```%%H`0`.````5V@!`!\```!F:`$`)@``
M`(9H`0`'````K6@!``<```"U:`$`%0```+UH`0`*````TV@!``@```#>:`$`
M,P```.=H`0`*````&VD!``<````F:0$`!P```"YI`0`&````-FD!``4````]
M:0$`"````$-I`0`&````3&D!``H```!3:0$`-````%YI`0`2````DVD!``X`
M``"F:0$`!P```+5I`0`'````O6D!``H```#%:0$`!0```-!I`0`1````UFD!
M``8```#H:0$`$@```.]I`0`%`````FH!``@````(:@$`"````!%J`0`.````
M&FH!``8````I:@$`*0```#!J`0`1````6FH!``@```!L:@$`$0```'5J`0`,
M````AVH!``<```"4:@$``P```)QJ`0`#````H&H!`!H```"D:@$`&````+]J
M`0`J````V&H!``8````#:P$`!0````IK`0`'````$&L!``<````8:P$`2```
M`"!K`0!/````:6L!`&4```"Y:P$`)P```!]L`0`X````1VP!`"D```"`;`$`
M(@```*IL`0`&````S6P!``@```#4;`$`'0```-UL`0`E````^VP!`"<````A
M;0$`-````$EM`0`H````?FT!`"T```"G;0$`8@```-5M`0`V````.&X!``H`
M``!O;@$`"0```'IN`0`)````A&X!`!8```".;@$`#````*5N`0`.````LFX!
M`!0```#!;@$`$````-9N`0`4````YVX!`!,```#\;@$`#@```!!O`0`5````
M'V\!``<````U;P$`&````#UO`0`;````5F\!`!@```!R;P$`&P```(MO`0`9
M````IV\!``0```#!;P$`!P```,9O`0`4````SF\!`%@```#C;P$`<@```#QP
M`0`'````KW`!`!4```"W<`$`!0```,UP`0`%````TW`!`!L```#9<`$`&```
M`/5P`0`+````#G$!`!0````:<0$`&@```"]Q`0`>````2G$!`#L```!I<0$`
M#@```*5Q`0`L````M'$!``<```#A<0$`&P```.EQ`0`/````!7(!`!(````5
M<@$`#@```"AR`0`8````-W(!`!````!0<@$`%@```&%R`0`3````>'(!``X`
M``",<@$`!0```)MR`0`/````H7(!``8```"Q<@$`&````+AR`0`5````T7(!
M``\```#G<@$`"````/=R`0`%`````',!`!$````&<P$`$@```!AS`0`)````
M*W,!`!<````U<P$`!@```$US`0`'````5',!`!$```!<<P$`"@```&YS`0`,
M````>7,!``<```"&<P$`"````(YS`0`+````EW,!``D```"C<P$`"P```*US
M`0`?````N7,!`$D```#9<P$`)0```"-T`0`-````270!`!0```!7=`$`!0``
M`&QT`0`@````<G0!`!(```"3=`$`$P```*9T`0`Z````NG0!`$H```#U=`$`
M)P```$!U`0`)````:'4!`#P```!R=0$`*@```*]U`0`1````VG4!``D```#L
M=0$`"@```/9U`0`&`````78!``8````(=@$`$@````]V`0`0````(G8!``L`
M```S=@$`"@```#]V`0`/````2G8!`"P```!:=@$`+````(=V`0`M````M'8!
M`"X```#B=@$`(@```!%W`0`E````-'<!`"(```!:=P$`)@```'UW`0`V````
MI'<!`"X```#;=P$`)@````IX`0`H````,7@!`"0```!:>`$`,0```']X`0!%
M````L7@!`$````#W>`$`-0```#AY`0`T````;GD!`#X```"C>0$`)@```.)Y
M`0`E````"7H!`#P````O>@$`)0```&QZ`0`5````DGH!`#D```"H>@$`)0``
M`.)Z`0`G````"'L!`!0````P>P$`R@```$5[`0`;````$'P!`#$````L?`$`
M,````%Y\`0`S````CWP!`#$```##?`$`)P```/5\`0`H````'7T!`"L```!&
M?0$`,@```')]`0`U````I7T!`$L```#;?0$`-````"=^`0"D````7'X!`"<`
M```!?P$`'0```"E_`0`F````1W\!`#,```!N?P$`,0```*)_`0!.````U'\!
M`%4````C@`$`#0```'F``0`$````AX`!``8```",@`$`!0```).``0`/````
MF8`!``4```"I@`$`$0```*^``0`6````P8`!`!P```#8@`$`!P```/6``0`$
M````_8`!`!`````"@0$`$0```!.!`0`+````)8$!``H````Q@0$`$0```#R!
M`0`-````3H$!`!(```!<@0$`#0```&^!`0`Z````?8$!``8```"X@0$`$```
M`+^!`0`&````T($!`!$```#7@0$`%P```.F!`0`;`````8(!``\````=@@$`
M`@```"V"`0!)````,((!``L```!Z@@$`#````(:"`0`<````DX(!``4```"P
M@@$`%P```+:"`0`2````SH(!``,```#A@@$`$0```.6"`0`)````]X(!`!$`
M```!@P$`$````!.#`0`+````)(,!`!$````P@P$`%0```$*#`0`1````6(,!
M``P```!J@P$`%````'>#`0`.````C(,!``X```";@P$`$0```*J#`0`3````
MO(,!`!H```#0@P$`#@```.N#`0`0````^H,!`"L````+A`$`$0```#>$`0`<
M````280!`$0```!FA`$`#0```*N$`0`?````N80!`!0```#9A`$`&0```.Z$
M`0`6````"(4!`$,````?A0$`$````&.%`0`)````=(4!`!0```!^A0$`"P``
M`).%`0`V````GX4!`#4```#6A0$`"@````R&`0`5````%X8!`"D````MA@$`
M%P```%>&`0`6````;X8!`!8```"&A@$`"@```)V&`0`@````J(8!`!D```#)
MA@$`'````..&`0`8`````(<!`!D````9AP$`&````#.'`0`(````3(<!``L`
M``!5AP$`*0```&&'`0!8````BX<!``@```#DAP$`%````.V'`0`B`````H@!
M``D````EB`$`#````"^(`0`V````/(@!`!$```!SB`$`!@```(6(`0`&````
MC(@!`%4```"3B`$``P```.F(`0`'````[8@!`!4```#UB`$`$`````N)`0`/
M````'(D!`!0````LB0$`%0```$&)`0`;````5XD!`!8```!SB0$`'0```(J)
M`0`;````J(D!``D```#$B0$`!@```,Z)`0`+````U8D!``L```#AB0$``@``
M`.V)`0`&````\(D!`!,```#WB0$`+P````N*`0`7````.XH!`!4```!3B@$`
M"@```&F*`0`1````=(H!`!0```"&B@$`'````)N*`0`Y````N(H!`#<```#R
MB@$`$@```"J+`0`/````/8L!`(8```!-BP$`(P```-2+`0`@````^(L!`!$`
M```9C`$`!P```"N,`0`%````,XP!`!P````YC`$`+0```%:,`0`S````A(P!
M`!\```"XC`$`)0```-B,`0`?````_HP!`!<````>C0$`!P```#:-`0`'````
M/HT!``8```!&C0$`!@```$V-`0`/````5(T!``X```!DC0$`$````'.-`0`.
M````A(T!`!4```"3C0$`#P```*F-`0`+````N8T!`!,```#%C0$`"````-F-
M`0`(````XHT!`!4```#KC0$`#P````&.`0!%````$8X!`!0```!7C@$`"0``
M`&R.`0`.````=HX!`!\```"%C@$`(````*6.`0`G````QHX!`"8```#NC@$`
M&````!6/`0`7````+H\!`"````!&CP$`&````&>/`0`6````@(\!``D```"7
MCP$`&0```*&/`0`+````NX\!`!0```#'CP$``P```-R/`0`%````X(\!``<`
M``#FCP$`#@```.Z/`0`0````_8\!``T````.D`$`&````!R0`0`0````-9`!
M`!$```!&D`$`#P```%B0`0`$````:)`!``<```!MD`$`&@```'60`0`;````
MD)`!``@```"LD`$`$0```+60`0`4````QY`!``X```#<D`$`)P```.N0`0`'
M````$Y$!``D````;D0$`$````"61`0`0````-I$!``H```!'D0$`!P```%*1
M`0`+````6I$!``8```!FD0$`&````&V1`0`.````AI$!``8```"5D0$`*```
M`)R1`0`0````Q9$!`)L```#6D0$`&P```'*2`0`+````CI(!``<```":D@$`
M#P```**2`0`(````LI(!``H```"[D@$`!0```,:2`0`(````S)(!``,```#5
MD@$`!@```-F2`0`'````X)(!`!8```#HD@$`$````/^2`0`2````$),!`!T`
M```CDP$``@```$&3`0`$````1),!`!0```!)DP$`"@```%Z3`0`/````:9,!
M``4```!YDP$`(P```'^3`0`(````HY,!``8```"LDP$`&P```+.3`0`/````
MSY,!``<```#?DP$`"````.>3`0`%````\),!``D```#VDP$`#P````"4`0`1
M````$)0!``(````BE`$`!@```"64`0`/````+)0!`!(````\E`$`$````$^4
M`0`&````8)0!`!,```!GE`$`"P```'N4`0`'````AY0!`!@```"/E`$`,```
M`*B4`0!-````V90!`"L````GE0$`+0```%.5`0`&````@94!``D```"(E0$`
M!````)*5`0`)````EY4!``D```"AE0$`%P```*N5`0`,````PY4!``8```#0
ME0$`#0```->5`0`'````Y94!``0```#ME0$`00```/*5`0!(````-)8!`$$`
M``!]E@$`)P```+^6`0`%````YY8!``T```#ME@$`!P```/N6`0`(`````Y<!
M``D````,EP$`&P```!:7`0`9````,I<!`!4```!,EP$`!@```&*7`0`%````
M:9<!`!````!OEP$`"````("7`0`*````B9<!`",```"4EP$`!````+B7`0`'
M````O9<!`"<```#%EP$`!@```.V7`0`)````])<!`!,```#^EP$`$P```!*8
M`0`(````)I@!``D````OF`$`!0```#F8`0!'````/Y@!`#0```"'F`$`00``
M`+R8`0`R````_I@!`$D````QF0$`.P```'N9`0`L````MYD!`#X```#DF0$`
M+P```".:`0`]````4YH!`#$```"1F@$`$````,.:`0`1````U)H!``L```#F
MF@$`,@```/*:`0`A````)9L!`!\```!'FP$`'@```&>;`0`'````AIL!``D`
M``".FP$`"@```)B;`0`'````HYL!`"D```"KFP$`+````-6;`0`]`````IP!
M``P```!`G`$`(P```$V<`0`V````<9P!`!8```"HG`$`%0```+^<`0`(````
MU9P!``L```#>G`$`#````.J<`0`0````]YP!`!<````(G0$`10```""=`0!\
M````9IT!`&<```#CG0$`#0```$N>`0`0````69X!`!$```!JG@$`%````'R>
M`0`5````D9X!`!<```"GG@$`"````+^>`0`1````R)X!`!,```#:G@$`$@``
M`.Z>`0`5`````9\!`"X````7GP$`+0```$:?`0"7````=)\!`!$````,H`$`
M!0```!Z@`0`5````)*`!``D````ZH`$`"P```$2@`0`+````4*`!`"4```!<
MH`$`&````(*@`0`/````FZ`!``X```"KH`$`%````+J@`0`9````SZ`!`"T`
M``#IH`$`+@```!>A`0`J````1J$!`"H```!QH0$`)@```)RA`0`H````PZ$!
M`!X```#LH0$`00````NB`0`5````3:(!`!0```!CH@$`%P```'BB`0`6````
MD*(!`!$```"GH@$`%P```+FB`0`6````T:(!`!0```#HH@$`%````/VB`0`[
M````$J,!`!D```!.HP$`&@```&BC`0`Z````@Z,!`!,```"^HP$`!@```-*C
M`0`0````V:,!`"T```#JHP$`%````!BD`0`5````+:0!`!4```!#I`$`(```
M`%FD`0`>````>J0!`!P```"9I`$`'````+:D`0`G````TZ0!`!,```#[I`$`
M(`````^E`0`F````,*4!`"````!7I0$`&0```'BE`0`=````DJ4!`!0```"P
MI0$`'````,6E`0`<````XJ4!`"$```#_I0$`&0```"&F`0`*````.Z8!`!(`
M``!&I@$`&P```%FF`0`$````=:8!``<```!ZI@$`"P```(*F`0`2````CJ8!
M``8```"AI@$`!@```*BF`0`'````KZ8!``8```"WI@$`!P```+ZF`0`%````
MQJ8!``4```#,I@$`%0```-*F`0`&````Z*8!``8```#OI@$`!0```/:F`0`%
M````_*8!``H````"IP$`$0````VG`0`*````'Z<!`!8````JIP$`%````$&G
M`0`*````5J<!`!<```!AIP$`!0```'FG`0`U````?Z<!`!(```"UIP$`$0``
M`,BG`0`:````VJ<!``\```#UIP$`#0````6H`0`0````$Z@!`#0````DJ`$`
M!0```%FH`0`(````7Z@!`"<```!HJ`$`$P```)"H`0`0````I*@!``8```"U
MJ`$`"@```+RH`0`-````QZ@!``8```#5J`$`(@```-RH`0`0````_Z@!`!L`
M```0J0$`$````"RI`0`5````/:D!`!$```!3J0$`&@```&6I`0`4````@*D!
M``8```"5J0$`!0```)RI`0`,````HJD!`"8```"OJ0$`!P```-:I`0`)````
MWJD!`!(```#HJ0$`%P```/NI`0`'````$ZH!``4````;J@$`!P```"&J`0`6
M````*:H!``T```!`J@$`#P```$ZJ`0`-````7JH!`!8```!LJ@$`&````(.J
M`0`/````G*H!`!$```"LJ@$`#````+ZJ`0`8````RZH!``P```#DJ@$`!P``
M`/&J`0`4````^:H!`$(````.JP$`"````%&K`0`,````6JL!`"T```!GJP$`
M%0```)6K`0`5````JZL!``T```#!JP$`#````,^K`0`)````W*L!``<```#F
MJP$`"@```.ZK`0`)````^:L!``X````#K`$`$````!*L`0`I````(ZP!`"4`
M``!-K`$`*@```'.L`0`*````GJP!``@```"IK`$`"@```+*L`0`,````O:P!
M``T```#*K`$`"0```-BL`0`.````XJP!`#4```#QK`$`!0```">M`0`.````
M+:T!`!H````\K0$`70```%>M`0`:````M:T!``X```#0K0$`!````-^M`0`$
M````Y*T!`!H```#IK0$`&@````2N`0`:````'ZX!``H````ZK@$``@```$6N
M`0`$````2*X!`"4```!-K@$``P```'.N`0`%````=ZX!`"D```!]K@$`"@``
M`*>N`0`%````LJX!``8```"XK@$`"P```+^N`0`1````RZX!``8```#=K@$`
M!P```.2N`0`(````[*X!``0```#UK@$`!0```/JN`0!K`````*\!``H```!L
MKP$`#0```'>O`0`=````A:\!``4```"CKP$`!@```*FO`0`I````L*\!`#8`
M``#:KP$`#@```!&P`0`)````(+`!`!,````JL`$`"@```#ZP`0`(````2;`!
M`!<```!2L`$`.````&JP`0`?````H[`!`!X```##L`$`(P```.*P`0`/````
M!K$!``0````6L0$`!P```!NQ`0`(````([$!``@````LL0$`$0```#6Q`0`/
M````1[$!``<```!7L0$`80```%^Q`0`1````P;$!``\```#3L0$`#P```..Q
M`0`;````\[$!`%$````/L@$`'````&&R`0`&````?K(!`!\```"%L@$`)@``
M`*6R`0`'````S+(!``8```#4L@$`(````-NR`0`(````_+(!``D````%LP$`
M(0````^S`0`@````,;,!`#P```!2LP$`"````(^S`0`*````F+,!`"<```"C
MLP$`5````,NS`0`;````(+0!`!\````\M`$`&@```%RT`0`#````=[0!``P`
M``![M`$`"````(BT`0`9````D;0!``T```"KM`$`!@```+FT`0`6````P+0!
M``8```#7M`$`"````-ZT`0`)````Y[0!``P```#QM`$`"@```/ZT`0`0````
M";4!`$$````:M0$`"0```%RU`0`:````9K4!`!<```"!M0$`(0```)FU`0`8
M````N[4!`!4```#4M0$`&````.JU`0`6`````[8!`!8````:M@$`%0```#&V
M`0`6````1[8!``H```!>M@$`'P```&FV`0`0````B;8!`!(```":M@$`"0``
M`*VV`0`,````M[8!``D```#$M@$`&0```,ZV`0`'````Z+8!`!<```#PM@$`
M!@````BW`0`'````#[<!``4````7MP$`!0```!VW`0`'````([<!`!,````K
MMP$`%````#^W`0`B````5+<!`"(```!WMP$`'0```)JW`0`<````N+<!`"(`
M``#5MP$`)@```/BW`0`?````'[@!``,````_N`$`!0```$.X`0`/````2;@!
M``\```!9N`$`"@```&FX`0`B````=+@!``T```"7N`$`$````*6X`0`C````
MMK@!`!T```#:N`$`%@```/BX`0`(````#[D!``X````8N0$`"0```">Y`0`0
M````,;D!`!,```!"N0$`"@```%:Y`0`)````8;D!``4```!KN0$`!P```'&Y
M`0`%````>;D!``0```!_N0$``@```(2Y`0`W````A[D!`#L```"_N0$`&0``
M`/NY`0`F````%;H!`$8````\N@$`#````(.Z`0`T````D+H!`#L```#%N@$`
M1`````&[`0!$````1KL!`$P```"+NP$`#P```-B[`0`@````Z+L!`!\````)
MO`$`'````"F\`0`?````1KP!`!\```!FO`$`(````(:\`0`@````I[P!`"``
M``#(O`$`#````.F\`0!!````]KP!`$$````XO0$`10```'J]`0!&````P+T!
M`$,````'O@$`0````$N^`0!Y````C+X!`!4````&OP$`$````!R_`0`)````
M+;\!`",````WOP$`!P```%N_`0`4````8[\!`#H```!XOP$`.````+._`0`D
M````[+\!``L````1P`$`4P```!W``0!*````<<`!``<```"\P`$`%P```,3`
M`0`5````W,`!``\```#RP`$`$`````+!`0`8````$\$!``<````LP0$`"@``
M`#3!`0`(````/\$!`!,```!(P0$`$````%S!`0`.````;<$!`!(```!\P0$`
M!0```(_!`0`D````E<$!``D```"ZP0$`!@```,3!`0`4````R\$!`!(```#@
MP0$`#P```//!`0!(`````\(!``<```!,P@$`!@```%3"`0`2````6\(!``4`
M``!NP@$`!P```'3"`0`/````?,(!``<```",P@$`-0```)3"`0`2````RL(!
M`"4```#=P@$`!`````/#`0`[````",,!``X```!$PP$`*````%/#`0"'````
M?,,!`!H````$Q`$`10```!_$`0`G````9<0!`!$```"-Q`$`"````)_$`0`.
M````J,0!``X```"WQ`$`#````,;$`0`3````T\0!``P```#GQ`$`(````/3$
M`0`<````%<4!``0````RQ0$`$````#?%`0`;````2,4!`"H```!DQ0$`%0``
M`(_%`0`1````I<4!`!8```"WQ0$`$0```,[%`0`?````X,4!``H`````Q@$`
M#`````O&`0`3````&,8!`!$````LQ@$`%P```#[&`0`0````5L8!`!P```!G
MQ@$`#@```(3&`0`5````D\8!`"(```"IQ@$`#0```,S&`0`&````VL8!``@`
M``#AQ@$`!0```.K&`0`@````\,8!``8````1QP$`$@```!C'`0`(````*\<!
M`!,````TQP$`"@```$C'`0`H````4\<!`!4```!\QP$`00```)+'`0`;````
MU,<!``L```#PQP$`#````/S'`0`E````"<@!``4````OR`$`%@```#7(`0`#
M````3,@!`!$```!0R`$`!0```&+(`0`*````:,@!`"4```!SR`$`.0```)G(
M`0`*````T\@!`"8```#>R`$`$P````7)`0`+````&<D!`!T````ER0$`%```
M`$/)`0`$````6,D!``@```!=R0$`"0```&;)`0`(````<,D!``L```!YR0$`
M"````(7)`0`'````CLD!``<```"6R0$`$@```)[)`0`J````L<D!`#<```#<
MR0$`&P```!3*`0`K````,,H!`",```!<R@$`00```(#*`0`;````PLH!`"0`
M``#>R@$`+0````/+`0!,````,<L!`"@```!^RP$`!P```*?+`0`(````K\L!
M``D```"XRP$`"````,++`0`5````R\L!`!0```#ARP$`+````/;+`0`O````
M(\P!`"(```!3S`$`-P```';,`0`_````KLP!``<```#NS`$`&@```/;,`0`)
M````$<T!``P````;S0$`+@```"C-`0`3````5\T!`!(```!KS0$`#0```'[-
M`0`+````C,T!`!@```"8S0$`"0```+'-`0`2````N\T!`!$```#.S0$`&@``
M`.#-`0`<````^\T!`#D````8S@$`"P```%+.`0`0````7LX!``4```!OS@$`
M"````'7.`0`%````?LX!`!H```"$S@$`#P```)_.`0`&````K\X!``\```"V
MS@$`$0```,;.`0`(````V,X!``X```#AS@$`#@```/#.`0`3````_\X!``4`
M```3SP$`$````!G/`0`-````*L\!`#P````XSP$`4@```'7/`0`B````R,\!
M``H```#KSP$`)P```/;/`0`;````'M`!``4````ZT`$`%P```$#0`0`)````
M6-`!``T```!BT`$`$@```'#0`0`J````@]`!``8```"NT`$`#0```+70`0`.
M````P]`!`!````#2T`$`"@```./0`0`]````[M`!``D````LT0$`(````#;1
M`0`0````5]$!`!0```!HT0$`0````'W1`0`F````OM$!`$(```#ET0$`0P``
M`"C2`0`\````;-(!``\```"IT@$`!P```+G2`0`2````P=(!`!(```#4T@$`
M&0```.?2`0`*`````=,!`!,````,TP$`&P```"#3`0`'````/-,!`!<```!$
MTP$`*````%S3`0`&````A=,!``<```",TP$`$````)33`0`5````I=,!`!<`
M``"[TP$`!P```-/3`0`'````V],!``D```#CTP$`%````.W3`0`2`````M0!
M`!,````5U`$`$P```"G4`0`&````/=0!``4```!$U`$`,0```$K4`0`H````
M?-0!`"4```"EU`$`"````,O4`0`/````U-0!``8```#DU`$`&@```.O4`0`9
M````!M4!`"L````@U0$`"0```$S5`0`,````5M4!`"<```!CU0$``P```(O5
M`0`%````C]4!``T```"5U0$``P```*/5`0`,````I]4!`!,```"TU0$`"P``
M`,C5`0`7````U-4!`!@```#LU0$`$P````76`0`%````&=8!``H````?U@$`
M%@```"K6`0`5````0=8!``X```!7U@$`!P```&;6`0`,````;M8!``H```![
MU@$`$````(;6`0!=````E]8!`"8```#UU@$`/````!S7`0`2````6=<!``<`
M``!LUP$`!@```'37`0`+````>]<!`!0```"'UP$`%````)S7`0`<````L=<!
M`!\```#.UP$`%@```.[7`0`>````!=@!`!`````DV`$`+0```#78`0`5````
M8]@!``T```!YV`$`;@```(?8`0`D````]M@!`"`````;V0$`*P```#S9`0`C
M````:-D!`!\```",V0$`(P```*S9`0`E````T-D!`!\```#VV0$`&P```!;:
M`0`*````,MH!``<````]V@$`"````$7:`0`*````3MH!`!,```!9V@$`#P``
M`&W:`0`M````?=H!`!@```"KV@$`'````,3:`0`(````X=H!``H```#JV@$`
M4@```/7:`0!%````2-L!`$````".VP$`>````,_;`0`-````2-P!`#````!6
MW`$`,0```(?<`0`*````N=P!``<```#$W`$`#0```,S<`0`Z````VMP!`!,`
M```5W0$`1````"G=`0`M````;MT!`"<```"<W0$`$````,3=`0`R````U=T!
M`",````(W@$`,P```"S>`0`J````8-X!`#(```"+W@$`*P```+[>`0`-````
MZMX!``D```#XW@$`$0````+?`0`3````%-\!`!@````HWP$`!P```$'?`0`W
M````2=\!``P```"!WP$`!````([?`0`%````D]\!`!(```"9WP$`"````*S?
M`0`&````M=\!`!0```"\WP$`"@```-'?`0`)````W-\!``4```#FWP$`$0``
M`.S?`0`1````_M\!`!H````0X`$`'````"O@`0`5````2.`!`"$```!>X`$`
M#0```(#@`0`'````CN`!`!(```"6X`$`*0```*G@`0`)````T^`!``D```#=
MX`$`&P```.?@`0`H`````^$!``X````LX0$`(0```#OA`0`T````7>$!``D`
M``"2X0$`"0```)SA`0`2````IN$!``8```"YX0$`!````,#A`0`B````Q>$!
M``T```#HX0$`#P```/;A`0`,````!N(!``@````3X@$`"0```!SB`0`(````
M)N(!``D````OX@$`#0```#GB`0`2````1^(!``8```!:X@$`&0```&'B`0`5
M````>^(!``<```"1X@$`$````)GB`0`@````JN(!``P```#+X@$``P```-CB
M`0`E````W.(!``8````"XP$`!@````GC`0![````$.,!``D```",XP$`!0``
M`);C`0`L````G.,!`$8```#)XP$`(P```!#D`0`O````-.0!`%````!DY`$`
M.@```+7D`0`]````\.0!`"0````NY0$`(````%/E`0`%````=.4!``<```!Z
MY0$`"````(+E`0`)````B^4!``<```"5Y0$`"````)WE`0`2````IN4!``H`
M``"YY0$`"0```,3E`0`+````SN4!``L```#:Y0$`!P```.;E`0`'````[N4!
M``@```#VY0$`%````/_E`0`+````%.8!``8````@Y@$`!0```"?F`0`D````
M+>8!``8```!2Y@$`+0```%GF`0`8````A^8!``@```"@Y@$`%````*GF`0`)
M````ON8!`!,```#(Y@$`"P```-SF`0`4````Z.8!``4```#]Y@$`%`````/G
M`0`&````&.<!`!H````?YP$`"@```#KG`0`<````1><!``@```!BYP$`!@``
M`&OG`0`2````<N<!`"0```"%YP$`"P```*KG`0`-````MN<!`"H```#$YP$`
M(0```._G`0`<````$>@!``4````NZ`$`"@```#3H`0`3````/^@!`!@```!3
MZ`$``P```&SH`0`3````<.@!``D```"$Z`$`)````([H`0`H````L^@!`#,`
M``#<Z`$`*````!#I`0`U````.>D!`"\```!OZ0$`9````)_I`0`6````!.H!
M`%P````;Z@$`.@```'CJ`0!)````L^H!`&L```#]Z@$`*@```&GK`0!!````
ME.L!`#$```#6ZP$`-P````CL`0`=````0.P!`$(```!>[`$`TP$``*'L`0`B
M````=>X!`!<```"8[@$`3````+#N`0"`````_>X!`#<```!^[P$`+````+;O
M`0`_````X^\!`%X````C\`$`2@```(+P`0`J````S?`!`"(```#X\`$`%```
M`!OQ`0`?````,/$!`"$```!0\0$`(````'+Q`0`K````D_$!`"0```"_\0$`
M(P```.3Q`0`^````"/(!`"(```!'\@$`%0```&KR`0`W````@/(!`"8```"X
M\@$`+````-_R`0`K````#/,!`!H````X\P$`+0```%/S`0!I````@?,!`#8`
M``#K\P$`20```"+T`0`W````;/0!`"T```"D]`$`0````-+T`0!P````$_4!
M`%(```"$]0$`-0```-?U`0`W````#?8!`#0```!%]@$`:P```'KV`0!S````
MYO8!`%H```!:]P$`60```+7W`0`W````#_@!`"D```!'^`$`*0```''X`0`O
M````F_@!`'D```#+^`$`;@```$7Y`0!W````M/D!`,0````L^@$`%@```/'Z
M`0`G````"/L!`#@````P^P$`+P```&G[`0!-````F?L!`"H```#G^P$`8P``
M`!+\`0`C````=OP!``L```":_`$`J````*;\`0!*````3_T!`"D```":_0$`
M.````,3]`0`J````_?T!`",````H_@$`/0```$S^`0`&````BOX!``L```"1
M_@$`!````)W^`0`*````HOX!``\```"M_@$`$0```+W^`0`+````S_X!``8`
M``#;_@$`$0```.+^`0`$````]/X!`&8```#Y_@$``P```&#_`0`4````9/\!
M``0```!Y_P$`!P```'[_`0`&````AO\!``4```"-_P$`-````)/_`0`(````
MR/\!`!4```#1_P$`#````.?_`0`1````]/\!`!$````&``(``P```!@``@`%
M````'``"``<````B``(`$@```"H``@`,````/0`"`!0```!*``(`!@```%\`
M`@`5````9@`"``T```!\``(``P```(H``@`N````C@`"``0```"]``(`!@``
M`,(``@`'````R0`"`"4```#1``(`1P```/<``@`X````/P$"`#D```!X`0(`
M&````+(!`@`G````RP$"`"H```#S`0(`)@```!X"`@`<````10("`"$```!B
M`@(`*````(0"`@`C````K0("`"````#1`@(`)````/("`@`F````%P,"`"(`
M```^`P(`-@```&$#`@`=````F`,"`#,```"V`P(`.0```.H#`@`F````)`0"
M`"H```!+!`(`*````'8$`@`C````GP0"`"@```##!`(`,@```.P$`@`K````
M'P4"`#````!+!0(`)@```'P%`@`D````HP4"`"4```#(!0(`+@```.X%`@`@
M````'08"`"<````^!@(`-P```&8&`@`Z````G@8"`!P```#9!@(`)@```/8&
M`@`]````'0<"`"<```!;!P(`*P```(,'`@`H````KP<"`"H```#8!P(`)```
M``,(`@`>````*`@"`$X```!'"`(`*````)8(`@`W````OP@"`"X```#W"`(`
M.0```"8)`@`)````8`D"`!````!J"0(`&````'L)`@`R````E`D"`"4```#'
M"0(`#0```.T)`@`/````^PD"`!8````+"@(`"@```"(*`@`.````+0H"`"H`
M```\"@(`"````&<*`@`+````<`H"`"\```!\"@(`,0```*P*`@`I````W@H"
M`"(````("P(`)````"L+`@`*````4`L"`.P```!;"P(`#````$@,`@`6````
M50P"``H```!L#`(`#0```'<,`@`2````A0P"`!<```"8#`(`*@```+`,`@`&
M````VPP"`%(```#B#`(`&@```#4-`@`:````4`T"``<```!K#0(`#P```',-
M`@`(````@PT"`$(```",#0(`!P```,\-`@`M````UPT"`!H````%#@(`$P``
M`"`.`@`4````-`X"`#0```!)#@(`(````'X.`@`'````GPX"`"0```"G#@(`
M"````,P.`@`)````U0X"`!<```#?#@(`"@```/<.`@`<`````@\"``@````?
M#P(`+@```"@/`@`'````5P\"`",```!?#P(`)P```(,/`@`'````JP\"`!4`
M``"S#P(`!P```,D/`@`(````T0\"``D```#:#P(`0````.0/`@`'````)1`"
M``P````M$`(`$P```#H0`@`/````3A`"``D```!>$`(`"````&@0`@`'````
M<1`"`!,```!Y$`(`!@```(T0`@`:````E!`"``L```"O$`(`&@```+L0`@`4
M````UA`"``L```#K$`(`#0```/<0`@`@````!1$"``4````F$0(`-0```"P1
M`@`,````8A$"``\```!O$0(`"P```'\1`@`#````BQ$"`!0```"/$0(`(@``
M`*01`@`+````QQ$"``,```#3$0(`"````-<1`@`,````X!$"``H```#M$0(`
M$````/@1`@`.````"1("`!(````8$@(`$P```"L2`@`1````/Q("`#@```!1
M$@(`(0```(H2`@`?````K!("`"$```#,$@(`"0```.X2`@`T````^!("``<`
M```M$P(`%P```#43`@!`````31,"`!,```".$P(`$P```*(3`@`(````MA,"
M``0```"_$P(`!@```,03`@`/````RQ,"`!T```#;$P(`!P```/D3`@`(````
M`10"``D````*%`(`!@```!04`@`&````&Q0"`!4````B%`(`%````#@4`@!"
M````310"`#,```"0%`(`*0```,04`@`%````[A0"`!L```#T%`(`'0```!`5
M`@`C````+A4"`"<```!2%0(`$@```'H5`@`"````C14"``0```"0%0(`#P``
M`)45`@`*````I14"``4```"P%0(``@```+85`@`-````N14"`$@```#'%0(`
M-P```!`6`@`6````2!8"`#<```!?%@(`+````)<6`@!:````Q!8"`!<````?
M%P(`@P```#<7`@`E````NQ<"`#H```#A%P(`(@```!P8`@`V````/Q@"`#@`
M``!V&`(`+0```*\8`@`L````W1@"`"P````*&0(`*@```#<9`@`N````8AD"
M`"X```"1&0(`,@```,`9`@`S````\QD"`#(````G&@(`%@```%H:`@`-````
M<1H"``X```!_&@(`A@```(X:`@`)````%1L"`*T````?&P(`<0```,T;`@"%
M````/QP"`"L```#%'`(`7````/$<`@`4````3AT"`"@```!C'0(`%@```(P=
M`@`0````HQT"`"0```"T'0(`(@```-D=`@!"````_!T"`"`````_'@(`'@``
M`&`>`@!<````?QX"`!H```#<'@(`$P```/<>`@`*````"Q\"``4````6'P(`
M!@```!P?`@`(````(Q\"``4````L'P(`%@```#(?`@`5````21\"`!<```!?
M'P(`(@```'<?`@`0````FA\"``\```"K'P(`!````+L?`@`,````P!\"``X`
M``#-'P(`!P```-P?`@`&````Y!\"`!D```#K'P(`#P````4@`@`&````%2`"
M`!4````<(`(`"0```#(@`@`,````/"`"`!0```!)(`(`#````%X@`@`8````
M:R`"``D```"$(`(`"P```(X@`@`8````FB`"``8```"S(`(`!0```+H@`@`G
M````P"`"`!L```#H(`(`"@````0A`@`9````#R$"`!8````I(0(`)````$`A
M`@`9````92$"``D```!_(0(`%0```(DA`@`(````GR$"``<```"H(0(`%P``
M`+`A`@`'````R"$"``(```#0(0(``@```-,A`@`?````UB$"``X```#V(0(`
M"`````4B`@`7````#B("`!D````F(@(`!P```$`B`@`K````2"("``(```!T
M(@(`!@```'<B`@`/````?B("`!D```".(@(`!0```*@B`@`*````KB("`!,`
M``"Y(@(`!P```,TB`@`9````U2("``H```#O(@(`%P```/HB`@`3````$B,"
M`!(````F(P(``@```#DC`@`'````/","`!$```!$(P(`!@```%8C`@`.````
M72,"`#````!L(P(`"0```)TC`@`*````IR,"`!0```"R(P(`!0```,<C`@`"
M````S2,"``L```#0(P(``0```-4$```>!```,P4``&$#````````G@$``&\"
M``"B!````````)8#``#)`0``_`8``'P``````````````(@"```J!P``#0$`
M``````""!P``P0```'D%```7!```\04``"P```#=`P``P@8``"0'```*`@``
M`P0``+X%```#!P``,P,```````"H`@``N`8``&8"``"T`@``$00``(,#````
M````````````````````V`0``%,%``"'!`````````````#X`0``<@(`````
M````````@0(``#`$````````)0$``*8%````````8P<``.4%``"0!@``)P$`
M`'$&``#W!```<`(``'(!```T!P``Q`$``-,"```Q!```<0,``$\'``!:````
MI`$``#4!``"*!P```````'T!``#M````EP8``,(%``!=!P``3`4``,T&````
M````E@0``&0"``#T````*P(``&@"````````W00``(4&``#?!0``````````
M``"E````````````````````F@,```````!`````Y08```````#/`0``````
M`)\$``!*`@``P04```````#_`@``B0<````````.!0```````%$$``#-!0``
M[@(``"@%```7`````````#0```!8````O@$`````````````MP(``%P$``!G
M`P``;`,``&$!``"#!P``````````````````_`$``&8#``!O````V`$`````
M``!^!@````````D'``"0`````````$\#``"=`@```````!X#``!>!@``]@$`
M`-\````J`P``W@$``-(!``"X`P``20,````````<!P``$@<``"<#``#S````
ML@4``-0$`````````````*T#``"D`````````,P%``!C`P``>P,``)<$```,
M!````````(L&``#"`0```````.,$``!Y!P``VP,``.D!````````_P4``$L'
M``"K`0``6@0``.8!````````3P```,`!```````````````````Q`P``;0<`
M`(@&``"R`````````)H%``!I!```I08``.0!``!'!@```````"H```#]`0``
M:@$``%4'``#<`P``*08``*4$``!5!@``6`0``+`&````````GP(``%L```"3
M!@``C0,``*D`````````K@4``-,```"B`P``?`$``&D"``#$`P``*0<``'T#
M```K`````````#8``````````````#,"``"#````Y@0```````#X!```>P0`
M`$4'````````^0``````````````E0(``+P%````````&04``*P#```M`@``
M>P<```````!V!```/0(`````````````D@(``)`!``",!```W````'T'``!9
M!0``G`,```4"```\!P``8`,```@!````````1P0````````N!P``H0,``*<!
M`````````````&D%``!S`0````````````!#!@``VP```#X'``!*````````
M``0"````````*P$```````!8`P```````)X$````````S@$``&,$```8`P``
M`````"D$``!A```````````````G!```=P```/`#``!G!@```````)T&````
M!@``>P`````````9!@``LP0```,````$!P``W@4```````#+`P``?@(``!<'
M``#N``````````````!E`0```````/`"``":````D@```*`#````````G0$`
M`"T%``!S`@``]0,``$@#``#``@``O`$``-\$``#7!@``M@,``.4$``#,!```
MK`0````````9!P``&0(``,$$```:`0``LP(`````````````Y`,``)$"````
M````@`$``/X%``!K`0``%P8``/H!```L`P``30,``'0#``!)!```F`$``$<`
M``#*`0``<P,``$\&```Z````808``%,```#6!@``>`(````````P!0``*`(`
M`'0&``#O````"P8```0```#F`@``@`,``(4%``"+`0``E00````#``!E!P``
MZ`4``!D!````````H0$```X'``!]`@``?@````<$```*!P``+@8``#4&````
M````5`(``+\`````````>0,```$$````````"P```#4%`````````````&<'
M```H!@``W0````````#V`@``0`<```````#:`P``W`0`````````````:```
M``\"``!S!@```````-0&``#&!@``<0```*````#]!@``1`(```````"=!```
MNP,``,`````&!```#P8``$X!``"6`@``NP4``*(!``##`0````````4`````
M````30<``-@"``!C`````````,0```````````````````#T!````````$(%
M``!P!P```````,X&````````&0,``((&`````````````%0%````````````
M`/4$``!Y!```I`8``'$$```(````7@```$D'``"\`P``>`4``-X```"&`P``
M)@0``#T%``#X!@``G@,``'D"````````;`$``$`"``"_!@``[P4``,`$````
M````<`8```````")````IP(````````T!@```````!T'````````5P$``"0$
M```Z`0```````&\$````````B0(``'L%``""!0``U@`````````C`@``4`8`
M`#D$```U`@````````````"9`P```04```$'```)`P``:@8```````#S`0``
MQ@```/(#``"/````7`<`````````````Z`8``(<#`````````````-\"```P
M`P``60$``/4&````````YP$````!``!-````SP0``!(%````````.`$``)(#
M``!_`0``EP```%L$``"!!```<P```*D%``!:`@``A`(```````!"!@``>`$`
M```"````````Z00````````D`````````/H$``!M!```R`0``%L!```C!```
M!@```*$"``!@`@`````````````$!@``E@4```````#B!@``D`,``#X````M
M`0``%@(``-D#``"2!@````````````!N`P```````)`$``"C`````````,<#
M``!1````OP(``"X$```B!```ZP0````````M!@``^`(``"\&``!:!0``````
M````````````JP(``"8#`````````````+4!````````?0```"D#````````
M<P<```````"3!````````-`!``#Q!@``"@$```````````````````(!``!.
M!0``.08```````#*!0``$P$``.<```#\`P``G````+(#``#&`0```````'<$
M``!S!```V0(``,L%``!^`0``C@$``````````````````/T%```W!```````
M`#\'``"F!@``T@,``*D&``#O`0``I@````````#Q`@``````````````````
MKP0``.T!``#[!```X0,``"H$````````:`0``)\````0!@``NP0``.P#````
M````RP0``%T"``".!````````,8"``#`!0``1`4``'4'``#7!0``E`8`````
M``!D!P`````````````=!````````/8#``!4````V0````````!(````E@``
M``````!8`@``-P```"`&```^`@``=0(```````#U`@````````H$``"Y`@``
MIP0``'@'````````VP8``!4`````````VP0```````#^`````````"$%``"-
M!0``^0$``/<%``!^`P``V08``+8%``"7!0``!04`````````````````````
M``"%!```P0(``-`"```-!P``FP,```$#````````]@0``$$"``!5`0``````
M`,<$```T`0```````,T"``",`````````'(&``!-`0````````````"[!@``
M"P$``.`!```H!```I@,``,X%``!U`0``-00``!$&``"-!```8@`````````O
M````H08``#H"``!;`@``@`<``$@'``"/!0``&0````````"M````\0,``-(&
M``!^!0``,@```+\%``#,`@```````/<&``"W!@``704``$8!````````````
M`!\"```?!P``W`8````````0!0```````&(!```[`@``10(``+T!``""`P``
M`````"P!``!&````T@(``!0&````````?P```$0#```V!P``+P$``#,$``#C
M`0```````-,%``"V`@``Z@$``%8#``#Z`P``?P0```````"D`P``U@(``&0#
M``#L!0````````````!?````(0(``#0#``#^`@```````'4$````````@08`
M`#D%```\!0``&@0```````!V````I0,```````"9!0``9`4``!0"``!N`0``
M)`$```````".`````````&P%````````QP4``!P!``#B`0```````)4#``"8
M`````````(<%```8`````````"X%``"(!````````!P```":!@``:08``/T"
M``"'`0```````$X#``!I!P``?`0``!($``!E````5@4``,4&``!V`@``X```
M````````````N0,``'<#`````````````````````````````%X!````````
M.0<``(`"``!L``````````````"*`@```````,\&```-`@``$04``&\!```O
M`@``X04``.D"``!1`P``#P$``&````!G`````````,`&``#;`@``N@8`````
M`````````````.P```"T!```*``````````P!P```````/4```"L!0``_P$`
M`-<$```:````````````````````9`0```````#)!@``8`8``$X`````````
M%0(`````````````3`0``!8&```C````/P```(0%``"J!```N@(``),%``#D
M````1`0```````"Z!0``0P4``"$!``"Z`0```````)T%````````M0````('
M```L!P````````````"R!````````&H'``!]!0``9@``````````````````
M`-`$```)`0``6`8`````````````X`8``&$'```]`0``/00``'<"``#L!@``
M.P0``"`'``#^!@``Y@````X!````````2`8``)X&``"^!```9@8```L%``!&
M!P``````````````````=0,``(L```!Z!P``U`,```,"``"E`0``+@,`````
M``"U!````````"4'```#`P``[0(``'````!N!@``V````!(&``!'`P``7@<`
M`/,%``#I!@``TP0``$$#````````^P4``&8'``"@!@``U`(```````!M`0``
MT0```(H&```P````R@(``*,$``#N`0``X@```&P"``"H`0``7@(````````Z
M`P```````%P&```M!```8@,``.(%````````SP```)@%``#8!@``1P(`````
M````````EP$`````````````!P8``$@%``#_!@```````$L#``!N!0``5`<`
M`-4!``""`0````````````````````````````#_!```;@0```@$``!``P``
M(00``.$$````````7@,``(`$```3`@``+`8``,T$```=`P```````'\&``!U
M````!P,``),!````````K``````````&`@``>P$``"L$```U!P```````'H`
M``!T``````````````!D`0``5@$```T```!!`0``X`,``+4&```X!P``````
M```````F````````````````````B@4``)$$````````2`0```$&````````
MLP```%(!``"1!@``M`$``!@"``!2`@``B0,``&\'``#W`@``M@```/,&``#S
M`P``4P$``.0$``#Q!````````-`&````````,0(````````,!P``4```````
M``!6`@```````$P&``"#`@```````!P&````````]`8``(P&``"[````708`
M``````#[`0``A````$8&````````=P$`````````````1@(``$H!```7`P``
M`````"8!``!;`P``]P```)P%``!5!0``W08``#L!```:!P```````(H!``!>
M!0``600``$('``"<`@``/P,``!,#``"P!0``2P$```````"A!````````$`!
M``!J````@`4``*D#``"H!@``(`````````"N````2P```!(```"H!````P$`
M`'D&````````UP$``+H```#F`P``N`$`````````````:@0`````````````
MO@```+D```!T!````````!$```!A!0``Z`0``"(#``"M`0``Z````"0"``"?
M!@``OP$``/0!```Z!@``@P8```````"!````%`0``+T"```_!```@0$``!L`
M``"U`@```````+\#``!W!0``9P(``(4`````````SP(``,0&``"!!0``````
M`%D"``"A!0``\@$``*\#````````C`4``'0!``"Q````@P0```````#P!@``
M`````!$'``!Q`@```````.\#````````$@(``!8!```O`P``1@0```````#7
M`P``X0(```````!\!@``2P4```````#<!0``B00```````"R!@``^0(``+$$
M```'`@```````"$```#\!0``>0$``#X#```*!@``]`4``/("``!S!0``N@,`
M``````#6`P``Z@(``%D&````````?00``$,#````````+`(``)X%``#(!0``
MVP4``&,%```````````````'``!\!0``20(``#P```"\```````````````1
M`P`````````````0!P``-P8``!8$`````````````&,"```(!P``-0,`````
M``!"`0``/P4```````";!@````````````")`0``R0```.L#``#D!@``O0``
M`(T!``"_!````````#@#```W`@``'P4```````"'!@``L`0```D"``#M!```
MP0,``````````````````$L$``!1!@``MP0``'4%``#&`P```````&T#``#<
M`0``L@$```````"5!0```````,H&``"D!0````````L#``!_`P``$P````\$
M``#'`0``#00```````!#`@``50```.0%````````K@,```4#```;!```!@8`
M````````````[`0``.T%```,`P``J@4``+D$```6````5@0``#D!``!7!0``
MI@(``/L"````````@@(``"4%``#]`P``10$``&P$`````````````$$%```5
M`0```````/0#``#)!```O@8```````!*`P```````,\#``!?!0``?@0``#T&
M``#[````(`4``$@!````````JP```%@!``#J!```C0````````#0`P``.`8`
M````````````RP```(<```#?`P````````````#.!````````%('````````
M&P4```````#I`P``,0```,X#``"+!0``$@$```X```!K!P``IP```-$$``!B
M!P``&`8``-H````C`0``I`(``)H"``!@!```+P0``",'``!G`0``>@(``!0'
M```?!```V@4``)X"``!=`````````.($``!H!0``/P8``.@"````````M`4`
M```````&`P``(`0```````````````````8%````````E0$``(8&``!V`P``
ML0,``/H&````````E`0``(<"```>!@```````-X#````````70$``%L'```6
M`P``\P(``#,'``!V!0``J@,``%\!```K!@``````````````````KP8``.(#
M``!0`P``_@0``#H'``!Z!````````#$%``!H!@``U````*("``#[`P``````
M`"H%``"&!P``[@4``'0"````````*0`````````(`@````````L'``#G!```
M`````%(&`````````````"<'```"!@```````$@"``````````````````#9
M`0``S0```#D#```&`0```````"L'``!R!P``8P8```````"#!0``<`$``+$"
M``#&!```,`(``%<$``````````````````"&!0``%00``),"``!7!@``T@``
M`+`#``!)!@``-P<``'P'````````T@0``!T%````````O`0`````````````
MA`$`````````````)0(``%P!````````&P<``#('```B`@``J@(``"8'````
M````/`0``(L"``!K````\@8``#L%```^`0``$P4```````#F!0``B@```!X!
M``"M!```BP,```@%````````)`4``%\"````````[`$```````#\!```````
M`.$!``!)!0```````!,&``"(````ZP(``#8$``#G`P``K04``,\%``#)`P``
M`````$$$``````````````````#L`@``HP,````$```:!0``,P```/8%``!W
M!P```````&\&````````S0,``'$!```@`P``6P4```````"&````A0$`````
M``"T````D0,``(8$```R!```N0$``)L"``"B!0``N`(``.<"``!L!@``-`0`
M`*$````N`@``R@,```T#````````C@4````````;!@``K@0`````````````
M`````&T%````````V@$````````0!```"`8````````E````XP,``)X`````
M`````````'0%```?!@```````!<!``!`!0``'0```,X"``"@!0``B08``)`"
M```C!0``F`(```````!`!@``008``*,!``"C!0``*0(`````````````+0``
M`$H'``"7`@``5`0`````````````-@(``/@%``!V`0``7P,``#<!````````
M4`0``%@%``"D!```"0```,4%``"%`P```````%H!``!K`@``[@,``!L"````
M````Q`(``%H'``!%`P``/@0``)(!``#H`0``Y0,``%,$`````````````*X"
M```0`@``'@(``%`!``!*!```"@````````!-!@``_@$``"X```"/`0``````
M`"T'``#O`@``ZP$``-$!``!N`@````````````#<`@``Q0(``"<```"U`P``
ME`4```````!N````$`````````"/!```'0$``'($``!V!P```@,``.`%``!3
M!P``M`,```<'``"/`P```````(\"``!I`0``A`,``,$!``!W!@``<`0``*H`
M``!0`@``9@4```````".`P``+P<``(0$````````O@,``$`$```:`@``````
M`#D"``"4`P``@@````($```````````````````1`@``%P(``,(```"]`P``
M`````-$&```R!0``\````,,%````````2@4``!,'``!9!P``!`0``&`!````
M`````````-L!``!*!@``\P0``&T&```Z!0``.P<``)P!``#A````O@(``,`#
M```8!`````````````";!0``ZP4``/<#````````0P<``!L#``#N!```EP,`
M``0#```)!@``C@8```````!A!```8`<``#`!```F!@```````&4&``!K`P``
M`````%\&``"W`P``#`(``$L"```?````#`8``&8!`````````````%$"````
M`````````*@%```Q!@``LP$```T&``#4`0``-P4``(@!``!<`````````#L&
M``#H`P``'`4``+T$``"O`@```````(````!\`P``00<```````"$!@``WP$`
M`#<#``#Q`0`````````````,````F`,``&4"``"@`@``\@4`````````````
M`````&8$`````````````.L```"X!0``H@8````````@`0``PP,``#P&``!R
M!0``A@$``&T"````````3P0``.<&````````QP8``)$!````````PP```!X'
M````````900``'0'````````#P4``#\!``!0!P``;P,``"(&``!$````%@<`
M````````````V@(``$D````]`P``&00```````#Q````:P8````````,!0``
M50,```D%```F!0``M@8``*L$```)!```20$``$0&```````````````````B
M!0```````+````"O````,`8``.\&``#C`````````",&```4`P``PP0``-H&
M`````````````($#```.!```&@,``*X!````````NP$``.,&``#.````````
M`)0!``!_!P``QP(```0%````````-@$```````"H````+@$``!`#````````
MD@0``!L!``"B````4@4```````#J!@``UP(```````````````````L$``";
M`0``G0,``*P!```.`@``U@4``/4%``#W`0``#P,```````"?`0``Q0``````
M``#(`@``5P```#@````J`@````````````#_`P``J00``+T%````````Q`4`
M``````!1`0``'P$``.T&``#Y!@``F`0``%($````````KP$`````````````
MI@$``*L%``"R`@``9`8```````#8`P``&`4``*@#````````'`(```(%````
M````AP<``($'``#2!0``Y0$``*T&``#E`@``P08``*T"``!R`P``D@4``+$!
M````````U`4``*,&````````MP4```````#0!0``;P4```````#Z`@``````
M`-X&`````````````"$#``!^!P``M@0``*<&````````Q@4``*D!``!#````
MGP,``!T"````````3@0````````$`0``F0(``%$%``!"`P``>@8``-X"````
M````1P<``&4%``"`!@``1@,``.4```!/!0``PP8`````````````````````
M``#0````70,``+<```![`@``104```````!3!@``V`4``$P"```]````+P4`
M``````![!@``X@(``&($```<`P``````````````````Q00```````#5`P``
MY`(``'H#``"4````B`<``!P$````````````````````````0P0``!H&````
M`````````%$'````````*P,``/\```!9`P`````````````B!P``4P,``#P"
M``"3````]0$``%<"``````````````X&````````FP0```````!$`0``80(`
M`$T$``!,!P``<`4``+,#````````A@(``$X&````````*`$```````#=`0``
M`````+,%``!Q!P``W@0``&L%``"T!@``*04``#T'``!$!P``3`,``&L$``#1
M`P```````&H"``"Q!0``@@0``'@#``#3`P``4@,``)H!``#C`@``3@(``,0$
M````````B@0``&P'``!R````````````````````_`(````````T!0``:@,`
M``8'```E`P``?08```````#J`P``F00``+<!``#+!@``T0(``"H!``"9`0``
MS0$```````!7!P``50(``%P#``"(!0```````#("``#Z````F0````````#,
M````L`(``#8%````````UP````````"G!0``````````````````)08``)D&
M``#P`0``(P,``#L```"8!@``0P$``,@#``".`@``!0<``!<%``!G!0``````
M````````````)`,``(P"```>````A`<``%8'``"O!0``10```'8&```Z!```
MQ0$``-8!``!"````9P0``"@'``!Q!0``]@8``%8````0`0``^@4``$\"````
M!0``7`(``*4%```%!@``Z@4``"(```!'!0```````$L&``":!```G`8``,,"
M```%!`````````````"]!@``<`,``!4&``#N!@```````'\%``#J````-@,`
M`%P%```4!0``$0$``"`"````````:@4````````Q`0``/P(``$\!```R`0``
M)P(``-4`````````)P4``&@#``#X````?`(``(\&`````````````*4"````
M````L`$``/X#``!C`0``N````)$```````````````````"5````*`,```\`
M`````````````(P#````````?P(``,D%``#(`0```````(@#```A!P``H`$`
M``````#=`@``RP$```P!``!7`P``>0```-8$``#%`P```````,P!```5`P``
M````````````````;@<``/($``!X!```"@,````````^!@``V@0```````"C
M`@``;0```)$%```8!P```````%@'```L!````@```&("```>!0```````/D%
M``!0!0```````,@````.`P``C0(```````"G`P``"@4````````[`P```0(`
M``\'``!?!```"P(```````!,````G`0``-,!```K!0``Z04```````!X````
M`````&@!``#R````\`4``$T"``"Y!0``!P4```````!2````[0,``$T%``#5
M!@``.0```,H$``"?!0``P@(``%\'```%`0``>`8``$8%``#?!@``````````
M```'````.`4``"T#``#\````R`8``!4'```#!@``R@```'H!```4`0``^0,`
M`.<%``"K!@``500``%0!````````"`,``+L"``!.!P``%````),#``"L`@``
M7@0``-D$```\`P``,@,``/8```!"!````````.`"``"Q!@````````````#=
M!0``8@8``,(#``#,`P``[P0``%T$``"6`0``B@,``&@'``"%!P``````````
M```5!0``C08``*8$```Q!P``C`$``$4$``";````(08``/0"``!U!@``````
M``````"X!````````!(#``#K!@``8@4```````#]!```E08``.,%```J!@``
M``````````#Y!````````+P"````````M@$``$4&````````K@8``%8&```^
M!0```````$$````X!````````#0"`````````P4```````"0!0``'P,``*D"
M`````````````%0#```G!@``U04``/L&````````J@$``&4#```3!```````
M``````!4!@``*0$``+4%````````Y@8``-4"````````B04``(4"``"Y!@``
M6@,``(,!````````\`0``"8"``#3!@```````#4```"\!@``RP(``*L#``!9
M`````````#,!````````X08``+,&```-!0``1P$``%L&``"Z!```-@8`````
M``!:!@```````&0````D!@``R0(```````"=`````0$```<!``!"`@``BP0`
M`&D```#9!0``(@$``*`$````````E`(``!8%````````/`$``-$%````````
M&`$```````!Z!0``QP```,P&`````````````&`%```E!```^`,``"P%``#I
M````P@0``*H&```=!@``3`$``#(&```"`@``:0,``.`$```X`@``````````
M``#]````K`8``)8&``!3`@```````#,&````("@E<R!D87ES(&%G;RD`("A!
M8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O
M=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN
M`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`
M)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N
M(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`
M)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F
M;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#
M86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z
M(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@
M=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R
M(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN
M9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T
M`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E
M(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@
M97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,
M:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`
M04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O
M='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER
M96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O
M=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z
M96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@
M4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E
M<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU
M;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@
M=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!
M9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N
M:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`
M06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E
M<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E
M<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E
M861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U3
M4"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@
M96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T
M97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`
M06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C
M=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T
M:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD
M(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC
M("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M
M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI
M80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES
M;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!
M=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF
M='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO
M=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E
M9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q
M=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A
M=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A
M:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N
M(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"
M('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`
M0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@
M:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H
M86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`
M0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U
M;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R
M;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO
M;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S
M.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N
M80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U
M;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D
M:6$`0V%M97)O;VX`0V%N(&YO="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD
M(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92X`0V%N(&YO="!M;W9E(&9I;&4H
M<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+@!#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B
M+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@
M9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I
M97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I
M;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F
M:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R
M('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@
M0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO
M=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I
M80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#
M;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M
M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O
M;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I
M;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O
M9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y
M(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A
M`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z
M(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R
M>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U
M<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`
M0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P
M96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R
M871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD
M;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S
M97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A
M=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R
M9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N
M="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N
M="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#
M=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+
M3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I
M;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B
M+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A
M<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$
M87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E
M8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)
M9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE
M=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`
M1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@
M<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T
M:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES
M<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I
M`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI
M;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G
M<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R
M<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R
M`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%
M9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P
M97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R
M`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA
M:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M
M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R
M9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U
M('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%
M;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L
M;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E
M871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C
M;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10
M('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@
M(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B
M+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&
M87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%0
M5$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL
M90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE
M`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1
M=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O
M<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U
M;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E
M+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA
M`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&
M=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R
M871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'
M97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I
M;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES
M8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N
M861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T
M96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U
M:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A
M9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(
M;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O
M<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE
M(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0
M(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`
M2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y
M`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R
M90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@
M=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE
M=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM
M86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L
M(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S
M97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R
M="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?
M0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E
M<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M
M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`
M26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R
M90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`
M26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@
M9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!)
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D
M9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME
M>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP
M92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S
M:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN
M=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L
M:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@
M<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@
M=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA
M;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L
M>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0
M*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N
M=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+
M87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y
M($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E
M`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H
M155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T
M(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S
M`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA
M`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT
M(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R
M`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO
M=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI
M<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S
M8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E
M<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E
M<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A
M;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S
M>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,
M;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E
M<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA
M9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`
M36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N
M`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`
M36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-
M875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I
M8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E
M>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S
M(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE
M;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@
M;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T
M90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!2
M97!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S
M=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN
M9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.
M979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R
M;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI
M8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N
M9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`
M3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU
M;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@
M4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E
M="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`
M3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.
M;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O
M;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D
M:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T
M960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E
M<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M
M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C
M="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E
M`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD
M('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z
M($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A
M<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG
M(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/
M<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%
M05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N
M8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@
M4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U
M;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`
M4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@
M9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T
M;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@
M2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`
M4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3
M;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R
M;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO
M=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R
M9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U
M;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U
M;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S
M`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2
M;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R
M;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3
M($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N
M80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R
M86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@
M9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V
M97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N
M90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E
M9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S
M($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3
M:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA
M='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@
M36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@
M;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3
M;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R
M90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A
M8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R
M=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3
M=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B
M)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E
M<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I
M<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I
M<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I
M;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD
M`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B
M;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R
M;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`
M5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`
M5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@
M:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO
M="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-
M4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4
M:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I
M;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@
M<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG
M;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K
M;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R
M+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S
M=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@
M:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD
M('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@
M8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M
M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S
M;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM
M93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L
M;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE
M('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@
M<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B
M)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E
M<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M
M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O
M;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE
M(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U
M<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?=&]P*0!4
M<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E
M`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM
M96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`
M56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B
M.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN
M92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE
M.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR
M96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T
M;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')I9V=E<B!F<F5E+V)U<WD@
M=7!D871E(&9O<B`E<P!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN
M86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R
M=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P
M9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`
M57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S
M97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T
M<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E
M9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5
M<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@
M86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN
M('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A
M;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L
M80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`
M5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R
M>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6
M:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET
M>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.
M('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE
M<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC
M;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/
M+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD
M($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O
M;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X
M=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y
M(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@
M;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@
M<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,
M20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@
M4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN
M+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U
M<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D
M9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I
M8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I
M=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I
M;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y
M970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N
M:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E
M<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@
M=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M
M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`V+3`U+3$X(#`X.C$W*S`R,#`*4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-BTP,BTQ-2`Q-SHR-"LP,3`P"DQA<W0M5')A;G-L871O
M<CH@36%N=65L(%`N($%Y86QA(#QM87EA;&%`=6YE>"YE<SX*3&%N9W5A9V4M
M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z
M(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`H:&%C92`E<R!D[6%S
M*0`@*$%C8V5D:65N9&\@82`E<RD`("AE;B`E<R!D[6%S*0`@*&AO>2D`("AM
M8?%A;F$I`"`H87EE<BD`96X@`"(E<R(@;F\@97,@=6X@9&ER96-T;W)I;RX`
M(B5S(B!N;R!E<R!U;F$@96QE8V-I\VX@=N%L:61A+@!.;R!S92!H82!C;VYF
M:6=U<F%D;R`B)7,B(&5N(&5L(')E9VES=')O(&1E($AO<F1E+@!.;R!S92!E
M;F-O;G1R\R!E;"!G96YE<F%D;W(@9&4@X7)B;VQE<R!D92`B)7,B+@!392!H
M82!A\6%D:61O("(E<R(@86P@<VES=&5M82!D92!G<G5P;W,N`%-E(&AA(&'Q
M861I9&\@(B5S(B!A;"!S:7-T96UA(&1E('!R:79I;&5G:6]S+@!.;R!S92!H
M82!C<F5A9&\@(B5S(CH@)7,N`%5S861O<R`E+C)F34(@9&4@)2XR9DU"('!E
M<FUI=&ED;W,@*"4N,F8E)2D`)60@)7,@>2`E<P!1=65D86X@)60@9.UA<R!H
M87-T82!Q=64@97AP:7)E(&QA(&-O;G1R87-E\6$N`"5D('!R;V[S<W1I8V]S
M(&1I87)I;W,`)7,@+2!!=FES;P!(=65L;&$@9&EG:71A;"!D92`E<P`E<R!+
M0@`E<R!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O("T@0V]N9FER;6%C
M:?-N`$-O;F9I9W5R86-I\VX@9&4@)7,`1FER;6$@9&4@)7,`06-U97)D;W,@
M9&4@;&EC96YC:6$@9&4@)7,`66$@97AI<W1E("5S+@`E<R!A(&QA<R`E<R`E
M<P`E<R!E<W3A('!R97!A<F%D;R!P87)A(')E86QI>F%R(&QA<R!O<&5R86-I
M;VYE<R!D92!M86YT96YI;6EE;G1O('-E;&5C8VEO;F%D87,N06-T:79E(&QA
M<R!C87-I;&QA<R!D92!L87,@;W!E<F%C:6]N97,@<75E(&1E<V5A(&5J96-U
M=&%R(&5N(&5S=&$@;V-A<VGS;BX`2&%C92!F86QT82`E<P`E<R!M:6YU=&]S
M`$YO('-E(&AA(&5N8V]N=')A9&\@)7,N`"5S(&%L("5S(&1E("5S`$1I<F5C
M8VEO;F5S(&1E("5S`$%G96YD82!D92`E<P!,:6)R971A(&1E(&YO=&%S(&1E
M("5S`%1A<F5A<R!D92`E<P`E<SH@)7,`)7,Z($5S=&4@;65N<V%J92!P=65D
M92!Q=64@;F\@<')O8V5D82!D92!Q=6EE;B!P87)E8V4@<V5R+B!%=FET92!S
M96=U:7(@8W5A;'%U:65R(';M;F-U;&\@:6YC;'7M9&\@;R!S=6UI;FES=')A
M<B!C=6%L<75I97(@:6YF;W)M86-I\VX@<&5R<V]N86P@86P@<F5M:71E;G1E
M+@`L('9E;G1O<V\@`"P@=F5N=&]S;R`E<R`E<P`L('9A<FEA8FQE(&1E("5S
M(&$@)7,`+2T@<V5L96-C:6]N87(@+2T`1F]R;6%T;R!D92`Q,B!H;W)A<P!&
M;W)M871O(&1E(#(T(&AO<F%S`#(T(&AO<F%S`#Q!;G1E<FEO<@!087)A(&5S
M=&4@8FQO<75E(&AA8V4@9F%L=&$@=6X@;6]T;W(@9&4@8F%S92!D92!D871O
M<RX`4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&ER<F5P87)A8FQE`$AA8V4@
M9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A('!A<F$@8VEF<F%R('5N(&UE
M;G-A:F4N`$AA8V4@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A('!A<F$@
M8V]M<')O8F%R('5N(&UE;G-A:F4@9FER;6%D;RX`2&%C96X@9F%L=&$@=6YA
M(&-L879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0('!R:79A9&$@>2!U
M;F$@9G)A<V4@8VQA=F4@<&%R82!D97-C:69R87(@=6X@;65N<V%J92X`2&%C
M96X@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0
M('!R:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@<&%R82!F:7)M87(@=6X@;65N
M<V%J92X`2&%C96X@9F%L=&$@=6YA(&-L879E(%,O34E-12!P^F)L:6-A+"!U
M;F$@8VQA=F4@4R]-24U%('!R:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@<&%R
M82!D97-C:69R87(@=6X@;65N<V%J92X`2&%C96X@9F%L=&$@=6YA(&-L879E
M(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=F4@4R]-24U%('!R:79A9&$@>2!U
M;F$@9G)A<V4@8VQA=F4@<&%R82!F:7)M87(@=6X@;65N<V%J92X`2&%C92!F
M86QT82!U;F$@8VQA=F4@4TU)344@</IB;&EC82!P87)A(&-I9G)A<B!U;B!M
M96YS86IE+@!.=6)E<R!M871I;F%L97,`3&EG97)A(&QL=79I82!M871I;F%L
M`$QL=79I82!M871I;F%L`$%G=6%C97)O<R!M871I;F%L97,`06=U86-E<F\@
M;6%T:6YA;"!D92!N:65V90!!32]030!)1"!D92!!4$D`06-E<F-A(&1E;"!E
M9&ET;W(`06-E<F-A(&1E+BXN`$EN9F5R:6]R($%B<RX`16X@;65D:6\@06)S
M+@!392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@9&ER96-T
M;W)I;R!61E,N`%-E(&AA(&1E;F5G861O(&5L(&%C8V5S;R!A;"!C<F5A<B!E
M;"!A<F-H:79O(%9&4RX`261E;G1I9&%D`$-O;G1R87-E\6$@9&4@86-C97-O
M`$ED96YT:61A9"!B;&]Q=65A9&$N`$-O;G1A8FEL:61A9`!!\6%D:7(`0?%A
M9&ER(&=R=7!O(&1E<V-E;F1I96YT90!!\6%D:7(@<')I=FEL96=I;R!D97-C
M96YD:65N=&4`0?%A9&ER(&%Q=>TZ`$'Q861I<B!G<G5P;P!!\6%D:7(@<')I
M=FEL96=I;P!!\6%D:7(@82`B)7,B('5N(&=R=7!O(&1E<V-E;F1I96YT90!!
M\6%D:7(@82`B)7,B('5N('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E`$'Q861I
M<B!U;B!U<W5A<FEO.@!!\6%D:7(@8V]L=6UN80!!\6%D:7(@;6EE;6)R;W,`
M0?%A9&ER('!A<@!!\6%D:7(@96P@;65N^B`E<R!C;VUO('!A;F5L(&QA=&5R
M86P@9&4@36]Z:6QL80!!\6%D:7(@82!L87,@9&ER96-C:6]N97,Z`$'Q861I
M<B!A(&QA<R!D:7)E8V-I;VYE<SH`0?%A9&ER('5S=6%R:6\`4V4@:&$@8?%A
M9&ED;R`B)7,B(&%L('-I<W1E;6$L('!E<F\@;F\@<V4@<'5E9&4@8?%A9&ER
M(&QA(&EN9F]R;6%C:?-N(&%D:6-I;VYA;"!D92!A;'1A.B`E<RX`4V4@:&$@
M8?%A9&ED;R`B)7,B(&%L('-I<W1E;6$N(%EA('!U961E(&EN:6-I87(@;&$@
M<V5S:?-N+@!,82!A9&EC:?-N(&1E('5S=6%R:6]S(&5S=.$@9&5S:&%B:6QI
M=&%D82X`1&ER96-C:?-N`$1I<F5C8VEO;F5S`$%D;6EN:7-T<F%D;W(@+2!D
M969I;F4@<')I=FEL96=I;W,@9&4@;W1R;W,@=7-U87)I;W,`061M:6YI<W1R
M86-I\VX`06YU;F-I;W,`069G86YI<W3A;@!!;&)A;FEA`$%R9V5L:6$`06QI
M87,`06QI;F5A<@!!;&EN96%C:?-N.@!4;V1O<P!4;V1O<R!L;W,@=7-U87)I
M;W,@875T96YT:69I8V%D;W,`5&]D;W,@;&]S(&=R=7!O<P!4;V1O<R!L;W,@
M<')I=FEL96=I;W,`5&]D;W,@;&]S(&QA9&]S`%!E<FUI=&ER('9A<FEA<R!D
M:7)E8V-I;VYE<P"_4&5R;6ET:7(@8V]N9FEG=7)A8VGS;B!D92!T:7!O(&1E
M(&QI<W1A<R!O<F1E;F%D87,_`%EA(&5X:7-T90!!8V-E<V\@24U34"!A;'1E
M<FYA=&EV;P!#;&%V92!)35-0(&%L=&5R;F%T:79A`%5S=6%R:6\@24U04R!A
M;'1E<FYA=&EV;P!$:7)E8V-I\VX@96QE8W1R\VYI8V$@86QT97)N871I=F$`
M4&QA;G1I;&QA<R!A;'1E<FYA=&EV87,`5&5X=&\@86QT97)N871I=F\`4V%M
M;V$@06UE<FEC86YA`%-E(&AA(&EN9&EC861O('5N('9A;&]R(&EL96=A;"X`
M4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&1E<V-O;F]C:61O+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QA`%!R;WAY(&%N\VYI;6\`4F5S<'5E<W1A`$%N=.%R
M=&ED80!!;G1I9W5A('D@0F%R8F%D;W,`07!L:6-A8VGS;@!,:7-T82!D92!A
M<&QI8V%C:6]N97,`3&$@87!L:6-A8VGS;B!E<W3A(&QI<W1A+@!!<&QI8V%R
M(&$@<F5C=7)S;W,@8V]M<&%R=&ED;W,@9&5S8V5N9&EE;G1E<P!!<')O8F%R
M`%1A;6'Q;R!A<')O>&EM861O`$%B<FEL`$%RX6)I9V\@*%=I;F1O=W,M,3(U
M-BD`5&%M8?%O(&1E;"!A<F-H:79O`$YO;6)R92!D96P@87)C:&EV;P"_17-T
M82!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&QA('-O;&EC:71U9"!D
M92!A;'1A(&1E("5S/P"_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI
M;F%R("(E<R(@>2!T;V1O<R!S=7,@<W5B9W)U<&]S/P!!<F=E;G1I;F$`07)M
M96YI80!!<FUE;FEO("A!4DU30TE)+3@I`$%R=&4`07)U8F$`27-L82!!<V-E
M;G-I\VX`1W+A9FEC;W,@07-C:6D`4F5G:?-N(&1E($%S:6$O4&%C[69I8V\`
MOU-O;&EC:71A<B!C;VYF:7)M86-I\VX@86YT97,@9&4@<F5A;&EZ87(@;W!E
M<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;S\`0V]L=6UN87,@9&4@87-I9VYA
M8VGS;@!);G1E;G1A(&5L:6UI;F%R('5N(&=R=7!O(&EN97AI<W1E;G1E+@!)
M;G1E;G1A(&5L:6UI;F%R('5N('!R:79I;&5G:6\@:6YE>&ES=&5N=&4N`$EN
M=&5N=&$@;6]D:69I8V%R('5N('!R:79I;&5G:6\@:6YE>&ES=&5N=&4N`$EN
M=&5N=&$@;6]D:69I8V%R('5N(')E8W5R<V\@8V]M<&%R=&ED;R!I;F5X:7-T
M96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<F%L:6$`075S=')I80!!=71H
M7V-Y<G-Q;#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C
M97-A<FEA+@!!=71H7V-Y<G5S.B!%;"!M;W1O<B!C87)E8V4@9&4@;&%S(&-A
M<&%C:61A9&5S(&YE8V5S87)I87,N`$%U=&A?8WER=7,Z($YO('-E(&5N8V]N
M='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE8V5S87)I82X`075T:%]F='`Z($YO
M('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!&5%`@;F5C97-A<FEA+B!#;VUP
M:6QE(%!(4"!C;VX@;&$@;W!C:?-N("TM96YA8FQE+69T<"X`075T:%]I;6%P
M.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@24U!4"!N96-E<V%R:6$N
M`$%U=&A?:W)B-3H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&MR8C4@
M;F5C97-A<FEA+@!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&%D
M:6-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&5L:6UI;F%C:?-N(&1E('5S=6%R
M:6]S(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.;R!S92!E;F-O
M;G1R\R!L82!E>'1E;G-I\VX@3$1!4"!N96-E<V%R:6$N`$%U=&A?;&1A<#H@
M3F\@<V4@<'5E9&4@8?%A9&ER(&5L('5S=6%R:6\@)7,N(,ES=&\@97,@;&\@
M<75E(&1I:F\@96P@<V5R=FED;W(Z(`!!=71H7VQD87`Z($EN8V%P87H@9&4@
M96QI;6EN87(@96P@=7-U87)I;R`E<P!!=71H7VQD87`Z($EN8V%P87H@9&4@
M86-T=6%L:7IA<B!E;"!U<W5A<FEO("5S`$%U=&A?;&1A<#H@3F\@97-TX2!S
M;W!O<G1A9&$@;&$@86-T=6%L:7IA8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I
M=F4@1&ER96-T;W)Y`$%U=&A?;6-A;#H@3F\@<V4@96YC;VYT<O,@;&$@97AT
M96YS:?-N($U#04P@;F5C97-A<FEA+@!!=71H7W-M8F%U=&@Z($YO('-E(&5N
M8V]N='+S(&QA(&5X=&5N<VGS;B!S;6)A=71H(&YE8V5S87)I82X`1F%L;/,@
M;&$@875T96YT:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!)34%0+@!&86QL
M\R!L82!A=71E;G1I9FEC86-I\VX`1F%L;/,@;&$@875T96YT:69I8V%C:?-N
M+B`E<P!%;"!S97)V:61O<B!2041)55,@:&$@<F5C:&%Z861O(&QA(&%U=&5N
M=&EF:6-A8VGS;BX`1F%L;/,@;&$@875T96YT:69I8V%C:?-N(&-O;B!E;"!S
M97)V:61O<B!&5%`N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@
M<V5R=FED;W(@4TU"+@!#86UP;W,@9&ES<&]N:6)L97,Z`$%Z97)B86EJ86X`
M17AC=7-A<R!"3T9(`$9O;F1O`$-O;&]R(&1E(&9O;F1O`$-O;G1R87-E\6$@
M:V5R8F5R;W,@:6YC;W)R96-T82X`3F]M8G)E(&1E('5S=6%R:6\@:V5R8F5R
M;W,@:6YC;W)R96-T;RX`0F%H86UA<P!"86AR86EN`$+A;'1I8V\@*$E33RTX
M.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$YO('-E(&5N8V]N='+S(&5L
M(&1I<F5C=&]R:6\@8F%S92!D92!I;>%G96YE<R`B)7,B+@!,[6YE82!B87-E
M`$)E;&%R=7,`0NEL9VEC80!"96QI>F4`0F5N:6X`0F5R;75D87,`0FAU=&%N
M`$-U;7!L96'Q;W,`3F\@<V4@96YC;VYT<O,@96P@8FQO<75E("(E<R(@9&4@
M;&$@87!L:6-A8VGS;B`B)7,B+@!/<&-I;VYE<R!D92!B;&]Q=64`5&EP;R!D
M92!B;&]Q=64`3F5G<FET80!";VQI=FEA`$UA<F-A9&]R97,`0F]R9&4`1W)O
M<V]R(&1E;"!B;W)D93H`0F]R9&5S`$)O<VYI82!(97)Z96=O=FEN80!!;6)O
M<P!";W1S=V%N80!);F9E<FEO<@!)<VQA(&1E($)O=79E=`!"<F%S:6P`5&5R
M<FET;W)I;R!O8V7A;FEC;R!D92!L82!);F1I82!B<FETX6YI8V$`0G)U;F5I
M($1A<G5S<V%L86T`0G5L9V%R:6$`3&ES=&$@9&5S;W)D96YA9&$`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!0=6YT;W,@9&4@9&ES=')I8G5C:?-N
M($-20P!0<F]P:65D861E<R!D92!?8V5L9&$N+BX`3F\@<V4@:&$@9FEN86QI
M>F%D;R!E;"!I;FEC:6\@9&4@;&$@8V%C:.DN`$%G96YD80!#86QM80!#86UB
M;WEA`$-A;65R^FX`3F\@<V4@<'5E9&4H;BD@8V]P:6%R(&5L+VQO<R!A<F-H
M:79O*',I("T@;W)I9V5N('D@9&5S=&EN;R!S;VX@96P@;6ES;6\N`$YO('-E
M('!U961E*&XI('1R87-L861A<B!E;"]L;W,@87)C:&EV;RAS*2`M(&5L(&1E
M<W1I;F\@97-TX2!D96YT<F\@9&5L(&]R:6=E;BX`3F\@<V4@<'5E9&4@<F5A
M:G5S=&%R(&QA(&-L879E(&%U=&]MX71I8V%M96YT92P@</-N9V%S92!E;B!C
M;VYT86-T;R!C;VX@96P@861M:6YI<W1R861O<B!D96P@<VES=&5M82X`3F\@
M<V4@<'5E9&4@97-C<FEB:7(@96X@96P@87)C:&EV;R`B)7,B`$YO('-E('!U
M961E;B!A9&UI;FES=')A<B!M86YE:F%D;W)E<R!D92!S97-I\VX@97AT97)N
M;W,N`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($E-05`Z("5S
M`$YO('-E('!U961E(&%B<FER(&5L(&%R8VAI=F\@(B5S(BX`0V%N863A`$-A
M;F-E;&%R`$-A;F-E;&%R(&EN9F]R;64@9&4@<')O8FQE;6%S`$YO('-E('!U
M961E(&5L:6UI;F%R(&5L(&%R8VAI=F\@(B5S(BX`3F\@<V4@96YC=65N=')A
M('5N(&1I<F5C=&]R:6\@=&5M<&]R86PN`$YO('-E('!U961E(&-O;G1I;G5A
M<B!S:6X@96P@<&%RX6UE=')O("=T87)G971&:6QE)RX`3F\@<V4@<'5E9&4@
M96QI;6EN87(@96P@9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P=65D92!E;&EM
M:6YA<BP@=&EE;F4@)60@9&5S8V5N9&EE;G1E<RX`3F\@<V4@<'5E9&4@<F5O
M<F1E;F%R+"!E;"!N^FUE<F\@9&4@96YT<F%D87,@<75E('-E(&1E<V5A(&]R
M9&5N87(@;F\@8V]I;F-I9&4@8V]N(&QA<R!A;&UA8V5N861A<RX`3F\@<V4@
M<'5E9&4@9&ER:6=I<B!E;"!M96YS86IE(&%L(&[Z;65R;R!E<W!E8VEF:6-A
M9&\N`$-A8F\@5F5R9&4`4W5B=.UT=6QO`%!R;W9E961O<@!#871E9V]R[6%S
M('D@971I<75E=&%S`$ES;&%S($-A:6WA;@!496SI9F]N;R!M\W9I;`!0<F]P
M:65D861E<R!D92!C96QD80!-87)G96X@9&4@8V5L9&$Z`%!R;W!I961A9&5S
M(&1E(&-E;&1A`$5S<&%C:6%D;R!D92!C96QD83H`5&5LZ69O;F\@;?-V:6P`
M0^EL=&EC;R`H25-/+3@X-3DM,30I`$-E;G1R87(`4F5P^F)L:6-A($-E;G1R
M;V%F<FEC86YA`$5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*0!$971A;&QE
M<R!D96P@8V5R=&EF:6-A9&\`4')O<&EE=&%R:6\@9&5L(&-E<G1I9FEC861O
M`%!O;.UT:6-A<R!D96P@8V5R=&EF:6-A9&\`0VAA9`!#86UB:6%R`$-A;6)I
M92!L82!C;VYT<F%S9?%A`$-A;6)I82!E;"!N;VUB<F4@>2!L82!D:7)E8V-I
M\VX@96QE8W1R\VYI8V$@=FES:6)L97,@86P@;&5E<B!O(')E<W!O;F1E<B!A
M('-U<R!M96YS86IE<RX`3&$@8V]N9FEG=7)A8VGS;B!A8W1U86P@;F\@<V]P
M;W)T82!E;"!C86UB:6\@9&4@8V]N=')A<V7Q87,N(%#S;F=A<V4@96X@8V]N
M=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N`$=RX69I
M8V\`5F5R:69I8V%R(%]V[6YC=6QO+BXN`$-H:6QE`$-H:6YA`$-H:6YO('-I
M;7!L:69I8V%D;R`H1T(R,S$R*0!#:&EN;R!T<F%D:6-I;VYA;"`H0FEG-2D`
M07!L:6-A8VGS;CH`16QI:F$@=6YA(&-O;G1R87-E\6$`16QI:F$@=6X@;F]M
M8G)E(&1E('5S=6%R:6\`16QI:F$@8_-M;R!M;W-T<F%R(&QA<R!F96-H87,Z
M`%-E;&5C8VEO;F%R('1I<&\@9&4@97-T:6QO(&1E(&QI<W1A("AP87)A(&QI
M<W1A<R!O<F1E;F%D87,I`$ES;&$@9&4@4&%S8W5A`$YO('-E(&5N8V]N='+S
M(&QA(&1E9FEN:6-I\VX@9&4@8VQA<V4@9&4@)7,N`$QI;7!I87(`16QI;6EN
M87(@971I<75E=&%S($U33V9F:6-E`$)O<G)A<B!C;VYS=6QT80!";W)R87(@
M=7-U87)I;SH@)7,`0F]R<F%R('5S=6%R:6\`0F]R<F%R(&1A=&]S(&1E;"!U
M<W5A<FEO`$1E<W!E:F%D;R!T87)D[6\`2&%G82!C;&EC:R!P87)A('-E9W5I
M<@!#;&EC:V%T96QL('!O<B!(5%10`$-E<G)A<B!V96YT86YA`$YU8F5S`$YU
M8F5S('1E;7!R86YA<P!N=6)O<V\`27-L87,@9&4@8V]C;W,@*$ME96QI;F<I
M`$]C=6QT87(@8F%R<F$@;&%T97)A;`!#;VQA<'-A<B!B;W)D97,`0V]L;VUB
M:6$`0V]L;W(`4V5L96-T;W(@9&4@8V]L;W(`4V5L96-C:?-N(&1E(&-O;&]R
M`$-O;'5M;F%S.@!4[71U;&]S(&1E(&QA<R!C;VQU;6YA<P!#\VUI8W,`0V]M
M86YD;P!);G3I<G!R+B!C;VUA;F1O<P!#;VUE;G1A<FEO`$YO;6)R92!C;VWZ
M;@!#;VUO<F]S`$-O;7!A\>UA`$]R9&5N861O<F5S`$-O;F1I8VGS;@!#;VYD
M:6-I;VYE<P!$:69E<F5N8VEA<R!D92!L82!C;VYF:6=U<F%C:?-N`$-O;F9I
M9W5R86-I\VX@<&%R82!S:6YC<F]N:7IA8VGS;B!C;VX@4$1!<RP@3?-V:6QE
M<R!C;VX@86=E;F1A('D@3W5T;&]O:RX`3&$@8V]N9FEG=7)A8VGS;B!E<W3A
M(&1E<V%C='5A;&EZ861A+@!#;VYF:6=U<F%R("5S`$-O;F9I<FUA<B!C;VYT
M<F%S9?%A`$-O;F=O`$-O;F=O+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&5L
M`$9A;&SS(&QA(&-O;F5X:?-N+@!&86QL\R!L82!C;VYE>&GS;CH@`%-E(&AA
M(')E8VAA>F%D;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@
M</IB;&EC;RX`4V4@:&$@<F5C:&%Z861O(&QA(&-O;F5X:?-N(&%L('-E<G9I
M9&]R(&1E(&-L879E<R!P^F)L:6-O+B!-;W1I=F\Z("5S("@E<RD`2&$@9F%L
M;&%D;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!&5%`N`$-O;G1A8W1O<P!3
M92!H86X@8?%A9&ED;R!C;W)R96-T86UE;G1E(&QO<R!C;VYT86-T;W,@82!S
M=7,@9&ER96-C:6]N97,`5&EP;R!D92!C;VYT96YI9&\@9&5L(&%R8VAI=F\@
M8V]M<')I;6ED;SH@`$-O;G1E;FED;R!D92`B)7,B`$-O;G1I;G5A<@!)<VQA
M<R!#;V]K`$-O;VMI90!#;W!I87(`1F%L;/,@;&$@8V]P:6$Z("5S`$-O<&EA
M<B!S96QE8V-I\VX`240@9&4@8V]S=&4`0V]S=&$@4FEC80!#;W-T82!D92!-
M87)F:6P`3F\@<V4@<'5E9&4@8VEF<F%R(&5L(&UE;G-A:F4@;65D:6%N=&4@
M4$=0.B``3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A:F4@;65D:6%N=&4@
M4$=0.B``3F\@<V4@<'5E9&4@8VEF<F%R(&5L(&UE;G-A:F4@;65D:6%N=&4@
M4R]-24U%`$YO('-E('!U961E(&9I<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E
M("!3+TU)344`3F\@<V4@<'5E9&4@8?%A9&ER(&5L(&-O;G1A8W1O+B`E<P!.
M;R!S92!P=65D92!E;FQA>F%R(&%L('-E<G9I9&]R($Q$05`N`$YO('-E('!U
M961E(&-O;7!R;V)A<B!E;"!S86QD;RX@)7,`3F\@<V4@<'5E9&4@8V]N96-T
M87(@86P@<V5R=FED;W(@3$1!4"X`3F\@<V4@<'5E9&4@8V]N96-T87(@86P@
M<V5R=FED;W(@(B5S(B!M961I86YT92!&5%`Z("5S`$YO('-E('!U961E(&-R
M96%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&5N
M(&1E<V-I9G)A<B!L;W,@9&%T;W,@4$=0.B``3F\@<V4@<'5E9&5N(&1E<V-I
M9G)A<B!L;W,@9&%T;W,@4R]-24U%+@!.;R!S92!P=65D92!E;&EM:6YA<B!E
M;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@96QI;6EN87(@;&$@;&ES=&$@
M9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!G
M=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&-O;F9I9W5R86-I\VX@(B5S(BX`
M3F\@<V4@<'5E9&4@9&5T97)M:6YA<F$@;&$@9&ER96-C:?-N(&1E(&-O<G)E
M;R!D96P@9&5S=&EN871A<FEO+@!.;R!S92!P=65D92!T<F%E<B!L82!L:6)R
M971A(&1E(&1I<F5C8VEO;F5S(&-O;7!L971A+@!.;R!S92!P=65D92!T<F%E
M<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VX@8V]M<&QE=&$N`$YO('-E('!U
M961E('1R865R(&QA(&QI<W1A(&-O;7!L971A(&1E(&QI<W1A<R!D92!D:7-T
M<FEB=6-I\VXN`$YO('-E('!U961E(&-A<F=A<B!L82!E<W1R871E9VEA("(E
M<R(N`$YO('-E('!U961E(&-R96%R(&5L(&1I<F5C=&]R:6\@(B5S(BX`3F\@
M<V4@<'5E9&4@;V)T96YE<B!L82!C;&%V92!P^F)L:6-A(&1E;"!S97)V:61O
M<B!D92!C;&%V97,N`$YO('-E('!U961E(&%B<FER("(E<R(@<&%R82!E<V-R
M:6)I<BX`3F\@<V4@<'5E9&4@86)R:7(@)7,N`$YO('-E('!U961E(&%B<FER
M(&5L(&WS9'5L;R!D92!T87)E87,@9&4@;6%N=&5N:6UI96YT;R`E<P!.;R!S
M92!P=65D92!A8G)I<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E
M(&QO8V%L:7IA<B!E;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!L965R
M("5S+@!.;R!S92!P=65D92!R97-T86)L96-E<B!L82!C;VYT<F%S9?%A(&1E
M;"!U<W5A<FEO('-O;&EC:71A9&\N(%!A<G1E(&1E(&QO<R!D971A;&QE<R!O
M('1O9&]S+"!S;VX@:6YC;W)R96-T;W,N(%!R=65B92!O=')A('9E>B!O('#S
M;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&5L('-I
M<W1E;6$@<&%R82!MX7,@:6YF;W)M86-I\VXN`$YO('-E('!U961E(&]B=&5N
M97(@;&$@04-,+@!.;R!S92!P=65D92!O8G1E;F5R(&QA(&QI8G)E=&$@9&4@
M9&ER96-C:6]N97,N("5S`$YO('-E('!U961E(&]B=&5N97(@;&$@;&ES=&$@
M9&4@9&ES=')I8G5C:?-N+B`E<P!.;R!S92!P=65D96X@;V)T96YE<B!L87,@
M;&ES=&%S(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&5N(&]B=&5N
M97(@;&%S(&-A<&%C:61A9&5S(&1E;"!S97)V:61O<@!.;R!S92!P=65D92!R
M97-T875R87(@;&$@8V]N9FEG=7)A8VGS;BX`3F\@<V4@<'5E9&4@96QI;6EN
M87(@96P@9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P=65D92!G=6%R9&%R(&QA
M(&-O;F9I9W5R86-I\VX@9&4@)7,N`$YO('-E('!U961E(&=U87)D87(@=6YA
M(&-O<&EA(&1E(&QA(&-O;F9I9W5R86-I\VXN`$YO('-E('!U961E(&=U87)D
M87(@=6YA(&-O<&EA(&1E(&QA(&-O;F9I9W5R86-I\VXZ("5S`$YO('-E('!U
M961E(&=U87)D87(@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C
M;VYF:6=U<F%C:?-N(&5N.B`B)7,B+@!.;R!S92!P=65D92!G=6%R9&%R(&QA
M(&-O<&EA("5S(&1E(&QA(&-O;F9I9W5R86-I\VXN`$YO('-E('!U961E(&=U
M87)D87(@96P@87)C:&EV;R`E<R!D92!C;VYF:6=U<F%C:?-N+B!0=65D92!U
M=&EL:7IA<B!U;F$@9&4@;&%S(&]P8VEO;F5S('!A<F$@<F5S=&%U<F%R(&5L
M(&/S9&EG;R!D92`E<R!O(&-O<&EA<B!M86YU86QM96YT92!A("5S(&5L(&/S
M9&EG;R!S:6=U:65N=&4N`$YO('-E('!U961E(&)U<V-A<B!E;B!E;"!S97)V
M:61O<B!,1$%0+@!.;R!S92!P=65D92!D97-V:6YC=6QA<B`B)7,B+@!.;R!S
M92!P=65D92!A8W1U86QI>F%R(&5L(&-O;G1A8W1O+B`E<P!.;R!S92!P=65D
M92!A8W1U86QI>F%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@
M<V4@<'5E9&4@97-C<FEB:7(@;&$@8V]N9FEG=7)A8VGS;B!D92`B)7,B.B`E
M<P!.;R!S92!P=65D92!L;V-A;&EZ87(@96P@<&%N96P@;&%T97)A;"!D92!-
M;WII;&QA+B!#;VUP<G5E8F4@<75E(&5S=.D@86)I97)T;RX`3F\@<V4@<'5E
M9&5N(&]T;W)G87(@86P@=7-U87)I;R`B)7,B(&QO<R!S:6=U:65N=&5S(&1E
M<F5C:&]S('!A<F$@;&$@8V%R<&5T82`B)7,B.B`E<P!497AT;R!C;VYT861O
M`%!A[7,`0W5R<V]S`$-R96%R`$-R96$@=6X@=NUN8W5L;P!#<F5A<@!#<F5A
M<B!S=6)C87)P971A<P!0<FEV:6QE9VEO<R!D92!C<F5A9&]R`$[Z;65R;R!D
M92!T87)J971A(&1E(&-RZ61I=&\`0W)O86-I80!#=6)A`#0@1F%S97,@86-T
M=6%L97,`4V5S:6]N97,@86-T=6%L97,`2&]R82!A8W1U86P`55),(&%C='5A
M;`!5<W5A<FEO<R!A8W1U86QE<P!4:65M<&\@86-T=6%L`$-O;F1I8VGS;B!A
M8W1U86PZ(`!%<W1I;&\@86-T=6%L`%!E<G-O;F%L:7IA(&QA<R!T87)E87,@
M82!E:F5C=71A<B!A;"!I;FEC:6%R('-E<VGS;B!E;B`E<RX`0V]R=&%R`$-O
M<G1A<B!S96QE8V-I\VX`0VAI<')E`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL
M:6-O("A7:6YD;W=S+3$R-3$I`$-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5
M*0!297#Z8FQI8V$@0VAE8V$`1$0`1%-.("AV96$@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO97,O<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$:6%R:6%M96YT90#!<E]B;VP@9&%T;W,`0V]N<W5L=&$@9&4@;&$@
M8F%S92!D92!D871O<P!&96-H80!392!H82!R96-I8FED;R!L82!F96-H80!3
M96QE8V-I\VX@9&4@9F5C:&$`1.UA`$5?;&EM:6YA<B!C;VQU;6YA`$1I8VEE
M;6)R90!.^FUE<F]S(&1E8VEM86QE<P!2961U8VER('-A;F=R861O`%!O<B!O
M;6ES:?-N`$-O;&]R('!O<B!O;6ES:?-N`$ED96YT:61A9"!P;W(@;VUI<VGS
M;@!3:&5L;"!P;W(@;VUI<VGS;@!$969I;FEC:6]N97,`)FYB<W`[16QI;6EN
M87(F;F)S<#L`16QI;6EN87(@8V5L9&$`16QI;6EN87(@9W)U<&\`16QI;6EN
M87(@<F5G:7-T<F\`16QI;6EN87(@<')I=FEL96=I;P!%;&EM:6YA<B!Y('9A
M8VEA<B!M96YS86IE<P!%;&EM:6YA<B!C96QD80!%;&EM:6YA<B!C;VQU;6YA
M`$5L:6UI;F%R('!L86YT:6QL87,@86QT97)N871I=F%S(&5X:7-T96YT97,`
M16QI;6EN87(@;65N<V%J97,`16QI;6EN87(@<')I=FEL96=I;W,@9&4@(B5S
M(@"_16QI;6EN87(@<')I=FEL96=I;W,@<&%R82`B)7,B('D@8W5A;'%U:65R
M('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E/P!%;&EM:6YA<B!F:6QA`$5L:6UI
M;F%R(&ED96YT:61A9"!S96QE8V-I;VYA9&$`16QI;6EN87(@<W5B8V%R<&5T
M87,`16QI;6EN82!L82!C;VQU;6YA(&%C='5A;`!%;&EM:6YA(&QA(&9I;&$@
M86-T=6%L`%-E(&AA(&5L:6UI;F%D;R!E;"!G=6GS;B!D92!A8W1U86QI>F%C
M:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX@(B5S(BX`2&]R82!D92!E;G1R96=A
M.@!$:6YA;6%R8V$`1&5S8W)I8F$@96P@<')O8FQE;6$`1&5S8W)I<&-I\VX`
M1&5T86QL97,@*'1A;6)IZ6X@96X@96P@87)C:&EV;R!D92!R96=I<W1R;R!D
M92!(;W)D92DZ`%-E(&AA;B!R96=I<W1R861O(&QO<R!D971A;&QE<R!P87)A
M(&5L(&%D;6EN:7-T<F%D;W(N`$1E<V%R<F]L;&\`4'5N=&\@9&4@8V]N9&5N
M<V%C:?-N`%!U;G1O(&1E(&-O;F1E;G-A8VGS;B!D92!L82#Z;'1I;6$@:&]R
M83H@`%!U;G1O(&1E(&-O;F1E;G-A8VGS;CH@`$1E(&EZ<75I97)D82!A(&1E
M<F5C:&$`1&4@9&5R96-H82!A(&EZ<75I97)D80!$:7)E8W1O<FEO`+]-;W-T
M<F%R(&5N(&9O<FUA=&\@9&4@,C0M:&]R87,_`$]P8VEO;F5S(&1E(%9I<W5A
M;&EZ86-I\VX`36]S=')A<B!P<F]N\W-T:6-O(&1E=&%L;&%D;P!-;W-T<F%R
M('!R;V[S<W1I8V\@*%1!1BD`1F]R;6%T;R!D92!V:7-U>F%L:7IA8VGS;@!.
M;W1I9FEC86-I\VX@9&4@8V]N<W5L=&$`1&II8F]U=&D`3F\@96QI;6EN87(`
M3F\@86-C961E<B!D:7)E8W1A;65N=&4@82!M86EN=&5N86YC92YP:'``OT-O
M;G1I96YE(&QA('!R:6UE<F$@9FEL82!L;W,@;F]M8G)E<R!D92!L;W,@8V%M
M<&]S/R!3:2!E<R!A<^TL('-E;&5C8VEO;F4@97-T82!C87-I;&QA.@!$;VUI
M;FEC80!297#Z8FQI8V$@1&]M:6YI8V%N80"_3F\@9&ES<&]N92!D92!C=65N
M=&$_(%-O;&EC[71E;&$N`$1E<V-A<F=A<@!$97-C87)G87(@)7,`1&5S8V%R
M9V%R(&QA(&-O;F9I9W5R86-I\VX@9V5N97)A9&$@8V]M;R!U;B!G=6GS;B!0
M2%`N`$QI<W1A(&1E<W!L96=A8FQE`$1R;V=A<P!#;W)R96\`0V]N=')O;&%D
M;W(@9&4@<&%S87)E;&$@0V]R<F5O+6$M4TU3('!A<F$@<')O=F5E9&]R97,@
M<75E('!R;W!O<F-I;VYE;B!E<W1E('-E<G9I8VEO+@!%4E(`16-U861O<@`F
M;F)S<#M-;V1I9FEC87(F;F)S<#L`36]D:69I8V%R(&)L;W%U90!-;V1I9FEC
M87(@9W)U<&\`36]D:69I8V%R('!R:79I;&5G:6\`36]D:69I8V%R('!R:79I
M;&5G:6]S`$UO9&EF:6-A<B!P<FEV:6QE9VEO<R!D92`E<P!-;V1I9FEC87(@
M;W!C:6]N97,@9&4Z`$UO9&EF:6-A<B!P<FEV:6QE9VEO<R!D92`B)7,B`$UO
M9&EF:6-A<B!P<FEV:6QE9VEO<R!D92`E<P!%9'5C86-I\VX`16=I<'1O`$5L
M(%-A;'9A9&]R`$5L96UE;G1O+BXN`$5M`$-O<G)E;P!$:7)E8V-I\VX@9&4@
M8V]R<F5O`$QA<R!D:7)E8V-I;VYE<R!D92!C;W)R96\@=&EE;F5N('%U92!C
M;VEN8VED:7(N`$-O<G)E;R!C;VX@8V]N9FER;6%C:?-N`%!A<V%R96QA($-O
M<G)E;RUA+5--4P!%;6]T:6-O;F5S`$UE;G-A:F4@96X@8FQA;F-O`%)E<W5L
M=&%D;R!E;B!B;&%N8V\N`$QI;7!I87(@=.ER;6EN;W,@9&4@8OIS<75E9&$`
MOU!E<FUI=&ER(&EN<V5R8VGS;B!D92!I;>%G96YE<R!D92!L87,@1V%L97+M
M87,@9&4@9F]T;W,_`+]097)M:71I<B!M96[Z(&1E(&-O;G1E>'1O(&1E;"!B
M;W3S;B!D97)E8VAO(&1E;"!R873S;C\`0?%O(&1E('1E<FUI;F%C:?-N`$%G
M<F%N9&%R(&5D:71O<@!);G1R;V1U>F-A('5N82!P<F5G=6YT82!D92!S96=U
M<FED860@<75E('-E(&QE(&9O<FUU;&%RX2!S:2!P<F5C:7-A(')E86IU<W1A
M<B!L82!C;VYT<F%S9?%A+"!P+F4N(">_0W7A;"!E<R!E;"!N;VUB<F4@9&4@
M<W4@;6%S8V]T83\G.@!);G1R;V1U>F-A(&%Q=>T@;&$@55),(&1E(&QA(&EM
M86=E;@!);G1R;V1U>F-A(&QA<R!L971R87,@9&4@9&5B86IO.@!'=6EN96$@
M16-U871O<FEA;`!%<FET<F5A`$5R<F]R`$5R<F]R(&%L(&-R96%R(&5L(&)L
M;W%U93H@)7,`17)R;W(@86P@96QI;6EN87(@86YC;&$@9&4@<VEN8W)O;FEZ
M86-I\VXZ("5S`$5R<F]R(&%L(&5L:6UI;F%R(&5L(')E9VES=')O(&1E('-I
M;F-R;VYI>F%C:?-N.B`E<P!%<G)O<B!A;"!O8G1E;F5R(&-O;G1E;FED;W,Z
M("5S`$5R<F]R(&%L(&%C='5A;&EZ87(@;&$@8V]N=')A<V7Q83H@)7,`17)R
M;W(@8V]N(&5L(&UE;G-A:F4@9&4@8V]R<F5O+@!%<G)O<B!A;"!E<V-R:6)I
M<B`B)7,B+@!%<W1O;FEA`$5T:6]P[6$`R71N:6-O`$5U<F]P80!#861A(#$U
M(&UI;G5T;W,`0V%D82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A
M(#4@;6EN=71O<P!#861A(&EN:6-I;R!D92!S97-I\VX`0V%D82!M961I82!H
M;W)A`$-A9&$@;6EN=71O`%9A;&]R97,@9&4@96IE;7!L;SH`16IE8W5T87(`
M17AP86YD:7(`36]S=')A<B!B87)R82!L871E<F%L`'-E(&5S<&5R86)A("<I
M)P!392!E<W!E<F%B82!U;F$@^FYI8V$@<&%L86)R82!O('5N('3I<FUI;F\@
M9&4@8OIS<75E9&$@96YT<F5C;VUI;&QA9&\`1F5C:&$@9&4@=F5N8VEM:65N
M=&\`17AP;VYE;G1E`$-O;&]R(&1E(&QE=')A`$-A<F=A<B!L82!C;VYF:6=U
M<F%C:?-N('!O<B!&5%``1F%L;&\@86P@=')A97(@;&%S('!R969E<F5N8VEA
M<RX`26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R($Q$05`N`$EN
M8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!334(N`$9A;&QO(&%L
M(&-O<&EA<B!D92`B)7,B+@!&86QL;R!A;"!C;W!I87(@82`B)7,B+@!&86QL
M;R!A;"!C<F5A<B!U;F$@8V]N97AI\VX@4T%33`!&86QL;R!A;"!T<F%S;&%D
M87(@(B5S(BX`1F%L;&\@86P@<F5C=7!E<F%R.B`E<P!$97-P96IA9&\`27-L
M87,@36%L=FEN87,@*$9A;&ML86YD*0!)<VQA<R!&87)O90!%<G)O<B!I<G)E
M8W5P97)A8FQE.@!&87@`1F%X97,`1F5B<F5R;P!392!S:65N=&4@8V]M;P!3
M92!S:65N=&4@8V]M;SH@`%!O8V%S(&QL=79I87,`17-C87-O(&%G=6%C97)O
M(&1E(&YI979E`$UA=')I>B!D92!C86UP;W,`0T%05$-(02!D92!&:6=L970`
M3&5T<F$@9&4@1FEG;&5T`$9I:FD`07)C:&EV;P!.NB!D92!A<F-H:79O<SH@
M)7,@87)C:&EV;P!.NB!D92!A<F-H:79O<SH@)7,@87)C:&EV;W,`07)C:&EV
M;W,`3F]M8G)E(&1E(&%R8VAI=F\`4V5L96-C:?-N(&1E(&%R8VAI=F\`0V%R
M9V%R(&%R8VAI=F\`3&$@8V%R9V$@9&4@87)C:&EV;W,@;F\@97-TX2!S;W!O
M<G1A9&$N`$9I;'1R;W,`1FEN;&%N9&EA`$-U87)T;R!C<F5C:65N=&4`0W5A
M<G1O(&-R96-I96YT90!287KS;B!F:6IA`%9O;'1E87(`1&ES<&]S:6-I\VX`
M3FEE8FQA`$QA(&-A<G!E=&$@)7,@;F\@97AI<W1E+@!#;VQO<B!D92!L971R
M80!#;VUI9&$`4&%R82!N879E9V%D;W)E<R!Q=64@;F\@861M:71A;B!I;>%G
M96YE<P!0<F]N\W-T:6-O("A4048I`$3M87,@9&5L('!R;V[S<W1I8V\@*'1E
M;F=A(&5N(&-U96YT82!Q=64@96P@<')O;O-S=&EC;R!F86-I;&ET861O(&EN
M8VQU>64@=&%N=&\@96P@9.UA(&-O;6\@;&$@;F]C:&4[('5N(&[Z;65R;R!G
M<F%N9&4@<V4@=')A9'5C:7+A(&5N('5N(&)L;W%U92!M=7D@86YC:&\I`+](
M82!O;'9I9&%D;R!L82!C;VYT<F%S9?%A/P!&;W)M=6QA<FEO<P!&;W)T=6YA
M`%1I<&\@9&4@9F]R='5N80!&;W)T=6YA<P!&;W)T=6YA<R`R`$9O<F]S`%)E
M96YV[6]S`%9I90!&<F%M97,`1G)A;F-I80!&<F%N8VEA+"!-971R;W!O;&ET
M86YA`$=U87EA;F$@9G)A;F-E<V$`4&]L:6YE<VEA(&9R86YC97-A`%1E<G)I
M=&]R:6]S(&9R86YC97-E<R!D96P@<W5R`$1E`$1E;"``1&5S8W)I<&-I\VX@
M8V]M<&QE=&$`3'5N82!L;&5N80!.;VUB<F4@8V]M<&QE=&\`1V%B\VX`1V%L
M97+M82!D92!L82!Q=64@;V)T96YE<B!L82!I;6%G96X`1V%L97+M83H`1V%M
M8FEA`$=E;F5R87(@8V]N9FEG=7)A8VGS;B!D92`E<P!#\V1I9V\@9V5N97)A
M9&\`1V5O<F=I80!!;&5M86YI80!':&%N80!':6)R86QT87(`3F]M8G)E(&EN
M9&EC861O`$]P8VEO;F5S(&=L;V)A;&5S`$ER`$=O961E;`!-87!A<R!D92!'
M;V]G;&4`0OIS<75E9&$@96X@1V]O9VQE`$5S8V%L82!D92!G<FES97,`1W)E
M8VEA`$=R:65G;R`H25-/+3@X-3DM-RD`1W)O96YL86YD:6$`1W)A;F%D80!!
M9&UI;FES=')A8VGS;B!D92!G<G5P;W,`3&]S(&YO;6)R97,@9&4@9W)U<&\@
M;F\@<'5E9&5N(&1E:F%R<V4@96X@8FQA;F-O`$=R;W5P7VQD87`Z($YO('-E
M('!U961E(&'Q861I<B!E;"!G<G5P;R`E<RX@R7-T;R!E<R!L;R!Q=64@9&EJ
M;R!E;"!S97)V:61O<CH@`$=R;W5P7VQD87`Z($EN8V%P87H@9&4@96QI;6EN
M87(@96P@9W)U<&\@)7,`1W)O=7!?;&1A<#H@26YC87!A>B!D92!A8W1U86QI
M>F%R(&5L(&=R=7!O("5S`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!'=6%T96UA
M;&$`1W5E<FYE<V5Y`%!R:79I;&5G:6]S(&1E(&EN=FET861O`$PN(&EN=FET
M861O<P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=6%Y86YA`$A434P`2%1-3"!S
M92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA<B!L82#Z;'1I;6$@8V5L
M9&$@9&4@;&$@9FEL82X`2%1-3$%R96$@<V4@;FEE9V$@8V]B87)D96UE;G1E
M(&$@96QI;6EN87(@;&$@^FQT:6UA(&-O;'5M;F$@9&4@;&$@=&%B;&$N`$A4
M34P@<V4@;FEE9V$@8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA
M(&9I;&$@9&4@;&$@=&%B;&$N`$YO('-E(&5N8V]N='+S(&QA(&%U=&5N=&EF
M:6-A8VGS;B!(5%10+@!(86ET[0!!;&=O<FEM;R!(87-H`$YE8FQI;F$`0V%B
M96-E<F$`0V%B96-E<F%S`$ES;&$@2&5A<F0@92!)<VQA<R!-8T1O;F%L9`!4
M;W)M96YT82!T<F]P:6-A;"!I;G1E;G-A`$AE8G)E;R`H25-/+3@X-3DM."U)
M*0!!;'1U<F$`07EU9&$`07EU9&$@9&5L(&5D:71O<@!!>75D86YT90!(96UI
M<V9E<FEO`$%Q=>T@=&EE;F4@96P@8V]M:65N>F\@9&5L(&%R8VAI=F\Z`$%L
M=&$`7TEN:6-I;P!386YT82!3961E("A#:75D860M17-T861O(&1E;"!6871I
M8V%N;RD`26YI8VEO`$1O;6EC:6QI;P!$:7)E8W1O<FEO('!E<G-O;F%L`%1E
M;.EF;VYO('!A<G1I8W5L87(`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!392!H86X@96YC;VYT<F%D;R!D871O<R!834P@)7,@;F\@
M=N%L:61O<R!E;B!E;"!M96YS86IE("5S`$AO<F1E+TMO;&%B.B!.:6YG^FX@
M;65N<V%J92!C;W)R97-P;VYD92!A;"!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z
M($YO('-E(&5N8V]N='+S('5N(&]B:F5T;R!D92!T:7!O("5S(&5N(&5L(&UE
M;G-A:F4@)7,`2&]R9&4O2V]L86(Z(%-E(&AA(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E("5S("(E<R(`2&]R9&4O2V]L86(Z($5L(&UO=&]R(&1E(&EN=&5G
M<F%C:?-N('!R96-I<V$@9&4@;&$@97AT96YS:?-N(%!(4"`G9&]M>&UL)P!(
M;W)D92]+;VQA8CH@26YC87!A>B!D92!C<F5A<B!N=65V;R#A<F)O;"!834P@
M9&5L(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@26YC87!A>B!D92!E;&EM:6YA
M<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26YC87!A>B!D92!O8G1E;F5R
M($E$($U)344@9&4@;&$@<&%R=&4@9&4@=&EP;R`E<P!(;W)D92]+;VQA8CH@
M26YC87!A>B!D92!S:6YC<F]N:7IA<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@26YC87!A>B!D92!S:6YC<F]N:7IA<B!E;&5M96YT;W,@8V]M<&%R=&ED
M;W,Z("5S`$AO<F1E+TMO;&%B.B!%;&5M96YT;R!C;VUP87)T:61O(&1E<V-O
M;F]C:61O("(E<R(`3.UN96$@:&]R:7IO;G1A;`!-87)G96X@:&]R:7IO;G1A
M;`!(;W)I>F]N=&%L.@"_0_-M;R!L;&5G\R!H87-T82!A<77M/R`HH4-O;75N
M[7%U96QO+"!P;W(@9F%V;W(A*0"_0W5A;G1A<R!C;VQU;6YA<R!D97-E82!C
M;VUB:6YA<C\`OT-UX6YT;W,@8V%M<&]S("AC;VQU;6YA<RD@:&%Y/P"_0W5A
M;G1A<R!F:6QA<R!D97-E82!C;VUB:6YA<C\`2'5M961A9`!(=6UE9&%D.B``
M2'5M;W)I<W1A<P!(=6YG<NUA`$AA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&5L
M(&)U>O-N($E-05`Z("5S`$AA(&9A;&QA9&\@;&$@96QI;6EN86-I\VX@9&5L
M(&)U>O-N($E-05`Z("5S`$AA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&4@97-P
M86-I;R!A<VEG;F%D;R!D96P@8G5Z\VX@24U!4#H@)7,`1&ER96-C:?-N($E0
M`$QA(&1I<F5C8VGS;B!)4"!N;R!E<W3A(&1I<W!O;FEB;&4N`$QA(&1I<F5C
M8VGS;B!)4"!N;R!E<W3A(&5N=')E(&)L;W%U97,@0TE$4B!P97)M:71I9&]S
M+@!6:6]L86-I\VX@;&]C:V1O=VX@25`N`$E?;G-E<G1A<B!F:6QA(&5N8VEM
M80!)<VQA;F1I80!3\VQO(&EC;VYO<P!)8V]N;W,@9&4@)7,`26-O;F]S(&-O
M;B!T97AT;P!.;VUB<F4@9&4@;&$@:61E;G1I9&%D.@!3:2!N;R!S92!M=65S
M=')A(&-O<G)E8W1A;65N=&4L("5S('!A<F$@86)R:7)L;R!E;B!U;F$@=F5N
M=&%N82!N=65V82X`4VD@;F\@=F4@;FEN9_IN(&EC;VYO(&UE9&EA;G1E($EN
M=&5R;F5T($5X<&QO<F5R+"!P=65D92!T96YE<B!Q=64@86-T:79A<B!E<W1A
M(&-A<VEL;&$@<&%R82!D97-A8W1I=F%R(&QA('1R86YS<&%R96YC:6$@4$Y'
M+@!3:2!V92!E<W1E(&UE;G-A:F4@<VEN(&YI;F=U;F$@:6UA9V5N+"!L82!I
M;6%G96X@<75E('%U:65R92!C87)G87(@;F\@<V4@<'5E9&4@;6]S=')A<B!E
M;B!S=2!N879E9V%D;W(N`%9I<W1A('!R979I83H`55),(&1E(&QA(&EM86=E
M;@!54DP@9&4@;&$@:6UA9V5N.@!);6%G96X@9&4@;&$@9V%L97+M80!);6%G
M96X@9&4@;&$@9V%L97+M83H`4V4@:&$@8V%R9V%D;R!L82!I;6%G96X`26WA
M9V5N97,`26UP;W)T87(L('!A<V\@)60`0V%M<&\@:6UP;W)T861O.B`E<P!#
M86UP;W,@:6UP;W)T861O<SH`26Y?<V5R=&%R(&9I;&$@9&5B86IO`%-E(&AA
M(&EN9&EC861O('5N(&/S9&EG;R!D92!A8V-I\VX@:6YC;W)R96-T;RX`3F]M
M8G)E(&1E('5S=6%R:6\@>2]O(&-O;G1R87-E\6$@:6YC;W)R96-T;W,N`$YO
M;6)R92!D92!U<W5A<FEO(&\@9&ER96-C:?-N(&%L=&5R;F%T:79A(&EN8V]R
M<F5C=&]S+B!6=65L=F$@82!I;G1E;G1A<FQO(&\@</-N9V%S92!E;B!C;VYT
M86-T;R!C;VX@96P@861M:6YI<W1R861O<B!D92!S:7-T96UA<R!P87)A(&WA
M<R!I;F9O<FUA8VGS;BX`075M96YT87(@<V%N9W)A9&\`26YD:6$`57-U87)I
M;W,@:6YD:79I9'5A;&5S`$EN9&]N97-I80!);F9O<FUA8VGS;@!);F9O<FUA
M8VGS;@!,82!I;F9O<FUA8VGS;B!Y82!N;R!E<W3A(&1I<W!O;FEB;&4N`$EN
M<V5R=&%R(&-?;VQU;6YA(&1E='+A<P!);G-E<G1A<B!I;6%G96X`26YS97)T
M87(@=&%B;&$`26YS97)T87(@=NUN8W5L;R!796(`26YS97)T87(@7V-O;'5M
M;F$@9&5L86YT90!);G-E<G1A('5N82!N=65V82!C;VQU;6YA(&1E='+A<R!D
M92!L82!A8W1U86P`26YS97)T82!U;F$@;G5E=F$@8V]L=6UN82!D96QA;G1E
M(&1E(&QA(&%C='5A;`!);G-E<G1A('5N82!F:6QA(&YU979A(&1E8F%J;R!D
M92!L82!A8W1U86P`26YS97)T82!U;F$@9FEL82!N=65V82!E;F-I;6$@9&4@
M;&$@86-T=6%L`$EN<V5R=&$@=6X@<.%R<F%F;R!T<F%S(&5L(&YO9&\@86-T
M=6%L`$EN<V5R=&$@=6X@<.%R<F%F;R!A;G1E<R!D96P@;F]D;R!A8W1U86P`
M26YS97)T87(@<&QA;G1I;&QA(&%L=&5R;F%T:79A`$EN<V5R=&%R('5N82!D
M:7)E8V-I\VX@9&4@8V]R<F5O(&5N(&QA('%U92!R96-I8FER(&QA(&-O;G1R
M87-E\6$Z`$EN<V5R=&%R(&-E;&1A(&1E='+A<P!);G-E<G1A<B!C96QD82!A
M;G1E<P!);G-E<G1A<B!C;VQU;6YA(&1E='+A<P!);G-E<G1A<B!C;VQU;6YA
M(&%N=&5S`$EN<V5R=&%R(&UE;G-A:F5S`$EN<V5R=&%R('#A<G)A9F\@9&5T
M<N%S`$EN<V5R=&%R('#A<G)A9F\@86YT97,`26YS97)T87(@9FEL82!D96)A
M:F\`26YS97)T87(@9FEL82!E;F-I;6$`26YS97)T87(@;&$@<F5S<'5E<W1A
M(&YE8V5S87)I82!A(&QA('!R96=U;G1A(&1E('-E9W5R:61A9#H`26YS97)T
M87(O36]D:69I8V%R(&EM86=E;@!);G-E<G1A<B]-;V1I9FEC87(@=NUN8W5L
M;P!386QD;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@82!L82!L:7-T82!D
M92!D:7-T<FEB=6-I\VXN`%-A;&1O(&EN<W5F:6-I96YT92X`16YT97)O`$QI
M<W1A(&1E(&5N=&5R;W,`541(("A#86)E8V5R82!D92!$871O<R!D92!5<W5A
M<FEO*2!N;R!VX6QI9&$N`$1A=&]S(%I)4"!N;R!VX6QI9&]S`$%P;&EC86-I
M\VX@;F\@=N%L:61A+@!)1"!D92!L;W1E(&YO(';A;&ED;RX`4V4@:&%N(&5N
M=FEA9&\@9&%T;W,@;F\@=N%L:61O<RX`1&ER96-C:?-N(&1E(&-O<G)E;R!N
M;R!VX6QI9&$N`$9O<FUA=&\@9&4@87)C:&EV;R!N;R!VX6QI9&\`0VQA=F4@
M9&4@;&EC96YC:6$@;F\@=N%L:61A+@!392!H82!I;F1I8V%D;R!U;F$@=6)I
M8V%C:?-N(&YO(';A;&ED82X`;7-G7W1Y<&4@;F\@=N%L:61O+@!A<&E?:60@
M;F\@=N%L:61O(&\@9&5S87!A<F5C:61O+@!087+A;65T<F]S(&YO(';A;&ED
M;W,@;R!D97-A<&%R96-I9&]S+@!0<FEV:6QE9VEO(&1E;"!P861R92!N;R!V
MX6QI9&]S+@!)1"!D92!A<V]C:6%D;R!N;R!VX6QI9&\N`$/S9&EG;R!D92!P
M<F]D=6-T;R!N;R!VX6QI9&\N`%!R;W1O8V]L;R!N;R!VX6QI9&\N`$1E<W1I
M;F%T87)I;R!N;R!VX6QI9&\Z("(E<R(`3V)J971O(&-O;7!A<G1I9&\@;F\@
M=N%L:61O+@!$:7)E8V-I\VX@9&5L(')E;6ET96YT92!N;R!VX6QI9&$`1&%T
M;W,@=6YI8V]D92!N;R!VX6QI9&]S+@!);G9E;G1A<FEO`$EN=F5R=&ER('-E
M;&5C8VGS;@!)<N%N+"!297#Z8FQI8V$@27-LX6UI8V$@9&4`27)A<0!)<FQA
M;F1A`$ES;&$@9&4@36%N`$)O<G)A<V-A<R!A:7-L861A<P!)<W)A96P`16UI
M<V]R`$-U<G-I=F$`271A;&EA`$IA;6%I8V$`16YE<F\`2F%P\VX`2F%P;V[I
M<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)DX6X`2G5L:6\`2G5N:6\`2G5S
M=&EF:6-A<@!!;&EN96%R(&%L(&-E;G1R;P!*=7-T:69I8V%R`$%L:6YE87(@
M82!L82!I>G%U:65R9&$`06QI;F5A<B!A(&QA(&1E<F5C:&$`2V%Z86MH<W1A
M;@"_0V]N<V5R=F%R(&5L(&]R:6=I;F%L/P!+96YY80!%;"!S97)V:61O<B!+
M97)B97)O<R!H82!R96-H87IA9&\@;&$@875T96YT:69I8V%C:?-N+@!.;W9A
M=&]S(&1E;"!+97)N96P`0W)E86-I\VX@9&4@8VQA=F4`2'5E;&QA(&1I9VET
M86P@9&4@;&$@8VQA=F4`5&%M8?%O(&1E(&-L879E`%1I<&\@9&4@8VQA=F4`
M57-O(&1E(&QA(&-L879E.@!,82!C;&%V92!Y82!E>&ES=&4@96X@96P@<V5R
M=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N`$YI\6]S`$MI<FEB871I`$-O<F5A
M+"!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D90!#;W)E82P@4F5P
M^F)L:6-A(&1E`$-O<F5A;F\@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`
M7T1I<W1R:6)U8VGS;@!)9&EO;6$`3&%O+"!297#Z8FQI8V$@1&5M;V-RX71I
M8V$@4&]P=6QA<@!#=6%R=&\@;65N9W5A;G1E`-IL=&EM;R!C86UB:6\@9&4@
M8V]N=')A<V7Q80!#=6%R=&\@;65N9W5A;G1E`-IL=&EM82!A8W1U86QI>F%C
M:?-N.@#:;'1I;6$@<V5S:?-N.B`E<P#:;'1I;6$@<V5S:?-N.B`E<R!D97-D
M92`E<P#:;'1I;6$@<V5S:?-N.B!.=6YC80!,871V:6$`3&5Y97,`1&ES=')I
M8G5C:?-N`$1E:F%R(&5N(&)L86YC;R!P87)A(&5L:6UI;F%R(&5L(&)O<F1E
M`$QE8F%N;VX`27IQ=6EE<F1A`$-A8F5C97)A(&EZ<75I97)D80!686QO<F5S
M(&1E(&QA(&EZ<75I97)D80!,97-O=&AO`$YI=F5L`$QI8F5R:6$`3&EB>6%N
M($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9V5R82!L;&]V:7IN
M80!,;'5V:6$@;&EG97)A`$QL=79I82!L:6=E<F$@;6%T=71I;F$`3&QU=FEA
M(&QI9V5R82!V97-P97)T:6YA`$%G=6%C97)O(&QI9V5R;P!,;'5V:6%S('D@
M=')U96YO<P!.979A9&$@<W5A=F4`3&EG97)O(&%G=6%C97)O(&1E(&YI979E
M`$-H87-C87)R:6QL;P!6[6YC=6QO`$5L(';M;F-U;&\@87!U;G1A(&$Z`%9I
M;F-U;&%R(&1I<F5C8VGS;B!D92!C;W)R96\@82!L82!PX6=I;F$@9&4@8V]M
M<&]S:6-I\VX@86P@;6]S=')A<@!6[6YC=6QO<P!#;V]K:64@3&EN=7@`3&ES
M=&%R("T@96P@=7-U87)I;R!P=65D92!E>&%M:6YA<B!L82!C87)P971A`$QI
M<W1A<B!B87-E<R!D92!D871O<P!,:7-T87(@=&5M87,@9&4@87EU9&$`3&ES
M=&%R('1A8FQA<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES
M="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C
M<FEB90!(82!F86QL861O(&5L(&QI<W1A9&\@9&4@;&%S('-E<VEO;F5S.B`E
M<P!(82!F86QL861O(&5L(&QI<W1A9&\@9&4@=7-U87)I;W,Z("5S`$5L(&QI
M<W1A9&\@9&4@=7-U87)I;W,@97-TX2!D97-H86)I;&ET861O+@!,:71E<F%T
M=7)A`$QI='5A;FEA`$QE>65N9&\N+BX`2&]R82!L;V-A;#H@`$ED:6]M82!Y
M(&AO<F$`56)I8V%C:?-N`$EN:6-I87(@<V5S:?-N`%)E9VES=')O(&1E(&QA
M<R!S97-I;VYE<R!D92!S:6YC<F]N:7IA8VGS;B!A;G1E<FEO<F5S`%-A;&ER
M`$EN:6-I87(@<V5S:?-N`%1A<F5A<R!D92!I;FEC:6\@9&4@<V5S:?-N`$9A
M;&SS(&5L(&EN:6-I;R!D92!S97-I\VX@<&]R<75E(&EN=')O9'5J;R!I;F-O
M<G)E8W1A;65N=&4@<W4@;F]M8G)E(&1E('5S=6%R:6\@;R!C;VYT<F%S9?%A
M+@!&86QL\R!E;"!I;FEC:6\@9&4@<V5S:?-N+@!497AT;R!C;VUP;&5T;P!!
M;6]R`$)A:F$`06QF86)E=&\@9W)I96=O(&5N(&UI;OIS8RX`06QF86)E=&\@
M;&%T:6YO(&5N(&UI;OIS8RX`3OIM97)O<R!R;VUA;F]S(&5N(&UI;OIS8RX`
M3'5X96UB=7)G;P!-30!-3U1$`$5L(&%D:G5N=&\@35,M5$Y%1B!N;R!C;VYT
M96[M82!D871O<RX`35-'`$UA8V%O`$UA8V5D;VYI82P@06YT:6=U82!297#Z
M8FQI8V$@675G;W-L879A(&1E`$UA9&%G87-C87(`36%G:6$`0V]R<F5O`$%D
M;2X@8V]R<F5O`$-R96%R(%]V[6YC=6QO+BXN`$UA;&%W:0!-86QA<VEA`$UA
M;&1I=F%S`$UA;&D`36%L=&$`1V5S=&EO;F$@;&$@;&ES=&$@9&4@8V%T96=O
M<NUA<R!C;VX@;&$@<75E(&5T:7%U971A<B!E;&5M96YT;W,@>2!L;W,@8V]L
M;W)E<R!A<V]C:6%D;W,@82!D:6-H87,@8V%T96=O<NUA<RX`36%P82!M87`R
M-`!-87!A(&UA<'%U97-T`$-O<G)E<W!O;F1E;F-I87,@86QM86-E;F%D87,N
M`$UA<GIO`$UA<F=E;@!-87)C87(@8V]N(&QA<R!B86YD97)A<R!D92!,9>UD
M;R]3:6X@;&5E<@!-87)C87(@8V]N(&]T<F%R(&)A;F1E<F%S("AP+F4N($EM
M<&]R=&%N=&4O4F5S<&]N9&ED;RD`27-L87,@36%R<VAA;&P`36%R=&EN:6-A
M`$-A;7!O<R!C;VEN8VED96YT97,`36%U<FET86YI80!-875R:6-I;P!386QD
M;R!MX7AI;6\@<&5R;6ET:61O+@!392!H82!S;V)R97!A<V%D;R!E;"!N^FUE
M<F\@;>%X:6UO(&1E('!A<G1E<R!D92!M96YS86IE+@!496UP+B!MX7AI;6$@
M^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7`N(&WA>&EM82#Z;'1I;6%S(#8@:&]R
M87,Z(`!.^FUE<F\@;>%X:6UO(&1E(&)L;W%U97,@9&5L('!O<G1A;`!,;VYG
M:71U9"!MX7AI;6$`36%Y;P!-87EO='1E`$UE9&EC:6YA`$UI96UB<F]S`$9O
M<FUA=&\@9&5L(&UE;OHZ`$-O;6)I;F%R(&-E;&1A<P!-96YS86IE`%-E(&AA
M(&-O;7!R;V)A9&\@8V]R<F5C=&%M96YT92!E;"!M96YS86IE('!E<F\@;F\@
M<V4@<'5E9&4@=F5R:69I8V%R(&5L(&-E<G1I9FEC861O(&1E;"!F:7)M86YT
M92X`365N<V%J92!C861U8V%D;RX`5&EP;R!D92!M96YS86IE`%1I96UP;R!D
M92!-971A<@!";&]Q=64@365T87(@;F\@9&ES<&]N:6)L92X`0FQO<75E($UE
M=&%R(&YO(&1I<W!O;FEB;&4N(%-E(&AA;B!R96=I<W1R861O(&QO<R!D971A
M;&QE<R!P87)A(&5L(&%D;6EN:7-T<F%D;W(N`$YO(&5S=.$@8V]N96-T861A
M(&QA($UE=&%R1$(`3>ET;V1O`$5L(&WI=&]D;R`B)7,B(&YO(&5S=.$@9&5F
M:6YI9&\`3>ET;V1O(&YO(&1E9FEN:61O+B!-Z71O9&\@;&QA;6%D;SH@)7,`
M3>ET<FEC;P!-Z6II8V\`36EC<F]N97-I82P@17-T861O<R!&961E<F%D;W,@
M9&4`16X@;65D:6\`5&EP;R!-:6UE`%1E;7`N(&WM;BX@;&%S(/IL=&EM87,@
M,C0@:&]R87,Z(`!496UP+B!M[6XN(&QA<R#Z;'1I;6%S(#8@:&]R87,Z(`!4
M;V1A=NUA(&YO(&AA(&5X<&ER861O(&QA(&%N=&EG_&5D860@;>UN:6UA(&1E
M(&QA(&-O;G1R87-E\6$`4F5F;&5J87(`36ES8V5LX6YE80!087%U971E(%!%
M05(@2%144%]297%U97-T(&1E<V%P87)E8VED;RX`1F%L=&$@;&$@8V]N9FEG
M=7)A8VGS;BX@5&EE;F4@<75E(&=E;F5R87)L82!A:&]R82!S:2!D97-E82!U
M=&EL:7IA<B!E<W1A(&%P;&EC86-I\VXN`$E$(&1E(&UE;G-A:F4@9&5S87!A
M<F5C:61O+@!087%U971E(%!%05(@36%I;"!D97-A<&%R96-I9&\N`$E$(&1E
M('-E<VGS;B!D97-A<&%R96-I9&\N`$QU;@!#;W)R96\@;?-V:6P`36]D97)A
M9&\`4V4@:&$@;6]D:69I8V%D;R!L82!F96-H80!-;V1I9FEC87(@55),`$WS
M9'5L;P!-;VQD879I82P@4F5P^F)L:6-A(&1E`$WS;F%C;P!-;VYG;VQI80!-
M97,@>2!A\6\`365N<W5A;&UE;G1E`$UO;G1S97)R870`1F%S97,@9&4@;&$@
M;'5N80!392!H86X@96YC;VYT<F%D;R!MX7,@8V%M<&]S(&5N(&QA(&SM;F5A
M("5D('%U92!L;W,@)60@97-P97)A9&]S+@!-87)R=65C;W,`1G5N9&%M96YT
M86QM96YT92!D97-P96IA9&\`1G5N9&%M96YT86QM96YT92!N=6)O<V\`1G5N
M9&%M96YT86QM96YT92!N=6)O<V\@>2!V96YT;W-O`$9U;F1A;65N=&%L;65N
M=&4@<V]L96%D;P!$97-P;&%Z87(@:&%C:6$@86)A:F\`1&5S<&QA>F%R(&$@
M;&$@:7IQ=6EE<F1A`$1E<W!L87IA<B!A(&QA(&1E<F5C:&$`1&5S<&QA>F%R
M(&AA8VEA(&%R<FEB80!$97-P;&%Z87(@:&%C:6$@86)A:F\`1&5S<&QA>F%R
M(&AA8VEA(&%R<FEB80!-;WIA;6)I<75E`$QI<W1A<R!D97-P;&5G86)L97,@
M;75L=&DM;FEV96P`36%P82!52R!M^FQT:7!L90!396QE8V-I\VX@;?IL=&EP
M;&4`261E;G1I9&%D`$UI(&ED96YT:61A9`!-:2!P;W)T86P`1&ES=')I8G5C
M:?-N(&1E(&UI('!O<G1A;`!->6%N;6%R`$Y/+"!.3R!E<W1O>2!D92!A8W5E
M<F1O`$YO;6)R90!.86UI8FEA`$YA=7)U`$YE<&%L`$AO;&%N9&$`06YT:6QL
M87,@2&]L86YD97-A<P!54DP@8F%S92!D92!.971S8V%P90!54DP@9&4@86YU
M;&%C:?-N(&1E($-!(&1E($YE='-C87!E`%523"!D92!P;VSM=&EC87,@9&4@
M0T$@9&4@3F5T<V-A<&4`55),(&1E(')E;F]V86-I\VX@9&4@3F5T<V-A<&4`
M55),(&1E(&%N=6QA8VGS;B!D92!.971S8V%P90!.;VUB<F4@9&4@<V5R=FED
M;W(@4U-,(&1E($YE='-C87!E`$-O;65N=&%R:6\@9&5L(&-E<G1I9FEC861O
M(&1E($YE='-C87!E`%1I<&\@9&4@8V5R=&EF:6-A9&\@9&4@3F5T<V-A<&4`
M4F5D`$YU;F-A`$YU979A($-A;&5D;VYI80!.=65V82!C871E9V]R[6$`3'5N
M82!N=65V80!.=65V;R!N;VUB<F4@9&4@=7-U87)I;R`H;W!C:6]N86PI`$YU
M979A(%IE;&%N9&$`0V]N=')A<V7Q82!N=65V80!,82!N=65V82!C;VYT<F%S
M9?%A(&5X<&ER87+A(&5L("5X+@!,87,@8V]N=')A<V7Q87,@;F\@8V]I;F-I
M9&5N+@!.=65V82!V96YT86YA("A?8FQA;FLI`$YO=&EC:6%S`$<N(&1E(&YO
M=&EC:6%S`%-I9W5I96YT90!0<O-X:6UA<R`T(&9A<V5S`$]P8VEO;F5S('-I
M9W5I96YT97,`4VEG=6EE;G1E/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.
M;V-H90!.:75E`$YO`$YO(&AA>2!D871O<R!D92!C;VYF:6=U<F%C:?-N('!A
M<F$@;6]S=')A<B!D:69E<F5N8VEA<RX`3F\@<V4@9&ES<&]N92!D92!E<W1R
M871E9VEA(&1E(&5L86)O<F%C:?-N(&1E(&EMX6=E;F5S($E33RX`3F\@:&%Y
M('!L86YT:6QL82!D92!L;W1E<P!.;R!H87D@8FQO<75E<R!E;B!L82!P;W-I
M8VGS;B!I;F1I8V%D80!.;R!S92!H82!I;G1R;V1U8VED;R!U;B!N;VUB<F4@
M9&4@86=E;F1A('!A<F$@;&$@875T96YT:69I8V%C:?-N($U#04PN`%-I;B!C
M86UB:6]S+@!.;R!S92!P=65D96X@8?%A9&ER(&1E<V-E;F1I96YT97,@82!E
M<W1E('!R:79I;&5G:6\N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA
M8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@)7,N`$YO('-E(&AA(&5S<&5C
M:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93
M('!O<B!&5%`N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D
M92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!344PN`$YO('-E(&AA(&5S
M<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@
M5D93('!O<B!A<F-H:79O(%-13"X`3F\@<75E9&$@<V%L9&\N`$YO('-E(&AA
M(&EN=')O9'5C:61O(&5L(&1E<W1I;F\N`$YO('-E(&AA(&-A<F=A9&\@;FEN
M9_IN(&%R8VAI=F\`3F\@<V4@:&%N(&5N8V]N=')A9&\@:6-O;F]S+@!.;R!S
M92!H82!D969I;FED;R!L82!U8FEC86-I\VXN`$YO('-E(&AA(&1E9FEN:61O
M(&QA('5B:6-A8VGS;BX`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@;65N<V%J
M92X`3F\@<V4@:&$@97-P96-I9FEC861O('5N(&YO;6)R92X`3F\@<V4@:&$@
M97-P96-I9FEC861O('5N(&[Z;65R;RX`3F\@;V9E;G-I=F%S`$YO('-E(&AA
M(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I
M8V%C:?-N($A45%`N`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S
M9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N($E-05`N`$YO('-E(&AA(&EN
M=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C
M:?-N($ME<F)E<F]S+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A
M<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!D92!I;FEC:6\N`$YO('-E
M(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT
M:69I8V%C:?-N(%!!4U-71"X`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O
M;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@4TU"+@!.;R!S92!H
M82!I;F1I8V%D;R!V[6$@9&4@86-C97-O(&$@;&]S(&)I;F%R:6]S($]P96Y3
M4TPN(%!A<F$@=')A8F%J87(@8V]N(&1A=&]S(%!+0U,@,3(@:&%C96X@9F%L
M=&$@;&]S(&)I;F%R:6]S($]P96Y34TPN`%-I;B!A;'1A<R!P96YD:65N=&5S
M+@!#87)E8V4@9&4@<75O=&$N`%-I;B!R87EA<P!.;R!S92!H82!E<W!E8VEF
M:6-A9&\@=6X@<V5P87)A9&]R+@!.:6YG=6YO`$YO(&5X:7-T92!E;"!A<F-H
M:79O`$YO('-E(&1I<W!O;F4@9&4@=6X@9&ER96-T;W)I;R!D92!A;&UA8V5N
M86UI96YT;R!T96UP;W)A;"X`3F\@<V4@:&$@96YV:6%D;R!E;"!N;VUB<F4@
M9&4@=7-U87)I;R!Y+V\@;&$@8V]N=')A<V7Q82X`3F\@<V4@:&%N(&1E=G5E
M;'1O(&1A=&]S(%A-3"!VX6QI9&]S`%-I;B!V86QO<F5S`$YO('-E(&5N8V]N
M='+S(&QA('9E<G-I\VX@96X@;&$@8V]N9FEG=7)A8VGS;B!O<FEG:6YA;"X@
M4F5G96YE<F%R(&QA(&-O;F9I9W5R86-I\VXN`$YO('-E(&5N8V]N='+S(&QA
M('9E<G-I\VX@96X@;&$@8V]N9FEG=7)A8VGS;BX@4F5G96YE<F%R(&QA(&-O
M;F9I9W5R86-I\VXN`$YI;F=U;F$`3FEN9W5N;R`H=7-O(&EM<&SM8VET;RD`
M3O-R9&EC;R`H25-/+3@X-3DM,3`I`$ES;&$@9&4@3F]R9F]L:P!(96UI<V9E
M<FEO(&YO<G1E`$ES;&%S($UA<FEA;F%S(&1E;"!.;W)T90!.;W)U96=A`$YO
M(&1E<W!UZ7,`3F\@86YT97,`3F\@97,@=6X@9&ER96-T;W)I;P!3:6X@9&5S
M87)R;VQL87(N`%-I;B!E<W1A8FQE8V5R`$YO(&5S=.$@<V]P;W)T861O+@!.
M;W1A<P!.;R!H87D@;F%D82!V:7-U86QI>F%B;&4L(')E=')O8V5D82X`3F]V
M:65M8G)E`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T97)E<P!.^FUE<F\@9&4@
M8V]L=6UN87,`3OIM97)O(&1E(&9I;&%S`$YO('-E(&AA;B!E<W!E8VEF:6-A
M9&\@;OIM97)O<R!A(&%C='5A;&EZ87(@96X@;&$@;&ES=&$@9&4@9&ES=')I
M8G5C:?-N+@!!8V5P=&%R`$]B:F5T;P!#<F5A9&]R(&1E(&]B:F5T;W,`3V-T
M86P`3V-T=6)R90!&:6QT<F%R(&]F96YS87,`3V9I8VEN80!,82!C;VYT<F%S
M9?%A(&%N=&EG=6$@>2!L82!N=65V82!D96)E;B!S97(@9&ES=&EN=&%S+@!#
M;VYT<F%S9?%A(&%N=&EG=6$`3&$@8V]N=')A<V7Q82!A;G1I9W5A(&YO(&5S
M(&-O<G)E8W1A+@!/;>%N`%/S;&\@;&]S('-E<G9I9&]R97,@24U!4"!S;W!O
M<G1A;B!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N`%/S;&\@;V9E;G-I=F%S
M`%/S;&\@<V4@<&5R;6ET92!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;RX`4_-L
M;R!E;"!P<F]P:65T87)I;R!O('5N(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M
M87,@<'5E9&4@8V%M8FEA<B!L82!P<F]P:65D860@;R!L;W,@<')I=FEL96=I
M;W,@9&4@<')O<&EE=&%R:6\@9&4@=6X@<F5C=7)S;R!C;VUP87)T:61O`$%B
M<FER(&5N('5N82!N=65V82!V96YT86YA`$5R<F]R($]P96Y34TPZ($YO('-E
M('!U961E;B!E>'1R865R(&1A=&]S(&1E(&QA('!A<G1E(%,O34E-12!F:7)M
M861A+@!!8G)I<B!E<W1E(';M;F-U;&\@96X@=6YA('9E;G1A;F$@;G5E=F$`
M4VES=&5M82!O<&5R871I=F\`3W!C:6]N97,`3W!C:6]N97,@9&4@)7,`3&ES
M=&$@;W)D96YA9&$`3W)G86YI>F%C:?-N`%5N:61A9"!O<F=A;FEZ871I=F$`
M3W)G86YI>F%C:?-N`%!L86YT:6QL82!D92!A<&QI8V%C:?-N(&]R:6=I;F%L
M`%!L86YT:6QL87,@;W)I9VEN86QE<R!E;B`E<SH`3W1R;P!/=')A(&EN9F]R
M;6%C:?-N`%!R:79I;&5G:6]S(&1E;"!P<F]P:65T87)I;P!,82!A=71E;G1I
M9FEC86-I\VX@4$%-(&YO(&5S=.$@9&ES<&]N:6)L92X`4$5!4CHZ36]T;W(@
M9&4@8V]R<F5O`$9I<FUA(&1I9VET86P@4$=0`$1A=&]S(&-I9G)A9&]S(&-O
M;B!01U``0VQA=F4@4$=0('#Z8FQI8V$`1&%T;W,@9FER;6%D;W,O8VEF<F%D
M;W,@8V]N(%!'4`!#\V1I9V\@4$A0`$EN=.ER<'(N(%!(4`!,;&]V:7IN82!V
M97-P97)T:6YA`$QL=79I82!V97-P97)T:6YA`$-H87!A<G)O;F5S('9E<W!E
M<G1I;F]S`$YI979E('9E<W!E<G1I;F$`06=U86-E<F\@9&4@;FEE=F4@=F5S
M<&5R=&EN;P!3;VP@=F5S<&5R=&EN;P!";W)R87-C87,@=F5S<&5R=&EN87,`
M3F\@<V4@96YC=65N=')A(&QA(&5X=&5N<VGS;B!03U-)6`!);G3I<G!R+B!0
M7TA0`$UA<F=E;@!086MI<W3A;@!086QA=0!086QE<W1I;F]S+"!497)R:71O
M<FEO<R!/8W5P861O<P!086YA;>$`4&%P^F$@3G5E=F$@1W5I;F5A`%!A<F%G
M=6%Y`%!A<F-I86QM96YT92!N=6)O<V\`0V]N=')A<V7Q80!,82!C;VYT<F%S
M9?%A('-E(&-A;6)I861O(&-O<G)E8W1A;65N=&4N`$-O;G1R87-E\6$@:6YC
M;W)R96-T80!(87D@<75E(&EN=')O9'5C:7(@=6YA(&-O;G1R87-E\6$@<&%R
M82!L82!A=71E;G1I9FEC86-I\VX@4D%$2553+@!#;VYT<F%S9?%A(&-O;B!C
M;VYF:7)M86-I\VX`0V]N=')A<V7Q83H`0V]N=')A<V7Q83H@`$QA<R!C;VYT
M<F%S9?%A<R!T:65N96X@<75E(&-O:6YC:61I<BX`4&5G87(`4&5G87(@9&5L
M('!O<G1A<&%P96QE<P!6[6$`06QT87,@<&5N9&EE;G1E<SH`1V5N=&4`4&]R
M8V5N=&%J90!296%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O
M`+]296%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O(&%L(&EN
M:6-I87(@<V5S:?-N/P!0<FEV:6QE9VEO`$YO('-E(&AA(&5L:6UI;F%D;R!E
M;"!P<FEV:6QE9VEO("(E<R(N`%!R:79I;&5G:6\@9&5N96=A9&\`4')I=FEL
M96=I;W,`061M:6YI<W1R86-I\VX@9&4@<')I=FEL96=I;W,`26YF;W)M86-I
M\VX@<&5R<V]N86P`4&5R^@!-87-C;W1A<P!&:6QI<&EN87,`5&5LZ69O;F\`
M1F]T;V=R86;M87,`4&ET8V%I<FX`4.UX96QE<P!4\W!I8V]S`%!U;'-E(&5N
M('5N82!C96QD80!#;VYF:7)M92!Q=64@9&5S96$@96QI;6EN87(@97-T92!E
M;&5M96YT;SH`0V]N9FER;64@<75E(&1E<V5A(&5L:6UI;F%R(&5L(';M;F-U
M;&\@82!E<W1E(&5L96UE;G1O+@!);G1R;V1U>F-A('5N(&UE<R!Y('5N(&'Q
M;RX`26YT<F]D=7IC82!E;"!N;VUB<F4@9&4@;&$@;G5E=F$@8V%T96=O<NUA
M.@!);G1R;V1U>F-A('5N82!D:7)E8V-I\VX@25`@=N%L:61A+@!);G1R;V1U
M>F-A('5N82!F96-H82!VX6QI9&$L(&-O;7!R=65B92!E;"!N^FUE<F\@9&4@
M9.UA<R!D96P@;65S+@!);G1R;V1U>F-A('5N82!H;W)A(';A;&ED82X`4')O
M<&]R8VEO;F4@=6X@<F5S=6UE;B!D96P@<')O8FQE;6$N`$EN=')O9'5Z8V$@
M<W4@;F]M8G)E(&1E('5S=6%R:6\@>2!C;VYT<F%S9?%A+@!,96$@96P@=&5X
M=&\@<VEG=6EE;G1E+B!$14)%(&%C97!T87(@;&]S('3I<FUI;F]S('-I('%U
M:65R92!U<V%R(&5L('-I<W1E;6$N`$EN=')O9'5Z8V$@96P@;G5E=F\@;F]M
M8G)E(&1E(&-A=&5G;W+M83H`4&]L;VYI80!0;VSM=&EC80!%;F-U97-T87,`
M4&]R='5G86P`4&]S:6-I\VX@9&4@;&$@:6UA9V5N`%!O<VEC:?-N(&1E(&QA
M('1A8FQA`$5N=FEA<B!A(&5S=&$@8V%R<&5T82`H;F\@;V)L:6=A9&\@<&]R
M($E-05`I`%!R96-I<&ET86-I;VYE<R!D92!L82AS*2#Z;'1I;6$H<RD@)7,@
M:&]R82AS*3H@`%!R;V)A8FEL:61A9#QB<B`O/F1E('!R96-I<&ET86-I\VX`
M4')E9G-?;&1A<#H@;F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N($Q$05`@
M<F5Q=65R:61A+@!0<F5F<U]S97-S:6]N.B!N;R!S92!E;F-O;G1R\R!L82!E
M>'1E;G-I\VX@9&4@<V5S:?-N(')E<75E<FED82X`4')E<VGS;@!0<F5S:?-N
M(&%L(&YI=F5L(&1E;"!M87(Z(`!0<F5S:?-N.B``5FES=&$@<')E=FEA`%9I
M<W1A('!R979I82!D92!L82!I;6%G96X@96X@=6YA(&YU979A('9E;G1A;F$`
M3W!C:6]N97,@86YT97)I;W)E<P!);7!R:6UI<B!D;V-U;65N=&\`0VQA=F4@
M<')I=F%D80"_4')O8FQE;6%S/P!$97-C<FEP8VGS;B!D96P@<')O8FQE;6$`
M4')O>65C=&]S`%1E>'1O(&1E;"!I;F1U8W1O<@!#;&%V92!01U`@</IB;&EC
M80!!;&=O<FET;6\@9&4@8VQA=F4@</IB;&EC80!);F9O<FUA8VGS;B!D92!C
M;&%V92!P^F)L:6-A`$YO('-E(&=E;F5R87)O;B!C;W)R96-T86UE;G1E(&QA
M<R!C;&%V97,@4/IB;&EC82]0<FEV861A+@!0=65R=&\@4FEC;P!,:6UP:6%R
M(&UE;G-A:F5S`%%A=&%R`$-O;G-U;'1A`%%U;W1A`$-L879E(%)302!P^F)L
M:6-A("@E9"!B:70I`$)O=/-N(&1E(&]P8VGS;@!,;'5V:6$`3&QU=FEA(&UA
M='5T:6YA`$QL=79I82!V97-P97)T:6YA`$%G=6%C97)O`$QL=79I82!Y($YI
M979E`$QL=79I82!A($YI979E`%)U961A(&1E(&QA(&9O<G1U;F$`4F%Z\VX`
M)FYB<W`[3&5E<B9N8G-P.P!,965R(&UE;G-A:F5S`+]%;&EM:6YA<B!R96%L
M;65N=&4@)7,_($5S=&$@;W!E<F%C:?-N(&YO('-E('!U961E(&1E<VAA8V5R
M+@"_16QI;6EN87(@<F5A;&UE;G1E(&QO<R!D871O<R!D96P@=7-U87)I;R`E
M<S\@17-T82!O<&5R86-I\VX@;F\@<V4@<'5E9&4@9&5S:&%C97(N`%9U96QV
M92!A(')E86QI>F%R(&QA(/IL=&EM82!A8V-I\VX`06-T=6%L:7IA<@!!8W1U
M86QI>F%R(&5L96UE;G1O<R!D92!M96[Z(&1I;N%M:6-O<SH`06-T=6%L:7IA
M<B!V:7-T82!D96P@<&]R=&%L`%)E9V5X`$YA=F5G861O<B!D92!R96QA8VEO
M;F5S`%)E9G)E<V-A<@!/8G-E<G9A8VEO;F5S`%-E<G9I9&]R97,@<F5M;W1O
M<P!54DP@<F5M;W1A("AH='1P.B\O=W=W+F5J96UP;&\N8V]M+VAO<F1E*3H`
M475I=&%R`%%U:71A<B!B;&]Q=64`475I=&%R(&-O;'5M;F$`16QI;6EN87(@
M9F]R;6%T;P!1=6ET87(@<&%R`$5L:6UI;F%R(&=U:?-N(&=U87)D861O(&1E
M;"!D:7)E8W1O<FEO('1E;7!O<F%L(&1E;"!S97)V:61O<BX`16QI;6EN87(@
M`$5L:6UI;F%R(&5S=&4@;F]D;R!D96P@9&]C=6UE;G1O`$5L:6UI;F%R('5S
M=6%R:6\`16QI;6EN87(@=7-U87)I;SH@)7,`3F\@<V4@<'5E9&4@<F5S<&]N
M9&5R(&$@;&$@<V]L:6-I='5D+B!#\V1I9V\@9&4@97)R;W(@9&5V=65L=&\Z
M(`!.;R!S92!E;F-O;G1R\R!E;"!S97)V:6-I;R!S;VQI8VET861O+@!.;R!S
M92!H82!E<W!E8VEF:6-A9&\@96P@(B5S(B!R97%U97)I9&\@96X@;&$@8V]N
M9FEG=7)A8VGS;B!D92`E<RX`3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E
M<R(@<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@5D93+@!.;R!S
M92!H82!E<W!E8VEF:6-A9&\@96P@(B5S(B!R97%U97)I9&\@96X@;&$@8V]N
M9FEG=7)A8VGS;BX`0V%M<&\@;F5C97-A<FEO`$QI;7!I87(`3&EM<&EA<B!C
M;VYT<F%S9?%A`$QI;7!I87(@8V]N=')A<V7Q80!297-T875R87(@^FQT:6UA
M(&-O;G-U;'1A`%)E<W5L=&%D;W,`4F5G<F5S87(@82!O<&-I;VYE<P!2965S
M8W)I8FER(&-O;G1R87-E\6$@;G5E=F$`4F5U;FGS;@!297-T875R87(@8V]N
M9FEG=7)A8VGS;@!/<&-I;VYE<R!D92!E9&EC:?-N(&1E('1E>'1O(&5N<FEQ
M=65C:61O`$-R:6)A<P!$97)E8VAA`$-A8F5C97)A(&1E<F5C:&$`5F%L;W)E
M<R!D92!L82!D97)E8VAA`%!R;W!I961A9&5S(&1E(%]F:6QA+BXN`$9U;F-I
M\VX`4G5M86[M80!':7)A<B`Q.#``1VER87(@82!L82!I>G%U:65R9&$`1VER
M87(@82!L82!D97)E8VAA`%!R;W!I961A9&5S(&1E(&9I;&$`4')O<&EE9&%D
M97,@9&4@9FEL80!&:6QA<SH`4F%Y87,`07!A<F5C97+A;B!R87EA<R!E;G1R
M92!T;V1A<R!L87,@9FEL87,@>2!C;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S
M('/S;&\@96YT<F4@;&%S(&-O;'5M;F%S`$%P87)E8V5RX6X@<F%Y87,@<_-L
M;R!E;G1R92!L87,@9FEL87,`16IE8W5T87(`1F5D97)A8VGS;B!2=7-A`%)U
M86YD80!&:7)M82!C<FEP=&]G<N%F:6-A(%,O34E-10!-96YS86IE(&-I9G)A
M9&\@96X@4R]-24U%`$YO(&5S=.$@9&ES<&]N:6)L92!L82!A=71E;G1I9FEC
M86-I\VX@4T%33"X`365N<RX@4TU3`$EN=.ER<'(N(%-13`!396YT96YC:6$@
M4U%,('!A<F$@8V]N<W5L=&%S(&1E('9A;&]R97,`4U-(`,E8251/`$EN=.ER
M<'(N(%-?44P`4V%B`%-A;G1A($AE;&5N80!386EN="!+:71T<R!Y($YE=FES
M`%-A;G1A($QU8^UA`%-A:6YT(%!I97)R92!Y($UI<75E;&]N`%-A;B!6:6-E
M;G1E('D@1W)A;F%D:6YA<P!-:7-M;R!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%N=&\@5&]MX7,@>2!0<NUN8VEP90!0<F]V965D;W(@9&4@
M<V%TZ6QI=&4`07)A8FEA(%-A=61I=&$`1W5A<F1A<@!'=6%R9&%R("(E<R(`
M1W5A<F1A<B`E<P!'=6%R9&%R(&]P8VEO;F5S`$=U87)D87(@;&$@8V]N9FEG
M=7)A8VGS;B!G96YE<F%D82!C;VUO('5N(&=U:?-N(%!(4"!E;B!E;"!D:7)E
M8W1O<FEO('1E;7!O<F%L(&1E('-U('-E<G9I9&]R+@!392!H82!G=6%R9&%D
M;R!L82!C;VYF:6=U<F%C:?-N(&1E("5S+@!'=6%R9&%R(&=U:?-N(&1E(&%C
M='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;B!E;CH@(B5S(BX`0F]R
M<F%S8V%S(&%I<VQA9&%S`$-I96YC:6$`0G5S8V%R`$TN(&+Z<W%U961A`%-E
M;&5C8VEO;F%R(&%R8VAI=F]S`%-E;&5C8VEO;F4@=6YA(&9E8VAA`%-E;&5C
M8VEO;F4@96P@9W)U<&\@82!A\6%D:7(`4V5L96-C:6]N92!U;B!N=65V;R!P
M<F]P:65T87)I;P!396QE8V-I;VYE('5N('-E<G9I9&]R`%-E;&5C8VEO;F4@
M96P@=7-U87)I;R!A(&'Q861I<@!396QE8V-I;VYA<B!T;V1O`%-E;&5C8VEO
M;F4@=&]D;W,@;&]S(&-O;7!O;F5N=&5S(&1E(&QA(&9E8VAA+@!396QE8V-I
M;VYA<B!U;B!O8FIE=&\`4VEN('-E;&5C8VGS;@!396QE8V-I;VYE(&QO<R!C
M87+A8W1E<F5S('%U92!N96-E<VET92!D92!L87,@8V%S:6QL87,@9&4@86)A
M:F\N(%!U961E(&-O<&EA<FQO<R!Y('!E9V%R;&]S(&1E;"#A<F5A(&1E('1E
M>'1O+@!396QE8V-I;VYE(&5L(&1E;&EM:71A9&]R(&1E(&9E8VAA<SH`4V5L
M96-C:6]N92!E;"!F;W)M871O(&1E(&9E8VAA<SH`4V5L96-C:6]N92!L82!I
M9&5N=&ED860@<75E('%U:65R82!C86UB:6%R.@!396QE8V-I;VYE(&5L(&1E
M;&EM:71A9&]R(&1E(&AO<F%S.@!396QE8V-I;VYE(&5L(&9O<FUA=&\@9&4@
M:&]R87,Z`%-E;&5C8VEO;F4@9&]S(&-A;7!O<R!C;VEN8VED96YT97,N`%-E
M;&5C8VEO;F4@<W4@8V]M8FEN86-I\VX@9&4@8V]L;W)E<RX`4V5L96-C:6]N
M92!S=2!I9&EO;6$@<')E9F5R:61O.@!%;G9I87(@:6YF;W)M92!D92!P<F]B
M;&5M87,`16YV:6%R(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1I96UB<F4`
M4V5R8FEA('D@36]N=&5N96=R;P!.^FUE<F\@9&4@<V5R:64`1&%T;W,@9&5L
M('-E<G9I9&]R(&5R<O-N96]S(&\@;F\@9&ES<&]N:6)L97,N`$%D;6EN:7-T
M<F%C:?-N(&1E('-E<VGS;@!(82!C861U8V%D;R!E;"!)1"!D92!S97-I\VXN
M`%-E<VEO;F5S`$5S=&%B;&5C97(`17-T86)L96-E(&]P8VEO;F5S('%U92!L
M92!P97)M:71E;B!R96%J=7-T87(@<W4@8V]N=')A<V7Q82!S:2!L;&5G87)A
M(&$@;VQV:61A<FQA+@!#;VYF:6=U<F$@<V5R=FED;W)E<R!R96UO=&]S(&$@
M;&]S('%U92!D97-E92!A8V-E9&5R(&1E<V1E(&5L('!O<G1A;"X`1&5F:6YE
M(&QA<R!O<&-I;VYE<R!P<F5F97)I9&%S(&1E(&ED:6]M82P@>F]N82!H;W)A
M<FEA('D@9F5C:&%S+@!$969I;F4@;&$@87!L:6-A8VGS;B!D92!I;FEC:6\L
M(&QA(&-O;6)I;F%C:?-N(&1E(&-O;&]R97,L(&QA(&%C='5A;&EZ86-I\VX@
M9&4@<.%G:6YA('D@;W1R87,@;W!C:6]N97,@9&4@=FES=6%L:7IA8VGS;BX`
M0V]N9FEG=7)A8VGS;@!(87D@9W5I;VYE<R!D92!A8W1U86QI>F%C:?-N(&1E
M(&QA(&-O;F9I9W5R86-I\VX`5F%R:6%S('5B:6-A8VEO;F5S(&1I<W!O;FEB
M;&5S(&-O;B!E;"!P87+A;65T<F\Z(`!397EC:&5L;&5S`$-O;7!R87,`4F5S
M=6UE;B!C;W)T;P"_1&5F:6YI<B!C;&%V97,@9&4@86-C97-O('!A<F$@;&$@
M;6%Y;W+M82!D92!L;W,@=NUN8W5L;W,_`"9N8G-P.TUO<W1R87(F;F)S<#L`
M375E<W1R82!L87,@9&EF97)E;F-I87,@96YT<F4@;&$@;G5E=F$@8V]N9FEG
M=7)A8VGS;B!Y(&QA(&%L;6%C96YA9&$`OTUO<W1R87(@:&]R82!D92!L82#Z
M;'1I;6$@<V5S:?-N(&%L(&EN:6-I87(_`$UO<W1R87(@;W!C:?-N(&1E(&-O
M;G-E<G9A<B!E;"!O<FEG:6YA;`!-;W-T<F%R('-E;&5C=&]R`+]-;W-T<F%R
M(&QA(&)A<G)A(&1E(&UE;OH@9&4@;W!E<F%C:6]N97,@9&4@=&%B;&$_`+]-
M;W-T<F%R(&5L(&UE;OH@)7,@82!L82!I>G%U:65R9&$_`$UU97-T<F$@96P@
M9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!C96QD82!D92!T86)L80!-=65S
M=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@=&%B;&$`375E<W1R
M82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E(&9I;&$@9&4@=&%B;&$`
M375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E(&EM86=E;@!-
M;W-T<F%R(&-A<F=A`$%G=6%C97)O<P!,;'5V:6%S(&UA='5T:6YA<P!,;'5V
M:6%S('9E<W!E<G1I;F%S`$%G=6%C97)O<R!E;B!L82!V96-I;F1A9`!2961U
M8VER`%!R:6UE<F\@<F5D=7IC82!O('%U:71E(&1E(&5N;65D:6\@;&]S(&)L
M;W%U97,@8V5R8V%N;W,`4VEE<G)A($QE;VYA`$%L=&$`1FER;6$`06QG;W)I
M=&UO(&1E(&9I<FUA`%-I;F=A<'5R`%1A;6'Q;P!/;6ET:7(@;6%N=&5N:6UI
M96YT;P!%<VQO=F%Q=6EA`$5S;&]V96YI80!.:65V90!!9W5A8V5R;R!D92!N
M:65V90!!9W5A8V5R;R!D92!N:65V90!!9W5A8V5R;R!D92!N:65V92!M871U
M=&EN;P!!9W5A8V5R;R!D92!N:65V92!V97-P97)T:6YO`$5S<&5S;W(@9&4@
M;&$@;FEE=F4Z(`!%<75I=F%L96YT92!D92!L82!N:65V92!E;B!A9W5A.B``
M27-L87,@4V%L;VWS;@!3;VUA;&EA`$-A;F-I;VYE<R`F(%!O96UA<P!396QE
M8V-I\VX@9&5L('-E;G1I9&\@9&4@;&$@8VQA<VEF:6-A8VGS;@!296UI=&5N
M=&4`4W5DX69R:6-A`$5U<F]P82!D96P@<W5R("A)4T\M.#@U.2TS*0!'96]R
M9VEA(&1E;"!3=7(@92!)<VQA<R!386YD=VEC:"!D96P@4W5R`$AE;6ES9F5R
M:6\@<W5R`$5S<&%C:6%D;R!E;G1R92!C96QD87,@861Y86-E;G1E<P!%<W!A
M8VEA9&\@96YT<F4@96P@8V]N=&5N:61O('D@96P@8F]R9&4@9&4@=6YA(&-E
M;&1A`%-E<&%R861O<@!%<W!A8VEA9&\`17-P86-I861O('D@;6%R9V5N`$5S
M<&'Q80!3<&%M`$5S8W)I='5R82!D92!C87)A8W1E<F5S(&5S<&5C:6%L97,`
M1&EV:61I<B!C96QD80!$:79I9&ER(&-O;'5M;F$`1&EV:61I<B!F:6QA`$1E
M<&]R=&5S`%-R:2!,86YK80!%<W3A;F1A<@!3=&%R(%1R96L`0?%O(&1E(&EN
M:6-I;P!%<W1A9&\@;R!P<F]V:6YC:6$`17-T861O`$9O<FUA=&\@9&4@86QM
M86-E;F%M:65N=&\`1&ER96-C:?-N(&1E(&QA(&-A;&QE`%1A8VAA9&$`3&ES
M=&$@9&4@8V%D96YA<P!%;&EM:6YA<B!D;VUI;FEO(&1E(&QA(&1I<F5C8VGS
M;@!%<W1I;&\@6T-34UT`1&]M`$YO('-E(&5N8V]N='+S(&5L('-U8F1I<F5C
M=&]R:6\@(B5S(BX`07-U;G1O`$5N=FEA<@!392!H82!E;G9I861O('5N82!S
M;VQI8VET=60@9&4@86QT82!D92`B)7,B(&5N(&5L('-I<W1E;6$N($YO('!O
M9'+A(&EN:6-I87(@<V5S:?-N(&AA<W1A('%U92!S92!H87EA(&%P<F]B861O
M(&QA('-O;&EC:71U9"X`4W5B[6YD:6-E`,EX:71O`%-E(&AA(&'Q861I9&\@
M8V]R<F5C=&%M96YT92`B)7,B(&%L('-I<W1E;6$N`%-E(&AA;B!E;&EM:6YA
M9&\@8V]R<F5C=&%M96YT92!L;W,@9&%T;W,@9&5L('5S=6%R:6\@(B5S(B!D
M96P@<VES=&5M82X`4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@(B5S
M(BX`4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@(B5S(B!D96P@<VES
M=&5M82X`4V4@:&$@<F5S=&%U<F%D;R!C;W)R96-T86UE;G1E(&QA(&-O;F9I
M9W5R86-I\VXN(%)E9G)E<W%U92!P87)A('9E<B!L;W,@8V%M8FEO<RX`4V4@
M:&$@9W5A<F1A9&\@8V]R<F5C=&%M96YT82!L82!C;W!I82!D92!L82!C;VYF
M:6=U<F%C:?-N+@!392!H82!G=6%R9&%D;R!C;W)R96-T86UE;G1E(&QA(&-O
M<&EA("5S(&1E(&QA(&-O;F9I9W5R86-I\VXN`%-E(&AA(&%C='5A;&EZ861O
M(&-O<G)E8W1A;65N=&4@(B5S(@!392!H82!E<V-R:71O(&-O<G)E8W1A;65N
M=&4@)R5S)P!3=63A;@!297-U;65N`$%M86YE8V5R`$%T87)D96-E<@!3;VQE
M861O`$%M86YE8V5R`$%M86YE8V5R+T%T87)D96-E<@!!;6%N96-E<CH@`$%T
M87)D96-E<@!!=&%R9&5C97(Z(`!3=7!E<NUN9&EC90!3;W!O<G1E`%-U<FEN
M86T`07!E;&QI9&\`4W9A;&)A<F0@>2!*86X@36%Y96X`4W=A>FEL86YD:6$`
M4W5E8VEA`%-U:7IA`%)E9VES=')O(&1E('-I;F-R;VYI>F%C:?-N(&5L:6UI
M;F%D;P!3>6YC34P`17)R;W(@9&4@<VEN=&%X:7,@96X@;&]S('3I<FUI;F]S
M(&1E(&+Z<W%U961A`%)E</IB;&EC82#!<F%B92!D92!3:7)I80!#:'5B87-C
M;P!";W)R87-C;W-O('D@=F5N=&]S;P!";W)R87-C87,`0F]R<F%S8V%S(&UA
M='5T:6YA<P!!<F-H:79O(%135@!0<F]P:65D861E<R!D92!T86)L80!486)L
M80!0<F]P:65D861E<R!D92!T86)L80!486EWX6X`5&%I=^%N+"!0<F]V:6YC
M:6$@9&4@0VAI;F$`5&%Y:6MI<W3A;@!486YZ86YI82P@4F5P^F)L:6-A(%5N
M:61A(&1E`$1E<W1I;F\Z`%1A<F5A<P!.^FUE<F\@9&4@=&5LZ69O;F\`5&5M
M<&5R871U<F$@9'5R86YT92!L82#Z;'1I;6$@:&]R83H@`%1E;7!E<F%T=7)A
M`%1E;7!E<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH)7--X7@E<R\E<TWM
M;B5S*2`F9&5G.R5S`$YO('-E(&5N8V]N='+S(&QA('!L86YT:6QL82`B)7,B
M+@!!9&UI;FES=')A8VGS;B!D92!P;&%N=&EL;&%S`%1E>'1O`%/S;&\@=&5X
M=&\`06QI;F5A8VGS;B!D92!T97AT;P!";W)D92!S=7!E<FEO<B!D96P@=&5X
M=&\`2G5E`%1A:6QA;F3I<R`H5$E3+38R,"D`5&%I;&%N9&EA`$YO(&5S=.$@
M9&ES<&]N:6)L92!L82!E>'1E;G-I\VX@1E10+@!%;"!S:7-T96UA(&AI<W3S
M<FEC;R!E<W3A(&1E<VAA8FEL:71A9&\N`$5L(&UO=&]R(&1E(&EN=&5G<F%C
M:?-N($AO<F1E+TMO;&%B(&YO('-O<&]R=&$@(B5S(@!.;R!S92!P=65D92!I
M;FEC:6%R(&5L(')E9VES=')O(&1E($E-4U`N`$YO('-E(&AA(&-A<F=A9&\@
M8V]R<F5C=&%M96YT92!L82!C;&%S92!-86EN=&5N86YC93HZ`%-E(&AA(&-E
M<G)A9&\@;&$@=F5N=&%N82!D92!O<&-I;VYE<RX@4V%L:65N9&\N`%-I(&1E
M<V5A('5T:6QI>F%R('!E<FUI<V]S+"!E;"!A9&UI;FES=')A9&]R('1I96YE
M('%U92!C;VYF:6=U<F%R('5N('-O<&]R=&4@9&4@<&5R;6ES;W,@<&5R;6%N
M96YT92X`4_-L;R!E;"!B;W)D92!I;F9E<FEO<@!%;"!)1"!D96P@8V]N=&%C
M=&\@;F\@<V4@97-P96-I9FEC\RP@<V4@9&5J\R!E;B!B;&%N8V\@;R!N;R!S
M92!E;F-O;G1R\R!E;B!L82!B87-E(&1E(&1A=&]S+@!392!H82!A\6%D:61O
M(&-O<G)E8W1A;65N=&4@96P@8V]N=&%C=&\@82!S=7,@9&ER96-C:6]N97,N
M`%!A<F$@8V]M<')O8F%R(&5L(&UE;G-A:F4@9FER;6%D;R!H86-E(&9A;'1A
M(&5L(&)L;W%U92!D92!F:7)M82!S97!A<F%D;RX`16P@240@9&4@;&$@;&ES
M=&$@9&4@9&ES=')I8G5C:?-N(&YO('-E(&5S<&5C:69I8_,L('-E(&1E:O,@
M96X@8FQA;F-O(&\@;F\@<V4@96YC;VYT<O,@96X@;&$@8F%S92!D92!D871O
M<RX`3F\@<V4@97-P96-I9FEC\R!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN
M`$QA<R!C87)A8W1E<NUS=&EC87,@9&4@8VEF<F%D;R!N96-E<VET86X@=6YA
M(&-O;F5X:?-N('=E8B!S96=U<F$N`$5L(&%R8VAI=F\@)7,@=&5N9'+M82!Q
M=64@8V]N=&5N97(@=6YA(&]P8VGS;B`E<RX`16P@87)C:&EV;R`E<R!T96YD
M<NUA('%U92!C;VYT96YE<B!A;&=U;F%S(&]P8VEO;F5S("5S+@!%;"!A<F-H
M:79O(&YO(&-O;G1I96YE(&1A=&]S+@!!(&-O;G1I;G5A8VGS;B!T:65N92!L
M87,@8V%B96-E<F%S(&1E(&5S=&4@;65N<V%J92!M97-S86=E+W)F8S@R,BX`
M4V4@<V%B92!Q=64@96P@;6]D;R!D92!P86YT86QL82!C;VUP;&5T82!D82!P
M<F]B;&5M87,@8V]N($EN=&5R;F5T($5X<&QO<F5R(&1E8FED;R!A(&9A;&QO
M<R!D96P@;F%V96=A9&]R('%U92!N;R!H96UO<R!P;V1I9&\@<V]S;&%Y87(N
M(%!U961E('-U9G)I<B!V:7-U86QI>F%C:?-N(&1E(&)A<W5R82P@<.ER9&ED
M82!D92!F=6YC:6]N97,@9&5L(&5D:71O<B!Y+V\@8W5E;&=U97,@86QE871O
M<FEO<R!D96P@;F%V96=A9&]R+B!3:2!S=2!S:7-T96UA(&]P97)A=&EV;R!E
M<R!7:6YD;W=S(#EX+"!E<R!M=7D@<')O8F%B;&4@<75E('-U9G)A('5N(&9A
M;&QO(&1E('!R;W1E8V-I\VX@9V5N97)A;"!Y('1E;F=A('%U92!R96EN:6-I
M87(@96P@97%U:7!O+EQN7&Y982!E<W3A(&%V:7-A9&\N(%!U;'-E($%C97!T
M87(@<VD@8?IN(&1E<V5A('!R;V)A<B!E;"!E9&ET;W(@96X@;6]D;R!D92!P
M86YT86QL82!C;VUP;&5T82X`4V4@:&$@96QI;6EN861O(&QA(&ED96YT:61A
M9"`B)7,B+@!3\VQO(&5L(&)O<F1E(&EZ<75I97)D;P!(87D@<75E(&EN9&EC
M87)L92!A(&QA(&-L87-E($-R>7!T7W!G<#HZ(&QA('5B:6-A8VGS;B!D92!L
M;W,@8FEN87)I;W,@1VYU4$<N`%-E(&AA(&UO<W1R861O(&5L(&UE;G-A:F4@
M96YV:6%D;R!E;"`E<R!A("5S(&-O;B!E;"!A<W5N=&\@(B5S(BX*R7-T;R!N
M;R!G87)A;G1I>F$@<75E(&5L(&UE;G-A:F4@:&%Y82!S:61O(&QE:61O(&\@
M8V]M<')E;F1I9&\N`$YO;6)R92!U=&EL:7IA9&\@86P@=FEN8W5L87(@82!L
M82!PX6=I;F$@9&4@8V]M<&]S:6-I\VX`16P@;OIM97)O(&1E(&-A;7!O<R!T
M:65N92!Q=64@<V5R('5N(&[Z;65R;RX`2&%C92!F86QT82!E;"!M\V1U;&\@
M;W!E;G-S;"!P87)A(&QA(&-L87-E($AO<F1E7T-R>7!T7W-M:6UE.CHN`$YO
M('-E('!U961E(&=U87)D87(@;&$@<')E9F5R96YC:6$@(B5S(B!P;W)Q=64@
M<W5S(&1A=&]S('-O8G)E<&%S86X@96P@=&%M8?%O(&WA>&EM;R!P97)M:71I
M9&\`3F\@<V4@96YC;VYT<O,@96X@96P@<VES=&5M82!E;"!P<F]G<F%M82!P
M87)A('9E<B!E<W1E('1I<&\@9&4@9&%T;W,@*"5S*2X`16P@8V%RX6-T97(@
M9&4@8VET82!D96)E('-E<B!S97(@<_-L;R!U;F\N`%/S;&\@;&]S(&QA9&]S
M(&EZ<75I97)D;R!Y(&1E<F5C:&\`4_-L;R!E;"!L861O(&1E<F5C:&\`16P@
M<V5P87)A9&]R(&1E8F4@<V5R('/S;&\@=6YO+@!392!H82!E;&EM:6YA9&\@
M96P@<V5R=FED;W(@(B5S(BX`4V4@:&$@9W5A<F1A9&\@96P@<V5R=FED;W(@
M(B5S(BX`4V4@:&$@96QI;6EN861O(&QA('-O;&EC:71U9"!D92!A;'1A(&1E
M("5S+@!,82!F:6QA(&5S<&5C:69I8V%D82`H)60I(&YO(&5X:7-T92X`16P@
M87)C:&EV;R!T96UP;W)A;"`B)7,B(&YO(&5X:7-T92X`16P@=&5X=&\@<75E
M(&AA(&EN=')O9'5C:61O(&YO(&-O:6YC:61E(&-O;B!E;"!D92!L82!P86YT
M86QL82X`4_-L;R!L;W,@;&%D;W,@<W5P97)I;W(@92!I;F9E<FEO<@!3\VQO
M(&5L(&QA9&\@<W5P97)I;W(`4V4@<&5R9&EE<F]N(&QO<R!D871O<R!C87)G
M861O<R!D97-D92!E;"!P87-O(&%N=&5R:6]R+@!.;R!S92!P=61O(&=U87)D
M87(@96P@87)C:&EV;R!C87)G861O+@!.;R!E<W3A(&1I<W!O;FEB;&4@96P@
M8FQO<75E(&1E('=E871H97(N8V]M+@!.;R!S92!E;F-O;G1R\R!E;"!D:7)E
M8W1O<FEO(&1E(%1E;6%S("(E<R(N`$YO('-E(&1I<W!O;F4@9&4@;W!C:6]N
M97,N`$YO(&AA>2!P87)T97,@<75E('-E('!U961A;B!M;W-T<F%R(&5N(&SM
M;F5A+@!%;B!E<W1E(&-A;7!O(&AA>2!D96UA<VEA9&]S(&-A<F%C=&5R97,N
M($AA(&EN=')O9'5C:61O("5S(&-A<F%C=&5R97,@>2!T:65N92!Q=64@:6YT
M<F]D=6-I<B!M96YO<R!D92`E<RX`4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A
M;"!A\6%D:7(@82`B)7,B(&%L('-I<W1E;6$Z("5S`%-E('!R;V1U:F\@=6X@
M<')O8FQE;6$@86P@8F]R<F%R(&QO<R!D871O<R!D96P@=7-U87)I;R`B)7,B
M(&1E;"!S:7-T96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!E;&EM
M:6YA<B!A("(E<R(@9&5L('-I<W1E;6$Z(`!392!P<F]D=6IO('5N('!R;V)L
M96UA(&%L(&%C='5A;&EZ87(@(B5S(CH@)7,`4V4@<')O9'5J;R!U;B!P<F]B
M;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\Z($YO('-E(&-A<F?S("5S
M+@!392!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C
M:&EV;RX@16P@)7,@97)A(&WA<R!G<F%N9&4@<75E(&5L('1A;6'Q;R!MX7AI
M;6\@<&5R;6ET:61O("@E9"!B>71E<RDN`%-E('!R;V1U:F\@=6X@<')O8FQE
M;6$@8V]N(&QA(&-A<F=A(&1E;"!A<F-H:79O+B!3\VQO('-E(&-A<F?S('!A
M<F-I86QM96YT92!E;"`E<RX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!M;W-T
M<F%R(&5S=&$@<&%R=&4@9&5L(&UE;G-A:F4`4V4@<')O9'5J;R!U;B!E<G)O
M<B!A;"!I;7!O<G1A<B!L;W,@9&%T;W,@9&5L(&-O;G1A8W1O+@!392!P<F]D
M=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R(&QO<R!D871O<R!I0V%L96YD87(N
M`%-E('!R;V1U:F\@=6X@97)R;W(@96X@96P@9F]R;75L87)I;R!D92!C;VYF
M:6=U<F%C:?-N+B!0=65D92!Q=64@:&%Y82!O;'9I9&%D;R!R96QL96YA<B!U
M;B!C86UP;R!N96-E<V%R:6\N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@96IE
M8W5T87(@;&$@9G5N8VGS;B!E<W!E8VEF:6-A9&$@9&4@;&$@;&EB<F5T82!D
M92!D:7)E8V-I;VYE<RX@5G5E;'9A(&$@<')O8F%R(&WA<R!A9&5L86YT92X`
M4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A8W1U86QI>F%R(&QO<R!D971A;&QE
M<R!D96P@8V]N=&%C=&\N(%9U96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N
M`%-E('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA<B!L82!L:7-T82!D
M92!D:7-T<FEB=6-I\VXN(%9U96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N
M`$5S=&4@<V5R=FED;W(@24U!4"!N;R!S;W!O<G1A(&QA<R!C87)P971A<R!C
M;VUP87)T:61A<RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@<F%R
M(';A;&ED;RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@>FEP(';A
M;&ED;RX`R7-T92!N;R!P87)E8V4@<V5R('5N(&[Z;65R;R!D92!T87)J971A
M(';A;&ED;RX`17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS
M86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!#;&EC:V%T96QL("AH='1P
M.B\O8VQI8VMA=&5L;"YC;VTI+"!M961I86YT92!L82!!4$D@2%144`!%<W1E
M(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S(&$@=')A=NES
M(&1E(&QA('!A<V%R96QA(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI+"!M961I
M86YT92!L82!!4$D@2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV
M:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!M961I86YT92!L82!!4$D@2%14
M4`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S('9I
M82!33510(&$@=')A=NES(&1E(&QA('!A<V%R96QA(&1E(%9O9&%F;VYE(&1E
M($ET86QI82P@<_-L;R!A(&[Z;65R;W,@5F]D869O;F4N($AA8V4@9F%L=&$@
M=6YA(&-U96YT82!D92!C;W)R96\@9&4@5F]D869O;F4@9&4@271A;&EA("AH
M='1P.B\O=W=W+C$Y,"YI="DN`$AA8V4@9F%L=&$@97-T92!C86UP;RX`17-T
M92!C86UP;R!S\VQO('!U961E(&-O;G1E;F5R(&5N=&5R;W,N`$5S=&4@8V%M
M<&\@<_-L;R!P=65D92!C;VYT96YE<B!N^FUE<F]S('D@;&]S(&1O<R!P=6YT
M;W,N`$5S=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE<B!V86QO<F5S(&]C
M=&%L97,N`$5S=&4@8V%M<&\@=&EE;F4@<75E('-E<B!U;F$@;&ES=&$@9&4@
M96YT97)O<R!S97!A<F%D;W,@<&]R(&-O;6%S(&\@97-P86-I;W,N`$5S=&4@
M8V%M<&\@=&EE;F4@<75E('-E<B!U;B!N^FUE<F\@=N%L:61O+@!%<W1E(&-A
M;7!O('1I96YE('%U92!C;VYT96YE<B!U;B!C\V1I9F\@9&4@8V]L;W(@96X@
M9F]R;6%T;R!21T(@2&5X861E8VEM86PL('!O<B!E:F5M<&QO("<C,3(S-&%F
M)RX`66$@<V4@:&$@<')O8V5S861O(&5S=&4@9F]R;75L87)I;RX`17-T;R!E
M<R`E<RX`R7-T;R!E<R!U;B!O8FIE=&\@9&4@2V]L86(@1W)O=7!W87)E+B!0
M87)A('9E<FQO(&YE8V5S:71A('5N(&-L:65N=&4@9&4@8V]R<F5O("!Q=64@
M96YT:65N9&$@96P@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=F5R
M('5N82!L:7-T82!D92!D:6-H;W,@8VQI96YT97,@=FES:71E("5S`$5S=&4@
M;65N<V%J92!S92!E<V-R:6)I\R!C;VX@=6X@:G5E9V\@9&4@8V%R86-T97)E
M<R`H)7,I(&1I<W1I;G1O(&%L('-U>6\N`$5S=&4@;OIM97)O(&1E8F4@<V5R
M('!O<B!L;R!M96YO<R!U;B!U;F\N`$5S=&4@<V5R=FED;W(@;F\@<'5E9&4@
M9&5S8V]M<')I;6ER(&%R8VAI=F]S('II<"!Y(&=Z:7`N`$5S=&4@<VES=&5M
M82!A8W1U86QM96YT92!E<W3A(&1E<V%C=&EV861O+@!%<W1E('9A;&]R('1I
M96YE('%U92!S97(@=6X@;OIM97)O+@!%<W1A('9E;G1A;F$@<_-L;R!P=65D
M92!A8G)I<G-E(&1E<V1E('5N82!V96YT86YA(&1E(&]P8VEO;F5S`%1R=65N
M;P!);F-I9&5N8VEA<P!(;W)A`$,N('1I96UP;W,`1F]R;6%T;R!H;W)A<FEO
M`%-E;&5C8VGS;B!D92!H;W)A`%1I;6]R+4QE<W1E`%3M='5L;P!4[71U;&\@
M*&-O;G-E:F\I.@!087)A`%!A<F$@<V5L96-C:6]N87(@=F%R:6]S(&-A;7!O
M<RP@;6%N=&5N9V$@<'5L<V%D82!L82!T96-L82!#;VYT<F]L("A00RD@;R!#
M;VUA;F1O("A-86,I(&%L(&AA8V5R(&-L:6-K+@!(;WD`0V]N;75T87(@;W)I
M9V5N($A434P`5&]G;P!4;VME;&%U`$UA\6%N80!4;VYG80!$96UA<VEA9&]S
M(&EN=&5N=&]S(&9A;&QI9&]S(&5N(&QO<R#Z;'1I;6]S(&UI;G5T;W,N`%-U
M<&5R:6]R`$9R86UE('-U<&5R:6]R("A?=&]P*0!4<F%D=6-C:6]N97,`5')I
M;FED860@>2!4;V)A9V\`5F5R9&%D97)O(&\@9F%L<V\`36%R`%3Z;F5Z`%1U
M<G%U[6$`5'5R8V\@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W3A;@!)<VQA<R!4
M=7)K<R!Y($-A:6-O<P!4=79A;'4`17-C<FEB82!S=2!E;&5C8VGS;CH@`,UN
M9&EC92!5+E8N.B``55),`%523"!D92!S=2!I;F9O<FUE(&1E(&5S=&%D;R!D
M92!E;G;M;R!D96P@9W5I\VX`55),.@!59V%N9&$`56-R86YI80!);F-A<&%Z
M(&1E(&%C8V5D97(@86P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@8?%A
M9&ER(&EN9F]R;6%C:?-N(&1E('5S=6%R:6\@861I8VEO;F%L(&%L(')E86QI
M>F%R(&5L(&%L=&$N`$EN8V%P87H@9&4@8V%M8FEA<B!L;W,@<')I=FEL96=I
M;W,@9&5L(&%R8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@8V%M8FEA<B!L
M;W,@<')I=FEL96=I;W,@9&5L(&%R8VAI=F\@5D93("5S+R5S+@!);F-A<&%Z
M(&1E(&-A;6)I87(@82`E<RX`26YC87!A>B!D92!C;VUP<F]B87(@96P@=&%M
M8?%O(&1E("(E<R(N`$EN8V%P87H@9&4@8V]M<')O8F%R(&5L('1A;6'Q;R!D
M92`B)7,O)7,B+@!);F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R=FED;W(@
M4U%,+@!);F-A<&%Z(&1E(&-O;F5C=&%R(&-O;B!34TPN`$EN8V%P87H@9&4@
M8V]P:6%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&-R96%R(&5L(&1I
M<F5C=&]R:6\@5D93("(E<R(N`$EN8V%P87H@9&4@8W)E87(@96P@9&ER96-T
M;W)I;R!61E,N`$EN8V%P87H@9&4@8W)E87(@96P@87)C:&EV;R!61E,N`$EN
M8V%P87H@9&4@8W)E87(@;&$@8V%R<&5T82!61E,@(B5S(@!);F-A<&%Z(&1E
M(&-R96%R('5N(&%R8VAI=F\@5D93('9A8^UO+@!);F-A<&%Z(&1E(&1E<V-O
M;7!R:6UI<B!L;W,@9&%T;W,N`$EN8V%P87H@9&4@96QI;6EN87(@(B5S(BP@
M96P@9&ER96-T;W)I;R!N;R!E<W3A('9A8^UO+@!);F-A<&%Z(&1E(&5L:6UI
M;F%R("(E<R(Z("5S+@!);F-A<&%Z(&1E(&5L:6UI;F%R("5S+"!E;"!D:7)E
M8W1O<FEO(&YO(&5S=.$@=F%C[6\`26YC87!A>B!D92!E;&EM:6YA<B!E;"!D
M:7)E8W1O<FEO(%9&4R!D92!F;W)M82!R96-U<G-I=F$N`$EN8V%P87H@9&4@
M96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@96QI;6EN
M87(@96P@9&ER96-T;W)I;R!61E,Z("5S+@!);F-A<&%Z(&1E(&5L:6UI;F%R
M(&5L(&%R8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@96QI;6EN87(@96P@
M87)C:&EV;R!61E,N`$EN8V%P87H@9&4@96QI;6EN87(@;&$@8V%R<&5T82!6
M1E,@(B5S(BX`26YC87!A>B!D92!E;&EM:6YA<B!E;"!61E,@9&4@9F]R;6$@
M<F5C=7)S:79A.B`E<RX`26YC87!A>B!D92!D971E<FUI;F%R(&5L(&1I<F5C
M=&]R:6\@86-T=6%L+@!);F-A<&%Z(&1E(&5X=')A97(@;&]S(&1E=&%L;&5S
M(&1E;"!C97)T:69I8V%D;RX`26YC87!A>B!D92!C87)G87(@;&$@9&5F:6YI
M8VGS;B!D92`E<RX`26YC87!A>B!D92!T<F%S;&%D87(@96P@87)C:&EV;R!6
M1E,N`$EN8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!61E,@(B5S(BX`26YC
M87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(%9&4R!P87)A(&5S8W)I8FER+@!)
M;F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&%B
M<FER(&5L(&%R8VAI=F\@8V]M<')I;6ED;RX`26YC87!A>B!D92!L965R('5N
M(&%R8VAI=F\@5D93("AH82!F86QL861O(&9I;&5S:7IE*"DI+@!);F-A<&%Z
M(&1E(&QE97(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA9&\@9V5T1FEL95-I
M>F4H*2DN`$EN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O.B``26YC87!A>B!D
M92!L965R(&5L(&1I<F5C=&]R:6\@=F9S<F]O="X`26YC87!A>B!D92!R96YO
M;6)R87(@)7,@8V]M;R`E<SH@;&$@8V%R<&5T82!D97-T:6YO('EA(&5X:7-T
M90!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!D:7)E8W1O<FEO(%9&4RX`26YC
M87!A>B!D92!R96YO;6)R87(@96P@9&ER96-T;W)I;R!61E,Z("5S+@!);F-A
M<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4R`B)7,B`$EN8V%P87H@
M9&4@<F5N;VUB<F%R(&5L(&%R8VAI=F\@5D93("5S+R5S+@!);F-A<&%Z(&1E
M(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!E:F5C=71A
M<B`G;6MI<V]F<R<N`$YO('-E('!U961E(&%C=&EV87(@;&$@86-T=6%L:7IA
M8VGS;B!D92!I;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES<&]N:6)L92!D92`E
M<P!);F-A<&%Z(&1E(&5S8W)I8FER(&5L(&%R8VAI=F\@5D93("(E<R(N`$EN
M8V%P87H@9&4@97-C<FEB:7(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA9&\@
M8V]P>2@I*2X`26YC87!A>B!D92!E<V-R:6)I<B!L;W,@9&%T;W,@9&5L(&%R
M8VAI=F\@5D93+@!);F-A<&%Z(&1E(&5S8W)I8FER('5N(&%R8VAI=F\@5D93
M+"!S92!S=7!E<F%RX2!L82!Q=6]T82X`4W5B<F%Y861A`$1E<VAA8V5R(&-A
M;6)I;W,`1&5S:&%C92!L82#Z;'1I;6$@86-C:?-N`%)E<W!U97-T82!I;F5S
M<&5R861A(&1E;"!S97)V:61O<B!E;B!L82!C;VYE>&GS;CH@`%)E<W!U97-T
M82!I;F5S<&5R861A(&1E;"!S97)V:61O<B!A.B``4VEN(&-A=&5G;W+M80!5
M;FEC;V1E("A55$8M."D`16UI<F%T;W,@P7)A8F5S(%5N:61O<P!);F=L871E
M<G)A`$5S=&%D;W,@56YI9&]S`$5S=&%D;W,@56YI9&]S(&UE;F]S(&QA<R!I
M<VQA<R!P97)I9NER:6-A<P!5;FED861E<P!$97-C;VYO8VED;P!!<&EM<V=I
M9"!D97-C;VYO8VED;R`H240@9&4@;65N<V%J92!D92!L82!!4$DI+@!#;&EM
M<V=I9"!D97-C;VYO8VED;R`H240@9&4@;65N<V%J92!D96P@8VQI96YT92DN
M`%-E(&AA(&1E9FEN:61O('5N82!U8FEC86-I\VX@9&5S8V]N;V-I9&$N`%5S
M=6%R:6\@;R!C;VYT<F%S9?%A(&1E<V-O;F]C:61O<RX`16QI;6EN87(@=NUN
M8W5L;R!D96P@96QE;65N=&\@86-T=6%L`%-I;B!N;VUB<F4`3&]S(&=U:6]N
M97,@<VEN('!R:79I;&5G:6]S(&YO('!U961E;B!A8V-E9&5R(&1E(&9O<FUA
M('!R;V=R86WA=&EC82!A($-O<G1A<B]#;W!I87(O4&5G87(@<&]R(')A>F]N
M97,@9&4@<V5G=7)I9&%D+B!0=6QS92!!8V5P=&%R('!A<F$@=F5R(&5N(&UO
M>FEL;&$N;W)G('5N82!N;W1A('3I8VYI8V$@<75E(&QE(&UU97-T<F4@8_-M
M;R!P97)M:71I<B!Q=64@=6X@9W5I\VX@86-C961A(&%L('!O<G1A<&%P96QE
M<RX`06YU;&%R(&-O;&]R`$5X=&5N<VGS;B!N;R!S;W!O<G1A9&$`06-T=6%L
M:7IA<@!!8W1U86QI>F%R("5S`$%C='5A;&EZ87(@=7-U87)I;P!392!H82!A
M8W1U86QI>F%D;R`B)7,B+@!392!H82!E;&EM:6YA9&\@96P@9W5I\VX@9&4@
M86-T=6%L:7IA8VGS;BX`0V%R9V%R`%-E(&AA;B!C87)G861O(&5N(&5L('-E
M<G9I9&]R('1O9&]S(&QO<R!A<F-H:79O<R!D92!C;VYF:6=U<F%C:?-N(&1E
M(&%P;&EC86-I;VYE<RX`06QF86)E=&\@;&%T:6YO(&5N(&UA>?IS8RX`3OIM
M97)O<R!R;VUA;F]S(&5N(&UA>?IS8RX`57)U9W5A>0!5<V%R(&%C='5A;#H@
M)7,`57-A<B!34TP`4V4@=7-A('-I(&5L('5S=6%R:6\O8V]N=')A<V7Q82!S
M;VX@9&ES=&EN=&]S(&5N(&5L('-E<G9I9&]R($E-4U`N`%5S=6%R:6\`16P@
M=7-U87)I;R`E<R!C87)E8V4@9&4@875T;W)I>F%C:?-N('!A<F$@)7,N`$%D
M;6EN:7-T<F%C:?-N(&1E('5S=6%R:6]S`$]P8VEO;F5S(&1E('5S=6%R:6\`
M4F5G:7-T<F\@9&4@=7-U87)I;W,`17-T82!S961E('1I96YE(&1E<V%C=&EV
M861O(&5L(')E9VES=')O(&1E('5S=6%R:6]S+@!.;R!S92!H82!E;F-O;G1R
M861O(&QA(&ED96YT:61A9`!5<W5A<FEO`%EA(&5X:7-T92!E;"!N;VUB<F4@
M9&4@=7-U87)I;R`B)7,B+@!5<W5A<FEO.@!5<W5A<FEO.B``57-U87)I;W,@
M96X@96P@<VES=&5M83H`57IB96MI<W3A;@!.;R!E>&ES=&4@96P@9&ER96-T
M;W)I;R!61E,N`$%U<V5N8VEA`$QA<R!U8FEC86-I;VYE<R!VX6QI9&%S(&5N
M8V]N=')A9&%S(&EN8VQU>65N.B``5F%L:61E>@!686QO<B!E;B!M:6YU=&]S
M(&$@<&%R=&ER(&1E(&%H;W)A+@!%;"!V86QO<B!E>&-E9&4@96P@=&%M8?%O
M(&WA>&EM;R!D92`E<RX`5F%L;W)E<P!686QO<F5S(&$@<V5L96-C:6]N87(`
M5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`2&$@9F%L;&%D;R!L82!C;VUP
M<F]B86-I\VX@+2!E<W1E(&UE;G-A:F4@<'5E9&4@:&%B97)S92!F;W)Z861O
M+@!697)S:?-N`$,N('9E<G-I;VYE<P!!;&EN96%C:?-N('9E<G1I8V%L`$UA
M<F=E;B!V97)T:6-A;`!697)T:6-A;#H`375Y(&%L=&$`5FEE=&YA;0!6:65T
M;F%M:71A("A625-#24DI`%9E<B`E<P!697(@=6YA('#A9VEN82!W96(@97AT
M97)N80!697(@8V]M;R`E<P!)<VQA<R!6[7)G96YE<RP@0G)I=.%N:6-A<P!)
M<VQA<R!6[7)G96YE<RP@52Y3+@!6:7-I8FEL:61A9`!6:7-I8FEL:61A9#H@
M`%9O9&%F;VYE(&1E($ET86QI82!M961I86YT92!33510`$%625-/`*&AH4%$
M5D525$5.0TE!(2$A($5,24U)3D4@34%.54%,345.5$4@14P@1U5)TTX@1$4@
M)7,N`%=)3B!P;W(@2%144`!786QL:7,@>2!&=71U;F$`061V97)T96YC:6$`
M36EE`%!R979I<VGS;B!D96P@=&EE;7!O`$1A=&]S(&1E;"!T:65M<&\@<W5M
M:6YI<W1R861O<R!P;W(`5V5A=&AE<BYC;VT`5V5B`%-E9&4@5V5B`%-E;6%N
M86QM96YT90!":65N=F5N:61O`$)I96YV96YI9&]S(&$@)7,`0FEE;G9E;FED
M;RP@)7,`3V5S=&4@*$E33RTX.#4Y+3$I`$]E<W1E("A)4T\M.#@U.2TQ-2D`
M4^%H87)A($]C8VED96YT86P`OU%UZ2!A<&QI8V%C:?-N(&1E8F5R[6$@;6]S
M=')A<B`E<R!A;"!I;FEC:6%R(&QA('-E<VGS;C\`OT-UX6P@97,@96P@8V%R
MX6-T97(@9&5L:6UI=&%D;W(_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E(&-I
M=&%D;S\`36%P82!D92!L;V-A;&EZ86-I\VX@9&4@075S=')A;&EA`%%UZ2!F
M87-E<P!0;'5G:6YS(&AA8FEL:71A9&]S(&1E;"!E9&ET;W(@9&4@=&5X=&\@
M96YR:7%U96-I9&\N`$%N8VAU<F$`06YC:'5R82!E;B!U;FED861E<R!#4U,`
M06YC:'5R82!D96P@;65N^B`E<R!I>G%U:65R9&\@*&1I<W!O;FEB;&4@96X@
M;&$@<'+S>&EM82!S97-I\VXI.@!!;F-H=7)A(&1E(&QA('1A8FQA`%5N:61A
M9&5S(&1E(&%N8VAU<F$`06YC:'5R83H`5VEK:0!6:65N=&\`5FEE;G1O(&UA
M='5T:6YA`%9E;&]C:61A9"!D96P@=FEE;G1O(&5N(&YU9&]S`%9I96YT;SH`
M5FEE;G1O.B``4V%B:61U<NUA`$1E<V5O<P!%;7!L96\`1&ER96-C:?-N(&1E
M;"!T<F%B86IO`%1E;.EF;VYO(&1E;"!T<F%B86IO`$[Z;65R;R!E<G+S;F5O
M(&1E(&-A;7!O<R!E;B!L82!L[6YE82`E9"X@4V4@97-P97)A8F%N("5D('D@
M:&%Y("5D+@!.^FUE<F\@97)R\VYE;R!D92!C86UP;W,N(%-E(&5S<&5R86)A
M;B`E9"!Y(&AA>2`E9"X`3V9F<V5T("5D(&5R<O-N96\@86P@;&5E<B!U;B!A
M<F-H:79O(%9&4RX`6"U2968`3&EM:71A8VEO;F5S(&+A<VEC87,@6#4P.78S
M`%5S;R!D92!C;&%V92!E>'1E;F1I9&$@6#4P.78S`$YO;6)R92!A;'1E<FYA
M=&EV;R!D92!A<W5N=&\@6#4P.78S`$ED96YT:69I8V%D;W(@9&4@8VQA=F4@
M9&4@87-U;G1O(%@U,#EV,P!%>'1E;G-I;VYE<R!8-3`Y=C,`04$`04%!00"A
M36%P82!D92!986AO;R$`06YU86QM96YT90!996UE;@!3[0!3[2P@;&\@86-E
M<'1O`$5S=.$@96X@34]$3R!415A43RX@571I;&EC92!E;"!B;W3S;B!;/#Y=
M('!A<F$@<F5G<F5S87(@86P@;6]D;R!765-)5UE'+@!.;R!D:7-P;VYE(&1E
M('!R:79I;&5G:6]S('!A<F$@8W)E87(@;>%S(&1E("5D(&)L;W%U97,N`$YO
M(&5S=.$@875T96YT:69I8V%D;RX`3F\@<'5E9&4@:6YC;'5I<B!E;"!C87+A
M8W1E<B`B7"(@96X@96P@;F]M8G)E(&-O;7!L971O+@!.;R!I;G1R;V1U:F\@
M=6YA(&1I<F5C8VGS;B!D92!C;W)R96\@=N%L:61A+@!.;R!A<V]C:?,@;FEN
M9W5N;R!D92!L;W,@8V%M<&]S(&1E;"!A<F-H:79O(&EM<&]R=&%D;R!A(&QO
M<R!C86UP;W,@8V]R<F5S<&]N9&EE;G1E<R!D92`E<RX`2&$@<V%L:61O(&1E
M(&QA('-E<VGS;BX`5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@;OIM97)O(&1E
M('1E;.EF;VYO(&WS=FEL(';A;&ED;RP@<_-L;R!D[6=I=&]S(&-O;B!U;B`G
M*R<@;W!C:6]N86P@<&%R82!E;"!P<F5F:6IO(&1E(&QL86UA9&$@:6YT97)N
M86-I;VYA;"X`5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@=F%L;W(@=N%L:61O
M+@!087)A('5S87(@06QT87,@=&EE;F4@<75E(&-O;F9I9W5R87(@=6X@;6]T
M;W(@9&4@1&%T851R964N`%1I96YE('%U92!C;VYF:6=U<F%R('5N(&UO=&]R
M(%9&4RX`1&5B92!D97-C<FEB:7(@96P@<')O8FQE;6$@86YT97,@9&4@96YV
M:6%R(&5L(&EN9F]R;64N`%1I96YE('%U92!I;G1R;V1U8VER(&QA(%523"!A
M(&QA('%U92!A<'5N=&$@97-T92!V[6YC=6QO`%1I96YE('%U92!S96QE8V-I
M;VYA<B!U;B!S97)V:61O<B!A(&5L:6UI;F%R+@!4:65N92!Q=64@97-P96-I
M9FEC87(@=6X@=7-U87)I;R!A(&5L:6UI;F%R+@!4:65N92!Q=64@97-P96-I
M9FEC87(@=6X@=7-U87)I;R!A(&5L:6UI;F%R+@!4:65N92!Q=64@97-P96-I
M9FEC87(@96P@=7-U87)I;R!A(&'Q861I<BX`5&EE;F4@<75E(&5S<&5C:69I
M8V%R(&5L('5S=6%R:6\@82!A8W1U86QI>F%R+@!4:65N92!Q=64@97-P96-I
M9FEC87(@<77I(&%C8VGS;B!S92!E:F5C=71A<N$N`%1I96YE('%U92!I;G1R
M;V1U8VER('5N(&YU979O(&YO;6)R92!D92!C871E9V]R[6$N`%1I96YE('%U
M92!I;G1R;V1U8VER('5N(&[Z;65R;R!D92!T96SI9F]N;R!I=&%L:6%N;P!(
M82!E>'!I<F%D;R!S=2!S97-I\VX@)7,N(%9U96QV82!A(&EN:6-I87(@<V5S
M:?-N+@!3=2!D:7)E8V-I\VX@9&4@8V]R<F5O`$1I<F5C8VGS;B!$93H`4W4@
M:6YF;W)M86-I\VX`2&$@8V%M8FEA9&\@<W4@9&ER96-C:?-N(&1E($EN=&5R
M;F5T(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R(')A
M>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U92!V;VQV97(@82!I;FEC:6%R
M(&QA('-E<VGS;BX`4W4@;F]M8G)E`%-U(&UO=&]R(&1E(&%U=&5N=&EF:6-A
M8VGS;B!N;R!P97)M:71E(&'Q861I<B!U<W5A<FEO<RX@4VD@<75I<VEE<F$@
M=7-A<B!(;W)D92!P87)A(&%D;6EN:7-T<F%R(&-U96YT87,@9&4@=7-U87)I
M;RP@=&5N9'+A('%U92!U=&EL:7IA<B!U;B!M;W1O<B!D92!A=71E;G1I9FEC
M86-I\VX@9&ES=&EN=&\N`%-U(&UO=&]R(&1E(&%U=&5N=&EF:6-A8VGS;B!N
M;R!P97)M:71E(&QI<W1A<B!U<W5A<FEO<RP@;R!S92!H82!D97-H86)I;&ET
M861O(&QA(&-A<F%C=&5R[7-T:6-A('!O<B!A;&?Z;B!M;W1I=F\N`%!A<F5C
M92!Q=64@:&$@8V%M8FEA9&\@<W4@;F%V96=A9&]R(&1E<V1E(&5L(&-O;6EE
M;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R(')A>F]N97,@9&4@<V5G=7)I9&%D
M('1I96YE('%U92!V;VQV97(@82!I;FEC:6%R(&QA('-E<VGS;BX`4W4@;F%V
M96=A9&]R(&YO(&%D;6ET92!E<W1A(&-A<F%C=&5R[7-T:6-A+@!%;"!N879E
M9V%D;W(@;F\@861M:71E(&5S=&$@;W!C:?-N(&1E(&EM<')E<VGS;BX@4')E
M<VEO;F4@0V]N=')O;"]#;VUA;F1O("L@4"!P87)A(&EM<')I;6ER+@!:;VYA
M(&AO<F%R:6$@86-T=6%L.@!392!H82!C86UB:6%D;R!S=2!I9&5N=&ED860@
M<&]R(&]M:7-I\VXN`$ED96YT:61A9"!P;W(@;VUI<VGS;CH`3F]M8G)E(&-O
M;7!L971O.@!392!H82!A9V]T861O('-U('1I96UP;R!D92!C;VYE>&GS;BX`
M3&$@;G5E=F$@8V]N=')A<V7Q82!P87)A("5S(&5S.B`E<P!392!H86X@86-T
M=6%L:7IA9&\@<W5S(&]P8VEO;F5S('/S;&\@<&]R(&QA(&1U<F%C:?-N(&1E
M(&QA('-E<VGS;BX`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE<RX`
M4V4@:&$@<F5A:G5S=&%D;R!S=2!C;VYT<F%S9?%A`%-E(&AA(')E86IU<W1A
M9&\@<W4@8V]N=')A<V7Q82P@8V]M<')U96)E(&5L(&-O<G)E;R!E(&EN:6-I
M92!S97-I\VX@8V]N('-U(&YU979A(&-O;G1R87-E\6$N`$QA(&-O;G1R87-E
M\6$@:&$@97AP:7)A9&\N`%-E<G9I9&]R97,@<F5M;W1O<SH`675G;W-L879I
M80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6T]C=6QT87(@=&5X=&\@
M8VET861O70!;26YF;W)M92!D92!P<F]B;&5M85T`6TUO<W1R87(@=&5X=&\@
M8VET861O("T`6TUO<W1R87(@=&5X=&\@8VET861O("T@)7,@;.UN96%S70!;
M;.UN96$@)7,@9&4@)7-=`%]!9&UI;FES=')A8VGS;@!?0TQ)`,%R7V)O;"!D
M871O<P!%7VQI;6EN87(@9FEL80!?1W)U<&]S`$%?>75D80!0<F]P:65D861E
M<R!D92!?:6UA9V5N+BXN`%]);FEC:6%R('-E<VGS;@!?4V%L:7(`36]D:69I
M8V%R(%]V[6YC=6QO+BXN`%]/<&-I;VYE<P!?4')I=FEL96=I;W,`7T5L:6UI
M;F%R(';M;F-U;&\N+BX`0V]N7V9I9W5R86,N`%!R;W!I961A9&5S(&1E(%]T
M86)L82XN+@!?57-U87)I;W,`9&ER96-C:6]N97,`9&5S=&EN871A<FEO(&1E
M<V-O;F]C:61O`&%G96YD80!C86QM80!N;R!S92!P=65D92!C<F5A<B!E;"!A
M<F-H:79O(&1E(&1E<W1I;F\`;F\@<V4@<'5E9&4@86)R:7(@96P@;W)I9V5N
M`'!U;'-E(&%Q=>T`97)R;W(@9&4@;.UN96$@9&4@8V]M86YD;P!E<G)O<B!D
M92!C;VYF:6=U<F%C:?-N`&9A;'1A('5N(&%R8VAI=F\@8W+M=&EC;R!D96P@
M<VES=&5M80!E<G)O<B!D92!F;W)M871O(&1E(&1A=&]S`&UO9&EF:6-A<@!E
M;G1R861A(&YO(&5N8V]N=')A9&$`9&5S8V5N<V\`87)C:&EV;P!D96P@)7,@
M*"5S*2!A(&QA<R`E<R`E<P!V96YT;W-O`&@Z`&AH`&YO;6)R92!D92!A;F9I
M=')I\VX@9&5S8V]N;V-I9&\`:6YM961I871A;65N=&4`96X@;.UN96$`97)R
M;W(@9&4@96YT<F%D82]S86QI9&$`97)R;W(@9&4@<V]F='=A<F4@:6YT97)N
M;P!L[6YE87-=`&/S9&EG;R!D92!E<G)O<B!M:VES;V9S("5D(&%L(')E86QI
M>F%R($E33RX`;6T`;F]M8G)E`'-I;B!D97-A<G)O;&QA<@!A^FX@;F\@<V4@
M:&$@9&5S87)R;VQL861O`&YO=&%S`'!O<F-E;G1A:F4`<')I=FEL96=I;R!D
M96YE9V%D;P!P[7AE;&5S`&5R<F]R(')E;6]T;R!D92!P<F]T;V-O;&\`96X@
M875M96YT;P!S97)V:6-I;R!N;R!D:7-P;VYI8FQE+@!M;W-T<F%R(&1I9F5R
M96YC:6%S`'-M<S)E;6%I;"!P;W(@2%144`!S<P!E<W1A8FQE`&5R<F]R(&1E
M;"!S:7-T96UA`'1A<F5A<P!F86QL;R!T96UP;W)A;`!E<V-R:6)A(&1O<R!V
M96-E<R!L82!C;VYT<F%S9?%A('!A<F$@8V]N9FER;6%R;&$`=6YI9FEC861O
M`'-I;B!N;VUB<F4`=7-U87)I;R!S96QE8V-I;VYA9&\`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O97-?15,O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,S(S
M`#$P-3$U-#,Q,#8Q`#`R,#,Q-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D
M2&]R9&4Z(&AO<F1E+VQO8V%L92]E<U]%4R]H96QP+GAM;"QV(#$N,R`R,#`T
M+S$R+S$P(#$V.C$W.C,W(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y
M(&ED/2)S=6UM87)Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-CAC83,S9C=F
M,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B/@H\=&ET;&4^3&$@<"8C>$4Q.V=I
M;F$@9&5L('!O<G1A;#PO=&ET;&4^"B`\<&%R83X*("!%<W1A('`F(WA%,3MG
M:6YA(&1E;"!P;W)T86P@<')O<&]R8VEO;F$@=6X@<B8C>$4Q.W!I9&\@<F5S
M=6UE;B!D92!T;V1A('-U(&EN9F]R;6%C:28C>$8S.VX*("!I;7!O<G1A;G1E
M+B!0;W(@96IE;7!L;RP@<'5E9&4@;6]S=')A<B!C=28C>$4Q.VYT;W,@;65N
M<V%J97,@;G5E=F]S('1I96YE(&5N(&5L"B`@8G5Z)B-X1C,[;B!D92!%;G1R
M861A+"!A8V]N=&5C:6UI96YT;W,@:6YM:6YE;G1E<R!D92!L82!A9V5N9&$L
M('1A<F5A<R!P96YD:65N=&5S"B`@9&4@;&$@;&ES=&$@9&4@=&%R96%S+"!T
M:71U;&%R97,@9&4@<V5R=FEC:6]S(&1E(&YO=&EC:6%S('-E;&5C8VEO;F%D
M;W,L(&5T8RX*("!-=6-H;W,@9&4@97-T;W,@<F5S)B-X1D$[;65N97,@<&]D
M<B8C>$4Q.VX@8V]N=&5N97(@871A:F]S(&$@86-T:79I9&%D97,@=7-U86QE
M<R!T86QE<PH@(&-O;6\@;&$@<F5D86-C:28C>$8S.VX@9&4@;G5E=F]S(&UE
M;G-A:F5S+"!L82!C<F5A8VDF(WA&,SMN(&1E(&%C;VYT96-I;6EE;G1O<R!D
M92!L80H@(&%G96YD82!O('1A<F5A<R!N=65V87,L(&5T8RX*(#PO<&%R83X*
M(#QP87)A/@H@($QO<R!C;VYT96YI9&]S(&1E(&5S=&$@<"8C>$4Q.V=I;F$@
M9&5L('!O<G1A;"!S92!P=65D96X@<&5R<V]N86QI>F%R(&UE9&EA;G1E(&5L
M"B`@8F]T)B-X1C,[;B!$:7-T<FEB=6-I)B-X1C,[;BX@4&]R(&5J96UP;&\L
M('!U961E(&5L96=I<B!Q=28C>$4Y.R!E;&5M96YT;W,@:6YC;'5I<B!E;B!E
M<W1A"B`@<"8C>$4Q.V=I;F$@9&5L('!O<G1A;"!A<R8C>$5$.R!C;VUO(&5L
M(&]R9&5N(&5N(&5L('%U92!S92!M;W-T<F%R)B-X13$[;BX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](G5P=&]D871E
M(B!M9#4](F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I
M=&QE/DQA(&)A<G)A(&1E(&YA=F5G86-I)B-X1C,[;B!D92!A<&QI8V%C:6]N
M97,\+W1I=&QE/@H@/'!A<F$^"B`@16X@96P@;&%D;R!I>G%U:65R9&\@9&4@
M;&$@<"8C>$4Q.V=I;F$@=V5B('-E(&5N8W5E;G1R82!L82!B87)R82!D92!N
M879E9V%C:28C>$8S.VX@9&4*("!A<&QI8V%C:6]N97,N(%!U;'-E(&QO<R!I
M8V]N;W,@9&4@9&EC:&$@8F%R<F$@<&%R82!C86UB:6%R('(F(WA%,3MP:61A
M('D@9B8C>$4Q.V-I;&UE;G1E"B`@96YT<F4@;&%S(&%P;&EC86-I;VYE<R!D
M:7-P;VYI8FQE<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB9&0Y
M-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B/@H@("`@/'1I=&QE/E!R
M969E<F5N8VEA<SH@36%N=&5N:6UI96YT;SH@4F5A;&EZ87(@;6%N=&5N:6UI
M96YT;SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-I(&1E<V5A(')E86QI>F%R
M(&QA<R!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O(&%L(&EN:6-I87(@
M;&$@<V5S:28C>$8S.VXL"B`@("!S96QE8V-I;VYE(&5S=&$@8V%S:6QL82X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I
M<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q-C)C
M9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^4')E9F5R
M96YC:6%S.B!-86YT96YI;6EE;G1O.B!#;VYF:7)M87(@;6%N=&5N:6UI96YT
M;SPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-I('%U:7-I97)A(&-O;F9I<FUA
M<B!L87,@=&%R96%S(&1E(&UA;G1E;FEM:65N=&\@86YT97,@9&4@<75E('-E
M(&5J96-U=&5N+`H@("`@<V5L96-C:6]N92!E<W1A(&-A<VEL;&$N(%-I('-E
M(&1E:F$@<VEN('-E;&5C8VEO;F%R+"!S92!E:F5C=71A<B8C>$4Q.VX*("`@
M(&%U=&]M)B-X13$[=&EC86UE;G1E(&%L(&EN:6-I87(@;&$@<V5S:28C>$8S
M.VX@=&]D87,@;&%S('1A<F5A<R!D92!M86YT96YI;6EE;G1O"B`@("!P96YD
M:65N=&5S('-I;B!L82!P;W-I8FEL:61A9"!D92!C86YC96QA<FQA<RX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M9FE?1DDO````````````````````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8R,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]F:5]&22],0U]-15-304=%4R\`````````````
M````````````````````````````````````````````````````,#`T,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#(P
M-#$P`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V9I7T9)+TQ#7TU%
M4U-!1T53+VAO<F1E+FUO````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0Q,C0P
M,0`Q,#4Q-30S,3`V,0`P,C(P-#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0````"*!P``'````&P\```3"@``O'@`
M```````(H0``#@````FA```/````&*$```T````HH0``"````#:A```+````
M/Z$```P```!+H0``!````%BA```8````7:$``!L```!VH0``+0```)*A```=
M````P*$``"0```#>H0``*0````.B```9````+:(``"8```!'H@``#````&ZB
M```D````>Z(```\```"@H@``"P```+"B```.````O*(```4```#+H@``*```
M`-&B```(````^J(```H````#HP``%0````ZC```2````)*,```L````WHP``
MA0```$.C```.````R:,```H```#8HP``#0```..C```.````\:,``!$`````
MI```#0```!*D```,````(*0```T````MI```!@```#ND``"4````0J0```H`
M``#7I```#P```.*D```8````\J0```P````+I0``#@```!BE```.````)Z4`
M``@````VI0``"0```#^E```N````2:4``!H```!XI0``,@```).E```X````
MQJ4``%0```#_I0``40```%2F``!:````IJ8``%<````!IP``-````%FG```)
M````CJ<```T```"8IP``!P```*:G```*````KJ<```\```"YIP``!0```,FG
M```&````SZ<``!$```#6IP``"````.BG```)````\:<```D```#[IP``)0``
M``6H```@````*Z@``!,```!,J```$````&"H```/````<:@```H```"!J```
M`P```(RH```/````D*@``!0```"@J```"0```+6H```-````OZ@``!(```#-
MJ```&0```."H```>````^J@```\````9J0``"@```"FI```/````-*D```@`
M``!$J0``)````$VI```4````<JD``!8```"'J0``"````)ZI``!.````IZD`
M`"T```#VJ0``&0```"2J```'````/JH```P```!&J@``+````%.J```.````
M@*H```,```"/J@``"P```).J```'````GZH```<```"GJ@``!0```*^J```%
M````M:H```H```"[J@```P```,:J```7````RJH```H```#BJ@``#P```.VJ
M```.````_:H``!@````,JP``(P```"6K```.````2:L``!0```!8JP``%P``
M`&VK```7````A:L``!<```"=JP``$P```+6K```/````R:L```X```#9JP``
M'P```.BK```=````"*P```<````FK```!@```"ZL```(````-:P```\````^
MK```!@```$ZL```*````5:P``!,```!@K```"P```'2L```0````@*P``!4`
M``"1K```%0```*>L```'````O:P``!````#%K```!0```-:L```5````W*P`
M`!$```#RK```#`````2M```[````$:T``#@```!-K0``"0```(:M```'````
MD*T``!0```"8K0```P```*VM```%````L:T``!````"WK0``"0```,BM```3
M````TJT``#D```#FK0``$@```""N```G````,ZX``"P```!;K@``*@```(BN
M```E````LZX```H```#9K@``!@```.2N```)````ZZX```<```#UK@``+P``
M`/VN```W````+:\``"X```!EKP``50```)2O```M````ZJ\``"T````8L```
M/0```$:P```_````A+```"T```#$L```0````/*P```C````,[$``",```!7
ML0``0````'NQ```M````O+$``#,```#JL0``)0```!ZR```5````1+(``!D`
M``!:L@``*0```'2R```D````GK(``"@```##L@``$0```.RR```*````_K(`
M``P````)LP``"@```!:S```0````(;,``!8````RLP``%@```$FS```'````
M8+,```<```!HLP``%````'"S```*````A;,```@```"0LP``)P```)FS```(
M````P;,```<```#*LP``!P```-*S```&````VK,```4```#ALP``!P```.>S
M```&````[[,```@```#VLP``*0```/^S```.````*;0```H````XM```!```
M`$.T```'````2+0```D```!0M```!@```%JT```1````8;0```<```!SM```
M%@```'NT```$````DK0```@```"7M```!@```*"T```-````I[0```8```"U
MM```'@```+RT```1````V[0```@```#MM```#0```/:T```,````!+4```<`
M```1M0```P```!FU```#````';4``!<````AM0``$P```#FU```=````3;4`
M``@```!KM0``!````'2U```(````>;4```@```""M0``00```(NU```:````
MS;4``"L```#HM0``(````!2V```5````-;8```8```!+M@``!@```%*V```5
M````6;8``!@```!OM@``(@```(BV```N````J[8``!T```#:M@``(0```/BV
M``!4````&K<``"D```!OMP``"@```)FW```'````I+<```<```"LMP``%0``
M`+2W```.````RK<```H```#9MP``#P```.2W```-````]+<```\````"N```
M#0```!*X```)````(+@``!0````JN```!@```#^X```8````1K@``!T```!?
MN```$P```'VX```1````D;@``!0```"CN```!````+BX```&````O;@``!0`
M``#$N```5````-FX``!D````+KD```0```"3N0``#@```)BY```%````I[D`
M``4```"MN0``&P```+.Y```:````S[D``!,```#JN0``$0```/ZY```1````
M$+H``!P````BN@``*@```#^Z```0````:KH``"$```![N@``!0```)VZ```3
M````H[H```L```"WN@``$@```,.Z```*````UKH```\```#AN@``#0```/&Z
M```1````_[H``!,````1NP``#````"6[```&````,KL```P````YNP``!@``
M`$:[```7````3;L``!````!ENP``$0```':[```(````B+L```4```"1NP``
M#````)>[```0````I+L```4```"UNP``#0```+N[```&````R;L```<```#0
MNP``#0```-B[```'````YKL```L```#NNP``!P```/J[```'`````KP```D`
M```*O```"0```!2\```*````'KP``!D````IO```/0```$.\```=````@;P`
M``P```"?O```$````*R\```%````O;P``"4```##O```$@```.F\```3````
M_+P``"L````0O0``.P```#R]```@````>+T```@```"9O0``-@```**]```A
M````V;T``!````#[O0``"`````R^```,````%;X```8````BO@``!````"F^
M```/````+KX```X````^O@``!P```$V^```*````5;X```T```!@O@``'P``
M`&Z^```<````CKX``"$```"KO@``'@```,V^```9````[+X``!X````&OP``
M&P```"6_```A````0;\``"X```!COP``)@```)*_```<````N;\``!X```#6
MOP``'````/6_```F````$L```"L````YP```,P```&7````F````F<```"L`
M``#`P```.````.S````=````)<$``!4```!#P0``+P```%G!```@````B<$`
M`!(```"JP0``*0```+W!```>````Y\$``"`````&P@``$@```"?"``"B````
M.L(``!8```#=P@``(P```/3"```H````&,,``"D```!!PP``*````&O#```?
M````E,,``!4```"TPP``(````,K#```E````Z\,``"@````1Q```+0```#K$
M```P````:,0``)(```"9Q```(0```"S%```6````3L4``!P```!EQ0``)@``
M`(+%```J````J<4``$$```#4Q0``1````!;&```,````6\8```<```!HQ@``
M!P```'#&```&````>,8```T```!_Q@``$````(W&```2````GL8``!,```"Q
MQ@``$@```,7&```'````V,8```0```#@Q@``$````.7&```0````]L8```P`
M```'QP``#@```!3'```-````(\<```\````QQP``$P```$''```-````5<<`
M`"@```!CQP```P```(S'```-````D,<```8```">QP``$0```*7'```7````
MM\<``!L```#/QP``#@```.O'```"````^L<``$D```#]QP``!0```$?(```0
M````3<@```\```!>R```!````&[(```-````<\@```X```"!R````P```)#(
M```.````E,@```@```"CR```#P```*S(```/````O,@```<```#,R```#0``
M`-3(```0````XL@```T```#SR```"P````')```&````#<D```L````4R0``
M#````"#)```*````+<D``!$````XR0``&0```$K)```+````9,D```T```!P
MR0``(@```'[)```/````H<D``!L```"QR0``-````,W)```*`````LH``!@`
M```-R@``$@```";*```9````.<H``!8```!3R@``(@```&K*```-````C<H`
M``<```";R@``%````*/*```+````N,H``"(```#$R@``+P```.?*```+````
M%\L```D````CRP``&0```"W+```+````1\L``!<```!3RP``%P```&O+```)
M````@\L``!8```"-RP``#P```*3+```9````M,L``!8```#.RP``#@```.7+
M```8````],L```@````-S```#0```!;,```F````),P``$,```!+S```"```
M`(_,```2````F,P``!\```"KS```"````,O,```+````U,P``"\```#@S```
M#@```!#-```%````'\T```8````ES0``10```"S-```#````<LT```<```!V
MS0``!````'[-```*````@\T```H```".S0``#P```)G-```0````J<T``!<`
M``"ZS0``$0```-+-```9````Y,T``!<```#^S0``"0```!;.```%````(,X`
M``L````FS@``"@```#+.```"````/<X```4```!`S@``#0```$;.```;````
M5,X``!<```!PS@``%````(C.```)````G<X```X```"GS@``#0```+;.```2
M````Q,X``#@```#7S@``(````!#/```(````,<\```X````ZSP``>P```$G/
M```8````Q<\``!@```#>SP``$0```/?/```'````"=````4````1T```&```
M`!?0```>````,-```!L```!/T```&0```&O0```;````A=```!D```"AT```
M$P```+O0```'````S]````@```#7T```!@```.#0```&````Y]```!````#N
MT```#P```/_0```0````#]$```\````@T0``"P```##1```/````/-$```P`
M``!,T0``#P```%G1```'````:=$```8```!QT0``#@```'C1```,````A]$`
M`"@```"4T0``#P```+W1```(````S=$```@```#6T0``$P```-_1```>````
M\]$``"$````2T@``(````#32```9````5=(``!<```!OT@``)0```(?2```7
M````K=(``!8```#%T@``!````-S2```;````X=(```T```#]T@``#`````O3
M```#````&-,```4````<TP``"````"+3```*````*],```P````VTP``"P``
M`$/3```0````3],```P```!@TP``#@```&W3```+````?-,```0```"(TP``
M!````(W3```3````DM,``!0```"FTP``#````+O3```)````R-,```X```#2
MTP``"P```.'3```;````[=,```<````)U```!P```!'4```*````&=0```T`
M```DU```"0```#+4```$````/-0```4```!!U````P```$?4```8````2]0`
M``H```!DU```!````&_4```F````=-0```X```";U```?````*K4```5````
M)]4```4````]U0``!P```$/5```,````2]4```@```!8U0``"@```&'5```&
M````;-4```@```!SU0```@```'S5```&````?]4```8```"&U0``%````(W5
M```-````HM4``!````"PU0``&P```,'5```$````W=4```D```#BU0``$```
M`.S5```)````_=4```D````'U@``!0```!'6```:````%]8```@````RU@``
M!@```#O6```9````0M8```X```!<U@``!P```&O6```'````<]8```4```![
MU@``"0```('6```*````B]8```X```"6U@```@```*76```&````J-8```L`
M``"OU@``#0```+O6```)````R=8```8```#3U@``$@```-K6```)````[=8`
M``<```#WU@``%````/_6```=````%-<``$(````RUP``)0```'77```E````
MF]<```8```#!UP``"@```,C7```$````T]<```D```#8UP``"````.+7```1
M````Z]<```D```#]UP``!@````?8```-````#M@```8````<V```!````"/8
M```Y````*-@``#T```!BV```.@```*#8```>````V]@```4```#ZV```#@``
M``#9```$````#]D```8````4V0``!P```!O9```A````(]D```T```!%V0``
M%0```%/9```&````:=D```0```!PV0``$0```'79```&````A]D```H```".
MV0``(@```)G9```$````O-D```4```#!V0``'0```,?9```$````Y=D```P`
M``#JV0``#@```/?9```*````!MH```@````1V@``"0```!K:```%````)-H`
M`#H````JV@``,````&7:```U````EMH``"D```#,V@``1P```/;:```X````
M/ML``"D```!WVP``/P```*';```N````X=L``"T````0W```'P```#[<```/
M````7MP``!(```!NW```"P```('<```F````C=P``"D```"TW```)````-[<
M```F`````]T```@````JW0``"@```#/=```)````/MT```<```!(W0``(```
M`%#=```@````<=T``"8```"2W0``"@```+G=```9````Q-T``"D```#>W0``
M%@````C>```2````']X```<````RW@``"@```#K>```,````1=X```\```!2
MW@``$````&+>``!`````<]X``'````"TW@``9@```"7?```.````C-\```D`
M``";WP``"@```*7?```2````L-\``!,```##WP``#````-??```&````Y-\`
M``\```#KWP``$@```/O?```0````#N```!$````?X```'````#'@```C````
M3N```&H```!RX```#P```-W@```%````[>```!````#SX```"0````3A```$
M````#N$```L````3X0``(````!_A```4````0.$```P```!5X0``#````&+A
M```/````;^$``!4```!_X0``*0```)7A```J````O^$``"8```#JX0``)P``
M`!'B```I````.>(``"H```!CX@``&0```([B``!"````J.(``!$```#KX@``
M$@```/WB```3````$.,``!0````DXP``#P```#GC```6````2>,``!<```!@
MXP``$````'CC```1````B>,``#0```";XP``$P```-#C```2````Y.,``#4`
M``#WXP``%````"WD```'````0N0```P```!*Y```(````%?D```0````>.0`
M`!0```")Y```$0```)[D```7````L.0``!P```#(Y```$P```.7D```4````
M^>0``!H````.Y0``$0```"GE```:````.^4``!X```!6Y0``&@```'7E```3
M````D.4``!4```"DY0``$0```+KE```7````S.4``!0```#DY0``%P```/GE
M```5````$>8```D````GY@``$````#'F```9````0N8```0```!<Y@``!P``
M`&'F```+````:>8``!$```!UY@``!@```(?F```&````CN8```8```"5Y@``
M!0```)SF```'````HN8```<```"JY@``!0```++F```6````N.8```8```#/
MY@``!@```-;F```$````W>8```0```#BY@``!P```.?F```.````[^8```P`
M``#^Y@``#`````OG```-````&.<```H````FYP``#@```#'G```%````0.<`
M`"@```!&YP``#@```&_G```,````?N<```\```"+YP``"@```)OG```(````
MIN<```D```"OYP``*P```+GG```$````Y><```@```#JYP``)@```//G```2
M````&N@```\````MZ```!@```#WH```*````1.@```<```!/Z```"````%?H
M```@````8.@```D```"!Z```%````(OH```,````H.@```T```"MZ```#@``
M`+OH```6````RN@``!$```#AZ```!@```//H```#````^N@```8```#^Z```
M&0````7I```'````'^D```0````GZ0``"P```"SI```+````..D```<```!$
MZ0``!0```$SI```'````4ND``!8```!:Z0``#0```''I```-````?^D```H`
M``"-Z0``$````)CI```/````J>D``!$```"YZ0``%P```,OI```*````X^D`
M`!$```#NZ0``"`````#J```$````">H```\````.Z@``.@```![J```%````
M6>H```P```!?Z@``'@```&SJ```.````B^H``!````":Z@``"P```*OJ```,
M````M^H```D```#$Z@``!P```,[J```*````UNH```D```#AZ@``#@```.OJ
M```0````^NH``!L````+ZP``&````"?K```:````0.L```H```!;ZP``"0``
M`&;K```*````<.L```P```![ZP``#P```(CK```(````F.L```8```"AZP``
M'````*CK```'````Q>L```4```#-ZP``"P```-/K``!'````W^L```T````G
M[```"0```#7L```$````/^P```,```!$[```$P```$CL```3````7.P``!,`
M``!P[```"@```(3L```"````C^P```0```"2[```)0```)?L```#````O>P`
M``4```#![```*@```,?L```*````\NP```4```#][```!`````/M```*````
M".T```T````3[0``!@```"'M```(````*.T```@````Q[0``!````#KM```%
M````/^T``&@```!%[0``"0```*[M```,````N.T``!````#%[0``!0```-;M
M```&````W.T``!L```#C[0``+P```/_M```0````+^X```H```!`[@``#P``
M`$ON```*````6^X```D```!F[@``$P```'#N```;````A.X``!@```"@[@``
M%P```+GN```?````T>X```X```#Q[@```P````#O```'````!.\```@````,
M[P``!P```!7O```*````'>\```L````H[P``!P```#3O``!1````/.\``!``
M``".[P``#````)_O```-````K.\``!H```"Z[P``2@```-7O```9````(/``
M``8````Z\```&@```$'P```E````7/````8```""\```!@```(GP```?````
MD/````8```"P\```"0```+?P```8````P?```!<```#:\```*````/+P```&
M````&_$```T````B\0``(@```##Q``!7````4_$``!,```"K\0``(P```+_Q
M```3````X_$```(```#W\0``"P```/KQ```(````!O(```T````/\@``"@``
M`!WR```'````*/(``!0````P\@``!@```$7R```(````3/(```X```!5\@``
M!P```&3R```*````;/(```L```!W\@``,@```(/R```'````MO(```P```"^
M\@``#0```,OR```7````V?(```P```#Q\@``"0```/[R```)````"/,```H`
M```2\P``!P```!WS```)````)?,```<````O\P``"@```#?S```;````0O,`
M``\```!>\P``$@```&[S```*````@?,``!8```",\P``"0```*/S```0````
MK?,```<```"^\P``$@```,;S```$````V?,```<```#>\P``!0```.;S```%
M````[/,```L```#R\P``%````/[S```1````$_0``!H````E]```%@```$#T
M```4````5_0``!<```!L]```&````(3T```<````G?0``!D```"Z]```!P``
M`-3T```%````W/0```T```#B]```#````/#T```(````_?0``!<````&]0``
M"P```![U```,````*O4``!\````W]0``&@```%?U```3````<O4```0```"&
M]0``"@```(OU```$````EO4```T```";]0``#````*GU```%````MO4```D`
M``"\]0``!0```,;U```'````S/4```4```#4]0``!````-KU```"````W_4`
M`#@```#B]0``+````!OV```2````2/8``"D```!;]@``,@```(7V```*````
MN/8``"P```##]@``+@```/#V```S````'_<``#,```!3]P``.````(?W```/
M````P/<``!@```#0]P``$````.GW```/````^O<``!,````*^```%0```![X
M```4````-/@``!(```!)^```%````%SX```5````<?@``"T```"'^```+0``
M`+7X```Q````X_@``"X````5^0``+P```$3Y```L````=/D``&(```"A^0``
M$P````3Z```-````&/H```@````F^@``%P```"_Z```(````1_H```P```!0
M^@``*P```%WZ```A````B?H``!H```"K^@``"0```,;Z``!%````T/H``$$`
M```6^P``!````%C[```3````7?L``!0```!Q^P``#@```(;[```3````E?L`
M`!@```"I^P``!@```,+[```)````R?L```H```#3^P``#P```-[[```0````
M[OL```<```#_^P``#@````?\```%````%OP``!L````<_```"````#C\```&
M````0?P``!0```!(_```$0```%W\```.````;_P``#@```!^_````@```+?\
M```&````NOP```X```#!_```!0```-#\```'````UOP```X```#>_```!@``
M`.W\```H````]/P```P````=_0``'````"K]```$````1_T``"D```!,_0``
M%P```';]```?````COT``%P```"N_0``%`````O^```^````(/X``!\```!?
M_@``$````'_^```'````D/X```X```"8_@``#````*?^```,````M/X``!,`
M``#!_@``"@```-7^```=````X/X``!D```#^_@``!0```!C_```1````'O\`
M`!$````P_P``)````$+_```2````9_\``!4```!Z_P``$@```)#_```.````
MH_\``!D```"R_P``"````,S_```)````U?\```T```#?_P``!P```.W_```*
M````]?\```<```````$`#P````@``0`&````&``!``L````?``$`&@```"L`
M`0`*````1@`!``<```!1``$`"````%D``0`%````8@`!`!\```!H``$`!@``
M`(@``0`0````CP`!``@```"@``$`#0```*D``0`(````MP`!`!X```#```$`
M$@```-\``0`L````\@`!`!H````?`0$`"0```#H!`0`*````1`$!`!4```!/
M`0$`!0```&4!`0`4````:P$!``0```"``0$`$````(4!`0`&````E@$!``<`
M``"=`0$`'@```*4!`0`H````Q`$!``H```#M`0$`'````/@!`0`1````%0(!
M``L````G`@$`&@```#,"`0`4````3@(!``0```!C`@$`!````&@"`0`+````
M;0(!``4```!Y`@$`!@```'\"`0`(````A@(!``8```"/`@$`"@```)8"`0`;
M````H0(!`#0```"]`@$`-````/("`0`@````)P,!`"D```!(`P$`(````'(#
M`0!!````DP,!`!H```#5`P$`*````/`#`0`I````&00!`%````!#!`$`(@``
M`)0$`0`&````MP0!``@```"^!`$`!0```,<$`0`(````S00!`!D```#6!`$`
M&0```/`$`0`J````"@4!`",````U!0$`&0```%D%`0`N````<P4!`#0```"B
M!0$`"````-<%`0`7````X`4!``H```#X!0$`!P````,&`0`A````"P8!`!``
M```M!@$`#@```#X&`0`+````308!``<```!9!@$`$P```&$&`0`(````=08!
M``L```!^!@$`"@```(H&`0`4````E08!``\```"J!@$`,@```+H&`0`+````
M[08!``X```#Y!@$`!0````@'`0`%````#@<!``4````4!P$`%P```!H'`0`/
M````,@<!``0```!"!P$`"@```$<'`0`)````4@<!``L```!<!P$`#0```&@'
M`0`,````=@<!``X```"#!P$`!0```)('`0`$````F`<!``T```"=!P$`,@``
M`*L'`0!%````W@<!`!<````D"`$`!P```#P(`0`>````1`@!`!0```!C"`$`
M!0```'@(`0`4````?@@!``8```"3"`$`!P```)H(`0`.````H@@!`"H```"Q
M"`$`!@```-P(`0`,````XP@!``T```#P"`$`$0```/X(`0`+````$`D!`#8`
M```<"0$`"@```%,)`0`B````7@D!``L```"!"0$`#P```(T)`0`R````G0D!
M`"4```#0"0$`,````/8)`0`Q````)PH!`"T```!9"@$`#@```(<*`0`%````
ME@H!``X```"<"@$`$P```*L*`0`2````OPH!``<```#2"@$`$0```-H*`0`3
M````[`H!``<`````"P$`%`````@+`0`8````'0L!``<````V"P$`!0```#X+
M`0`,````1`L!``P```!1"P$`$@```%X+`0`$````<0L!``<```!V"P$`"@``
M`'X+`0`+````B0L!``P```"5"P$`#@```*(+`0`.````L0L!``4```#`"P$`
M!0```,8+`0`N````S`L!`"8```#["P$`(P```"(,`0`#````1@P!`!(```!*
M#`$`!@```%T,`0`>````9`P!`!@```"##`$`)0```)P,`0`-````P@P!``D`
M``#0#`$`'P```-H,`0`#````^@P!``<```#^#`$`"@````8-`0`"````$0T!
M``P````4#0$`%0```"$-`0`+````-PT!`!D```!##0$`(````%T-`0`2````
M?@T!``4```"1#0$`"@```)<-`0`5````H@T!`!(```"X#0$`#````,L-`0`$
M````V`T!``D```#=#0$`!P```.<-`0`,````[PT!`%(```#\#0$`%P```$\.
M`0`D````9PX!`!(```",#@$`!P```)\.`0`&````IPX!``X```"N#@$`#```
M`+T.`0`-````R@X!`!4```#8#@$`$@```.X.`0`/`````0\!`!0````1#P$`
M"@```"8/`0`;````,0\!`!````!-#P$`"P```%X/`0!I````:@\!`!H```#4
M#P$`%P```.\/`0`G````!Q`!`!H````O$`$`%P```$H0`0`;````8A`!`!D`
M``!^$`$`'P```)@0`0`3````N!`!``@```#,$`$`!P```-40`0`(````W1`!
M``D```#F$`$`%0```/`0`0`-````!A$!`",````4$0$`#0```#@1`0`3````
M1A$!``@```!:$0$``P```&,1`0!&````9Q$!`#\```"N$0$`-P```.X1`0!7
M````)A(!``4```!^$@$`'P```(02`0`O````I!(!``H```#4$@$`"````-\2
M`0`-````Z!(!`"T```#V$@$`!````"03`0!/````*1,!`"4```!Y$P$`'```
M`)\3`0`+````O!,!`!\```#($P$`'0```.@3`0`E````!A0!`"`````L%`$`
M)````$T4`0`@````<A0!``L```"3%`$`!P```)\4`0`-````IQ0!``P```"U
M%`$`%P```,(4`0`&````VA0!`#D```#A%`$`#````!L5`0`'````*!4!``D`
M```P%0$`$P```#H5`0`)````3A4!``0```!8%0$`$````%T5`0`(````;A4!
M``@```!W%0$`!````(`5`0`+````A14!``P```"1%0$`$@```)X5`0`1````
ML14!``P```##%0$`&@```-`5`0`/````ZQ4!``<```#[%0$`#0````,6`0`4
M````$18!``X````F%@$`#````#46`0`;````0A8!`"P```!>%@$`$P```(L6
M`0`<````GQ8!`"@```"\%@$`!@```.46`0`'````[!8!`!,```#T%@$`!0``
M``@7`0`$````#A<!`!<````3%P$`"@```"L7`0`,````-A<!``D```!#%P$`
M!@```$T7`0`)````5!<!``@```!>%P$`"0```&<7`0`*````<1<!`!$```!\
M%P$`!@```(X7`0`.````E1<!``X```"D%P$`#0```+,7`0`+````P1<!`!T`
M``#-%P$`"P```.L7`0`"````]Q<!`!P```#Z%P$`!P```!<8`0`&````'Q@!
M`&0````F&`$`"0```(L8`0`'````E1@!`"8```"=&`$`.````,08`0`:````
M_1@!`"H````8&0$`.P```$,9`0`H````?QD!`#0```"H&0$`&0```-T9`0`5
M````]QD!``4````-&@$`!P```!,:`0`(````&QH!``<````D&@$`!0```"P:
M`0`'````,AH!``X````Z&@$`"0```$D:`0`&````4QH!``@```!:&@$`"P``
M`&,:`0`'````;QH!``@```!W&@$`!P```(`:`0`6````B!H!``D```"?&@$`
M!@```*D:`0`+````L!H!`!````"\&@$`!@```,T:`0`<````U!H!`!0```#Q
M&@$`!P````8;`0`1````#AL!``@````@&P$`#@```"D;`0`(````.!L!``4`
M``!!&P$`$````$<;`0`)````6!L!`!````!B&P$`!@```',;`0`9````>AL!
M``H```"4&P$`'````)\;`0`'````O!L!``4```#$&P$`$````,H;`0`4````
MVQL!``L```#P&P$`#0```/P;`0`H````"AP!`!@````S'`$`%P```$P<`0`$
M````9!P!``D```!I'`$`"@```',<`0`'````?AP!``(```"&'`$`#@```(D<
M`0`(````F!P!`",```"A'`$`'P```,4<`0`X````Y1P!`"8````>'0$`,0``
M`$4=`0`G````=QT!`&0```"?'0$`%`````0>`0!5````&1X!`#@```!O'@$`
M2@```*@>`0!;````\QX!`"@```!/'P$`.````'@?`0`H````L1\!`"P```#:
M'P$`)@````<@`0`;````+B`!`#X```!*(`$`J0$``(D@`0`C````,R(!`!<`
M``!7(@$`2````&\B`0"%````N"(!`#`````^(P$`)0```&\C`0!!````E2,!
M`%L```#7(P$`20```#,D`0`Q````?20!`!T```"O)`$`&````,TD`0`K````
MYB0!`"$````2)0$`'P```#0E`0`K````5"4!`"8```"`)0$`)P```*<E`0`Z
M````SR4!`!T````*)@$`$0```"@F`0`S````.B8!`"4```!N)@$`)P```)0F
M`0`@````O"8!`!\```#=)@$`,````/TF`0!I````+B<!`#$```"8)P$`00``
M`,HG`0`S````#"@!`"4```!`*`$`/0```&8H`0!E````I"@!`$T````**0$`
M+P```%@I`0`N````B"D!`#````"W*0$`5````.@I`0!:````/2H!`$@```"8
M*@$`2@```.$J`0`R````+"L!`"\```!?*P$`+````(\K`0`M````O"L!`'$`
M``#J*P$`9@```%PL`0!O````PRP!`+,````S+0$`%P```.<M`0`E````_RT!
M`#(````E+@$`*0```%@N`0`^````@BX!`"(```#!+@$`4@```.0N`0`E````
M-R\!``L```!=+P$`L0```&DO`0!%````&S`!`"$```!A,`$`,````(,P`0`E
M````M#`!`!P```#:,`$`,0```/<P`0`'````*3$!``<````Q,0$`!````#DQ
M`0`-````/C$!``L```!,,0$`#@```%@Q`0`+````9S$!``4```!S,0$`$```
M`'DQ`0`"````BC$!`%D```"-,0$`!0```.<Q`0`2````[3$!``0`````,@$`
M!P````4R`0`(````#3(!``4````6,@$`,````!PR`0`#````33(!`!````!1
M,@$`#````&(R`0`3````;S(!``T```"#,@$``@```)$R`0`'````E#(!``8`
M``"<,@$`%````*,R`0`,````N#(!`!@```#%,@$`!@```-XR`0`2````Y3(!
M``P```#X,@$``P````4S`0`J````"3,!``0````T,P$`!@```#DS`0`'````
M0#,!`!\```!(,P$`-0```&@S`0`N````GC,!`"\```#-,P$`%P```/TS`0`B
M````%30!`"4````X-`$`(````%XT`0`;````?S0!`!@```";-`$`)````+0T
M`0`?````V30!`!H```#Y-`$`(0```!0U`0`@````-C4!`!H```!7-0$`,@``
M`'(U`0`:````I34!`"\```#`-0$`*P```/`U`0`?````'#8!`",````\-@$`
M'P```&`V`0`:````@#8!`"$```";-@$`)0```+TV`0`F````XS8!`"4````*
M-P$`)````#`W`0`8````53<!`!T```!N-P$`)````(PW`0`8````L3<!`"(`
M``#*-P$`+````.TW`0`O````&C@!`!4```!*.`$`)0```&`X`0`\````AC@!
M`!\```##.`$`(P```.,X`0`?````!SD!`"`````G.0$`&@```$@Y`0`8````
M8SD!`"8```!\.0$`'@```*,Y`0`I````PCD!`!X```#L.0$`,0````LZ`0`)
M````/3H!``P```!'.@$`%P```%0Z`0`O````;#H!`"0```"<.@$`!P```,$Z
M`0`/````R3H!`!0```#9.@$`#@```.XZ`0`-````_3H!`"0````+.P$`!0``
M`#`[`0`'````-CL!`"(````^.P$`)0```&$[`0`:````ASL!`!T```"B.P$`
M&@```,`[`0`'````VSL!`,<```#C.P$`"P```*L\`0`5````MSP!``8```#-
M/`$`"0```-0\`0`+````WCP!``T```#J/`$`%P```/@\`0`&````$#T!`#,`
M```7/0$`$P```$L]`0`3````7ST!``<```!S/0$`#P```'L]`0`'````BST!
M`#(```"3/0$`!````,8]`0`A````RST!`!,```#M/0$`#`````$^`0`1````
M#CX!`#(````@/@$`%@```%,^`0`(````:CX!`!T```!S/@$`"0```)$^`0`*
M````FSX!`!0```"F/@$`"@```+L^`0`=````QCX!``@```#D/@$`'P```.T^
M`0`(````#3\!`!H````6/P$`)P```#$_`0`&````63\!`!4```!@/P$`!P``
M`'8_`0`(````?C\!``D```"'/P$`/P```)$_`0`'````T3\!``\```#9/P$`
M#@```.D_`0`0````^#\!``D````)0`$`"0```!-``0`(````'4`!`!,````F
M0`$`!P```#I``0`9````0D`!``H```!<0`$`%P```&=``0`4````?T`!``H`
M``"40`$`#````)]``0`7````K$`!``0```#$0`$`*@```,E``0`,````]$`!
M`!$````!00$`!P```!-!`0`"````&T$!`!`````>00$`&````"]!`0`+````
M2$$!``,```!400$`"````%A!`0`&````84$!``<```!H00$`#0```'!!`0`+
M````?D$!`!0```"*00$`%0```)]!`0`.````M4$!`"\```#$00$`(````/1!
M`0`<````%4(!`!4````R0@$`#````$A"`0`Q````54(!``4```"'0@$`$@``
M`(U"`0`_````H$(!`!(```#@0@$`"@```/-"`0`&````_D(!``0````%0P$`
M!`````I#`0`*````#T,!`!,````:0P$`!0```"Y#`0`&````-$,!``8````[
M0P$`"````$)#`0`$````2T,!``P```!00P$`"@```%U#`0`Y````:$,!`"X`
M``"B0P$`*0```-%#`0`%````^T,!`!@````!1`$`&0```!I$`0`?````-$0!
M`!T```!41`$`$0```')$`0`"````A$0!``0```"'1`$`"@```(Q$`0`&````
MET0!``4```">1`$``P```*1$`0`,````J$0!`$4```"U1`$`,@```/M$`0`:
M````+D4!`#0```!)10$`*````'Y%`0!3````IT4!`!D```#[10$`<@```!5&
M`0`@````B$8!`#4```"I1@$`(0```-]&`0!%`````4<!`#````!'1P$`*```
M`'A'`0`I````H4<!`"8```#+1P$`)0```/)'`0`H````&$@!`"@```!!2`$`
M(@```&I(`0`K````C4@!`#````"Y2`$`$@```.I(`0`3````_4@!`!`````1
M20$`>0```"))`0`)````G$D!`*$```"F20$`<P```$A*`0!\````O$H!`"L`
M```Y2P$`5````&5+`0`7````NDL!`"<```#22P$`%@```/I+`0`/````$4P!
M`!<````A3`$`'P```#E,`0!`````64P!`!\```":3`$`'````+I,`0!1````
MUTP!`!H````I30$`%````$1-`0`*````64T!``4```!D30$`!@```&I-`0`(
M````<4T!``4```!Z30$`$@```(!-`0`0````DTT!`!,```"D30$`'0```+A-
M`0`/````UDT!``\```#F30$`!````/9-`0`)````^TT!``L````%3@$`!P``
M`!%.`0`%````&4X!`!0````?3@$`!P```#1.`0`(````/$X!``\```!%3@$`
M"````%5.`0`,````7DX!``\```!K3@$`!@```'M.`0`4````@DX!``8```"7
M3@$`#````)Y.`0`1````JTX!``@```"]3@$`!````,9.`0`9````RTX!`!$`
M``#E3@$`"@```/=.`0`8`````D\!`!,````;3P$`'````"]/`0`1````3$\!
M``0```!>3P$`#P```&-/`0`'````<T\!``0```![3P$`&0```(!/`0`'````
MFD\!``(```"B3P$``@```*5/`0`1````J$\!``D```"Z3P$`!@```,1/`0`2
M````RT\!`!<```#>3P$`!@```/9/`0`G````_4\!``(````E4`$`!````"A0
M`0`/````+5`!`!,````]4`$`!P```%%0`0`'````65`!`!$```!A4`$`!@``
M`'-0`0`8````>E`!``8```"34`$`$P```)I0`0`0````KE`!`!(```"_4`$`
M`@```-)0`0`&````U5`!``P```#<4`$`"0```.E0`0`1````\U`!`"(````%
M40$`!P```"A1`0`'````,%$!``L````X40$`!0```$11`0`"````2E$!``L`
M``!-40$`5P$``%E1`0`3````L5(!`!$```#%4@$`#@```-=2`0`)````YE(!
M``L```#P4@$`"````/Q2`0`!````!5,!`!4````'4P$`&@```!U3`0`J````
M.%,!`"$```!C4P$`(@```(53`0`:````J%,!`!(```##4P$`*@```-93`0`+
M`````50!`"8````-5`$`$@```#14`0`-````1U0!``X```!55`$`!0```&14
M`0`C````:E0!``H```".5`$`$````)E4`0`.````JE0!`!(```"Y5`$`#P``
M`,Q4`0!E````W%0!`!````!"50$`#````%-5`0`/````8%4!``P```!P50$`
M$````'U5`0`.````CE4!`!````"=50$`$0```*Y5`0`&````P%4!`,(```#'
M50$`#P```(I6`0`5````FE8!`!4```"P5@$`#0```,96`0`5````U%8!`!4`
M``#J5@$`"0````!7`0`*````"E<!`#P````55P$`%0```%)7`0`P````:%<!
M`$,```"95P$`7@```-U7`0!@````/%@!`%P```"=6`$`9@```/I8`0`R````
M85D!``D```"460$`$@```)Y9`0`'````L5D!``H```"Y60$`#@```,19`0`%
M````TUD!``8```#960$`$@```.!9`0`*````\UD!``D```#^60$`#0````A:
M`0`N````%EH!`"T```!%6@$`&````'-:`0`:````C%H!`!8```"G6@$`"@``
M`+Y:`0`%````R5H!``X```#/6@$`#P```-Y:`0`,````[EH!`!````#[6@$`
M$0````Q;`0`;````'EL!`!8````Z6P$`%````%%;`0`,````9EL!`!,```!S
M6P$`"@```(=;`0`H````DEL!`!0```"[6P$`%0```-!;`0`.````YEL!`%L`
M``#U6P$`.````%%<`0`A````BEP!``8```"L7`$`"P```+-<`0`Y````OUP!
M``@```#Y7`$`"0````)=`0`*````#%T!``<````770$`!P```!]=`0`%````
M)UT!``4````M70$`!P```#-=`0`&````.UT!`!X```!"70$`#0```&%=`0`/
M````;UT!`!D```!_70$`%0```)E=`0`G````KUT!``X```#770$`)P```.9=
M`0`<````#EX!`"(````K7@$`(@```$Y>`0`5````<5X!`!8```"'7@$`$@``
M`)Y>`0`7````L5X!`!H```#)7@$`!P```.1>`0`&````[%X!``@```#S7@$`
M#@```/Q>`0`'````"U\!``D````37P$`$@```!U?`0`'````,%\!``P````X
M7P$`$@```$5?`0`A````6%\!``<```!Z7P$`#0```()?`0`(````D%\!`!4`
M``"97P$`#````*]?`0`,````O%\!`#\```#)7P$`/P````E@`0`)````26`!
M``<```!38`$`$P```%M@`0`%````;V`!``4```!U8`$`$````'M@`0`+````
MC&`!`!8```"88`$`-P```*]@`0`0````YV`!`"4```#X8`$`)P```!YA`0`G
M````1F$!`"0```!N80$`#P```)-A`0`&````HV$!``D```"J80$`"````+1A
M`0`V````O6$!`#\```#T80$`-0```#1B`0!=````:F(!`#0```#(8@$`-```
M`/UB`0!!````,F,!`$,```!T8P$`-````+AC`0!'````[6,!`"@````U9`$`
M*@```%YD`0!%````B60!`#0```#/9`$`.@````1E`0`L````/V4!`!D```!L
M90$`'0```(9E`0`N````I&4!`"L```#390$`*P```/]E`0`;````*V8!``L`
M``!'9@$`#P```%-F`0`&````8V8!``H```!J9@$`&````'5F`0`>````CF8!
M``8```"M9@$`!P```+1F`0`4````O&8!``H```#19@$`"````-QF`0`N````
MY68!``H````49P$`#````!]G`0`&````+&<!``8````S9P$`!0```#IG`0`'
M````0&<!``8```!(9P$`#````$]G`0`H````7&<!``\```"%9P$`#````)5G
M`0`)````HF<!``<```"L9P$`#````+1G`0`%````P6<!``\```#'9P$`!@``
M`-=G`0`2````WF<!``@```#Q9P$`"````/IG`0`$`````V@!``T````(:`$`
M"````!9H`0`G````'V@!`!````!':`$`"````%AH`0`-````86@!``P```!O
M:`$`!P```'QH`0`#````A&@!``,```"(:`$`$P```(QH`0`0````H&@!`",`
M``"Q:`$`"0```-5H`0`%````WV@!``D```#E:`$`!P```.]H`0!&````]V@!
M`"$````^:0$`.@```&!I`0`F````FVD!`!P```#":0$`!@```-]I`0`$````
MYFD!`!(```#K:0$`(````/YI`0`A````'VH!`"\```!!:@$`(0```'%J`0`H
M````DVH!`&$```"\:@$`*0```!YK`0`)````2&L!``H```!2:P$`$````%UK
M`0`5````;FL!``T```"$:P$`#````))K`0`,````GVL!``P```"L:P$`#```
M`+EK`0`,````QFL!``P```#3:P$`%````.!K`0`*````]6L!`!<`````;`$`
M&P```!AL`0`1````-&P!`!,```!&;`$`%0```%IL`0`$````<&P!``4```!U
M;`$`$0```'ML`0!+````C6P!`%,```#9;`$`!@```"UM`0`3````-&T!``4`
M``!(;0$`!0```$YM`0`@````5&T!`!@```!U;0$`#P```(YM`0`0````GFT!
M`!8```"O;0$`'P```,9M`0`P````YFT!``L````7;@$`(````"-N`0`&````
M1&X!`!4```!+;@$`#0```&%N`0`3````;VX!``\```"#;@$`%P```)-N`0`2
M````JVX!`!0```"^;@$`%P```--N`0`,````ZVX!``8```#X;@$`$0```/]N
M`0`(````$6\!`!<````:;P$`%````#)O`0`2````1V\!``@```!:;P$`!```
M`&-O`0`,````:&\!``L```!U;P$`!@```(%O`0`3````B&\!``H```"<;P$`
M!P```*=O`0`-````KV\!``D```"];P$`#````,=O`0`'````U&\!``8```#<
M;P$`"P```.-O`0`(````[V\!``H```#X;P$`#P````-P`0!#````$W`!`!H`
M``!7<`$`$@```')P`0`J````A7`!``4```"P<`$`'P```+9P`0`3````UG`!
M`!0```#J<`$`,P```/]P`0!"````,W$!`"0```!V<0$`#````)MQ`0`F````
MJ'$!`!T```#/<0$`#@```.UQ`0`%````_'$!``L````"<@$`!@````YR`0`&
M````%7(!`!D````<<@$`#@```#9R`0`'````17(!``H```!-<@$`$0```%AR
M`0`E````:G(!`#$```"0<@$`)P```,)R`0`S````ZG(!`!L````><P$`,```
M`#IS`0`=````:W,!`",```")<P$`.0```*US`0`?````YW,!`"<````'=`$`
M*0```"]T`0`A````670!`"$```![=`$`)P```)UT`0!"````Q70!`"$````(
M=0$`(0```"IU`0`K````3'4!`!\```!X=0$`'P```)AU`0`Z````N'4!`"(`
M``#S=0$`%0```!9V`0`G````+'8!`"````!4=@$`*P```'5V`0`5````H78!
M`)(```"W=@$`&@```$IW`0`?````97<!`!\```"%=P$`(````*5W`0`N````
MQG<!`!T```#U=P$`'P```!-X`0`@````,W@!`"P```!4>`$`+@```(%X`0`P
M````L'@!`"\```#A>`$`H0```!%Y`0`K````LWD!`"````#?>0$`)`````!Z
M`0`C````)7H!`"P```!)>@$`0````'9Z`0!$````MWH!``\```#\>@$``P``
M``Q[`0`'````$'L!``,````8>P$`#P```!Q[`0`(````+'L!`!D````U>P$`
M$@```$][`0`2````8GL!``<```!U>P$`!0```'U[`0`8````@WL!`!8```"<
M>P$`&0```+-[`0`4````S7L!`!<```#B>P$`$0```/I[`0`4````#'P!`!,`
M```A?`$`3@```#5\`0`'````A'P!``\```",?`$`!@```)Q\`0`3````HWP!
M`!D```"W?`$`&P```-%\`0`0````[7P!``(```#^?`$`4`````%]`0`*````
M4GT!``\```!=?0$`#@```&U]`0`'````?'T!`!@```"$?0$`$P```)U]`0`%
M````L7T!``X```"W?0$`"````,9]`0`0````SWT!`!,```#@?0$`!@```/1]
M`0`*````^WT!``X````&?@$`%````!5^`0`+````*GX!``8````V?@$`"P``
M`#U^`0`,````27X!``L```!6?@$`#0```&)^`0`J````<'X!``L```";?@$`
M#0```*=^`0`K````M7X!`!0```#A?@$`%P```/9^`0!!````#G\!``L```!0
M?P$`%P```%Q_`0`9````='\!`!4```".?P$`$P```*1_`0`?````N'\!``P`
M``#8?P$`!@```.5_`0`/````['\!``8```#\?P$`.0````.``0`X````/8`!
M``<```!V@`$`#````'Z``0`?````BX`!``X```"K@`$`&@```+J``0`:````
MU8`!``D```#P@`$`'0```/J``0`1````&($!`"0````J@0$`'````$^!`0`*
M````;($!`!,```!W@0$`"````(N!`0`.````E($!`"0```"C@0$`0````,B!
M`0`.````"8(!`!@````8@@$`,````#&"`0`(````8H(!``L```!K@@$`)```
M`'>"`0`/````G((!``<```"L@@$`$````+2"`0!6````Q8(!``4````<@P$`
M!P```"*#`0`'````*H,!``X````R@P$`#@```$&#`0`0````4(,!`!$```!A
M@P$`&````'.#`0`2````C(,!`!@```"?@P$`%@```+B#`0`(````SX,!``8`
M``#8@P$`"P```-^#`0`,````ZX,!``(```#X@P$`"@```/N#`0`0````!H0!
M`"<````7A`$`&0```#^$`0`4````680!``8```!NA`$`#0```'6$`0`.````
M@X0!``\```"2A`$`.@```**$`0`M````W80!``X````+A0$`$0```!J%`0!G
M````+(4!`!0```"4A0$`%````*F%`0`6````OH4!``<```#5A0$`!0```-V%
M`0`?````XX4!`"P````#A@$`(@```#"&`0`>````4X8!`"(```!RA@$`&@``
M`)6&`0`;````L(8!``4```#,A@$`!P```-*&`0`'````VH8!``@```#BA@$`
M$@```.N&`0`1````_H8!`!(````0AP$`$0```".'`0`@````-8<!`!0```!6
MAP$`#P```&N'`0`/````>X<!``<```"+AP$`"````).'`0`4````G(<!`!8`
M``"QAP$`,````,B'`0`/````^8<!``L````)B`$`!P```!6(`0`@````'8@!
M`!L````^B`$`)````%J(`0`C````?X@!`!\```"CB`$`'P```,.(`0`I````
MXX@!`!P````-B0$`%@```"J)`0`&````08D!`!P```!(B0$`"@```&6)`0`-
M````<(D!``4```!^B0$`!@```(2)`0`(````BXD!``L```"4B0$`#0```*")
M`0`0````KHD!`!0```"_B0$`#@```-2)`0`.````XXD!``\```#RB0$`!0``
M``**`0`(````"(H!`"(````1B@$`(P```#2*`0`5````6(H!``X```!NB@$`
M$0```'V*`0`0````CXH!`"@```"@B@$`"P```,F*`0`%````U8H!`!0```#;
MB@$`%0```/"*`0`,````!HL!``T````3BP$`!P```"&+`0`$````*8L!`!P`
M```NBP$`#P```$N+`0`%````6XL!`"$```!ABP$`#0```(.+`0"3````D8L!
M`!4````EC`$`"0```#N,`0`*````18P!`!,```!0C`$`#````&2,`0`.````
M<8P!``@```"`C`$`$@```(F,`0`"````G(P!``@```"?C`$`!@```*B,`0`1
M````KXP!``X```#!C`$`$0```-",`0`=````XHP!``D`````C0$`"@````J-
M`0`/````%8T!``@````EC0$`"0```"Z-`0`%````.(T!`!P````^C0$`"0``
M`%N-`0`&````98T!`!````!LC0$`#P```'V-`0`'````C8T!``4```"5C0$`
M!0```)N-`0`)````H8T!``<```"KC0$`$0```+.-`0`$````Q8T!``4```#*
MC0$`#0```-"-`0`+````WHT!``H```#JC0$`!P```/6-`0`4````_8T!``D`
M```2C@$`!P```!R.`0`/````)(X!`",````TC@$`2````%B.`0`K````H8X!
M`"L```#-C@$`!@```/F.`0`*`````(\!``0````+CP$`"0```!"/`0`(````
M&H\!`!0````CCP$`"P```#B/`0`&````1(\!``T```!+CP$`!@```%F/`0`$
M````8(\!`$8```!ECP$`3P```*R/`0!+````_(\!`"````!(D`$`!0```&F0
M`0`.````;Y`!``0```!^D`$`!@```(.0`0`&````BI`!`!@```"1D`$`%```
M`*J0`0`5````OY`!``<```#5D`$`!````-V0`0`6````XI`!``0```#YD`$`
M#P```/Z0`0`;````#I$!``8````JD0$`!0```#&1`0`G````-Y$!``0```!?
MD0$`"@```&21`0`-````;Y$!``X```!]D0$`"````(R1`0`)````E9$!``4`
M``"?D0$`,````*61`0`R````UI$!`#H````)D@$`(````$22`0!)````99(!
M`#D```"OD@$`*0```.F2`0`X````$Y,!`"H```!,DP$`+````'>3`0`A````
MI),!`!$```#&DP$`$````-B3`0`+````Z9,!`"4```#UDP$`)P```!N4`0`A
M````0Y0!`",```!EE`$`!P```(F4`0`)````D90!``H```";E`$`!@```*:4
M`0`I````K90!`"D```#7E`$`,@````&5`0`)````-)4!`!\````^E0$`+0``
M`%Z5`0`6````C)4!`!$```"CE0$`!P```+65`0`+````O94!``T```#)E0$`
M$````->5`0`/````Z)4!`$````#XE0$`C0```#F6`0!D````QY8!`!$````L
MEP$`"````#Z7`0`)````1Y<!`!````!1EP$`$0```&*7`0`,````=)<!``4`
M``"!EP$`$````(>7`0`0````F)<!``X```"IEP$`$P```+B7`0`<````S)<!
M`"8```#IEP$`=````!"8`0`0````A9@!``4```"6F`$`%0```)R8`0`)````
MLI@!``0```"\F`$`"P```,&8`0`>````S9@!`!4```#LF`$`"@````*9`0`.
M````#9D!`!`````<F0$`$P```"V9`0`B````09D!`"````!DF0$`(````(69
M`0`>````IID!`"0```#%F0$`(@```.J9`0`:````#9H!`#4````HF@$`$@``
M`%Z:`0`0````<9H!`!(```""F@$`$@```)6:`0`4````J)H!`!4```"]F@$`
M$P```-.:`0`0````YYH!`!(```#XF@$`*0````N;`0`3````-9L!`!4```!)
MFP$`2@```%^;`0`<````JIL!``P```#'FP$`$0```-2;`0`A````YIL!`!4`
M```(G`$`$0```!Z<`0`2````,)P!`!T```!#G`$`'P```&&<`0`6````@9P!
M`!<```"8G`$`%0```+"<`0`3````QIP!`!T```#:G`$`(````/B<`0`E````
M&9T!`!,````_G0$`%````%.=`0`4````:)T!`!P```!]G0$`%0```)J=`0`5
M````L)T!`!D```#&G0$`"P```."=`0`;````[)T!`!P````(G@$`!````"6>
M`0`'````*IX!``D````RG@$`%P```#R>`0`&````5)X!`!$```!;G@$`"@``
M`&V>`0`&````>)X!``<```!_G@$`"````(>>`0`&````D)X!`!0```"7G@$`
M!@```*R>`0`(````LYX!``@```"\G@$`!P```,6>`0`'````S9X!`!````#5
MG@$`#@```.:>`0`2````]9X!`!`````(GP$`"0```!F?`0`5````(Y\!``4`
M```YGP$`,````#^?`0`3````<)\!``X```"$GP$`$````).?`0`.````I)\!
M``X```"SGP$`#@```,*?`0`K````T9\!``8```#]GP$`"`````2@`0`U````
M#:`!`!X```!#H`$`#@```&*@`0`&````<:`!``D```!XH`$`"0```(*@`0`%
M````C*`!`"0```"2H`$`%0```+>@`0`9````S:`!`!8```#GH`$`%````/Z@
M`0`A````$Z$!`"4````UH0$`+0```%NA`0`&````B:$!``0```"0H0$`"```
M`)6A`0`<````GJ$!``<```"[H0$`!0```,.A`0`,````R:$!``L```#6H0$`
M!@```.*A`0`$````Z:$!``<```#NH0$`%0```/:A`0`,````#*(!``X````9
MH@$`#P```"BB`0`8````.*(!`!D```!1H@$`$P```&NB`0`=````?Z(!`!,`
M``"=H@$`$P```+&B`0`)````Q:(!``8```#/H@$`$````-:B`0`_````YZ(!
M``8````GHP$`#P```"ZC`0`>````/J,!`!$```!=HP$`%0```&^C`0`,````
MA:,!``X```"2HP$`"P```*&C`0`)````K:,!``\```"WHP$`#````,>C`0`-
M````U*,!`!T```#BHP$`(@````"D`0`B````(Z0!`"@```!&I`$`#````&^D
M`0`'````?*0!``L```"$I`$`$P```)"D`0`4````I*0!``8```"YI`$`#P``
M`,"D`0`B````T*0!``T```#SI`$`#P````&E`0`>````$:4!`&4````PI0$`
M(````):E`0`,````MZ4!``<```#$I0$`!@```,RE`0`>````TZ4!`!T```#R
MI0$`&@```!"F`0`)````*Z8!``(````UI@$`!````#BF`0`@````/:8!``8`
M``!>I@$`!0```&6F`0`J````:Z8!``H```"6I@$`!P```*&F`0`*````J:8!
M``\```"TI@$`#@```,2F`0`&````TZ8!``<```#:I@$`"@```.*F`0`%````
M[:8!``4```#SI@$`@P```/FF`0`,````?:<!``\```"*IP$`&````)JG`0`)
M````LZ<!``H```"]IP$`'@```,BG`0`L````YZ<!``\````4J`$`"@```"2H
M`0`0````+Z@!``H```!`J`$`"0```$NH`0`:````5:@!`"D```!PJ`$`)P``
M`)JH`0`F````PJ@!`!X```#IJ`$`%@````BI`0`(````'ZD!``D````HJ0$`
M"@```#*I`0`'````/:D!``P```!%J0$`#0```%*I`0`&````8*D!`%(```!G
MJ0$`#P```+JI`0`.````RJD!``D```#9J0$`(````..I`0!9````!*H!`!H`
M``!>J@$`!@```'FJ`0`>````@*H!`"T```"?J@$`"````,VJ`0`'````UJH!
M`!\```#>J@$`"````/ZJ`0`+````!ZL!`"<````3JP$`)@```#NK`0`E````
M8JL!``D```"(JP$`"@```)*K`0`B````G:L!`%P```#`JP$`%````!VL`0`F
M````,JP!`!0```!9K`$``@```&ZL`0`1````<:P!``L```"#K`$`%@```(^L
M`0`.````IJP!``<```"UK`$`$@```+VL`0`&````T*P!``@```#7K`$`$0``
M`."L`0`-````\JP!``H`````K0$`#`````NM`0`S````&*T!``<```!,K0$`
M$0```%2M`0`2````9JT!`"````!YK0$`%P```)JM`0`/````LJT!`!$```#"
MK0$`#P```-2M`0`/````Y*T!``\```#TK0$`#P````2N`0`(````%*X!`!P`
M```=K@$`'@```#JN`0`+````6:X!`!(```!EK@$`'0```'BN`0`,````EJX!
M`!<```"CK@$`#P```+NN`0`-````RZX!``0```#9K@$`!P```-ZN`0`%````
MYJX!``4```#LK@$`"@```/*N`0`5````_:X!`!$````3KP$`&@```"6O`0`6
M````0*\!`!0```!7KP$`%P```&RO`0`>````A*\!`!T```"CKP$`&@```,&O
M`0`&````W*\!``H```#CKP$`#@```.ZO`0`-````_:\!``<````+L`$`(P``
M`!.P`0`-````-[`!``T```!%L`$`&@```%.P`0`F````;K`!`!0```"5L`$`
M!P```*JP`0`0````LK`!``@```##L`$`%````,RP`0`3````X;`!``D```#U
ML`$`"0```/^P`0`%````";$!``<````/L0$``@```!>Q`0`$````&K$!``(`
M```?L0$`1````"*Q`0!#````9[$!``T```"KL0$`(@```+FQ`0`V````W+$!
M``P````3L@$`*0```""R`0`=````2K(!`"(```!HL@$`(@```(NR`0`G````
MKK(!`!````#6L@$`%````.>R`0`>````_+(!`!4````;LP$`&````#&S`0`7
M````2K,!`!,```!BLP$`%P```':S`0`<````CK,!`!H```"KLP$`+P```,:S
M`0`O````]K,!`#,````FM`$`,````%JT`0`Q````B[0!`"X```"]M`$`:P``
M`.RT`0`E````6+4!`!D```!^M0$`"P```)BU`0`;````I+4!``H```#`M0$`
M%0```,NU`0`J````X;4!`"P````,M@$`*````#FV`0`)````8K8!`%L```!L
MM@$`30```,BV`0`)````%K<!`"`````@MP$`)@```$&W`0`.````:+<!`!@`
M``!WMP$`&P```)"W`0`%````K+<!``H```"RMP$`"````+VW`0`0````QK<!
M`!(```#7MP$`"P```.JW`0`*````]K<!``T````!N`$`)0````^X`0`)````
M-;@!``D````_N`$`$@```$FX`0`5````7+@!`!````!RN`$`.0```(.X`0`"
M````O;@!``<```#`N`$`#@```,BX`0`'````U[@!``<```#?N`$`$P```.>X
M`0`(````^[@!`#@````$N0$`#@```#VY`0`9````3+D!``0```!FN0$`,```
M`&NY`0`<````G+D!`"P```"YN0$`50```.:Y`0`6````/+H!`$<```!3N@$`
M(P```)NZ`0`1````O[H!``D```#1N@$`$````-NZ`0`1````[+H!``P```#^
MN@$`$P````N[`0`,````'[L!`!L````LNP$`&P```$B[`0`#````9+L!``L`
M``!HNP$`$@```'2[`0`H````A[L!`!P```"PNP$`'@```,V[`0`3````[+L!
M`!(`````O`$`)P```!.\`0`)````.[P!`!$```!%O`$`$@```%>\`0`'````
M:KP!``H```!RO`$`!P```'V\`0`.````A;P!``<```"4O`$`$````)R\`0`<
M````K;P!`!(```#*O`$`!0```-V\`0`(````X[P!``4```#LO`$`'````/*\
M`0`&````#[T!`!$````6O0$`"````"B]`0`1````,;T!``@```!#O0$`&@``
M`$R]`0`.````9[T!`"L```!VO0$`%P```**]`0`)````NKT!``H```#$O0$`
M'0```,^]`0`%````[;T!`!,```#SO0$`!0````>^`0`H````#;X!``<````V
MO@$`"0```#Z^`0`<````2+X!`#P```!EO@$`!@```**^`0`;````J;X!`!``
M``#%O@$`"````-:^`0`3````W[X!``L```#SO@$`!````/^^`0`(````!+\!
M``L````-OP$`!P```!F_`0`)````(;\!``@````KOP$`!P```#2_`0`'````
M/+\!`!4```!$OP$`+0```%J_`0`[````B+\!`!<```#$OP$`(````-R_`0`5
M````_;\!`#X````3P`$`'````%+``0`=````;\`!`"4```"-P`$`6````+/`
M`0`@````#,$!``4````MP0$`"@```#/!`0`'````/L$!``D```!&P0$`$@``
M`%#!`0`5````8\$!`#@```!YP0$`(P```++!`0`?````UL$!`#4```#VP0$`
M.@```"S"`0`*````9\(!`!H```!RP@$`#````(W"`0`*````FL(!`"$```"E
MP@$`$P```,?"`0`2````V\(!``X```#NP@$`!P```/W"`0`/````!<,!``D`
M```5PP$`$````!_#`0`.````,,,!`!H````_PP$`%P```%K#`0`P````<L,!
M``L```"CPP$`'P```*_#`0`%````S\,!``8```#5PP$`!P```-S#`0`>````
MY,,!``P````#Q`$`!````!#$`0`0````%<0!``\````FQ`$`"0```#;$`0`,
M````0,0!``X```!-Q`$`%@```%S$`0`%````<\0!``0```!YQ`$`$@```'[$
M`0`Q````D<0!`$0```##Q`$`%P````C%`0`'````(,4!`",````HQ0$`&```
M`$S%`0`4````9<4!``X```!ZQ0$`#P```(G%`0`-````F<4!``T```"GQ0$`
M+P```+7%`0`&````Y<4!``L```#LQ0$`#0```/C%`0`/````!L8!``L````6
MQ@$`/````"+&`0`&````7\8!`!X```!FQ@$`#P```(7&`0`3````E<8!`"<`
M``"IQ@$`'P```-'&`0`[````\<8!`#P````MQP$`.````&K'`0`1````H\<!
M``@```"UQP$`$0```+['`0`3````T,<!`!@```#DQP$`"````/W'`0`0````
M!L@!`!8````7R`$`!P```"[(`0`1````-L@!`!P```!(R`$`"P```&7(`0`%
M````<<@!``P```!WR`$`"P```(3(`0`0````D,@!``4```"AR`$`!P```*?(
M`0`*````K\@!`!,```"ZR`$`$P```,[(`0`,````XL@!``P```#OR`$`!@``
M`/S(`0`)`````\D!`#8````-R0$`*````$3)`0`C````;<D!``<```"1R0$`
M(````)G)`0`&````NLD!`"0```#!R0$`%0```.;)`0`H````_,D!`!$````E
MR@$`$0```#?*`0`<````2<H!``,```!FR@$`"````&K*`0`2````<\H!``(`
M``"&R@$`#````(G*`0`4````ELH!``L```"KR@$`&````+?*`0`<````T,H!
M`!@```#MR@$`!0````;+`0`*````#,L!`!0````7RP$`'````"S+`0`-````
M2<L!``<```!7RP$`#````%_+`0`*````;,L!`!$```!WRP$`2@```(G+`0`<
M````U,L!`#<```#QRP$`&````"G,`0`%````0LP!``0```!(S`$`"@```$W,
M`0`1````6,P!`!(```!JS`$`%P```'W,`0`5````E<P!`!````"KS`$`&@``
M`+S,`0`.````U\P!`"0```#FS`$`#P````O-`0`0````&\T!`&L````LS0$`
M(````)C-`0`>````N<T!`!P```#8S0$`(````/7-`0`8````%LX!`"0````O
MS@$`$@```%3.`0`9````9\X!`!0```"!S@$`"@```);.`0`'````H<X!``L`
M``"IS@$`!P```+7.`0`4````O<X!``L```#2S@$`.@```-[.`0`3````&<\!
M`!H````MSP$`"````$C/`0`%````4<\!`$H```!7SP$`3P```*+/`0!-````
M\L\!`&0```!`T`$`!P```*70`0`H````K=`!`"P```#6T`$`"@````/1`0`(
M````#M$!``T````7T0$`,@```"71`0`%````6-$!`%(```!>T0$`+````+'1
M`0`D````WM$!``X````#T@$`(````!+2`0`<````,](!`",```!0T@$`'0``
M`'32`0`C````DM(!`!H```"VT@$`#````-'2`0`'````WM(!`!````#FT@$`
M$0```/?2`0`4````"=,!``@````>TP$`0````"?3`0`,````:-,!``@```!U
MTP$`#0```'[3`0`:````C-,!``D```"GTP$`!````+'3`0`6````MM,!``@`
M``#-TP$`"````-;3`0`$````W],!``L```#DTP$`"P```/#3`0`4````_-,!
M`!,````1U`$`#@```"74`0`4````--0!``X```!)U`$`!P```%C4`0`0````
M8-0!`!P```!QU`$`"P```([4`0`-````FM0!`!L```"HU`$`*@```,34`0`8
M````[]0!`!X````(U0$`*@```"?5`0`$````4M4!``0```!7U0$`#0```%S5
M`0`'````:M4!``H```!RU0$`%@```'W5`0`(````E-4!``H```"=U0$`"```
M`*C5`0`'````L=4!``D```"YU0$`"0```,/5`0`)````S=4!``P```#7U0$`
M#@```.35`0`$````\]4!``X```#XU0$`"@````?6`0`*````$M8!``\````=
MU@$`'````"W6`0`+````2M8!``(```!6U@$`'P```%G6`0`'````>=8!``8`
M``"!U@$`:````(C6`0`,````\=8!``@```#^U@$`*`````?7`0!$````,-<!
M`!\```!UUP$`+0```)77`0!8````P]<!`"8````<V`$`*0```$/8`0`8````
M;=@!`!T```"&V`$`!0```*38`0`*````JM@!``T```"UV`$`#0```,/8`0`+
M````T=@!``T```#=V`$`%0```.O8`0`/`````=D!``T````1V0$`#P```!_9
M`0`/````+]D!``0````_V0$`!P```$39`0`(````3-D!`!D```!5V0$`"```
M`&_9`0`&````>-D!``<```!_V0$`$P```(?9`0`&````F]D!`!L```"BV0$`
M%@```+[9`0`+````U=D!`!D```#AV0$`#````/O9`0`6````"-H!``P````?
MV@$`"````"S:`0`/````-=H!`!(```!%V@$`#P```%C:`0`&````:-H!`!<`
M``!OV@$`"P```(?:`0`>````D]H!``8```"RV@$`"````+G:`0`-````PMH!
M`"````#0V@$`"0```/':`0`+````^]H!`"8````'VP$`&````"[;`0`0````
M1]L!``8```!8VP$`"P```%_;`0`.````:]L!``D```!ZVP$``@```(3;`0`.
M````A]L!``<```"6VP$`)@```)[;`0`I````Q=L!`"L```#OVP$`'````!O<
M`0`L````.-P!`"D```!EW`$`6@```(_<`0`-````ZMP!`$T```#XW`$`-```
M`$;=`0!3````>]T!`$P```#/W0$`(0```!S>`0`S````/MX!`"8```!RW@$`
M,@```)G>`0`K````S-X!`!,```#XW@$`/0````S?`0"8`@``2M\!`!H```#C
MX0$`$````/[A`0`_````#^(!`(4```!/X@$`+@```-7B`0`E````!.,!`$0`
M```JXP$`3P```&_C`0!*````O^,!`"P````*Y`$`&0```#?D`0`0````4>0!
M`"4```!BY`$`&P```(CD`0`<````I.0!`"@```#!Y`$`)P```.KD`0`J````
M$N4!`#`````]Y0$`&0```&[E`0`-````B.4!`"L```"6Y0$`)````,+E`0`H
M````Y^4!`"$````0Y@$`'````#+F`0`Z````3^8!`&4```"*Y@$`-0```/#F
M`0!+````)N<!`#4```!RYP$`*````*CG`0`V````T><!`%P````(Z`$`.@``
M`&7H`0`O````H.@!`"@```#0Z`$`+````/GH`0!7````)ND!`%8```!^Z0$`
M1P```-7I`0!%````'>H!`"\```!CZ@$`*0```)/J`0`I````O>H!`"D```#G
MZ@$`:````!'K`0!B````>NL!`&L```#=ZP$`NP```$GL`0`:````!>T!`"X`
M```@[0$`-P```$_M`0`H````A^T!`&0```"P[0$`&````!7N`0!8````+NX!
M`!P```"'[@$`"P```*3N`0#,````L.X!`$\```!][P$`(@```,WO`0`\````
M\.\!`"`````M\`$`&````$[P`0`S````9_`!``8```";\`$`!P```*+P`0`$
M````JO`!``P```"O\`$`$````+SP`0`,````S?`!``L```#:\`$`!P```.;P
M`0`2````[O`!``T````!\0$`@@````_Q`0`&````DO$!`!4```"9\0$`!```
M`*_Q`0`'````M/$!``@```"\\0$`!0```,7Q`0!2````R_$!``0````>\@$`
M&0```"/R`0`*````/?(!`!(```!(\@$`$````%OR`0`"````;/(!``<```!O
M\@$`!@```'?R`0`3````?O(!``P```"2\@$`%@```)_R`0`&````MO(!`!0`
M``"]\@$`#P```-+R`0`#````XO(!`"X```#F\@$`!````!7S`0`&````&O,!
M``<````A\P$`'@```"GS`0`\````2/,!`"X```"%\P$`+P```+3S`0`6````
MY/,!`"@```#[\P$`,````"3T`0`B````5?0!`"H```!X]`$`(````*/T`0`C
M````Q/0!`!X```#H]`$`'`````?U`0`L````)/4!`"0```!1]0$`&@```';U
M`0`N````D?4!`!H```#`]0$`+````-OU`0`P````"/8!`"`````Y]@$`)```
M`%KV`0`D````?_8!`!\```"D]@$`(P```,3V`0`L````Z/8!`"<````5]P$`
M)P```#WW`0`E````9?<!`!\```"+]P$`)````*OW`0`P````T/<!`!T````!
M^`$`*@```!_X`0`V````2O@!`#D```"!^`$`&@```+OX`0`G````UO@!`$T`
M``#^^`$`*0```$SY`0`M````=OD!`"T```"D^0$`+@```-+Y`0`H`````?H!
M`"8````J^@$`(0```%'Z`0`G````<_H!`#@```";^@$`*@```-3Z`0`U````
M__H!``P````U^P$`#@```$+[`0`@````4?L!`"H```!R^P$`(0```)W[`0`/
M````O_L!``\```#/^P$`&@```-_[`0`:````^OL!``L````5_`$`)P```"'\
M`0`,````2?P!``H```!6_`$`)0```&'\`0`H````A_P!`"(```"P_`$`)P``
M`-/\`0`B````^_P!``<````>_0$`W````";]`0`+`````_X!`!,````/_@$`
M!P```"/^`0`*````*_X!`!`````V_@$`$@```$?^`0`<````6OX!``,```!W
M_@$`,P```'O^`0`;````K_X!`!@```#+_@$`!P```.3^`0`2````[/X!`!(`
M``#__@$`,P```!+_`0`(````1O\!`"D```!/_P$`$P```'G_`0`3````C?\!
M`!D```"A_P$`,P```+O_`0`=````[_\!``X````-``(`(P```!P``@`/````
M0``"`!````!0``(`%P```&$``@`*````>0`"`!\```"$``(`#P```*0``@`=
M````M``"``\```#2``(`'@```.(``@`F`````0$"``4````H`0(`$````"X!
M`@`'````/P$"``L```!'`0(`"0```%,!`@`X````70$"``8```"6`0(`#P``
M`)T!`@`1````K0$"`!````"_`0(`"P```-`!`@`/````W`$"``<```#L`0(`
M$````/0!`@`(````!0("`!L````.`@(`"````"H"`@`;````,P("`!L```!/
M`@(`"P```&L"`@`-````=P("`!P```"%`@(`"````*("`@`Q````JP("`!$`
M``#=`@(`$````.\"`@`(``````,"``(````)`P(`"@````P#`@`8````%P,"
M``L````P`P(``P```#P#`@`+````0`,"``L```!,`P(`"@```%@#`@`7````
M8P,"``X```![`P(`&````(H#`@`>````HP,"``P```#"`P(`.0```,\#`@`B
M````"00"`",````L!`(`&0```%`$`@`-````:@0"`$4```!X!`(`!@```+X$
M`@`:````Q00"`%8```#@!`(`#P```#<%`@`0````1P4"``<```!8!0(`!```
M`&`%`@`%````904"`!$```!K!0(`%@```'T%`@`&````E`4"``<```";!0(`
M!P```*,%`@`+````JP4"``,```"W!0(`#````+L%`@`-````R`4"`#D```#6
M!0(`+@```!`&`@`L````/P8"``4```!L!@(`%@```'(&`@`E````B08"`"(`
M``"O!@(`'P```-(&`@`3````\@8"``(````&!P(`!`````D'`@`-````#@<"
M``H````<!P(`!0```"<'`@`%````+0<"``\````S!P(`30```$,'`@`D````
MD0<"`!<```"V!P(`(@```,X'`@`P````\0<"`$X````B"`(`%@```'$(`@!^
M````B`@"`!X````'"0(`60```"8)`@`J````@`D"`$\```"K"0(`,````/L)
M`@`H````+`H"`"T```!5"@(`+0```(,*`@`K````L0H"`"X```#="@(`*0``
M``P+`@`H````-@L"`"P```!?"P(`-P```(P+`@`4````Q`L"`!H```#9"P(`
M#````/0+`@"H`````0P"``8```"J#`(`N0```+$,`@"%````:PT"`*````#Q
M#0(`(````)(.`@!7````LPX"`!`````+#P(`'0```!P/`@`1````.@\"``<`
M``!,#P(`&0```%0/`@`>````;@\"`$$```"-#P(`&0```,\/`@`6````Z0\"
M`%<`````$`(`&@```%@0`@`/````<Q`"``H```"#$`(`!0```(X0`@`&````
ME!`"``@```";$`(`!0```*00`@`9````JA`"``D```#$$`(`&````,X0`@`B
M````YQ`"``\````*$0(`"0```!H1`@`.````)!$"``D````S$0(`#````#T1
M`@`'````2A$"``4```!2$0(`$````%@1`@`0````:1$"``X```!Z$0(`$```
M`(D1`@`*````FA$"``D```"E$0(`$````*\1`@`(````P!$"`!,```#)$0(`
M"@```-T1`@`+````Z!$"`!@```#T$0(`"0````T2`@`&````%Q("`!L````>
M$@(`&````#H2`@`.````4Q("`!0```!B$@(`"P```'<2`@`F````@Q("`!0`
M``"J$@(`!P```+\2`@`5````QQ("``<```#=$@(`"````.42`@`B````[A("
M``L````1$P(``@```!T3`@`"````(!,"`!H````C$P(`#````#X3`@`&````
M2Q,"``@```!2$P(`&@```%L3`@`&````=A,"`"4```!]$P(``@```*,3`@`$
M````IA,"`!$```"K$P(`%P```+T3`@`+````U1,"``D```#A$P(`$````.L3
M`@`*````_!,"`!8````'%`(`!P```!X4`@`<````)A0"``H```!#%`(`%P``
M`$X4`@`"````9A0"``4```!I%`(`$````&\4`@`,````@!0"`!(```"-%`(`
M*0```*`4`@`'````RA0"``<```#2%`(`$0```-H4`@`%````[!0"``(```#R
M%`(`"P```/44`@`!````TP0``!P$```Q!0``7P,```````"<`0``;0(``*`$
M````````E`,``,<!``#\!@``?```````````````A@(``"H'```+`0``````
M`(('``#!````=P4``!4$``#Q!0``+````-L#``#"!@``)`<```@"```!!```
MO`4```,'```Q`P```````*8"``#P!0``9`(``+("```/!```@0,`````````
M``````````````#6!```404``(4$`````````````/8!``!P`@``````````
M``!_`@``+@0````````C`0``I`4```````!C!P``Y`4``)`&```E`0``<08`
M`/4$``!N`@``<`$``#0'``#"`0``T0(``"\$``!O`P``3P<``%H```"B`0``
M,P$``(H'````````>P$``.L```"7!@``P`4``%T'``!*!0``S08```````"4
M!```8@(``/(````I`@``9@(```````#;!```A08``-X%`````````````*4`
M``````````````````"8`P```````$````#E!@```````,T!````````G00`
M`$@"``"_!0```````/T"``")!P````````P%````````3P0``,P%``#L`@``
M)@4``!<`````````-````%@```"\`0````````````"U`@``6@0``&4#``!J
M`P``7P$``(,'``````````````````#Z`0``9`,``&\```#6`0```````'X&
M````````"0<``)``````````30,``)L"````````'`,``%X&``#T`0``WP``
M`"@#``#<`0``T`$``+8#``!'`P```````!P'```2!P``)0,``/$```"P!0``
MT@0`````````````JP,``*0`````````RP4``&$#``!Y`P``E00```H$````
M````BP8``,`!````````X00``'D'``#9`P``YP$```````#_!0``2P<``*D!
M``!8!```Y`$```````!/````O@$``````````````````"\#``!M!P``````
M`+(`````````F`4``&<$``"E!@``X@$``$<&````````*@```/L!``!H`0``
M50<``-H#```I!@``HP0``%4&``!6!```L`8```````"=`@``6P```),&``"+
M`P``J0````````"L!0``TP```*`#``!Z`0``9P(``,(#```I!P``>P,``"L`
M````````-@``````````````,0(``(,```#D!````````/8$``!Y!```10<`
M``````#W``````````````"3`@``N@4````````7!0``J@,``"L"``![!P``
M`````'0$```[`@````````````"0`@``C@$``(H$``#<````?0<``%<%``":
M`P```P(``#P'``!>`P``!@$```````!%!````````"X'``"?`P``I0$`````
M````````9P4``'$!`````````````$,&``#;````/@<``$H``````````@(`
M```````I`0```````%8#````````G`0```````#,`0``800``!8#````````
M)P0``&$``````````````"4$``!W````[@,``&<&````````G08````&``![
M`````````!D&``"Q!````P````0'``#=!0``N`8``,D#``!\`@``%P<``.P`
M`````````````&,!````````[@(``)H```"2````G@,```````";`0``*P4`
M`'$"``#S`P``1@,``+X"``"Z`0``W00``-<&``"T`P``XP0``,H$``"J!```
M`````!D'```7`@``OP0``!@!``"Q`@````````````#B`P``CP(```````!^
M`0``_@4``&D!```7!@``^`$``"H#``!+`P``<@,``$<$``"6`0``1P```,@!
M``!Q`P``3P8``#H```!A!@``4P```-8&``!V`@```````"X%```F`@``=`8`
M`.T````+!@``!````.0"``!^`P``@P4``(D!``"3!```_@(``&4'``#G!0``
M%P$```````"?`0``#@<``'L"``!^````!00```H'```N!@``-08```````!2
M`@``OP````````!W`P``_P,````````+````,P4`````````````9P<``"@&
M``#=`````````/0"``!`!P```````-@#``#:!`````````````!H````#0(`
M`',&````````U`8``,8&``!Q````H````/T&``!"`@```````)L$``"Y`P``
MP`````0$```/!@``3`$``)0"``"Y!0``H`$``,$!````````!0````````!-
M!P``U@(``&,`````````Q````````````````````/($````````0`4``'`'
M````````S@8````````7`P``@@8`````````````4@4`````````````\P0`
M`'<$``"D!@``;P0```@```!>````20<``+H#``!V!0``W@```(0#```D!```
M.P4``/@&``"<`P``=P(```````!J`0``/@(``+\&``#N!0``O@0```````!P
M!@```````(D```"E`@```````#0&````````'0<```````!5`0``(@0``#@!
M````````;00```````"'`@``>04``(`%``#6`````````"$"``!0!@``-P0`
M`#,"`````````````)<#``#_!````0<```<#``!J!@```````/$!``#&````
M\`,``(\```!<!P````````````#H!@``A0,`````````````W0(``"X#``!7
M`0``]08```````#E`0``_@```$T```#-!```$`4````````V`0``D`,``'T!
M``"7````600``'\$``!S````IP4``%@"``""`@```````$(&``!V`0``_@$`
M``````#G!````````"0`````````^`0``&L$``#&!```60$``"$$```&````
MGP(``%X"``````````````0&``"4!0```````.(&``".`P``/@```"L!```4
M`@``UP,``)(&``!!!P```````&P#````````C@0``*,`````````Q0,``%$`
M``"]`@``+`0``"`$``#I!````````"T&``#V`@``+P8``%@%````````````
M``````"I`@``)`,`````````````LP$```````!]````)P,```````!S!P``
M`````)$$````````S@$``/$&```(`0````````````````````$``$P%```Y
M!@```````,D%```1`0``7P0``/H#``"<````L`,``,0!````````=00``'$$
M``#7`@``R@4``'P!``",`0``````````````````_04``#4$````````/P<`
M`*8&``#0`P``J08``.T!``"F`````````.\"``````````````````"M!```
MZP$``/D$``#?`P``*`0```````!F!```GP```!`&``"Y!```Z@,```````#)
M!```6P(``(P$````````Q`(``+X%``!"!0``=0<``-8%``"4!@```````&0'
M`````````````!L$````````]`,``%0```#9`````````$@```"6````````
M`%8"```W````(`8``#P"``!S`@```````/,"````````"`0``+<"``"E!```
M>`<```````#;!@``%0````````#9!````````/P`````````'P4``(L%``#W
M`0``]P4``'P#``#9!@``M`4``)4%```#!0```````````````````````(,$
M``"_`@``S@(```T'``"9`P``_P(```````#T!```/P(``%,!````````Q00`
M`#(!````````RP(``(P``````````````$L!`````````````+L&```)`0``
MW@$``"8$``"D`P``S04``',!```S!```$08``(L$``!B`````````"\```"A
M!@``.`(``%D"``"`!P``2`<``(T%```9`````````*T```#O`P``T@8``'P%
M```R````O04``,H"````````]P8``+<&``!;!0``1`$`````````````'0(`
M`!\'``#<!@````````X%````````8`$``#D"``!#`@``NP$``(`#````````
M*@$``$8```#0`@``%`8```````!_````0@,``#8'```M`0``,00``.$!````
M````T@4``+0"``#H`0``5`,``/@#``!]!````````*(#``#4`@``8@,``.L%
M`````````````%\````?`@``,@,``/P"````````<P0```````"!!@``-P4`
M`#H%```8!````````'8```"C`P```````)<%``!B!0``$@(``&P!```B`0``
M`````(X`````````:@4```````#%!0``&@$``.`!````````DP,``)@`````
M````A04``!@`````````+`4``(8$````````'````)H&``!I!@``^P(``(4!
M````````3`,``&D'``!Z!```$`0``&4```!4!0``Q08``'0"``#@````````
M``````"W`P``=0,`````````````````````````````7`$````````Y!P``
M?@(``&P``````````````(@"````````SP8```L"```/!0``;0$``"T"``#@
M!0``YP(``$\#```-`0``8````&<`````````P`8``-D"``"Z!@``````````
M````````Z@```+($```H`````````#`'````````\P```*H%``#]`0``U00`
M`!H```````````````````!B!````````,D&``!@!@``3@`````````3`@``
M``````````!*!```%@8``",````_````@@4``*@$``"X`@``D04``.0```!"
M!````````+@%``!!!0``'P$``+@!````````FP4```````"U`````@<``"P'
M`````````````+`$````````:@<``'L%``!F````````````````````S@0`
M``<!``!8!@````````````#@!@``80<``#L!```[!```=0(``.P&```Y!```
M(`<``/X&``!R!@``#`$```````!(!@``G@8``+P$``!F!@``"04``$8'````
M``````````````!S`P``BP```'H'``#2`P```0(``*,!```L`P```````+,$
M````````)0<```$#``#K`@``<````&X&``#8````$@8``$4#``!>!P``\P4`
M`.D&``#1!```/P,```````#[!0``9@<``*`&``#2`@```````&L!``#1````
MB@8``#````#(`@``H00``.P!``#B````:@(``*8!``!<`@```````#@#````
M````7`8``"L$``!@`P``X04```````#/````E@4``-@&``!%`@``````````
M``"5`0`````````````'!@``1@4``/\&````````20,``&P%``!4!P``TP$`
M`(`!`````````````````````````````/T$``!L!```!@0``#X#```?!```
MWP0```````!<`P``?@0``!$"```L!@``RP0``!L#````````?P8``'4````%
M`P``D0$```````"L``````````0"``!Y`0``*00``#4'````````>@```'0`
M`````````````&(!``!4`0``#0```#\!``#>`P``M08``#@'````````````
M`"8```````````````````"(!0``CP0```````!&!````08```````"S````
M4`$``)$&``"R`0``%@(``%`"``"'`P``;P<``/4"``"V````\P8``/$#``!1
M`0``X@0``.\$````````T`8````````O`@````````P'``!0`````````%0"
M````````3`8``($"````````'`8```````#T!@``C`8``+L```!=!@``````
M`/D!``"$````1@8```````!U`0````````````!$`@``2`$``!4#````````
M)`$``%D#``#U````F@4``%,%``#=!@``.0$``!H'````````B`$``%P%``!7
M!```0@<``)H"```]`P``$0,``*X%``!)`0```````)\$````````/@$``&H`
M``!^!0``IP,``*@&```@`````````*X```!+````$@```*8$```!`0``>08`
M``````#5`0``N@```.0#``"V`0````````````!H!`````````````"^````
MN0```'($````````$0```%\%``#F!```(`,``*L!``#F````(@(``)\&``"]
M`0``\@$``#H&``"#!@```````($````2!```NP(``#T$``!_`0``&P```+,"
M````````O0,``'4%``!E`@``A0````````#-`@``Q`8``'\%````````5P(`
M`)\%``#P`0``K0,```````"*!0``<@$``+$```"!!````````/`&````````
M$0<``&\"````````[0,````````0`@``%`$``"T#``!$!````````-4#``#?
M`@```````'P&``!)!0```````-L%``"'!````````+(&``#W`@``KP0```4"
M````````(0```/P%``!W`0``/`,```H&``#T!0``\`(``'$%``"X`P``````
M`-0#``#H`@``608```````![!```00,````````J`@``G`4``,8%``#:!0``
M804```````````````<``'H%``!'`@``/````+P```````````````\#````
M`````````!`'```W!@``%`0`````````````80(```@'```S`P```````$`!
M```]!0```````)L&`````````````(<!``#)````Z0,``.0&``"]````BP$`
M`+T$````````-@,``#4"```=!0```````(<&``"N!```!P(``.L$``"_`P``
M````````````````200``%$&``"U!```<P4``,0#````````:P,``-H!``"P
M`0```````),%````````R@8``*(%````````"0,``'T#```3````#00``,4!
M```+!````````$$"``!5````XP4```````"L`P```P,``!D$```&!@``````
M``````#J!```[`4```H#``"H!0``MP0``!8```!4!```-P$``%4%``"D`@``
M^0(```````"``@``(P4``/L#``!#`0``:@0`````````````/P4``!,!````
M````\@,``,<$``"^!@```````$@#````````S0,``%T%``!\!```/08``/D`
M```>!0``1@$```````"K````5@$``.@$``"-`````````,X#```X!@``````
M``````#+````AP```-T#`````````````,P$````````4@<````````9!0``
M`````.<#```Q````S`,``(D%```0`0``#@```&L'``"G````SP0``&('```8
M!@``V@```"$!``"B`@``F`(``%X$```M!```(P<``&4!``!X`@``%`<``!T$
M``#9!0``G`(``%T`````````X`0``&8%```_!@``Y@(```````"R!0``````
M``0#```>!```````````````````!`4```````"3`0``A@8``'0#``"O`P``
M^@8```````"2!```A0(``!X&````````W`,```````!;`0``6P<``!0#``#Q
M`@``,P<``'0%``"H`P``70$``"L&``````````````````"O!@``X`,``$X#
M``#\!```.@<``'@$````````+P4``&@&``#4````H`(``/D#````````*`4`
M`(8'``#M!0``<@(````````I``````````8"````````"P<``.4$````````
M4@8`````````````)P<```(&````````1@(``````````````````-<!``#-
M````-P,```0!````````*P<``'('``!C!@```````($%``!N`0``KP(``,0$
M```N`@``500``````````````````(0%```3!```D0(``%<&``#2````K@,`
M`$D&```W!P``?`<```````#0!```&P4```````"Z!`````````````""`0``
M```````````C`@``6@$````````;!P``,@<``"`"``"H`@``)@<````````Z
M!```B0(``&L```#R!@``.04``#P!```1!0```````.4%``"*````'`$``*L$
M``")`P``!@4````````B!0``70(```````#J`0```````/H$````````WP$`
M`$<%````````$P8``(@```#I`@``-`0``.4#``"K!0``S@4``,<#````````
M/P0``````````````````.H"``"A`P``_@,``!@%```S````]@4``'<'````
M````;P8```````#+`P``;P$``!X#``!9!0```````(8```"#`0```````+0`
M``"/`P``A`0``#`$``"W`0``F0(``*`%``"V`@``Y0(````````R!```H0``
M`"P"``#(`P``"P,```````",!0```````!L&``"L!```````````````````
M:P4```````#8`0````````X$```(!@```````"4```#A`P``G@``````````
M````<@4``!\&````````%0$``#X%```=````S`(``)X%``")!@``C@(``"$%
M``"6`@```````$`&``!!!@``H0$``*$%```G`@`````````````M````2@<`
M`)4"``!2!``````````````T`@``^`4``'0!``!=`P``-0$```````!.!```
M5@4``*($```)````PP4``(,#````````6`$``&D"``#L`P``&0(```````#"
M`@``6@<``$,#```\!```D`$``.8!``#C`P``400`````````````K`(```X"
M```<`@``3@$``$@$```*`````````$T&``#\`0``+@```(T!````````+0<`
M`.T"``#I`0``SP$``&P"`````````````-H"``##`@``)P```+,#``"2!0``
M`````&X````0`````````(T$```;`0``<`0``'8'`````P``WP4``%,'``"R
M`P``!P<``(T#````````C0(``&<!``""`P``OP$``'<&``!N!```J@```$X"
M``!D!0```````(P#```O!P``@@0```````"\`P``/@0``!@"````````-P(`
M`)(#``""``````0```````````````````\"```5`@``P@```+L#````````
MT08``#`%``#N````P04```````!(!0``$P<``%D'```"!```7@$`````````
M````V0$``$H&``#Q!```;08``#@%```[!P``F@$``.$```"\`@``O@,``!8$
M`````````````)D%``#J!0``]0,```````!#!P``&0,``.P$``"5`P```@,`
M``D&``".!@```````&P&``!@!P``+@$``"8&````````908``&D#````````
M7P8``+4#```*`@``20(``!\````,!@``9`$`````````````3P(`````````
M````I@4``#$&``"Q`0``#08``-(!```U!0``A@$``%P`````````.P8``.8#
M```:!0``NP0``*T"````````@````'H#``"(!@``R`4``(0&``#=`0``-0,`
M`.\!``````````````P```"6`P``8P(``)X"``#R!0``````````````````
M9`0`````````````Z0```+8%``"B!@```````!X!``#!`P``/`8``'`%``"$
M`0``:P(```````!-!```YP8```````#'!@``CP$```````##````'@<`````
M``!C!```=`<````````-!0``/0$``%`'``!M`P``(@8``$0````6!P``````
M``````#8`@``20```#L#```7!````````.\```!K!@````````H%``!3`P``
M!P4``"0%``"V!@``J00```<$``!'`0``1`8``````````````````"`%````
M````L````*\````P!@``[P8``.,`````````(P8``!(#``#!!```V@8`````
M````````?P,```P$```8`P``K`$```````"Y`0``XP8``,X`````````D@$`
M`'\'``#%`@```@4````````T`0```````*@````L`0``#@,```````"0!```
M&0$``*(```!0!0```````.H&``#5`@``````````````````"00``)D!``";
M`P``J@$```P"``#5!0``]04``/4!```-`P```````)T!``#%`````````,8"
M``!7````.````"@"`````````````/T#``"G!```NP4```````#"!0``````
M`$\!```=`0``[08``/D&``"6!```4`0```````"M`0````````````"D`0``
MJ04``+`"``!D!@```````-8#```6!0``I@,````````:`@````4```````"'
M!P``@0<``-$%``#C`0``K08``.,"``#!!@``JP(``'`#``"0!0``KP$`````
M``#3!0``HP8```````"U!0```````,\%``!M!0```````/@"````````W@8`
M````````````'P,``'X'``"T!```IP8```````#$!0``IP$``$,```"=`P``
M&P(```````!,!`````````(!``"7`@``3P4``$`#``!Z!@``W`(```````!'
M!P``8P4``(`&``!$`P``Y0```$T%``##!@```````````````````````-``
M``!;`P``MP```'D"``!#!0```````%,&``#7!0``2@(``#T````M!0``````
M`'L&``#@`@``8`0``!H#``````````````````##!````````-,#``#B`@``
M>`,``)0```"(!P``&@0```````````````````````!!!```&@8`````````
M````40<````````I`P``_0```%<#`````````````"('``!1`P``.@(``),`
M``#S`0``50(`````````````#@8```````"9!````````$(!``!?`@``2P0`
M`$P'``!N!0``L0,```````"$`@``3@8````````F`0```````-L!````````
ML04``'$'``#<!```:04``+0&```G!0``/0<``$0'``!*`P``:00``,\#````
M````:`(``*\%``"`!```=@,``-$#``!0`P``F`$``.$"``!,`@``P@0`````
M``"(!```;`<``'(```````````````````#Z`@```````#(%``!H`P``!@<`
M`",#``!]!@```````.@#``"7!```M0$``,L&``#/`@``*`$``)<!``#+`0``
M`````%<'``!3`@``6@,``(8%````````,`(``/@```"9`````````,P```"N
M`@``-`4```````#7`````````*4%```````````````````E!@``F08``.X!
M```A`P``.P```)@&``!!`0``Q@,``(P"```%!P``%04``&4%````````````
M```````B`P``B@(``!X```"$!P``5@<``*T%``!%````=@8``#@$``##`0``
MU`$``$(```!E!```*`<``&\%``#V!@``5@````X!``#Z!0``30(``/X$``!:
M`@``HP4```4&``#I!0``(@```$4%````````2P8``)@$``"<!@``P0(```,$
M`````````````+T&``!N`P``%08``.X&````````?04``.@````T`P``6@4`
M`!(%```/`0``'@(```````!H!0```````"\!```]`@``30$``#`!```E`@``
MU0`````````E!0``9@,``/8```!Z`@``CP8`````````````HP(```````"N
M`0``_`,``&$!``"X````D0```````````````````)4````F`P``#P``````
M````````B@,```````!]`@``QP4``,8!````````A@,``"$'``">`0``````
M`-L"``#)`0``"@$``%4#``!Y````U`0``,,#````````R@$``!,#````````
M``````````!N!P``\`0``'8$```(`P```````#X&``#8!````````*$"``!M
M````CP4``!@'````````6`<``"H$```"````8`(``!P%````````^04``$X%
M````````R`````P#``"+`@```````*4#```(!0```````#D#``#_`0``#P<`
M`%T$```)`@```````$P```":!```T0$``"D%``#H!0```````'@`````````
M9@$``/````#O!0``2P(``+<%```%!0```````%(```#K`P``2P4``-4&```Y
M````R`0``)T%``#``@``7P<```,!``!X!@``1`4``-\&``````````````<`
M```V!0``*P,``/H```#(!@``%0<```,&``#*````>`$``!(!``#W`P``Y@4`
M`*L&``!3!```4@$````````&`P``N0(``$X'```4````D0,``*H"``!<!```
MUP0``#H#```P`P``]````$`$````````W@(``+$&`````````````-P%``!B
M!@``P`,``,H#``#M!```6P0``)0!``"(`P``:`<``(4'`````````````!,%
M``"-!@``I`0``#$'``"*`0``0P0``)L````A!@``\@(``'4&````````````
M`+8$````````$`,``.L&``!@!0```````/L$``"5!@``X@4``"H&````````
M`````/<$````````N@(```````"T`0``108```````"N!@``5@8``#P%````
M````00```#8$````````,@(````````!!0```````(X%```=`P``IP(`````
M````````4@,``"<&``#4!0``^P8```````"H`0``8P,``!$$````````````
M`%0&```G`0``LP4```````#F!@``TP(```````"'!0``@P(``+D&``!8`P``
M@0$```````#N!```)`(``-,&````````-0```+P&``#)`@``J0,``%D`````
M````,0$```````#A!@``LP8```L%``!%`0``6P8``+@$```V!@```````%H&
M````````9````"0&``#'`@```````)T```#_````!0$``$`"``")!```:0``
M`-@%```@`0``G@0```````"2`@``%`4````````Z`0``T`4````````6`0``
M`````'@%``#'````S`8`````````````7@4``",$``#V`P``*@4``.<```#`
M!```J@8``!T&``!*`0``,@8````"``!G`P``W@0``#8"`````````````/L`
M``"L!@``E@8``%$"````````,P8````@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S
M(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@
M;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`
M(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F
M34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I
M;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M
M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``
M)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A
M="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD
M+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N
M9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI
M<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B
M92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@
M2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C
M:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT
M(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]0
M30!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M
M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@
M26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`
M06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M
M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES
M<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!
M9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M
M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES
M=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O
M<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E
M<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A
M;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`
M06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES
M<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@
M97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A
M<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I
M;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z
M`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O
M;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A
M`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@
M3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA
M<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD
M`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!
M<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N
M(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D
M`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(
M($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B
M97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S
M`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B
M861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A
M`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E
M<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`
M0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O
M='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T
M960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#
M86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O
M(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@
M:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A
M;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!6
M97)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A
M>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@
M<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H
M;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R
M=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T
M92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#
M:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H
M96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I
M;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U
M<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@
M4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U
M*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S
M92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO
M;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES
M=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@
M;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R
M:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%14
M4`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S
M960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R
M('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD
M`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O
M;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W
M:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S
M=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD
M<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`
M0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN
M9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N
M;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I
M=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R
M>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O
M=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S
M`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M
M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@
M=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E
M871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M
M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E
M;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R
M<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R
M<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`
M0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI
M8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4
M<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E
M9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`
M1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN
M:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E
M($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@
M<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`
M1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A
M:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT
M`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN
M=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T
M;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L
M87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@
M9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A
M;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$
M<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P
M`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N
M`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@
M061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET
M:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS
M`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E
M<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT
M97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T
M:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@
M)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P
M87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W
M<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%
M=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O
M;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO
M=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N
M9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP
M;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A
M:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S
M(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL
M960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A
M:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`
M1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E
M96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD
M(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`
M1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE
M($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D
M`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`
M1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T
M`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N
M80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE
M<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&
M=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L
M;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A
M=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E
M;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!'
M;V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y
M+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L
M92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M
M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M
M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E
M<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(
M;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO
M;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E
M<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S
M(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E
M<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T
M(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S
M(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT
M86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@
M`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL
M960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@
M;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H
M:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN
M`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@
M9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET
M(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN
M(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T
M:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O
M=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA
M9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L
M;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T
M(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!)
M;F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T
M:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#
M7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T
M(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@
M8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U
M<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A
M;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@
M;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B
M969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R
M90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E
M<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R
M;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S
M96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O
M36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H
M92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT
M96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!)
M;G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A
M;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`
M26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P
M<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I
M96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E
M(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV
M97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`
M27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`
M27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P
M86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*
M=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE
M9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME
M;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`
M2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+
M97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E
M<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,
M85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T
M97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E
M<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T
M`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@
M:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y
M86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL
M90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E
M`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI
M9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK
M('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M
M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S
M`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI
M<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B
M<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL
M960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN
M`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN
M`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F
M86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S
M`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE
M;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D
M;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA
M;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA
M<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T
M:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R
M9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V
M97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@
M5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N
M`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T
M(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E
M`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D
M`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P
M;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-
M;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`
M36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`
M36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S
M`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S
M=&QY($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-
M;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P
M`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I
M;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!
M8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T
M`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R
M=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S
M8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S
M8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C
M87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E
M9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A
M;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?
M8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X
M="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT
M`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L
M;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO
M(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R
M;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I
M="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO
M861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L
M;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M
M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV
M92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO
M9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,
M(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S
M<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I
M9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P
M96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D
M`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H
M25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE
M<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`
M3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.
M;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E
M<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N
M;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES
M="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F
M96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T
M(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N
M;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN
M9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R
M("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@
M56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E
M`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M
M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A
M;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y
M`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL
M`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@
M4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I
M;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L
M874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P
M=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D
M`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O
M<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R
M;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R
M8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E
M<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`
M4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N
M86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H
M;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R
M979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I
M;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE
M;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U
M8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O
M`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y
M`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO
M;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@
M86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E
M860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G
M97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO
M=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H
M90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U
M<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O
M<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP
M92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H
M96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O
M;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W
M(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T
M:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T
M871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H
M96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I
M;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M
M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E
M(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S
M`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I
M96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C
M="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O
M=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L
M96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N
M(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0
M<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE
M;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO
M860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S
M(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,
M96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I
M;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N
M:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S
M($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q
M=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3
M;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R
M97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`
M4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`
M4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M
M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L
M=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@
M5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R
M86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN
M9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#
M4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3
M=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U
M;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S
M8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*
M86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO
M9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS
M`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN
M9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B
M;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW
M86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO
M;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E
M;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M
M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P
M`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A
M8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I
M;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG
M=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4
M:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H
M92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N
M=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B
M)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E
M9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@
M;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H
M92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X
M="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S
M8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA
M8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M
M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N
M=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I
M;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES
M=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@
M5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S
M=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP
M;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-
M3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY
M(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``
M5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O
M8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@
M*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``
M55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N
M('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T
M;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O
M(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA
M8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I
M;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5
M;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T
M:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E
M9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``
M56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`
M56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L
M:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R
M96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN
M;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T
M(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L
M971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R
M(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-3
M3`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES
M=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE
M`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R
M;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I
M;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A
M<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!6
M97)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN
M9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)
M4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@
M87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L
M(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@
M=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A
M<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED
M960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE
M`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM
M,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@
M87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H
M87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7
M;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@
M17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE
M87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@
M8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U
M(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9
M;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC
M871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA
M`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X
M=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W
M(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M
M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P
M<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T
M`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V
M92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`
M861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C
M;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T
M:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F
M;W)M870@97)R;W(`961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE
M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T
M(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E
M<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM
M<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT
M`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O
M=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E
M;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O
M<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE
M8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`S+C$M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3(W(#$Y.C4Q
M*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTR-"`Q,CHU.2LP,C`P
M"DQA<W0M5')A;G-L871O<CH@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*
M3&%N9W5A9V4M5&5A;3H@1FEN;FES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET"@`@*"5S('#D:7;DY"!S:71T96XI`"`H4&EK86[D<'#D:6X@)7,I
M`"`H)7,@<.1I=N1S<^0I`"`H=.1NY.1N*0`@*&AU;VUE;FYA*0`@*&5I;&5N
M*0`@`"(E<R(@96D@;VQE(&AA:V5M:7-T;P`B)7,B(&5I(&ME;'!A82!V86QI
M;FYA:W-I+@`B)7,B(&5I(&]L92!A<V5N;F5T='4@2&]R9&5N(')E:VES=&5R
M:7-SY"X`(B5S(B!P=6ED96X@:W5V86%J86$@96D@;/9Y='EN>70N`"(E<R(@
M;&ESY'1T:6EN(')Y:&WD:N1R:F5S=&5L;>3D;BX`(B5S(B!L:7/D='1I:6X@
M;VEK975K<VEI;BX`(B5S(B!E:2!L=6]T=3H@)7,N`"4N,F9-0B!KY'ET971T
M>2`E+C)F34(@<V%L;&ET=7-T82`H)2XR9B4E*0`E9"`E<R!J82`E<P!386QA
M<V%N87-I('9A;FAE;G1U=2`E9"!PY&EVY&X@<.3D<W3D+@`E9"!PY&EVY&X@
M96YN=7-T=7,`)7,@+2!);&UO:71U<P`E<R!3;W)M96YJY&QK:0`E<R!+0@`E
M<R!9;&SD<&ET;W1O:6UE;G!I=&5E="`M(%9A<FUI<W1U<P`E<R!A<V5N;G5S
M`"5S(&MI<FIA=71U;6EN96X`)7,@:^1Y='3V96AD;W0`)7,@;VX@:F\@;VQE
M;6%S<V$N`"5S('-U=6YT82`E<R`E<P`E<R!O;B!V86QM:7,@<W5O<FET=&%M
M86%N('EL;.1P:71O=&]I;65N<&ET96ETY"X@5F%L:71S92!V86QI;G1A<G5U
M9'5I<W1A('-U;W)I=&5T=&%V870@=&]I;65N<&ET965T+@`E<R!O;B!P86MO
M;&QI;F5N`"5S(&UI;G5U='1I80`E<R!E:2!L]GET>6YY="X`)7,@+2`E<R`O
M("5S`"5S.FX@;W-O:71E:VER:F$`)7,Z;B!K86QE;G1E<FD`)7,Z;B!M=6ES
M=&EL:7-T80`E<SIN('1E:'3D=N1L:7-T80`E<SH@)7,`)7,@.B!4Y&WD('9I
M97-T:2!E:2!O;&4@=N1L='3D;>1T=.0@<VEL=.0@;.1H971TY&KD;'3D+"!J
M;VMA(&]N(&UE<FMI='1Y(&SD:&5T=.1JY&MS:2X@4W5H=&%U9'4@=F%R875K
M<V5L;&$@=FEE<W1I<W/D(&]L979I:6X@;&EN:VME:6AI;B!J82!V87)O(&%N
M=&%M87-T82!LY&AE='3D:N1L;&4@;6ETY.1N('EK<VEL]FEV:>0@=&EE=&]J
M82X`+"!P=75S:VET=&%I<W1A`"P@<'5U<VMI='1A:7-T82`E<R`E<P`L('9A
M:6AT96QE=F%A("5S("T@)7,`+2T@=F%L:71S92`M+0`Q,BUT=6YN:6X@:N1R
M:F5S=&5L;>0`,C0M='5N;FEN(&KD<FIE<W1E;&WD`#(T('1U;G1I80`\161E
M;&QI;F5N`%1I971O:V%N=&%T875S=&%JY')J97-T96QMY.0@96D@;VQE(&WD
MY')I=&5L='D@=.1L;&4@;W-I;VQL90!487!A:'1U:2!V86MA=F$@=FER:&4`
M5FEE<W1I;B!S86QA=6MS965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A
M:6XN`$%L;&5K:7)J;VET971U;B!V:65S=&EN('1A<FMI<W1U:W-E96X@=&%R
M=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BX`4V%L871U;B!V:65S=&EN(&%V
M86%M:7-E96X@=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BP@<V%L86EN
M96X@4$=0+6%V86EN(&IA('-A;&%S86YA=&5K<W1I+@!6:65S=&EN(&%L;&5K
M:7)J;VET=&%M:7-E:W-I('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XL
M('-A;&%I;F5N(%!'4"UA=F%I;B!J82!S86QA<V%N871E:W-T:2X`5FEE<W1I
M;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK:6YE;B!3+TU)344M879A:6XL
M('-A;&%I;F5N(%,O34E-12UA=F%I;B!J82!S86QA<V%N871E:W-T:2X`5FEE
M<W1I;B!A;&QE:VER:F]I='1A;6ES96MS:2!T87)V:71A86X@:G5L:VEN96X@
M4R]-24U%+6%V86EN+"!S86QA:6YE;B!3+TU)344M879A:6X@:F$@<V%L87-A
M;F%T96MS=&DN`%9I97-T:6X@<V%L875K<V5E;B!T87)V:71A86X@:G5L:VEN
M96X@4TU)344M879A:6XN`$%-(%!I;'9IY`!!32!K979Y='3D('-A9&5T=&$`
M04T@<V%D90!!32!S871E:71A`$%-(&QU;6ES871E:71A`$%-+U!-`$%022!)
M1`!4:65T;VIA(&5D:71O<FES=&$`5&EE=&]J82XN+@!!8G,N(&%L:6X`06)S
M+B!K97-K96QLY`!3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@5D93
M+6AA:V5M:7-T;V$N`%-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!L=6]D82!6
M1E,M=&EE9&]S=&]A+@!+Y'ET=.1JY'1U;FYU:W-E;B!T:65D;W0`2^1Y='3D
M:N1T=6YN=6MS96X@<V%L87-A;F$`2^1Y='3D:N1T:6QI('-U;&IE='1U+@!+
M:7)J86YP:71O`$QI<^3D`$QI<^3D(&%L:7)Y:&WD`$QI<^3D(&%L:6]I:V5U
M<P!,:7/DY"!TY&CD;CH`3&ESY.0@=75S:2!R>6AMY`!,:7/DY"!U=7-I(&]I
M:V5U<P!,:7/DY"!A;&ER>6AMY"!R>6AMY.1N("(E<R(`3&ESY.0@86QI;VEK
M975D970@(B5S(@!,:7/DY"!U=7-I(&OD>71TY&KD.@!,:7/DY"!S87)A:V4`
M3&ESY.0@=75S:6$@:N1S96YIY`!,:7/DY"!P87)I`$QI<^3D("5S('9A;&EK
M:V\@36]Z:6QL86X@4VED96)A<B!O<VEO;VX`3&ESY.0@;W-O:71E:VER:F%A
M;CH`3&ESY.0@;W-O:71E:VER:F%A;FDZ`$QI<^3D(&OD>71TY&KD`$QI<^1T
M=&EI;B`B)7,B(&KD<FIE<W1E;&WDY&XL(&UU='1A(&5I('9O:2!L:7/D=.0@
M<VESY.1N:VER:F%U='5M:7-P>7EN;O9N(&QI<^1T:65T;VIA.B`E<RX`3&ES
MY'1T:6EN("(E<R(@:N1R:F5S=&5L;>3D;BX@5F]I="!N>70@:VER:F%U='5A
M('-I<^3D;BX`2^1Y='3D:FEE;B!L:7/DY&UI;F5N(&]N(&5S=&5T='DN`$]S
M;VET90!/<V]I=&5K:7)J80!6;VD@87-E='1A82!T86D@;>3D<FET96QLY"!O
M:6ME=6MS:6$@=&]I<VEL;&4@:^1Y='3D:FEL;&4`66QLY'!I=&\`36%I;F]K
M<V5T`$%F9V%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`%1A<V%A`%1A
M<V%U<SH`2V%I:VMI`$MA:6MK:2!A=71E;G1I:V]I9'5T(&OD>71TY&KD=`!+
M86EK:VD@<GEH;>1T`$MA:6MK:2!O:6ME=61E=`!+86EK:6QT82!N96QJY&QT
MY"!S:79U;'1A`%-A;&QI(&UO;F5T(&]S;VET=&5E=`!386QL:2!JY')J97-T
M971Y;B!L:7-T86X@='EY<&EN(&%S971U<RX`3VX@:F\@;VQE;6%S<V$`5F%I
M:'1O96AT;VEN96X@24U34"US:7/DY&YK:7)J875T=6UI;F5N`%9A:6AT;V5H
M=&]I;F5N($E-4U`M<V%L87-A;F$`5F%I:'1O96AT;VEN96X@24U34"UKY'ET
M=.1JY'1U;FYU<P!686EH=&]E:'1O:7-E="!SY&AK]G!O<W1I;W-O:71T965T
M`%9A:6AT;V5H=&]I<V5T(&UA;&QI=`!686EH=&]E:'1O:6YE;B!T96MS=&DZ
M`%EH9'ES=F%L=&%I;B!386UO80!!;FYE='1U(&%R=F\@96D@:V5L<&%A+@!T
M87!A:'1U:2!T=6YT96UA=&]N('9I<FAE+@!!;F1O<G)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N>7EM:2!P<F]X>0!687-T875S`$%N=&%R:W1I<P!!;G1I9W5A
M(&IA($)A<F)U9&$`3VAJ96QM80!/:&IE;&UA;&ES=&$`3VAJ96QM82!O;B!V
M86QM:7,N`$QA:71A(&OD>71T]O9N(&MA:6MK:2!A;&EJ86MO:6AI;@!(>7;D
M:W-Y`$%R=FEO:71U(&MO:V\`:'5H=&EK=74`07)A8FEA("A7:6YD;W=S+3$R
M-38I`%!A:V5T:6X@:V]K;P!086ME=&EN(&YI;6D`3VQE=&MO('9A<FUA+"!E
M='3D(&AA;'5A="!P;VES=&%A('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V;B`E
M<R`_`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82`B)7,B(&IA
M(&MA:6MK:2!S96X@86QI<GEH;>1T/P!!9V5N=&EI;F$`07)M96YI80!!<FUE
M;FEA("A!4DU30TE)+3@I`%1A:61E`$%R=6)A`$%S8V5N<VEO;B!S86%R970`
M07-C:6DM=&%I9&4`07-I86XO5'EY;F5N;65R96X@86QU90!+>7-Y('9A<FUI
M<W1U<R!E;FYE;B!K=6EN('1E:&3DY&X@>6QLY'!I=&]T;VEM96YP:71E970N
M`%1E:'3D=N1S87)A:VME970`67)I=&5T=&EI;B!P;VES=&%A(&]L96UA=&]N
M=&$@<GEH;>3D+@!9<FET971T:6EN('!O:7-T86$@;VQE;6%T;VYT82!O:6ME
M=71T82X`67)I=&5T=&EI;B!M=6]K871A(&]L96UA=&]N=&$@;VEK975T=&$N
M`%ER:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&IA:V]A+@!,:7/D;>3D
M<FET>6MS970`96QO:W5U`$%U<W1R86QI80!)=.1V86QT80!!=71H7V-Y<G-Q
M;#H@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`
M075T:%]C>7)U<SH@5&%U<W1A:N1R:F5S=&5L;>0@96D@='5E('1A<G9I='1A
M=FEA(&]M:6YA:7-U=6MS:6$N`$%U=&A?8WER=7,Z(%1A<G9I='1A=F%A($E-
M05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?9G1P.B!T87)V:71T
M879A82!&5%`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N($ODY&YNY"!02%`@
M:^1Y='3D96X@+2UE;F%B;&4M9G1P(&%S971U<W1A+@!!=71H7VEM87`Z(%1A
M<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?
M:W)B-3H@5&%R=FET=&%V86$@:W)B-2UL86%J96YN=7-T82!E:2!L]GET>6YY
M="X`075T:%]L9&%P.B!KY'ET=.1J:65N(&QI<^3D;6EN96X@06-T:79E($1I
M<F5C=&]R>7EN(&5I(&]L92!T=65T='4`075T:%]L9&%P.B!+Y'ET=.1J:65N
M('!O:7-T86UI96YN($%C=&EV92!$:7)E8W1O<GES=.0@96D@;VQE('1U971T
M=0!!=71H7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@
M;/9Y='EN>70N`$%U=&A?;&1A<#H@16D@=F]I9&$@;&ESY'3D(&OD>71TY&KD
MY"`E<RX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:3H@`$%U=&A?;&1A
M<#H@16D@=F]I9&$@<&]I<W1A82!KY'ET=.1JY.0@)7,`075T:%]L9&%P.B!%
M:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S`$%U=&A?;&1A<#H@2^1Y
M='3D:FEE;B!PY&EV:71TY&UI;F5N($%C=&EV92!$:7)E8W1O<GEY;B!E:2!O
M;&4@='5E='1U+@!!=71H7VUC86PZ(%1A<G9I='1A=F%A($U#04PM;&%A:F5N
M;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?<VUB875T:#H@5&%R=FET=&%V86$@
M<VUB875T:"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`075T96YT:6MO:6YT
M:2!)34%0+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`075T96YT:6MO:6YT
M:2!E<.1O;FYI<W1U:0!!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I+B`E<P!!
M=71E;G1I:V]I;G1I(%)!1$E54RUP86QV96QI;65L=&$@97#D;VYN:7-T=6DN
M`$%U=&5N=&EK;VEN=&D@1E10+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`
M075T96YT:6MO:6YT:2!334(M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+@!+
MY'ET971TY'9I<W/D;VQE=F%T(&ME;G3D=#H`07IE<F)A:7ID86X`0D]&2"!S
M96QI='EK<V5T`%1A=7-T80!4875S=&%VY')I`%;DY'+D(&ME<F)E<F]S('-A
M;&%S86YA+@!6Y.1RY"!K97)B97)O<R!KY'ET=.1JY'1U;FYU<RX`0F%H86UA
M`$)A:')A:6X`0F%L=&EA("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B
M861O<P!'<F%F:6EK;VED96X@<&5R=7-H86ME;6ES=&]A("(E<R(@96D@;/9Y
M='EN>70N`%!E<G5S=FEI=F$`5F%L:V\M5F5NY&KD`$)E;&=I80!"96QI>F4`
M0F5N:6X`0F5R;75D80!":'5T86X`4WEN='EMY'#D:7;D`$]S:6]T82`B)7,B
M(&]H:F5L;6%L;&4@(B5S(B!E:2!L]GET>6YY="X`3W-I;VX@87-E='5K<V5T
M`$]S:6]N('1Y>7!P:0!,:6AA=F]I='4`0F]L:79I80!+:7)J86YM97)K:70`
M4F5U;F$`4F5U;F%N('9A:'9U=7,Z`%)E=6YA=`!";W-N:6$@2&5R>F5G;W9I
M;F$`36]L96UM870`0F]T<W=A;F$`06QI;@!";W5V970@<V%A<F5T`$)R87-I
M;&EA`$)R:71A;FYI86X@26YT:6%N('9A;'1A;65R96X@=&5R<FET;W)I;P!"
M<G5N96D@1&%R=7-A;&%M`$)U;&=A<FEA`%!A;&QU:VMA;&ES=&$`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DPM:F%K96QU;W-O:71T965T`%-?
M;VQU;B!T:65D;W0N+BX`5N1L:6UU:7-T:6X@86QU<W1U<R!E:2!V86QM:7-T
M=6YU="X`2V%L96YT97)I`%1Y>6YI`$MA;7!U='-E80!+86UE<G5N`%-A;&%S
M86YA82!E:2!V;VD@='EH:F5N=.3D(&%U=&]M86%T=&ES97-T:2P@;W1A('EH
M=&5Y='3D('EL;.1P:73D:N3D;BX`16D@=F]I(&MI<FIO:71T86$@=&EE9&]S
M=&]O;B`B)7,B`%5L:V]I<VEA(&ES='5N=&]KY'-I='1E;&EJ]FETY"!E:2!O
M;&4@;6%H9&]L;&ES=&$@:&%L;&ET82X`24U!4"UP86QV96QI;65E;B!E:2!S
M86%T=2!Y:'1E>71TY#H@)7,`16D@=F]I(&%V871A('1I961O<W1O82`B)7,B
M+@!+86YA9&$`4&5R=0!097)U(&]N9V5L;6%V:65S=&D`16D@=F]I9&$@<&]I
M<W1A82!T:65D;W-T;V$@(B5S(BX`5N1L:6%I:V%I<VAA:V5M:7-T;V$@96D@
M;/9Y='EN>70N`$5I('9O:61A(&IA=&MA82!I;&UA;B`G=&%R9V5T1FEL92<@
M+7!A<F%M971R:6$N`$5I('9O:61A('!O:7-T86$@:&%K96UI<W1O82`B)7,B
M+@!%:2!V;VED82!P;VES=&%A+"`E9"!A;&ET87-O:F$@;VQE;6%S<V$N`$5I
M('9O:2!U=61E;&QE96YJY')J97-TY.0L(&%N;F5T='5J96X@=&EE='5E:61E
M;B!MY.1RY"!E:2!V87-T86$@=&%L;&5T971T=6IE;B!T:65T=65I9&5N(&WD
MY'+DY"X`16D@=F]I(&]H:F%T82!V:65S=&GD(&%N;F5T='5U;B!N=6UE<F]O
M;BX`2V%P(%9E<F1E`$MU=F%T96MS=&D`4&%L=F5L=6YT87)J;V%J80!+871E
M9V]R:6%T(&IA(&]T<VEK;W0`0V%Y;6%N('-A87)E=`!0=6AE;&EN*$=332D`
M4V]L=6X@=&EE9&]T`%-O;'5N('3D>71E.@!3;VQU;B!T:65D;W0`4V]L=6X@
M=N1L>7,Z`$UA=&MA<'5H96QI;@!+96QT=&D@*$E33RTX.#4Y+3$T*0!+97-K
M:71E='1Y`$ME<VMI+4%F<FEK86X@=&%S879A;'1A`$ME<VMI+45U<F]O<'!A
M("A)4T\M.#@U.2TR*0!687)M96YT965N('1I961O=`!687)M96YT965N(&]M
M:7-T86IA`%9A<FUE;G1E96X@<&]L:71I:6MA=`!4<V%D`$UU=71A`%9A:6AD
M82!S86QA<V%N87-I`%9O:70@;75U='1A82!LY&AE='3D;6ES<^1S:2!SY&AK
M]G!O<W1E:7-S82!NY&MY=FGD(&YI;6DM('1A:2!O<V]I=&5T:65T;VIA+@!3
M86QA<V%N86X@=F%I:'1O(&5I(&]L92!KY'ET]G-SY"!N>6MY:7-I;&SD(&%S
M971U:W-I;&QA+B!/=&$@>6AT97ET=.0@>6QLY'!I=.1J:6EN+@!-97)K:VD`
M5&%R:VES=%]A(&QI;FMK:2XN+@!#:&EL90!+:6EN80!+:6EN82!Y:W-I;FME
M<G1A:7-T971T=2`H1T(R,S$R*0!+:6EN82!P97)I;G1E:6YE;B`H0FEG-2D`
M5F%L:71S92!O:&IE;&UA`%9A;&ET<V4@<V%L87-A;F$`5F%L:71S92!KY'ET
M=.1JY'1U;FYU<P!686QI='-E('#D:7;D;>3D<FEE;B!E<VET>7-A<W4Z`%9A
M;&ET<V4@;&ES=&%N('1Y>7!P:2`H:N1R:F5S=&5T>6EL;&4@;&ES=&]I;&QE
M*0!*;W5L=7-A87)E=`!,=6]K:V%MY.1R:71Y<W3D("5S(&5I(&SV>71Y;GET
M+@!396QK9>0`4&]I<W1A($U33V9F:6-E('1A9VET`%!O:7-T82!K>7-E;'D`
M4&]I<W1A(&OD>71TY&KD.B`E<P!0;VES=&$@:^1Y='3D:N0`4&]I<W1A(&OD
M>71TY&KD;B!T:65D;W0`4V5L:V5N97;DY"!M>?9HY.1N`$YA<'-A=71A(&IA
M=&MA86MS97-I`$-L:6MA=&5L;"!(5%10.FX@:V%U='1A`%-U;&IE(&EK:W5N
M80!0:6QV:>0`4&EL=FEN96X@86EK86ES:6X`4&EL=FEN96X`2V]O:V]S("A+
M965L:6YG*2!S86%R970`4&EE;F5N;N0@<VEV=79A;&EK:V\`4&EE;F5N;F5T
M>70@<F5U;F%T`$MO;'5M8FEA`%;D<FD`5N1R:79A;&ET<VEN`%;D<FEV86QI
M;G1A`%-A<F%K.@!387)A:VME:61E;B!O='-I:V]T`%-A<FIA:W5V870`2V]M
M96YT;P!+;VUE;G1O='5L:VMI`$MO;6UE;G1T:0!9;&5I;F5N(&YI;6D`2V]M
M;W)I=`!9<FET>7,`5&EE=&]K;VYE970`3VQO<W5H9&4`3VQO<W5H=&5E=`!!
M<V5T=6MS:65N(&5R;W0`07-E='5K<V5T(%!$02UL86ET=&5I9&5N+"#D;'EP
M=6AE;&EM:65N(&IA($]U=&QO;VMI;B!S>6YK<F]N;VET:6EN+@!!<V5T=6MS
M:6$@<&ETY.0@<.1I=FET=.3D+@!!<V5T82!A<V5T=6MS970@)7,`5F%H=FES
M=&$@:VER:F]I='1A;6%L;&$@<V%L87-A;F$@=75D97-T86%N`$MO;F=O`$MO
M;F=O;B!D96UO:W)A871T:6YE;B!T87-A=F%L=&$`66AT97ES(&5PY&]N;FES
M='5I+@!9:'1E>7,@97#D;VYN:7-T=6DZ(`!9:'1E>7,@:G5L:VES=&5N(&%V
M86EN=&5N('!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`66AT97ES(&IU;&MI
M<W1E;B!A=F%I;G1E;B!P86QV96QI;65L;&4@97#D;VYN:7-T=6DN(%9I<FAE
M.B`E<R`H)7,I`%EH=&5Y<R!F='`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I
M+@!9:'1E>7-T:65D;W0`66AT97ES=&EE9&]T(&QI<^1T=&EI;B!O<V]I=&5K
M:7)J86%S:2X`5&EI=FES=&5T>6X@=&EE9&]S=&]N('1Y>7!P:3H`(B5S(CIN
M('-I<^1L=/8`2F%T:V$`0V]O:R!S86%R970`17;D<W1E`$MO<&EO:0!+;W!I
M;VEN=&D@97#D;VYN:7-T=6DZ("5S`$MO<&EO:2!V86QI;G1A`$-O<W0@240`
M0V]S=&$@4FEC80!.;W)S=6YL=75R86YN:6MK;P!6:65S=&EN(%!'4"US86QA
M=7-T82!E:2!V;VET=2!T96ADY#H@`%9I97-T:6EN(&5I('9O:71U(&UU;V1O
M<W1A82!01U`M86QL96MI<FIO:71U<W1A.B``5FEE<W1I;B!3+TU)344M<V%L
M875S=&$@96D@=F]I='4@=&5H9.0N`%9I97-T:6EN(&5I('9O:71U(&UU;V1O
M<W1A82!3+TU)344M86QL96MI<FIO:71U<W1A+@!%:2!V;VET=2!O='1A82!Y
M:'1E>71TY"X@)7,`3&1A<"UP86QV96QI;65E;B!E:2!S86%T=2!A=71O<FES
M;VET=6$@>6AT97ET=.0N`$5I('9O:71U('1A<FMI<W1A82!S86QD;V$N("5S
M`$Q$05`M<&%L=F5L:6UE96X@96D@<V%A='4@>6AT97ET=.0N`$5I('9O:71U
M(&]T=&%A('EH=&5Y='3D('!A;'9E;&EM965N("(E<R(@:^1Y='3D96X@1E10
M.B`E<P!%:2!V;VET=2!L=6]D82!J86ME;'5L:7-T86$N("5S`%!'4"US86QA
M='1U82!T:65T;V$@96D@=F]I='4@875K86ES=&$Z(`!3+TU)344M<V%L871T
M=6$@=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A+@!%:2!V;VET=2!P;VES=&%A
M('EH=&5Y<W1I971O82X@)7,`16D@=F]I='4@<&]I<W1A82!J86ME;'5L:7-T
M86$N("5S`$5I('9O:71U('!O:7-T86$@<.1I=FET>7-S:W)I<'1IY"`B)7,B
M+@!6:65S=&EN(&SD:&5T=.1JY&X@<^1H:_9P;W-T:6]S;VET971T82!E:2!P
M>7-T>71T>2!MY.1R:71T96QE;>3D;BX`16D@=F]I='4@:&%K96$@:V]K;R!O
M<V]I=&5K:7)J86$N`$5I('9O:71U(&AA:V5A(&MO:V\@:F%K96QU;&ES=&%A
M+@!%:2!V;VET=2!H86ME82!K;VMO(&QI<W1A82!J86ME;'5L:7-T;VES=&$N
M`$5I('9O:71U(&QU:V5A('-T<F%T96=I86$@(B5S(BX`2V]M96YT;R!M:V1I
M<B`B)7,B(&5PY&]N;FES='5I+@!*=6QK:7-T96X@879A:6YT96X@<&%L=F5L
M:6UE;'1A(&5I('-A871U(&IU;&MI<W1A(&%V86EN=&$N`%1I961O<W1O;VX@
M(B5S(B!E:2!V;VD@:VER:F]I='1A82X`16D@=F]I='4@875K86ES=&$@)7,N
M`%EL;.1P:71O;6]D=75L:6X@)7,@875K86ES=2!E<.1O;FYI<W1U:0!%:2!V
M;VD@875K86ES=&$@:&%K96UI<W1O82`B)7,B+@!,1$%0+7!A;'9E;&EM96QT
M82!E:2!O;&4@;6%H9&]L;&ES=&$@971S:>0N`"5S.N3D(&5I('9O:71U(&QU
M:V5A+@!+Y'ET=.1JY&X@<V%L87-A;F%A(&5I('9O:71U(&YO;&QA=&$N($IO
M=&MU="!T87)V:71T879A="!T:65D;W0@;W9A="!VY.1R:6XN(%ER:73D('5U
M9&5S=&%A;B!T86D@;W1A('EH=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I
M='-E="!L:7/DY"!A<'5A+@!%:2!V;VET=2!H86ME82!!0TPM=&EE=&]J80!%
M:2!V;VET=2!H86ME82!O<V]I=&5K:7)J86$N("5S`$5I('9O:71U(&AA:V5A
M(&IA:V5L=6QI<W1A82X@)7,`16D@=F]I='4@:&%K96$@:F%K96QU;&ES=&]J
M82X@)7,`16D@=F]I='4@:&%K96$@=&EE=&]J82!P86QV96QI;65N('1O:6UI
M;FYO:7-T80!%:2!V;VET=2!P86QA=71T86$@87-E='5K<VEA+@!+;VUE;G1O
M(')M9&ER("(E<R(@97#D;VYN:7-T=6DN`$5I('9O:71U('1A;&QE='1A82`E
M<R!A<V5T=6MS:6$N`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R
M;75U<VMO<&EO=&$N`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R
M;75U<VMO<&EO=&$@)7,`16D@=F]I='4@=&%L;&5T=&%A(&%S971U<W#D:79I
M='ES<VMR:7!T:>0Z("(E<R(N`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-T
M96X@=F%R;75U<VMO<&EO=&$@)7,N`$%S971U<W1I961O<W1O;B`E<R!T86QL
M971U<R!E<.1O;FYI<W1U:2X@5F]I="!KY'ET=.3D(&IO=&%K:6X@87-E='5S
M=&$@=&%L;&5T=&%A:W-E<VD@:V]O9&EN('1A:V%I<VEN("5S('1A:2!T86D@
M:V]P:6]I9&$@:^1S:6X@86QL82!O;&5V86X@:V]O9&EN('1I961O<W1O;VX@
M)7,N`$Q$05`M<&%L=F5L:6UE;'1A(&5I(&]L92!M86AD;VQL:7-T82!E='-I
MY"X`2V]M96YT;R!U;FQI;FL@(B5S(B!E<.1O;FYI<W1U:2X`16D@=F]I='4@
M<.1I=FET=.3D('EH=&5Y<W1I971O:F$N("5S`$5I('9O:71U('#D:79I='3D
MY"!J86ME;'5L:7-T86$N("5S`%9I97-T96KD(&5I('9O:71U('!O:7-T86$@
M:V%N<VEO<W1A("(E<R(Z("5S`$UO>FEL;&$@4VED96)A<B!E:2!L]GET>6YY
M="X@5F%R;6ES=&$@971TY"!3:61E8F%R(&]S:6\@;VX@875K:2X`2^1Y='3D
M:N1L;&4@(B5S(B!E:2!V;VET=2!A;G1A82!S975R86%V:6$@;VEK975S:6$@
M:V%N<VEO;VX@(B5S(CH@)7,`3&%S:V5T='4@=&5K<W1I`$UA80!+=7)S<VET
M`$QU;P!,=6\@=75S:2!L:6YK:VD`3'5O('5U<VD`5F]I(&QU;V1A('5U<VEA
M(&MA;G-I;VET80!/:6ME=61E="!T96MI:N1L;.0`3'5O='1O:V]R=&EN;G5M
M97)O`$MR;V%T:6$`2W5U8F$`5.1MY&YH971K:6YE;B`T('9A:6AE='1A`%3D
M;>1N:&5T:VES970@:7-T=6YN;W0`2V5L;&]N86EK82!TY&QLY"!H971K96QL
MY`!4Y&WD;FAE=&MI;F5N(%523"!O;@!4Y&WD;FAE=&MI<V5T(&OD>71TY&KD
M=`!4Y&WD;FAE=&MI;F5N('/DY`!4Y&WD;FAE=&MI;F5N('1I;&$Z(`!4Y&WD
M;FAE=&MI;F5N('1Y>6QI`%9O:70@;75O:V%T82!T96ATY'9IY"P@:F]T:V$@
M<W5O<FET971A86X@:W5N(&MI<FIA=61U=&%A;B!S:7/DY&X@;VAJ96QM86%N
M("5S+@!,96EK:V%A`$QE:6MK86$@=F%L:71T=0!+>7!R;W,`2WER:6QL:6YE
M;B`H2T])."U2*0!+>7)I;&QI;F5N("A7:6YD;W=S+3$R-3$I`$MY<FEL;&EN
M96XO56MR86EN82`H2T])."U5*0!4<V5K:6X@=&%S879A;'1A`%!0`$133B`H
M;&ESY'1I971O82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`%#D:79I='3D:6X`1&%T
M851R964M<V5L86EN`%1I971O:V%N=&%H86MU`%#D:7;D>7,`4.1I=N1MY.1R
MY"!V87-T86%N;W1E='1U`%#D:7;D;>3D<N1N('9A;&EN=&$`4.1I=N0`4&]?
M:7-T82!S87)A:V4`:F]U;'5K=74`1&5S:6UA86QI;G5M97)O=`!0:65N96YN
MY"!S:7-E;FYY<W3D`$]L971U<P!/;&5T=7-VY')I`$]L971U<W!R;V9I:6QI
M`$]L971U<R!K;VUE;G1O='5L:VMI`$WDY')I=&5L;>1T`%!O:7-T80!0;VES
M=&$@<V]L=0!0;VES=&$@<GEH;>0`4&]I<W1A(&QO:VD`4&]I<W1A(&]I:V5U
M<P!6;VD@<&]I<W1A82!J82!T=6AO=&$@<&]I<W1E='1U:F$@=FEE<W1E:N0`
M4&]I<W1A('-O;'4`4&]I<W1A('-A<F%K90!0;VES=&$@;VQE;6%S<V$@;VQE
M=F%T('9A:6AT;V5H=&]I;F5N(&UA;&QI`%9O:2!P;VES=&%A('9I97-T96KD
M`%!O:7-T82`B)7,B.FX@;VEK975K<VEA`$]L971K;R!V87)M82P@971TY"!H
M86QU870@<&]I<W1A82`B)7,B(&IA(&MA:6MK:2!S96X@86QI;VEK975D970_
M`%!O:7-T82!R:79I`%!O:7-T82!V86QI='1U('!R;V9I:6QI`%9O:2!L=6]D
M82!U=7-I82!K86YS:6]I=&$`4&]I<W1A('9A;&ET='4@<V%R86ME`%!O:7-T
M82!V86QI='1U(')I=FD`4&]I<W1E='1U('#D:79I='ES<VMR:7!T:2`B)7,B
M+@!4;VEM:71U<V%I:V$`5&%N<VMA`$]N9V5L;6%N(&MU=F%U<P!+=79A=7,`
M5&%R:V5M;6%T('1I961O="`H;/9Y='EVY'0@;7GV<R!(;W)D93IN(&QO:VET
M:65D;W-T;W-T82DZ`%1A<FME;6UA="!T:65D;W0@;VX@=&%L;&5T971T=2!Y
M;&SD<&ED;VX@:^1S:71E;'3D=N1K<VDN`$ME:&ET>7,`2V]S=&5U<W!I<W1E
M`$5D96QL:7-E;B!T=6YN:6X@:V]S=&5U<W!I<W1E.B``2V]S=&5U<W!I<W1E
M.B``4W5U;G1A('9A<V5M;6%L=&$@;VEK96%L;&4`4W5U;G1A(&]I:V5A;'1A
M('9A<V5M;6%L;&4`2&%K96UI<W1O`$OD>73D(#(T+71U;FYI;B!A:6MA97-I
M='ES=.0N`$[D:WEMY&X@87-E='5K<V5T`$5S:71Y<W1A<&$@>6MS:71Y:7-K
M;VAT86EN96X@96YN=7-T90!%<VET>7-T87!A(&5N;G5S=&5E;&QE("A4048I
M`$5S:71Y<W1A<&$`4&5R:6QL96UE;F]I;&UO:71U<P!$:FEB;W5T:0!%:2!S
M86$@<&]I<W1A80#$;.0@:^1Y=.0@<W5O<F%A;B!M86EN=&5N86YC92YP:'`Z
M=.0`2F]S(&5N<VEM;>1I;F5N(')I=FD@<VESY&QTY.0@<V%R86MK96ED96X@
M;W1S:6MO="P@;FEI;B!V86QI='-E.@!$;VUI;FEK86%N:6YE;@!$;VUI;FEK
M86%N:6YE;B!T87-A=F%L=&$`16EK]B!O;&4@:^1Y='3D:N1T=6YN=7-T83\@
M2VER:F%U9'4@:^1Y='3D:N1K<VDN`%1A;&QE;FYA`%1A;&QE;FYA("5S`%1A
M;&QE;FYA(&QU;W1U(&%S971U<R!02%`M<VMR:7!T:6[D+@!!;&%S=F5T;W9A
M;&EK:V\`2'5U;65E=`!3Y&AK]G!O<W1I;W-O:71E`$5-86EL+71O+5--4R!G
M871E=V%Y(&%J=7)I+"!N:6EL;&4@<&%L=F5L=6YT87)J;V%J:6QL92P@:F]T
M:V$@=&%R:F]A=F%T('3D=.0@<&%L=F5L=6$N`%9)4DA%`$5C=6%D;W(`375O
M:VMA80!-=6]K:V%A(&]S:6]T80!-=6]K:V%A(')Y:&WDY`!-=6]K:V%A(&]I
M:V5U='1A`$UU;VMK86$@;VEK975K<VEA`$UU;VMK86$@)R5S)SIN(&]I:V5U
M:W-I80!-=6]K:V%A(&%S971U:W-I83H`375O:VMA82`B)7,B.FX@;VEK975K
M<VEA`$UU;VMK86$@)7,Z;B!O:6ME=6MS:6$`2V]U;'5T=7,`16=Y<'1I`$5L
M(%-A;'9A9&]R`$5L96UE;G1T:2XN+@!%;0!3Y&AK]G!O<W1I`%/D:&OV<&]S
M=&EO<V]I=&4`4^1H:_9P;W-T:6]S;VET=&5I9&5N('!I=.3D(&]L;&$@<V%M
M870N`%/D:&OV<&]S=&D@=F%R;6ES='5K<V5L;&$`16UA:6PM=&\M4TU3($=A
M=&5W87D`2'EM:?9T`%1Y:&KD('9I97-T:2X`5'EH:N0@=F%S=&%U<RX`5'EH
M:N0@:&%K=71E<FUI`%-A;&QI(&MU=FEE;B!L86ET=&%M:6YE;B!K=79A9V%L
M;&5R:6%S=&$@=&5K<W1I;B!J;W5K:V]O;BX`3&%I=&$@<.3D;&QE(&]I:V5A
M;B!P86EN:6MK965N(&MO;G1E:W-T:6UE;G4N`%#DY'1T>6UI<W9U;W-I`%-U
M=7)E;FYA(&5D:71O<FEA`$%N;F$@:WES>6UY<R!J;VMA(&MY<WETY.1N+"!J
M;W,@<V%L87-A;F%S:2!J;W5D=71A86X@;F]L;&%A;6%A;B!E<VEM97)K:6MS
M:2`G;6EKY"!O;B!L96UM:6MK:7-I(&YI;6D_)SH`3&%I=&$@:W5V82!54DP@
M=.1HY&X`06YN82!K:7)J86EM970@86QL93H`16MV871O<FEA86QI;F5N($=U
M:6YE80!%<FET<F5A`%9I<FAE`%9I<FAE('#D:79I=&5T=.1E<W/D(&]S:6]T
M83H@)7,`5FER:&4@<.1I=FET971TY&5S<^0@<WEN8R!A;F-H;W(@+71I971O
M83H@)7,`5FER:&4@<&]I<W1E='1A97-S82!S>6YC(&QO:VEA.B`E<P!6:7)H
M92!H865T=&%E<W-A('-I<^1L=/;D.B`E<RX`5FER:&4@<.1I=FET971TY&5S
M<^0@<V%L87-A;F%A.B`E<P!6:7)H92!SY&AK]G!O<W1I=FEE<W1I<W/D+@!6
M:7)H92!K:7)J;VET971T865S<V$@(B5S(BX`165S=&D`171I;W!I80!%=&YI
M;F5N`$5U<F]O<'!A`#$U(&UI;G5U=&EN(';D;&5I;@`R(&UI;G5U=&EN(';D
M;&5I;@`S,"!S96MU;FYI;B!VY&QE:6X`-2!M:6YU=71I;B!VY&QE:6X`2F]K
M86ES96QL82!S:7/DY&YK:7)J875T=6UI<V5L;&$`4'5O;&5N('1U;FYI;B!V
MY&QE:6X`36EN=75T:6X@=N1L96EN`$5S:6UE<FMK:6%R=F]T.@!3=6]R:71A
M`$QA86IE;FYA`$QA86IE;FYA('-I=G5V86QI:VMO`$]D;W1E='1I:6X@;65R
M:VMIY"`G*2<`4V%N82!S96QL86ES96YA86X@=&%I(&AA:W5T97)M:2!L86EN
M875S;65R:V5I<W/D`$QO<'!U<.1I=N1MY.1RY`!%:W-P;VYE;G1T:0!&1R!V
MY')I`$%S971U<W1I961O<W1O:F5N('1U;VYT:2!&5%`Z;&SD`$%S971U<W1E
M;B!H86MU(&5PY&]N;FES='5I+@!9:'1E>7,@3$1!4"UP86QV96QI;65E;B!E
M<.1O;FYI<W1U:2X`66AT97ES(%--0BUP86QV96QI;65E;B!E<.1O;FYI<W1U
M:2X`2V]P:6]I;G1I("(E<R(Z;'3D(&5PY&]N;FES='5I+@!+;W!I;VEN=&D@
M(B5S(CIL;&4@97#D;VYN:7-T=6DN`%5U9&5N(%-!4TPM>6AT97ED96X@;'5O
M;6EN96X@97#D;VYN:7-T=6DN`%-I:7)T;R`B)7,B.N3D;B!E<.1O;FYI<W1U
M:2X`4VEI<G1O(&5PY&]N;FES='5I.B`E<P!+875N:7,`1F%L:VQA;F1I;B!S
M86%R970@*$UA;'9I;F%S*0!&Y'(@<V%A<F5T`%9A:V%V82!V:7)H93H`1F%K
M<VD`1F%K<VET`&AE;&UI:W5U`%1U;G1U=2!K=6EN`%1U;G1U=2!K=6EN.B``
M375U=&%M:6$@<V%T96ET80!-=75T86UI82!L=6UI<V%T96ET80!+96YT=.1M
M871R:6ES:0!&:6=L970@0T%05$-(00!&:6=L970@:VER:F%S:6X`1FED>FD`
M5&EE9&]S=&\`5&EE9&]S=&]J96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;P!4
M:65D;W-T;VIE;B!L=6MU;>3D<N0Z("5S('1I961O<W1O80!4:65D;W-T;VIE
M;B!KY'-I='1E;'D`5&EE9&]S=&]N(&YI;6D`5&EE9&]S=&]N('9A;&EN=&$`
M5&EE9&]S=&]N('1U;VYT:0!4:65D;W-T;VIE;B!T=6]N=&D@96D@;VQE(&OD
M>71E='3D=FES<^0N`%-U;V1A='1I;65T`%-U;VUI`$5N<VEM;>1I;F5N('!U
M;VQI<VMO`$5N<VEM;>1I;F5N(&YE;&KD;FYE<P!+;W)J86$@<W5H9&4`2^3D
M;F[D('EM<.1R:0!+96QL=79A`%-U;74`2V%N<VEO=&$@)7,@96D@;VQE(&]L
M96UA<W-A+@!+:7)J87-I;65N(';D<FD`4G5O:V$`4V5L86EM:6QL92P@:F]T
M:V$@96EVY'0@='5E(&MU=FEA`$5N;G5S=&4@*%1!1BD`16YN=7-T971T879A
M="!V=6]R;VMA=61E="`H2'5O;6%A=&AA;B!E='3D(&5N;G5S='5K<V5S<V$@
M;VX@=&EE9&]T('-E:^0@<.1I=FES=.0@971TY"#V:7-TY"P@:F]T96X@<W5U
M<FD@;>3D<N0@<.1I=FGD(&%I:&5U='1A82!L:6EA;B!L979EY&X@;W-I;VXI
M`%5N;VAD:71K;R!S86QA<V%N87-I/P!,;VUA:VME970`36EE=&5L875S90!-
M:65T96QA=7-E96X@='EY<'!I`$UI971E;&%U<V5E=`!-:65T96QA=7-E970@
M,@!&;V]R=6UI=`!5=61E;&QE96YO:&IA=6MS970`<&4`2V5H>6MS970`4F%N
M<VMA`%)A;G-K82P@365T<F]P;VQI`%)A;G-K86X@1W5Y86YA`%)A;G-K86X@
M4&]L>6YE<VEA`%)A;G-K86X@971E;.1I<V5T('1E<G)I=&]R:6]T`$SD:&5T
M=.1JY`!3=75N;F%S=&$@`%!I9&5M<&D@:W5V875S.@!4Y'ES:6MU=0!+;VMO
M(&YI;6D`1V%B;VX`1V%L;&5R:6$L(&IO<W1A(&MU=F$@;W1E=&%A;@!'86QL
M97)I83H`1V%M8FEA`%1E92`E<R!A<V5T=6MS970`1V5N97)O:71U(&MO;V1I
M`$=E;W)G:6$`4V%K<V$`1VAA;F$`1VEB<F%L=&%R`$5T=6YI;6D`66QE:7-E
M="!A<V5T=6MS970`365N90!']F1E;`!';V]G;&4@2V%R=&%T`$=O;V=L92!H
M86MU`$AA<FUA87/D=GD`2W)E:6MK80!+<F5I:VMA("A)4T\M.#@U.2TW*0!'
M<O9N;&%N=&D`1W)E;F%D80!2>6AMY&X@>6QLY'!I=&\`4GEH;6EE;B!N:6UE
M="!E:7;D="!S86$@;VQL82!T>6AJ:>0`1W)O=7!?;&1A<#H@16D@=F]I9&$@
M;&ESY'3D(&OD>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S
M(&]L:3H@`$=R;W5P7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET=.1J
MY.0@)7,`1W)O=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD>71TY&KD
MY"`E<P!2>6AMY'0`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!6:65R86EL:6IA;B!O:6ME=61E=`!6:65R87-K:7)J80!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!P96QK=7)I;6%I<V5S
M=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!R:79I;B!V:6EM96ES=.0@<V]L
M=6$N`$A434Q!<F5A('!E;&MU<FEM86ES97-T:2!K:65L=.1Y='EY('!O:7-T
M86UA<W1A('9I:6UE:7-TY"!S87)A:V5T=&$@=&%U;'5K;W-T82X`2%1-3$%R
M96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A;6%S=&$@=FEI
M;65I<W3D(')I=FGD('1A=6QU:V]S=&$N`$A45%`M875T96YT:6MO:6YT:6$@
M96D@;/9Y='EN>70N`$AA:71I`$AA<V@M86QG;W)I=&UI`%5S=F$`3W1S86ME
M`$]T<V%K90!(96%R9"!J82!-8T1O;F%L9"!S86%R970`5F]I;6%K87,@=6MK
M;W-M>7)S:WD`2&5P<F5A("A)4T\M.#@U.2TX+4DI`$MO<FME=7,`3VAJ90!!
M<'5A(&5D:71O<FEN(&OD>71T]O9N`$]H:F4`4&%L;&]N<'5O;&ES:V\Z`%3D
M<W/D(&]N('1I961O<W1O;B!A;&MU;W-A.@!+;W)K96$`2V]?=&D`4'EHY"!I
M<W1U:6X@*%9A=&EK86%N:6X@:V%U<'5N:VEV86QT:6\I`$MO=&D`2V]T:6]S
M;VET90!+;W1I:&%K96UI<W1O`%!U:&5L:6X@*&MO=&DI`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@17#D:V5L<&]A("5S(%A-3"UD
M871A82!V:65S=&ES<^0@)7,`2&]R9&4O2V]L86(Z(%EK<VEKY.1N('9I97-T
M:2!E:2!V87-T86$@;V)J96MT:6$@)7,`2&]R9&4O2V]L86(Z(%EH=.1KY.1N
M(&]B:F5K=&EA("5S(&5I(&SV>71Y;GET('9I97-T:7-TY"`E<P!(;W)D92]+
M;VQA8CH@4&]I<W1E='1I:6X@)7,@(B5S(@!(;W)D92]+;VQA8CH@26YT96=R
M86%T:6]K;VYE('9A871I:2!T;VEM:6%K<V5E;B`G9&]M>&UL)R!02%`M;&%A
M:F5N;G5K<V5N`$AO<F1E+TMO;&%B.B!%:2!V;VED82!L=6]D82!U=71T82!8
M34PM<'5U=&$@;V)J96MT:6QL92`E<P!(;W)D92]+;VQA8CH@16D@=F]I='4@
M<&]I<W1A82`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@16D@=F]I9&$@:&%K
M96$@34E-12!)1#KD(&]S:6]L;&4@='EY<'!IY"`E<P!(;W)D92]+;VQA8CH@
M16D@=F]I('-Y:W)O;F]I9&$@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($5I
M('9O:61A('-Y;FMR;VYO:61A(&IA:V]J83H@)7,`2&]R9&4O2V]L86(Z(%1U
M;G1E;6%T;VX@:F%K;R`B)7,B`%9A86MA<W5O<F$@<^3D;G3V`%9A86MA<W5O
M<F$@=.1Y=&4`5F%A:V%S=6]R83H`36ET96X@='5L:70@=.1N;F4_("A287!O
M<G1O:2!K:6ET;W,A*0!+=6EN:V$@;6]N=&$@<V%R86ME='1A(&AA;'5A="!Y
M:&1I<W3DY#\`2V5N='1I96X@*'-A<F%K:V5I9&5N*2!L=6MU;>3D<N0N`$MU
M:6YK82!M;VYT82!R:79IY"!H86QU870@>6AD:7-TY.0_`$MO<W1E=7,`2V]S
M=&5U<SH@`$AU;6]R:7-T:70`56YK87)I`$E-05`M<&]S=&EL86%T:6MO;B!L
M=6]N=&D@97#D;VYN:7-T=6DZ("5S`$E-05`M<&]S=&EL86%T:6MO;B!P;VES
M=&\@97#D;VYN:7-T=6DZ("5S`$E-05`M<&]S=&EL86%T:6MO;B!K:6EN=&GV
M;B!L=6]N=&D@97#D;VYN:7-T=6DZ("5S`$E0+6]S;VET90!)4"UO<V]I=&4@
M96D@;VQE(&OD>71E='3D=FES<^0N`$E0+6]S;VET92!E:2!O;&4@<V%L;&ET
M=6X@0TE$4BUB;&]K:6X@<VESY&QLY`!)4"USY.1N;O9S=/9N(')I:VMO;75S
M`$Q?86ET82!R:79I(&5N;F5N`$ES;&%N=&D`5F%I;B!I:V]N:70`26MO;FET
M("5S.FQL90!):V]N:70@:F$@=&5K<W1I`%!R;V9I:6QI;B!N:6UI.@!*;W,@
M<VEV=2!E:2!NY'D@:W5N;F]L;&$L(&YI:6X@875K86ES92`E<R!E<FEL;&ES
M97-SY"!I:VMU;F%S<V$N`$IO<R!E="!NY&4@:6MO;F5I=&$@:^1Y='3D97-S
MY'-I($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;G1A+"!N:6EN('-I;G5N('!I
M=.3D(&]T=&%A('!O:7,@<.3D;'3D(%!.1R!LY'!I;N1K>79Y>7,@<F%S=&ET
M=&%M86QL82!TY&WD(&QA871I:VMO+@!*;W,@;N1E="!TY&WD;B!V:65S=&EN
M+"!M=71T82!E="!K=79A82P@;FEI;B!T=6]M86%S:2!K=79A82!E:2!V;VD@
M;N1Y='3DY"!KY'ET=.1MY'-SY'-I('-E;&%I;65S<V$N`$MU=FEE;B!E<VEK
M871S96QU`$MU=F$@55),`$MU=F$@55),.@!+=79A(&=A;&QE<FEA<W1A`$MU
M=F$@9V%L;&5R:6%S=&$Z`$MU=F%N('9I96YT:0!+=79A=`!4=6]N=&DL(&%S
M:V5L("5D`%1U;W1U(&ME;G1TY#H@)7,`5'5O9'5T(&ME;G3D=#H`3&%?:71A
M(')I=FD@:N1L:V5E;@!6Y.1RY"!T;VEM:6YT;VMO;V1I(&%N;F5T='4N`$OD
M>71TY&KD='5N;G5S('1A:2!S86QA<V%N82!O;B!VY.1R:6XN`%;DY'+D(&OD
M>71TY&KD='5N;G5S('1A:2!V86EH=&]E:'1O:6YE;B!O<V]I=&4N(%ER:73D
M('5U9&5S=&%A;B!J82!O=&$@>6AT97ET=.0@>6QLY'!I=&]O;B!J;W,@=&%R
M=FET<V5T(&QI<^3D(&%P=6$N`$QI<^3D('-I<V5N;GES=.0`26YT:6$`66MS
M:71TY&ES970@:^1Y='3D:N1T`$EN9&]N97-I80!);F9O`$EN9F]R;6%A=&EO
M`%1I971O82!E:2!O;&4@96[DY"!S86%T879I;&QA+@!,86ET82!S7V%R86ME
M(&KD;&ME96X`3&%I=&$@:W5V80!,86ET82!T875L=6MK;P!,86ET82!W=W<M
M;&EN:VMI`$QA:71A(%]S87)A:V4@96YN96X`3&%I=&$@=75S:2!S87)A:V4@
M;GEK>6ES96X@:N1L:V5E;@!,86ET82!U=7-I('-A<F%K92!E;FYE;B!N>6MY
M:7-TY`!,86ET82!U=7-I(')I=FD@;GEK>6ES96X@:N1L:V5E;@!,86ET82!U
M=7-I(')I=FD@96YN96X@;GEK>6ES=.0`3&%I=&$@:V%P<&%L92!N>6MY:7-E
M;B!N;V1E;B!JY&QK965N`$QA:71A(&MA<'!A;&4@96YN96X@;GEK>6ES=.0@
M;F]D96$`3&%I=&$@=F%I:'1O96AT;VEN96X@;6%L;&D`06YN82!SY&AK]G!O
M<W1I;W-O:71E(&IO:&]N('5U<VD@<V%L87-A;F$@;.1H971E=.3D;CH`3&%I
M=&$@<V]L=2!JY&QK965N`$QA:71A('-O;'4@96YN96X`3&%I=&$@<V]L=2!J
MY&QK965N`$QA:71A('-A<F%K92!E;FYE;@!6;VD@;&%I='1A82!V:65S=&5J
MY`!,86ET82!K87!P86QE(&KD;&ME96X`3&%I=&$@:V%P<&%L92!E;FYE;@!,
M86ET82!R:79I(&5N;F5N`$QA:71A(')I=FD@:N1L:V5E;@!!;FYA('9A861I
M='1A=F$@=F%S=&%U<R!T=7)V86MY<WEM>6MS965N.@!,:6ETY"]-=6]K:V%A
M(&MU=FEA`$QI:73D+TUU;VMK86$@;&EN:VMIY`!3:6YU;&QA(&5I(&]L92!T
M87)P965K<VD@:W)E9&EI='1E:N0@;.1H971TY.1K<V5S:2!V:65S=&EN(&IA
M:V5L=6QI<W1A;&QE+@!2:6ET=.1MY'1T]FWD<W1I(&MR961I:71T96KD`$MO
M:V]N86ES;'5K=0!+;VMO;F%I<VQU:W5L:7-T80!%<.1K96QP;R`@541(("A5
M<V5R($1A=&$@2&5A9&5R*2X`17#D:V5L<&]A(%I)4"UT:65T;V$N`$5PY&ME
M;'!O(&]H:F5L;6$N`$5PY&ME;'!O(&)A=&-H($E$+@!,Y&AE=&5T=&EI;B!E
M<.1K96QP;V$@=&EE=&]A+@!%<.1K96QP;R!V87-T86%N;W1T86IA;B!O<V]I
M=&4N`$5PY&ME;'!O('1I961O<W1O;75O=&\`17#D:V5L<&\@;&ES96YS<VEA
M=F%I;BX`17#D:V5L<&\@<&%I:VMA=&EE=&\N`$5PY&ME;'!O(&US9U]T>7!E
M("X`17#D:V5L<&\@=&%I('!U=71T=79A(&%P:5]I9"X`17#D:V5L<&\@=&%I
M('!U=71T=79A('!A<F%M971R:2X`17#D:V5L=F]T(&]I:V5U9&5T('EL96UM
MY&QLY"!T87-O;&QA+@!%<.1K96QP;R!P87)N97(@:60N`$5PY&ME;'!O('1U
M;W1E:V]O9&DN`$5PY&ME;'!O('!R;W1O:V]L;&$N`$5PY&ME;'!O('9A<W1A
M86YO='1A:F$Z("(E<R(`17#D:V5L<&\@:F%K;RUO8FIE:W1I`$5PY&ME;'!O
M(&SD:&1E;W-O:71E+@!%<.1K96QP;V$@=6YI8V]D92UT:65T;V$N`$EN=F5N
M=&%A<FEO`$ODY&YNY"!V86QI;G1A(&ODY&YT96ES96MS:0!)<F%N+"!)<VQA
M;6EL86EN96X@=&%S879A;'1A`$ER86L`27)L86YT:0!-86XM<V%A<FD`17)I
M;&QI<VGD(%5K:V]S;7ER<VMY:N0`27-R865L`$QI:6MK965L;&5L87-K:6IA
M`$MU<G-I=F]I='4`271A;&EA`$IA;6%I:V$`=&%M;6EK=74`2F%P86YI`$IA
M<&%N:2`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI80!H96ENY&MU=0!K
M97/D:W5U`$ME<VMI=.0`2V5S:VETY"!K97-K96QL90!+97-K:73D('3D>7-I
M;@!+97-K:73D('9A<V5M;6%L;&4`2V5S:VETY"!O:6ME86QL90!+87IA:W-T
M86X`4^1I;'ETY"!A;&MU<&5RY&EN96X_`$ME;FEA`$%U=&5N=&EK;VEN=&D@
M97#D;VYN:7-T=6D@2V5R8F5R;W,M<&%L=F5L:6UE;&QE+@!+97)N96P@86QO
M:71T96QI:F%T`$%V86EM96X@;'5O;G1I`$%V86EM96X@='5N;FES=&4`079A
M:6UE;B!P:71U=7,`079A:6UE;B!T>7EP<&D`079A:6UE;B!KY'ET=/8`079A
M:6X@;VX@:F\@:G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM96QL80!,87!S
M970`2VER:6)A=&D`2V]R96$L(&1E;6]K<F%A='1I;F5N(&MA;G-A;G1A<V%V
M86QT82`H4&]H:F]I<RU+;W)E82D`2V]R96$L('1A<V%V86QT82`H171E;.0M
M2V]R96$I`$MO<F5A("A%54,M2U(I`$MU=V%I=`!+:7)G:7-T86X`07-?971T
M96QU`$MI96QI`$QA;W,L(&1E;6]K<F%A='1I;F5N(&MA;G-A;G1A<V%V86QT
M80!*Y&QK:6UMY&EN96X@<'5O;&ES:V\`161E;&QI;F5N('-A;&%S86YA;G9A
M:6AT;P!*Y&QK:6UMY&EN96X@;F5L:N1N;F5S`%#D:79I=&5T='D@=FEI;65K
M<VDZ`$5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N.B`E<P!%9&5L;&EN
M96X@<VESY.1N:VER:F%U='5M:6YE;CH@)7,L("5S`$5D96QL:6YE;B!S:7/D
MY&YK:7)J875T=6UI;F5N.B!%:2!M:6QL;VEN:V%A;@!,871V:6$`3&%K:0!!
M<V5T=&5L=0!*Y'3D('1Y:&KD:W-I(&IO<R!E:2!R975N;VIA`$QI8F%N;VX`
M5F%S96X`5F%S96X@;W1S86ME`%9A<V5N(&%R=F]T`$QE<V]T;P!487-O`$QI
M8F5R:6$`3&EB>6$@07)A8B!*86UA:&ER:7EA`$QI8VAT96YS=&%I;@!+979Y
M='3D('+D;G3DY`!+:7)J875D=2!S:7/DY&X`2V5V>71TY"!S861E='1A(&%I
M:V%I<VEN`$ME=GET=.0@<V%D971T82!M>?9H96UM:6X`2V5V>6ETY"!S861E
M:W5U<F]J80!+979Y='3D('-A9&5T=&$@:F$@;7ER<VMY:7-TY`!+979Y='3D
M(&QU;6ES861E='1A`$ME=GEI=.0@;'5M:6MU=7)O:F$`3&EM97)I:VET`$QI
M;FMK:0!,:6YK:VD@;W-O:71T86$Z`$QI;FMI=.0@<^1H:_9P;W-T:6]S;VET
M92!K:7)J;VET82!U=7-I('9I97-T:2!S:79U;&QE(&[D:WEMY'-SY`!,:6YK
M:70`3&EN=7@@<&EP87)E:71A`%9O:2!L:7-T875K<V5S<V$@;N1H9.0@:V%N
M<VEO;@!.Y'ETY"!T:65T;VMA;FYA=`!.Y'ETY"!O:&IE:61E;B!A:6AE970`
M3N1Y=.0@=&%U;'5T`$QI<W1A;BU!<FMI<W1O`$QI<W1A;BU/:&IE`$QI<W1A
M;BU)9`!,:7-T86XM3VUI<W1A:F$`3&ES=&$M=FEE<W1I`$QI<W1A;BU4:6QA
M=7,`3&ES=&%N+51I;&%U:W-E;BUL;W!E='1A;6EN96X`27-T=6YT;VIE;B!L
M:7-T875S(&5PY&]N;FES='5I.B`E<P!+Y'ET=.1J:65N(&QI<W1A=7,@97#D
M;VYN:7-T=6DZ("5S`$OD>71TY&KD=&EE=&]J96X@;N1Y='3D;6EN96X@;VX@
M97-T971T>2X`2VER:F%L;&ES=75S`$QI971T=6$`3&%D871A86XN+BX`4&%I
M:V%L;&ES=&$@86EK86$Z(`!,;VMA;&ES86%T:6\@:F$@86EK80!086EK:V$`
M2VER:F%U9'4@<VESY.1N`$5D96QL:7-E;B!S>6YK<F]N;VEN=&ES97-S:6]N
M(&QO:VD`2VER:F%U9'4@=6QO<P!+:7)J875D=2!S:7/DY&X`5&5H=.1VY'0@
M<VESY.1N:VER:F%U='5M:7-E<W-A`%-I<^3D;FMI<FIA=71U;6ES97-I(&5P
MY&]N;FES='5I+B!4;V1E;F[D:_9I<V5S=&D@:VER:F]I=&ET(';DY')I;B!K
MY'ET=.1JY'1U;FYU:W-E<VD@=&%I('-A;&%S86YA<VDN`%-I<^3D;FMI<FIA
M=71U;6EN96X@97#D;VYN:7-T=6DN`%!I=&OD('1E:W-T:0!286MK875S`$UA
M=&%L80!0:65N970@:W)E:6MK86QA:7-E="!K:7)J86EM970`4&EE;F5T(&QA
M=&EN86QA:7-E="!K:7)J86EM970`4&EE;F5T(')O;VUA;&%I<V5T(&YU;65R
M;W0`3'5X96UB=7)G`$M+`$U/5$0`35,M5$Y%1B!L:6ET971I961O<W1O(&]L
M:2!T>6AJY"X`5DE%4U1)`$UA8V%O`$UA:V5D;VYI82P@16YT:6YE;B!*=6=O
M<VQA=FEA;B!T87-A=F%L;&%N+@!-861A9V%S:V%R`%1A:6MU=7,`4^1H:_9P
M;W-T:0!0;W-T:6X@>6QLY'!I=&\`5&5E(&QI;FM?:VDN+BX`36%L87=I`$UA
M;&5S:6$`36%L961I:79I=`!0;W-T:0!-86QT80!6;VET(&AA;&QI;FYO:61A
M(&QI<W1A82!K871E9V]R:6]I<W1A+"!J;VED96X@879U;&QA('9O:70@;&EI
M='3DY"!A<VEO:71A('EH=&5E;B!S86UO:F5N(&]T<V%K:V5I9&5N(&%L;&4@
M:F$@;&EI='3DY"!N:6EH:6X@=N1R96KD+@!-87`R-"!K87)T=&$`36%P475E
M<W0@:V%R='1A`%9A<W1A879U=61E="!T86QL971E='1U+@!M86%L:7-K=74`
M36%R9VEN86%L:0!6;VD@;65R:VETY"!686YH82]5=7-I('1I971O:F$`5F]I
M(&UE<FMI=.0@=FEE<W1E:N0@*&5S:6TN(%3D<FMEY"]687-T871T=2D`36%R
M<VAA;&P@<V%A<F5T`$UA<G1I;FEQ=64`5.1S;>3D=N1T(&ME;G3D=`!-875R
M:71A;FEA`$UA=7)I=&EU<P!3=75R:6X@<V%L;&ET='D@:W)E9&EI='1I+@!3
M=75R:6X@<V%L;&ET='4@=FEE<W1I;W-I;VWDY'+D('EL:71E='1Y+@!%9&5L
M;&ES96X@,C0@='5N;FEN(&MO<FME:6X@;.1M</9T:6QA.B``161E;&QI<V5N
M(#8@='5N;FEN(&MO<FME:6X@;.1M</9T:6QA.B``4&]R=&%A;&EO<VEO:61E
M;B!E;FEM;>1I<VWDY'+D`%-U=7)I;B!S86QL:71T=2!P:71U=7,`=&]U:V]K
M=74`36%Y;VYE='1E`$SDY&ME=&EE9&4`2N1S96YE=`!-96YU;B!M=6]T;SH`
M66AD:7-TY"!S;VQU=`!6:65S=&D`5FEE<W1I;B!T87)K:7-T=7,@;VYN:7-T
M=6DL(&UU='1A(&%L;&5K:7)J;VET=&%J86X@=F%R;65N;F5T=&$@96D@=F]I
M='4@=&%R:VES=&%A+@!6:65S=&D@=F%N:&5N:2X`5FEE<W1I;B!T>7EP<&D`
M365T87(@<^3D`$UE=&%R+6]S:6\@96D@;VQE(&OD>71E='3D=FES<^0N`$UE
M=&%R+6]S:6\@96D@;VQE(&OD>71E='3D=FES<^0N(%1A<FME;6UA="!T:65D
M;W0@;VX@=&%L;&5T971T=2!Y;&SD<&ED;VX@:^1S:71E;'3D=N1K<VDN`$UE
M=&%R1$(@96D@;VQE('EH9&ES=&5T='DN`$UE=&]D:0!-971O9&EA("(E<R(@
M96D@;VQE(&WDY')I=&5L='D`365T;V1I82!E:2!O;&4@;>3D<FET96QT>2X@
M2W5T<W5V82!M971O9&DZ("5S`$UE=')I;F5N`$UE:W-I:V\`36EK<F]N97-I
M82P@66AD:7-T>6YE970@=F%L=&EO=`!+97-K96QLY`!-:6UE+71Y>7!P:0!%
M9&5L;&ES96X@,C0@='5N;FEN(&UA=&%L:6X@;.1M</9T:6QA.B``161E;&QI
M<V5N(#8@='5N;FEN(&UA=&%L:6X@;.1M</9T:6QA.B``4V%L87-A;F$@96D@
M;VQE('9I96SD('1A<G!E96MS:2!V86YH80!096EL:6MU=F$`4V5K86QA:7-E
M=`!014%2+7!A:V5T=&D@2%144%]297%U97-T('!U=71T=74N`%!U=71T=79A
M="!A<V5T=7-T:65D;W-T;RX@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5S=&EE
M9&]S=&\@:F]S(&AA;'5A="!KY'ET=.3D('3D=.0@;VAJ96QM86$N`%!U=71T
M=79A(&UE<W-A9V4@240N`%;D;'1TY&WD=/9N(%!%05(M<&%K971T:2!-86EL
M('!U=71T=74N`%!U=71T=79A('-E<W-I;VX@240N`&UA`$UO8FEI;&ESY&AK
M]G!O<W1I`$MO:'1A;&%I;F5N`$UU;VMK875K<V5N('#D:7;D;>3D<N0`375O
M:VMA82!54DPZ:6$`2V5R<F]I;@!-;VQD;W9A+"!T87-A=F%L=&$`36]N86-O
M`$UO;F=O;&EA`&MU=6MA=7-I(&IA('9U;W-I`$MU=6MA=7-I='1A:6X`36]N
M='-E<G)A=`!+=75N('9A:6AE970`4FEV:6QTY"`E9"!L]GET>6D@96YE;6WD
M;B!K96YT=&GD(&MU:6X@;V1O=&5T='4@)60N`$UA<F]K:V\`16YI;6WD:W-I
M('-E;&MEY.0`16YI;6WD:W-I('!I;'9I<W3D`$5N:6UMY&MS965N('!I;'9I
M<W3D(&IA('1U=6QI<W1A`$5N:6UMY&MS965N(&%U<FEN:V]I<W1A`%-I:7)R
MY"!A;&%S<.1I;@!3:6ER<N0@=F%S96UM86QL90!3:6ER<N0@;VEK96%L;&4`
M4VEI<G+D('EL]G-PY&EN`%-I:7)RY"!A;&%S<.1I;@!3:6ER<N0@>6SV<W#D
M:6X`36]S86UB:6L`36]N:71A<V]I;F5N(&%L87-V971O=F%L:6MK;P!-=6QT
M:6UA<"!)<V\M0G)I=&%N;FEA;B!K87)T=&$`36]N:79A;&EN=&$`2^1Y='3D
M:N1T=6YN=6MS96YI`$]M86X@:^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T`$]M
M82!P;W)T86%L:0!/;6%N('!O<G1A86QI;B!A<V5T=&5L=0!->6%N;6%R("A"
M=7)M82D`14DL($5.('-U;W-T=0!.:6UI`$YA;6EB:6$`3F%U<G4`3F5P86P`
M06QA;FMO;6%A=`!!;&%N:V]M86ED96X@06YT:6QL:70`3F5T<V-A<&4@0F%S
M92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@
M<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O
M8V%T:6]N(%523`!.971S8V%P92!34TPM<&%L=F5L:6UE;B!O<V]I=&4`3F5T
M<V-A<&4@=F%R;65N=&5E;B!K;VUM96YT=&D`3F5T<V-A<&4@=F%R;65N=&5E
M;B!T>7EP<&D`5F5R:VMO`$5I(&MO<VMA86X`575S:2U+86QE9&]N:6$`575S
M:2!L=6]K:71U<P!5=7-I:W5U`%5U<VD@:^1Y='3D:N1T=6YN=7,@*'9A<&%A
M96AT;VEN96XI`%5U<VDM4V5E;&%N=&D`575S:2!S86QA<V%N80!5=7-I('-A
M;&%S86YA('9A;FAE;F5E("5X+@!!;G1A;6%S:2!U=61E="!S86QA<V%N870@
M96EVY'0@=.1S;>3D+@!5=7-I(&EK:W5N82`H7V)L86YK*0!5=71I<V5T`$ME
M<VMU<W1E;'5R>6AMY'0`4V5U<F%A=F$`4V5U<F%A=F%T(#0@=F%I:&5T=&$`
M4V5U<F%A=F%T(&%S971U:W-E=`!3975R86%V83X`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`6?8`3FEU90!%:0!!<V5T=7-T:65T;VIA(&5I(&]L92!S86%T
M879I;&QA+"!J;W-T82!V;VES:2!NY'ET=.3D(&5R;V%V86ES=75K<VEA+@!%
M:2!O;&4@<V%A=&%V:6QL82!S=75N;FET96QM86$@25-/(&QE=GEK=79A=&EE
M9&]S=&]J96X@=&5K96UI<V5K<VDN`$5I(&5RY&UA;&QI82X`3W-I;W1A(&5I
M(&]L92!P>7ED971Y<W/D('!A:6MA<W-A+@!+86QE;G1E<FEN(&YI;67D(&5I
M(&]L92!A;FYE='1U($U#04PM875T96YT:6MO:6YN:6QL92X`16D@;75U=&]S
M=&$N`$%L:71A<V]J82!E:2!V;VD@;&ESY'3D('3D;&QE(&]I:V5U9&5L;&4N
M`$%S971U:W-I82!E:2!L]GET>6YY="`E<SIL;&4N`$%S971U:W-I82!E:2!L
M]GET>6YY="!&5%`@5D93.FQL92X`07-E='5K<VEA(&5I(&SV>71Y;GET(%-1
M3"!61E,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@4U%,+49I;&4@5D93
M.FQL92X`2W)E9&EI=&ET(&QO<'!U+@!+;VAD971T82!E:2!A;FYE='1U+@!%
M:2!T=6]T=2!A:6YU='1A:V%A;B!T:65D;W-T;V$`26MO;F5I=&$@96D@;/9Y
M='EN>70N`%!A:6MK86$@96D@;VQE(&%S971E='1U+@!086EK:V%A(&5I(&]L
M92!A;FYE='1U+@!%:2!A;FYE='1U('9I97-T:>0N`$YI;67D(&5I(&]L;'5T
M(&%N;F5T='4N`$QU:W5MY.1RY.0@96D@;VQL=70@86YN971T=2X`16D@;&]U
M:VMA879A="!M:65T96QA=7-E970`4V%L87-A;F%A(&5I(&]L92!A;FYE='1U
M($A45%`M875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A;FYE
M='1U($E-05`M875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A
M;FYE='1U($ME<F)E<F]S+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E
M:2!O;&4@86YN971T=2!,;V=I;B!A=71E;G1I:V]I;FYI<W-A+@!386QA<V%N
M86$@96D@;VQE(&%N;F5T='4@4$%34U=$+6%U=&5N=&EK;VEN;FES<V$N`%-A
M;&%S86YA82!E:2!O;&4@86YN971T=2!334(M875T96YT:6MO:6YN:7-S82X`
M4&]L:W5A($]P96Y34TP@:V]M96YT;V]N(&5I(&]L92!MY.1R:71E;'1Y+B!/
M<&5N4U-,('!I=.3D(&]L;&$@:^1Y=&5T=.1V:7-SY"!J;W,@:^1S:71E;&SD
MY&X@4$M#4R`Q,B!D871A82X`16D@<VESY.1N:VER:F%U='5M:7-P>7EN=/9J
MY"!J;VYO<W-A+@!+:6EN=&GV=.0@96D@;VQE(&%S971E='1U`$5I('/DY&YT
M]FKD`$5R;W1I;G1A(&5I(&]L92!MY.1R:71E;'1Y+@!%:2!R975N;VIA`$5I
M(&SV>71Y;GET('1I961O<W1O80!6Y&QI;75I<W1I;&QE(&5I(&]L92!VY&QI
M86EK86ES:&%K96UI<W1O82X`2^1Y='3D:N1T=6YN=7-T82!T86D@<V%L87-A
M;F%A(&5I(&SD:&5T971T>2X`2V%I:VMI('!A;&%U='5N=70@6$U,+61A=&$@
M;VQI(&5PY&ME;'!O80!%:2!A<G9O:F$`5F5R<VEO=&EE=&]J82!E:2!L]GET
M>6YY="!A;&MU<&5RY&ES:73D(&%S971U:W-I<W1A+B!3:6YU;B!P:73DY"!T
M96ADY"!A<V5T=6MS970@=75D97-T86%N+@!697)S:6]T:65T;VIA(&5I(&SV
M>71Y;GET(&%S971U:W-I<W1A+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T=6MS
M970@=75D97-T86%N+@!%:2!M:73DY&X`16D@;6ETY.1N("A+Y'ETY"!I;7!L
M:7-I:71T:7-TY"D`3&%P<&DO4&]H:F]I<VUA870O17-K:6UO("A)4T\M.#@U
M.2TQ,"D`3F]R9F]L:R!S86%R970`4&]H:F]I;F5N('!A;&QO;G!U;VQI<VMO
M`%!O:&IO:7-E="!-87)I86%N:65N('-A87)E=`!.;W)J80!%:2!JY&QK965N
M`$5I(&5N;F5N`$5I(&]L92!H86ME;6ES=&\`16D@;VQE('1O=&5U=&5T='4N
M`$5I(&%S971E='1U`$5I('1U971T=2X`375I<W1I:6YP86YO=`!%:2!M:73D
MY&X@<V5L871T879A82P@<&%L86$@=&%K86ES:6XN`&UA<G)A<VMU=0!,=6MU
M;>3D<N0`365R:VMI96X@;'5K=6WDY'+D`%-A<F%K:V5I9&5N(&QU:W5MY.1R
MY`!2:79I96X@;'5K=6WDY'+D`$IA:V5L=6QI<W1A;B!N=6UE<F]I=&$@96D@
M;VQE(&WDY')I=&5L='D@<.1I=FET971TY';D:W-I+@!/2P!/8FIE:W1I`$]B
M:F5K=&EN(&QU;VIA`$]K=&%A;&D`;&]K86MU=0!,;W5K:V%A=G5U<W-U;V1A
M=&EN`%1O:6UI<W1O`%5U<VD@<V%L87-A;F$@96D@<V%A(&]L;&$@<V%M82!K
M=6EN(&YY:WEI;F5N('-A;&%S86YA<VDN`%9A;FAA('-A;&%S86YA`%9A;FAA
M('-A;&%S86YA(&]N(';DY')I;BX`3VUA;@!686EN($E-05`M<&%L=F5L:6UE
M="!T=6ME=F%T(&IA971T=6IA(&MA;G-I;VET82X`5F%I;B!L;W5K:V%A=F%T
M(&UI971E;&%U<V5E=`!6;VET(&QA:71T86$@=F%I;B!Y:&1E;B!SY&AK]G!O
M<W1I;W-O:71T965N+@!686EN(&]M:7-T86IA('1A:2!JY')J97-T96QMY&X@
M>6QLY'!I=.1JY"!V;VD@;75U='1A82!J86MO:F5N(&]M:7-T86II82!T86D@
M;VEK975K<VEA`$%V86$@=75D97-S82!I:VMU;F%S<V$`3W!E;E-33"!V:7)H
M93H@5&EE=&]J82!E:2!S86%T=2!E<VEL;&4@86QL96MI<FIO:71E='5S=&$@
M4R]-24U%+6]S87-T82X`079A82!TY&WD;B!L:6YK:6X@=75D97-S82!I:VMU
M;F%S<V$`2^1Y='3V:N1R:F5S=&5L;>0`07-E='5K<V5T`$%S971U:W-E="`E
M<SIL;&4`2N1R:F5S=&5T='D@;&ES=&$`3W)G86YI<V%A=&EO`$]R9V%N:7-A
M871I;WEK<VEK:_8`3W)G86YI<V]I;G1I`$%L:W5P97+D:6YE;B!O:&IE;&UA
M;B!M86QL:0!!;&MU<&5RY&ES970@;6%L;&ET("5S.G-SY#H`375U`$UU=70@
M=&EE9&]T`$]M:7-T86IA;B!O:6ME=61E=`!004TM875T96YT:6MO:6YT:6$@
M96D@;VQE(&OD>71E='3D=FES<^0N`%!%05(Z.DUA:6P@=&%U<W1A:N1R:F5S
M=&5L;>0`1&EG:71A86QI;F5N(%!'4"UA;&QE:VER:F]I='5S`%!'4"US86QA
M='1U82!T:65T;V$`2G5L:VEN96X@4$=0+6%V86EN`%!'4"UA;&QE:VER:F]I
M=&5T='5A(&IA('-A;&%T='5A('1I971O80!02%`M:V]O9&D`4$A0+6MO;65N
M=&]T=6QK:VD`4$T@:V5V>71TY"!S861E='1A`%!-('-A9&4`4$T@:W5U<F]J
M80!032!L=6UI`%!-(&QU;6ES871E:71A`%!-(&QU;6D`4$T@=6MK;W-M>7)S
M:WEJY`!03U-)6"UL86%J96YN=6MS970@<'5U='1U=F%T`%!?2%`M:V]M96YT
M;W1U;&MK:0!4Y'ET90!086MI<W1A;@!086QA=0!086QE<W1I:6YA("AM:65H
M:71E='1Y(&%L=64I`%!A;F%M80!087!U82!5=7-I+4=U:6YE80!087)A9W5A
M>0!/<VET=&%I;B!P:6QV:7-TY`!386QA<V%N80!386QA<V%N86X@=F%I:'1O
M(&]N;FES='5I+@!6Y.1RY"!S86QA<V%N80!386QA<V%N86$@=&%R=FET86%N
M(%)!1$E54RUA=71E;G1I:V]I;G1I:6XN`%-A;&%S86YA('9A<FUI<W1U:W-E
M;&QA`%-A;&%S86YA.@!386QA<V%N83H@`%-A;&%S86YO:F5N('!I=.3D(&]L
M;&$@<V%M870N`$QI:73D`$QI:73D(&QE:6ME</9Y9.1L=.0`4&]L:W4`2F]N
M;W-S82!O;&5V870@<VESY.1N:VER:F%U='5M:7-P>7EN;O9T.@!):&UI<V5T
M`%!R;W-E;G1T:0!3=6]R:71A('EL;.1P:71O=&]I;65N<&ET965T`%-U;W)I
M=&$@>6QLY'!I=&]T;VEM96YP:71E970@<VESY.1N:VER:F%U='5M:7-E;B!Y
M:'1E>61E<W/D+@!/:6ME=7,`3VEK975T=&$@(B5S(B!E:2!P;VES=&5T='4N
M`$OD>71T]B!K:65L;&5T='D`3VEK975D970`3VEK975K<VEE;B!Y;&SD<&ET
M;P!/;6%T('1I961O=`!097)U`$QE;6UI:VET`$9I;&EP<&EI;FET`%!U:&5L
M:6X`5F%L;VMU=F%T`%!I=&-A:7)N`%!I:W-E;&D`2VQI<V5E=`!.87!S875T
M82!J;W1A:6X@<V]L=6$`5F%R;6ES=&$@971TY"!H86QU870@<&]I<W1A82!T
MY&WD;B!E;&5M96YT:6XZ`%9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@
M;&EN:VET>6MS96X@=.1HY&X@96QE;65N='1I:6XN`$%N;F$@:W5U:V%U<VD@
M:F$@=G5O<VDN`$%N;F$@;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z`$%N
M;F$@;VEK96$@25`M;W-O:71E+@!!;FYA(&]I:V5A('#D:7;D;>3D<N0[(%1A
M<FMI<W1A('#D:79I96X@;'5K=6WDY'+D(&MU=6MA=61E<W-A+@!!;FYA(&%I
M:V$@;VEK96%S<V$@;75O9&]S<V$N`$%N;F$@;'EH>70@:W5V875S(&]N9V5L
M;6%S=&$N`$%N;F$@:^1Y='3D:N1T=6YN=6MS97-I(&IA('-A;&%S86YA<VD`
M3'5E('-E=7)A879A('1E:W-T:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!KY'ET
M=/9E:'1O:6AI;B!V;VED86MS97-I(&OD>71TY.0@:N1R:F5S=&5L;>3D+@!!
M;FYA(&YI;6D@=75D96QL92!L=6]K:71U:W-E;&QE.@!0=6]L80!0;VQI=&EI
M:VMA`$MY<V5L>70`4&]R='5G86QI`%3D;>1N(&MU=F%N('!A:6MK80!4Y&WD
M;B!T875L=6MO;B!P86EK:V$`5F]I(&SD:&5T=.3D('9I97-T96KD(&MA;G-I
M;V]N("AE:2!K;W-K92!)34%0('EH=&5Y:W-IY"D`4V%D96WDY'+D(&5D96QL
M:7-I;&QE("5S('1U;FYI;&QE.B``2&%I:'1U=G5U<R`\8G(@+SYT;V1E;F[D
M:_9I<WEY<P!0<F5F<U]L9&%P.B!487)V:71T879A82!,1$%0+6QA86IE;FYU
M<W1A(&5I(&SV>71Y;GET+@!0<F5F<U]S97-S:6]N.B!487)V:71T879A82!S
M97-S:6]N+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET`$EL;6%N<&%I;F4`26QM
M86YP86EN92!M97)E;G!I;FYA<W-A.B``26QM86YP86EN93H@`$5S:6MA='-E
M;'4`17-I:V%T<V5L92!K=79A('5U9&5S<V$@:6MK=6YA<W-A`$5D96QL:7-E
M="!A<V5T=6MS970`5'5L;W-T82!D;VMU;65N='1I`%-A;&%I;F5N(&%V86EN
M`$]N9V5L;6$`3VYG96QM86X@:W5V875S`%!R;VIE:W1I=`!+96AO='1E96X@
M=&5K<W1I`$IU;&MI;F5N(&%V86EN`$IU;&MI<V5N(&%V86EM96X@86QG;W)I
M=&UI`$IU;&MI<V5N(&%V86EM96X@=&EE9&]T`$IU;&MI<V5N+W-A;&%I<V5N
M(&%V86EN<&%R:6X@;'5O;G1I(&5PY&]N;FES='5I+@!0=65R=&\@4FEC;P!6
M;VD@='5H;W1A('!O:7-T971T=6IA('9I97-T96KD`%%A=&%R`$MY<V5L90!+
M:6EN=&GV`%)302!*=6QK:6YE;B!A=F%I;B`H)60@8FET=&GD*0!2861I;W!A
M:6YI:V4`4V%D90!3861E='1A(&%I:V%I<VEN`%-A9&5T=&$@;7GV:.3D;@!3
M861E:W5U<F\`5F5S:2!J82!L=6UI`%9E9&5S=.0@;'5M965N`%-A='5N;F%I
M;F5N(&UI971E;&%U<V4`4W5H9&4`3'5K=0!6;VD@;'5K96$@=FEE<W1E:N0`
M4&]I<W1E=&%A;FMO("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T
M=&%A+@!0;VES=&5T86%N:V\@=&EE9&]T(&OD>71TY&KD<W3D("5S/R!4Y'3D
M('1O:6UI;G1O82!E:2!V;VD@<&5R=75T=&%A+@!4964@;75U=&]K<V5T('5U
M9&5S=&%A;@!0Y&EV:73D`%#D:7;D="!D>6YA86UI<V5T('9A;&EK:V]E;&5M
M96YT:70Z`%#D:79I=.0@<&]R=&%A;&ENY&MY;>3D.@!3Y.1N;O9L;&EN96X@
M;&%U<V5K90!296QA871I;W-E;&%I;@!,871A82!U=61E;&QE96X`375I<W1I
M:6YP86YO=`!%=.1P86QV96QI;65T`$5TY'!A;'9E;'5N(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%!O:7-T80!0;VES=&$@;W-I;P!0
M;VES=&$@<V%R86ME`%!O:7-T82!M=6]T;VEL=0!0;VES=&$@<&%R:0!0;VES
M=&$@=&%L;&5T971T=2!S:W)I<'1I('!A;'9E;&EM96X@=N1L:6%I:V%I<VAA
M:V5M:7-T;W-T82X`4&]I<W1A`%!O:7-T82!TY&WD(&YO;V1I(&1O:W5M96YT
M:7-T80!0;VES=&$@:^1Y='3D:N0`4&]I<W1A(&OD>71TY&KD.B`E<P!0>7EN
M=/;V;B!E:2!V;VET=2!V87-T871A+B!6:7)H96MO;V1I.B``4'EY9&5T='GD
M('!A;'9E;'5A(&5I(&SV>71Y;GET+@!487)V:71T879A82`B)7,B+71I971O
M82!E:2!O;&QU="!MY.1R:71E;'1Y("5S(&%S971U:W-I<W-A+@!487)V:71T
M879A82`B)7,B+71I971O82!E:2!O;&QU="!MY.1R:71E;'1Y(%9&4R!A<V5T
M=6MS:7-S82X`5&%R=FET=&%V86$@(B5S(BUT:65T;V$@96D@;VQL=70@;>3D
M<FET96QT>2!A<V5T=6MS:7-S82X`4&%K;VQL:6YE;B!K96YT=.0`5'EH:F5N
M;N0`5'EH:F5N;N0@<V%L87-A;F$`5'EH:F5N;N0@<V%L87-A;F%S:0!086QA
M=71A(&5D96QL:6YE;B!K>7-E;'D`5'5L;VMS970`4&%L86$@87-E='5K<VEI
M;@!686AV:7-T82!U=7-I('-A;&%S86YA`%)E=6YI;VX`4&%L875T82!A<V5T
M=6MS970`4FEC:"!497AT($5D:71O<FEN(&%S971U:W-E=`!!<G9O:71U:W-E
M=`!/:6ME80!/:6ME82!O='-A:V4`3VEK96$@87)V;W0`4FEV:5]N('1I961O
M="XN+@!2;V]L:0!2;VUA;FEA`$ODY&YNY"`Q.#``2^3D;F[D('9A<W1A<.1I
M=N3D;@!+Y.1N;N0@;7GV=.1PY&EVY.1N`%)I=FEN('1I961O=`!2:79I;B!T
M:65D;W0`4FEV:70Z`%9I:79O:71I;@!6:6EV;VET:6X@;N1K>7D@:V%I:VMI
M96X@<FEV:65N(&IA('-A<F%K:V5I9&5N(';D;&EL;.0`5FEI=F]I=&EN(&[D
M:WEY('9A:6X@<V%R86MK96ED96X@=N1L:6QLY`!6:6EV;VET:6X@;N1K>7D@
M=F%I;B!R:79I96X@=N1L:6QLY`!3=6]R:71A`%9E;N1JY&X@1F5D97)A=&EI
M=FEN96X@=&%S879A;'1A`%)U86YD80!3+TU)344@:W)Y<'1O9W)A869I;F5N
M(&%L;&5K:7)J;VET=7,`4R]-24U%('-A;&%T='4@=FEE<W1I`%-!4TPM875T
M96YT:6MO:6YT:2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`4TU3(%1E:W-T:79I
M97-T:70`4U%,+6MO;65N=&]T=6QK:VD`4U%,+6QA=7-E(&%R=F]J96X@:&%K
M96UI<V5E;@!34T@`3TY.25-454D`4U]13"UK;VUE;G1O='5L:VMI`&QA`%-A
M:6YT($AE;&5N80!386EN="!+:71T<R!J82!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@:F$@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!J82!'<F5N
M861I:6YI=`!386UA86X@:V5H>6MS965N("A?<V5L9BD`4V%M;V$`4V%N($UA
M<FEN;P!386\@5&]M92!J82!0<FEN8VEP90!3871E;&QI:71T:2!P86QV96QU
M;G1A<FIO86IA`%-A=61I82!!<F%B:6$`5&%L;&5T80!486QL971A("(E<R(`
M5&%L;&5T82`E<P!486QL971A(&%S971U:W-E=`!486QL971A(&QU;V1U="!A
M<V5T=6MS970@4$A0+7-K<FEP=&ENY"!P86QV96QI;65S:2!VY&QI86EK86ES
M:&%K96UI<W1O;VXN(`!486QL971E='1I:6X@)7,Z;B!A<V5T=6MS970N`$%S
M971U<W1E;B!PY&EV:71Y<W-K<FEP=&D@;VX@=&%L;&5T971T=2!P86EK:V%A
M;CH@(B5S(BX`2&%J86YA:7-I82!U:VMO<VUY<G-K>6KD`%1I961E`$AA:W4`
M2&%K=6MO;F5E=`!686QI='-E('1I961O<W1O=`!686QI='-E('#D:7;D;>3D
M<N0`5F%L:71S92!L:7/D='3D=N0@<GEH;>0`5F%L:71S92!U=7-I(&]M:7-T
M86IA`%9A;&ET<V4@<&%L=F5L:6X`5F%L:71S92!L:7/D='3D=N0@:^1Y='3D
M:N0`5F%L:71S92!K86EK:VD`5F%L:71S92!K86EK:VD@<.1I=N1MY.1RY&MO
M;7!O;F5N=&ET`%9A;&ET<V4@;V)J96MT:0!4>6AJ96YNY"!V86QI;G1A`%9A
M;&ET<V4@=&%R=FET=&%V870@;65R:VET(&%L;&$@;VQE=FES=&$@=F%L:6MO
M:7-T82X@5F]I="!S96X@:N1L:V5E;B!K;W!I;VED82!J82!L:6ET=.3D(&UE
M<FMI="!T96MS=&EI<VDN`%9A;&ET<V4@<.1I=N1Y:W-E;B!E<F]T:6YM97)K
M:VDZ`%9A;&ET<V4@<.1I=N1Y:W-E;B!E<VET>7-T87!A.@!686QI='-E(&UU
M=71E='1A=F$@<')O9FEI;&DZ`%9A;&ET<V4@:V5L;&]N86IA;B!E<F]T:6YM
M97)K:VDZ`%9A;&ET<V4@86IA;B!E<VET>7-T87!A.@!686QI='-E(&MA:W-I
M('EH=&5E;G-O<&EV86$@:V5N='3DY"X`5F%L:71S92!VY')I=&5E;6$N`%9A
M;&ET<V4@:^1Y=&5T=.1VY"!K:65L:3H`3.1H973D(&]N9V5L;6%V:65S=&D`
M3.1H973D(%--4P!396YE9V%L`%1U;FYI<W1I;CH@`'-Y>7-K=74`4V5R8FEA
M(&IA($UO;G1E;F5G<F\`4V%R:F%N=6UE<F\`4&%L=F5L:6UE;B!T:65D;W0@
M;W9A="!VY.1R:>0@=&%I(&5I=N1T(&]L92!KY'ET971TY'9I<W/D+@!)<W1U
M;G1O:F5N(&AA;&QI;G1A`%-E<W-I;VX@240@;VX@=F%N:&5N='5N=70N`$ES
M='5N;F]T`$%S971A`%-A;&%S86YA;B!R97-E=&]I;G1I:6X@;&EI='1Y=FGD
M(&%S971U:W-I82P@:F]S(&IO<VMU<R!U;F]H9&%T('-A;&%S86YA<VDN`%9O
M:70@87-E='1A82!U;&MO:7-T96X@<&%L=F5L:6UI96X@87-E='5K<V5T+"!J
M;VET82!H86QU870@:^1Y='3DY"!P;W)T86%L:7-S82X`5F]I="!A<V5T=&%A
M(&OD>71E='3D=N1N(&MI96QE;BP@86EK879Y]FAY:VME96X@:F$@;75I=&$@
M<.1I=N1MY.1RY&%S971U:W-I82X`5F]I="!A<V5T=&%A(&%L;VET=7-O:&IE
M;&UA;BP@=N1R:71E96UA;BP@;N1K>6WD;B!PY&EV:71Y:W-E;B!J82!M=6ET
M82!NY&MY;>3D;B!L:6ET='EV:>0@87-E='5K<VEA+@!!<V5N;G5S`$%S96YN
M=6MS96X@<.1I=FET>7-S:W)I<'1I(&]N('-A871A=FEL;&$`57-E870@<&%I
M:V%T('-O<&EV870@86YN971T=75N('!A<F%M971R:6EN.B``4V5Y8VAE;&QI
M=`!/<W1O:W-E=`!,>6AY="!K=79A=7,Z`$%S971E=&$@<&EK879A;&EN=&%N
MY'!PY&EM970@=7-E:6UM:6QL92!L:6YK96EL;&4N`$[D>73D`$[D>73D(&5R
M;V%V86ES=75D970@87-E='5K<VEE;B!T86QL971E='5S<V$@:F$@=75D97-S
M82!J=75R:2!M=6]K871U<W-A('9E<G-I;W-S82X`3N1Y=.0@961E;&QI<V5N
M('-I<^3D;FMI<FIA=71U;6ES96X@<.1I=N1Y<RX`3N1Y=.0@87-E='5S('!I
M=.3D:W-E<VD@86QK=7!E<N1I<V5N`$[D>73D('9A;&ET<VEN`$[D>73D('1A
M=6QU:VMO=&]I;6EN;F]T('9A;&EK:V\N`$[D>73D('9A<V5M;6%L;&$@)7,@
M=F%L:6MK;RX`3N1Y=.0@=&%U;'5K;VX@<V]L=6X@=&EE9&]T(&1I86QO9VD`
M3N1Y=.0@=&%U;'5K;VX@=&EE9&]T(&1I86QO9VD`3N1Y=.0@=&%U;'5K;VX@
M<FEV:6X@=&EE9&]T(&1I86QO9VD`3N1Y=.0@:W5V86X@=&EE9&]T(&1I86QO
M9VD`3N1Y=.0@='5O;G1I`%-A=&5I=&$`4V%T96ET82!A:6MA:7-I;@!3871E
M:71A(&UY]FAE;6UI;@!3871E:71A(&SD:&5T='EV:6QL80!0:65N96YNY`!0
M:65N96YNY"!T86D@<VEI<G+D('9I97)E:7-IY"!O<VEO:71A+"!J;W1T82!N
M92!E:7;D="!O;&4@=&EE;&SD`%-I97)R82!,96]N90!+:7)J875D=0!!;&QE
M:VER:F]I='5S`$%L;&5K:7)J;VET=6MS96X@86QG;W)I=&UI`%-I;F=A<&]R
M90!+;VMO`$]H:71A('EL;.1P:71O=&5H=.1VY'0`4VQO=F%K:6$`4VQO=F5N
M:6$`3'5M:0!,=6UI<V%D971T80!,=6UI<V%T96ET80!,=6UI<V%T96ET82!A
M:6MA:7-I;@!,=6UI<V%T96ET82!M>?9HY.1N`$QU;65N('-Y=GEY<SH@`$QU
M;65N(&WDY'+D('9E=&5NY#H@`%-A;&]M;VX@<V%A<F5T`%-O;6%L:6$`3&%U
M;'5T(&IA(%)U;F]U<P!*Y')J97-T>6MS96X@<W5U;FYA;B!V86QI;G1A`$SD
M:&1E;W-O:71E`$5T96SD+4%F<FEK:V$`171E;.0M175R;V]P<&$@*$E33RTX
M.#4Y+3,I`$5T96SD+4=E;W)G:6$@:F$@971E;.1I<V5T(%-A;F1W:6-H('-A
M87)E=`!%=&5LY&EN96X@<&%L;&]N<'5O;&ES:V\`5N1L:2!V:65R96ES970@
M<V]L=6IE;B!VY&QI<W/D`%;D;&D@<V]L=6X@;&5I<.1T96MS=&EN(&IA(')E
M=6YA;B!VY&QI<W/D(`!6Y&QI`%;D;&D`5N1L:2!J82!TY'ET90!%<W!A;FIA
M`%)O<VMA<&]S=&D`17)I:V]I<VUE<FMK:65N('-Y]G1T]@!*86$@<V]L=0!*
M86$@<V%R86ME`$IA82!R:79I`%5R:&5I;'4`4W)I($QA;FMA`%-T86YD87)D
M:0!3=&%R(%1R96L`06QK86UI<W9U;W-I`$SDY&YI('1A:2!A;'5E`%1I;&$`
M5&%L;&5N;G5S;75O=&\`2V%T=6]S;VET90!,Y'!I;'GV;G1I`$UE<FMK:6IO
M;F]L:7-T80!0;VES=&$@=&]I;6EA;'5E(&]S;VET=&5E<W1A`%1Y>6QI(%M#
M4U-=`'-U`$%L:6AA:V5M:7-T;V$@(B5S(B!E:2!L]GET>6YY="X`3W1S:6MK
M;P!,Y&AE=.0`3.1H971E='1I:6X@(B5S(CIN(&QI<^1Y<W!Y>6YT]BX@170@
M=F]I(&MI<FIA=71U82!S:7/DY&X@96YN96X@:W5I;B!P>7EN=/9S:2!O;B!K
MY'-I=&5L='D@:F$@:'EVY&MS>71T>2X`06QI:VER:F]I='5S`$]N;FES='5I
M`"(E<R(Z(&QI<^3D;6EN96X@:N1R:F5S=&5L;>3D;B!O;FYI<W1U:2X`2^1Y
M='3D:N1N("(E<R(@:^1Y='3D:N1T:65T;VIE;B!P;VES=&%M:6YE;B!JY')J
M97-T96QMY'-TY"!O;FYI<W1U:2X`(B5S(B!P;VES=&5T=&EI;B!O;FYI<W1U
M;F5E<W1I+@`B)7,B.B!O;FYI<W1U='1I:6X@<&]I<W1A;6%A;B!JY')J97-T
M96QMY'-TY"X`4&%L871T:6EN(&]N;FES='5N965S=&D@=F%N:&]I:&EN(&%S
M971U:W-I:6XN($QA=&%A('-I=G4@=75D97-T86%N(&[D:&3D:W-E<VD@;75U
M=&]K<V5T+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U<VMO<&EO
M+@!486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U<VMO<&EO("5S+@`G
M)7,G.B!PY&EV:71Y<R!O;FYI<W1U:2X`)7,Z;B!K:7)J;VET=&%M:6YE;B!O
M;FYI<W1U:2X`4W5D86X`66AT965N=F5T;P!!=7)I;F=O;FYO=7-U`$%U<FEN
M9V]N;&%S:W4`075R:6YK;VEN96X`075R:6YG;VYN;W5S=0!!=7)I;FMO(&YO
M=7-E92]L87-K964`075R:6YG;VYN;W5S=3H@`$%U<FEN9V]N;&%S:W4`075R
M:6YG;VYL87-K=3H@`%#DY&QL96MI<FIO:71U<P!4=6MI`%-U<FEN86T`4W5K
M=6YI;6D`2'5I<'!U=G5O<F5T(&IA($IA;B!-87EE;@!3=V%Z:6UA80!2=6]T
M<VD`4W9E:71S:0!3>6YC(&QO:VD@<&]I<W1E='1U`%-Y;F--3`!3>6YT86MS
M:79I<FAE(&AA:W5T97)M96ES<^0`4WEY<FEA+"!A<F%B:71A<V%V86QT80!5
M:VMO<VUY<G-K>0!5:VMO<VUY<G-K>6KD(&IA('1U=6QI<W1A`%5K:V]S;7ER
M<VMY=`!5:VMO<VUY<G-K>6KD(&%I:V%I<VEN`%135BUT:65D;W-T;P!4875L
M=6MK;P!4875L=6MO;B!T:65D;W0`5&%U;'5K;VX@87-E='5K<V5T`%1A=6QU
M:V]N('1I961O=`!486EW86X`5&%I=V%N+"!+:6EN86X@;6%A:W5N=&$`5&%D
M>FEK:7-T86X`5&%N>F%N:6$L(%EH9&ES='EN>70@=&%S879A;'1A`$MO:&1E
M.@!496ATY';D=`!0=6AE;&EN;G5M97)O`$SD;7#V=&EL82!E9&5L;&ES96QL
M92!T=6YN:6QL93H@`$SD;7#V=&EL80!,Y&UP]G1I;&$Z(`!,Y&UP]G1I;&$\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!-86QL:6$@(B5S(B!E:2!L
M]GET>6YY="X`36%L;&EE;B!H86QL:6YT80!496MS=&D`5F%I;B!T96MS=&D`
M5&5K<W1I;B!T87-A=7,`5&5K<W1I=&]P`'1O`%1H86D@*%1)4RTV,C`I`%1H
M86EM86$`1E10+6QI<^1T;VEM:6YT;R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`
M2&ES=&]R>2!JY')J97-T96QMY"!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X`2&]R
M9&4O2V]L86(@:6YT96=R;VEN=&EM;V]T=&]R:2!E:2!T=64@(B5S(@!)35-0
M(&QO:VEA(&5I('9O:71U(&%L=7-T86$N`$UA:6YT96YA;F-E.CH@+6QU;VMA
M;B!L871A86UI;F5N(&5PY&]N;FES='5I`$%S971U:W-E="!I:VMU;F$@;VX@
M<W5L:F5T='4N(%!O:7-T=71A86XN`%EL;.1P:61O;B!P:73DY"!O='1A82!K
MY'ET=/;V;B!P>7-Y=N0@=&%L;&5T=7-T>7EP<&D@4&5R;6ES<VEO;BP@:F]S
M(&AA;'5A="!KY'ET=.3D(&YI:73D+@!686EN(&%L87!U;VQI`$-O;G1A8W0@
M:60@;G5M97)O82!E:2!O;&4@;>3D<FET96QT>2P@;VX@='EH:N0@=&%I(&5I
M(&SV>71Y;GET('1I971O:V%N;F%S=&$N`%EH=&5Y<W1I961O="!L:7/D='1I
M:6X@;VYN:7-T=6YE97-T:2!O<V]I=&5K:7)J86%S:2X`5FEE<W1I;B!A;&QE
M:VER:F]I='5K<V5N('1A<FMI<W1A;6ES965N('1A<G9I=&%A;B!E<FEL;&EN
M96X@4$=0+6%L;&5K:7)J;VET=7-L;VAK;RX`2F%K96QU;&ES=&%N($E$(&5I
M(&]L;'5T(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY="!T
M:65T;VMA;FYA<W1A+@!*86ME;'5L:7-T86$@96D@;VQL=70@;>3D<FET96QT
M>2X`4V%L875S=&]I;6EN;F]N(&OD>71T]B!V86%T:2!S86QA='1U82!75U<M
M>6AT97ET=.0N`%1I961O<W1O<W-A("5S('!I=.1I<VD@;VQL82`E<R!A<V5T
M=7,N`%1I961O<W1O<W-A("5S('!I=.1I<VD@;VQL82!J;VET86MI;B`E<R!A
M<V5T=6MS:6$N`%1I961O<W1O82!E:2!V;VED82!K;W!I;VED82!I='-E;G/D
M('#DY&QL92X`5&EE9&]S=&\@;VQI('1Y:&KD+@!3975R86%V87-S82!O;B!O
M='-I:VMO=&EE9&]T('3D<W3D(&UE<W-A9V4O<F9C.#(R("UV:65S=&ES=.0N
M`$MO:V]R=75D=6X@;N1Y='3V=&EL82!A:6AE=71T86$@;VYG96QM:6$@:F]I
M;&QA:VEN($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;65N(&OD>71TY&II;&SD
M+B!686QI=&5T=&%V87-T:2!K>7-E:6YE;B!S96QA:6X@<VESY&QTY.0@<&EI
M<G1E:73D(&IA('9I<FAE:73D(&IO:6AI;B!E:2!O;&4@;/9Y='EN>70@:V]R
M:F%U<W1A('1A:2!K96EN;V$@:VEE<G3DY"!O;F=E;&UA+B!(=6]M86%T:&%N
M(&5T=.0@:F]S(&OD>73D="!TY'3D(&[D>71T]G1I;&%A(&IA($EN=&5R;F5T
M($5X<&QO<F5R('-E;&%I;G1A+"!N:6EN(&[D>71T]B!S86%T=&%A(&UE;F[D
M('-E:V%I<VEN+"!J;W1K=70@=&]I;6EN;F]T(&5I=N1T('1O:6UI('1A:2!S
M96QA:6X@<V%A='1A82!K86%T=6$N($IO<R!KY'ETY'0@5VEN9&]W<R`Y>"!T
M86D@344@=F5R<VEO=&$L(&YI:6X@;VX@;6%H9&]L;&ES=&$@971TY"!KY'ET
M=/9JY')J97-T96QMY"!K86%T=74@;G,N("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G("UV:7)H965S965N(&IA('-I;G5N('!I=.3D(&OD>6YN:7-TY.0@
M:V]N92!U=61E<W1A86XN7&Y<;B!-=6ES=&$@971TY"!S:6YU82!O;B!V87)O
M:71E='1U+B!.87!S875T82!/2RUN87!P=6QA82!J;W,@:&%L=6%T(&MO:V5I
M;&QE(&5D:71O<FEN(&MO:V]R=75T=2!NY'ET=/9T:6QA82X`4&]I<W1E='1I
M:6X@<')O9FEI;&D@(B5S(BX`5F%I;B!V87-E;B!P=6]L:0!';G501R!O:&IE
M;&UA;B!S:6IA:6YT:2!P:73DY"!MY.1R:71E;&SD($-R>7!T7W!G<#HZ("UL
M=6]K87-S82X`5FEE<W1I(&SD:&5T971T>2`E<R!V87-T86%N;W1T86IA;&QE
M("5S(&]T<VEK:V]N82`B)7,B(&]N(&[D>71E='1Y+@I%:2!O;&4@;6ETY.1N
M('1A:V5I=&$@<VEI=.0@971TY"!V:65S=&D@;VX@;'5E='1U('1A:2!Y;6WD
M<G)E='1Y+@!.:6UI(&IO=&$@:^1Y=&5TY.1N(&QI;FMI=&5T=.1E<W-A(&QU
M;R!S:79U;&QE`$ME;G1T:65N(&WDY'+D('!I=.3D(&%N=&%A(&YU;65R;VEN
M82X`36]D=75L:2!O<&5N<W-L('1A<G9I=&%A;B!(;W)D95]#<GEP=%]S;6EM
M93HZ("UL=6]K86X@:^1Y='3D;6ES96MS:2X`07-E='5S=&$@(B5S(B!K;W-K
M82!S96X@=&EE9&]T('EL:71T:7;D="!T86QL971U<W1A=F%N('-U=7)I;6UA
M;B!S86QL:71U;B!R86IA;@!/:&IE;&UA82P@:F]L;&$@=F]I(&MA='-O82!V
M:65S=&ET>7EP<&GD("@E<RDL(&5I(&SV>71Y;GET(&KD<FIE<W1E;&WD<W3D
M+@!,86EN875S;65R:VMI('!I=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI
M+@!686EN(&]I:V5A(&IA('9A<V5N('!U;VQI`%9A:6X@;VEK96$@<'5O;&D`
M17)O=&EN('!I=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+@!086QV96QI
M;B`B)7,B(&]N('!O:7-T971T=2X`4&%L=F5L:6X@(B5S(B!O;B!T86QL971E
M='1U+@!3:7/DY&YK:7)J875T=6UI<W!Y>6YT]B`E<R!O;B!P;VES=&5T='4N
M`$WDY')I=&5L='GD(')I=FGD("@E9"D@96D@;VQE(&]L96UA<W-A+@!686QI
MY&%I:V%I<W1I961O<W1O82`B)7,B(&5I(&]L92!O;&5M87-S82X`2VER:F]I
M='1A;6%S:2!T96MS=&D@96D@=F%S=&%A('1E:W-T:>0@<G5U9'5L;&$N`%9A
M:6X@>6SD<'5O;&D@:F$@86QA<'5O;&D`5F%I;B!Y;.1P=6]L:0!4=6]T=2!T
M:65T;R!HY'9I<VD@961E;&QI<V5N(&MO:&1A;B!A:6MA;F$N`%1U;W1U82!T
M:65D;W-T;V$@96D@=F]I='4@=&%L;&5T=&%A+@!/<VEO=&$@=V5A=&AE<BYC
M;VT@96D@;VQE(&OD>71E='3D=FES<^0N`%1E96UA:&%K96UI<W1O82`B)7,B
M(&5I(&SV>71Y;GET+@!!<V5T=6MS:6$@96D@;VQE('-A871A=FEL;&$N`$5I
M(&]L92!O<VEO:71A+"!J;W1K82!V;VED86%N(&[D>71TY.0@=FEE<W1I96X@
M>6AT97ED97-SY"X`5.1S<^0@:V5N=.1S<^0@;VX@;&EI86X@;6]N=&$@;65R
M:VMIY"X@06YN;VET("5S(&UE<FMK:>0[('-I;G5N('!I=.3D(&%N=&%A(';D
M:&5M;>1N(&MU:6X@)7,@;65R:VMIY"X`2F]I=&%K:6X@;VYG96QM:6$@(B5S
M(B!L:7/DY&UI<V5S<^0@:N1R:F5S=&5L;>3D;CH@)7,`2^1Y='3D:N1N("(E
M<R(@:^1Y='3D:N1T:65T;VIE;B!P;VES=&%M:7-E<W-A(&KD<FIE<W1E;&WD
M<W/D(&]L:2!O;F=E;&UI83H@`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@<&]I
M<W1A;6ES97-S82!JY')J97-T96QMY'-TY#H@`$IO:71A:VEN(&]N9V5L;6EA
M("(E<R(@<.1I=FET>6MS97-SY#H@)7,`5&EE9&]S=&]N('1U;VYN:7-S82!O
M;&D@;VYG96QM:6$N(%EH=.3D;B`E<SIA(&5I('1U;W1U`%1I961O<W1O;B!T
M=6]N;FES<V$@;VQI(&]N9V5L;6EA+B`E<R!K;VMO(&]L:2!S=75R96UP:2!K
M=6EN('-U=7)I;B!S86QL:71T=2!K;VMO("@E9"!T879U82DN`%1I961O<W1O
M;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA+B`E<R!L871A=71U:2!V86EN(&]S
M86MS:2X`5&%P86AT=6D@=FER:&4@;N1Y=&5T=.1E<W/D('9I97-T:6X@=.1T
MY"!O<VEO=&$`66AT97ES=&EE=&]J96X@='5O;FYI<W-A('1A<&%H='5I('9I
M<FAE+@!I0V%L96YD87(M=&EE=&]J96X@='5O;FYI<W-A('1A<&%H='5I('9I
M<FAE+@!!<V5T=7-T:65T;VQO;6%K:V5E<W-A(&]N(&IO:VEN('9I<FAE+B!%
M:&OD(&KD=&ET(&IO;FMU;B!P86MO;&QI<V5N(&MO:&1A;B!TY'ET=.1MY'1T
MY"X`5&%P86AT=6D@=FER:&4@>7)I=&5T=.1E<W/D('-U;W)I='1A82!O<V]I
M=&5K:7)J871O:6UI;G1O82X@67)I=.0@;7GV:&5M;6EN('5U9&5S=&%A;BX`
M66AT97ES=&EE=&]J96X@<.1I=FET>6MS97-SY"!T87!A:'1U:2!V:7)H92X@
M67)I=.0@;7GV:&5M;6EN('5U9&5S=&%A;BX`2F%K96QU;&ES=&%N('#D:79I
M='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E
M<W1A86XN`%3D;>0@24U!4"!P86QV96QI;B!E:2!T=64@:V%N<VEO:61E;B!J
M86MA;6ES=&$N`%3D;>0@=&EE9&]S=&\@96D@=F%I:W5T82!R87(M=&EE9&]S
M=&]L=&$N`%3D;>0@=&EE9&]S=&\@96D@=F%I:W5T82!Z:7`M=&EE9&]S=&]L
M=&$N`%3D;>0@96D@=F%I:W5T82!O:6ME86QT82!K;W)T=&EN=6UE<F]L=&$N
M`%3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!#;&EC:V%T
M96QL:6X@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2!P86QV96QU
M82!(5%10($%023IL;&$N`%3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V
M:65S=&5JY"!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y('!A;'9E
M;'5N(&MA=71T82!(5%10($%023IL;&$N`%3D;&SD(&%J=7)I;&QA('9O:2!L
MY&AE='3DY"!V:65S=&5JY"!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN
M8V]M*2!G871E=V%Y('!A;'9E;'5N(&MA=71T82!(5%10($%023IL;&$N`%3D
M;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!6;V1A9F]N96X@
M;G5M97)O:6AI;B!33510.FQLY"!KY'ET=.1E;B!6;V1A9F]N92!)=&%L>2!G
M871E=V%Y('!A;'9E;'5A+B!4Y'3D('!A;'9E;'5A('9O:2!KY'ET=.3D('9A
M:6X@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!T=6YN=6MS
M:6QL82X`5.1MY"!K96YT=.0@;VX@<&%K;VQL:6YE;BX`5.1S<^0@:V5N=.1S
M<^0@<&ETY.0@;VQL82!V86EN(&MO:V]N86ES;'5K=6IA+@!4Y'-SY"!K96YT
MY'-SY"!P:73DY"!O;&QA(&YU;65R;VET82!J82!P:6QK:W4M;65R:VME:N0N
M`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@;VMT86%L:6QU:W5J82X`5.1S
M<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!L:7-T82!K;VMO;F%I<VQU:W5J82P@
M:F]T:V$@<&ETY.0@;VQL82!E<F]T971T=2!P:6QK=6QL82!T86D@=N1L:6QY
M]FYN:6QLY`!!<G9O;B!P:73DY"!O;&QA(&YU;65R;RX`5.1S<^0@:V5N=.1S
M<^0@;VX@=N1R:6WDY')I='ES+"!J;VYK82!P:73DY"!O;&QA(%)'0B!(97@@
M;75O9&]S<RP@97-I;65R:VEK<VD@)R,Q,C,T868G+@!4Y&WD(&QO;6%K92!O
M;B!J;R!KY'-I=&5L='DN`%3D;>0@;VX@)7,N`%3D;>0@;VX@2V]L86(@1W)O
M=7!W87)E(&]B:F5K=&DN($MA='-O86MS97-I('3D;>1N(&]B:F5K=&EN('-I
M;G5L;&$@<&ETY.0@;VQL82!SY&AK]G!O<W1I;VAJ96QM82P@:F]K82!Y;6WD
M<G3DY"!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A='1I82X@3&ES=&$@>6AT965N
M<V]P:79I<W1A('/D:&OV<&]S=&EO:&IE;&UI<W1A(&SV>71Y>2!O<V]I='1E
M97-T82`E<P!4Y&WD('9I97-T:2!O;B!K:7)J;VET971T=2!E<FD@;65R:VES
M=/9L;.0@*"5S*2!K=6EN(&UI:^0@<VEN=6QL82!O;B!KY'ET]G-SY"X@`$YU
M;65R;VX@<&ETY.0@;VQL82!VY&AI;G3DY&X@>6MS:2X`5.1L;.0@<&%L=F5L
M:6UE;&QA(&5I('9O:2!A=6MA:7-T82!Z:7`M('1A:2!G>FEP+71I961O<W1O
M:F$N`%3D;>0@:N1R:F5S=&5L;>0@;VX@<&]I<R!PY.1L=.0N`$%R=F]N('!I
M=.3D(&]L;&$@;G5M97)O+@!4Y&WD;B!I:VMU;F%N('9O:2!A=6MA:7-T82!V
M86EN($%S971U:W-E="!I:VMU;F%S=&$`37ER<VMY`%1I:V5T:70`06EK80!!
M:F%N<V5U<F%N=&$`06IA;B!E<VET>7-M=6]T;P!!:F%N('9A;&EN=&$`5&EM
M;W(M3&5S=&4`5&ET=&5L:0!/='-I:VMO("AT;V]L=&EP*3H`5F%S=&%A;F]T
M=&%J80!6;VED86MS97-I('9A;&ET82!U<V5A;7!I82!V86EH=&]E:'1O:F$L
M('!I9.0@0V]N=')O;"T@*%!#*2!T86D@0V]M;6%N9"T@*$UA8RD@;N1P<.1I
M;G3D('!O:&IA<W-A(&MU;B!N87!S875T870@:&EI<F5N('!A:6YI:V5T=&$N
M`%3D;N3D;@!.Y'ETY"!(5$U,+6SD:&1E:V]O9&D`5&]G;P!4;VME;&%U`$AU
M;VUE;FYA`%1O;F=A`$QI:6%N(&UO;G1A(&5PY&]N;FES='5N=71T82!K:7)J
M875T=6UI<WER:71Y<W3D('9I:6UE:7-I;7!I96X@;6EN=75T=&EE;B!K=6QU
M97-S82X`66SV<P!9;&EM<.3D;B!K96AY:W-E96X@*%]T;W`I`$ODY&YN]FMS
M970`5')I;FED860@:F$@5&]B86=O`%1O<VD@=F%I(&5PY'1O<VD`=&D`5'5N
M:7-I80!4=7)K:VD`5'5R:VMI("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`
M5'5R:W,@:F$@0V%I8V]S('-A87)E=`!4=79A;'4`2VER:F]I=&$@=F%L:6YT
M87-I.B``52Y6+B`M:6YD96MS:3H@`%523`!54DP@:F]H;VX@<&%L875T971A
M86X@<VMR:7!T:6X@<W1A='5S(')A<&]R='1I`%523#H`56=A;F1A`%5K<F%I
M;F$`5D93+6AA:V5M:7-T;V$@96D@=F]I='4@;'5K96$N`$OD>71TY&KD;B!L
M:7/D=&EE=&]J96X@;&ESY'ES(&5I(&]N;FES='5N=70@:VER:F%U='5M:7-E
M<W-A+@!%:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE
M("(E<R(N`$5I('9O:2!V86EH=&%A(&]I:V5U:W-I82!61E,M=&EE9&]S=&]L
M;&4@)7,O)7,N`$5I('9O:61A('9A:6AT86$@)7,Z;BX`5&EE9&]S=&]N("(E
M<R(@:V]K;V$@96D@=F]I='4@=&%R:VES=&%A+@!%:2!V;VED82!N:6UE=.0@
M=75D96QL965N(%9&4RUT:65D;W-T;V$@(B5S+R5S(BX`4U%,+7!A;'9E;&EM
M965N(&5I('-A861A('EH=&5Y='3D+@!9:'1E>71TY"!E:2!V;VED82!M=6]D
M;W-T86$@4U-,+7-A;&%T='5N82X`5D93+71I961O<W1O82!E:2!V;VED82!K
M;W!I;VED82X`16D@=F]I9&$@;'5O9&$@5D93+6AA:V5M:7-T;V$@(B5S(BX`
M16D@=F]I9&$@;'5O9&$@5D93+6AA:V5M:7-T;V$N`$5I('9O:71U(&QU;V1A
M(%9&4RUT:65D;W-T;V$`16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M
M:V%N<VEO=&$@(B5S(BX`16D@=F]I='4@;'5O9&$@='EH:N3D(%9&4RUT:65D
M;W-T;V$N`%1I971O82!E:2!V;VED82!L86%J96YT86$N`$5I('9O:61A('!O
M:7-T86$@(B5S(BP@:&%K96UI<W1O(&5I(&]L92!T>6AJY"X`16D@=F]I9&$@
M<&]I<W1A82`B)7,B.B`E<RX`16D@=F]I9&$@<&]I<W1A82`E<RP@:&%K96UI
M<W1O(&5I(&]L92!T>6AJY"X`16D@=F]I9&$@<&]I<W1A82!61E,M:&%K96UI
M<W1O82!R96MU<G-I:79I<V5S=&DN`$5I('9O:61A('!O:7-T86$@5D93+6AA
M:V5M:7-T;V$N`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T;V$Z("5S
M+@!%:2!V;VED82!P;VES=&%A(%9&4RUT:65D;W-T;V$@(B5S(BX`16D@=F]I
M9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A+@!%:2!V;VED82!P;VES=&%A(%9&
M4RUK86YS:6]T82`B)7,B+@!%:2!V;VED82!P;VES=&%A(%9&4SKDY"!R96MU
M<G-I:79I<V5S=&DZ("5S+@!.>6MY:7-TY"!H86ME;6ES=&]A(&5I('9O:71U
M('-E;'9I='3DY"X`5F%R;65N=&5E;B!T:65T;VIA(&5I('9O:61A(&5X=')A
M:W1O:61A`$WDY')I='EK<V5N("5S(&QU:V5M:6YE;B!E<.1O;FYI<W1U:2X`
M16D@=F]I9&$@<VEI<G3DY"!61E,M=&EE9&]S=&]A+@!%:2!V;VED82!P;VES
M=&%A(%9&4RUT:65D;W-T;V$@(B5S(BX`16D@=F]I9&$@879A=&$@5D93+71I
M961O<W1O82!K:7)J;VET=7-T82!V87)T96XN`$5I('9O:61A(&%V871A(%9&
M4RUT:65D;W-T;V$N`%1I:79I<W1E='EN('1I961O<W1O;B!A=6MA:7-U(&5P
MY&]N;FES='5I+@!%:2!V;VET=2!L=6ME82!61E,M=&EE9&]S=&]A("AF:6QE
M<VEZ92@I(&5PY&]N;FES='5I*2X`16D@=F]I9&$@;'5K96$@5D93+71I961O
M<W1O82`H9V5T1FEL95-I>F4H*2!E<.1O;FYI<W1U:2DN`$5I('9O:71U(&QU
M:V5A('1I961O<W1O83H@`'9F<W)O;W0@:G5U<FEH86ME;6ES=&]A(&5I('9O
M:71U(&QU:V5A+@!5=61E;&QE96YN:6UEY&UI;F5N("5S("5S.FMS:2!E<.1O
M;FYI<W1U:2!K;W-K82!K;VAD96AA:V5M:7-T;R!O;B!J;R!O;&5M87-S80!%
M:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&4RUH86ME;6ES=&]A+@!%:2!V
M;VED82!N:6UE=.0@=75D96QL965N(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@
M=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A("(E<R(N`$5I
M('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`E<R\E<RX`
M16D@=F]I='4@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A+@!%:2!V
M;VED82!S=6]R:71T86$@:V]M96YT;V$@)VUK:7-O9G,G+@!7;W)D+61O:W5M
M96YT=&EA(&5I('9O:71U(&ODY&YTY.0`16D@=F]I9&$@:VER:F]I='1A82!6
M1E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I
M961O<W1O;VX@*&-O<'DH*2!E<.1O;FYI<W1U:2DN`$5I('9O:61A(&MI<FIO
M:71T86$@5D93+71I961O<W1O;B!T:65T;VIA+@!%:2!V;VED82!K:7)J;VET
M=&%A(%9&4RUT:65D;W-T;V$L(&MI:6YT:?8@;VX@=.1Y;F[D+@!!;&QE=FEI
M=F%T='4`4&5R=2!M=75T;VMS970`4&5R=75T=&%A(&5D96QL:7-E;B!T;VEM
M96YP:71E96X`5'5N=&5M871O;B!V87-T875S('!A;'9E;&EM96QT82!Y:'1E
M>71E96XZ`%1U;G1E;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$Z(`!,=6]K
M:71T96QE;6%T;VX`56YI8V]D92`H551&+3@I`%EH9&ES='EN965T(&%R86)I
M96UI<F%A=&ET`%EH9&ES='EN965T(&MU;FEN9V%S:W5N;F%T`%EH9'ES=F%L
M;&%T`%EH9'ES=F%L=&]J96X@5'EY;F5N;65R96X@97)I;&QI<W-A87)E=`!-
M:71T87EK<VEK]G0`5'5N=&5M871O;@!4=6YT96UA=&]N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%1U;G1E;6%T;VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`06YN971T=2!P86EK:V%T:65T;R!O;B!T=6YT96UA=&]N
M+@!4=6YT96UA=&]N(&OD>71TY&KD='5N;G5S('1A:2!S86QA<V%N82X`4&]I
M<W1A(&YY:WEI<V5N(&5L96UE;G1I;B!L:6YK:71Y<P!.:6UE=/9N`%1I971O
M='5R=F%S>6ES=.0@96DM<')I=FEL965G:7-E="!S:W)I<'1I="!E:7;D="!V
M;VD@:W5T<W5A($QE:6MK86$O2V]P:6]I+TQI:73D('1O:6UI;G1O:F$N($YA
M<'-A=71A($]++6YA<'!U;&%A(&[D:&3D:W-E<VD@;6]Z:6QL82YO<F<@<VEV
M=6EL;&$@;VQE=F%N(&]H:F5E;BP@:F]S<V$@;F5U=F]T86%N(&UI=&5N('-K
M<FEP=&ES:2!V;VEV870@:^1Y='3DY"!L96EK97#V>73DY"X`4&]I<W1A(';D
M<FD`16DM='5E='1U(&QA86IE;FYU<P!0Y&EV:73D`%#D:79I=.0@)7,`4.1I
M=FETY"!KY'ET=.1JY`!0Y&EV:71E='1I:6X@(B5S(BX`4.1I=FET>7-S:W)I
M<'1I('!O:7-T971T:6EN+@!4=6\`='5O(&MA:6MK:2!O:&IE;&UI96X@87-E
M;FYU<W1I961O<W1O="!P86QV96QI;65L;&4N`$ES;W0@;&%T:6YA;&%I<V5T
M(&MI<FIA:6UE=`!)<V]T(')O;VUA;&%I<V5T(&YU;65R;W0`57)U9W5A>0!+
MY'ETY"!N>6MY:7-TY#H@)7,`2^1Y=.0@4U-,+7-A;&%U<W1A`$OD>73D(&IO
M<R!T=6YN=7,O<V%L87-A;F$@;VX@97)I($E-4U`M<&%L=F5L:6UE;&QE+@!+
MY'ET=.1JY`!+Y'ET=.1JY&QLY"`E<R!E:2!O;&4@;VEK975K<VEA('1E:&3D
M("5S+@!+Y'ET=.1J:65N('EL;.1P:71O`$OD>71TY&KD;B!A<V5T=6MS970`
M2^1Y='3D:N1N(')E:VES=&5R]FEM:6YE;@!4Y'-SY"!JY')J97-T96QMY'-S
MY"!E:2!V;VD@<F5K:7-T97+V:63D(&OD>71TY&IIY"X`2^1Y='3D:N1T=6YN
M=7-T82!E:2!L]GET>6YY="X`2^1Y='3D:N1T=6YN=7,`2^1Y='3D:N1T=6YN
M=7,@(B5S(B!O;B!J;R!O;&5M87-S82X`2^1Y='3D:N1T=6YN=7,Z`$OD>71T
MY&KD='5N;G5S.B``2N1R:F5S=&5L;>1N(&OD>71TY&KD=#H`57IB96MI<W1A
M;@!61E,M:&%K96UI<W1O82!E:2!O;&4@;VQE;6%S<V$N`%!O:7-S86]L;W9I
M97-T:0!086EK:V]J82!L]GET>6D@97-I;65R:VEK<VDZ(`!6;VEM87-S86]L
M;V%I:V$`07)V;R!M:6YU=71E:7-S82!N>6MY:&5T:V5S=.0N`$%R=F\@;VX@
M>6QI('!I='5U9&5N(&UA:W-I;6EA<G9O;B`E<RX\`$%R=F]T`%9A;&ET=&%V
M870@87)V;W0`5F%N=6%T=0!686EH=&5L979A80!696YE>G5E;&$`5&%R:VES
M='5S(&5PY&]N;FES='5I("T@5.1TY"!V:65S=&GD(&]N('9O:71U(&OD<VET
M96QLY"X`5F5R<VEO`%9E<G-I;VYH86QL:6YT80!0>7-T>7-U;W)A('1A<V%U
M<P!0>7-T>7-U;W)A('3D>71E`%!Y<W1Y<W5O<F$Z`$5R:71TY&EN(&MO<FME
M80!6:65T;F%M`%9I971N86T@*%9)4T-)22D`3N1Y=.0@)7,`3N1Y=.0@97)I
M;&QI<V5NY"!W=W<M<VEV=6YA`$[D>73D("5S`$YE:71S>71S86%R970L($)R
M:71T:6SD:6YE;@!.96ET<WET<V%A<F5T+"!9:&1Y<W9A;'1A:6X`3N1K>7;D
M:7-Y>7,`3N1K>7;D:7-Y>7,Z(`!6;V1A9F]N92!)=&%L>2!33510.FX@879U
M;&QA`%9!4D])5%53`%9!4D])5%53(2$A(%!/25-402!32U))4%1)($OD4TE.
M(%!!3%9%3$E-14Q402`E<RX`5TE.($A45%`Z;B!A=G5L;&$`5V%L;&ES(&IA
M($9U='5N80!687)O:71U<P!K90!3Y.1E;FYU<W1E`%/DY'1I961O="!O;B!T
M;VEM:71T86YU=`!796%T:&5R+F-O;0!75U<`5U=7+7-I=G5S=&\`5FEI:V]I
M='1A:6X`5&5R=F5T=6QO80!497)V971U;&]A(&]H:F5L;6%A;B`E<P!497)V
M971U;&]A+"`E<P!,Y&YS:6UA:6YE;B`H25-/+3@X-3DM,2D`3.1N<VEM86EN
M96XO175R;R`H25-/+3@X-3DM,34I`$SD;G-I+5-A:&%R80!-:6YKY"!O:&IE
M;&UA;B`E<R!KY'EN;FES=.3D('-I<^3D;FMI<FIA=71U;6ES96X@:N1L:V5E
M;BX`36ETY"!M97)K:VGD(&OD>71E=.3D;B!E<F]T=&EM96YA/P!-:73D(&UE
M<FMK:>0@:^1Y=&5TY.1N(&QA:6YA=6MS965N/P!7:&5R96ES($%U<W1R86QI
M86X@:V%R='1A`$UI=&OD('9A:6AE970`5F]I="!MY.1R:71E;&SD(&QI<^1T
M;VEM:6YT;VIA(&QA:71E=&%A;B!PY.1L;&4@4FEC:"!497AT(&5D:71O<FES
M<V$N`$QE=F5Y<P!,979E>7,@0U-3(&UI='1A>6MS:6MK]FENY`!687-E;6UA
M;&QA(&]L979A;B`E<R!V86QI:V]N(&QE=F5Y<R`H='5L964@=F]I;6%A;B!S
M975R86%V86QL82!S:7/DY&YK:7)J875T=6UI<V5L;&$I.@!4875L=6MO;B!L
M979E>7,`3&5V97ED96X@>6MS:6MK]@!,979E>7,Z`%=I:VD`5'5U;&D`5'5U
M;&ES=&$@86EK86ES:6X`5'5U;&5N;F]P975S('-O;&UU:7-S80!4=75L:3H`
M5'5U;&DZ(`!6:6ES875S`%1O:79E;&ES=&%T`%1Y]@!/<V]I=&4@*'1Y]BD`
M4'5H96QI;B`H='GV*0!6Y.1RY"!MY.1RY"!K96YT=&GD(')I=FEL;.0@)60N
M($]D;W1E='1I:6X@)60L(&SV>71Y:2`E9"X`5N3D<N0@;>3D<N0@:V5N='1I
MY"X@3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+@!6Y.1RY"!P;VEK:V5A;6$@
M)60@;'5E='1A97-S82!61E,M=&EE9&]S=&]A+@!8+5)E9@!8-3`Y=C,@<&5R
M=7-R86IO:71T965T`%@U,#EV,R!L:7/D=&]I;6EN;F]T(&%V86EM96X@:^1Y
M=/9L;&4`6#4P.78S($MO:'1E96X@=F%I:'1O96AT;VEN96X@;FEM:0!8-3`Y
M=C,@2V]H=&5E;B!A=F%I;65N('1U;FYI<W1E`%@U,#EV,RUL86%J96YN=6MS
M970`5E8`5E965@!986AO;R$@:V%R='1A`%9U;W-I='1A:6X`2F5M96X`2WEL
M;.0`2WEL;.0L('-U;W-T=6XN`$OD>73D="!414M35$E424Q!02X@2^1Y=.0@
M6SP^72!N87!P=6QA82!V86EH=&%A:W-E<VD@=&%K86ES:6X@5UE325=91RUT
M:6QA86XN`$5T('9O:2!T96ADY"!E;F5M<.3D(&MU:6X@)60@;W-I;W1A+@!%
M="!O;&4@875T96YT:6MO:71U;G5T+@!.:6UE<W/D<VD@96D@<V%A(&]L;&$@
M)UPG+6UE<FMK:>0N`$5T(&%N=&%N=70@;VEK96%N(&UU;W1O:7-T82!SY&AK
M]G!O<W1I;W-O:71E='1A+@!%="!MY.1R:71E;&QY="!M:71KY"!T=6]D=6X@
M=&EE9&]S=&]N(&ME;G3D="!V87-T86%V870@;6ETY&MI;B!K96YT=&GD("5S
M.G-SY"X`3VQE="!K:7)J875T=6YU="!U;&]S+@!3:6YU;B!P:73DY"!A;G1A
M82!O:6ME82!M871K87!U:&5L:6YN=6UE<F\L('9A:6X@;G5M97)O:71A(&IA
M(&UA:&1O;&QI<V5S=&D@)RLG(&IO<R!KY'ETY'0@:V%N<V%I;G;D;&ES=.0@
M<'5H96QI;FYU;65R;VUU;W1O82X`4VEN=6X@=.1Y='EY(&%N=&%A(&]I:V5A
M(&%R=F\N`%-I;G5N('!I=.3D(&%S96YT86$@1&%T851R964M=&%U<W1A:N1R
M:F5S=&5L;>0@96YN96X@:W5I;B!V;VET(&OD>71TY.0@4VEG;G5P+71O:6UI
M;G1O:F$N`%-I;G5N('!I=.3D(&%S96YT86$@5D93+71A=7-T86KD<FIE<W1E
M;&WD+@!3:6YU;B!T=6QE92!K=79A:6QL82!O;F=E;&UA=&EL86YN971T82!E
M;FYE;B!K=6EN('9O:70@;.1H971TY.0@;VYG96QM879I97-T:6XN`%-I;G5N
M('!I=.3D(&%N=&%A(%523"!M:6AI;B!TY&WD(&QI;FMK:2!O<V]I='1A80!3
M:6YU;B!P:73DY"!V86QI=&$@<&]I<W1E='1A=F$@<&%L=F5L:6XN`%-I;G5N
M('!I=.3D(&%N=&%A('!O:7-T971T879A(&OD>71TY&KD='5N;G5S+@!3:6YU
M;B!P:73DY"!A;G1A82!P;VES=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN
M=6X@<&ETY.0@86YT86$@;&ESY'1TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU
M;B!P:73DY"!A;G1A82!PY&EV:71E='3D=N0@:^1Y='3D:N1T=6YN=7,N`%-I
M;G5N('!I=.3D('9A;&ET82!S=6]R:71E='1A=F$@=&]I;6EN=&\N`%-I;G5N
M('!I=.3D(&%N=&%A('5U9&5N(&MA=&5G;W)I86X@;FEM:2X`4VEN=6X@<&ET
MY.0@86YT86$@:71A;&EA;&%I;F5N('!U:&5L:6YN=6UE<F\`27-T=6YT;W-I
M("5S(&]N('9A;FAE;G1U;G5T+B!+:7)J875D=2!U=61E;&QE96X@<VESY.1N
M+@!3Y&AK]G!O<W1I;W-O:71T965S:0!3:6YU;B!LY&AE='3D:N1O<V]I='1E
M97-I.@!/;6%T('1I971O<VD`4VEN=6X@=&EE=&]K;VYE97-I(&OD>71TY&WD
M('1I971O=F5R:VMO+6]S;VET92!O;B!M=75T='5N=70@<V5N(&KD;&ME96X@
M:W5N(&]L970@86QO:71T86YU="`E<R!I<W1U;FYO;BX@5&EE=&]T=7)V87-Y
M:7-TY"!S:6YU;B!P:73DY"!K:7)J875T=6$@=75D97-T86%N(&KD<FIE<W1E
M;&WDY&XN`$YI;65S:0!+Y'ET=.1MY'-I(&%U=&AE;G1I8V%T:6]N('1A=7-T
M86KD<FIE<W1E;&WD(&5I('1U92!KY'ET=.1J:65N(&QI<^3D;6ES=.0N($IO
M<R!H86QU870@:&%L;&EN;F]I9&$@:^1Y='3D:N1T=6YN=6MS:6$L('-I;G5N
M('!I=.3D(&OD>71TY.0@:F]T86MI;B!T;VES=&$@875T:&5N=&EC871I;VX@
M=&%U<W1A:N1R:F5S=&5L;>3D+@!+Y'ET=.1MY'-I(&%U=&AE;G1I8V%T:6]N
M('1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!KY'ET=.1JY'1I971O:F5N(&[D
M>71TY&UI<W3D('1A:2!TY&WD('!I:7)R92!E:2!O;&4@:F]S=&%K:6X@<WEY
M<W3D(&OD>71E='3D=FES<^0N`%-I;G5N(&OD>71TY&WD<VD@=W=W+7-E;&%I
M;B!NY'ET=.3D(&]L979A;B!M=75T='5N=70@<V5N(&KD;&ME96X@:W5N(&]L
M970@86QO:71T86YU="`E<R!I<W1U;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S
M:6YU;B!P:73DY"!K:7)J875T=6$@=75D97-T86%N:N1R:F5S=&5L;>3D;BX`
M4V5L86EM97-I(&5I('1U92!TY'3D('1O:6UI;G1O82X`4V5L86EM97-I(&5I
M('1U92!T87)V:71T879A82!T=6QO<W1U<W1O:6UI;G1O82X@4&%I;F$@0V]N
M=')O;"]/<'1I;VX@*R!0('1U;&]S=&%A:W-E<VDN`$%I:V%V>?9H>6MK965S
M:3H`3VQE='5S<')O9FEI;&ES:2!O;B!M=75T971T=2X`3VQE='5S<')O9FEI
M;&ES:3H`3FEM97-I.@!)<W1U;G1O<VD@;VX@=F%N:&5N='5N=70N`%-I;G5N
M('-A;&%S86YA<VD@)7,Z;&QE(&]N.B`E<P!!<V5T=6MS97-I(&]N('#D:79I
M=&5T='D@:F$@;F4@;W9A="!V;VEM87-S82!TY&WD;B!I<W1U;FYO;B!A:F%N
M+@!!<V5T=6MS97-I(&]N('#D:79I=&5T='DN`%-A;&%S86YA<VD@;VX@;F]L
M;&%T='4`4V%L87-A;F%S:2!O;B!N;VQL871T=2P@=&%R:VES=&$@<^1H:_9P
M;W-T:7-I(&IA(&MI<FIA=61U('-I<^3D;B!U=61E;&QA('-A;&%S86YA;&QA
M<VDN`%-A;&%S86YA<VD@;VX@=F%N:&5N='5N=70N`$5TY'!A;'9E;&EM97-I
M.@!*=6=O<VQA=FEA`%IA:7)E`%-A;6)I80!::6UB86)W90!::7!P>0!;4&EI
M;&]T82!L86EN871T=2!T96MS=&E=`%M/;F=E;&UA70!;3N1Y=.0@;&%I;F%T
M='4@=&5K<W1I("T`6T[D>73D(&QA:6YA='1U('1E:W-T:2`M("5S(')I=FGD
M70!;<FEV:6QLY"`E<R\E<UT`7UEL;.1P:71O`%]+;VUE;G1O='5L:VMI`%]$
M871A5')E90!?4&]I<W1A(')I=FD`7U)Y:&WD=`!?3VAJ90!?2W5V86X@=&EE
M9&]T+BXN`%]+:7)J875D=2!S:7/DY&X`7TMI<FIA=61U('5L;W,`7TUU;VMK
M86$@;&EN:VMIY`!?07-E='5K<V5T`%]/:6ME=61E=`!0;VES=&$@;&EN:VMI
M+BXN`%]!<V5N;G5S`%]4875L=6MO;B!T:65D;W0N+BX`7TOD>71TY&KD=`!O
M<V]I=&5K:7)J80!V87-T86%N;W1T86IA('1U;G1E;6%T;VX`:V%L96YT97)I
M`'1Y>6YTY`!E:2!V;VD@;'5O9&$@='5L;W-T:65D;W-T;V$`96D@=F]I(&%U
M:V%I<W1A(&SD:&1E='3D`&YA<'-A=71A('3D<W3D`'9I<FAE(&MO;65N=&]R
M:79I;&SD`&%S971U<W9I<FAE`&MR:6ET=&EN96X@:N1R:F5S=&5L;>1T:65D
M;W-T;R!P=75T='5U`&UU;W1O=FER:&4@=&EE9&]I<W-A`&UU;VMK86$`=&EE
M='5E='1A(&5I(&SV>71Y;GET`&QA<VME=F$`=&EE9&]S=&\`<W5U;FYA<W1A
M("5S("@E<RD@;F]P975D96QL82`E<R`E<P!P=75S:VET=&%I;@!H.@!H:`!T
M=6YT96UA=&]N('!A;'9E;&EM96X@;FEM:0!VY&QI='3V;>1S=&D`:6YL:6YE
M`&EO+79I<FAE`&]H:F5L;6ES=&]N('-I<^1I;F5N('9I<FAE`')I=FET70!M
M:VES;V9S('9I<FAE:V]O9&D@)60@25-/.F$@=&5H9&5S<^0N`&UM`&YI;6D`
M96D@;VQE('1O=&5U=&5T='4`96D@;VQE('9I96SD('1O=&5U=&5T='4`;75I
M<W1I;&ES=&$`<')O<V5N='1I`&OD>71T]B!K:65L;&5T='D`<&EK<V5L96ET
MY`!E=.1V:7)H92!P<F]T;VMO;&QA<W-A`&YO=7-E=F$`<&%L=F5L=2!E:2!O
M;&4@:^1Y=&5T=.1V:7-SY`!NY'ETY"!E<F]T`'-M<S)E;6%I;"!(5%10.FX@
M879U;&QA`'-S`'9A:V%A`&KD<FIE<W1E;&WD=FER:&4`=&5H=.1VY&QI<W1A
M`';D;&EA:6MA:6YE;B!V:7)H90!V87)M:7-T86%K<V5S:2!K:7)J;VET82!S
M86QA<V%N82!K86AD97-T:0!U;FEF:65D`&YI;65T]FX`:^1Y='3D:N1N('9A
M;&EN=&$`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M9FE?1DDO:&5L<"YX;6P`````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`T,S,W`#$P-3$U-#,Q,#8Q`#`R,#,P,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/WAM;"!V97)S:6]N/2(Q
M+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]F:5]&22]H96QP+GAM
M;"QV(#$N,RXQ,"XS(#(P,#8O,#(O,C`@,3$Z,C`Z,3$@:F%N($5X<"`D("TM
M/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB(&UD-3TB-CAC83,S9C=F
M,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B('-T871E/2)U<'1O9&%T92(^"CQT
M:71L93Y0;W)T86%L:3PO=&ET;&4^"B`\<&%R83X*("!0;W)T86%L:7-S82!V
M;VET(&XF(WA%-#MH9"8C>$4T.R!P:6MA:7-E<W1I(&QY:'EE;B!Y:'1E96YV
M961O;B!T)B-X130[<FME)B-X130[:W-I"B`@;65R:VET<V5M:7-T)B-X130[
M(&%S:6]I<W1A+B!%<VEM97)K:6MS:2!V;VET(&XF(WA%-#MH9"8C>$4T.R!M
M;VYT86MO('5U='1A"B`@<R8C>$4T.VAK)B-X1C8[<&]S=&EV:65S=&DF(WA%
M-#L@<VEN=6QL92!O;B!T=6QL=70@24Y"3U@@:V%N<VEO;VXL('1U;&5V870*
M("!T87!A:'1U;6%T(&MA;&5N=&5R:7-S82P@=&5H="8C>$4T.W8F(WA%-#MT
M('1O+61O(&QI<W1A;&QA+"!O='-I:V]T"B`@=F%L:71S96UI<W1A<VD@=75T
M:7-P86QV96QU:7-T82!J;F4N($UO;F5T(&XF(WA%-#MI<W0F(WA%-#L@>6AT
M965N=F5D;VES=&$*("!S:7,F(WA%-#ML="8C>$4T.W8F(WA%-#MT(&QI;FMK
M96HF(WA%-#L@>6QE:7-I;7!I:6X@=&]I;6EN=&]I:&EN(&MU=&5N(&5S:6UE
M<FMI:W-I('9I97-T:6X*("!K:7)J;VET=7,L(&MA;&5N=&5R:6UE<FMI;FXF
M(WA%-#MN('1A:2!T96AT)B-X130[=B8C>$4T.VX@;&ES)B-X130[>7,@:FYE
M+@H@/"]P87)A/@H@/'!A<F$^"B`@4&]R=&%A;&EN('-I<R8C>$4T.VQT)B-X
M1C8[(&]N(&UU;VMA='1A=FES<V$@07-E='1E;'4@<&%I;FEK:V5E;B!K875T
M=&$N(%9O:70*("!E<VEM97)K:6MS:2!V86QI=&$@;6ET:R8C>$4T.R!A<VEA
M="!L:6ET970F(WA%-#LF(WA%-#MN('!O<G1A86QI:6X@:F$@;6ES<R8C>$4T
M.PH@(&HF(WA%-#MR:F5S='EK<V5S<R8C>$4T.R!N92!N)B-X130[>71E="8C
M>$4T.R8C>$4T.VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N
M879B87(B(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B
M('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y/:&IE;&UI96X@;F%V:6=O:6YT
M:79A;&EK:V\\+W1I=&QE/@H@/'!A<F$^"B`@5W=W+7-I=G5N('9A<V5M86QL
M82!L86ED86QL82!O;B!N879I9V]I;G1I=F%L:6MK;R!E<FD@;VAJ96QM:6EN
M+@H@($YA<'-A=71T86UA;&QA(&EK;VYE:71A(&YA=FEG;VEN=&EV86QI:V]S
M<V$@=F]I="!H96QP;W-T:2!J80H@(&YO<&5A<W1I('9A:6AT86$@;VAJ96QM
M87-T82!T;VES965N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&]?;6%I;G1E;F%N8V4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B
M865A.3$Y,C@X8C)D,#`B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
M07-E='5K<V5T.B!9;&PF(WA%-#MP:71O=&]I;65N<&ET965T.B!3=6]R:71A
M('EL;"8C>$4T.W!I=&]T;VEM970\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!*
M;W,@:&%L=6%T('-U;W)I='1A82!Y;&PF(WA%-#MP:71O=&]I;65N<&ET96ET
M)B-X130[('-I<R8C>$4T.R8C>$4T.VYK:7)J875T=6UI<V5N"B`@("!Y:'1E
M>61E<W,F(WA%-#LL(&YI:6X@87-E=&$@="8C>$4T.VTF(WA%-#L@=&]I;6EN
M=&\@<"8C>$4T.R8C>$4T.VQL92!V86QI;G1A<G5U9'5S=&$N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT
M96YA;F-E(B!M9#4](F$R,3$V,F-D9F8S8C%D.&9A96%D8C<R.38R-#`P,S9E
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%S971U:W-E=#H@66QL
M)B-X130[<&ET;W1O:6UE;G!I=&5E=#H@5F%R;6ES=&$@>6QL)B-X130[<&ET
M;W1O:6UE=#PO=&ET;&4^"B`@("`\<&%R83X*("`@($IO<R!H86QU870@=F%R
M;6ES=&%A(&MA:6MK:2!Y;&PF(WA%-#MP:71O=&]I;65N<&ET965T(&5N96YN
M:W5I;B!N90H@("`@<W5O<FET971A86XL(&YI:6X@87-E=&$@="8C>$4T.VTF
M(WA%-#L@=&]I;6EN=&\@<"8C>$4T.R8C>$4T.VQL90H@("`@=F%L:6YT87)U
M=61U<W1A+B!*;W,@=F%R;6ES='5S=&$@96D@;VQE('`F(WA%-#LF(WA%-#ML
M;"8C>$4T.RP@;FEI;B!K86EK:VD*("`@('EL;"8C>$4T.W!I=&]T;VEM96YP
M:71E970@<W5O<FET971A86X@875T;VUA871T:7-E<W1I(&IA(&YI:70F(WA%
M-#L@96D@=F]I"B`@("!P97)U82X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H
M96QP/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O971?144O````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8S,``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E=%]%12],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C$`,#(P-#$U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+V5T7T5%+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#0P,C(S,@`Q,#4Q-30S,3`V,0`P,C(P-3,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````"/!P``'```
M`)0\```?"@``#'D```````"(H0``#@```(FA```/````F*$```T```"HH0``
M"````+:A```+````OZ$```P```#+H0``!````-BA```8````W:$``!L```#V
MH0``+0```!*B```=````0*(``"0```!>H@``*0```(.B```9````K:(``"8`
M``#'H@``#````.ZB```D````^Z(```\````@HP``"P```#"C```.````/*,`
M``4```!+HP``*````%&C```(````>J,```H```"#HP``%0```(ZC```2````
MI*,```L```"WHP``A0```,.C```.````2:0```H```!8I```#0```&.D```.
M````<:0``!$```"`I```#0```)*D```,````H*0```T```"MI```!@```+ND
M``"4````PJ0```H```!7I0``#P```&*E```8````<J4```P```"+I0``#@``
M`)BE```.````IZ4```@```"VI0``"0```+^E```N````R:4``!H```#XI0``
M,@```!.F```X````1J8``%0```!_I@``40```-2F``!:````)J<``%<```"!
MIP``-````-FG```)````#J@```T````8J```!P```":H```*````+J@```\`
M```YJ```!0```$FH```&````3Z@``!$```!6J```"````&BH```)````<:@`
M``D```![J```)0```(6H```@````JZ@``!,```#,J```$````."H```/````
M\:@```H````!J0```P````RI```/````$*D``!0````@J0``"0```#6I```-
M````/ZD``!(```!-J0``&0```&"I```>````>JD```\```"9J0``"@```*FI
M```/````M*D```@```#$J0``)````,VI```4````\JD``!8````'J@``"```
M`!ZJ``!.````)ZH``"T```!VJ@``&0```*2J```'````OJH```P```#&J@``
M+````-.J```.`````*L```,````/JP``"P```!.K```'````'ZL```<````G
MJP``!0```"^K```%````-:L```H````[JP```P```$:K```7````2JL```H`
M``!BJP``#P```&VK```.````?:L``!@```",JP``(P```*6K```.````R:L`
M`!0```#8JP``%P```.VK```7````!:P``!<````=K```$P```#6L```/````
M2:P```X```!9K```'P```&BL```=````B*P```<```"FK```!@```*ZL```(
M````M:P```\```"^K```!@```,ZL```*````U:P``!,```#@K```"P```/2L
M```0`````*T``!4````1K0``%0```">M```'````/:T``!````!%K0``!0``
M`%:M```5````7*T``!$```!RK0``#````(2M```[````D:T``#@```#-K0``
M"0````:N```'````$*X``!0````8K@```P```"VN```%````,:X``!`````W
MK@``"0```$BN```3````4JX``#D```!FK@``$@```*"N```G````LZX``"P`
M``#;K@``*@````BO```E````,Z\```H```!9KP``!@```&2O```)````:Z\`
M``<```!UKP``+P```'VO```W````K:\``"X```#EKP``50```!2P```M````
M:K```"T```"8L```/0```,:P```_````!+$``"T```!$L0``0````'*Q```C
M````L[$``",```#7L0``0````/NQ```M````/+(``#,```!JL@``%0```)ZR
M```9````M+(``"D```#.L@``)````/BR```H````';,``!$```!&LP``"@``
M`%BS```,````8[,```H```!PLP``$````'NS```6````C+,``!8```"CLP``
M!P```+JS```'````PK,``!0```#*LP``"@```-^S```(````ZK,``"<```#S
MLP``"````!NT```'````)+0```<````LM```!@```#2T```%````.[0```<`
M``!!M```!@```$FT```(````4+0``"D```!9M```#@```(.T```*````DK0`
M``0```"=M```!P```**T```)````JK0```8```"TM```$0```+NT```'````
MS;0``!8```#5M```!````.RT```(````\;0```8```#ZM```#0````&U```&
M````#[4``!X````6M0``$0```#6U```(````1[4```T```!0M0``#````%ZU
M```'````:[4```,```!SM0```P```'>U```7````>[4``!,```"3M0``'0``
M`*>U```(````Q;4```0```#.M0``"````-.U```(````W+4``$$```#EM0``
M&@```">V```K````0K8``"````!NM@``%0```(^V```&````I;8```8```"L
MM@``%0```+.V```8````R;8``"(```#BM@``+@````6W```=````-+<``"$`
M``!2MP``5````'2W```I````R;<```H```#SMP``!P```/ZW```'````!K@`
M`!4````.N```#@```"2X```*````,[@```\````^N```#0```$ZX```/````
M7+@```T```!LN```"0```'JX```4````A+@```8```"9N```&````*"X```=
M````N;@``!,```#7N```$0```.NX```4````_;@```0````2N0``!@```!>Y
M```4````'KD``%0````SN0``9````(BY```$````[;D```X```#RN0``!0``
M``&Z```%````![H``!L````-N@``&@```"FZ```3````1+H``!$```!8N@``
M$0```&JZ```<````?+H``"H```"9N@``$````,2Z```A````U;H```4```#W
MN@``$P```/VZ```+````$;L``!(````=NP``"@```#"[```/````.[L```T`
M``!+NP``$0```%F[```3````:[L```P```!_NP``!@```(R[```,````D[L`
M``8```"@NP``%P```*>[```0````O[L``!$```#0NP``"````.*[```%````
MZ[L```P```#QNP``$````/Z[```%````#[P```T````5O```!@```".\```'
M````*KP```T````RO```!P```$"\```+````2+P```<```!4O```!P```%R\
M```)````9+P```D```!NO```"@```'B\```9````@[P``#T```"=O```'0``
M`-N\```,````^;P``!`````&O0``!0```!>]```E````';T``!(```!#O0``
M$P```%:]```K````:KT``#L```"6O0``(````-*]```(````\[T``#8```#\
MO0``$````#.^```(````1+X```P```!-O@``!@```%J^```$````8;X```\`
M``!FO@``#@```':^```'````A;X```H```"-O@``#0```)B^```>````IKX`
M`!L```#%O@``(0```.&^```>`````[\``!D````BOP``'@```#R_```=````
M6[\``!L```!YOP``(0```)6_```N````M[\``"8```#FOP``&P````W````>
M````*<```!P```!(P```)@```&7````K````C,```#,```"XP```)@```.S`
M```K````$\$``#@````_P0``'0```'C!```5````EL$``"\```"LP0``(```
M`-S!```2````_<$``"D````0P@``'@```#K"```@````6<(``!(```!ZP@``
MH@```(W"```6````,,,``",```!'PP``*````&O#```I````E,,``"@```"^
MPP``'P```.?#```5````!\0``"`````=Q```)0```#[$```H````9,0``"T`
M``"-Q```,````+O$``"2````[,0``"$```!_Q0``%@```*'%```<````N,4`
M`"8```#5Q0``*@```/S%``!!````)\8``$0```!IQ@``#````*[&```'````
MN\8```<```##Q@``!@```,O&```-````TL8``!````#@Q@``$@```/'&```3
M````!,<``!(````8QP``!P```"O'```$````,\<``!`````XQP``$````$G'
M```,````6L<```X```!GQP``#0```';'```/````A,<``!,```"4QP``#0``
M`*C'```H````ML<```,```#?QP``#0```./'```&````\<<``!$```#XQP``
M%P````K(```;````(L@```X````^R````@```$W(``!)````4,@```4```":
MR```$````*#(```/````L<@```0```#!R```#0```,;(```.````U,@```,`
M``#CR```#@```.?(```(````]L@```\```#_R```#P````_)```'````'\D`
M``T````GR0``$````#7)```-````1LD```L```!4R0``!@```&#)```+````
M9\D```P```!SR0``"@```(#)```1````B\D``!D```"=R0``"P```+?)```-
M````P\D``"(```#1R0``#P```/3)```;````!,H``#0````@R@``"@```%7*
M```8````8,H``!D```!YR@``%@```)/*```B````JLH```T```#-R@``!P``
M`-O*```4````X\H```L```#XR@``(@````3+```O````)\L```L```!7RP``
M"0```&/+```9````;<L```L```"'RP``%P```)/+```7````J\L```D```##
MRP``%@```,W+```/````Y,L``!D```#TRP``%@````[,```.````)<P``!@`
M```TS```"````$W,```-````5LP``"8```!DS```0P```(O,```(````S\P`
M`!(```#8S```'P```.O,```(````"\T```L````4S0``+P```"#-```.````
M4,T```4```!?S0``!@```&7-``!%````;,T```,```"RS0``!P```+;-```$
M````OLT```H```##S0``"@```,[-```/````V<T``!````#IS0``%P```/K-
M```1````$LX``!D````DS@``%P```#[.```)````5LX```4```!@S@``/0``
M`&;.```+````I,X```H```"PS@```@```+O.```%````OLX```T```#$S@``
M&P```-+.```7````[LX``!0````&SP``"0```!O/```.````)<\```T````T
MSP``$@```$+/```X````5<\``"````".SP``"````*_/```.````N,\``'L`
M``#'SP``&````$/0```8````7-```!$```!UT```!P```(?0```%````C]``
M`!@```"5T```'@```*[0```;````S=```!D```#IT```&P````/1```9````
M']$``!,````YT0``!P```$W1```(````5=$```8```!>T0``!@```&71```0
M````;-$```\```!]T0``$````(W1```/````GM$```L```"NT0``#P```+K1
M```,````RM$```\```#7T0``!P```.?1```&````[]$```X```#VT0``#```
M``72```H````$M(```\````[T@``"````$O2```(````5-(``!,```!=T@``
M'@```''2```A````D-(``"````"RT@``&0```-/2```7````[=(``"4````%
MTP``%P```"O3```6````0],```0```!:TP``&P```%_3```-````>],```P`
M``")TP```P```);3```%````FM,```@```"@TP``"@```*G3```,````M-,`
M``L```#!TP``$````,W3```,````WM,```X```#KTP``"P```/K3```$````
M!M0```0````+U```$P```!#4```4````)-0```P````YU```"0```$;4```.
M````4-0```L```!?U```&P```&O4```'````A]0```<```"/U```"@```)?4
M```-````HM0```D```"PU```!````+K4```%````O]0```,```#%U```&```
M`,G4```*````XM0```0```#MU```)@```/+4```.````&=4``'P````HU0``
M%0```*75```%````N]4```<```#!U0``#````,G5```(````UM4```H```#?
MU0``!@```.K5```(````\=4```(```#ZU0``!@```/W5```&````!-8``!0`
M```+U@``#0```"#6```0````+M8``!L````_U@``!````%O6```)````8-8`
M`!````!JU@``"0```'O6```)````A=8```4```"/U@``&@```)76```(````
ML-8```8```"YU@``&0```,#6```.````VM8```<```#IU@``!P```/'6```%
M````^=8```D```#_U@``"@````G7```.````%-<```(````CUP``!@```";7
M```+````+=<```T````YUP``"0```$?7```&````4=<``!(```!8UP``"0``
M`&O7```'````==<``!0```!]UP``'0```)+7``!"````L-<``"4```#SUP``
M)0```!G8```&````/]@```H```!&V```!````%'8```)````5M@```@```!@
MV```$0```&G8```)````>]@```8```"%V```#0```(S8```&````FM@```0`
M``"AV```.0```*;8```]````X-@``#H````>V0``'@```%G9```%````>-D`
M``X```!^V0``!````(W9```&````DMD```<```"9V0``(0```*'9```-````
MP]D``!4```#1V0``!@```.?9```$````[MD``!$```#SV0``!@````7:```*
M````#-H``"(````7V@``!````#K:```%````/]H``!T```!%V@``!````&/:
M```,````:-H```X```!UV@``"@```(3:```(````C]H```D```"8V@``!0``
M`*+:```Z````J-H``#````#CV@``-0```!3;```I````2ML``$<```!TVP``
M.````+S;```I````]=L``#\````?W```+@```%_<```M````CMP``!\```"\
MW```#P```-S<```2````[-P```L```#_W```)@````O=```I````,MT``"0`
M``!<W0``)@```('=```(````J-T```H```"QW0``"0```+S=```'````QMT`
M`"````#.W0``(````._=```F````$-X```H````WW@``&0```$+>```I````
M7-X``!8```"&W@``$@```)W>```'````L-X```H```"XW@``#````,/>```/
M````T-X``!````#@W@``0````/'>``!P````,M\``&8```"CWP``#@````K@
M```)````&>````H````CX```$@```"[@```3````0>````P```!5X```!@``
M`&+@```/````:>```!(```!YX```$````(S@```1````G>```!P```"OX```
M(P```,S@``!J````\.````\```!;X0``!0```&OA```0````<>$```D```""
MX0``!````(SA```+````D>$``"````"=X0``%````+[A```,````T^$```P`
M``#@X0``#P```.WA```5````_>$``"D````3X@``*@```#WB```F````:.(`
M`"<```"/X@``*0```+?B```J````X>(``!D````,XP``0@```";C```1````
M:>,``!(```![XP``$P```([C```4````HN,```\```"WXP``%@```,?C```7
M````WN,``!````#VXP``$0````?D```T````&>0``!,```!.Y```$@```&+D
M```U````=>0``!0```"KY```!P```,#D```,````R.0``"````#5Y```$```
M`/;D```4````!^4``!$````<Y0``%P```"[E```<````1N4``!,```!CY0``
M%````'?E```:````C.4``!$```"GY0``&@```+GE```>````U.4``!H```#S
MY0``$P````[F```5````(N8``!$````XY@``%P```$KF```4````8N8``!<`
M``!WY@``%0```(_F```)````I>8``!````"OY@``&0```,#F```$````VN8`
M``<```#?Y@``"P```.?F```1````\^8```8````%YP``!@````SG```&````
M$^<```4````:YP``!P```"#G```'````*.<```4````PYP``%@```#;G``!;
M````3><```8```"IYP``!@```+#G```$````M^<```0```"\YP``!P```,'G
M```.````R><```P```#8YP``#````.7G```-````\N<```H`````Z```#@``
M``OH```%````&N@``"@````@Z```#@```$GH```,````6.@```\```!EZ```
M"@```'7H```(````@.@```D```")Z```*P```)/H```$````O^@```@```#$
MZ```)@```,WH```2````].@```\````'Z0``!@```!?I```*````'ND```<`
M```IZ0``"````#'I```@````.ND```D```!;Z0``%````&7I```,````>ND`
M``T```"'Z0``#@```)7I```6````I.D``!$```"[Z0``!@```,WI```#````
MU.D```8```#8Z0``&0```-_I```'````^>D```0````!Z@``"P````;J```+
M````$NH```<````>Z@``!0```";J```'````+.H``!8````TZ@``#0```$OJ
M```-````6>H```H```!GZ@``$````'+J```/````@^H``!$```"3Z@``%P``
M`*7J```*````O>H``!$```#(Z@``"````-KJ```$````X^H```\```#HZ@``
M.@```/CJ```%````,^L```P````YZP``'@```$;K```.````9>L``!````!T
MZP``"P```(7K```,````D>L```D```">ZP``!P```*CK```*````L.L```D`
M``"[ZP``#@```,7K```0````U.L``!L```#EZP``&`````'L```:````&NP`
M``H````U[```"0```$#L```*````2NP```P```!5[```#P```&+L```(````
M<NP```8```![[```'````(+L```'````G^P```4```"G[```"P```*WL``!'
M````N>P```T````![0``"0````_M```$````&>T```,````>[0``$P```"+M
M```3````-NT``!,```!*[0``"@```%[M```"````:>T```0```!L[0``)0``
M`''M```#````E^T```4```";[0``*@```*'M```*````S.T```4```#7[0``
M!````-WM```*````XNT```T```#M[0``!@```/OM```(`````NX```@````+
M[@``!````!3N```%````&>X``&@````?[@``"0```(CN```,````DNX``!``
M``"?[@``!0```+#N```&````MNX``!L```"][@``+P```-GN```0````">\`
M``H````:[P``#P```"7O```*````->\```D```!`[P``$P```$KO```;````
M7N\``!@```!Z[P``%P```)/O```?````J^\```X```#+[P```P```-KO```'
M````WN\```@```#F[P``!P```._O```*````]^\```L````"\```!P````[P
M``!1````%O```!````!H\```#````'GP```-````AO```!H```"4\```2@``
M`*_P```9````^O````8````4\0``&@```!OQ```E````-O$```8```!<\0``
M!@```&/Q```?````:O$```8```"*\0``"0```)'Q```8````F_$``!<```"T
M\0``*````,SQ```&````]?$```T```#\\0``(@````KR``!7````+?(``!,`
M``"%\@``(P```)GR```3````O?(```(```#1\@``"P```-3R```(````X/(`
M``T```#I\@``"@```/?R```'`````O,``!0````*\P``!@```!_S```(````
M)O,```X````O\P``!P```#[S```*````1O,```L```!1\P``,@```%WS```'
M````D/,```P```"8\P``#0```*7S```7````L_,```P```#+\P``"0```-CS
M```)````XO,```H```#L\P``!P```/?S```)````__,```<````)]```"@``
M`!'T```;````'/0```\````X]```$@```$CT```*````6_0``!8```!F]```
M"0```'WT```0````A_0```<```"8]```$@```*#T```$````L_0```<```"X
M]```!0```,#T```%````QO0```L```#,]```%````-CT```1````[?0``!H`
M``#_]```%@```!KU```4````,?4``!<```!&]0``&````%[U```<````=_4`
M`!D```"4]0``!P```*[U```%````MO4```T```"\]0``#````,KU```1````
MU_4```@```#I]0``%P```/+U```+````"O8```P````6]@``'P```"/V```:
M````0_8``!,```!>]@``!````'+V```*````=_8```0```""]@``#0```(?V
M```,````E?8```4```"B]@``"0```*CV```%````LO8```<```"X]@``!0``
M`,#V```$````QO8```(```#+]@``.````,[V```L````!_<``!(````T]P``
M*0```$?W```R````<?<```H```"D]P``+````*_W```N````W/<``#,````+
M^```,P```#_X```X````<_@```\```"L^```&````+SX```0````U?@```\`
M``#F^```$P```/;X```5````"OD``!0````@^0``$@```#7Y```4````2/D`
M`!4```!=^0``+0```'/Y```M````H?D``#$```#/^0``+@````'Z```O````
M,/H``"P```!@^@``8@```(WZ```3````\/H```T````$^P``"````!+[```7
M````&_L```@````S^P``#````#S[```K````2?L``"$```!U^P``&@```)?[
M```)````LOL``$4```"\^P``00````+\```$````1/P``!,```!)_```%```
M`%W\```.````<OP``!,```"!_```&````)7\```&````KOP```D```"U_```
M"@```+_\```/````ROP``!````#:_```!P```.O\```.````\_P```4````"
M_0``&P````C]```(````)/T```8````M_0``%````#3]```1````2?T```X`
M``!;_0``.````&K]```"````H_T```8```"F_0``#@```*W]```%````O/T`
M``<```#"_0``#@```,K]```&````V?T``"@```#@_0``#`````G^```<````
M%OX```0````S_@``*0```#C^```7````8OX``!\```!Z_@``7````)K^```4
M````]_X``#X````,_P``'P```$O_```0````:_\```<```!\_P``#@```(3_
M```,````D_\```P```"@_P``$P```*W_```*````P?\``!T```#,_P``&0``
M`.K_```%````!``!`!$````*``$`$0```!P``0`D````+@`!`!(```!3``$`
M%0```&8``0`2````?``!``X```"/``$`&0```)X``0`(````N``!``D```#!
M``$`#0```,L``0`'````V0`!``H```#A``$`!P```.P``0`/````]``!``8`
M```$`0$`"P````L!`0`:````%P$!``H````R`0$`!P```#T!`0`(````10$!
M``4```!.`0$`'P```%0!`0`&````=`$!`!````![`0$`"````(P!`0`-````
ME0$!``@```"C`0$`'@```*P!`0`2````RP$!`"P```#>`0$`&@````L"`0`)
M````)@(!``H````P`@$`%0```#L"`0`%````40(!`!0```!7`@$`!````&P"
M`0`0````<0(!``8```""`@$`!P```(D"`0`>````D0(!`"@```"P`@$`"@``
M`-D"`0`<````Y`(!`!$````!`P$`"P```!,#`0`:````'P,!`!0````Z`P$`
M!````$\#`0`$````5`,!``L```!9`P$`!0```&4#`0`&````:P,!``@```!R
M`P$`!@```'L#`0`*````@@,!`!L```"-`P$`-````*D#`0`T````W@,!`"``
M```3!`$`*0```#0$`0`@````7@0!`$$```!_!`$`&@```,$$`0`H````W`0!
M`"D````%!0$`4````"\%`0`B````@`4!``8```"C!0$`"````*H%`0`%````
MLP4!``@```"Y!0$`&0```,(%`0`9````W`4!`"H```#V!0$`(P```"$&`0`9
M````108!`"X```!?!@$`-````(X&`0`(````PP8!`!<```#,!@$`"@```.0&
M`0`'````[P8!`"$```#W!@$`$````!D'`0`.````*@<!``L````Y!P$`!P``
M`$4'`0`3````30<!``@```!A!P$`"P```&H'`0`*````=@<!`!0```"!!P$`
M#P```)8'`0`R````I@<!``L```#9!P$`#@```.4'`0`%````]`<!``4```#Z
M!P$`!0`````(`0`7````!@@!``\````>"`$`!````"X(`0`*````,P@!``D`
M```^"`$`"P```$@(`0`-````5`@!``P```!B"`$`#@```&\(`0`%````?@@!
M``0```"$"`$`#0```(D(`0`R````EP@!`$4```#*"`$`%P```!`)`0`'````
M*`D!`!X````P"0$`%````$\)`0`%````9`D!`!0```!J"0$`!@```'\)`0`'
M````A@D!``X```"."0$`*@```)T)`0`&````R`D!``P```#/"0$`#0```-P)
M`0`1````Z@D!``L```#\"0$`-@````@*`0`*````/PH!`"(```!*"@$`"P``
M`&T*`0`/````>0H!`#(```")"@$`)0```+P*`0`P````X@H!`#$````3"P$`
M+0```$4+`0`.````<PL!``4```"""P$`#@```(@+`0`3````EPL!`!(```"K
M"P$`!P```+X+`0`1````Q@L!`!,```#8"P$`!P```.P+`0`4````]`L!`!@`
M```)#`$`!P```"(,`0`%````*@P!``P````P#`$`#````#T,`0`2````2@P!
M``0```!=#`$`!P```&(,`0`*````:@P!``L```!U#`$`#````($,`0`.````
MC@P!``X```"=#`$`!0```*P,`0`%````L@P!`"X```"X#`$`)@```.<,`0`C
M````#@T!``,````R#0$`$@```#8-`0`&````20T!`!X```!0#0$`&````&\-
M`0`E````B`T!``T```"N#0$`"0```+P-`0`?````Q@T!``,```#F#0$`!P``
M`.H-`0`*````\@T!``(```#]#0$`#``````.`0`5````#0X!``L````C#@$`
M&0```"\.`0`@````20X!`!(```!J#@$`!0```'T.`0`*````@PX!`!4```".
M#@$`$@```*0.`0`,````MPX!``0```#$#@$`"0```,D.`0`'````TPX!``P`
M``#;#@$`4@```.@.`0`7````.P\!`"0```!3#P$`$@```'@/`0`'````BP\!
M``8```"3#P$`#@```)H/`0`,````J0\!``T```"V#P$`%0```,0/`0`2````
MV@\!``\```#M#P$`%````/T/`0`*````$A`!`!L````=$`$`$````#D0`0`+
M````2A`!`&D```!6$`$`&@```,`0`0`7````VQ`!`"<```#S$`$`&@```!L1
M`0`7````-A$!`!L```!.$0$`&0```&H1`0`?````A!$!`!,```"D$0$`"```
M`+@1`0`'````P1$!``@```#)$0$`"0```-(1`0`5````W!$!``T```#R$0$`
M(P`````2`0`-````)!(!`!,````R$@$`"````$82`0`#````3Q(!`$8```!3
M$@$`/P```)H2`0`W````VA(!`%<````2$P$`!0```&H3`0`?````<!,!`"\`
M``"0$P$`"@```,`3`0`(````RQ,!``T```#4$P$`+0```.(3`0`$````$!0!
M`$\````5%`$`)0```&44`0`<````BQ0!``L```"H%`$`'P```+04`0`=````
MU!0!`"4```#R%`$`(````!@5`0`D````.14!`"````!>%0$`"P```'\5`0`'
M````BQ4!``T```"3%0$`#````*$5`0`7````KA4!``8```#&%0$`.0```,T5
M`0`,````!Q8!``<````4%@$`"0```!P6`0`3````)A8!``D````Z%@$`!```
M`$06`0`0````218!``@```!:%@$`"````&,6`0`$````;!8!``L```!Q%@$`
M#````'T6`0`2````BA8!`!$```"=%@$`#````*\6`0`:````O!8!``\```#7
M%@$`!P```.<6`0`-````[Q8!`!0```#]%@$`#@```!(7`0`,````(1<!`!L`
M```N%P$`+````$H7`0`3````=Q<!`!P```"+%P$`*````*@7`0`&````T1<!
M``<```#8%P$`$P```.`7`0`%````]!<!``0```#Z%P$`%P```/\7`0`*````
M%Q@!``P````B&`$`"0```"\8`0`&````.1@!``D```!`&`$`"````$H8`0`)
M````4Q@!``H```!=&`$`$0```&@8`0`&````>A@!``X```"!&`$`#@```)`8
M`0`-````GQ@!``L```"M&`$`'0```+D8`0`+````UQ@!``(```#C&`$`'```
M`.88`0`'`````QD!``8````+&0$`90```!(9`0`)````>!D!``<```""&0$`
M)@```(H9`0`X````L1D!`!H```#J&0$`*@````4:`0`[````,!H!`"@```!L
M&@$`-````)4:`0`9````RAH!`!4```#D&@$`!0```/H:`0`'`````!L!``@`
M```(&P$`!P```!$;`0`%````&1L!``<````?&P$`#@```"<;`0`)````-AL!
M``8```!`&P$`"````$<;`0`+````4!L!``<```!<&P$`"````&0;`0`'````
M;1L!`!8```!U&P$`"0```(P;`0`&````EAL!``L```"=&P$`$````*D;`0`&
M````NAL!`!P```#!&P$`%````-X;`0`'````\QL!`!$```#[&P$`"`````T<
M`0`.````%AP!``@````E'`$`!0```"X<`0`0````-!P!``D```!%'`$`$```
M`$\<`0`&````8!P!`!D```!G'`$`"@```($<`0`<````C!P!``<```"I'`$`
M!0```+$<`0`0````MQP!`!0```#('`$`"P```-T<`0`-````Z1P!`"@```#W
M'`$`&````"`=`0`7````.1T!``0```!1'0$`"0```%8=`0`*````8!T!``<`
M``!K'0$``@```',=`0`.````=AT!``@```"%'0$`'P```(X=`0`C````KAT!
M`!\```#2'0$`.````/(=`0`F````*QX!`#$```!2'@$`)P```(0>`0!D````
MK!X!`!0````1'P$`50```"8?`0`X````?!\!`$H```"U'P$`6P`````@`0`H
M````7"`!`#@```"%(`$`*````+X@`0`L````YR`!`"<````4(0$`&P```#PA
M`0`^````6"$!`*D!``"7(0$`(P```$$C`0`7````92,!`$@```!](P$`A0``
M`,8C`0`P````3"0!`"4```!])`$`00```*,D`0!;````Y20!`$D```!!)0$`
M,0```(LE`0`=````O24!`!@```#;)0$`*P```/0E`0`A````("8!`!\```!"
M)@$`*P```&(F`0`F````CB8!`"$```"U)@$`)P```-<F`0`Z````_R8!`!T`
M```Z)P$`$0```%@G`0`S````:B<!`"4```">)P$`)P```,0G`0`@````["<!
M`!\````-*`$`,````"TH`0!I````7B@!`#$```#(*`$`00```/HH`0`S````
M/"D!`"4```!P*0$`/0```)8I`0!E````U"D!`$T````Z*@$`+P```(@J`0`N
M````N"H!`#````#G*@$`5````!@K`0!:````;2L!`$@```#(*P$`2@```!$L
M`0`R````7"P!`"\```"/+`$`+````+\L`0`M````["P!`'$````:+0$`9@``
M`(PM`0!O````\RT!`+,```!C+@$`%P```!<O`0`E````+R\!`#(```!5+P$`
M*0```(@O`0`^````LB\!`"(```#Q+P$`4@```!0P`0`E````9S`!``L```"-
M,`$`L0```)DP`0!%````2S$!`"$```"1,0$`,````+,Q`0`E````Y#$!`!P`
M```*,@$`,0```"<R`0`'````63(!``<```!A,@$`!````&DR`0`-````;C(!
M``L```!\,@$`#@```(@R`0`+````ES(!``4```"C,@$`$````*DR`0`"````
MNC(!`%D```"],@$`!0```!<S`0`2````'3,!``0````P,P$`!P```#4S`0`(
M````/3,!``4```!&,P$`,````$PS`0`#````?3,!`!````"!,P$`#````)(S
M`0`3````GS,!``T```"S,P$``@```,$S`0`'````Q#,!``8```#,,P$`%```
M`-,S`0`,````Z#,!`!@```#U,P$`!@````XT`0`2````%30!``P````H-`$`
M`P```#4T`0`J````.30!``0```!D-`$`!@```&DT`0`'````<#0!`!\```!X
M-`$`-0```)@T`0`N````SC0!`"\```#]-`$`%P```"TU`0`B````134!`"4`
M``!H-0$`(````(XU`0`;````KS4!`!@```#+-0$`)````.0U`0`?````"38!
M`!H````I-@$`(0```$0V`0`@````9C8!`!H```"'-@$`,@```*(V`0`:````
MU38!`"\```#P-@$`*P```"`W`0`?````3#<!`",```!L-P$`'P```)`W`0`:
M````L#<!`"$```#+-P$`)0```.TW`0`F````$S@!`"4````Z.`$`)````&`X
M`0`8````A3@!`!T```">.`$`)````+PX`0`8````X3@!`"(```#Z.`$`+```
M`!TY`0`O````2CD!`!4```!Z.0$`)0```)`Y`0`\````MCD!`!\```#S.0$`
M(P```!,Z`0`?````-SH!`"````!7.@$`&@```'@Z`0`8````DSH!`"8```"L
M.@$`'@```-,Z`0`I````\CH!`!X````<.P$`,0```#L[`0`)````;3L!``P`
M``!W.P$`%P```(0[`0`O````G#L!`"0```#,.P$`!P```/$[`0`/````^3L!
M`!0````)/`$`#@```!X\`0`-````+3P!`"0````[/`$`!0```&`\`0`'````
M9CP!`"(```!N/`$`)0```)$\`0`:````MSP!`!T```#2/`$`&@```/`\`0`'
M````"ST!`,<````3/0$`"P```-L]`0`5````YST!``8```#]/0$`"0````0^
M`0`+````#CX!``T````:/@$`%P```"@^`0`&````0#X!`#,```!'/@$`$P``
M`'L^`0`3````CSX!``<```"C/@$`#P```*L^`0`'````NSX!`#(```##/@$`
M!````/8^`0`A````^SX!`!,````=/P$`#````#$_`0`1````/C\!`#(```!0
M/P$`%@```(,_`0`(````FC\!`!T```"C/P$`"0```,$_`0`*````RS\!`!0`
M``#6/P$`"@```.L_`0`=````]C\!``@````40`$`'P```!U``0`(````/4`!
M`!H```!&0`$`)P```&%``0`&````B4`!`!4```"00`$`!P```*9``0`(````
MKD`!``D```"W0`$`/P```,%``0`'`````4$!``\````)00$`#@```!E!`0`0
M````*$$!``D````Y00$`"0```$-!`0`(````34$!`!,```!600$`!P```&I!
M`0`9````<D$!``H```",00$`%P```)=!`0`4````KT$!``H```#$00$`#```
M`,]!`0`7````W$$!``0```#T00$`*@```/E!`0`,````)$(!`!$````Q0@$`
M!P```$-"`0`"````2T(!`!````!.0@$`&````%]"`0`+````>$(!``,```"$
M0@$`"````(A"`0`&````D4(!``<```"80@$`#0```*!"`0`+````KD(!`!0`
M``"Z0@$`%0```,]"`0`.````Y4(!`"\```#T0@$`(````"1#`0`<````14,!
M`!4```!B0P$`#````'A#`0`Q````A4,!``4```"W0P$`$@```+U#`0`_````
MT$,!`!(````01`$`"@```"-$`0`&````+D0!``0````U1`$`!````#I$`0`*
M````/T0!`!,```!*1`$`!0```%Y$`0`&````9$0!``8```!K1`$`"````')$
M`0`$````>T0!``P```"`1`$`"@```(U$`0`Y````F$0!`"X```#21`$`*0``
M``%%`0`%````*T4!`!@````Q10$`&0```$I%`0`?````9$4!`!T```"$10$`
M$0```*)%`0`"````M$4!``0```"W10$`"@```+Q%`0`&````QT4!``4```#.
M10$``P```-1%`0`,````V$4!`$4```#E10$`,@```"M&`0`:````7D8!`#4`
M``!Y1@$`*````*]&`0!3````V$8!`!D````L1P$`<@```$9'`0`@````N4<!
M`#4```#:1P$`(0```!!(`0!%````,D@!`#````!X2`$`*````*E(`0`I````
MTD@!`"8```#\2`$`)0```"-)`0`H````24D!`"@```!R20$`(@```)M)`0`K
M````ODD!`#````#J20$`$@```!M*`0`3````+DH!`!````!"2@$`>0```%-*
M`0`)````S4H!`*$```#72@$`<P```'E+`0!\````[4L!`"L```!J3`$`5```
M`)9,`0`7````ZTP!`"<````#30$`%@```"M-`0`/````0DT!`!<```!230$`
M'P```&I-`0!`````BDT!`!\```#+30$`'````.M-`0!1````"$X!`!H```!:
M3@$`%````'5.`0`*````BDX!``4```"53@$`!@```)M.`0`(````HDX!``4`
M``"K3@$`$@```+%.`0`0````Q$X!`!,```#53@$`'0```.E.`0`/````!T\!
M``\````73P$`!````"=/`0`)````+$\!``L````V3P$`!P```$)/`0`%````
M2D\!`!0```!03P$`!P```&5/`0`(````;4\!``\```!V3P$`"````(9/`0`,
M````CT\!``\```"<3P$`!@```*Q/`0`4````LT\!``8```#(3P$`#````,]/
M`0`1````W$\!``@```#N3P$`!````/=/`0`9````_$\!`!$````64`$`"@``
M`"A0`0`8````,U`!`!,```!,4`$`'````&!0`0`1````?5`!``0```"/4`$`
M#P```)10`0`'````I%`!``0```"L4`$`&0```+%0`0`'````RU`!``(```#3
M4`$``@```-90`0`1````V5`!``D```#K4`$`!@```/50`0`2````_%`!`!<`
M```/40$`!@```"=1`0`G````+E$!``(```!640$`!````%E1`0`/````7E$!
M`!,```!N40$`!P```()1`0`'````BE$!`!$```"240$`!@```*11`0`8````
MJU$!``8```#$40$`$P```,M1`0`0````WU$!`!(```#P40$``@````-2`0`&
M````!E(!`!4````-4@$`#````"-2`0`)````,%(!`!$````Z4@$`"0```$Q2
M`0`B````5E(!``<```!Y4@$`!P```(%2`0`+````B5(!``4```"54@$``@``
M`)M2`0`+````GE(!`%P!``"J4@$`$@````=4`0`/````&E0!`!(````J5`$`
M!P```#U4`0`(````150!``<```!.5`$`"P```%94`0`5````8E0!`!L```!X
M5`$`*````)14`0`<````O50!`!X```#:5`$`'0```/E4`0`3````%U4!`"D`
M```K50$`"P```%55`0`B````854!`!$```"$50$`#P```)95`0`,````IE4!
M``4```"S50$`&0```+E5`0`,````TU4!`!,```#@50$`%````/15`0`2````
M"58!`!(````<5@$`6@```"]6`0`1````BE8!``H```"<5@$`#0```*=6`0`0
M````M58!`!H```#&5@$`%````.%6`0`3````]E8!`!4````*5P$`!@```"!7
M`0";````)U<!``T```##5P$`$@```-%7`0`6````Y%<!``H```#[5P$`$0``
M``98`0`1````&%@!``@````J6`$`"````#-8`0`@````/%@!`!,```!=6`$`
M,0```'%8`0`T````HU@!`%@```#86`$`4P```#%9`0!>````A5D!`%D```#D
M60$`,P```#Y:`0`*````<EH!``T```!]6@$`!P```(M:`0`*````DUH!`!$`
M``">6@$`!0```+!:`0`&````MEH!`!(```"]6@$`!P```-!:`0`)````V%H!
M``D```#B6@$`*P```.Q:`0`H````&%L!``H```!!6P$`#@```$Q;`0`1````
M6UL!``\```!M6P$`!````'U;`0`.````@EL!``X```"16P$`"@```*!;`0`.
M````JUL!``X```"Z6P$`%````,E;`0`4````WEL!`!(```#S6P$`"@````9<
M`0`1````$5P!``D````C7`$`'P```"U<`0`8````35P!`!P```!F7`$`#0``
M`(-<`0!/````D5P!`"T```#A7`$`(0````]=`0`'````,5T!``X````Y70$`
M)P```$A=`0`&````<%T!``<```!W70$`"@```']=`0`(````BET!``@```"3
M70$`!0```)Q=`0`'````HET!``@```"J70$`!````+-=`0`;````N%T!``L`
M``#470$`#````.!=`0`/````[5T!`!,```#]70$`)````!%>`0`.````-EX!
M`!@```!%7@$`&P```%Y>`0`?````>EX!`!T```":7@$`%0```+A>`0`4````
MSEX!``X```#C7@$`&P```/)>`0`4````#E\!``<````C7P$`!P```"M?`0`(
M````,U\!`!,````\7P$`!@```%!?`0`*````5U\!`!(```!B7P$`"````'5?
M`0`3````?E\!`!8```"27P$`%````*E?`0`'````OE\!`!$```#&7P$`!@``
M`-A?`0`6````WU\!``X```#V7P$`#`````5@`0`T````$F`!`$8```!'8`$`
M"@```(Y@`0`(````F6`!`!0```"B8`$`!0```+=@`0`%````O6`!``T```##
M8`$`#P```-%@`0`=````X6`!`"8```#_8`$`!@```"9A`0`@````+6$!`"``
M``!.80$`'````&]A`0`:````C&$!``H```"G80$`!@```+)A`0`*````N6$!
M``<```#$80$`,````,QA`0`P````_6$!`"\````N8@$`40```%YB`0`N````
ML&(!`"X```#?8@$`/P````YC`0!`````3F,!`"X```"/8P$`-0```+YC`0`H
M````]&,!`"0````=9`$`/````$)D`0`N````?V0!`#0```"N9`$`%````.-D
M`0`8````^&0!`"8````190$`)````#AE`0`D````764!`!,```""90$`#```
M`)9E`0`0````HV4!``4```"T90$`"P```+IE`0`8````QF4!`!P```#?90$`
M!@```/QE`0`'`````V8!`!,````+9@$`"@```!]F`0`(````*F8!`"8````S
M9@$`"````%IF`0`)````8V8!``8```!M9@$`!@```'1F`0`%````>V8!``<`
M``"!9@$`!@```(EF`0`)````D&8!`"8```":9@$`#P```,%F`0`*````T68!
M``D```#<9@$`"````.9F`0`,````[V8!``@```#\9@$`#0````5G`0`*````
M$V<!`!<````>9P$`!P```#9G`0`(````/F<!``0```!'9P$`"P```$QG`0`)
M````6&<!`"````!B9P$`$@```(-G`0`)````EF<!``<```"@9P$`#````*AG
M`0`'````M6<!``H```"]9P$``P```,AG`0`?````S&<!`!,```#L9P$`+@``
M``!H`0`(````+V@!``8````X:`$`"0```#]H`0`'````26@!`$<```!1:`$`
M'P```)EH`0`Z````N6@!`"(```#T:`$`&P```!=I`0`&````,VD!``4````Z
M:0$`!0```$!I`0`@````1FD!`!D```!G:0$`+@```(%I`0`D````L&D!`",`
M``#5:0$`7@```/EI`0`H````6&H!`!4```"!:@$`"````)=J`0`.````H&H!
M`!@```"O:@$`#@```,AJ`0`-````UVH!``\```#E:@$`$0```/5J`0`/````
M!VL!`!0````7:P$`#0```"QK`0`3````.FL!``<```!.:P$`%0```%9K`0`9
M````;&L!`!<```"&:P$`$P```)YK`0`7````LFL!``8```#*:P$`!0```-%K
M`0`.````UVL!`%@```#F:P$`5@```#]L`0`$````EFP!`!,```";;`$`!P``
M`*]L`0`%````MVP!`!L```"];`$`'0```-EL`0`.````]VP!``T````&;0$`
M$0```!1M`0`;````)FT!`"X```!";0$`"P```'%M`0`?````?6T!``4```"=
M;0$`&@```*-M`0`/````OFT!`!0```#.;0$`$````.-M`0`8````]&T!``X`
M```-;@$`$@```!QN`0`3````+VX!``D```!#;@$`!@```$UN`0`/````5&X!
M``8```!D;@$`'@```&MN`0`.````BFX!`!,```"9;@$`"````*UN`0`$````
MMFX!``H```"[;@$`"P```,9N`0`'````TFX!`!,```#:;@$`"0```.YN`0`$
M````^&X!``@```#];@$`"@````9O`0`(````$6\!``@````:;P$`!0```"-O
M`0`'````*6\!``,````Q;P$``P```#5O`0`;````.6\!`$(```!5;P$`%0``
M`)AO`0`+````KF\!`!````"Z;P$`!0```,MO`0`;````T6\!``\```#M;P$`
M$````/UO`0`D````#G`!`#0````S<`$`'0```&AP`0`)````AG`!`#(```"0
M<`$`"0```,-P`0`%````S7`!``P```#3<`$`"0```.!P`0`'````ZG`!`!8`
M``#R<`$`#0````EQ`0`'````%W$!``H````?<0$`#0```"IQ`0`?````.'$!
M`"0```!8<0$`(@```'UQ`0`G````H'$!`!T```#(<0$`(````.9Q`0`?````
M!W(!`"0````G<@$`(@```$QR`0`N````;W(!`"(```"><@$`(0```,%R`0`D
M````XW(!`"`````(<P$`)P```"ES`0`W````47,!`#4```")<P$`*P```+]S
M`0`K````ZW,!`#<````7=`$`)P```$]T`0`2````=W0!`"X```"*=`$`(@``
M`+ET`0`2````W'0!`"L```#O=`$`'P```!MU`0`>````.W4!`!,```!:=0$`
MD@```&YU`0`:`````78!`"D````<=@$`*0```$9V`0`K````<'8!`"@```"<
M=@$`)P```,5V`0`9````[78!`"(````'=P$`,````"IW`0`S````6W<!`#\`
M``"/=P$`/@```,]W`0";````#G@!`!,```"J>`$`$P```+YX`0`>````TG@!
M`"4```#Q>`$`)P```!=Y`0`\````/WD!`$(```!\>0$`&````+]Y`0`$````
MV'D!``@```#=>0$``P```.9Y`0`)````ZGD!``@```#T>0$`$````/UY`0`.
M````#GH!`!0````=>@$`"0```#)Z`0`%````/'H!`!$```!">@$`%````%1Z
M`0`(````:7H!``\```!R>@$`$P```()Z`0`,````EGH!``T```"C>@$`#@``
M`+%Z`0`L````P'H!``4```#M>@$`"P```/-Z`0`&````_WH!`!,````&>P$`
M&0```!I[`0`;````-'L!``\```!0>P$``@```&![`0!+````8WL!``@```"O
M>P$`$````+A[`0`0````R7L!``<```#:>P$`$0```.)[`0`.````]'L!``0`
M```#?`$`#@````A\`0`)````%WP!``X````A?`$`$0```#!\`0`)````0GP!
M``X```!,?`$`#P```%M\`0`/````:WP!``T```![?`$`!P```(E\`0`.````
MD7P!``T```"@?`$`#````*Y\`0`-````NWP!`!D```#)?`$`#@```.-\`0`-
M````\GP!`"4`````?0$`$P```"9]`0`7````.GT!`"P```!2?0$`#````']]
M`0`:````C'T!`!8```"G?0$`%0```+Y]`0`N````U'T!`!0````#?@$`!0``
M`!A^`0`2````'GX!``D````Q?@$`)P```#M^`0`H````8WX!``<```",?@$`
M"@```)1^`0`8````GWX!``L```"X?@$`%P```,1^`0`7````W'X!``@```#T
M?@$`'````/U^`0`.````&G\!`!H````I?P$`%0```$1_`0`.````6G\!`!@`
M``!I?P$`"````()_`0`+````BW\!`"X```"7?P$`.@```,9_`0`(`````8`!
M`!0````*@`$`'0```!^``0`(````/8`!``L```!&@`$`*````%*``0`(````
M>X`!``<```"$@`$`!@```(R``0!*````DX`!``,```#>@`$`!P```.*``0`%
M````ZH`!``P```#P@`$`#````/V``0`,````"H$!``P````7@0$`#P```"2!
M`0`.````-($!`!$```!#@0$`#P```%6!`0`'````98$!``<```!M@0$`1```
M`'6!`0`+````NH$!``H```#&@0$``@```-&!`0`&````U($!``\```#;@0$`
M(@```.N!`0`2````#H(!`!(````A@@$`!P```#2"`0`.````/((!`!````!+
M@@$`%P```%R"`0`N````=((!`!T```"C@@$`"@```,&"`0`/````S((!`&L`
M``#<@@$`%@```$B#`0`3````7X,!`!$```!S@P$`!P```(6#`0`$````C8,!
M`!<```"2@P$`*P```*J#`0`L````UH,!`!@````#A`$`&P```!R$`0`4````
M.(0!`!<```!-A`$`!0```&6$`0`(````:X0!``D```!TA`$`!P```'Z$`0`4
M````AH0!`!,```";A`$`%0```*^$`0`3````Q80!`!,```#9A`$`%@```.V$
M`0`,````!(4!`!`````1A0$`!P```"*%`0`'````*H4!``X````RA0$`"P``
M`$&%`0`S````384!`!````"!A0$`"0```)*%`0`+````G(4!`"(```"HA0$`
M'````,N%`0`B````Z(4!`"$````+A@$`'````"V&`0`;````2H8!`"$```!F
MA@$`%P```(B&`0`4````H(8!``,```"UA@$`'````+F&`0`,````UH8!``T`
M``#CA@$`!````/&&`0`&````]H8!``@```#]A@$`"P````:'`0`-````$H<!
M`!$````@AP$`%````#*'`0`,````1X<!``X```!4AP$`"P```&.'`0`%````
M;X<!``0```!UAP$`%````'J'`0`5````CX<!``L```"EAP$`"@```+&'`0`+
M````O(<!`!,```#(AP$`(0```-R'`0`'````_H<!``4````&B`$`#`````R(
M`0`/````&8@!``P````IB`$`"````#:(`0`&````/X@!``,```!&B`$`&```
M`$J(`0`+````8X@!``0```!OB`$`)0```'2(`0`.````FH@!`'````"IB`$`
M$P```!J)`0`&````+HD!``0````UB0$`"@```#J)`0`&````18D!``@```!,
MB0$`"````%6)`0`'````7HD!``(```!FB0$`!@```&F)`0`+````<(D!`!@`
M``!\B0$`$@```)6)`0`4````J(D!`!,```"]B0$`!P```-&)`0`(````V8D!
M`!(```#BB0$`!P```/6)`0`(````_8D!``4````&B@$`&`````R*`0`(````
M)8H!``8````NB@$`'````#6*`0`1````4HH!``<```!DB@$`"````&R*`0`%
M````=8H!``D```![B@$`!P```(6*`0`.````C8H!``0```"<B@$`!0```*&*
M`0`.````IXH!``T```"VB@$`#@```,2*`0`&````TXH!`!,```#:B@$`"0``
M`.Z*`0`'````^(H!``\`````BP$`(0```!"+`0`S````,HL!`"8```!FBP$`
M(@```(V+`0`&````L(L!``H```"WBP$`!````,*+`0`*````QXL!``@```#2
MBP$`$````-N+`0`/````[(L!``4```#\BP$`#`````*,`0`(````#XP!``0`
M```8C`$`/P```!V,`0!!````78P!`#\```"?C`$`&P```-^,`0`&````^XP!
M``P````"C0$`!`````^-`0`$````%(T!``8````9C0$`'P```""-`0`/````
M0(T!`!8```!0C0$`!@```&>-`0`#````;HT!`!8```!RC0$`!P```(F-`0`(
M````D8T!`!,```":C0$`!0```*Z-`0`(````M(T!`!T```"]C0$`"0```-N-
M`0`.````Y8T!``P```#TC0$`#@````&.`0`)````$(X!``@````:C@$`!0``
M`"..`0`L````*8X!`"T```!6C@$`-P```(2.`0`G````O(X!`#X```#DC@$`
M-@```"./`0`I````6H\!`#P```"$CP$`+P```,&/`0`O````\8\!`!\````A
MD`$`#P```$&0`0`7````49`!``X```!ID`$`)P```'B0`0`D````H)`!`!P`
M``#%D`$`(@```.*0`0`'````!9$!``@````-D0$`"@```!:1`0`&````(9$!
M`"$````HD0$`)0```$J1`0`H````<)$!``H```"9D0$`%@```*21`0`H````
MNY$!`!8```#DD0$`#P```/N1`0`&````"Y(!``X````2D@$`"@```"&2`0`0
M````+)(!`!$````]D@$`.0```$^2`0![````B9(!`'@````%DP$`#P```'Z3
M`0`)````CI,!``H```"8DP$`#@```*.3`0`/````LI,!`!,```#"DP$`!@``
M`-:3`0`/````W9,!`!,```#MDP$`$@````&4`0`1````%)0!`!L````FE`$`
M(````$*4`0!?````8Y0!`!(```##E`$`!0```-:4`0`1````W)0!``H```#N
ME`$`!````/F4`0`-````_I0!`!X````,E0$`$@```"N5`0`)````/I4!``H`
M``!(E0$`#@```%.5`0`0````8I4!`"0```!SE0$`(@```)B5`0`A````NY4!
M`!\```#=E0$`(0```/V5`0`?````'Y8!`!<````_E@$`.````%>6`0`2````
MD)8!`!````"CE@$`$0```+26`0`/````QI8!``L```#6E@$`$````.*6`0`.
M````\Y8!`!`````"EP$`#@```!.7`0`A````(I<!``\```!$EP$`#P```%27
M`0`O````9)<!`!(```"4EP$`!P```*>7`0`3````KY<!`!X```##EP$`$P``
M`.*7`0`0````]I<!``T````'F`$`&0```!68`0`3````+Y@!`!$```!#F`$`
M%0```%68`0`8````:Y@!``\```"$F`$`&P```)28`0`A````L)@!`!$```#2
MF`$`$@```.28`0`1````]Y@!`!$````)F0$`$@```!N9`0`5````+ID!`!0`
M``!$F0$`%P```%F9`0`(````<9D!``H```!ZF0$`%0```(69`0`%````FYD!
M``<```"AF0$`"0```*F9`0`4````LYD!``<```#(F0$`"@```-"9`0`(````
MVYD!``<```#DF0$`!P```.R9`0`'````])D!``8```#\F0$`%0````.:`0!2
M````&9H!``8```!LF@$`"0```'.:`0`%````?9H!``4```"#F@$`"````(F:
M`0`'````DIH!``@```":F@$`"````*.:`0`(````K)H!``D```"UF@$`$@``
M`+^:`0`&````TIH!`"(```#9F@$`#P```/R:`0`-````#)L!``\````:FP$`
M#````"J;`0`*````-YL!``T```!"FP$`)@```%";`0`&````=YL!``@```!^
MFP$`(````(>;`0`.````J)L!``X```"WFP$`!@```,:;`0`*````S9L!``D`
M``#8FP$`!````.*;`0`@````YYL!``P````(G`$`%@```!6<`0`/````+)P!
M`!$````\G`$`%````$Z<`0`B````8YP!`!X```"&G`$`!````*6<`0`&````
MJIP!``@```"QG`$`(0```+J<`0`(````W)P!``4```#EG`$`"@```.N<`0`1
M````]IP!``<````(G0$`!````!"=`0`(````%9T!`!<````>G0$`#0```#:=
M`0`-````1)T!``D```!2G0$`%@```%R=`0`3````<YT!``T```"'G0$`$@``
M`)6=`0`.````J)T!``X```"WG0$`!P```,:=`0`$````SIT!`!4```#3G0$`
M,@```.F=`0`&````')X!``X````CG@$`(````#*>`0`4````4YX!`!@```!H
MG@$`$````(&>`0`,````DIX!``D```"?G@$`!P```*F>`0`*````L9X!``D`
M``"\G@$`#@```,:>`0`0````U9X!`"H```#FG@$`*0```!&?`0`G````.Y\!
M``D```!CGP$`!0```&V?`0`'````<Y\!``T```![GP$`#@```(F?`0`'````
MF)\!``H```"@GP$`'@```*N?`0`*````RI\!``P```#5GP$`$P```.*?`0`_
M````]I\!`!4````VH`$`"@```$R@`0`(````5Z`!``4```!@H`$`$0```&:@
M`0`1````>*`!`!8```"*H`$`"@```*&@`0`"````K*`!``0```"OH`$`)0``
M`+2@`0`#````VJ`!``4```#>H`$`*````.2@`0`*````#:$!``8````8H0$`
M!@```!^A`0`4````)J$!``D````[H0$`!@```$6A`0`(````3*$!``D```!5
MH0$`!````%^A`0`%````9*$!`&D```!JH0$`"P```-2A`0`.````X*$!`!<`
M``#OH0$`!0````>B`0`$````#:(!`!\````2H@$`*0```#*B`0`0````7*(!
M``H```!MH@$`#@```'BB`0`+````AZ(!``H```"3H@$`%P```)ZB`0`=````
MMJ(!`"8```#4H@$`)0```/NB`0`<````(:,!``T````^HP$``P```$RC`0`'
M````4*,!``D```!8HP$`!P```&*C`0`-````:J,!``X```!XHP$`!0```(>C
M`0!3````C:,!`!$```#AHP$`"@```/.C`0`)````_J,!`!P````(I`$`10``
M`"6D`0`7````:Z0!``8```"#I`$`'P```(JD`0`Q````JJ0!``8```#<I`$`
M!P```..D`0`8````ZZ0!``<````$I0$`"0````RE`0`F````%J4!`"0````]
MI0$`)P```&*E`0`(````BJ4!``L```"3I0$`(````)^E`0!B````P*4!`!$`
M```CI@$`(````#6F`0`4````5J8!``(```!KI@$`#P```&ZF`0`(````?J8!
M`!````"'I@$`"0```)BF`0`$````HJ8!`!````"GI@$`!@```+BF`0`)````
MOZ8!``P```#)I@$`"0```-:F`0`*````X*8!``D```#KI@$`*P```/6F`0`&
M````(:<!``\````HIP$`$````#BG`0`;````2:<!`!L```!EIP$`"P```(&G
M`0`/````C:<!``\```"=IP$`"P```*VG`0`+````N:<!``L```#%IP$`"0``
M`-&G`0`5````VZ<!`!$```#QIP$`!0````.H`0`*````":@!``\````4J`$`
M#````"2H`0`6````,:@!``<```!(J`$`$@```%"H`0`$````8Z@!``@```!H
MJ`$`!0```'&H`0`&````=Z@!``<```!^J`$`$0```(:H`0`1````F*@!`!D`
M``"JJ`$`%@```,2H`0`5````VZ@!`!8```#QJ`$`&0````BI`0`@````(JD!
M`!H```!#J0$`!````%ZI`0`,````8ZD!``X```!PJ0$`#@```'^I`0`.````
MCJD!``<```"=J0$`(P```*6I`0`+````R:D!``P```#5J0$`%@```.*I`0`:
M````^:D!`!,````4J@$`!P```"BJ`0`&````,*H!``@````WJ@$`$0```$"J
M`0`0````4JH!``D```!CJ@$`"@```&VJ`0`%````>*H!``@```!^J@$``@``
M`(>J`0`$````BJH!``(```"/J@$`.````)*J`0`B````RZH!``P```#NJ@$`
M'0```/NJ`0`R````&:L!`!$```!,JP$`)P```%ZK`0`8````AJL!`!T```"?
MJP$`'0```+VK`0`B````VZL!`!8```#^JP$`$P```!6L`0`/````*:P!`!$`
M```YK`$`$@```$NL`0`1````7JP!``T```!PK`$`#````'ZL`0`.````BZP!
M`!8```":K`$`(0```+&L`0`A````TZP!`"4```#UK`$`(@```!NM`0`C````
M/JT!`"````!BK0$`90```(.M`0`;````Z:T!`!$````%K@$`"````!>N`0`7
M````(*X!`!`````XK@$`%````$FN`0`G````7JX!`"D```"&K@$`)0```+"N
M`0`2````UJX!`$<```#IK@$`1@```#&O`0`)````>*\!``D```""KP$`%P``
M`(RO`0`-````I*\!``T```"RKP$`%0```,"O`0`%````UJ\!`!````#<KP$`
M#P```.VO`0`/````_:\!``\````-L`$`"0```!VP`0`0````)[`!``<````X
ML`$`(0```$"P`0`(````8K`!``,```!KL`$`"P```&^P`0`,````>[`!``H`
M``"(L`$`.P```).P`0`"````S[`!``8```#2L`$`#0```-FP`0`/````Y[`!
M``@```#WL`$`#@````"Q`0`*````#[$!`"L````:L0$`$0```$:Q`0`>````
M6+$!``4```!WL0$`+````'VQ`0`9````JK$!`"8```#$L0$`50```.NQ`0`.
M````0;(!`$0```!0L@$`&P```)6R`0`3````L;(!``8```#%L@$`#0```,RR
M`0`3````VK(!``X```#NL@$`"````/VR`0`$````!K,!`!0````+LP$`'```
M`""S`0`#````/;,!``@```!!LP$`#P```$JS`0`@````6K,!``\```![LP$`
M$P```(NS`0`4````G[,!``\```"TLP$`(P```,2S`0`(````Z+,!``P```#Q
MLP$`#0```/ZS`0`'````#+0!``P````4M`$`!P```"&T`0`0````*;0!``@`
M```ZM`$`#0```$.T`0`5````4;0!``T```!GM`$`!0```'6T`0`(````>[0!
M``4```"$M`$`(P```(JT`0`&````KK0!`!````"UM`$`"````,:T`0`1````
MS[0!``@```#AM`$`$@```.JT`0`-````_;0!`"D````+M0$`%````#6U`0`)
M````2K4!``H```!4M0$`&@```%^U`0`%````>K4!`!,```"`M0$`!P```)2U
M`0`5````G+4!``@```"RM0$`"0```+NU`0`3````Q;4!`!X```#9M0$`!0``
M`/BU`0`:````_K4!`!,````9M@$`!P```"VV`0`.````-;8!``P```!$M@$`
M!0```%&V`0`,````5[8!``H```!DM@$`!P```&^V`0`%````=[8!``@```!]
MM@$`!P```(:V`0`*````CK8!`!8```"9M@$`*P```+"V`0`P````W+8!`!4`
M```-MP$`(@```".W`0`=````1K<!`#<```!DMP$`%@```)RW`0`3````L[<!
M`"0```#'MP$`20```.RW`0`<````-K@!``4```!3N`$`"0```%FX`0`*````
M8[@!``@```!NN`$`%````'>X`0`5````C+@!`"L```"BN`$`&@```,ZX`0`7
M````Z;@!`"\````!N0$`-0```#&Y`0`'````9[D!`!,```!ON0$`"````(.Y
M`0`(````C+D!`!D```"5N0$`#P```*^Y`0`.````O[D!``T```#.N0$`"```
M`-RY`0`3````Y;D!``D```#YN0$`#@````.Z`0`+````$KH!`!8````>N@$`
M$@```#6Z`0`G````2+H!``L```!PN@$`'@```'RZ`0`%````F[H!``8```"A
MN@$`!P```*BZ`0`:````L+H!``4```#+N@$`!````-&Z`0`-````UKH!``H`
M``#DN@$`!P```.^Z`0`,````][H!``P````$NP$`#0```!&[`0`(````'[L!
M``,````HNP$`"0```"R[`0`S````-KL!`$,```!JNP$`&````*Z[`0`)````
MQ[L!`"<```#1NP$`&0```/F[`0`/````$[P!``X````CO`$`"@```#*\`0`(
M````/;P!`!````!&O`$`*@```%>\`0`'````@KP!``T```"*O`$`#0```)B\
M`0`0````IKP!``P```"WO`$`.0```,2\`0`'````_KP!`!,````&O0$`$```
M`!J]`0`4````*[T!`#8```!`O0$`'0```'>]`0`C````E;T!`"0```"YO0$`
M(````-Z]`0`0````_[T!``@````0O@$`#@```!F^`0`6````*+X!`!4````_
MO@$`"0```%6^`0`2````7[X!`!(```!RO@$`!P```(6^`0`;````C;X!`!L`
M``"IO@$`"P```,6^`0`%````T;X!``H```#7O@$`$0```.*^`0`.````]+X!
M``0````#OP$`"`````B_`0`)````$;\!``X````;OP$`#@```"J_`0`*````
M.;\!``H```!$OP$`!0```$^_`0`&````5;\!`"X```!<OP$`)0```(N_`0`C
M````L;\!``<```#5OP$`$0```-V_`0`&````[[\!`!\```#VOP$`%0```!;`
M`0`A````+,`!``\```!.P`$`#````%[``0`@````:\`!``,```",P`$`"```
M`)#``0`-````F<`!``(```"GP`$`#````*K``0`4````M\`!``L```#,P`$`
M&````-C``0`<````\<`!`!0````.P0$`!0```"/!`0`*````*<$!`!0````T
MP0$`%@```$G!`0`-````8,$!``D```!NP0$`#0```'C!`0`+````AL$!`!(`
M``"2P0$`3P```*7!`0`?````]<$!`#4````5P@$`$0```$O"`0`&````7<(!
M``8```!DP@$`#P```&O"`0`+````>\(!``P```"'P@$`$@```)3"`0`/````
MI\(!``L```"WP@$`%0```,/"`0`)````V<(!`!\```#CP@$`"P````/#`0`/
M````#\,!`$8````?PP$`%P```&;#`0`9````?L,!`"(```"8PP$`%P```+O#
M`0`9````T\,!`!@```#MPP$`$`````;$`0`4````%\0!`!D````LQ`$`"0``
M`$;$`0`'````4,0!``@```!8Q`$`"0```&'$`0`4````:\0!``L```"`Q`$`
M)0```(S$`0`2````LL0!`!@```#%Q`$`"P```-[$`0`$````ZL0!`$P```#O
MQ`$`/0```#S%`0`V````>L4!`%L```"QQ0$`"0````W&`0`K````%\8!`"P`
M``!#Q@$`"@```'#&`0`)````>\8!``T```"%Q@$`,P```)/&`0`%````Q\8!
M`$(```#-Q@$`+P```!#'`0`G````0,<!``T```!HQP$`(````';'`0`7````
ME\<!`"4```"OQP$`'@```-7'`0`B````],<!`!T````7R`$`#0```#7(`0`'
M````0\@!`!(```!+R`$`#P```%[(`0`6````;L@!``@```"%R`$`.0```([(
M`0`,````R,@!``4```#5R`$`!P```-O(`0`1````X\@!``@```#UR`$`!@``
M`/[(`0`3````!<D!``D````9R0$`"0```"/)`0`$````+<D!``T````RR0$`
M$0```$#)`0`:````4LD!`!<```!MR0$`#0```(7)`0`5````D\D!`!````"I
MR0$`"````+K)`0`4````P\D!`!L```#8R0$`#````/3)`0`-`````<H!`!H`
M```/R@$`)P```"K*`0`-````4LH!`!,```!@R@$`'@```'3*`0`(````D\H!
M``0```"<R@$`$@```*'*`0`)````M,H!``D```"^R@$`$P```,C*`0`.````
MW,H!``P```#KR@$`"P```/C*`0`%````!,L!``D````*RP$`"````!3+`0`)
M````'<L!``H````GRP$`$P```#++`0`$````1LL!`!````!+RP$`#0```%S+
M`0`2````:LL!``\```!]RP$`&````(W+`0`+````ILL!``(```"RRP$`'0``
M`+7+`0`%````T\L!``<```#9RP$`:@```.'+`0`)````3,P!``H```!6S`$`
M&0```&',`0`E````>\P!`!,```"AS`$`'@```+7,`0!'````U,P!`#`````<
MS0$`.````$W-`0`7````ALT!`!<```">S0$`!@```+;-`0`-````O<T!``L`
M``#+S0$`#@```-?-`0`1````YLT!``L```#XS0$`$P````3.`0`-````&,X!
M``X````FS@$`$````#7.`0`)````1LX!``0```!0S@$`"````%7.`0`-````
M7LX!`!4```!LS@$`"0```(+.`0`&````C,X!``<```"3S@$`(0```)O.`0`&
M````O<X!`!P```#$S@$`%P```.'.`0`*````^<X!`!4````$SP$`#@```!K/
M`0`7````*<\!``@```!!SP$`!0```$K/`0`/````4,\!``T```!@SP$`#P``
M`&[/`0`&````?L\!`!8```"%SP$`"P```)S/`0`7````J,\!``H```#`SP$`
M!````,O/`0`.````T,\!`!H```#?SP$`"P```/K/`0`-````!M`!`"H````4
MT`$`%0```#_0`0`.````5=`!``4```!DT`$`#````&K0`0`.````=]`!``<`
M``"&T`$``@```([0`0`-````D=`!``,```"?T`$`$P```*/0`0`=````M]`!
M`",```#5T`$`,````/G0`0`B````*M$!`"4```!-T0$`(````'/1`0!2````
ME-$!`!,```#GT0$`2@```/O1`0`N````1M(!`$<```!UT@$`1@```+W2`0`=
M````!-,!`"T````BTP$`)0```%#3`0`N````=M,!`"8```"ETP$`&P```,S3
M`0`L````Z-,!`-<!```5U`$`'@```.W5`0`1````#-8!`$4````>U@$`=0``
M`&36`0`L````VM8!`!L````'UP$`,0```"/7`0!7````5=<!`$T```"MUP$`
M'0```/O7`0`:````&=@!`!$````TV`$`'0```$;8`0`:````9-@!`!L```!_
MV`$`'@```)O8`0`?````NM@!`!H```#:V`$`'P```/78`0`P````%=D!`!X`
M``!&V0$`$P```&79`0`J````>=D!`"0```"DV0$`)0```,G9`0`D````[]D!
M`!D````4V@$`)P```"[:`0!8````5MH!`"L```"OV@$`/P```-O:`0`N````
M&]L!`"(```!*VP$`.@```&W;`0!<````J-L!`$<````%W`$`)@```$W<`0`H
M````=-P!`"T```"=W`$`2P```,O<`0!;````%]T!`$,```!SW0$`1````+?=
M`0`N````_-T!`"8````KW@$`)````%+>`0`G````=]X!`&<```"?W@$`70``
M``??`0!F````9=\!`+(```#,WP$`&````'_@`0`F````F.`!`#0```"_X`$`
M+0```/3@`0!"````(N$!`"(```!EX0$`1````(CA`0`?````S>$!``H```#M
MX0$`K0```/CA`0`^````IN(!`"````#EX@$`-0````;C`0`F````/.,!`!\`
M``!CXP$`(P```(/C`0`$````I^,!``@```"LXP$``P```+7C`0`+````N>,!
M``H```#%XP$`"0```-#C`0`)````VN,!``@```#DXP$`$@```.WC`0`'````
M`.0!`%H````(Y`$`!````&/D`0`1````:.0!``0```!ZY`$`!P```'_D`0`%
M````A^0!``4```"-Y`$`.@```)/D`0`$````SN0!`!<```#3Y`$`!@```.OD
M`0`2````\N0!``T````%Y0$``@```!/E`0`(````%N4!``4````?Y0$`$@``
M`"7E`0`,````..4!``\```!%Y0$`!@```%7E`0`2````7.4!``L```!OY0$`
M`P```'OE`0`G````?^4!``0```"GY0$`!@```*SE`0`'````L^4!`!X```"[
MY0$`-@```-KE`0`C````$>8!`"0````UY@$`&@```%KF`0`M````=>8!`#``
M``"CY@$`'@```-3F`0`?````\^8!`!T````3YP$`(@```#'G`0`=````5.<!
M`!D```!RYP$`'P```(SG`0`<````K.<!`!8```#)YP$`+````.#G`0`:````
M#>@!`"D````HZ`$`)````%+H`0`A````=^@!`",```"9Z`$`(````+WH`0`=
M````WN@!`"$```#\Z`$`*````![I`0`H````1^D!`",```!PZ0$`(@```)3I
M`0`?````M^D!`!P```#7Z0$`(@```/3I`0`9````%^H!`!\````QZ@$`+```
M`%'J`0`O````?NH!`!D```"NZ@$`(@```,CJ`0`Y````Z^H!`"4````EZP$`
M)P```$OK`0`E````<^L!`"@```"9ZP$`(0```,+K`0`?````Y.L!`"H````$
M[`$`(````"_L`0`K````4.P!`"8```!\[`$`,P```*/L`0`2````U^P!``X`
M``#J[`$`'0```/GL`0`M````%^T!`!L```!%[0$`#````&'M`0`/````;NT!
M`!8```!^[0$`#0```)7M`0`4````H^T!`"$```"X[0$`!@```-KM`0`(````
MX>T!`",```#J[0$`)@````[N`0`9````->X!`",```!/[@$`&0```'/N`0`&
M````C>X!`+P```"4[@$`#````%'O`0`2````7N\!``<```!Q[P$`"````'GO
M`0`.````@N\!``X```"1[P$`&P```*#O`0`.````O.\!`#0```#+[P$`$```
M``#P`0`4````$?`!``<````F\`$`$P```"[P`0`+````0O`!`#<```!.\`$`
M"````(;P`0`?````C_`!``X```"O\`$`$@```+[P`0`8````T?`!`#<```#J
M\`$`&````"+Q`0`,````._$!`"$```!(\0$`#0```&KQ`0`-````>/$!`!0`
M``"&\0$`"@```)OQ`0`:````IO$!``8```#!\0$`)0```,CQ`0`(````[O$!
M`"<```#W\0$`(@```!_R`0`)````0O(!`!X```!,\@$`!P```&OR`0`'````
M<_(!``L```![\@$`0@```(?R`0`+````RO(!``\```#6\@$`$P```.;R`0`5
M````^O(!``P````0\P$`"@```!WS`0`'````*/,!`!$````P\P$`"````$+S
M`0`7````2_,!``P```!C\P$`$@```'#S`0`0````@_,!``@```"4\P$`"@``
M`)WS`0`7````J/,!``<```#`\P$`,0```,CS`0`,````^O,!`!`````']`$`
M!P```!CT`0`"````(/0!``P````C]`$`$0```##T`0`+````0O0!``0```!.
M]`$`"0```%/T`0`,````7?0!``T```!J]`$`$@```'CT`0`1````B_0!`!(`
M``"=]`$`$P```+#T`0`,````Q/0!`#8```#1]`$`)0````CU`0`F````+O4!
M`!<```!5]0$`#P```&WU`0`N````??4!``4```"L]0$`$@```++U`0!`````
MQ?4!``P````&]@$`"0```!/V`0`&````'?8!``0````D]@$`!````"GV`0`-
M````+O8!`!4````\]@$`!0```%+V`0`&````6/8!``8```!?]@$`#0```&;V
M`0`#````=/8!``\```!X]@$`"@```(CV`0`U````D_8!`"H```#)]@$`)P``
M`/3V`0`%````'/<!`!H````B]P$`'P```#WW`0`B````7?<!`"0```"`]P$`
M$0```*7W`0`"````M_<!``0```"Z]P$`#````+_W`0`+````S/<!``8```#8
M]P$``P```-_W`0`.````X_<!`$$```#R]P$`*0```#3X`0`8````7O@!`"D`
M``!W^`$`+0```*'X`0`]````S_@!`!(````-^0$`D````"#Y`0`E````L?D!
M`#<```#7^0$`(`````_Z`0`N````,/H!`"L```!?^@$`(0```(OZ`0`J````
MK?H!`"D```#8^@$`)@````+[`0`E````*?L!`"@```!/^P$`(P```'C[`0`E
M````G/L!`#4```#"^P$`%0```/C[`0`4````#OP!``D````C_`$`:````"W\
M`0`)````EOP!`(T```"@_`$`=P```"[]`0!O````IOT!`#8````6_@$`7P``
M`$W^`0`.````K?X!`"$```"\_@$`%0```-[^`0`2````]/X!`!X````'_P$`
M&P```";_`0`Q````0O\!`!H```!T_P$`&@```(__`0!+````JO\!`!D```#V
M_P$`%@```!```@`+````)P`"``0````S``(`!@```#@``@`(````/P`"``4`
M``!(``(`%P```$X``@`0````9@`"`!D```!W``(`(@```)$``@`/````M``"
M``<```#$``(`"0```,P``@`)````U@`"``T```#@``(`!P```.X``@`$````
M]@`"`!(```#[``(`"P````X!`@`+````&@$"``\````F`0(`"@```#8!`@`(
M````00$"`!````!*`0(`"@```%L!`@`3````9@$"``H```!Z`0(`#@```(4!
M`@`2````E`$"``@```"G`0(`!@```+`!`@`;````MP$"`!8```#3`0(`"P``
M`.H!`@`7````]@$"``\````.`@(`'P```!X"`@`5````/@("``4```!4`@(`
M$````%H"`@`&````:P("``0```!R`@(`'0```'<"`@`+````E0("``(```"A
M`@(``@```*0"`@`2````IP("``L```"Z`@(`!@```,8"`@`3````S0("`!8`
M``#A`@(`!0```/@"`@`@````_@("``(````?`P(`!````"(#`@`.````)P,"
M`!,````V`P(`!P```$H#`@`)````4@,"`!````!<`P(`!P```&T#`@`<````
M=0,"``8```"2`P(`%P```)D#`@`/````L0,"`!(```#!`P(``@```-0#`@`'
M````UP,"`!<```#?`P(`#0```/<#`@`3````!00"``T````9!`(`#0```"<$
M`@`P````-00"``@```!F!`(`!@```&\$`@`.````=@0"``4```"%!`(``@``
M`(L$`@`+````C@0"``$```!<!P``,````"P&```8!0```````+@$``"J!@``
M'@`````````)!@``Y`$``,8$``",!0``*P(```````"4`0``JP4`````````
M`````````&8$``!>`@``(P0``,H`````````'0,``)0$````````(0``````
M``#9`@```````)\"``!X`0``FP,``"H```#L!@```````),$````````T@$`
M`,H%``!H`0``&P$``(\#````````P`,``)L"``!I`0``@@<``"@````F`@``
M?P$``/8#````````>@<```````!%`@``+P4`````````````&P<`````````
M````N@,`````````````<`0``$P```#F!@``1`$```````!+!@``.@(``+0"
M``"E`@```````$\!``!+`@```````!T"``!X!P``@@(``*8"```*!P``&`$`
M`'@$````````"@$``$$``````````````!X%````````RP```/H"```S````
M7@8``,\#``"?!```CP4``%X!````````6P$``',$``#J`@``^P,``&D"````
M````]@0```````#=`0````````````!P````OP$```````"I!@``<0,`````
M````````:04````````O!```:`8``,0```"-`0``#`0``.\#``!*`0``=`(`
M`%0"````````,0``````````````I0`````````)`0``R08```0```!N!0``
M>P8```````"G!@``ZP8````````:!```````````````````-````.,$``"S
M!0```````-$````G````%P0```````!6!```Z`(``%L$``"Q`P```````-4"
M`````````````,T#```!!```````````````````/P<``#`"````````TP,`
M`/8!````````^`(``!<"````````#`<```````!P`@``50```/$#``"]`P``
MKP4``+D%``"X`0``V`0``(T%``!A!```T`4``$X'````````=`$```H```!5
M!P```````%H!``#*`0``2@```.D&``"!`0``N0,``-0!````````AP8`````
M``#(!```7`$``,````"Z!@```````+L%``!D!@``80```/(#``!+`0``*@(`
M`"8$``!S!@``7P4``%P```!H`P``3`4```````"P`0````<``.($````````
M`````#@'```P!@````````\#`````````````"`#``"\`P``G0```,0"``#:
M`P````````````"0!@``!`,``+T```"(`@```````*T%````````W`8``!H#
M``"<`@``;P<```````"T!@```````(8```#"`0``KP8``.D$``")`P``````
M`',!```K!```3@4`````````````&P4``*$````4!````````%L"```[`P``
MSP4``*$"````````EP,``&($```$!0``V@8````````@````)`0``,@!````
M````L@0``"(&``!#!P``K`0``'D#````````C@,``-$"``!;`P``/`,``-4!
M``"7`0```````'D&````````;P```-X%`````````````/$&````````C`$`
M``P#``#@!0``V0,``$@'``"4!0``<00``/8```!A`0``0@8````````;!```
M+`4``(T````A!@```````+8"``!,!@```````-P```!$!P``N0$``(@!``!N
M!P``[0,``#@$```A!```'P$``&@```"S````$@````````"C!0```````+("
M``!Q````]`$``'P```#^!0``#0<``(H`````````_@(``),```#,`@``````
M`)H!```=!P``M@,``$,&``!,!P``<`8`````````````I@,``'H%````````
M```````````[`@``9P$``%$'``!_`@``JP$````````<`@``+0$``#<&``"9
M!0`````````````9`0``3@```+@&``#S!@``I@0`````````````R0``````
M``"2`P```````-X&``#=````R@8``.$```#T````,`$``/X````L!```20``
M`*,#``!\`0```````/$``````````````-8%````````9`<``$`'``!O`0``
MFP0``*,````N!P``@`4```````!J!P```````*P!````````208````````O
M````^0(```````!Q`0```````-P!`````````````.`"````````"`8```T!
M```.!P``V00``%H```#[`0``'00```\````!!0``CP```!T%````````````
M``8$``!8!@``2`8``(H&````````4@$``&(&``#<!0``(04``(\$``#[!0``
MT```````````````>`8````````.`0``-@(``/0&``"^`0``40(``/0%``#&
M!0``CP<``*```````````````*D#``"H!@``BP4``)T#``"V!0``9@8`````
M``#H`P```````(`&``#0`@``;@````(!``!``P``&0<``(X&````````````
M```````V`P``BP```$`!``!-````5P4``$D!````````400```````#6`@``
MKP```/<&```Y!```0P$``+T&``!9!P``VP```)<$````````)`````@!``!]
M`P``EP8````````V`0``K`4``!$````0!```U@0````````Q`0``S`$``+D"
M````````.0```+T$``````````````X$```)!P``2@<``%('``!&!P``+`(`
M```````E`P``9P(``)@$``#4`P``(`(```````"^!0``X@````@#``!V`0``
MQ@8``&D&````````ZP,``$L$``#B`@``.`,``$(!``#H````P@0```````!-
M`@``;@,```````!Z!````````%<"``"'!```X```````````````B@4``)P#
M```W!0``GP4``+L!``#Z!0```````+<#```K`P``108``-<%``"0`@``7P<`
M``$"```O!@``!P,``",%``"L`@``3@(```,&````````V@4``#,&````````
M<P```(H$``#S`0```````/T!`````````````/H```#4!@``[@```#4%``"$
M!```:@,``&T&`````````````$\$``!@`@``$P$``$$!``"`!````````+4$
M```V````*@,``%`!``!'!0``?`<``#L%``!:`P``?`,``-4&```2!0``/`$`
M`&0$```2!P````````````!]!P```````'`'``#E`@```````/,````]`@``
M200``"8!``"*`P```P0``.D"``##!@``T0$```D"``!_!0``*`0``/X#``#:
M!```Z@8`````````````=@,```````#]````%@4``((#``#_`P``SP(``#4&
M``!,`P``V`,``%$```!K!```!@,``"$#``#E!@````````````!G`P``BP,`
M``````!+!0```````%(````Z!@``;`(``"(#````````F@(``!X'````````
M#P<``'D!``!7````X`8``'H````B!0``8P0``,@"``````````````<&``"<
M````4P$``,X!``"!!0``#`4``'(&```#`P``(P(``#@```!4!0```````"T`
M``".!P``)`(````````B`0``9P````````#>`P``4P```"L%```D`0``````
M````````````1`0````````(!0``]04```````!H!0``+04`````````````
M1`````````!6`0``-P<``.H#``!:!@``$P0`````````````*0<```````")
M````M````-X`````````=08`````````````804```<!````````#@(`````
M`````````````.<!``":````S`,``-P#`````````````*\"``!F`@``C@0`
M```````\!P```````%D$```6`P````````8'``#:`````````-`$``#S!```
M`````%@"````````8`0``'T$``#,!@``R`4``+(````E!````````(0#``!G
M!P``M0````(%``"J!0```@8``!H```!R!0``2P```&H$``#%!```O@,``%@#
M````````-`(`````````````I`$```(`````````HP0`````````````````
M`.`#``!1!0``*`,``$T#```A!P``V@$``/@$``#P!0``10,``%\`````````
MK`8``!8`````````````````````````.P```%0```"E!```,P0``-,"``"_
M`@``[P8``!L#``",````G@,``$P"````````7@4```````!9`P``U`4`````
M``"``@```````%`#``#P!@``IP,``-,```#/`````````.(&``""````TP0`
M``<$``!?`@``'`4``&('``#E!```\`0``%4"```N!@``P@8``%<$``#%`0``
M;@8```````!!!````````(,```":!`````(``+$&``!6`P``NP```)(!``">
M!@```````````````````````(0```"$!@``3`$``````````````````/L"
M````````AP$``-L#````````,@4``.X"```/`0``A0$``!L&````````L```
M`!@&``!J`0``@`$```````"5````WP0``#L!``![`0``C`(``,8"``"W!```
M5P<```````!*`@``#@8``,8#```T`P``"`(``#`%``!1`0``QP,``!0'``!%
M!```904``.$!````````*@$``$X!``!,!```UP$``)\#```!`0``QP4`````
M``!7`0``S@4``'H#``"N`P``V````+$!```]!```,P(``%($```&!0``````
M`$,%``!$`P``I0$``)$$```?````H`(``````````````````,$!``!:!P``
MG`$``/L&````````&04``.\!``!P`0```````+0%``!L!0``V`(````&````
M````V0$```````#U`P```````($&```J!```8P``````````````````````
M`````````````,4"``#X`P``&`(``-$#```2!```8P(```````"]`@``````
M``````!D`P```````,<````3`@``90<``)`#```_!0``5`,``#T`````````
M`````"`&````````P`4``&4&``"6`0`````````````#!P``>0(```````"R
M`0``M@````````!'!```@P0``'X```"G!0``RP$```````#T`P``E`8``%`%
M```%!P``A0<``"8#```5````A0,``#<$```[!P``70(````````H!P``````
M````````````M08``/$$```?!P``EP```"($`````````````%0&``#3!@``
MNP0``+,&``"?`0``#`````0!```Q!@``00<``-D%``"8`@```````,$$``#C
M`P``LP$``/P$````````<@<```````!O`P``=P0````%``!*!@``Q`0``/D`
M````````5`<``-X"```<!@``Y@```*T&````````U@8``/\$``#<!```````
M`#4````%`P``4P(```````!U`0``(P8````````%!```TP$```````"E!@``
MA@,``#X!``#"`P``/`4``(P&``````````````````"``````````(4````7
M!@``=0,```````#K!```NP,```````"&!@```````"X"``"N!@``D@```$\&
M``":`P``2`4```````!6````W@$``)($``",`P``4@4```````!S`@``<P,`
M``T&```5`0```````)\```"%!```````````````````0`8```,%``":!0``
M/@<```````!&!@``8`8``````````````````*@#``"1!0``AP<``(<#``".
M!0``?@(````````+!````````'$"``!5!0``VP8``*`&``"Q`````````!`"
M``"=`0````````P"``"=`@```````!$!`````````````%,$``!(`0``W0(`
M`/L$````````%0<``&L"````````W@0``#0&``!7`P``0@<``-\#````````
M`````-T%```6!```;P8``*P````1`@``H`0```````"S`@```````,T%``"H
M`0``MP(``.<&``!P`P``70$``.D!``"@!0``'@(`````````````XP(``!\$
M`````````````(@&```D!P````````````#Q!0``9`(```````#)`0``;P(`
M`"<"``#Q`0``P`(``"$!```>`P``$@8``#@&``!9````70```&\%``#?`0``
M_`(``#<!``#U!```'`0``````````````````.(!``#<`@``#00``*4%``"C
M`0``!`(``'X#``"/`@``8P,```````!0!```Z@```+X```!P!0```````,D$
M``#\!0``F`$`````````````;`$``!8&```V!0``E@(`````````````L`4`
M`)@#```R`@``JP0```````!]!0``F08``$D'``#^`0``?P```!<%``#'`0``
M_@8``&P&```1!```$P4``!0!``#J`0```````&`!``"N!0``PP,``!0#````
M````=0(```````!F`0````````````"-!P``+0,````````D`P``R@(``&D#
M````````G@````````````````````````"J!```M0$``+$$``#.`@``````
M`$T'```Y!P``\P,```````#2!```+@,``!D#``"!`P``T`,``#4'````````
MS`4``/8"``!/`````````-8!````````8@```-0$```*`@````````````"4
M`@``D```````````````*08```````#-`@``I`,``/`"``!C!P``V0``````
M``!K!P``P`8```````!*!```/P8```````#O`@``*0```(<"````````?08`
M``````!Z`0``"@4``%<&```Q`@````````````#?`@``LP0```````#D`@``
MS0````T````O!P```````&4$``#+!0```````-8```#@`0``A@$``#,%``#'
M`@``D@4``'(#````````WP8``%L%```E!@````````````#L``````````T%
M`````````````&T!```/`@```````*$&`````````````+P$``!@!P``@P(`
M`!`&``!+!P``T08``#T'````````DP$``,L$````````DP,````````Y`0``
MG`8``+D```"B`@``]0(``#T%```_!`````$``$\"``!>!P```````"`!``"9
M`0``T@,```0$``"X`@``OP,```````!Q!@``RP8``,\$``"3!@```````!H%
M``#E!0``J````#0!``#_!0``&08``/D#```Q!P``!0$``.4!```I`0``L@8`
M````````````J0(``,0#``#W!````````"P!``!(`@``G@4``!P````4`@``
MK0(``#`$``!L!```B`0``-`!``#7!```X@,``"T"``!D````*04``"8%``"Z
M`0``E@8``%`&```B`@``(0(``#@%``#F!```_08``/P&```0````6@0`````
M``!(`P``508```````!2!@```````.D%``"!`@``K@$``#(#````````'P8`
M`!<'`````````````+P```!-!0```````'X&``#)!0``YP(``*L&````````
MX08``!4"``#@!```G00`````````````^0$``)$"``#.!@``&P```'4```"P
M`P```````.@!``#O!```[`,``.,`````````H@```,L#``"P`@``E@,``)4&
M`````````````%H%``#F`P``;P0``%@$``#Y!0``'P4``"<'``"C!@``H00`
M`/T"``"D`@```````+4"``#_````N`,```(#``#L!```T04`````````````
M_`,``)4"``!E`0``?`8``$4'``#]!```PP$``,8!````````&`<``-T$````
M````704```````"_!@``>P(``+H$``#K`@``,P,``'0$``#=`P``:P$`````
M``#5!```YP,``/@!``"Z!0``ZP4```D`````````BP<``,@&``"^!```````
M``````!B`@``;0```%@``````````P```#X%```"!P```````/H&``##````
MPP(```````"8!@```````'<"````````/0,``````````````````,$"``"A
M`0``C@```$4%```T!0``,@<```8&``!H`@``)0(``$H%````````MP4````#
M````````U0,``"4'```T!P``BP(``(H!``#M!```D@8``!<!````````VP$`
M````````````I````&$&```5!0``A@(```````#L!0```````!T````=!@``
M`````+0!````````AP4`````````````D0,```H&```O`@``E`````````!W
M`0``/P$````````3!@```````%D%``!C!0``PP4``.0&``",!P```````.T%
M``#D!```M@0``/4&``"R!0```````"0%``!2`@``.@$```````#:`@``````
M`$<"```]!@``Y`4```````")!@``Y````,("``#]!0```````)`%``!'````
M[@4``$$#````````````````````````D0```#H'``!J`@``CP8``#@!``#F
M`0``B@(```````!;````AP```"`'``"U!0``XP$``*@"``#R````,P$``!H'
M``!L!P``A@4``%(#``#$`0````````````"F`0``Q`8```````!&`P``TP4`
M`*8`````````<P4``-8#``!B`0```````)4$````````\`````````"M!```
M`````/<!```F!P``N`4``(L!`````````````%$&``#;!0``'P,`````````
M````Z@0``)$!``"]!0``$`4``'<%`````````````"T'``"$`@``8`4`````
M```'````\`,``$0&````````%`4``%4$``"\!@``H@4````````'`@``+08`
M`'($``"$!P``,0,``%T&````````-0(``#,'````````%P``````````````
MM`0``,X```"8!0``O`(``"4!``!M!P``$0<``.X!``!0````:@8````````'
M!P``&`0``$L#``#Y!`````````````#K````#P0```4"````````$@(`````
M``![!```?0(```````"#`0``!P4````````?`@``K0,``#8'``##!```````
M`&(#```P!P``0@(``.X$``!@`````````'@%``!X`@``0@0```````!R````
M_`$``(($```^`P``G`4``/($``#E````W08````````]`0``J@,``#<`````
M`````````%0$````````)0```$T&```C!P``'@8``,4%````````8`,`````
M````````X0,``'$'``#W!0```````)X"``""!@``)P8```````#[````%00`
M``````!?!@``QP8``.H%`````````````)T&```+`P``$P,```````#+`@``
MV`4``"<$```2`P``-@8```````"7!0````````````!%````J`0``$X&```Q
M!0````````````#"````MP$``*\$```;`@```````'X%````````BP0``-("
M``"X````"P<```````#!````*@<````````:`@``U0```!`#``#X!@``]P,`
M`*<```!`!0``V`$``#<"``#$!0````````````#'!```Q0,``*D$````````
MWP````````"(!0``90,``&L``````````````.\```"V`0``4P,```````!8
M`0``````````````````I`4``'H&```"`@```````$D%```X`@``?@0``*L`
M````````E@4``#\#``#]`P``=`,````````(!```JP,``&<$``!/!0``S0$`
M`!$%````````R`,``*\!``!R`0```````/8&``````````````,!``!>`P``
M*0,```````!C!@``!@$```````"4`P``9@,``*($``")`@``;04``,X#``!<
M`@``[08```````!N`0``F00``,8```"A`P``A04``/4`````````OP````X`
M``!B!0```````'$%```3````F0```&L#````````#`8```````"@`P``[@8`
M``H$```Y`@```````%4!``"F!@``P04``,4```"#`P``"P8``"8&``!6!0``
M60(``)L!``"%!@``/@8``(`#``!]`0``,00``&<%``!W!@``@P8````````[
M!```?P0``"('```4!@``B@<```````#S`@``/`0``%0!````````Z0,``.8"
M````````)@```$T$```-`P```````````````````````%`'````````(@``
M`/@%``!G!@``+@```+P!`````````````'H"``"$`0``:0```$(%``"8````
M`````!P#````````[0$``(T"``#7`````````$D"`````````````&D'``!A
M`P``1@4``#X$```*`P``D@(`````````````?P<``$$%```>!```>P<``'4$
M```6`0``T@```"@&``!?`P``B`<```````!H!P``H04``)$&``#C!@``'`<`
M`$8$```L!P``=@```$D#``#/`0```````.@%```O`0``^@0``!`!```\````
M`````````````````````/(&``#O!0``P@4````````Z!0``Y@4````````3
M!P```````.$$``!F!0``*00`````````````R0,``'8$``"G`@```````!P!
M``!V!0``10$``,4&```(!P```````,P$``!(````!@```.T`````````A@0`
M`%D&```Z!```"P(``!0```">`0``4P4``/0$``!;!P``C0,```````#\````
M`````&$"``#A!0``&@8``/@`````````T`8``(@#``!T!@``&`,``"`%```\
M!@``80<``$<&``#Z`0``90(``%,'``!S!P``I`8```($``![````_P8``%H"
M````````:`0````````J!@``;0(``/`!```Z````*`(```````#A`@``````
M`````````````````($'``"Q`@``,@```"L!````````\@(```L!```@!```
M#P8``%$#``"B`0``>0<``+8&``#(````7`8``&P```"K`@```````$,#```#
M`@``90```%,&``"%`@```````'L#``"C`@``M0,``.D```"M`0````````L`
M```0!P``"04``*X$```N!0``9`$`````````````P`0```````!<!```E@``
M`.X#```\`@```````*X```!T!0```````&T$``"/`0```````/(!``!V!P``
M$0,``*T````7`P```````'L%``#1!```$@$``"P#``!=!```&0(``*8%``!M
M`P```````(T$```%````+@0```4%````````0P0```$#``!U!P``(P,``&H%
M```O`P``D`0`````````````````````````````50,```````#4`@``#@4`
M`$\#```[!@```````%D!````````IP$``.,%`````````````,H#``"3`@``
MJ@```.<$``"9`@``6`<`````````````E0,``'8"``#?!0``=@8```````"<
M!```]`(``&8`````````2@,```D#````````7`4``$0%``"Y!@``Y0,``%`"
M``"#!0`````````````^`@``M`,``/H#```V!```9`4``.@&```W`P``7`,`
M`,H$````````70,``$$"``"P!```I0,``"P`````````L04``.@$``#W`@``
M``````D$``"9`P``\P4``-@&````````#0(``/\"```1!@``B````!X!``"R
M`P``!`<``/D&``":!@``X@4`````````````H`$``"L&```,`0```````+L&
M``#5!0```````%\$``#M`@``GP8``+,#```(````1`(```\%```_`@``008`
M`*0$``!_`P``[`$``$8"``!(!```:P4````````E!0``S00``'X!````````
M`````#4#````````?`(``(8'````````C@(``-<#```5!@``S@0``",!````
M`````````*<$``!'!P```````,`!```G!0``!`8`````````````1@$``)8$
M```C````VP0````$``"[`@``J0$```````"P!@``+@$``$`$``"-!@``````
M`($$```````````````````9````C`0`````````````>00``$X$```G`P``
M'0$``.<%``#2!@``Y`,```````"5!0``DP4``'P%``#!!@````````8"``!'
M`P``O@(``(,'``!/!P````````4&``!>````&00````````!!@``_P$`````
M``#,````%@<``-(%````````;@0``,T&````````@@$``(D!````````*0(`
M`#0$``!"````=P<``/X$````````O0$``&H```!``@``OP0``+<&``#7`@``
M````````````````,@$``'X'``"0`0``0P(``(X!``"H!0``1@```#`#``"7
M`@``P0,``%8&`````````````!@```!I!```N@(``$X#``!6!P``````````
M``````````````````"I!0``=04``'("``#R!0```````%8"``!C`0``)P$`
M`-D&``!8!0``J0```%T'`````````````+D$```H`0``*P```(D$````````
M0@,````````Y`P``#@,``*P#``#K`0``*`4``&L&````````.08``"H%```!
M!P``;@(``!8"``"$!0```````)L```#/!@``UP8``$T!``"Z````6P8``#($
M````````U````(D'``#U`0```````$```````````````%\!```+!0``KP,`
M`$<!````````\0(```````#L`@``)`8``!H!`````````````(D%````````
MG04``'<```!Y!0``H@8``(L&``!\!``````````````R!@``?P8````````M
M!```.@,``!4#```Y!0``;`,``"L'``"`!P``@@4``)X$``!F!P``0P``````
M```^`````````.<```#;`@``=````'@#``"_!0```````,D"``#V!0``````
M`+X&``!]````J@$```````"!``````````````!X````E0$``#4$````````
M>0```*X"``#W`````````)L&``"J`@``/P```*(#``"W````-0$``'0'````
M````FP4```````!W`P```````+P%``!>!````"`H)7,@9&%Y<R!A9V\I`"`H
M06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R
M;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y
M+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD
M97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T
M`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG
M;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N
M`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O
M>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T
M('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@
M9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@
M0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S
M.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US
M('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O
M<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I
M;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I
M86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA
M=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@
M3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S
M`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B
M;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I
M<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C
M;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O
M>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD
M(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!0
M97)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L
M=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D
M('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H
M92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P
M(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA
M;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z
M`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!0
M97)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR
M96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-
M4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E
M(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@
M=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R
M8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A
M=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL
M9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I
M8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA
M;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)
M<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M
M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER
M960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E
M<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC
M871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N
M=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC
M871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE
M<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O
M;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N
M86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B
M(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"
M96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P
M<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C
M:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T
M:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H
M`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L
M9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`
M0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N
M+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L
M;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@
M;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S
M(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE
M<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U
M<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M
M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D
M('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H
M:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E
M<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@
M475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E
M<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA
M=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L
M>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED
M96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0
M:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O
M;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M
M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I
M;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F
M;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K
M+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`
M0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N
M(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G1S(&]F("(E
M<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I
M;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T
M92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S
M(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O
M=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O
M<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM
M90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE
M<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C
M=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O
M=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E
M<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`
M1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E
M8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`
M1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U<`!$
M96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@
M;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI
M<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(
M;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O
M<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I
M`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB
M;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`
M1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG
M;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`
M1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R
M(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U
M861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I
M;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%
M9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%:71H97(@
M96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R
M<VEO;CH@)7,N`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA
M:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@
M=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R
M:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN
M9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O
M<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P
M90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R
M92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`
M17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@
M(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&
M86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S
M`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N
M9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME
M`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I
M96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&
M:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L
M;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA
M;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L
M;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&
M;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O
M<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T
M=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@
M;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C
M:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N
M92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R
M`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U
M:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O
M;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`
M1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N
M97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!'
M:79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P
M<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX
M.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N
M`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N
M86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S
M`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S
M`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R
M;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N
M80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA
M<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE
M;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE
M`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E
M+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(
M;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S
M<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@
M(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ
M;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I
M`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET
M>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E
M<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I
M;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O
M;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`
M26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@
M=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z
M("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N
M=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R
M;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R
M="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS
M97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N
M97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L
M;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E
M9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!)
M;G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R
M="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H
M92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E
M<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O
M('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`
M26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N
M+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!)
M;G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M
M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V
M:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@
M<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI
M9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C
M:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U
M<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`
M26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER
M87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A
M96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`
M2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*879A<V-R:7!T(&AA<R!B965N(&1I
M<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@
M8F4@9&ES<&QA>6EN9R!C;W)R96-T;'DN`$IE<G-E>0!*;W)D86X`2G5L>0!*
M=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I
M9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA
M;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R
M:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T
M:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E
M82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS
M=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@
M475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,
M87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`
M3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$
M<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN
M($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK
M`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O
M;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A
M8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI
M=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES
M="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO
M9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA
M:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV
M97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E
M<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I
M;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA
M>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@
M;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E
M.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-
M971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC
M;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE
M(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N
M`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y
M(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG
M;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0
M:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D
M>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N;GD`36]V92!$
M;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO
M=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`
M375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT
M`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,
M87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA
M`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S
M`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),
M`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`
M3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N
M86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W
M($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@
M<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N
M)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S
M`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A
M9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.
M;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.
M;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U
M97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.
M;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M
M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R
M('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN
M`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.
M;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S
M=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@
M=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@
M*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES
M;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C
M=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`
M3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU
M;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.
M=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R
M96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD
M(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S
M<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U
M;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES
M=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N
M:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N
M<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ
M36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP
M=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN
M`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-
M(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE
M;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y
M`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S
M="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD
M:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE
M=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N
M<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E
M=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0
M;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\
M8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E
M82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U
M;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L
M9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I
M<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R
M9V4@;65S<V%G97,`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@
M*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN
M($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`
M4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL
M>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C
M=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2
M969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E
M<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!"
M;&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P
M86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`
M4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N
M`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N
M<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?
M=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T
M92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R
M=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP
M=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S
M<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K
M=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG
M=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N
M`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG
M:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U
M<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!3
M96QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3
M`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N
M96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!3
M97-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE
M>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U
M;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@
M;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L
M92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H
M92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R
M;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN
M:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E
M`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN
M=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N
M;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA
M=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O
M;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E
M<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P
M86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG
M(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@
M;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R
M97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@
M:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B
M+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`
M4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`
M4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z
M(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M
M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W
M961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@
M16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3
M970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA
M<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U
M<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B
M(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT
M($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H
M86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES
M=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E
M;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG
M(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S
M86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E
M<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9
M;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI
M:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R
M;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N
M"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L
M9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N
M;W0@97AI<W0N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P
M('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL
M86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E
M;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H
M)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D
M971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T
M:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O
M9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@
M=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES
M(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R
M;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE
M;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE
M(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE
M<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A4
M34P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N
M>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P
M`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4
M;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@
M`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO
M;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E
M<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T
M;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N
M86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ
M("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P
M>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D
M960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A
M8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S
M`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N
M`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R
M<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N
M;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R
M('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC
M86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O
M(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E
M="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E
M<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@
M9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E
M<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!3
M4TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E
M<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I
M<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@
M9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M
M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D
M:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T
M:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E
M<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@
M;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!6
M87)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`
M5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I
M;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A6
M25-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W
M(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S
M+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY
M('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!
M3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!7
M87)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I
M9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M
M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y
M+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T
M(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q
M=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P
M:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E
M>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H
M.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I
M;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N
M=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!9
M96%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T
M:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U
M(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX
M+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S
M8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O
M8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C
M;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A
M;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S
M`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT
M:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N
M=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@
M>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@
M;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V
M:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!4
M97AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!
M9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O
M=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O
M=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M
M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R
M<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L
M;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T
M`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R
M871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A
M(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I
M;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO
M<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T
M(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S
M(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@
M:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E
M;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P
M<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E
M<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<W=I=&-H(&]F
M9B!J879A<V-R:7!T`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y
M(&9A:6QU<F4`=')Y(&%G86EN`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z
M`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+6-V
M<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI0
M3U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#8M,#,M,S`@,38Z,3$K,#,P,`I,87-T+51R86YS
M;&%T;W(Z(%1O;VUA<R!!87,@/'1O;VUA<RYA87-`;6%I;"YE93X*3&%N9W5A
M9V4M5&5A;3H@17-T;VYI86X@/&1E=D!L:7-T<RYH;W)D92YO<F<^"DU)344M
M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ,PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M"@`@*"5S('#D979A('1A9V%S:2D`("A+:6ER:VQA:'8@)7,I`"`H)7,@<.1E
M=F$@<.1R87-T*0`@*'3D;F$I`"`H:&]M;64I`"`H96EL92D`(&MI:7)U<V5G
M82``(B5S(B!E:2!O;&4@:V%T86QO;V<N`"(E<R(@96D@;VQE(';U:6UA;&EK
M('9A;&EK+@`B)7,B(&5I(&]L92!(;W)D92!R96=I<W1R:7,@:.3D;&5S=&%T
M=60N`"(E<R(@<'5U(&5S:71A:F%T(&5I(&QE:71U9"X`(B5S(B!L:7-A=&D@
M9W)U<'!I9&4@<_QS=&5E;6DN`"(E<R(@;&ES871I(/5I9W5S=&4@<_QS=&5E
M;6DN`"(E<R(@96D@;&]O9'5D.B`E<RX`)2XR9DU"(&MA<W5T871U9"!K;VMK
M=2`E+C)F34(M<W0@*"4N,F8E)2D`)60@)7,@:F$@)7,`4VEN=2!P87)O;VP@
M865G=6(@)60@<.1E=F$@<.1R87-T+@`E9"!PY&5V82!E;FYU<W1U<P`E<R`M
M(%3D:&5L97!A;G4`)7,@<_5R;65JY&QG`"5S($M"`"5S(&AO;VQD=7-T]O9D
M("T@:VEN;FET=7,`)7,@<&%I9V%L9'5S`"5S(&MO;G1O('1A;W1L96UI;F4`
M)7,@:V%S=71U<W1I;F=I;75S960`)7,@;VX@:G5B82!O;&5M87,N`"5S(&MI
M:7)U<V5G82`E<R`E<P`E<R!O;B!V86QM:7,@=&5G96UA(&%L;'!O;VP@;&]E
M=&QE='5D(&AO;VQD=7-T]O9D+B!-Y')G:7-T82!T]O9D+"!M:61A('-O;W9I
M9"!P<F%E9W4@=&5H82X`)7,@;VX@:V]H=7-T=7-L:6L`)7,@;6EN=71I=``E
M<R!E:2!L96ET=60N`"5S(&MU;FD@)7,@)7,M<W0`2V%S=71A:F$@)7,@86%D
M<F5S<VER86%M870`2V%S=71A:F$@)7,@:V%L96YD97(`2V%S=71A:F$@)7,@
M;>1R:VUE9`!+87-U=&%J82`E<R#\;&5S86YD960`)7,Z("5S`"5S.B!3964@
M=&5A9&4@96D@<')U=6=I(&]L;&$@<V%A=&IA;'0L(&ME;&QE;'0@<V5E('!A
M:7-T86(@;VQE=F%T+B#$<F$@:VEI<G5S=&$@:VSU<'-A;6$@<V5L;&5S(&5S
M:6YE=F%I9"!L:6YK92!V]6D@97-I=&%M82!S86%T:F%L92!M:6YG:71I<VEK
M;&EK:W4@:6YF;W0N`"P@='5U;&5I:6QI9"``+"!T=75L96EI;&ED("5S("5S
M`"P@=F%H96UI:W5S("5S(&MU;FD@)7,`+2T@=F%L:2`M+0`Q,BUT=6YN:6YE
M(&5S:71U<P`R-"UT=6YN:6YE(&5S:71U<P`R-"!T=6YD:0`\165L;6EN90!3
M964@8FQO:VL@=F%J86(@86YD;65B86%S:2!T=6=E+@!*=6AT=7,@:V]H=71A
M=B!V:6=A`$MI<FIA(&MR_'!T965R:6UI<V5K<R!O;B!V86IA(&%V86QI:VMU
M(%!'4"!V]71I="X`06QL:VER:F$@:V]N=')O;&QI;6ES96MS(&]N('9A:F$@
M879A;&EK:W4@4$=0(';U=&ET+@!+<OQP=&5E<FET=60@:VER:F$@879A;6ES
M96MS(&]N('9A:F$@879A;&EK:W4@4$=0(';U=&ET+"!S86QA:F%S="!01U`@
M=O5T:70@:F$@<V%L87/U;F$N`$MI<FIA(&%L;&MI<FIA<W1A;6ES96MS(&]N
M('9A:F$@879A;&EK:W4@4$=0(';U=&ET+"!S86QA:F%S="!01U`@=O5T:70@
M:F$@<V%L87/U;F$N`$MR_'!T965R:71U9"!K:7)J82!A=F%M:7-E:W,@;VX@
M=F%J82!A=F%L:6MK=2!3+TU)344@=O5T:70L('-A;&%J87-T(%,O34E-12!V
M]71I="!J82!S86QA<_5N82X`2VER:F$@86QL:VER:F%S=&%M:7-E:W,@;VX@
M=F%J82!A=F%L:6MK=2!3+TU)344@=O5T:70L('-A;&%J87-T(%,O34E-12!V
M]71I="!J82!S86QA<_5N82X`2VER:F$@:W+\<'1E97)I;6ES96MS(&]N('9A
M:F$@879A;&EK:W4@4R]-24U%(';U=&ET`$5,('!I;'9I;F4`14P@:V5R9V4@
M=FEH;0!%3"!V:6AM`$5,(&AO;W9I:&T`14P@='5G978@;'5M97-A9'4`14PO
M4$P`05!)($E$`%-E;&QE(&5D:71O<FD@:6YF;P!);F9O+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`5D93(&MA=&%L;V]G:2!L;V]M:7-E:W,@:G5U<F1E<.3D
M<R!K965L871U9`!61E,@9F%I;&D@;&]O;6ES96MS(&IU=7)D97#DY',@:V5E
M;&%T=60N`$MO;G1O(&EN9F\`2V]N=&\@<V%L87/U;F$`2V]N=&\@;'5K=7-T
M871U9"X`4F%A;6%T=7!I9&%M:6YE`$QI<V$`3&ES82!A;&%M9W)U<'``3&ES
M82!A;&%M]6EG=7,`3&ES82!S:6EA.@!,:7-A('5U<R!G<G5P<`!,:7-A('5U
M<R#U:6=U<P!,:7-A(&=R=7!P("(E<R(@86QL80!,:7-A(/5I9W5S("(E<R(@
M86QL80!,:7-A('5U<R!K87-U=&%J83H`3&ES82!V965R9P!,:7-A('5U960@
M;&EI:VUE9`!,:7-A('!A87(`5&5E("5S(&UE;OS\($UO>FEL;&$@:_QL9W)I
M8F%K<P!,:7-A(&%A9')E<W-I<F%A;6%T=7-S93H`3&ES82!M:6YU(&%A9')E
M<W-I<F%A;6%T=7-S90!,:7-A(&MA<W5T86IA`"(E<R(@;&ES871I('/\<W1E
M96UI+"!K=6ED('3D:65N9&%V870@;&EI='5M:7-I;F9O="!P;VQN=60@=O5I
M;6%L:6L@;&ES861A.B`E<RX`(B5S(B!L:7-A=&D@<_QS=&5E;6DN($[\_&0@
M=O5I9"!S:7-S92!L;V=I9&$N`$MA<W5T86IA=&4@;&ES86UI;F4@<&]L92!L
M=6)A='5D+@!!861R97-S`$%A9')E<W-I<F%A;6%T`$AA;&1U<R`M(&UU=61A
M('1E:7-T92!K87-U=&%J871E(/5I9W5S:0!(86QD=7,`4F5K;&%A;0!!9F=A
M;FES=&%N`$%L8F%A;FEA`$%L>F5E<FEA`$%L:6%S`$IO;VYD=7,`2F]O;F1U
M<SH`2_5I:P!+]6EK('-I<W-E;&]G:71U9"!K87-U=&%J860`2_5I:R!G<G5P
M:60`2_5I:R#U:6=U<V5D`$OU:6L@;F5L:2!K_&QG90!,=6)A(&UI='5T(&%A
M9')E<W-I`$QU8F$@;>3D<F%T82!JY')J97-T871U9"!L;V5N9&D@=/S\<`!/
M;B!J=6)A(&]L96UA<P!!;'1E<FYA=&EI=FYE($E-4U`@:V]N=&\`06QT97)N
M871I:79N92!)35-0('-A;&%S]6YA`$%L=&5R;F%T:6EV;F4@24U34"!K87-U
M=&%J86YI;6D`06QT97)N871I:79N92!E+7!O<W1I(&%A9')E<W,`06QT97)N
M871I:79S960@;6%L;&ED`$%L=&5R;F%T:6EV;F4@=&5K<W0Z`$%M965R:6MA
M(%-A;6]A`%-I<V5S=&%T:2!L=6)A;6%T=2!VY.1R='5S+@!*=6AT=7,@='5N
M9&UA='4@=FEG80!!;F1O<G)A`$%N9V]O;&$`06YG=6EL;&$`06YO;OS\;6YE
M('9A:&5N9&%J80!687-T=7,`06YT87)K=&EK80!!;G1I9W5A(&IA($)A<F)U
M9&$`4F%K96YD=7,`4F%K96YD=7-T92!N:6UE:VER:0!286ME;F1U<R!O;B!T
M]O9V86QM:7,N`%)A:V5N9&$@86QA;6IA9W5D96QE`$MI;FYI=&$`3&EG:6MA
M=61N92!S=75R=7,`07!R:6QL`$%R86%B:6$@*%=I;F1O=W,M,3(U-BD`07)H
M:6EV:2!S=75R=7,`07)H:6EV:2!N:6UI`$]L960@<V$@:VEN9&5L(&5T('-O
M;W9I9"`E<R!L:6ET=6UI<W-O;W9I(&MU<W1U=&%D83\`3VQE9"!S82!K:6YD
M96P@970@<V]O=FED(&MU<W1U=&%D82!G<G5P:2`B)7,B(&IA(&OU:6L@=&5M
M82!A;&%M9W)U<&ED/P!!<F=E;G1I:6YA`$%R;65E;FEA`$%R;65E;FEA("A!
M4DU30TE)+3@I`$MU;G-T`$%R=6)A`$QI:&%V]71T97-A87(`05-#24D@:F]O
M;FES='5S`$%A<VEA+U9A:6MS92!O;VME86YI('!I:7)K;VYD`$O\<VD@:&]O
M;&1U<W3V]F1E('1E9V5M:7-E:W,@:VEN;FET=7-T`%9E97)U9`!+871S92!K
M=7-T=71A9&$@;VQE;6%T=70@9W)U<'!I+@!+871S92!K=7-T=71A9&$@;VQE
M;6%T=70@]6EG=7-T+@!+871S92!M=75T82!O;&5M871U="#U:6=U<W0N`$MA
M='-E(&UU=71A(&]L96UA='5T(&IA9W4N`$%T<FEB=75D:60`075G=7-T`$%U
M<W1R86%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@=F%J86QI:VMU($E-05`@
M;&%I96YD=7-T(&5I(&QE:71U9"X`075T:%]C>7)U<SH@<_QS=&5E;6EL('!U
M=61U=F%D('9A:F%L:6MU9"!V]6EM960N`$%U=&A?8WER=7,Z('9A:F%L:6MK
M=2!)34%0(&QA:65N9'5S="!E:2!L96ET=60N`$%U=&A?9G1P.B!686IA;&EK
M:W4@1E10(&QA:65N9'5S="!E:2!L96ET=60N($MO;7!I;&5E<FD@4$A0(';U
M=&UE9V$@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z(%9A:F%L:6MK=2!)34%0
M(&QA:65N9'5S="!E:2!L96ET=60N`$%U=&A?:W)B-3H@5F%J86QI:VMU(&MR
M8C4@;&%I96YD=7-T(&5I(&QE:71U9"X`075T:%]L9&%P.B!!8W1I=F4@1&ER
M96-T;W)Y)W-S92!K87-U=&%J871E(&QI<V%M:7-E('1U9VD@<'5U9'5B`$%U
M=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>7-T(&MA<W5T86IA=&4@965M86QD
M86UI<V4@='5G:2!P=75D=6(`075T:%]L9&%P.B!686IA;&EK:W4@3$1!4"!L
M86EE;F1U<W0@96D@;&5I='5D+@!!=71H7VQD87`Z($5I('-A82!L:7-A9&$@
M:V%S=71A:F%T("5S+B!397)V97(@_'1L97,Z(`!!=71H7VQD87`Z($5I('-A
M82!E96UA;&1A9&$@:V%S=71A:F%T("5S`$%U=&A?;&1A<#H@16D@<V%A(&UU
M=71A(&MA<W5T86IA="`E<P!!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GD@
M:V%S=71A:F%T92!M=75T;6ES92!T=6=I('!U=61U8BX`075T:%]M8V%L.B!6
M86IA;&EK:W4@34-!3"!L86EE;F1U<W0@96D@;&5I='5D+@!!=71H7W-M8F%U
M=&@Z(%9A:F%L:6MK=2!S;6)A=71H(&QA:65N9'5S="!E:2!L96ET=60N`%-I
M<W-E;&]G:6UI;F4@;G5R:G5S`%-I<W-E;&]G:6UI;F4@;G5R:G5S+B`E<P!2
M041)55,@<V5R=F5R(&5I(&QU8F%N=60@<VES<V4@;&]G:61A+@!&5%`@<V5R
M=F5R:7-S92!S:7-S96QO9VEM:6YE(&YU<FIU<RX`4TU"('-E<G9E<FES<V4@
M<VES<V5L;V=I;6EN92!N=7)J=7,N`$MA<W5T871A=F%D(';D;&IA9#H`07-E
M<F)A:61Z86%N`$)/1D@@971T96ODY&YD960`5&%U<W0`5&%U<W1A(';D<G8`
M5F%L92!K97)B97)O<V4@<V%L87/U;F$N`%9A;&4@:V5R8F5R;W-E(&MA<W5T
M86IA;FEM:2X`0F%H86UA`$)A:')E:6X`0F%L=&D@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$=R86%F:6MA('#U:&EK871A;&]O9VD@(B5S
M(B!E:2!L96ET=60N`$)A<V5L:6YE`%9A;&=E=F5N90!"96QG:6$`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`%/\;FYI<.1E=@!";&]K:VD@(B5S(B!R
M86ME;F1U<V5S("(E<R(@96D@;&5I='5D+@!";&]K:2!HY.1L97-T=7,`0FQO
M:VD@=/S\<`!086MS(&MI<FD`0F]L:6EV:6$`2N1R:F5H;VED:F%D`%!I:7)J
M;V]N`$IO;VYE('!A:W-U<SH`4&EI<FIO;VYE9`!";W-N:6$@:F$@2&5R='-E
M9V]V:6EN80!-]6QE;6%D`$)O='-W86YA`$%L;&$`0F]U=F5T('-A87(`0G)A
M<VEI;&EA`$)R:71I($EN9&EA($]O:V5A;FD@5&5R<FET;V]R:75M`$)R=6YE
M:2!3=6QT86YI<FEI:P!"=6QG86%R:6$`3&]E=&5L=0!"=7)K:6YA($9A<V\`
M0G5R=6YD:0!3:7-U:&%L9'5S`$-20P!4_&AI<W1U<VYI;65K:7)J82!J86]T
M=7-P=6YK=&ED`$Q?86AT<FD@;VUA9'5S960N+BX`5F%H96WD;'4@:6YI='-I
M86QI<V5E<FEM:6YE(&5I(&KU=61N=60@;/5P=6QE+@!+86QE;F1E<@!686EK
M;F4`2V%M8F]D>FAA`$MA;65R=6X`4&%R;V]L:2!E:2!S86$@875T;VUA871S
M96QT('3\:&ES=&%D82P@=O5T82#\:&5N9'5S="!A9&UI;FES=')A871O<FEG
M82X`16D@]6YN97-T=2!K:7)J=71A9&$@9F%I;&D@(B5S(@!6Y&QI<V5I9"!S
M97-S:6]O;FEH86QD=7)E:60@<&]L92!V]6EM86QI:R!A9&UI;FES=')E97)I
M9&$N`$5I('-A82#\:&5N9'5S="!)34%0('-E<G9E<FEG83H@)7,`16D@]6YN
M97-T=2!A=F%D82!F86EL:2`B)7,B`$MA;F%D80!,;V]B=0!,;V]B=0!%:2#U
M;FYE<W1U(&MU<W1U=&%D82!F86EL:2`B)7,B+@!%:2!L96EA(&%J=71I<W0@
M:V%T86QO;V=I`$EL;6$@)W1A<F=E=$9I;&4G('!A<F%M965T<FET82!E:2!S
M86$@:N1T:V%T82X`16D@]6YN97-T=2!E96UA;&1A9&$@:V%T86QO;V=I("(E
M<R(N`$5I('-A82!E96UA;&1A9&$L("5D+6P@;VX@86QL=79A:60N`$5I('-A
M82#\;6)E<B!JY')J97-T861A+"#\;6)E<FKD<FIE<W1A;6ES96MS(&WDY')A
M='5D(&MA;FYE=&4@87)V(&5I(&ML87!I('-A;'9E<W1A='5D(&%R=G5G82X`
M16D@<V%A('-U=6YA=&$@=&5A9&5T(&WDY')A='5D(&YU;6)R:6QE+@!2;VAE
M;&ES92!.965M92!S86%R960`4&5A;&MI<FD`5&5E;G5S97!A:VMU:F$`2V%T
M96=O;W)I860@:F$@;>1R9V5N9&ED`$-A>6UA;FD@4V%A<F5D`$UO8FEI;'1E
M;&5F;VX`3&%H=')I(&]M861U<V5D`$QA:'1R:2!V;V]D97)D=7,Z`$QA:'1R
M:2!O;6%D=7-E9`!,86AT<FET92!V86AE:V%U9W5S.@!-;V)I:6QT96QE9F]N
M`$ME;'1I("A)4T\M.#@U.2TQ-"D`2V5S:V5L90!+97-K+4%A9G)I:V$@5F%B
M87)I:6L`2V5S:RU%=7)O;W!A("A)4T\M.#@U.2TR*0!397)T:69I:V%A9&D@
M_&MS:6MA<VIA9`!397)T:69I:V%A9&D@;VUA;FEK`%-E<G1I9FEK86%D:2!P
M;VQI:71I:V%D`%1S:&%A9`!-=75D80!-=75D82!S86QA<_5N80!-=75D82!N
M:6UE(&IA(&%A9')E<W-I(&UI9&$@:6YI;65S960@;N1E=F%D(&MU:2!N860@
M<VEN=2!K:7)J=2!L;V5V860@:F$@;F5I;&4@=F%S=&%V860N`%/\<W1E96UI
M(&MO;F9I9W5R871S:6]O;B!E:2!V]6EM86QD82!S86QA<_5N82!M=75T82X@
M5O5T82#\:&5N9'5S="`@861M:6YI<W1R86%T;W)I9V$N`$WD<FL`7TMO;G1R
M;VQL:2!L:6YK:2XN+@!4<VAI:6QI`$AI:6YA`$AI:6YA(&QI:'1S=7-T871U
M9"`H1T(R,S$R*0!(:6EN82!T<F%D:71S:6]O;FEL:6YE("A":6<U*0!686QI
M(')A:V5N9'5S.@!686QI('-A;&%S]6YA`%9A;&D@:V%S=71A:F%N:6UI`%9A
M;&D@:W5U<.1E=F%D92!E<VET=7-V:6ES.@!686QI(&QO96YD:2!S=&EI;"`H
M:N1R:F5S=&%T=60@;&]E;F1I=&4@:F%O:W,I`$KU=6QU<V%A<F5D`$ML87-S
M:2`E<R!K:7)J96QD=7-T(&5I(&QE:71U9"X`4V5L9V4`165M86QD82!-4T]F
M9FEC92!MY')G96YD:60`5/QH:F5N9&$@<.1R:6YG`$5E;6%L9&$@:V%S=71A
M:F$Z("5S`$5E;6%L9&$@:V%S=71A:F$`5/QH:F5N9&$@:V%S=71A:F$@86YD
M;65D`-5H='5L('-E;&=I;F5B`$ML]7!S82!JY'1K86UI<V5K<P!#;&EC:V%T
M96QL(/QL92!(5%10`%-U;&4@86ME;@!0:6QV960`2&]M;6EK=6P@<&EL=F5S
M`%!I;'9E<P!+;V]K;W-S86%R960@*$ME96QI;F=I('-A87)E9"D`4&5I9&$@
M:_QL9W)I8F$`4&5I9&5T=60@<&EI<FIO;VYE9`!+;VQU;6)I80!6Y')V`%;D
M<G9I=F%L:6L`5N1R=FD@=F%L:6L`5F5E<F=E.@!6965R9W5D92!P96%L:VER
M:F%D`$MO;VUI:W-I9`!+Y'-K`$OD<W5R:61A`$MO;6UE;G1A87(`3&EH=&YI
M;6D`2V]M;V]R:60`1FER;6$`07)V=71I9`!);&T`26QM`$MO;F9I9W5R871S
M:6]O;FD@97)I;F5V=7-E9`!396%D:7-T=7,@<_QN:W)O;FES965R:6UI<V5K
M<R!01$%D92P@;G5T:71E;&5F;VYI9&4@:F$@3W5T;&]O:VEG82X`4V5A9&ES
M='5S(&]N(&%E9W5N=60N`%-E861I<W1A("5S`$MI;FYI=&$@<V%L87/U;F$`
M2V]N9V\`2V]N9V\@1&5M;VMR86%T;&EK(%9A8F%R:6EK`-QH96YD=7,@;G5R
M:G5S+@#<:&5N9'5S(&YU<FIU<SH@`$%V86QI:R!V]71M97-E<G9E<B!E:2!A
M;FYA(/QH96YD=7-T+@!!=F%L:6L@=O5T;65S97)V97(@96D@86YN82#\:&5N
M9'5S="X@4/5H:G5S.B`E<R`H)7,I`-QH96YD=7,@1E10('-E<G9E<FEG82!N
M=7)J=7,N`$MO;G1A:W1I9`!+;VYT86MT:60@]6YN97-T=7,@;&ES861A('-I
M;G4@86%D<F5S<VER86%M871U<W-E+@`B)7,B('-I<W4`2N1T:V$`0V]O:VD@
M4V%A<F5D`$WU='1E=&5R80!+;W!E97)I`$MO<&5E<FEM:6YE(&YU<FIU<SH@
M)7,`2V]P965R:2!V86QI:P!#;W-T($E$`$MO<W1A<FEI:V$`0V]T92!D)TEV
M;VER90!%:2!S86%N=60@:VER:F$@4$=09V$@:W+\<'1I9&$N`$5I('-A86YU
M9"!K:7)J82!01U!G82!A;&QK:7)J87-T861A+@!%:2!S86%N=60@:VER:F$@
M4R]-24U%9V$@:W+\<'1I9&$N`$5I('-A86YU9"!K:7)J82!3+TU)345G82!A
M;&QK:7)J87-T861A+@!%:2!S86%N=60@;&ES861A(&MO;G1A:W1I+B`E<P!%
M:2!S86%N=60@<VES<V4@3$1!4"!S97)V97)I<W-E+@!%:2!S86%N=60@<VES
M<V4@3$1!4"!S97)V97)I<W-E`$5I('-A86YU9"!K;VYT;VKDY&MI(&MO;G1R
M;VQL:61A+B`E<P!%:2!S86%N=60@_&AE;F1U<W0@3$1!4"!S97)V97)I9V$N
M`$5I('-A86YU9"!S97)V97)I9V$@(B5S(B!&5%`@86)I;"#\:&5N9'5S=#H@
M)7,`2F%O='5S;FEM96MI<FIA(&QO;VUI;F4@;G5R:G5S+B`E<P!%:2!S86%N
M=60@4$=0(&%N9&UE:60@9&5K<OQP=&ED82X`16D@<V%A;G5D(%,O34E-12!A
M;F1M96ED(&1E:W+\<'1I9&$N`$5I('-A86YU9"!K=7-T=71A9&$@:V]N=&%K
M=&DN("5S`$5I('-A86YU9"!K=7-T=71A9&$@:F%O='5S;FEM96MI<FIA+B`E
M<P!%:2!S86%N=60@:W5S='5T861A('!A:6=A;&1U<V4@=75E;F1A;6ES92!S
M:W)I<'1I("(E<R(N`$5I('-U=71N=60@=N1L:F$@<V5L9VET861A(&%D<F5S
M<V%A9&D@92UP;W-T:2!A861R97-S`$MO9W4@86%D<F5S<VER86%M871U(&MO
M:&%L971I<FEM:6YE(&YU<FIU<RX`2V]G=2!J86]T=7-N:6UE:VER:F$@:V]H
M86QE=&ER:6UI;F4@;G5R:G5S+@!+;V=U(&IA;W1U<VYI;65K:7)J861E(&YI
M;65K:7)J82!K;VAA;&5T:7)I;6EN92!N=7)J=7,N`$5I(/5N;F5S='5N=60@
M;&%A9&ED82!S=')A=&5E9VEA="`B)7,B+@!M:V1I<B`B)7,B(&YU<FIU<RX`
M16D@<V%A;G5D(';U=&UE<V5R=F5R:7-T(&%V86QI:VMU(';U=&ET(&OD='1E
M+@`B)7,B(&%V86UI;F4@:VER:G5T86UI<V5K<R!N=7)J=7,N`"5S(&%V86UI
M;F4@;G5R:G5S+@!%:2!S=75T;G5D(&OD:79I=&%D82!H;V]L9'5S=/;V(&UO
M;V1U;&ET("5S`$5I('-A86YU9"!A=F%D82!K871A;&]O9VD@(B5S(BX`16D@
M<V%A;G5D(&OD='1E($Q$05`@<V5R=F5R:70N`"5S(&QU9V5M:6YE(&YU<FIU
M<RX`4V]O=FET=60@:V%S=71A:F$@<&%R;V]L:2!T_&AJ96YD86UI;F4@;G5R
M:G5S+B!-]6YE9"!A;F1M960@96D@;VQE(/5I9V5D+B!0<F]O=FD@=75E<W1I
M(';U:2!V]71A(/QH96YD=7-T(&%D;6EN:7-T<F%A=&]R:6=A+"!K=6D@=F%J
M860@<VEI<VMI(&%B:2X`04-,:2!L86%D:6UI;F4@96)A]6YN97-T=7,`06%D
M<F5S<VER86%M871U(&QA861I;6EN92!E8F'U;FYE<W1U<RX@)7,`2F%O='5S
M;FEM96MI<FIA(&QA861I;6EN92!E8F'U;FYE<W1U<RX@)7,`2F%O='5S;FEM
M96MI<FIA9&4@;&%A9&EM:6YE(&5B8?5N;F5S='5S+B`E<P!397)V97)I(';U
M:6UA;'5S=&4@;&%A9&EM:6YE(&5B8?5N;F5S='5S`$MO;F9I9W5R871S:6]O
M;FD@=&%G87-I;75U=&UI;F4@;G5R:G5S+@!R;61I<B`B)7,B(&5I(/5N;F5S
M='5N=60N`"5S('-E861I<W1U<V4@<V%L=F5S=&%M:6YE(&YU<FIU<RX`2V]N
M9FEG=7)A='-I;V]N:2!V87)U:V]O<&EA('-A;'9E<W1A;6EN92!N=7)J=7,N
M`$MO;F9I9W5R871S:6]O;FD@=F%R=6MO;W!I82!S86QV97-T86UI;F4@;G5R
M:G5S.B`E<P!086EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:2!E:2!S86%N
M=60@<V%L=F5S=&%D82!K;VAT83H@(B5S(BX`16D@]6YN97-T=6YU9"!S86QV
M97-T861A(&MO;F9I9W5R871S:6]O;FEF86EL:2!V87)U:V]O<&EA="`E<RX`
M2V]N9FEG=7)A='-I;V]N:69A:6QI("5S(&5I(/5N;F5S='5N=60@<V%L=F5S
M=&%D82X@4V$@=O5I9"!K87-U=&%D82#\:'0@=O5I;6%L=7-T(&MO;V1I('-A
M;'9E<W1A;6ES96MS('1A9V%S:2!F86EL:2`E<R!V]6D@:V]P965R:61A(&MO
M;V0@:^1S:71S:2!F86EL:2`E<RX`3$1!4"!O='-I;F<@;G5R:G5S+@!U;FQI
M;FL@(B5S(B!N=7)J=7,N`$MO;G1A:W1I('5U96YD86UI;F4@;G5R:G5S+B`E
M<P!*86]T=7-N:6UE:VER:F$@=75E;F1A;6EN92!N=7)J=7,N("5S`"(E<R(@
M<V5A9&ES='5S92!S86QV97-T86UI;F4@;G5R:G5S.B`E<P!%:2!L96ED;G5D
M($UO>FEL;&$@:_QL9VER8F$N(%9A871A(&5T(&O\;&=R:6)A(&]L96MS(&%V
M871U9"X`2V%S=71A:F%L92`B)7,B(&5I('-A86YU9"!A;F1A(&KD<F=M:7-I
M(/5I9W5S96ED(&MA=7-T86QE("(E<R(Z("5S`%!I:7)A='5D('!I:VMU<V5G
M82!T96MS=`!2:6EK`$MU<G-U<V5D`$QO;P!,:7-A(&QI;FL`3&ES82!U=7,`
M3&ES82!A;&%M:V%U<W1A9`!!=71O<FD@]6EG=7-E9`!+<F5D:6ET:V%A<F1I
M(&YU;6)E<@!(;W)V86%T:6$`2W5U8F$`4')A96=U<V5D(#0@9F%A<VD`06MT
M:6EV<V5D('-E<W-I;V]N:60`2V5L;&%A96<`4')A96=U;F4@55),(&]N`$%K
M=&EI=G-E9"!K87-U=&%J860`4')A96=U;F4@:6QM`%!R865G=6YE(&EL;3H`
M4')A96=U;F4@<W1I:6P`2.3D;&5S=&$@=/9I9"!M:61A('1E:&%K<V4@<VES
M96YE;6ES96P@)7,M:2X`3/5I:V$`3/5I:V$@=F%L:6L`2_QP<F]S`$MI<FEL
M;&ET<V$@*$M/23@M4BD`2VER:6QL:71S82`H5VEN9&]W<RTQ,C4Q*0!+:7)I
M;&QI='-A+U5K<F%I;F$@*$M/23@M52D`5'-E:&AI(%9A8F%R:6EK`%!0`$13
M3B`H=F%A=&$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!)9V$@<.1E=@!$871A5')E
M92!S:7)V:6IA`$%N9&UE8F%A<VEO='-I;F<`2W5U<.1E=@!386%B=6UI<V4@
M:W5U<.1E=@!+=75PY&5V82!V86QI:P!0Y&5V`$MU7W-T=71A('9E97)G`$1E
M='-E;6)E<@!+_&UN96YD;G5M8G)I9`!6Y&AE;F1A('1A86YD<FED80!686EK
M:6UI<VD`5F%I:VEM:7-I(';D<G8`5F%I:V5I9&5N=&ET965T`%9A:6MI;6ES
M:2!S:&5L;`!3]6YA<V5L971U<V5D`$MU<W1U=&$`2W5S='5T82!L86AT97(`
M2W5S='5T82!G<G5P<`!+=7-T=71A(&QO9VD`2W5S='5T82#U:6=U<P!+=7-T
M=71A(&IA(&5E;6%L9&$@:VER:F%D`$MU<W1U=&$@;&%H=&5R`$MU<W1U=&$@
M=F5E<F<`2W5S='5T82!O;&5M87-O;&5V(&%L=&5R;F%T:6EV;F4@;6%L;`!+
M:7)J861E(&MU<W1U=&%M:6YE`$MU<W1U=&$@]6EG=7-E9"`B)7,B+6QE`$MU
M<W1U=&$@]6EG=7-E9"`B)7,B+6QE(&IA(&OU:6L@86QA;?5I9W5S960_`$MU
M<W1U=&$@<FED80!+=7-T=71A('9A;&ET=60@:61E;G1I=&5E=`!+=7-T=71A
M(&%K=&EI=FYE('9E97)G`$MU<W1U=&$@86MT:6EV;F4@<FED80!+=7-T=71A
M<VEN('!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I<'1I("(E<R(N`$OD='1E
M=&]I;65T86UI<V4@865G`%1A86YI`$MI<FIE;&1A('!R;V)L965M:0!+:7)J
M96QD=7,`W&MS:6MA<VIA9"`H:V%N='5D(&MA($AO<F1E(&QO9VEF86EL:2DZ
M`-QK<VEK87-J860@;&]G:71I(&%D;6EN:7-T<F%A=&]R:2!J86]K<RX`07)E
M;F1U<P!+87-T97!U;FMT`$5E;&UI<V4@='5N;FD@:V%S=&5P=6YK=`!+87-T
M97!U;FMT.@!3=75N9"!V87-A:W5L="!P87)E;6%L90!3=75N9"!P87)E;6%L
M="!V87-A:W5L90!+871A;&]O9P!%<VET82!K96QL86%J860@,C0M='5N;FES
M96YA`$5K<F%A;FD@<V5A9&5D`$[D:71A('#U:&IA;&EK:W4@96YN=7-T=7-T
M`$[D:71A(&5N;G5S='5S="`H5$%&*0!%:W)A86YI('-E861E9`!$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`Q')A(&MU<W1U=&$`Q')A(/QR
M:71A(&UA:6YT96YA;F-E+G!H<"!F86EL:2!O='-E(&OD:79I=&%D80!+=6D@
M97-I;65N92!R:61A('-I<V%L9&%B(';D;&IA9&4@;FEM97-I9"P@;>1R9VD@
M<V5E(')U=70Z`$1O;6EN:6-A`$1O;6EN:6MA86YI(%9A8F%R:6EK`%-U;"!P
M;VQE(&MO;G1O=#\@4F5G:7-T<F5E<G4N`%-A;'9E<W1A`%-A;'9E<W1A("5S
M`%-A;'9E<W1A(&QO;V1U9"!S96%D:7-T=7,@4$A0('-K<FEP=&EN82X`3FEM
M96MI<FD`4F%V:6UI9`!%+7!O<W0`12UP;W-T+5--4VEL92!V86AE;F1U<V1R
M86EV97(L('1E96YU<V5P86MK=6IA=&5L92!K96QL96P@<V5L;&EN92!T965N
M=7,@;VX`15)2`$5K=6%D;W(`375U9&$`375U9&$@8FQO:VMI`$UU=61A(&=R
M=7!P:0!-=75D82#U:6=U<W0`375U9&$@]6EG=7-I`$UU=61A("5S(/5I9W5S
M:0!-=75D82!S96%D96ED.@!-=75D82`B)7,B(/5I9W5S:0!-=75D82`E<R#U
M:6=U<VD`2&%R:61U<P!%9VEP='5S`$S\;&ET82!S964@<VES<V4@:F$@<VEI
M<SH@)7,L(';U:2!K87-U=&$@;&EH='-A="!(5$U,('9E<G-I;V]N:3H@)7,N
M`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`12UP;W-T`$4M<&]S=&D@86%D
M<F5S<P!%+7!O<W1I(&%A9')E<W-I9"!P96%V860@:VQA<'!I;6$N`$4M<&]S
M="!K:6YN:71U<V5G80!%+7!O<W0M4TU3:6QE(&S\_',`4VUA:6QI9`!3]6YU
M;2!O;B!T_&AI+@!4=6QE;75S(&]N('3\:&DN`$]T<VEN9W5T:6YG:6UU<R!O
M;B!T_&AI`$QU8F$@=&5K<W1I('-I<W-E(&QI<V%D82!P:6QT92!F;W1O9V%L
M97)I:61E<W0`3'5B82!P87)E;6ML]7!S=6=A(&C\<&EK;65N_/P`06%S=&$@
M;/5P<`!3=75R96YD82!E9&ET;W(`4VES97-T82!S86QA:F%N92!K_'-I;75S
M(&UI9&$@<VEN=6QT(&O\<VET86MS92!P87)O;VQI(&UU=71M:7-E:W,L(&[D
M:71E:W,@)VUI<R!O;B!S:6YU(&QE;6UI:VQO;VUA(&YI;6D_)SH`4VES97-T
M82!S:6EA('!I;&1I(%523`!3:7-E<W1A(&%L;&$@=.1H960Z`$5K=F%T;W)I
M86%L+4=I;F5A`$5R:71R96$`5FEG80!6:6=A(&)L;VMI(&QO;VUI<V5L.B`E
M<P!6:6=A('/\;FMR;VYI<V5E<FEM:7-A;FMR=2!K=7-T=71A;6ES96PZ("5S
M`%9I9V$@<_QN:W)O;FES965R:6UI<V4@;&]G:2!K=7-T=71A;6ES96PZ("5S
M`%9I9V$@<VES=2!L86%D:6UI<V5L.B`E<P!6:6=A('-A;&%S]6YA(&UU=71M
M:7-E;#H@)7,`5FEG82!E+7!O<W1I('1E871E<RX`5FEG82`B)7,B(&MI<FIU
M=&%M:7-E;"X`165S=&D`171I;V]P:6$`4F%H=G5S;&EK`$5U<F]O<&$`26=A
M(#$U(&UI;G5T:2!T86=A;G0`26=A(#(@;6EN=71I('1A9V%N=`!)9V$@,S`@
M<V5K=6YD:2!T86=A;G0`26=A(#4@;6EN=71I('1A9V%N=`!)9V%L('-I<W-E
M;&]G:6UI<V5L`$EG82!P;V]L92!T=6YN:2!T86=A;G0`2V]R9"!M:6YU=&ES
M`$[D:61I<W;DY')T=7-E9#H`2^1I=FET80!,86EE;F1A`$[D:71A(&O\;&=R
M:6)A`$]O=&%S:6X@)RDG`$]O=&%S:6X@;&EH='-A="!S]6YA(';U:2!J=71U
M;>1R:VED97,@;W1S:6YG=69R86%S:0!!96=U;6ES92!K=75PY&5V`$5K<W!O
M;F5N=`!496MS=&D@=N1R=@!396%D:7-T=7-E(/QL97-L86%D:6UI;F4@1E10
M(&MA=61U`$CDY&QE<W1U<V4@;&%A9&EM:6YE(&YU<FIU<RX`16D@<V%A;G5D
M(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A+@!%:2!S86%N=60@_&AE;F1U<W0@
M4TU"('-E<G9E<FEG82X`16D@<V%A;G5D(&MO<&5E<FED82`B)7,B+7-T+@!%
M:2!S86%N=60@:V]P965R:61A("(E<R(M:2X`575E(%-!4TP@_&AE;F1U<V4@
M;&]O;6EN92!N=7)J=7,N`$5I('-A86YU9"!T]7-T82`B)7,B+6DN`$5I('-A
M86YU9"!T:7)I9&$Z("5S`$AE80!&86QK;&%N9&D@<V%A<F5D("A-86QV:6EN
M:60I`$;DY')I('-A87)E9`!+;VAU=&%V('9I9V$Z`$9A:W,`1F%K<VED`%9E
M96)R=6%R`%1U;F1U8B!N86=U`%1U;F1U8B!N86=U.B``W&MS:6MU9"!V:6AM
M86AO;V0`W&MS:6MU9"!L=6UE<V%J=6AO;V0`1FEE;&0@;6%T<FEX`$9I9VQE
M="!#05!40TA!`$9I9VQE="!F;VYT`$9I9'II`$9A:6P`1F%I;&ED92!A<G8Z
M("5S(&9A:6P`1F%I;&ED92!A<G8Z("5S(&9A:6QI`$9A:6QI:&%L9'5R`$9A
M:6QI(&YI;6D`1F%I;&D@=F%L:6L`1F%I;&D@_&QE<VQA861I;6EN90!&86EL
M:61E(/QL97-L86%D:6UI<W0@96D@=&]E=&%T82X`1FEL=')I9`!3;V]M90!%
M<VEM96YE('!O;VP`17-I;65N92!V965R86YD`%/D:6QI=&$@<W5H90!0965G
M96QD80!(]6QJ=78`561U`$MA=&%L;V]G:2`E<R!P;VQE(&]L96UA<P!496MS
M=&D@=N1R=@!4;VET`%9E96)I;&5H:71S96IA=&5L92!M:7,@<&EL=&4@96D@
M=&]E=&$`16YN=7-T=7,@*%1!1BD`4.1E=F%D92!A<G8@*&]L9W4@]F5L9'5D
M(&5T('1A9V%S=&%T878@96YN=7-T=7,@<VES86QD86(@;FEI('#D979I(&MU
M:2#V:60[('-U=7(@87)V(';U:6(@8FQO:VD@;&%I86MS('9E;FET861A*0!5
M;G5S=&%S:60@<V%L87/U;F$_`%9O<FUI9`!+:6QD`$MI;&QU('3\_'``2VEL
M;'5D`$MI;&QU9"`R`$9O;W)U;6ED`$5D87-T=7,`4F4`4F%A;6ED`%!R86YT
M<W5S;6%A`%!R86YT<W5S;6%A+"!%=7)O;W!A+6]S80!0<F%N='-U<V4@1W5A
M:F%A;F$`4')A;G1S=7-E(%!O;/QN965S:6$`4')A;G1S=7-E($SU=6YA86QA
M9`!+96QL96QT`%-U=6YA9V$@`%#U:&IA;&EK(&MI<FIE;&1U<P!4Y&ES:W5U
M`%3D:7-N:6UI`$=A8F]N`$=A;&5R:6DL(&MU<W0@<&EL="!V]71T80!'86QE
M<FEI.@!'86UB:6$`1V5N97)E97)I("5S(&MO;F9I9W5R871S:6]O;@!'96YE
M<F5E<FET=60@:V]O9`!'<G5U<VEA`%-A:W-A;6%A`$=A86YA`$=I8G)A;'1A
M<@!%97-N:6UI`-QL9&ES960@<V5A9&5D`$UI;F4`1_9D96P`1V]O9VQE(&MA
M87)D:60`1V]O9VQE(&]T<VEN9P!(86QL=&]O;FED97-S90!+<F5E:V$`2W)E
M96MA("A)4T\M.#@U.2TW*0!'<O;V;FEM86$`1W)E;F%D80!'<G5P<&ED92!H
M86QD=7,`1W)U<'!I9&4@;FEM960@96D@=O5I(&]L;&$@=/QH:F%D`$=R;W5P
M7VQD87`Z($5I('-A82!L:7-A9&$@9W)U<'!I("5S+B!397)V97(@_'1L97,Z
M(`!'<F]U<%]L9&%P.B!%:2!S86$@:W5S='5T861A(&=R=7!P:2`E<P!'<F]U
M<%]L9&%P.B!%:2!S86$@;75U=&$@9W)U<'!I("5S`$=R=7!I9`!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86%L80!'=65R;G-E>0!+_&QA;&ES92#U:6=U<V5D
M`$O\;&%L:7-T97)A86UA=`!':6YE80!':6YE82U":7-S874`1W5A:F%A;F$`
M2%1-3`!(5$U,07)E82!K965L9'5B(&%R9W#\:W-L:6MU;'0@:W5S='5T86UA
M<W0@<F5A('9I:6UA<W0@;&%H=')I="X`2%1-3$%R96$@:V5E;&1U8B!A<F=P
M_&MS;&EK=6QT(&MU<W1U=&%M87-T('1A8F5L:2!V:6EM87-T('9E97)G=2X`
M2%1-3$%R96$@:V5E;&1U8B!A<F=P_&MS;&EK=6QT(&MU<W1U=&%M87-T('1A
M8F5L:2!V:6EM87-T(')I9&$N`$A45%`@875T96YT:6UI<W0@96D@;&5I='5D
M+@!(86EI=&D`4N1S:6%L9V]R:71M`$CD9W4`4.1I<P!0Y&ES960`2&5A<F1I
M('-A87(@:F$@36-$;VYA;&1I('-A87)E9`!2Y&YK(.1I:V5S971O<FT`2&5E
M8G)E82`H25-/+3@X-3DM."U)*0!+]7)G=7,`06)I`$5D:71O<FD@:V%S=71A
M;6ES92!A8FD`06)I;&EN90!P;V]L:V5R80!3:6EN(&]N(&9A:6QI(&%L9W5S
M`$OU<F=E`%]!=F%L96AT`%#\:&$@5&]O;"`H5F%T:6MA;FD@3&EN;G)I:6LI
M`$%V86QE:&5L90!+;V1U;F4@86%D<F5S<P!+;V1U:V%T86QO;V<`2V]D=6YE
M('1E;&5F;VX`2&]N9'5U<F%S`$AO;F=K;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!6:6=A<V5D("5S(%A-3"!A;F1M960@:VER:F%S("5S`$AO<F1E+TMO;&%B
M.B!/8FIE:W1I;&4@)7,@96D@=F%S=&$@_&MS:VD@:VER:0!(;W)D92]+;VQA
M8CH@16D@;&5I='5D(/QH=&MI("5S('3\_'!I(&]B:F5K=&D@:VER:F%S("5S
M`$AO<F1E+TMO;&%B.B#5;FYE<W1U<R!E96UA;&1A9&$@)7,@(B5S(@!(;W)D
M92]+;VQA8CH@26YT96=R871S:6]O;FEM;V]T;W(@=F%J86(@)V1O;7AM;"<@
M4$A0(&QA:65N9'5S=`!(;W)D92]+;VQA8CH@16D@<V%A(&QU=6$@=75T(%A-
M3"!P=75D(&]B:F5K=&D@)7,@:F%O:W,`2&]R9&4O2V]L86(Z($5I('-A82!E
M96UA;&1A9&$@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($5I(/5N;F5S='4@
M:&%N:VED82!-24U%($E$+60@)7,@=/S\<&D@;W-A(&IA;VMS`$AO<F1E+TMO
M;&%B.B!%:2!S86$@<_QN:W)O;FES965R:61A("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!%:2!S86$@<_QN:W)O;FES965R:61A(&IA9W5S:60Z("5S`$AO
M<F1E+TMO;&%B.B!4=6YD;6%T=2!J86=U("(E<R(`2&]R:7-O;G1A86QJ;V]N
M`$AO<FES;VYT86%L;F4@=F]O9&5R9'5S`$AO<FES;VYT86%L;F4Z`$MU:61A
M<R!S82!S:6EA('-A='1U<VED/R`H4&%L=6X@=&5A=&$A*0!+=6D@<&%L:G4@
M=F5E<F=E('-O;W9I:W-I9"#\:&5N9&%D83\`2W5I('!A;&IU(';D;&IU("AV
M965R9V4I(&]N/P!+=6D@<&%L:G4@<FED=2!S;V]V:6MS:60@_&AE;F1A9&$_
M`$YI:7-K=7,`3FEI<VMU<SH`2'5M;W)I<W1I9`!5;F=A<FD`24U!4"!P;W-T
M:V%S=&D@;&]O;6EN92!N=7)J=7,Z("5S`$E-05`@<&]S=&MA<W1I(&MU<W1U
M=&%M:6YE(&YU<FIU<SH@)7,`24U!4"!P;W-T:V%S=&D@:W9O;V1I(&QO;VUI
M;F4@;G5R:G5S.B`E<P!)4"!A861R97-S`$E0(&%A9')E<W,@<&]L92!T96%D
M82X`25`@86%D<F5S<R!E:2!K=75L=2!L=6)A='5D($-)1%(@8FQO:VMI+@!)
M4"!P:6ER86YG=2!R:6MK=6UI;F4N`$QI<V$@<FED82!?96YN90!)<VQA;F0`
M06EN=6QT(&EK;V]N:60`)7,@:6MO;VYI9`!):V]O;FED(&IA('1E:W-T`$ED
M96YT:71E961I(&YI;6DZ`$MU:2!S961A(/5I971I(&5I(&[D:61A=&$L("5S
M(&IA('-E92!A=F%T86MS92!U=65S(&%K;F%S+@!+=6D@<V$@:V%S=71A9"!)
M;G1E<FYE="!%>'!L;W)E<FET(&IA(&5I(&[D92#\;&1S92!I:V]O;F4L('-I
M:7,@<')O;W9I(&WD<FMI9&$@<V5E(')U=70L(&S\;&ET86UA:W,@<VES<V4@
M4$Y'(&SD8FEP86ES='9U<RX`2W5I('-A(&[D960@<V5D82!T96%D970@86=A
M('!I;'1I(&5I(&[D92P@<VEI<R!E:2!O<VMA('-I;G4@=F5E8FEL96AI='-E
M:F$@;N1I9&%T82!S961A('!I;'1I+"!M:61A('-O;W9I9"#\;&5S(&QA861I
M9&$N`%!I;&1I(&5E;'9A861E.@!0:6QD:2!54DP`4&EL9&D@55),.@!0:6QT
M(&=A;&5R:6ES=`!0:6QT(&=A;&5R:6ES=#H`4&EL9&D@_&QE<VQA861I;6EN
M90!0:6QD:60`26UP;W)T+"!S86UM("5D`$EM<&]R9&ET=60@=N1L:3H@)7,`
M26UP;W)D:71U9"!VY&QJ860Z`$QI<V$@<FED82!?<.1R87-T`$5S:71A=&D@
M=F%L92!T96=E=G5S92!K;V]D+@!686QE(&MA<W5T86IA;FEM:2!J82]V]6D@
M<&%R;V]L+@!686QE(&MA<W5T86IA;FEM:2!V]6D@86QT97)N971I:79N92!A
M861R97-S+B!0<F]O=FD@=75E<W1I(';U:2!V]71A(/QH96YD=7-T(&%D;6EN
M:7-T<F%A=&]R:6=A+@!3=75R96YD82!T86%N9')I9&$`26YD:6$`W&MS:6MU
M9"!K87-U=&%J860`26YD;VYE97-I80!);F9O`$EN9F]R;6%T<VEO;VX`5&5A
M=F4@96D@;VQE(&5N86T@:^1T=&5S86%D878N`$QI<V$@7W9E97)G('#D<F%S
M=`!,:7-A('!I;'0`3&ES82!T86)E;`!,:7-A(&C\<&5R;&EN:P!,:7-A('9E
M95]R9R!E;FYE`$QI<V$@=75S('9E97)G(&%K=&EI=G-E('9E97)U(&KD<F5L
M90!,:7-A('5U<R!V965R9R!A:W1I:79S92!V965R=2!E='1E`$QI<V$@=75S
M(')I9&$@86MT:6EV<V4@<F5A(&KD<F5L90!,:7-A('5U<R!R:61A(&%K=&EI
M=G-E(')E82!E='1E`$QI<V$@;/5I:R!P<F%E9W5S92!A<W5K;VAA(&KD<F5L
M90!,:7-A(&SU:6L@<')A96=U<V4@87-U:V]H82!E='1E`$QI<V$@86QT97)N
M871I:79N92!M86QL`%-I<V5S=&$@;6%I;&EA861R97-S(&MU:'4@<V%A:W,@
M<W5L;&4@=75E('!A<F]O;&D@<V%A=&$Z`$QI<V$@;&%H=&5R('#D<F%S=`!,
M:7-A(&QA:'1E<B!E;FYE`$QI<V$@=F5E<F<@<.1R87-T`$QI<V$@=F5E<F<@
M96YN90!,:7-A(&MI<FIA9`!,:7-A(&SU:6L@<.1R87-T`$QI<V$@;/5I:R!E
M;FYE`$QI<V$@<FED82!PY')A<W0`3&ES82!R:61A(&5N;F4`2VER:G5T82!S
M86QA:_QS:6UU<V4@]6EG92!V87-T=7,Z`$QI<V$O;75U9&$@<&EL=`!,:7-A
M+VUU=61A(&QI;FL`2F%O='5S;FEM96MI<FIA;&4@<V%A=&UI<V5K<R!E:2!J
MY'1K=2!K<F5D:6ET:2X`2W)E9&EI=&D@96D@:N1T:W4N`%3D:7-A<G8`5.1I
M<V%R=G5D92!N:6UE:VER:0!6:6=A;F4@541(("A5<V5R($1A=&$@2&5A9&5R
M*2X`5FEG87-E9"!:25`@86YD;65D+@!6:6=A;F4@<F%K96YD=7,N`%9A;&4@
M8F%T8V@@240`4VES97-T871I('9I9V%S960@86YD;65D+@!6:6=A;F4@<VEH
M=&%A9')E<W,N`%9A;&4@9F%I;&EF;W)M86%T`%9I9V%N92!L:71S96YT<VEV
M]71I+@!3:7-E<W1A=&D@=FEG86YE(&%S=6MO:'0`5FEG86YE(&US9U]T>7!E
M`&%P:5]I9"!O;B!P=75D=2!V]6D@=FEG86YE+@!6:6=A<V5D(';U:2!P=75D
M=79A9"!P87)A;65E=')I9"X`5FEG86YE(/QL96WU:6=U<RX`5FEG86YE('!A
M<G1N97)I($E$`%9I9V%N92!T;V]T96MO;V0N`%9I9V%N92!P<F]T;VMO;&PN
M`%9I9V%N92!S86%J83H@(B5S(@!6:6=A;F4@:F%G871U9"!O8FIE:W0`5FEG
M86YE(&SD:'1E86%D<F5S<RX`5FEG87-E9"!U;FEC;V1E(&%N9&UE9"X`3FEM
M96MI<FD`4/;V<F1V86QI:P!)<F%A;FD@27-L86UI=F%B87)I:6L`27)A86L`
M26ER:6UA80!-86YI('-A87(`W&MS:6MU9"#D:6ME<V5T;W)M:60`26ES<F%E
M;`!6Y&QJ86%N9&IA`$MA;&1K:7)I`$ET86%L:6$`2F%M86EK80!*86%N=6%R
M`$IA87!A;@!*86%P86YI("A)4T\M,C`R,BU*4"D`2W5N82!S:6YU('9E96)I
M;&5H:71S96IA<R!O;B!*879A<V-R:7!T(&ME96QA='5D+"!E:2!P<G5U9VD@
M<V5E(&QE:'0@]6EE=&D@<&%I<W1A+@!*97)S97D`2F]R9&%A;FEA`$IU=6QI
M`$IU=6YI`%+V]G!S96QT`$ME<VME;&4`4O;V<'-E;'0`5F%S86MU;&4`4&%R
M96UA;&4`2V%S86AS=&%N`%/D:6QI=&$@;W)I9VEN86%L/P!+965N:6$`2V5R
M8F5R;W-E('-E<G9E<B!E:2!L87-K;G5D('-I<W-E+@!+97)N96QI(';U:&EK
M=60`5O5T;64@;&]O;6EN90!6]71M92!S]7)M96KD;&<`5O5T;64@<&EK:W5S
M`%;U=&UE('3\_'``5O5T;64@:V%S=71U<P!6]71I(&]N(&%V86QI:W5S('-E
M<G9E<FES(&IU8F$@;VQE;6%S+@!,87!S960`2VER:6)A=&D`2V]R96$@4F%H
M=F%D96UO:W)A871L:6L@5F%B87)I:6L`2V]R96$@5F%B87)I:6L`2V]R96$@
M*$550RU+4BD`2W5V96ET`$OU<F?U>G-T86X`7TMU:G5N9'5S`$ME96P`3&%O
M<V4@4F%H=F%D96UO:W)A871L:6L@5F%B87)I:6L`5FEI;6%N92!P;V]L`%9I
M:6UA;F4@<&%R;V]L:2!M=75T=7,`5FEI;6%N92!V965R86YD`%9I:6UA=&D@
M;75U9&5T=60Z`$5E;&UI;F4@:_QL87-T=7,Z("5S`$5E;&UI;F4@:_QL87-T
M=7,Z("5S(&%A9')E<W-I;'0@)7,`165L;6EN92!K_&QA<W1U<SH@;6ET=&4@
M:W5N86=I`$SD=&D`4V5A9'5S`$MU:G5N9'5S`%3\:&D@=.1H96YD86(@<&EI
M<FIO;VYE('!U=61U;6ES=`!,:6EB86YO;@!687-A:P!687-A:R!PY&ES`%9A
M<V%K=60@=N3D<G1U<V5D`$QE<V]T:&\`5&%S90!,:6)E97)I80!,:6EB_&$@
M07)A86)I82!686)A<FEI:P!,:65C:'1E;G-T96EN`%1I8G5T86(@=FEH;6$`
M4V5E;F5V:6AM`$AO;6UI:W5L('1I8G5T86(@=FEH;6$`U6AT=6P@=&EB=71A
M8B!V:6AM80!+97)G92!H;V]V:6AM`$ME<F=E('9I:&T@:F$@Y&EK90!+97)G
M92!L=6UE<V%D=0!+97)G92!L=6UE=&]R;0!,:6UE<FEK`$QI;FL`3&EN:R!V
M:6ET86(@87-U:V]H=&$Z`$5S:71A;6ES96P@<V5O<W1A(&4M<&]S=&D@86%D
M<F5S<R!U=64@:VER:F$@86MN86=A`$QI;F=I9`!,:6YU>&D@<'+DY&YI:P!,
M:7-T("T@:V%S=71A:F$@=O5I8B!K875S=&$@;N1H80!!;F1M96)A87-I9&4@
M;&]E=&5L=0!!8FEI;F9O('1E96UA9&4@;FEM96MI<FD`5&%B96QI=&4@;&]E
M=&5L=0!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE
M<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!3
M97-S:6]O;FED92!N:6UE:VER:F$@97-I=&%M:6YE(&YU<FIU<SH@)7,`2V%S
M=71A:F%T92!N:6UE:VER:F$@97-I=&%M:6YE(&YU<FIU<SH@)7,`2V%S=71A
M:F%T92!N:6UE:VER:F$@<&]L92!L=6)A='5D(&[D:&$N`$MI<FIA;F1U<P!,
M965D=0!,865N+BXN`$MO:&%L:6L@865G.B``4F5G:6]O;B!J82!A96<`07-U
M:V]H=`!,;V=I('-I<W-E`$5E;&UI<V4@<_QN:W)O;FES965R:6UI<V4@;&]G
M:0!,;V=I(';D;&IA`$MA<W5T86IA;FEM:0!4]O9D('-I<W-E;&]G:6UI<V5L
M`%-I<W-E;&]G:6UI;F4@;G5R:G5S+"!K=6YA(&MA<W5T86IA;FEM:2!V]6D@
M<&%R;V]L('!O;&YU9"#U:6=E+@!3:7-S96QO9VEM:6YE(&YU<FIU<RX`4&EK
M:R!T96MS=`!!<FUA<W1U<P!-861A;`!+<F5E:V$@=N1I:V5TY&AE9`!,861I
M;F$@=N1I:V5TY&AE9`!6Y&EK97-E9"!R;V]M82!N=6UB<FED`$QU:W-E;6)U
M<F<`2TL`34]41`!-4RU43D5&(&QI<V%N9"!E:2!S:7-A;&1A;G5D(&%N9&UE
M:60N`$U31P!-86MA;P!-86ME9&]O;FEA("A%;F1I;F4@2G5G;W-L86%V:6$@
M5F%B87)I:6LI`$UA9&%G87-K87(`36%A9VEA`$4M<&]S=`!0;W-T:2!A9&UI
M;FES=')A871O<@!?5&5E(&QI;FL`36%L87=I`$UA;&%I<VEA`$UA;&1I:79I
M9`!-86QI`$UA;'1A`%-E861I<W1A(&MA=&5G;V]R:6%I9"P@;6ED82!K87-U
M=&%T86MS92#\:W-U<W1E(&WD<F=E;F1A;6ES96MS(&IA(&YE;F1E;&4@:V%T
M96=O;W)I871E;&4@=F%S=&%V86ED(';D<G9E+@!-87`R-"!K86%R=`!-87!1
M=65S="!K86%R=`!687-T879U<V5D('-A;'9E<W1A='5D+@!-Y')T<P!397)V
M`%3D:&ES=&$@;&]E='5D+VQU9V5M871A('-T86%T=7,`5.1H:7-T82!M=74@
M<W1A871U<R`H;G0N('3D:'1I<R]V87-T871U9"D`36%R<VAA;&QI('-A87)E
M9`!-87)T:6YI<75E`%-O8FEV860@=N1L:F%D`$UA=7)E=&%A;FEA`$UA=7)I
M:71I=7,`4W5U<FEM(&QU8F%T=60@:W)E9&EI="X`2VER:F$@;W-A9&4@<&EI
M<F%N9R#\;&5T871U9"X`5FEI;6%S92`R-"!T=6YN:2!K]7)G96EM('1E;7!E
M<F%T=75R.B``5FEI;6%S92`V('1U;FYI(&OU<F=E:6T@=&5M<&5R871U=7(Z
M(`!3=75R:6T@<&]R=&%A;&D@8FQO:VMI9&4@87)V`%-U=7)I;2!P:6MK=7,`
M36%I`$UA>6]T=&4`365D:71S:6EN`$QI:6MM960`365N_/P@97-I='5S.@#<
M:&5N9&$@;&%H=')I9`!496%D90!+:7)I(&]N(&5D=6MA;'0@:V]N=')O;&QI
M='5D+"!E;G0@86QL:VER:F%S=&%J82!S97)T:69I:V%A=&D@96D@<V%A;G5D
M(&MO;G1R;VQL:61A+@!496%D92!O;B!A96=U;G5D+@!496%T92!T_/QP`$UE
M=&%R(&EL;0!-971A<B!B;&]K:R!E:2!O;&4@<V%A9&%V86PN`$UE=&%R(&)L
M;VMK(&5I(&]L92!S86%D879A;"X@W&MS:6MA<VIA9"!L;V=I=&D@861M:6YI
M<W1R86%T;W)I(&IA;VMS+@!-971A<D1"(/QH96YD=7,@<'5U9'5B+@!-965T
M;V0`365E=&]D("(E<R(@96D@;VQE(&1E9FEN965R:71U9`!-965T;V0@96D@
M;VQE(&1E9FEN965R:71U9"X@2^1I=FET871U9"!M965T;V0Z("5S`$UE971E
M<@!-96AH:6MO`$UI:W)O;F5E<VEA($;V9&5R871S:6]O;@!+97-K96QE`$U)
M344@=/S\<`!6:6EM87-E(#(T('1U;FYI(&UA9&%L86EM('1E;7!E<F%T=75R
M.@!6:6EM87-E(#8@='5N;FD@;6%D86QA:6T@=&5M<&5R871U=7(`4&%R;V]L
M:2!M:6YI;6%A;&YE('9A;G5S('!O;&4@=F5E;"!TY&ES`%!E96=E;&1A`$UI
M=&UE<W5G=7-T`%!U=61U8B!014%2('!A:V5T="!(5%107U)E<75E<W0N`$MO
M;F9I9W5R871S:6]O;B!P=75D=6(N($MU:2!T86AA9"!S961A(')A:V5N9'5S
M="!K87-U=&%D82P@<&5A9"!E;FYE(&=E;F5R965R:6UA(&MO;F9I9W5R871S
M:6]O;FDN`%!U=61U8B!S]6YU;6D@240N`%!U=61U8B!V86IA;&EK(%!%05(@
M<&%K971T($UA:6PN`%!U=61U8B!S97-S:6]O;FD@240N`$5S`$UO8FEI;&YE
M(&4M<&]S=`!-]?5D=6MA<P!-=75T;6ES92!K=75PY&5V`$UU=61A(%523`!*
MY.1K`$UO;&1O=F$@5F%B87)I:6L`36]N86MO`$UO;F=O;VQI80!+=74@:F$@
M86%S=&$`2V]R9"!K=75S`$UO;G1S97)R870`2W5U9F%A<VED`%)E87,@)60@
M;&5I=&D@<F]H:V5M(';D;&IU(&MU:2!E96QD871A=B`E9"X`36%R;VMO`%9A
M;&1A=F%L="!S96QG90!686QD879A;'0@<&EL=F5S`%9A;&1A=F%L="!P:6QV
M97,@:F$@='5U;&EN90!686QD879A;'0@<.1I:V5S97!A:7-T96QI;F4`3FEH
M=71A(&%L;&$`3FEH=71A('9A<V%K=6QE`$YI:'5T82!P87)E;6%L90!.:6AU
M=&$@_&QE<P!.:6AU=&$@86QL80!.:6AU=&$@_&QE<P!-;W-A;6)I:6L`36ET
M;65T87-E;65L:6YE(&QO96YD`$UU;'1I;6%P(%5+(&MA87)T`%9A;&EK`$UI
M;G4@:V]N=&\`36EN=2!K;VYT;R!I;F9O`$UI;G4@<&]R=&%A;`!-:6YU('!O
M<G1A86QI(&MU:G5N9'5S`$UY86YM87(`14DL(&UA($5)($],12!N]75S`$YI
M;6D`3F%M:6EB:6$`3F%U<G4`3F5P86%L`$AO;&QA;F0`2&]L;&%N9&D@06YT
M:6QL:60`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@=/QH:7-T=7-E
M(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E('5U96YD=7-E
M(%523`!.971S8V%P92!T_&AI<W1U<V4@55),`$YE='-C87!E(%-33"!S97)V
M97)I(&YI;6D`3F5T<V-A<&4@<V5R=&EF:6MA861I(&MO;6UE;G1A87(`3F5T
M<V-A<&4@<V5R=&EF:6MA861I('3\_'``5O5R:P!-:71T92!K=6YA9VD`575S
M+4MA;&5D;V]N:6$`575S(&MA=&5G;V]R:6$`575S(&MI<FD@)7,M;&4`3F]O
M<FMU=0!5=7,@:V%S=71A:F%N:6UI("AP;VQE(&MO:'5S='5S;&EK*0!5=7,M
M365R96UA80!5=7,@<V%L87/U;F$`575S('-A;&%S]6YA(&%E9W5B("5X+@!3
M86QA<_5N860@<&5A=F%D(&ML87!P:6UA+@!5=65S(&%K;F%S("A?8FQA;FLI
M`%5U9&ES960`1W)U<&ED`$KD<F=M:6YE`$KD<F=M:7-E9"`T(&9A87-I`$KD
M<F=M:7-E9"!S96%D960`2N1R9VUI;F4^`$YI:V%R86%G=6$`3FEG97(`3FEG
M965R:6$`UO8`3FEU90!%:0!0=75D=79A9"!K;VYF:6=U<F%T<VEO;VYI86YD
M;65D(&UI;&QE(&5R:6YE=G5S:2!NY&ED871A+@!0=75D=6(@<W1R871E96=I
M82!)4T]D92!L;V]M:7-E:W,N`%!U=61U8B!M86QL+@!396QL97,@87-U:V]H
M87,@96D@;VQE(&)L;VMK:0!-0T%,(&%U=&5N=&EM:7-E:W,@=F%J86QI:R!K
M86QE;F1R:2!N:6UI(&]N('!U=61U+@!%<FEN979U<VD@96D@;VQE+@!396QL
M96QE(/5I9W5S96QE(&5I('-A82!A;&%M86ED(&QI<V%D82X`)7,@:.3D;&5S
M='5S:6YF;R!P=75D=6(N`$944"!61E,@:.3D;&5S='5S:6YF;R!P=75D=6(N
M`%-13"!61E,@:.3D;&5S='5S:6YF;R!P=75D=6(N`%-13"U&:6QE(%9&4R!H
MY.1L97-T=7-I;F9O('!U=61U8BX`2W)E9&EI="!O;B!A;6UE;F1A='5D+@!3
M:6AT:V]H="!MY.1R86UA=&$N`$9A:6QI(&5I(&QA971U9`!):V]O;F4@96D@
M;&5I='5D+@!!<W5K;VAT(&WDY')A;6%T82X`07-U:V]H="!MY.1R86UA=&$`
M4_5N=6T@<'5U9'5B+@!.:6UI('!U=61U8BX`3G5M8F5R('!U=61U8BX`06EN
M=6QT('9I:7-A:V%D(&MI;&QU9`!(5%10(&%U=&5N=&EM:7-E('-A;&%S]6YA
M('!U=61U8BX`24U!4"!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N`$ME
M<F)E<F]S(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BX`3&]G:6X@875T
M96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+@!005-35T0@875T96YT:6UI<V4@
M<V%L87/U;F$@<'5U9'5B+@!334(@875T96YT:6UI<V4@<V%L87/U;F$@<'5U
M9'5B+@!/<&5N4U-,('!R;V=R86UM:2!A<W5K;VAT(&5I(&]L92!MY.1R871U
M9"X@3W!E;E-33"!P<F]G<F%M;2!O;B!V86IA;&EK(%!+0U,C,3(@86YD;65T
M96=A('3V]G1A;6ES96MS+@!/;W1E;"!L:6ET=6UI<W-O;W9E(&5I(&]L92X`
M4&EI<F%N9W5T(&5I(&]L92X`4'5U9'5V860`17)A;&1A:F$@<&]L92!MY.1R
M871U9"X`36ET=&4@_&MS:VD@:_QL9P!396QL:7-T(&9A:6QI(&5I(&]L90!0
M=6AV97)D86UI<V5K<R!P=75D=6(@86IU=&EN92!K871A;&]O9RX`2V%S=71A
M:F%N:6UE(&IA+W;U:2!S86QA<_5N82!E:2!S86%D971U9"X`16D@=&%G87-T
M871U9"!K;W)R96MT<V5I9"!834P@86YD;65I9`!6Y.1R='5S960@<'5U9'5V
M860`06QG;F4@:V]N9FEG=7)A='-I;V]N(&5I('-I<V%L9&$@=F5R<VEO;VYI
M+B!,;V\@:V]N9FEG=7)A='-I;V]N('5U97-T:2X`4VEN=2!K;VYF:6=U<F%T
M<VEO;VX@96D@<VES86QD82!V97)S:6]O;FDN($QO;R!K;VYF:6=U<F%T<VEO
M;VX@=75E<W1I+@!-Y.1R86UA=&$`3>3D<F%M871A`%#U:&IA;6%A9"`H25-/
M+3@X-3DM,3`I`$YO<F9O;&MI('-A87(`4/5H:F%P;V]L:V5R80!0]6AJ82U-
M87)I86%N:2!S86%R960`3F]R<F$`36ET=&4@:&EL:F5M(&MU:0!-:71T92!V
M87)E;2!K=6D`16D@;VQE(&MA=&%L;V]G`%!O;&4@=&5O<W1A='5D+@!-Y.1R
M86UA=&$`16D@;VQE('1O971A='5D+@!-Y')K;65D`%!O;&4@;6ED86=I('-I
M<G9I9&$L(&UI;F4@=&%G87-I+@!.;W9E;6)E<@!!<G8`3>1R:VED92!A<G8`
M5F5E<F=U9&4@87)V`%)I9&%D92!A<G8`2F%O='5S;FEM96MI<FIA<R!M=75T
M;6ES96QE(&MU=6QU=F%D(&YU;6)R:60@<&]L92!MY.1R871U9"X`3TL`3V)J
M96MT`$]B:F5K=&D@;&]O:F$`2V%H96MS86YD;G5M8F5R`$]K=&]O8F5R`%9I
M:7-A:W5S92!A<W1E`$MO;G1O<FET]O8`5F%N82!J82!U=7,@<V%L87/U;F$@
M<&5A=F%D(&]L96UA(&5R:6YE=F%D+@!0<F%E9W5N92!S86QA<_5N80!0<F%E
M9W5N92!S86QA<_5N82!E:2!O;&4@]6EG92X`3VUA86X`W&AI<VMA=7-T=2!V
M]6EM86QD879A9"!A:6YU;'0@24U!4"!S97)V97)I9"X`06EN=6QT(&5B879I
M:7-A:V%D(&MI;&QU9`!,=6)A='5D(&]N(&%I;G5L="#\:W,@92UP;W-T:2!A
M861R97-S+@!*86\@;VUA;FEK:W4@=O5I(&]M86YI:W4@]6EG=7-I('-A86(@
M;75U=&$@86EN=6QT(&]M86YI:R!V]6D@<_QS=&5E;6D@861M:6YI<W1R86%T
M;W(N`$%V82!U=65S(&%K;F%S`$]P96Y34TP@=FEG83H@06YD;65T92!E<F%L
M9&%M:6YE(&%L;&MI<FIA<W1A='5D(%,O34E-12!O<V%S="!N=7)J=7,N`$%V
M86(@<V5L;&4@;&EN9VD@=75E<R!A:VYA<P!/<&5R871S:6]O;FES_'-T965M
M`%-E861E9`!396%D:7-T=7,Z("5S`$YU;6UE<F1A='5D(&QO971E;'4`3W)G
M86YI<V%T<VEO;VX`06QL_&MS=7,`26YF;P!286ME;F1U<V4@86QG;F4@;6%L
M;`!!;&=S960@;6%L;&ED(&MA=&%L;V]G:7,@)7,Z`$UU=0!-=74@:6YF;P!/
M;6%N:6MU(/5I9W5S960`4$%-(&%U=&5N=&EM:6YE(&5I(&]L92!S86%D879A
M;"X`4$5!4CHZ36%I;"!T=6=I`%!'4"!D:6=I=&%A;&%L;&MI<FD`4$=0(&MR
M_'!T:71U9"!A;F1M960`4$=0(&%V86QI:R!V]71I`%!'4"!A;&QK:7)J87-T
M871U9"]K<OQP=&ET=60@86YD;65D`%!(4"!K;V]D`%!(4"!KY'-U<FED80!0
M3"!K97)G92!V:6AM`%!,('9I:&T`4$P@:&]O=FEH;6%D`%!,(&QU;6D`4$P@
M=&EH92!L=6UE<V%D=0!03"!PY&EK90!03"#D:6ME<V5T;W)M`%!/4TE8(&QA
M:65N9'5S('!U=61U8@!07TA0(&OD<W5R:61A`%3D:61E`%!A:VES=&%N`%!A
M;&%U`%!A;&5S=&EI;F$@;VMU<&5E<FET=60@=&5R<FET;V]R:75M`%!A;F%M
M80!086%P=6$@575S+4=I;F5A`%!A<F%G=6%I`%9A:&5L9'5V('!I;'9I<W5S
M`%-A;&%S]6YA`%-A;&%S]6YA(&UU=61E='5D+@!686QE('-A;&%S]6YA`%)!
M1$E54R!A=71E;G1I;6ES96MS(&]N('9A:F%L:6L@<V%L87/U;F$N`%-A;&%S
M]6YA(&MI;FYI='5S96=A`%-A;&%S]6YA.@!386QA<_5N83H@`%-A;&%S]6YA
M9"!P96%V860@:VQA<'!I;6$N`$%S971A`$%S971A(&SU:6ME<'5H=G)I<W0`
M07-U:V]H=`!/;W1E;"!L:6ET=6UI<W-O;W9I9#H`26YI;65S960`4')O='-E
M;G1I`$OD:79I=&$@:&]O;&1U<W3V]F0`5&5E('-I<W-E;&]G:6UI<V5L(&AO
M;VQD=7-T]FED`-5I9W5S`-5I9W5S="`B)7,B(&5I(&MU<W1U=&%T=60N`$IU
M=7)D97#DY',@:V5E;&%T=60`U6EG=7-E9`#5:6=U<W1E(&AA;&1U<P!)<VEK
M;&EK(&EN9F\`4&5R=74`3&5M;6EK;&]O;6%D`$9I;&EP:6EN:60`5&5L969O
M;@!&;W1O9`!0:71C86ER;@!0:6MS;&ET`$WU='1E='5S960`2VSU<'-A(&WU
M;F1A(&QA:'1R:7-S90!+:6YN:71A(&5T('-O;W9I9"!S96QL92!E;&5M96YD
M:2!E96UA;&1A9&$Z`$MI;FYI=&$@970@<V]O=FED('-E;&QE(&5L96UE;F1I
M(&QA:'1I(/QH96YD861A+@!3:7-E<W1A(&MU=2!J82!A87-T82X`4VES97-T
M82!S96QL92!U=64@:V%T96=O;W)I82!N:6UI.@!3:7-E<W1A(&MO<G)E:W1N
M92!)4"!A861R97-S+@!3:7-E<W1A(&MO<G)E:W1N92!K=75PY&5V+"!K;VYT
M<F]L;&D@<.1E=F%D92!A<G9U(&MU=7,N`%-I<V5S=&$@:V]R<F5K=&YE(&%E
M9RX`2VER:F5L9&$@<')O8FQE96UI+@!3:7-E<W1A(&]M82!K87-U=&%J86YI
M;6D@:F$@<V%L87/U;F$`3&]E(&KD<F=N978@=&5K<W0@;.1B:2X@4_QS=&5E
M;6D@:V%S=71A;6ES96MS(%!%040@=&EN9VEM=7-T96=A(&[U=7-T=6UA+@!+
M:7)J=71A('5U92!K871E9V]O<FEA(&YI;6DZ`%!O;VQA`%!O;&EI=&EK80!+
M_'-I=&QU<V5D`%!O<G1U9V%L`%-E;&QE('!I;&1I('!A:6=U='5S`%-E;&QE
M('1A8F5L:2!P86EG=71U<P!+:7)J=71A('-E;&QE<W-E(&MA=7-T82`H24U!
M4"!E:2!K;VYT<F]L;&DI`%9I:6UA<V4@)7,@='5N;FD@<V%D96UE9#H@`%-A
M9&5M971E/&)R("\^=/5E;N1O<W5S`%!R969S7VQD87`Z(%9A:F%L:6MK=2!,
M1$%0(&QA:65N9'5S="!E:2!L96ET=60N`%!R969S7W-E<W-I;VXZ(%9A:F%L
M:6MK=2!S97-S:6]N(&QA:65N9'5S="!E:2!L96ET=60N`-5H=7+U:&L`U6AU
M<O5H:R!M97)E<&EN;F%L.@#5:'5R]6AK.@!%96QV86%D90!0:6QD:2!E96QV
M86%D92!U=65S(&%K;F%S`$5E;&UI<V5D('-E861E9`!4<OQK:2!D;VMU;65N
M=`!386QA:F%N92!V]71I`%!R;V)L965M`%!R;V)L965M:2!K:7)J96QD=7,`
M4')O:F5K=&ED`%-E;&=I=&%V('1E:W-T`$%V86QI:R!V]71I`$%V86QI:W4@
M=O5T;64@86QG;W)I=&T`079A;&EK=2!V]71M92!I;F9O`%;U=&UE<&%A<FD@
M9V5N97)E97)I;6EN92!E:2#U;FYE<W1U;G5D+@!0=65R=&]R:6EK;P!+=7-T
M=71A='5D(&MI<FIA9&4@965M86QD86UI;F4`2V%T87(`4.1R:6YG`%!I:7)A
M;F<`4E-!(&%V86QI:R!V]71I("@E9"!B:71T:2D`5F%L:6L`5FEH;0!(;VUM
M:6MU;"!V:6AM`-5H='5L('9I:&T`2&]O=FEH;0!6:6AM(&IA(&QU;6D`5FEH
M;2!J82!L=6UI`$IU:'5S;&EK(&MI;&0`4')O='-E;G0`3&]E`$QO92!K:7)J
M=0!+87,@=/5E<W1I(&MU<W1U=&%D82`E<S\@4V5E('1O:6UI;F<@;VX@</;V
M<F1U;6%T=2X`2V%S('3U97-T:2!K=7-T=71A9&$@:V%S=71A:F$@)7,@86YD
M;65D/R!3964@=&]I;6EN9R!O;B!P]O9R9'5M871U+@!486%S=&%B('9I:6UA
M<V4@=&5G979U<V4`5N1R<VME;F1A`%;D<G-K96YD82!D_&YA86UI;&ES960@
M;65N_/P@96QE;65N9&ED.@!6Y')S:V5N9&$@<&]R=&%A;&D@=F%A9&4Z`%)E
M9W5L86%R879A;&1I<P!3=6AE=&4@<VER=FEJ80!,864@=75E<W1I`$WD<FMU
M<V5D`%;D;&ES960@<V5R=F5R:60`5N1L:6YE(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ`$5E;6%L9&$`165M86QD82!B;&]K:P!+=7-T
M=71A('9E97)G`$5E;6%L9&$@:W5J=6YD=7,`165M86QD82!P86%R`$MU<W1U
M=&$@<V%L=F5S=&%T=60@<VMR:7!T('-E<G9E<FD@86IU=&ES97-T(&MA=&%L
M;V]G:7-T+@!%96UA;&1A`$5E;6%L9&$@9&]K=6UE;F1I<W0`2W5S='5T82!K
M87-U=&%J80!+=7-T=71A(&MA<W5T86IA.B`E<P!0Y')I;F=U;&4@<&]L;G5D
M(';U:6UA;&EK('9A<W1A=&$N(%1A9V%S=&%T:2!V96%K;V]D.B``4V]O=FET
M879A="!T965N=7-T(&5I(&QE:71U9"X`5F%J86QI:R`B)7,B('!U=61U8B`E
M<R!S96%D:7-T=7-E<RX`5F%J86QI:R`B)7,B('!U=61U8B!61E,@<V5A9&ES
M='5S97,N`%9A:F%L:6L@(B5S(B!P=75D=6(@<V5A9&ES='5S97,N`$MO:'5S
M='5S;&EK(';D;&D`5/QH:F5N9&$`375U9&$@<V%L87/U;F$`56YU<W1A<VEN
M(&]M82!S86QA<_5N80!486%S=&$@965L;6EN92!PY')I;F<`5'5L96UU<V5D
M`%1A9V%S:2!S96%D:7-T=7-S90!+;W)D82!U=70@<V%L87/U;F$`4F5U;FEO
M;@!6]71A(&MO;F9I9W5R871S:6]O;B!T86=A<VD`4FEC:"!497AT($5D:71O
M<FD@<V5A9&ES='5S`$WU:7-T871U<V5D`%!A<F5M`%!A<F5M('#D:7,`4&%R
M96UA9"!VY.1R='5S960`7U)E82!S96%D960N+BX`4F]L;`!2=6UE96YI80!0
M]O9R82`Q.#``4/;V<F$@=F%S86MU;&4`4/;V<F$@<&%R96UA;&4`4F5A('-E
M861E9`!296$@<V5A9&5D`%)I9'4Z`$IO;VYE9`!*;V]N960@=&5K:79A9"!K
M]6EG:2!R:61A9&4@:F$@=F5E<F=U9&4@=F%H96QE`$IO;VYE9"!T96MI=F%D
M(&%I;G5L="!V965R9W5D92!V86AE;&4`2F]O;F5D('1E:VEV860@86EN=6QT
M(')I9&%D92!V86AE;&4`2^1I=FET80!696YE($;V9&5R871S:6]O;@!2=6%N
M9&$`4R]-24U%(&MR_'!T;V=R86%F:6QI;F4@86QL:VER:0!3+TU)344@:W+\
M<'1I='5D(&MI<FD`4T%33"!A=71E;G1I;6EN92!E:2!O;&4@<V%A9&%V86PN
M`%--4R!L_&AI<_5N=6UI9`!344P@:^1S=7)I9&$`4U%,(&%V86QD:7,@=N3D
M<G1U<W1E(&QE:61M:7-E:W,`4U-(`-5.3D535%53`%-?44P@:^1S=7)I9&$`
M3&$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&IA($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!J82!-:7%U96QO;@!386EN="!6:6YC96YT(&IA
M($=R96YA9&EI;FED`%-A;6%S(')A86UI<R`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@:F$@4')I;F-I<&4`4V%T96QL:6ET<VED92!K87-U
M=&%J80!3875D:2!!<F%A8FEA`%-A;'9E<W1A(`!386QV97-T82`B)7,B`%-A
M;'9E<W1A("5S`%-A;'9E<W1A('-E861I<W1U<P!386QV97-T82!G96YE<F5E
M<FET=60@:V]N9FEG=7)A='-I;V]N(%!(4"!S:W)I<'1I;F$@<V5R=F5R:2!A
M:G5T:7-S92!K871A;&]O9VDN`"5S(&MO;F9I9W5R871S:6]O;B!S86QV97-T
M871U9"X`4&%I9V%L9'5S92!U=65N9&%M:7-E('-K<FEP="!S86QV97-T871U
M9"!F86EL:3H@(B5S(BX`2&%J=7-A9"#D:6ME<VAO;V0`5&5A9'5S`$]T<VEN
M9P!/='-I;F=U;6]O=&]R:60`5F%L:2!F86EL:60`5F%L:2!K=75PY&5V`%9A
M;&D@;&ES871A=B!G<G5P<`!686QI('5U<R!O;6%N:6L`5F%L:2!S97)V97(`
M5F%L:2!L:7-A=&%V(&MA<W5T86IA`%9A;&D@:_5I:P!686QI(&OU:6L@:W5U
M<.1E=F$@:V]O<W1I<V]S860N`%9A;&D@;V)J96MT`,1R82!V86QI(&UI9&%G
M:0!686QI('9A:F%L:6MU9"!MY')G:60@:V%S=&ED97-T+B!3:6ES('-A860@
M;F5E9"!K;W!E97)I9&$@:VER:F$@<VES<V4N`%9A;&D@:W5U<.1E=F$@97)A
M;&1A:F$Z`%9A;&D@:W5U<.1E=F$@97-I='5S=FEI<SH`5F%L:2!I9&5N=&ET
M965T(&UI9&$@<V]O=FED(&UU=71A.@!686QI(&ME;&QA86IA(&5R86QD86IA
M.@!686QI(&ME;&QA86IA(&5S:71U<W9I:7,Z`%9A;&D@:V%K<R!S;V)I=F%T
M(';D;&IA+@!686QI(';D<G9I<VME96TN`%9A;&D@;VUA(&QE;6UI:VME96PZ
M`%-A861A('!R;V)L965M:2!K:7)J96QD=7,`4V%A9&$@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!J82!-;VYT96YE9W)O`$KD<FIE
M;G5M8F5R`%-E<G9E<FD@86YD;65D(&]N('9A;&5D(';U:2!P=75D=79A9"X`
M4V5S<VEO;VYI9&4@:&%L9'5S`%-E<W-I;V]N:2!)1"!O;B!A96=U;G5D+@!3
M7V5S<VEO;VYI9`!(=6QK`$WDY')A(&%N9&UE9"!M:7,@=O5I;6%L9&%V860@
M<W5L(&]M82!P87)O;VQI(.1R82!M=75T82!K=6D@<V$@<V5L;&4@=6YU<W1A
M9"X`4V5A9&ES=&$@=N1L:7-E9"!S97)V97)I9"!M:61A('-O;W9I9"!O;6$@
M<&]R=&%A;&ES(&MA<W5T861A+@!086YE('!A:6MA(&]M82!K965L92P@86IA
M=O;V;F1I(&IA(&MU=7#D979A('-E861I<W1U<RX`3>3D<F$@;VUA(&%L9W)A
M:V5N9'5S+"!VY')V:7-K965M+"!L96AE:_QL:F4@=N1R<VME;F1A;6ES92!S
M86=E9'5S(&IA(&UU=60@(&5S:71U<V4@<V5A9&5D+@!086EG86QD=7,`3VQE
M;6%S;VQE=F%D('!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I<'1I9`!087)A
M;65E=&5R(&WDY')A8B!M:71U(';U:6UA;&EK:W4@87-U:V]H=&$Z(`!396ES
M:&5L;&ED`$]S=&QE;6EN90!,_&AI:V]K:W5V]71E`$MA<R!E;F%M=7-E;&4@
M;&EN:VED96QE('1U;&5K<R!MY.1R871A(&MI:7)K;&%H=FED/P!.Y&ET80!.
MY&ET82!O;&5M87-O;&5V82!J82#D<VIA(&=E;F5R965R:71U9"!K;VYF:6=U
M<F%T<VEO;VYI(&5R:6YE=G5S:2X`3N1I=&$@<VES<V5L;V=I;6ES96P@965L
M;6ES92!S:7-S96QO9VEM:7-E(&%E9V$`4&%K=2!V]6EM86QU<W0@;W)I9VEN
M86%L:2!SY&EL:71A;6ES96MS`$[D:71A('9A;&EJ870`3N1I=&$@=&%B96QI
M=&]I;6EN9W5T92!M96[\_')I8F$`3N1I=&$@=F%S86MU;"`E<R!M96[\_&0`
M3N1I=&$@=&%B96QI(&QA:'1R:2!O;6%D=7-T92!D:6%L;V]G:0!.Y&ET82!T
M86)E;&D@;VUA9'5S=&4@9&EA;&]O9VD`3N1I=&$@=&%B96QI(')E82!O;6%D
M=7-T92!D:6%L;V]G:0!.Y&ET82!P:6QD:2!O;6%D=7-T92!D:6%L;V]G:0!.
MY&ET82!U<&QO861I`$AO;W9I:&T`2&]M;6EK=6P@:&]O=FEH;6%D`-5H='5L
M(&AO;W9I:&UA9`!(;V]V:6AM860@_&UB<G5S:V]N;F%S`$MI='-E;F1A`$MI
M='-E;F1A(&OU:6=E<&5A;'0@;F%A8F5R8FQO:VME(';U:2!N:6AU=&$@;F5E
M9"!E97-T(.1R80!3:65R<F$@3&5O;F4`3&EI='4`06QL:VER:0!!;&QK:7)J
M82!A;&=O<FET;0!3:6YG87!U<@!3=75R=7,`2N1T82!H;V]L9'5S('9A:&5L
M90!3;&]V86MK:6$`4VQO=F5E;FEA`$QU;6D`5&EH92!L=6UE<V%D=0!4:6AE
M9&%D(&QU;65S86IU9`!(;VUM:6MU;"!T:6AE9&%D(&QU;65S86IU9`#5:'1U
M;"!T:6AE9&%D(&QU;65S86IU9`!,=6UE('!A:W-U<SH@`$QU;64@=F5E+65K
M=FEV86QE;G0Z(`!386%L;VUO;FD@<V%A<F5D`%-O;6%A;&EA`$QA=6QU9"!J
M82!L=75L971U<V5D`%-O<G1E97)I;6ES:N1R:F5K;W)R82!V86QI:P!,Y&AT
M96%A9')E<W,`3/5U;F$M06%F<FEK80!,]75N82U%=7)O;W!A("A)4T\M.#@U
M.2TS*0!,]75N82U'96]R9VEA(&IA($SU=6YA+5-A;F1W:6-H:2!386%R960`
M3/5U;F%P;V]L:V5R80!686AE(&QA:'1R:71E('9A:&5L`%9A:&4@;&%H=')I
M('-I<W4@:F$@Y.1R92!V86AE;`!%<F%L9&%J80!686AE`%9A:&5D(&IA('9O
M;V1E<F1U<P!(:7-P86%N:6$`4N1M<'-P;W-T`$5R:6WD<FMI9&4@<VES97-T
M=7,`17)A;&1A(&QA:'1R:60`3&%H=71A('9E97)G`$QA:'5T82!R:61A`%-P
M;W)T`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`06QG=7-A87-T80!/
M<V%R:6EK(';U:2!M86%K;VYD`$]L96L`4V%L=F5S='5S9F]R;6%A=`!4Y&YA
M=B!J82!M86IA`$SD8FEJ;V]N:71U9"!T96MS=`!3=')I;F=I9&4@;&]E;F0`
M17)A;&1A(&1O;65E;B!A861R97-S:7-T`%-T:6EL(%M#4U-=`%#\`$%L86UK
M871A;&]O9VD@(B5S(B!E:2!L96ET=60N`%1E96UA`$MI;FYI=&$`4V]O=B`B
M)7,B(&QI<V%M:7-E:W,@<_QS=&5E;6D@;VX@<V%L=F5S=&%T=60N(%-A(&5I
M('-A82!S:7-S92!L;V=I9&$@96YN92!K=6D@<VEN=2!S;V]V(&]N(&AE86MS
M(&MI:61E='5D+@!!;&%I;F1E:W,`3.1K<R!K;W)D80`B)7,B(&]N('/\<W1E
M96UI(&QI<V%T=60N`"(E<R(@86YD;65D(&]N('/\<W1E96UI<W0@965M86QD
M871U9"X`(B5S(B!O;B!K=7-T=71A='5D+@`B)7,B(&]N('/\<W1E96UI<W0@
M965M86QD871U9"X`2V]N9FEG=7)A='-I;V]N(&]N('1A9V%S:2!V]65T=60N
M($UU=71U<W1E(&[D9V5M:7-E:W,@=N1R<VME;F1A('9A861E="X`2V]N9FEG
M=7)A='-I;V]N:2!V87)U:V]O<&EA(/5N;F5S='5S('-A;'9E<W1A9&$N`$MO
M;F9I9W5R871S:6]O;FEF86EL:2!V87)U:V]O<&EA("5S(/5N;F5S='5S('-A
M;'9E<W1A9&$N`"(E<R(@;75U=&UI;F4@]6YN97-T=7,N`"5S(&MI<FIU=&%M
M:6YE(/5N;F5S='5S`%-U9&%A;@!3:7-U:V]K:W5V]71E`%#D:6ME<V5T]75S
M`%#D:6ME<V5L;V]J86YG`%#D:6ME<V5P86ES=&5L:6YE`%#D:6ME<V5T]75S
M`%#D:6ME<V5T]75S+VQO;VIA;F<`4.1I:V5S973U=7,Z(`!0Y&EK97-E;&]O
M:F%N9P!0Y&EK97-E;&]O:F%N9SH@`-QL86EN9&5K<P!4=6=I`%-U<FEN86UI
M`%!E<F5K;VYN86YI;6D`4W9A;&)A<F0@:F$@2F%N($UA>65N`%-V86%S:6UA
M80!2;V]T<VD`4VAV96ET<P!3_&YK<F]N:7-E97)I;6ES92!L;V=I(&MU<W1U
M=&%T=60`4WEN8TU,`$MI<FIA=FEG82!O='-I;F=U=&EN9VEM=7-T97,`4_S\
M<FEA($%R86%B:6$@5F%B87)I:6L`Q&EK97-E=&]R;0!4=75L:6YE(&IA(.1I
M:V5S96QI;F4`Q&EK97-E<'5H86YG=60`2&]M;6EK=6P@Y&EK97-E<'5H86YG
M=60`5%-6(&9A:6P`5&%B96P`5&%B96QI(&]M861U<V5D`%1A8F5L:71E(&AU
M;&L`5&%B96QI(&]M861U<V5D`%1A:79A;@!486EV86XL($AI:6YA('!R;W9I
M;G1S`%1A9'II:VES=&%N`%1A;G-A86YI82#<:&5N9'9A8F%R:6EK`$%V86YE
M;6EN93H`5/;V9`!496QE9F]N:6YU;6)E<@!6:6EM87-E('1U;FYI('1E;7!E
M<F%T=75R.@!496UP97)A='5U<@!496UP97)A='5U<CH@`%1E;7!E<F%T=75R
M/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<P!-86QL:2`B)7,B(&5I
M(&QE:71U9"X`36%L;&ED92!H86QD=7,`5&5K<W0`06EN=6QT('1E:W-T`%1E
M:W-T:2!J;V]N9'5S`%1E>'1T;W``3F4`5&%I("A425,M-C(P*0!486D`5.1N
M86UE(&O\;&%S=&%M87-T+@!&5%`@;&%I96YD=7,@96D@;VQE('-A861A=F%L
M+@!(:7-T;W)Y('/\<W1E96T@;VX@=N1L:F$@;/QL:71A='5D+@!(;W)D92]+
M;VQA8B!I;G1E9W)A='-I;V]N:6UO;W1O<B!E:2!T;V5T82`B)7,B+6D`24U3
M4"!L;V=I(&%L9W;DY')T=7-T86UI;F4@;G5R:G5S+@!-86EN=&5N86YC93HZ
M(&ML87-S:2!L86%D:6UI;F4@;G5R:G5S`%-E861E=&4@86ME;B!O;B!S=6QE
M='5D+B!6Y&QJ=6XN`$MU:2!T86AA9"!K87-U=&%D82#U:6=U<VDL('!E86(@
M861M:6YI<W1R86%T;W(@<V5A9&ES=&%M82!P_'-I=F$@]6EG=7-T92!S_'-T
M965M:2X`06EN=6QT(&%L=6UI;F4@:_QL9P!+;VYT86MT:2!)1"!N=6UB<FET
M(&5I(&WDY')A='5D+"!JY&5T:2!T_&AJ86MS(';U:2!S964@<'5U9'5B(&%N
M9&UE8F%A<VES+@!+:7)J92#U;FYE<W1U<R!L:7-A9&$@<VEN=2!A861R97-S
M:7)A86UA='5S<V4N`$%L;&MI<FIA<W1A='5D(&MI<FIA(&MO;G1R;VQL:6UI
M<V5K<R!O;B!V86IA(&5R86QD:2!01U`@86QL:VER:F%B;&]K:VDN`$IA;W1U
M<VYI;65K:7)J82!)1"!O;B!MY.1R86UA=&$L(&KD971I('3\:&IA:W,@=O5I
M('!U=61U8B!A;F1M96)A87-I<RX`2F%O='5S;FEM96MI<FD@<&]L92!MY.1R
M871U9"X`2W+\<'1I;6ES96MS(&]N('9A:F$@='5R=F%L:7-T($A45%`@_&AE
M;F1U<W0N`$9A:6P@)7,@<&5A:W,@<VES86QD86UA("5S(&WDY')A;F=U="X`
M1F%I;"`E<R!P96%K<R!S:7-A;&1A;6$@;6EN9V5I9"`E<R!MY.1R86YG=6ED
M+@!&86EL:2!E:2!S86$@:V]P965R:61A(&ES965N9&%L92!O='-A+@!&86EL
M(&5I('-I<V%L9&%N=60@86YD;65I9"X`2N1R9VYE=F%D('-E;&QE(&UE<W-A
M9V4O<F9C.#(R(&MI<FIA('#D:7-E9"X`5.1I<V5K<F%A;FER97II:6UI(&MA
M<W5T86UI;F4@=&5K:71A8B!P<F]B;&5E;64@26YT97)N970@17AP;&]R97)I
M<R!TY&YU('-E;&QE('9E96)I;&5H:71S96IA('9I9V%D96QE+"!M:61A(&UE
M:6P@96D@]6YN97-T=2!M86AA('-U<G5D82X@17-I;F5D82!V]6EB(&SD8G4@
M:W5J=71I<V5S+"!E9&ET;W)I(&9U;FMT<VEO;VYI9&4@<'5U9'5M:7-T(&IA
M+W;U:2!V965B:6QE:&ET<V5J82!J=6AU<VQI:VMU(&MI;FYI:F]O:W-M:7-T
M+B!+=6D@<VEN=2!A<G9U=&D@;W!E<F%T<VEO;VYI:W,@;VX@5VEN9&]W<R`Y
M>"P@<VEI<R!O;B!VY&=A('3U96[D;VQI;F4@970@<V%A9"`B1V5N97)A;"!0
M<F]T96-T:6]N($9A=6QT(B!V96%T96%T92!J82!P96%D(&%R=G5T:2!T86%S
M:^1I=FET86UA+EQN7&Y3:6YD(&]N(&AO:6%T871U9"X@2VSU<'-A($]++"!K
M=6D@<V]O=FED('-I:7-K:2!TY&ES96MR86%N:7)E>FEI;6D@<')O;W9I9&$N
M`$ED96YT:71E970@(B5S(B!O;B!K=7-T=71A='5D+@!!:6YU;'0@=F%S86L@
M:_QL9P!#<GEP=%]P9W`Z.B!K;&%S<VD@:F%O:W,@<&5A8B!O;&5M82!MY.1R
M871U9"!';G501R!P<F]G<F%M;6D@87-U:V]H="X`2VER:2!M:7,@<V%A9&5T
M:2`E<R!A861R97-S:6QE("5S('1E96UA9V$@(B5S(B!O;B!A=F%T=60N"E-E
M92!E:2!G87)A;G1E97)I(&5T(&MI<FD@;.1B:2!L;V5T:2!V]6D@<V5L;&5S
M="!A<G4@<V%A9&DN`$YI;6D@;6ED82!K87-U=&%D82!E9&ET;W)I(&QE:&5G
M82!L:6YK:6UI<V5L`%;D;&IA9&4@87)V('!E86(@;VQE;6$@87)V+@!(;W)D
M95]#<GEP=%]S;6EM93HZ(&ML87-S('9A:F%B(&]P96YS<VP@;6]O9'5L:70N
M`$5E;&ES='5S="`B)7,B(&5I(/5N;F5S='5N=60@<V%L=F5S=&%D82P@:W5N
M82!A;F1M971E(&AU;&L@_&QE=&%S('-U=7)I;6$@;'5B871U9"!MY.1R80!3
M961A('3\_'!I(&%N9&UE=&4@*"5S*2!V86%T86UI<V5K<R!V86IA;&EK:W4@
M<')O9W)A;6UI(&5I(&QE:71U9"!S_'-T965M:7-T+@!*=71U;>1R:R!P96%B
M(&]L96UA(/QK<R!MY')K+@!!:6YU;'0@=F%S86L@:F$@<&%R96T@:_QL9P!!
M:6YU;'0@<&%R96T@:_QL9P!%<F%L9&%J82!P96%B(&]L96UA(/QK<R!MY')K
M+@!397)V97(@(B5S(B!O;B!K=7-T=71A='5D+@!397)V97(@(B5S(B!O;B!S
M86QV97-T871U9"X`)7,@;&EI='5M:7-S;V]V(&]N(&5E;6%L9&%T=60N`$WD
MY')A='5D(')I9&$@*"5D*2!P;VQE(&]L96UA<RX`3>3D<F%T=60@<FED82!P
M;VQE(&]L96UA<RX`06IU=&ES="!F86EL:2`B)7,B('!O;&4@;VQE;6%S+@!3
M:6YU('-I<V5S=&%T=60@=&5K<W0@96D@:V%T='4@96MR86%N:6P@;VQE=F%G
M82X`06EN=6QT(/QL96UI;F4@:F$@86QU;6EN92!K_&QG`$%I;G5L="#\;&5M
M:6YE(&O\;&<`4V%A9&5T=60@86YD;65D(&]N('9A:&5P96%L(&MA;W1S:2!L
MY&EN=60N`%-A861E='5D(&9A:6QI(&5I('-A86YU9"!S86QV97-T861A+@!W
M96%T:&5R+F-O;2!B;&]K:R!E:2!O;&4@:^1T=&5S86%D878N`$MU:G5N9'5S
M=&4@:V%T86QO;V=I("(E<R(@96D@;&5I='5D+@!%:2!O;&4@;6ED86=I('-E
M861I<W1A9&$N`$MI<FIA;"!E:2!O;&4@=F%H971U;'0@97-I=&%T879A:60@
M;W-I+@!396QL97,@=N1L:F%S(&]N(&QI:6%L="!P86QJ=2!MY')K92X@4V$@
M<VES97-T87-I9"`E<R!MY')K:3L@;'5B871U9"!P;VQE(')O:&ME;2!K=6D@
M)7,N`"(E<R(@;&ES86UI<V5L('/\<W1E96UI('1E:VMI<R!P<F]B;&5E;3H@
M)7,`2V%S=71A:F$@(B5S(B!A;F1M971E('/\<W1E96UI<W0@965M86QD86UI
M<V5L('1E:VMI<R!P<F]B;&5E;3H@`"(E<R(@965M86QD86UI<V5L('/\<W1E
M96UI<W0@=&5K:VES('!R;V)L965M.B``(B5S(B!M=75T;6ES96P@=&5K:VES
M('!R;V)L965M.B`E<P!&86EL:2!L86%D:6UI<V5L('-E<G9E<FES<V4@=&5K
M:VES('!R;V)L965M.B`E<R!E:2!L865T=60N`$9A:6QI(&QA861I;6ES96P@
M<V5R=F5R:7-S92!T96MK:7,@<')O8FQE96TZ("5S(&]L:2!S=75R96T@:W5I
M(';U:6UA;&1A8B!P:6ER86YG("@E9"!B86ET:2DN`$9A:6QI(&QA861I;6ES
M96P@<V5R=F5R:7-S92!T96MK:7,@<')O8FQE96TZ("5S(&QA971I(&%I;G5L
M="!O<V%L:7-E;'0N`%-E;&QE(&MI<FIA(&]S82!E<VET86UI<V5L('1E:VMI
M<R!V:6=A`$MO;G1A:W1A;F1M971E(&EM<&]R=&EM:7-E;"!T96MK:7,@=FEG
M82X`:4-A;&5N9&%R)VD@86YD;65T92!I;7!O<G1I;6ES96P@=&5K:VES('9I
M9V$N`%-E861I<W1U<V4@=F]R;6EL(&5S:6YE<R!V:6=A+B!%:&L@:N1T<VED
M('3D:71M871A(&WU;F4@:V]H=7-T=7-L:6MU(';D;&IA+@!3;V]V:71U9"!A
M861R97-S:7)A86UA='4@;W!E<F%T<VEO;VYI('-O;W)I=&%M:7-E;"!T96MK
M:7,@=FEG82X@4&%L=6X@<')O;W9I(&AI;&IE;2!U=65S=&DN`$MO;G1A:W1A
M;F1M971E('5U96YD86UI<V5L('1E:VMI<R!V:6=A+B!086QU;B!P<F]O=FD@
M:&EL:F5M('5U97-T:2X`2F%O='5S;FEM96MI<FIA('5U96YD86UI<V5L('1E
M:VMI<R!V:6=A+B!086QU;B!P<F]O=FD@:&EL:F5M('5U97-T:2X`4V5E($E-
M05`@<V5R=F5R(&5I(';U:6UA;&1A(&MA=7-T861E(&IA9V%M:7-T+@!3964@
M96D@;N1I(&]L979A="!K;W)R86QI:R!205(@87)H:6EV+@!3964@96D@;N1I
M(&]L979A="!K;W)R86QI:R!:25`@9F%I;"X`4V5E(&5I(&[D:2!O;&5V870@
M:V5H=&EV(&MA87)D:2!N=6UB97(N`%-E92!D<F%I=F5R(';U:6UA;&1A8B!S
M86%T82!S]6YU;65I9"!LY&)I($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@;/S\<VDL(&MA<W5T861E<R!(5%10($%0270`4V5E(&1R86EV
M97(@=O5I;6%L9&%B('-A871A('/U;G5M96ED(&SD8FD@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@;/S\<VDL(&MA<W5T861E<R!(5%10($%0270N`%-E92!D
M<F%I=F5R(';U:6UA;&1A8B!S86%T82!S]6YU;65I9"!LY&)I('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&S\_'-I+"!K87-U=&%D97,@2%14
M4"!!4$ET+@!3964@9')A:79E<B!V]6EM86QD86(@<_5N=6UI=&4@<V%A=&UI
M<W0@4TU44"!P<F]T;VMO;&QI9V$@;.1B:2!6;V1A9F]N92!)=&%L>2!L_/QS
M:2P@86EN=6QT(%9O9&%F;VYE(&YU;6)R:71E;&4N(%-E;&QE:W,@;VX@=F%J
M82!6;V1A9F]N92!)=&%L>2!E+7!O<W1I(&MO;G1O="`H:'1T<#HO+W=W=RXQ
M.3`N:70I`%-E92!VY&QI(&]N(&MO:'5S='5S;&EK+@!3964@=N1L:2!V]6EB
M('-I<V%L9&%D82!V86ED('3D:7-A<G9E+@!3964@=N1L:2!V]6EB('-I<V%L
M9&%D82!A:6YU;'0@;G5M8G)E:60@:F$@:V]O;&]N:70N`%-E92!VY&QI(';U
M:6(@<VES86QD861A(&%I;G5L="!K86AE:W-A;F1A<G9E+@!3964@=N1L:2!P
M96%B(&]L96UA(&MO;6%G82!V]6D@=/QH:6MU9V$@97)A;&1A='5D('3D:7-A
M<G9U9&4@;&]E;F0`4V5E(';D;&D@<&5A8B!O;&5M82!K;W)R96MT;F4@87)V
M+@!3964@=N1L:2!P96%B('-I<V%L9&%M82!VY')V:6MO;V1I(%)'0B!(97@@
M:W5J=6PL(&[D:71E:W,@)R,Q,C,T868G+@!3964@=F]R;2!O;B!J=6)A(&SD
M8FD@=/;V=&%T=60N`%-E92!O;B`E<RX`4V5E(&]N($MO;&%B($=R;W5P=V%R
M92!O8FIE:W0N(%-E;&QE(&]B:F5K=&D@=F%A=&%M:7-E:W,@=F%J860@92UP
M;W-T:2!K;&EE;G1I(&UI<R!M]6ES=&%B($MO;&%B($=R;W5P=V%R92!F;W)M
M86%T:2X@4V5L;&ES=&4@92UP;W-T:2!K;&EE;G1I9&4@;FEM96MI<FIA(&QE
M:6%D(&%A9')E<W-I;'0@)7,`4V5E(&MI<FD@;VX@:VER:G5T871U9"!MY')G
M:7-T:6MU<R`H)7,I(&UI<R!E<FEN96(@<VEN=2!O;6%S="X`4V5E(&%R=B!P
M96%B(&]L96UA(';D:&5M86QT(/QK<RX`4V5E('-E<G9E<B!E:2!M]6ES=&$@
M;&%H=&D@<&%K:VED82!Z:7`@:F$@9WII<"!F86EL92X`4V5E('/\<W1E96T@
M;VX@<')A96=U(';D;&IA(&S\;&ET871U9"X`4V5L;&4@:V]H82!P96%L('!E
M86(@;VQE;6$@87)V+@!3964@86ME;B!T=6QE8B!A=F%D82!396%D971E(&%K
M;F%S=`#$:6ME`$AE;'!D97-K`$%E9P!4]O9A:F%T86)E;`!!:F$@97-I='5S
M`$%J82!V86QI:P!)9&$M5&EM;W(`4&5A;&MI<FD`4&5A;&MI<FD@*'1O;VQT
M:7`I`$ME;&QE;&4`36ET;64@;V)J96MT:2!V86QI;6ES96MS(&AO:6$@86QL
M($-T<FP@*%!#*2!V]6D@0V]M;6%N9"`H36%C*2!K;&%H=FD@:F$@:VSU<'-A
M(&]B:F5K=&ED96PN`%3D;F$`2%1-3"!K;V]D:2!R97II:6T`5&]G;P!4;VME
M;&%U`$AO;6UE`%1O;F=A`%9I:6UA<W1E;"!M:6YU=&ET96P@;VX@;&EI9V$@
M<&%L:G4@;G5R:G5N=60@<VES<V5L;V=I;6ES:2X`W&QE<P!096%L;6ES97,@
M<F%A;6ES("A?=&]P*0!4]6QK960`5')I;FED860@:F$@5&]B86=O`%3U9&4@
M=O5I('9A;&4`5&4`5'5N965S:6$`5/QR9VD`5/QR9VD@*$E33RTX.#4Y+3DI
M`%1U<FMM96YI<W1A;@!4=7)K<R!J82!#86EC;W,`5'5V86QU`$MI<FIU=&$@
M;VUA('9A;&EK.@!55BUI;F1E:W,Z(`!54DP`4VEN=2!S:W)I<'1I(&OD='1E
M=&]I;65T86UI<W)A<&]R=&D@55),`%523#H`56=A;F1A`%5K<F%I;F$`16D@
M<.3D<V4@;&EG:2!61E,@:V%T86QO;V=I;&4N`%3D:65N9&%V82!K87-U=&%J
M86EN9F\@;&ES86UI;F4@;&EI='5M:7-E;"!E:2#U;FYE<W1U+@!%:2!S86$@
M;75U=&$@5D93(&9A:6QI("(E<R(@]6EG=7-I+@!%:2!S86$@;75U=&$@5D93
M(&9A:6QI("5S+R5S(/5I9W5S:2X`16D@<V%A(&UI;FYA(&MA=&%L;V]G:2`E
M<RX`1F%I;&D@(B5S(B!S=75R=7-T('!O;&4@=O5I;6%L:6L@:V]N=')O;&QI
M9&$N`$9A:6QI("(E<R\E<R(@<W5U<G5S="!P;VQE(';U:6UA;&EK(&MO;G1R
M;VQL:61A+@!%:2!S86$@_&AE;F1U<W0@4U%,('-E<G9E<FEG82X`4U-,(/QH
M96YD=7-E(&%L9V%T86UI;F4@;G5R:G5S+@!61E,@9F%I;&D@:V]P965R:6UI
M;F4@;G5R:G5S+@!61E,@:V%T86QO;V=I("(E<R(@;&]O;6EN92!N=7)J=7,N
M`%9&4R!K871A;&]O9VD@;&]O;6EN92!N=7)J=7,N`%9&4R!F86EL:2!L;V]M
M:6YE(&YU<FIU<RX`5D93(&MA=7-T82`B)7,B(&QO;VUI;F4@;G5R:G5S+@!%
M:2!S86$@;'5U82!T_&AJ82!61E,@9F%I;&DN`$QA:'1I<&%K:VEM:6YE(&YU
M<FIU<RX`(B5S(B!E:2!S86$@:W5S='5T861A+"!K871A;&]O9R!E:2!O;&4@
M=/QH:2X`16D@<V%A(&MU<W1U=&%D82`B)7,B.B`E<RX`)7,@96D@<V%A(&MU
M<W1U=&%D82P@:V%T86QO;V<@96D@;VQE('3\:&D`5D93(&MA=&%L;V]G:7!U
M=2!K=7-T=71A;6EN92!N=7)J=7,N`%9&4R!K871A;&]O9VD@:W5S='5T86UI
M;F4@;G5R:G5S+@!%:2!S86$@:W5S='5T861A(%9&4R!K871A;&]O9VDZ("5S
M+@!%:2!S86$@:W5S='5T861A(%9&4R!F86EL:2`B)7,B+@!61E,@9F%I;&D@
M:W5S='5T86UI;F4@;G5R:G5S+@!%:2!S86$@:W5S='5T861A(%9&4R!K875S
M=&$@(B5S(BX`16D@<V%A(&MU<W1U=&%D82!61E-I(')E:W5R<VEI=G-E;'0Z
M("5S+@!*;V]K<W9A="!K871A;&]O9VD@96D@]6YN97-T=2!T=79A<W1A9&$N
M`$5I('-A82!KY'1T92!S97)T:69I:V%A9&D@_&MS:6MA<VIU`"5S(&1E9FEN
M:71S:6]O;FD@;&%A9&EM:6YE(&YU<FIU<RX`5D93(&9A:6QI(/QM8F5R=/5S
M=&UI;F4@;G5R:G5S+@!%:2!S86$@879A9&$@5D93(&9A:6QI("(E<R(N`$5I
M('-A82!A=F%D82!61E,@9F%I;&D@;75U=&UI<V5K<RX`5D93(&9A:6QI(&%V
M86UI;F4@;G5R:G5S+@!086MI='5D(&%R:&EI=FD@879A;6EN92!N=7)J=7,N
M`$5I('-A82!L=6=E9&$@5D93(&9A:6QI("AF:6QE<VEZ92@I(&YU<FIU<RDN
M`$5I('-A82!L=6=E9&$@5D93(&9A:6QI("AG971&:6QE4VEZ92@I(&YU<FIU
M<RDN`$5I(/5N;F5S='4@;'5G961A(&9A:6QI.B``=F9S<F]O="!K871A;&]O
M9VD@;'5G96UI;F4@;G5R:G5S+@`E<R!E:2!S86$@_&UB97(@;FEM971A9&$@
M)7,M:W,Z('-I:'1K875S="!O;B!J=6)A(&]L96UA<RX`5D93(&MA=&%L;V]G
M:2#\;6)E<FYI;65T86UI;F4@;G5R:G5S+@!%:2!S86$@_&UB97(@;FEM971A
M9&$@5D93(&MA=&%L;V]G:3H@)7,`16D@<V%A(/QM8F5R(&YI;65T861A(%9&
M4R!F86EL:2`B)7,B+@!%:2!S=75D82#\;6)E<B!N:6UE=&%D82!61E,@9F%I
M;&D@)7,O)7,N`%9&4R!F86EL:2#\;6)E<FYI;65T86UI;F4@;G5R:G5S+@!%
M:2#U;FYE<W1U(&OD:79I=&%D82`G;6MI<V]F<R<N`%-E9&$@5V]R9&D@9&]K
M=6UE;G1I(&]N(';U:6UA='4@=/5L9V5N9&%D80!%:2!S86$@:VER:G5T861A
M(%9&4R!F86EL:2`B)7,B+@!%:2!S86$@:VER:G5T861A(%9&4R!F86EL:2`H
M8V]P>2@I(&YU<FIU<RDN`%9&4R!F86EL:2!A;F1M971E('-A;'9E<W1A;6EN
M92!N=7)J=7,N`$5I('-A82!K:7)J=71A9&$@5D93(&9A:6QI+"!K971T86MV
M;V]T(&SD:&5B(&SU:&MI+@!!;&QA:F]O;FET=60@=&5K<W0`5&%A<W1A(&%L
M9W-E:7,`5O5T86(@=FEI;6%S92!T96=E=G5S92!T86=A<VD`3V]T86UA='4@
M=F%S='5S('-E<G9E<FEL="#\:&5N9'5S92!L;V]M:7-E;#H@`$]O=&%M871U
M('9A<W1U<R!S97)V97)I;'0Z(`!+871E9V]O<FEA=&$`56YI8V]D92`H551&
M+3@I`$%R86%B:6$@W&AE;F1E;6ER86%D:60`4W5U<F)R:71A;FYI80!!;65E
M<FEK82#<:&5N9')I:6=I9`!!;65E<FEK82#<:&5N9')I:6MI9&4@=N1I:V5S
M86%R960`W&AI:W5D`%1U;F1M871U`%1U;F1M871U(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN`%1U;F1M871U(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN`$WDY')A=&D@='5N9&UA='4@87-U:V]H="X`5'5N9&UA='4@:V%S
M=71A:F%N:6UI(&IA('-A;&%S]6YN82X`W&AE;F1A('-E92!E;&5M96YT(&QA
M:'1I+@!.:6UE='4`U6EG=7-T971A('-K<FEP=&ED(&5I('-A82!T=7)V86MA
M86QU=&QU<W1E;"!P<F]G<F%M<V5L="!S;V]R:71A9&$@;/5I:V%M:7-T+VML
M965P:6UI<W0N($MU:2!K;/5P<V%D($]++"!NY&5D(&UO>FEL;&$N;W)G('1E
M:&YI;&ES="!S96QG:71U<W0@:W5I9&%S(&QU8F%D82!S:W)I<'1I9&5L(&SU
M:6ME<'5H=G)I="!K87-U=&%D82X`165M86QD82!VY')V`%1O971A;6%T82!L
M86EE;F1U<P!+:6YN:71A`$UU=61A("5S`$UU=61A(&MA<W5T86IA`"(E<R(@
M;75U9&5T=60N`%5U96YD=7-E('-K<FEP="!K=7-T=71A='5D+@!,864@<V5R
M=F5R:7-S90!+]6EK(')A:V5N9'5S92!P86EG86QD=7-F86EL:60@;VX@<V5R
M=F5R:7-S92!L865T=60N`$QA9&EN82!S=75R=.1H960`4W5U<F5D(')O;VUA
M(&YU;6)R:60`57)U9W5A:0!+87-U=&$@<')A96=U<W0Z("5S`$MA<W5T82!3
M4TQI`$MA<W5T82!J=6AU;"!K=6D@;FEM:2]S86QA<_5N82!)35-0('-E<G9E
M<FES(&]N(&5R:6YE=BX`2V%S=71A:F$`2V%S=71A:F%L("5S(&5I(&]L92!L
M=6)A='5D("5S+@!+87-U=&%J86AA;&1U<P!+87-U=&%J82!S96%D:7-T=7,`
M2V%S=71A:F$@<F5G:7-T<F5E<FEM:6YE`%-E;&QE<R!S86ED:7,@:V%S=71A
M:F%T92!R96=I<W1R965R:6UI<W0@96D@=O5I;6%L9&%T82X`2V%S=71A:F%K
M;VYT;W0@96D@;&5I='5D`$MA<W5T86IA;FEM:0!+87-U=&%J86YI;6D@(B5S
M(B!O;B!J=6)A(&]L96UA<RX`2V%S=71A:F%N:6UI.@!+87-U=&%J86YI;6DZ
M`$MA<W5T86IA9"!S_'-T965M:7,Z`%5S8F5K:7-T86X`5D93(&MA=&%L;V]G
M:2!P;VQE(&]L96UA<RX`4'5H:W5S`$]L96UA<V]L979A9"!K;W)R96MT<V5D
M(&%S=6MO:&%D(&]N.B``2V5H=&EV=7,`36EN=71I=&4@87)V('!R865G=7-E
M<W0@:&5T:V5S="!A;&%T97,N`%;DY')T=7,@_&QE=&%B("5S(&UA:W-I;75M
M<&EK:W5S92X`5N3D<G1U<V5D`%;DY')T=7-E9"!M:6QL92!H=6QG87-T('9A
M;&ED80!686YU871U`$UU=71L:6L`5F5N971S=65E;&$`2V]N=')O;&QI;6EN
M92!N=7)J=7,@+2!S964@:VER:2!V]6EB(&]L;&$@<&%H871A:'1L:6MU;'0@
M;75U9&5T=60N`$KD<FIE;G5M8F5R`%9E<G-I;V]N:6AA;&1U<P!697)T:6MA
M86QN92!J;V]N9'5S`%9E<G1I:V%A;&YE('9O;V1E<F1U<P!697)T:6MA86QN
M93H`5N1G82!K]7)G90!6:65T;F%M`%9I971N86UI("A625-#24DI`%9A871A
M("5S`%9A871A(';D;&ES="!V965B:6QE:'1E`%9A871A(&MU:2`E<P!"<FET
M:2!.96ET<VES86%R960`55-!($YE:71S:7-A87)E9`!.Y&AT879U<P!.Y&AT
M879U<SH@`%9O9&%F;VYE($ET86QY(/QL92!33510`$A/24%455,`2$])0515
M4R$A(2!+55-4551!(%-+4DE05"!+Q%-)5%-)($M!5$%,3T]'25-4("5S+@!7
M24X@_&QE($A45%``5V%L;&ES(&IA($9U='5N80!(;VEA='5S`$MO`$EL;6%E
M;FYU<W1U<P!);&UA86YD;65I9"!P86MU8@!796%T:&5R+F-O;0!6965B`%9E
M96)I<V%I=`!+;W)D(&[D9&%L87,`5&5R92!T=6QE;6%S=`!497)E('1U;&5M
M87-T("5S+6D`5&5R92!T=6QE;6%S="P@)7,`3.3D;F4@*$E33RTX.#4Y+3$I
M`$SDY&YE("A)4T\M.#@U.2TQ-2D`3.3D;F4M4V%H87)A`$UI;&QI<V4@<F%K
M96YD=7-E('!E86MS("5S('#D<F%S="!S:7-S96QO9VEM:7-T(&%V86UA/P!-
M:6QL:7-T(&WD<FMI(&MA<W5T871A:W-E(&5R86QD86IA;F$_`$UI;&QI<W0@
M;>1R:VD@:V%S=71A=&%K<V4@:G5T=6WD<F=I;F$_`%=H97)E:7,@075S=')A
M;&EA(&MA87)T`$UI;&QI<V5D(&9A87-I9`!-:6QL:7-E:60@<&QU9VEN86ED
M(&QU8F%D82!2:6-H(%1E>'0@961I=&]R:7,N`$QA:75S`$QA:75S($-34R#\
M:&EK=71E<P`E<R!M96[\_"!L86EU<R!V87-A:W5L("AH86MK86(@;?5J=6UA
M(&KD<F=M:7-E;"!S:7-S96QO9VEM:7-E;"DZ`%1A8F5L:2!L86EU<P!,86EU
M<_QH:6L`3&%I=7,Z`%=I:VD`5'5U;`!(;VUM:6MU;"!T=75L`%1U=6QE(&MI
M:7)U<R!S]6QM961E<P!4=75L.@!4=75L.B``5&%R:W5S`%-O;W9I;FEM96MI
M<FD`5/;V`%3V]FMO:&$@86%D<F5S<P!4]O9T96QE9F]N`%)E87,@)60@;VX@
M=F%L92!A<G8@=N1L:G4N(%!E86MS(&]L96UA("5D+"!A9V$@;VX@)60N`%9A
M;&4@87)V(';D;&IU+B!096%K<R!O;&5M82`E9"P@86=A(&]N("5D+@!686QE
M(&%L9W5S<'5N:W0@)60@5D93(&9A:6QI(&QU9V5M:7-E;"X`6"U2968`6#4P
M.78S('#U:&EL:7-E9"!P:6ER86YG=60`6#4P.78S(';U=&UE(&QA:65N9&%T
M=60@:V%S=71U<P!8-3`Y=C,@<W5B:F5K=&D@86QT97)N871I:79N92!N:6UI
M`%@U,#EV,R!S=6)J96MT:2!V]71M92!I9&5N=&EF:6MA871O<@!8-3`Y=C,@
M;&%I96YD=7-E9`!!00!!04%!`%EA:&]O(2!K86%R=`!+;W)D(&%A<W1A<P!*
M965M96X`2F%H`$IA:"P@;VQE;B!N]75S`$]L960@5$5+4U1)4D5:24E-25,N
M($ML]7!S82!;/#Y=(&5T(&UI;FYA('1A9V%S:2!765-)5UE'(')E>FEI;6DN
M`$5I(&]L92!L=6)A='5D(&QU=6$@<F]H:V5M(&MU:2`E9"!B;&]K:VDN`%-A
M(&5I(&]L92!S:7-S92!L;V=I='5D+@!3:6YU('3D:7-N:6UI(&5I(';U:2!S
M:7-A;&1A9&$@)UPG(&WD<FMI+@!382!E:2!S:7-E<W1A;G5D(&MO<G)E:W1S
M970@92UP;W-T:2!A861R97-S:2X`4V$@96D@<V5A9&YU9"!I;7!O<F1I='5D
M(&9A:6QI(';D;&IU('9A<W1A=G5S<V4@)7,@=N1L:F%D96=A+@!3:6YD(&QO
M9VET:2!VY&QJ82X`4V$@<&5A9"!S:7-E<W1A;6$@:V5H=&EV82!M;V)I:6QT
M96QE9F]N:2!N=6UB<FD@;6ES('-I<V%L9&%B(&%I;G5L="!N=6UB<F5I9"!J
M82!M:6QL92!A;&=U<V5S(';U:6(@;VQL82`G*R<@<F%H=G5S=F%H96QI<V4@
M<W5U;F%K;V]D:2!T=6YN=7-E;F$N`%-A('!E860@<VES97-T86UA(&MO<G)E
M:W1S92!VY.1R='5S92X`3&EI='5M:7-E(&QU8F%M:7-E:W,@<&5A9"!S96%D
M:7-T86UA($1A=&%4<F5E('/\<W1E96UI+@!382!P96%D('-E861I<W1A;6$@
M5D93('/\<W1E96UI+@!%;FYE('-A871M:7-T(&]L96MS('1A<FL@<')O8FQE
M96UI(&MI<FIE;&1A9&$N`%-A('!E860@<VES97-T86UA(%523&D@:W5H=2!S
M964@;&EN:R!V:6ET86(`4&5A9"!MY.1R86UA(&MU<W1U=&%T879A('-E<G9E
M<FDN`%!E860@;>3D<F%M82!K87-U=&%J86YI;64@;6ED82!T_&AJ96YD861A
M+@!096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@965M86QD861A+@!0
M96%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@;&ES861A+@!096%D(&WD
MY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@;75U=&$N`%!E860@;>3D<F%M82!T
M96=E=G5S92P@;6ED82!S;V]V:60@=&5H82X`4&5A9"!S:7-E<W1A;6$@=75E
M(&MA=&5G;V]R:6$@;FEM92X`4&5A9"!S:7-E<W1A;6$@271A86QI82!T96QE
M9F]N:6YU;6)R:0!3:6YU("5S('-E<W-I;V]N(&]N(&%E9W5N=60N(%!A;'5N
M(&QO9VD@=75E<W1I('-I<W-E+@!3:6YU(&4M<&]S=&D@86%D<F5S<SH`4VEN
M=2!S86%T:F$@86%D<F5S<SH`4VEN=2!I;F9O`%-I;G4@:6YT97)N971I86%D
M<F5S<R!O;B`E<R!S97-S:6]O;FD@:F]O:W-U;"!M=75T=6YU9"X@5'5R=F%L
M:7-U<V4@=&%G86UI<V5K<R!P96%D('5U97-T:2!S:7-S92!L;V=I;6$N`%-I
M;G4@;FEM:0!3:6YU(&%U=&5N=&EM:7-S_'-T965M(&5I(';U:6UA;&1A(&MA
M<W5T86IA:60@;&ES861A+B!+=6D@<V]O=FED($AO<F1E(&%B:6P@:V%S=71A
M:F%I9"!H86QL871A+"!P96%D(&MA<W5T86UA('1E:7-T<W5G=7-T(&%U=&5N
M=&EM:7-S_'-T965M:2X`4VEN=2!A=71E;G1I;6ES<_QS=&5E;2!E:2!V]6EM
M86QD82!K87-U=&%J871E(&YI;65K:7)J82!NY&AA+"!V]6D@;VX@<V5E(';U
M:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA(&S\;&ET871U9"X`
M4VEN=2!V965B:6QE:&ET<V5J82!NY&EB(&]L979A="`E<R!S97-S:6]O;FD@
M:F]O:W-U;"!M=75T=6YU9"X@5'5R=F%L:7-U<V4@=&%G86UI<V5K<R!P96%D
M('5U97-T:2!S:7-S92!L;V=I;6$N`%-I;G4@=F5E8FEL96AI='-E:F$@96D@
M=O5I;6%L9&$@<V5D82!O;6%D=7-T(&MA<W5T861A+@!3:6YU('9E96)I;&5H
M:71S96IA(&5I(';U:6UA;&1A(&YI:6UO;V1I('1R_&MK:61A+B!686IU=&$@
M='+\:VMI;6ES96MS($-O;G1R;VPK4"!V]6D@0V]M;6%N9"M0+@!3:6YU(&%J
M87;V]FYD.@!3:6YU('9A:6ME:61E;G1I=&5E="!O;B!M=75D971U9"X`4VEN
M=2!V86EK96ED96YT:71E970Z`%-I;G4@=.1I96QI:R!N:6UI.@!3:6YU('-I
M<W-E;&]G:6UI;F4@;VX@865G=6YU9"X`4VEN=2!U=7,@)7,@<V%L87/U;F$@
M;VXZ("5S`$UU=61A='5S960@;VX@<V%L=F5S=&%T=60@<V5L;&4@<V5S<VEO
M;VYI(&SU<'5N:2X`375U9&%T=7-E9"!O;B!S86QV97-T871U9"X`4VEN=2!S
M86QA<_5N82!O;B!V86AE=&%T=60`4VEN=2!S86QA<_5N82!O;B!V86AE=&%T
M=60L('9A871A(&]M82!E+7!O<W1I(&IA(&QO9VD@<VES<V4@=75E('-A;&%S
M]6YA9V$N`%-I;G4@<V%L87/U;F$@;VX@865G=6YU9"X`4VEN=2!VY&QI<V5D
M('-E<G9E<FED.@!*=6=O<VQA879I80!:86ER`%-A;6)I80!::6UB86)W90!:
M:7!P>0!;4&5I9&$@;W-U;F1A='5D('1E:W-T70!;2&]R9&4@<')O8FQE96U=
M`%M.Y&ET82!O<W5N9&%T=60@=&5K<W1I("T`6T[D:71A(&]S=6YD871U9"!T
M96MS=&D@+2`E<R!R:61A70!;<FED82`E<R`E<RUS=%T`7TAA;&1U<P!+Y'-U
M7W)I9&$`7T1A=&%4<F5E`%]+=7-T=71A(')I9&$`7T=R=7!I9`!!7V)I`%]0
M:6QD:2!O;6%D=7-E9"XN+@!?3&]G:2!S:7-S90!?3&]G:2!VY&QJ80!?375U
M9&$@;&EN:VDN+BX`7U-E861I<W1U<P#5:6=?=7-E9`!?165M86QD82!L:6YK
M+BXN`%]086EG86QD=7,`7U1A8F5L:2!O;6%D=7-E9"XN+@!?2V%S=71A:F%D
M`&%A9')E<W-I<F%A;6%T`&%D<F5S<V%A="!T=6YD;6%T=0!K86QE;F1E<@!V
M86EK;F4`=N1L:G5N9&9A:6QI(&QO;VUI;F4@;G5R:G5S`'-I<V5N9&D@879A
M;6EN92!N=7)J=7,`:VSU<'-A('-I:6$`:^1S=7)E82!K87-U=&%M:7-E('9I
M9V$`<V5A9&ES='5S92!V:6=A`&5L=73D:'1I<R!S_'-T965M:69A:6P@;VX@
M<'5U9'4`86YD;65T92!F;W)M86%D:2!V:6=A`&UU=61A`&MA;FYE="!E:2!L
M96ET=60`;&%N9V5B`&9A:6P`<W5U;F0@)7,@*"5S*2!J82!K:6ER=7,@)7,@
M)7,`<'5H86YG=6QI;F4`:SH`='0`='5N9&UA='4@:&]S=&EN:6UI`'9I:79I
M=&%M871U`&EN;&EN90!S:7-E;F0O=N1L:G5N9"!V:6=A`'1A<FMV87)A('-E
M97-M:6YE('9I9V$`<FED85T`;6MI<V]F<R!V96%K;V]D("5D($E33R!L;V]M
M:7-E;"X`;6T`;FEM:0!P;VQE('1E;W-T871U9`!P;VQE('9E96P@=&5O<W1A
M='5D`&WD<FMM:6L`<')O='-E;G1I`/5I9W5S960@<'5U9'5V860`<&EK<VQI
M=`!P<F]T;VMO;&QI('9I9V$@=&5I<V5S(&]T<V%S`'3U=7-E8@!T965N=7,@
M<&]L92!KY'1T97-A861A=@!NY&ET82!E<FEN979U<VD`<VUS,F5M86EL(/QL
M92!(5%10`'-S`/QH=&QA;F4`;/QL:71A(&IA=F%S8W)I<'0@=N1L:F$`<_QS
M=&5E;6D@=FEG80#\;&5S86YN971E(&YI;65K:7)I`&%J=71I;F4@=/5R9V4`
M<')O;W9I('5U97-T:0!K:7)J=71A('-A;&%S]6YA(&5K<VET=7-E(';D;'1I
M;6ES96MS(&MA:W,@:V]R9&$`_&AI=&%T=60`;FEM971U`&MA<W5T86IA('9A
M;&EK`'9#87)D`&PZ`'=E871H97(N8V]M````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]E=%]%12]H96QP+GAM;```````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`U,34T,S$P-C$`,#(P,C<U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_>&UL
M('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+V5T
M7T5%+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,34@:F%N($5X
M<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N
M97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@
M(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F
M(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L
M92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S
M('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N
M('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H
M96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@
M;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q
M=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@
M(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W
M(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A
M/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T
M;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE
M+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H
M:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H
M97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.
M879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H
M86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N
M879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N
M879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@
M8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@
M>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA
M;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X
M+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O
M;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O9G)?1E(O````````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`Q-C8T-0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F<E]&4B],0U]-15-304=%4R\`````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P
M-C$`,#(P-#,R`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V9R7T92
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#0R-34V-P`Q,#4Q-30S,3`V,0`P,C(Q,3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````")!P``'````&0\```3
M"@``K'@```````#XH```#@```/F@```/````"*$```T````8H0``"````":A
M```+````+Z$```P````[H0``!````$BA```8````3:$``!L```!FH0``+0``
M`(*A```=````L*$``"0```#.H0``*0```/.A```9````':(``"8````WH@``
M#````%ZB```D````:Z(```\```"0H@``"P```*"B```.````K*(```4```"[
MH@``*````,&B```(````ZJ(```H```#SH@``%0```/ZB```2````%*,```L`
M```GHP``A0```#.C```.````N:,```H```#(HP``#0```-.C```.````X:,`
M`!$```#PHP``#0````*D```,````$*0```T````=I```!@```"ND``"4````
M,J0```H```#'I```#P```-*D```8````XJ0```P```#[I```#@````BE```.
M````%Z4```@````FI0``"0```"^E```N````.:4``!H```!HI0``,@```(.E
M```X````MJ4``%0```#OI0``40```$2F``!:````EJ8``%<```#QI@``-```
M`$FG```)````?J<```T```"(IP``!P```):G```*````GJ<```\```"IIP``
M!0```+FG```&````OZ<``!$```#&IP``"````-BG```)````X:<```D```#K
MIP``)0```/6G```@````&Z@``!,````\J```$````%"H```/````8:@```H`
M``!QJ````P```'RH```/````@*@``!0```"0J```"0```*6H```-````KZ@`
M`!(```"]J```&0```-"H```>````ZJ@```\````)J0``"@```!FI```/````
M)*D```@````TJ0``)````#VI```4````8JD``!8```!WJ0``"````(ZI``!.
M````EZD``"T```#FJ0``&0```!2J```'````+JH```P````VJ@``+````$.J
M```.````<*H```,```!_J@``"P```(.J```'````CZH```<```"7J@``!0``
M`)^J```%````I:H```H```"KJ@```P```+:J```7````NJH```H```#2J@``
M#P```-VJ```.````[:H``!@```#\J@``(P```!6K```.````.:L``!0```!(
MJP``%P```%VK```7````=:L``!<```"-JP``$P```*6K```/````N:L```X`
M``#)JP``'P```-BK```=````^*L```<````6K```!@```!ZL```(````):P`
M``\````NK```!@```#ZL```*````1:P``!,```!0K```"P```&2L```0````
M<*P``!4```"!K```%0```)>L```'````K:P``!````"UK```!0```,:L```5
M````S*P``!$```#BK```#````/2L```[`````:T``#@````]K0``"0```':M
M```'````@*T``!0```"(K0```P```)VM```%````H:T``!````"GK0``"0``
M`+BM```3````PJT``#D```#6K0``$@```!"N```G````(ZX``"P```!+K@``
M*@```'BN```E````HZX```H```#)K@``!@```-2N```)````VZX```<```#E
MK@``+P```.VN```W````':\``"X```!5KP``50```(2O```M````VJ\``"T`
M```(L```/0```#:P```_````=+```"T```"TL```0````.*P```C````([$`
M`",```!'L0``0````&NQ```M````K+$``#,```#:L0``)0````ZR```5````
M-+(``!D```!*L@``*0```&2R```D````CK(``"@```"SL@``$0```-RR```*
M````[K(```P```#YL@``"@````:S```0````$;,``!8````BLP``%@```#FS
M```'````4+,```<```!8LP``%````&"S```*````=;,```@```"`LP``)P``
M`(FS```(````L;,```<```"ZLP``!P```,*S```&````RK,```4```#1LP``
M!P```->S```&````W[,```@```#FLP``*0```.^S```.````&;0```H````H
MM```!````#.T```'````.+0```D```!`M```!@```$JT```1````4;0```<`
M``!CM```%@```&NT```$````@K0```@```"'M```!@```)"T```-````E[0`
M``8```"EM```'@```*RT```1````R[0```@```#=M```#0```.:T```,````
M]+0```<````!M0```P````FU```#````#;4``!<````1M0``$P```"FU```=
M````/;4```@```!;M0``!````&2U```(````:;4```@```!RM0``00```'NU
M```:````O;4``"L```#8M0``(`````2V```5````);8```8````[M@``!@``
M`$*V```5````2;8``!@```!?M@``(@```'BV```N````F[8``!T```#*M@``
M(0```.BV``!4````"K<``"D```!?MP``"@```(FW```'````E+<```<```"<
MMP``%0```*2W```.````NK<```H```#)MP``#P```-2W```-````Y+<```\`
M``#RMP``#0````*X```)````$+@``!0````:N```!@```"^X```8````-K@`
M`!T```!/N```$P```&VX```1````@;@``!0```"3N```!````*BX```&````
MK;@``!0```"TN```5````,FX``!D````'KD```0```"#N0``#@```(BY```%
M````E[D```4```"=N0``&P```*.Y```:````O[D``!,```#:N0``$0```.ZY
M```1`````+H``!P````2N@``*@```"^Z```0````6KH``"$```!KN@``!0``
M`(VZ```3````D[H```L```"GN@``$@```+.Z```*````QKH```\```#1N@``
M#0```.&Z```1````[[H``!,````!NP``#````!6[```&````(KL```P````I
MNP``!@```#:[```7````/;L``!````!5NP``$0```&:[```(````>+L```4`
M``"!NP``#````(>[```0````E+L```4```"ENP``#0```*N[```&````N;L`
M``<```#`NP``#0```,B[```'````UKL```L```#>NP``!P```.J[```'````
M\KL```D```#ZNP``"0````2\```*````#KP``!D````9O```/0```#.\```=
M````<;P```P```"/O```$````)R\```%````K;P``"4```"SO```$@```-F\
M```3````[+P``"L`````O0``.P```"R]```@````:+T```@```")O0``-@``
M`)*]```A````R;T``!````#KO0``"````/R]```,````!;X```8````2O@``
M!````!F^```/````'KX```X````NO@``!P```#V^```*````1;X```T```!0
MO@``'P```%Z^```<````?KX``"$```";O@``'@```+V^```9````W+X``!X`
M``#VO@``&P```!6_```A````,;\``"X```!3OP``)@```(*_```<````J;\`
M`!X```#&OP``'````.6_```F`````L```"L````IP```,P```%7````F````
MB<```"L```"PP```.````-S````=````%<$``!4````SP0``+P```$G!```@
M````><$``!(```":P0``*0```*W!```>````U\$``"````#VP0``$@```!?"
M``"B````*L(``!8```#-P@``(P```.3"```H````",,``"D````QPP``*```
M`%O#```?````A,,``!4```"DPP``(````+K#```E````V\,``"@````!Q```
M+0```"K$```P````6,0``)(```")Q```(0```!S%```6````/L4``!P```!5
MQ0``)@```'+%```J````F<4``$$```#$Q0``1`````;&```,````2\8```<`
M``!8Q@``!P```&#&```&````:,8```T```!OQ@``$````'W&```2````CL8`
M`!,```"AQ@``$@```+7&```'````R,8```0```#0Q@``$````-7&```0````
MYL8```P```#WQ@``#@````3'```-````$\<```\````AQP``$P```#''```-
M````1<<``"@```!3QP```P```'S'```-````@,<```8```".QP``$0```)7'
M```7````I\<``!L```"_QP``#@```-O'```"````ZL<``$D```#MQP``!0``
M`#?(```0````/<@```\```!.R```!````%[(```-````8\@```X```!QR```
M`P```(#(```.````A,@```@```"3R```#P```)S(```/````K,@```<```"\
MR```#0```,3(```0````TL@```T```#CR```"P```/'(```&````_<@```L`
M```$R0``#````!#)```*````'<D``!$````HR0``&0```#K)```+````5,D`
M``T```!@R0``(@```&[)```/````D<D``!L```"AR0``-````+W)```*````
M\LD``!@```#]R0``$@```!;*```9````*<H``!8```!#R@``(@```%K*```-
M````?<H```<```"+R@``%````)/*```+````J,H``"(```"TR@``+P```-?*
M```+````!\L```D````3RP``&0```!W+```+````-\L``!<```!#RP``%P``
M`%O+```)````<\L``!8```!]RP``#P```)3+```9````I,L``!8```"^RP``
M#@```-7+```8````Y,L```@```#]RP``#0````;,```F````%,P``$,````[
MS```"````'_,```2````B,P``!\```";S```"````+O,```+````Q,P``"\`
M``#0S```#@````#-```%````#\T```8````5S0``10```!S-```#````8LT`
M``<```!FS0``!````&[-```*````<\T```H```!^S0``#P```(G-```0````
MF<T``!<```"JS0``$0```,+-```9````U,T``!<```#NS0``"0````;.```%
M````$,X```L````6S@``"@```"+.```"````+<X```4````PS@``#0```#;.
M```;````1,X``!<```!@S@``%````'C.```)````C<X```X```"7S@``#0``
M`*;.```2````M,X``#@```#'S@``(`````#/```(````(<\```X````JSP``
M>P```#G/```8````M<\``!@```#.SP``$0```.?/```'````^<\```4````!
MT```&`````?0```>````(-```!L````_T```&0```%O0```;````==```!D`
M``"1T```$P```*O0```'````O]````@```#'T```!@```-#0```&````U]``
M`!````#>T```#P```._0```0````_]````\````0T0``"P```"#1```/````
M+-$```P````\T0``#P```$G1```'````6=$```8```!AT0``#@```&C1```,
M````=]$``"@```"$T0``#P```*W1```(````O=$```@```#&T0``$P```,_1
M```>````X]$``"$````"T@``(````"32```9````1=(``!<```!?T@``)0``
M`'?2```7````G=(``!8```"UT@``!````,S2```;````T=(```T```#MT@``
M#````/O2```#````"-,```4````,TP``"````!+3```*````&],```P````F
MTP``"P```#/3```0````/],```P```!0TP``#@```%W3```+````;-,```0`
M``!XTP``!````'W3```3````@M,``!0```"6TP``#````*O3```)````N-,`
M``X```#"TP``"P```-'3```;````W=,```<```#YTP``!P````'4```*````
M"=0```T````4U```"0```"+4```$````+-0```4````QU````P```#?4```8
M````.]0```H```!4U```!````%_4```F````9-0```X```"+U```?````)K4
M```5````%]4```4````MU0``!P```#/5```,````.]4```@```!(U0``"@``
M`%'5```&````7-4```@```!CU0```@```&S5```&````;]4```8```!VU0``
M%````'W5```-````DM4``!````"@U0``&P```+'5```$````S=4```D```#2
MU0``$````-S5```)````[=4```D```#WU0``!0````'6```:````!]8```@`
M```BU@``!@```"O6```9````,M8```X```!,U@``!P```%O6```'````8]8`
M``4```!KU@``"0```''6```*````>]8```X```"&U@```@```)76```&````
MF-8```L```"?U@``#0```*O6```)````N=8```8```##U@``$@```,K6```)
M````W=8```<```#GU@``%````._6```=````!-<``$(````BUP``)0```&77
M```E````B]<```8```"QUP``"@```+C7```$````P]<```D```#(UP``"```
M`-+7```1````V]<```D```#MUP``!@```/?7```-````_M<```8````,V```
M!````!/8```Y````&-@``#T```!2V```.@```)#8```>````R]@```4```#J
MV```#@```/#8```$````_]@```8````$V0``!P````O9```A````$]D```T`
M```UV0``%0```$/9```&````6=D```0```!@V0``$0```&79```&````=]D`
M``H```!^V0``(@```(G9```$````K-D```4```"QV0``'0```+?9```$````
MU=D```P```#:V0``#@```.?9```*````]MD```@````!V@``"0````K:```%
M````%-H``#H````:V@``,````%7:```U````AMH``"D```"\V@``1P```.;:
M```X````+ML``"D```!GVP``/P```)';```N````T=L``"T`````W```'P``
M`"[<```/````3MP``!(```!>W```"P```''<```F````?=P``"D```"DW```
M)````,[<```F````\]P```@````:W0``"@```"/=```)````+MT```<````X
MW0``(````$#=```@````8=T``"8```""W0``"@```*G=```9````M-T``"D`
M``#.W0``%@```/C=```2````#]X```<````BW@``"@```"K>```,````-=X`
M``\```!"W@``$````%+>``!`````8]X``'````"DW@``9@```!7?```.````
M?-\```D```"+WP``"@```)7?```2````H-\``!,```"SWP``#````,??```&
M````U-\```\```#;WP``$@```.O?```0````_M\``!$````/X```'````"'@
M```C````/N```&H```!BX```#P```,W@```%````W>```!````#CX```"0``
M`/3@```$````_N````L````#X0``(`````_A```4````,.$```P```!%X0``
M#````%+A```/````7^$``!4```!OX0``*0```(7A```J````K^$``"8```#:
MX0``)P````'B```I````*>(``"H```!3X@``&0```'[B``!"````F.(``!$`
M``#;X@``$@```.WB```3`````.,``!0````4XP``#P```"GC```6````.>,`
M`!<```!0XP``$````&CC```1````>>,``#0```"+XP``$P```,#C```2````
MU.,``#4```#GXP``%````!WD```'````,N0```P````ZY```(````$?D```0
M````:.0``!0```!YY```$0```([D```7````H.0``!P```"XY```$P```-7D
M```4````Z>0``!H```#^Y```$0```!GE```:````*^4``!X```!&Y0``&@``
M`&7E```3````@.4``!4```"4Y0``$0```*KE```7````O.4``!0```#4Y0``
M%P```.GE```5`````>8```D````7Y@``$````"'F```9````,N8```0```!,
MY@``!P```%'F```+````6>8``!$```!EY@``!@```'?F```&````?N8```8`
M``"%Y@``!0```(SF```'````DN8```<```":Y@``!0```*+F```6````J.8`
M``8```"_Y@``!@```,;F```$````S>8```0```#2Y@``!P```-?F```.````
MW^8```P```#NY@``#````/OF```-````".<```H````6YP``#@```"'G```%
M````,.<``"@````VYP``#@```%_G```,````;N<```\```![YP``"@```(OG
M```(````EN<```D```"?YP``*P```*GG```$````U><```@```#:YP``)@``
M`./G```2````"N@```\````=Z```!@```"WH```*````-.@```<````_Z```
M"````$?H```@````4.@```D```!QZ```%````'OH```,````D.@```T```"=
MZ```#@```*OH```6````NN@``!$```#1Z```!@```./H```#````ZN@```8`
M``#NZ```&0```/7H```'````#^D```0````7Z0``"P```!SI```+````*.D`
M``<````TZ0``!0```#SI```'````0ND``!8```!*Z0``#0```&'I```-````
M;^D```H```!]Z0``$````(CI```/````F>D``!$```"IZ0``%P```+OI```*
M````T^D``!$```#>Z0``"````/#I```$````^>D```\```#^Z0``.@````[J
M```%````2>H```P```!/Z@``'@```%SJ```.````>^H``!````"*Z@``"P``
M`)OJ```,````I^H```D```"TZ@``!P```+[J```*````QNH```D```#1Z@``
M#@```-OJ```0````ZNH``!L```#[Z@``&````!?K```:````,.L```H```!+
MZP``"0```%;K```*````8.L```P```!KZP``#P```'CK```(````B.L```8`
M``"1ZP``'````)CK```'````M>L```4```"]ZP``"P```,/K``!'````S^L`
M``T````7[```"0```"7L```$````+^P```,````T[```$P```#CL```3````
M3.P``!,```!@[```"@```'3L```"````?^P```0```""[```)0```(?L```#
M````K>P```4```"Q[```*@```+?L```*````XNP```4```#M[```!````//L
M```*````^.P```T````#[0``!@```!'M```(````&.T```@````A[0``!```
M`"KM```%````+^T``&@````U[0``"0```)[M```,````J.T``!````"U[0``
M!0```,;M```&````S.T``!L```#3[0``+P```._M```0````'^X```H````P
M[@``#P```#ON```*````2^X```D```!6[@``$P```&#N```;````=.X``!@`
M``"0[@``%P```*GN```?````P>X```X```#A[@```P```/#N```'````].X`
M``@```#\[@``!P````7O```*````#>\```L````8[P``!P```"3O``!1````
M+.\``!````!^[P``#````(_O```-````G.\``!H```"J[P``2@```,7O```9
M````$/````8````J\```&@```#'P```E````3/````8```!R\```!@```'GP
M```?````@/````8```"@\```"0```*?P```8````L?```!<```#*\```*```
M`.+P```&````"_$```T````2\0``(@```"#Q``!7````0_$``!,```";\0``
M(P```*_Q```3````T_$```(```#G\0``"P```.KQ```(````]O$```T```#_
M\0``"@````WR```'````&/(``!0````@\@``!@```#7R```(````//(```X`
M``!%\@``!P```%3R```*````7/(```L```!G\@``,@```'/R```'````IO(`
M``P```"N\@``#0```+OR```7````R?(```P```#A\@``"0```.[R```)````
M^/(```H````"\P``!P````WS```)````%?,```<````?\P``"@```"?S```;
M````,O,```\```!.\P``$@```%[S```*````<?,``!8```!\\P``"0```)/S
M```0````G?,```<```"N\P``$@```+;S```$````R?,```<```#.\P``!0``
M`-;S```%````W/,```L```#B\P``%````.[S```1`````_0``!H````5]```
M%@```##T```4````1_0``!<```!<]```&````'3T```<````C?0``!D```"J
M]```!P```,3T```%````S/0```T```#2]```#````.#T```(````[?0``!<`
M``#V]```"P````[U```,````&O4``!\````G]0``&@```$?U```3````8O4`
M``0```!V]0``"@```'OU```$````AO4```T```"+]0``#````)GU```%````
MIO4```D```"L]0``!0```+;U```'````O/4```4```#$]0``!````,KU```"
M````S_4``#@```#2]0``+`````OV```2````./8``"D```!+]@``,@```'7V
M```*````J/8``"P```"S]@``+@```.#V```S````#_<``#,```!#]P``.```
M`'?W```/````L/<``!@```#`]P``$````-GW```/````ZO<``!,```#Z]P``
M%0````[X```4````)/@``!(````Y^```%````$SX```5````8?@``"T```!W
M^```+0```*7X```Q````T_@``"X````%^0``+P```#3Y```L````9/D``&(`
M``"1^0``$P```/3Y```-````"/H```@````6^@``%P```!_Z```(````-_H`
M``P```!`^@``*P```$WZ```A````>?H``!H```";^@``"0```+;Z``!%````
MP/H``$$````&^P``!````$C[```3````3?L``!0```!A^P``#@```';[```3
M````A?L``!@```"9^P``!@```++[```)````N?L```H```##^P``#P```,[[
M```0````WOL```<```#O^P``#@```/?[```%````!OP``!L````,_```"```
M`"C\```&````,?P``!0````X_```$0```$W\```.````7_P``#@```!N_```
M`@```*?\```&````JOP```X```"Q_```!0```,#\```'````QOP```X```#.
M_```!@```-W\```H````Y/P```P````-_0``'````!K]```$````-_T``"D`
M```\_0``%P```&;]```?````?OT``%P```">_0``%````/O]```^````$/X`
M`!\```!/_@``$````&_^```'````@/X```X```"(_@``#````)?^```,````
MI/X``!,```"Q_@``"@```,7^```=````T/X``!D```#N_@``!0````C_```1
M````#O\``!$````@_P``)````#+_```2````5_\``!4```!J_P``$@```(#_
M```.````D_\``!D```"B_P``"````+S_```)````Q?\```T```#/_P``!P``
M`-W_```*````Y?\```<```#P_P``#P```/C_```&````"``!``L````/``$`
M&@```!L``0`*````-@`!``<```!!``$`"````$D``0`%````4@`!`!\```!8
M``$`!@```'@``0`0````?P`!``@```"0``$`#0```)D``0`(````IP`!`!X`
M``"P``$`$@```,\``0`L````X@`!`!H````/`0$`"0```"H!`0`*````-`$!
M`!4````_`0$`!0```%4!`0`4````6P$!``0```!P`0$`$````'4!`0`&````
MA@$!``<```"-`0$`'@```)4!`0`H````M`$!``H```#=`0$`'````.@!`0`1
M````!0(!``L````7`@$`&@```","`0`4````/@(!``0```!3`@$`!````%@"
M`0`+````70(!``4```!I`@$`!@```&\"`0`(````=@(!``8```!_`@$`"@``
M`(8"`0`;````D0(!`#0```"M`@$`-````.("`0`@````%P,!`"D````X`P$`
M(````&(#`0!!````@P,!`!H```#%`P$`*````.`#`0`I````"00!`%`````S
M!`$`(@```(0$`0`&````IP0!``@```"N!`$`!0```+<$`0`(````O00!`!D`
M``#&!`$`&0```.`$`0`J````^@0!`",````E!0$`&0```$D%`0`N````8P4!
M`#0```"2!0$`"````,<%`0`7````T`4!``H```#H!0$`!P```/,%`0`A````
M^P4!`!`````=!@$`#@```"X&`0`+````/08!``<```!)!@$`$P```%$&`0`(
M````908!``L```!N!@$`"@```'H&`0`4````A08!``\```":!@$`,@```*H&
M`0`+````W08!``X```#I!@$`!0```/@&`0`%````_@8!``4````$!P$`%P``
M``H'`0`/````(@<!``0````R!P$`"@```#<'`0`)````0@<!``L```!,!P$`
M#0```%@'`0`,````9@<!``X```!S!P$`!0```(('`0`$````B`<!``T```"-
M!P$`,@```)L'`0!%````S@<!`!<````4"`$`!P```"P(`0`>````-`@!`!0`
M``!3"`$`!0```&@(`0`4````;@@!``8```"#"`$`!P```(H(`0`.````D@@!
M`"H```"A"`$`!@```,P(`0`,````TP@!``T```#@"`$`$0```.X(`0`+````
M``D!`#8````,"0$`"@```$,)`0`B````3@D!``L```!Q"0$`#P```'T)`0`R
M````C0D!`"4```#`"0$`,````.8)`0`Q````%PH!`"T```!)"@$`#@```'<*
M`0`%````A@H!``X```","@$`$P```)L*`0`2````KPH!``<```#""@$`$0``
M`,H*`0`3````W`H!``<```#P"@$`%````/@*`0`8````#0L!``<````F"P$`
M!0```"X+`0`,````-`L!``P```!!"P$`$@```$X+`0`$````80L!``<```!F
M"P$`"@```&X+`0`+````>0L!``P```"%"P$`#@```)(+`0`.````H0L!``4`
M``"P"P$`!0```+8+`0`N````O`L!`"8```#K"P$`(P```!(,`0`#````-@P!
M`!(````Z#`$`!@```$T,`0`>````5`P!`!@```!S#`$`)0```(P,`0`-````
ML@P!``D```#`#`$`'P```,H,`0`#````Z@P!``<```#N#`$`"@```/8,`0`"
M`````0T!``P````$#0$`%0```!$-`0`+````)PT!`!D````S#0$`(````$T-
M`0`2````;@T!``4```"!#0$`"@```(<-`0`5````D@T!`!(```"H#0$`#```
M`+L-`0`$````R`T!``D```#-#0$`!P```-<-`0`,````WPT!`%(```#L#0$`
M%P```#\.`0`D````5PX!`!(```!\#@$`!P```(\.`0`&````EPX!``X```">
M#@$`#````*T.`0`-````N@X!`!4```#(#@$`$@```-X.`0`/````\0X!`!0`
M```!#P$`"@```!8/`0`;````(0\!`!`````]#P$`"P```$X/`0!I````6@\!
M`!H```#$#P$`%P```-\/`0`G````]P\!`!H````?$`$`%P```#H0`0`;````
M4A`!`!D```!N$`$`'P```(@0`0`3````J!`!``@```"\$`$`!P```,40`0`(
M````S1`!``D```#6$`$`%0```.`0`0`-````]A`!`",````$$0$`#0```"@1
M`0`3````-A$!``@```!*$0$``P```%,1`0!&````5Q$!`#\```">$0$`-P``
M`-X1`0!7````%A(!``4```!N$@$`'P```'02`0`O````E!(!``H```#$$@$`
M"````,\2`0`-````V!(!`"T```#F$@$`!````!03`0!/````&1,!`"4```!I
M$P$`'````(\3`0`+````K!,!`!\```"X$P$`'0```-@3`0`E````]A,!`"``
M```<%`$`)````#T4`0`@````8A0!``L```"#%`$`!P```(\4`0`-````EQ0!
M``P```"E%`$`%P```+(4`0`&````RA0!`#D```#1%`$`#`````L5`0`'````
M&!4!``D````@%0$`$P```"H5`0`)````/A4!``0```!(%0$`$````$T5`0`(
M````7A4!``@```!G%0$`!````'`5`0`+````=14!``P```"!%0$`$@```(X5
M`0`1````H14!``P```"S%0$`&@```,`5`0`/````VQ4!``<```#K%0$`#0``
M`/,5`0`4`````18!``X````6%@$`#````"46`0`;````,A8!`"P```!.%@$`
M$P```'L6`0`<````CQ8!`"@```"L%@$`!@```-46`0`'````W!8!`!,```#D
M%@$`!0```/@6`0`$````_A8!`!<````#%P$`"@```!L7`0`,````)A<!``D`
M```S%P$`!@```#T7`0`)````1!<!``@```!.%P$`"0```%<7`0`*````81<!
M`!$```!L%P$`!@```'X7`0`.````A1<!``X```"4%P$`#0```*,7`0`+````
ML1<!`!T```"]%P$`"P```-L7`0`"````YQ<!`!P```#J%P$`!P````<8`0`&
M````#Q@!`&0````6&`$`"0```'L8`0`'````A1@!`"8```"-&`$`.````+08
M`0`:````[1@!`"H````(&0$`.P```#,9`0`H````;QD!`#0```"8&0$`&0``
M`,T9`0`5````YQD!``4```#]&0$`!P````,:`0`(````"QH!``<````4&@$`
M!0```!P:`0`'````(AH!``X````J&@$`"0```#D:`0`&````0QH!``@```!*
M&@$`"P```%,:`0`'````7QH!``@```!G&@$`!P```'`:`0`6````>!H!``D`
M``"/&@$`!@```)D:`0`+````H!H!`!````"L&@$`!@```+T:`0`<````Q!H!
M`!0```#A&@$`!P```/8:`0`1````_AH!``@````0&P$`#@```!D;`0`(````
M*!L!`!`````Q&P$`"0```$(;`0`0````3!L!``8```!=&P$`&0```&0;`0`*
M````?AL!`!P```")&P$`!P```*8;`0`%````KAL!`!````"T&P$`%````,4;
M`0`+````VAL!``T```#F&P$`*````/0;`0`8````'1P!`!<````V'`$`!```
M`$X<`0`)````4QP!``H```!='`$`!P```&@<`0`"````<!P!``X```!S'`$`
M"````((<`0`C````BQP!`!\```"O'`$`.````,\<`0`F````"!T!`#$````O
M'0$`)P```&$=`0!D````B1T!`!0```#N'0$`50````,>`0`X````61X!`$H`
M``"2'@$`6P```-T>`0`H````.1\!`#@```!B'P$`*````)L?`0`L````Q!\!
M`"8```#Q'P$`&P```!@@`0`^````-"`!`*D!``!S(`$`(P```!TB`0`7````
M02(!`$@```!9(@$`A0```*(B`0`P````*",!`"4```!9(P$`00```'\C`0!;
M````P2,!`$D````=)`$`,0```&<D`0`=````F20!`!@```"W)`$`*P```-`D
M`0`A````_"0!`!\````>)0$`*P```#XE`0`F````:B4!`"<```"1)0$`.@``
M`+DE`0`=````]"4!`!$````2)@$`,P```"0F`0`E````6"8!`"<```!^)@$`
M(````*8F`0`?````QR8!`#````#G)@$`:0```!@G`0`Q````@B<!`$$```"T
M)P$`,P```/8G`0`E````*B@!`#T```!0*`$`90```(XH`0!-````]"@!`"\`
M``!"*0$`+@```'(I`0`P````H2D!`%0```#2*0$`6@```"<J`0!(````@BH!
M`$H```#+*@$`,@```!8K`0`O````22L!`"P```!Y*P$`+0```*8K`0!Q````
MU"L!`&8```!&+`$`;P```*TL`0"S````'2T!`!<```#1+0$`)0```.DM`0`R
M````#RX!`"D```!"+@$`/@```&PN`0`B````JRX!`%(```#.+@$`)0```"$O
M`0`+````1R\!`+$```!3+P$`10````4P`0`A````2S`!`#````!M,`$`)0``
M`)XP`0`<````Q#`!`#$```#A,`$`!P```!,Q`0`'````&S$!``0````C,0$`
M#0```"@Q`0`+````-C$!``X```!",0$`"P```%$Q`0`%````73$!`!````!C
M,0$``@```'0Q`0!9````=S$!``4```#1,0$`$@```-<Q`0`$````ZC$!``<`
M``#O,0$`"````/<Q`0`%`````#(!`#`````&,@$``P```#<R`0`0````.S(!
M``P```!,,@$`$P```%DR`0`-````;3(!``(```![,@$`!P```'XR`0`&````
MAC(!`!0```"-,@$`#````*(R`0`8````KS(!``8```#(,@$`$@```,\R`0`,
M````XC(!``,```#O,@$`*@```/,R`0`$````'C,!``8````C,P$`!P```"HS
M`0`?````,C,!`#4```!2,P$`+@```(@S`0`O````MS,!`!<```#G,P$`(@``
M`/\S`0`E````(C0!`"````!(-`$`&P```&DT`0`8````A30!`"0```">-`$`
M'P```,,T`0`:````XS0!`"$```#^-`$`(````"`U`0`:````034!`#(```!<
M-0$`&@```(\U`0`O````JC4!`"L```#:-0$`'P````8V`0`C````)C8!`!\`
M``!*-@$`&@```&HV`0`A````A38!`"4```"G-@$`)@```,TV`0`E````]#8!
M`"0````:-P$`&````#\W`0`=````6#<!`"0```!V-P$`&````)LW`0`B````
MM#<!`"P```#7-P$`+P````0X`0`5````-#@!`"4```!*.`$`/````'`X`0`?
M````K3@!`",```#-.`$`'P```/$X`0`@````$3D!`!H````R.0$`&````$TY
M`0`F````9CD!`!X```"-.0$`*0```*PY`0`>````UCD!`#$```#U.0$`"0``
M`"<Z`0`,````,3H!`!<````^.@$`+P```%8Z`0`D````ACH!``<```"K.@$`
M#P```+,Z`0`4````PSH!``X```#8.@$`#0```.<Z`0`D````]3H!``4````:
M.P$`!P```"`[`0`B````*#L!`"4```!+.P$`&@```'$[`0`=````C#L!`!H`
M``"J.P$`!P```,4[`0#'````S3L!``L```"5/`$`%0```*$\`0`&````MSP!
M``D```"^/`$`"P```,@\`0`-````U#P!`!<```#B/`$`!@```/H\`0`S````
M`3T!`!,````U/0$`$P```$D]`0`'````73T!``\```!E/0$`!P```'4]`0`R
M````?3T!``0```"P/0$`(0```+4]`0`3````UST!``P```#K/0$`$0```/@]
M`0`R````"CX!`!8````]/@$`"````%0^`0`=````73X!``D```![/@$`"@``
M`(4^`0`4````D#X!``H```"E/@$`'0```+`^`0`(````SCX!`!\```#7/@$`
M"````/<^`0`:`````#\!`"<````;/P$`!@```$,_`0`5````2C\!``<```!@
M/P$`"````&@_`0`)````<3\!`#\```![/P$`!P```+L_`0`/````PS\!``X`
M``#3/P$`$````.(_`0`)````\S\!``D```#]/P$`"`````=``0`3````$$`!
M``<````D0`$`&0```"Q``0`*````1D`!`!<```!10`$`%````&E``0`*````
M?D`!``P```")0`$`%P```)9``0`$````KD`!`"H```"S0`$`#````-Y``0`1
M````ZT`!``<```#]0`$``@````5!`0`0````"$$!`!@````900$`"P```#)!
M`0`#````/D$!``@```!"00$`!@```$M!`0`'````4D$!``T```!:00$`"P``
M`&A!`0`4````=$$!`!4```")00$`#@```)]!`0`O````KD$!`"````#>00$`
M'````/]!`0`5````'$(!``P````R0@$`,0```#]"`0`%````<4(!`!(```!W
M0@$`/P```(I"`0`2````RD(!``H```#=0@$`!@```.A"`0`$````[T(!``0`
M``#T0@$`"@```/E"`0`3````!$,!``4````80P$`!@```!Y#`0`&````)4,!
M``@````L0P$`!````#5#`0`,````.D,!``H```!'0P$`.0```%)#`0`N````
MC$,!`"D```"[0P$`!0```.5#`0`8````ZT,!`!D````$1`$`'P```!Y$`0`=
M````/D0!`!$```!<1`$``@```&Y$`0`$````<40!``H```!V1`$`!@```(%$
M`0`%````B$0!``,```".1`$`#````))$`0!%````GT0!`#(```#E1`$`&@``
M`!A%`0`T````,T4!`"@```!H10$`4P```)%%`0`9````Y44!`'(```#_10$`
M(````')&`0`U````DT8!`"$```#)1@$`10```.M&`0`P````,4<!`"@```!B
M1P$`*0```(M'`0`F````M4<!`"4```#<1P$`*`````)(`0`H````*T@!`"(`
M``!42`$`*P```'=(`0`P````HT@!`!(```#42`$`$P```.=(`0`0````^T@!
M`'D````,20$`"0```(9)`0"A````D$D!`',````R2@$`?````*9*`0`K````
M(TL!`%0```!/2P$`%P```*1+`0`G````O$L!`!8```#D2P$`#P```/M+`0`7
M````"TP!`!\````C3`$`0````$-,`0`?````A$P!`!P```"D3`$`40```,%,
M`0`:````$TT!`!0````N30$`"@```$--`0`%````3DT!``8```!430$`"```
M`%M-`0`%````9$T!`!(```!J30$`$````'U-`0`3````CDT!`!T```"B30$`
M#P```,!-`0`/````T$T!``0```#@30$`"0```.5-`0`+````[TT!``<```#[
M30$`!0````-.`0`4````"4X!``<````>3@$`"````"9.`0`/````+TX!``@`
M```_3@$`#````$A.`0`/````54X!``8```!E3@$`%````&Q.`0`&````@4X!
M``P```"(3@$`$0```)5.`0`(````ITX!``0```"P3@$`&0```+5.`0`1````
MSTX!``H```#A3@$`&````.Q.`0`3````!4\!`!P````93P$`$0```#9/`0`$
M````2$\!``\```!-3P$`!P```%U/`0`$````94\!`!D```!J3P$`!P```(1/
M`0`"````C$\!``(```"/3P$`$0```))/`0`)````I$\!``8```"N3P$`$@``
M`+5/`0`7````R$\!``8```#@3P$`)P```.=/`0`"````#U`!``0````24`$`
M#P```!=0`0`3````)U`!``<````[4`$`!P```$-0`0`1````2U`!``8```!=
M4`$`&````&10`0`&````?5`!`!,```"$4`$`$````)A0`0`2````J5`!``(`
M``"\4`$`!@```+]0`0`,````QE`!``D```#34`$`$0```-U0`0`B````[U`!
M``<````240$`!P```!I1`0`+````(E$!``4````N40$``@```#11`0`+````
M-U$!`'\!``!#40$`$@```,-2`0`;````UE(!`!````#R4@$`#@````-3`0`)
M````$E,!``<````<4P$``P```"13`0`;````*%,!`"$```!$4P$`-0```&93
M`0`Q````G%,!`"L```#.4P$`+P```/I3`0`=````*E0!`"T```!(5`$`"P``
M`'94`0`R````@E0!`!0```"U5`$`"P```,I4`0`3````UE0!``4```#J5`$`
M,0```/!4`0`0````(E4!`!$````S50$`'@```$55`0`/````9%4!``L```!T
M50$`E@```(!5`0`2````%U8!``H````J5@$`#0```#56`0`-````0U8!`!<`
M``!15@$`#````&E6`0`0````=E8!`!4```"'5@$`!P```)U6`0"=````I58!
M``P```!#5P$`#````%!7`0`4````75<!`!(```!R5P$`$````(57`0`0````
MEE<!``D```"G5P$`"@```+%7`0!$````O%<!`"`````!6`$`/@```")8`0!-
M````85@!`&X```"O6`$`:@```!Y9`0!T````B5D!`'````#^60$`00```&]:
M`0`/````L5H!`!4```#!6@$`#@```-=:`0`0````YEH!`!@```#W6@$`!0``
M`!!;`0`&````%EL!`!<````=6P$`"P```#5;`0`*````05L!``T```!,6P$`
M-````%I;`0`P````CUL!`!0```#`6P$`%@```-5;`0`.````[%L!``<```#[
M6P$`!P````-<`0`6````"UP!`"0````B7`$`#0```$=<`0`9````55P!`!\`
M``!O7`$`'P```(]<`0`E````KUP!`!\```#57`$`$P```/5<`0`;````"5T!
M`!$````E70$`*````#==`0`>````8%T!`!\```!_70$`%@```)]=`0!A````
MMET!`#`````87@$`,@```$E>`0`'````?%X!`!$```"$7@$`0P```)9>`0`.
M````VEX!``0```#I7@$`"P```.Y>`0`'````^EX!``<````"7P$`!0````I?
M`0`'````$%\!``P````87P$`!````"5?`0`B````*E\!`!````!-7P$`%@``
M`%Y?`0`0````=5\!`"P```"&7P$`,0```+-?`0`+````Y5\!`"$```#Q7P$`
M'````!-@`0`A````,&`!`!\```!28`$`#@```')@`0`2````@6`!``\```"4
M8`$`)````*1@`0`C````R6`!``<```#M8`$`!@```/5@`0`(````_&`!``T`
M```%80$`!P```!-A`0`+````&V$!`!(````G80$`"P```#IA`0`4````1F$!
M`!<```!;80$`&P```'-A`0`(````CV$!`!0```"880$`!0```*UA`0`4````
MLV$!`!D```#(80$`$````.)A`0!-````\V$!`$$```!!8@$`"0```(-B`0`'
M````C6(!`!0```"58@$``P```*IB`0`%````KF(!``\```"T8@$`"0```,1B
M`0`5````SF(!`$D```#D8@$`$P```"YC`0`N````0F,!`#4```!Q8P$`-P``
M`*=C`0`R````WV,!``H````29`$`!````!UD`0`)````(F0!``@````L9`$`
M,````#5D`0`W````9F0!`"\```">9`$`7@```,YD`0`O````+64!`"\```!=
M90$`2P```(UE`0!.````V64!`"\````H9@$`5````%AF`0`T````K68!`#<`
M``#B9@$`5P```!IG`0`O````<F<!`#4```"B9P$`+````-AG`0`;````!6@!
M`!X````A:`$`+@```$!H`0`K````;V@!`"L```";:`$`%````,=H`0`+````
MW&@!``P```#H:`$`#P```/5H`0`/````!6D!`!T````5:0$`(0```#-I`0`'
M````56D!``<```!=:0$`$P```&5I`0`*````>6D!``<```"$:0$`+````(QI
M`0`-````N6D!``<```#':0$`"````,]I`0`&````V&D!``4```#?:0$`"```
M`.5I`0`'````[FD!``P```#V:0$`*@````-J`0`3````+FH!``P```!":@$`
M!````$]J`0`'````5&H!``<```!<:@$`!P```&1J`0`9````;&H!``4```"&
M:@$`$@```(QJ`0`(````GVH!``@```"H:@$``P```+%J`0`&````M6H!``8`
M``"\:@$`*@```,-J`0`2````[FH!``@````!:P$`#0````IK`0`,````&&L!
M``<````E:P$`$@```"UK`0`#````0&L!`$$```!$:P$`&0```(9K`0`P````
MH&L!``8```#1:P$`!0```-AK`0`(````WFL!``@```#G:P$`9````/!K`0`J
M````56P!`#\```"`;`$`*@```,!L`0`F````ZVP!``8````2;0$`!P```!EM
M`0`>````(6T!`"H```!`;0$`+@```&MM`0`W````FFT!`"T```#2;0$`-P``
M``!N`0!O````.&X!`#,```"H;@$`"````-QN`0`'````Y6X!``P```#M;@$`
M&````/IN`0`+````$V\!`!0````?;P$`&````#1O`0`B````36\!`!@```!P
M;P$`&@```(EO`0`5````I&\!`!,```"Z;P$`!P```,YO`0`9````UF\!`!T`
M``#P;P$`%0````YP`0`:````)'`!`!H````_<`$`!0```%IP`0`(````8'`!
M`!L```!I<`$`<@```(5P`0!Y````^'`!``0```!R<0$`$0```'=Q`0`%````
MB7$!``4```"/<0$`&@```)5Q`0`;````L'$!`!<```#,<0$`%P```.1Q`0`;
M````_'$!`"<````8<@$`-@```$!R`0`.````=W(!`"H```"&<@$`!P```+%R
M`0`>````N7(!`!(```#8<@$`&0```.MR`0`5````!7,!`"0````;<P$`'P``
M`$!S`0`7````8',!`!,```!X<P$`$0```(QS`0`&````GG,!``\```"E<P$`
M!P```+5S`0`*````O7,!`!@```#(<P$`$0```.%S`0`(````\W,!``<```#\
M<P$`$P````1T`0`7````&'0!``8````P=`$`$0```#=T`0`$````270!``@`
M``!.=`$`#@```%=T`0`+````9G0!``D```!R=`$`!P```'QT`0`'````A'0!
M``L```",=`$`"0```)AT`0`*````HG0!`!P```"M=`$`20```,IT`0`B````
M%'4!``T````W=0$`&0```$5U`0`%````7W4!`"````!E=0$`%0```(9U`0`8
M````G'4!`"T```"U=0$`/P```.-U`0`D````(W8!``@```!(=@$`/````%%V
M`0`G````CG8!`!$```"V=@$`"@```,AV`0`)````TW8!``\```#==@$`!@``
M`.UV`0`6````]'8!`!4````+=P$`"````"%W`0`*````*G<!``T````U=P$`
M)````$-W`0`F````:'<!`"X```"/=P$`)P```+YW`0`@````YG<!`"4````'
M>`$`*@```"UX`0`F````6'@!`#0```!_>`$`,````+1X`0`K````Y7@!`"P`
M```1>0$`(P```#YY`0`Q````8GD!`#8```"4>0$`-@```,MY`0`K`````GH!
M`#$````N>@$`00```&!Z`0`J````HGH!`"D```#->@$`0P```/=Z`0`K````
M.WL!`!L```!G>P$`,0```(-[`0`G````M7L!`"<```#=>P$`&@````5\`0"S
M````('P!`!\```#4?`$`*@```/1\`0`N````'WT!`#````!.?0$`+0```']]
M`0`R````K7T!`"D```#@?0$`*P````I^`0`[````-GX!`#L```!R?@$`0```
M`*Y^`0!"````[WX!`+(````R?P$`)P```.5_`0`A````#8`!`"4````O@`$`
M,@```%6``0`Y````B(`!`$8```#"@`$`3P````F!`0`,````68$!``0```!F
M@0$`!0```&N!`0`%````<8$!``T```!W@0$`$````(6!`0`5````EH$!`!<`
M``"L@0$`&0```,2!`0`'````WH$!``0```#F@0$`$@```.N!`0`1````_H$!
M``X````0@@$`&@```!^"`0`4````.H(!`!8```!/@@$`%0```&:"`0`-````
M?((!`#D```"*@@$`!@```,2"`0`3````RX(!``8```#?@@$`$P```.:"`0`9
M````^H(!`!T````4@P$`$@```#*#`0`"````18,!`$D```!(@P$`"P```)*#
M`0`6````GH,!`!````"U@P$`!````,:#`0`1````RX,!`!0```#=@P$`!```
M`/*#`0`5````]X,!``@````-A`$`$````!:$`0`6````)X0!``8````^A`$`
M$@```$6$`0`3````6(0!`",```!LA`$`"P```)"$`0`'````G(0!`!(```"D
MA`$`$P```+>$`0`0````RX0!`!@```#<A`$`(````/6$`0`2````%H4!`!(`
M```IA0$`(@```#R%`0`6````7X4!`"4```!VA0$`10```)R%`0`1````XH4!
M`"$```#TA0$`&0```!:&`0`;````,(8!`!H```!,A@$`-P```&>&`0`2````
MGX8!``@```"RA@$`$P```+N&`0`+````SX8!`#0```#;A@$`-````!"'`0`-
M````18<!``X```!3AP$`*````&*'`0`1````BX<!`!(```"=AP$`$@```+"'
M`0`*````PX<!`!@```#.AP$`$P```.>'`0`?````^X<!`!L````;B`$`$@``
M`#>(`0`1````2H@!``@```!<B`$`$````&6(`0`L````=H@!`&(```"CB`$`
M"0````:)`0`6````$(D!`"T````GB0$`"P```%6)`0`.````88D!`#@```!P
MB0$`$````*F)`0`'````NHD!`!4```#"B0$`20```-B)`0`#````(HH!``@`
M```FB@$`"````"^*`0`.````.(H!`!````!'B@$`%0```%B*`0`6````;HH!
M`"(```"%B@$`&0```*B*`0`B````PHH!`!X```#EB@$`"0````2+`0`&````
M#HL!``@````5BP$`"@```!Z+`0`"````*8L!`!0````LBP$`%````$&+`0`P
M````5HL!`!H```"'BP$`&0```**+`0`*````O(L!``T```#'BP$`#@```-6+
M`0`8````Y(L!`$4```#]BP$`+P```$.,`0`.````<XP!`!(```""C`$`H```
M`)6,`0`F````-HT!`!\```!=C0$`$@```'V-`0`(````D(T!``8```"9C0$`
M)P```*"-`0!`````R(T!`$`````)C@$`+@```$J.`0`R````>8X!`!<```"L
MC@$`*@```,2.`0`'````[XX!``@```#WC@$`"`````"/`0`&````"8\!`!D`
M```0CP$`%````"J/`0`6````/X\!`!0```!6CP$`$@```&N/`0`:````?H\!
M`!(```"9CP$`%````*R/`0`(````P8\!``H```#*CP$`&````-6/`0`.````
M[H\!`#,```#]CP$`$0```#&0`0`,````0Y`!`!0```!0D`$`.@```&60`0`C
M````H)`!`"8```#$D`$`)0```.N0`0`@````$9$!`!\````RD0$`+P```%*1
M`0`A````@I$!`"(```"DD0$`!````,>1`0`9````S)$!``H```#FD0$`#P``
M`/&1`0`#`````9(!``H````%D@$`!P```!"2`0`5````&)(!`!@````ND@$`
M$````$>2`0`8````6)(!`!(```!QD@$`#@```(22`0`:````DY(!``4```"N
MD@$`!P```+22`0`7````O)(!`!<```#4D@$`&````.R2`0`.````!9,!`!``
M```4DP$`&0```"63`0`M````/Y,!``<```!MDP$`"````'63`0`.````?I,!
M`!````"-DP$`#@```)Z3`0`)````K9,!``@```"WDP$`"@```,"3`0`6````
MRY,!`!$```#BDP$`"@```/23`0`Q````_Y,!``\````QE`$`A````$&4`0`E
M````QI0!``L```#LE`$`"````/B4`0`0`````94!``D````2E0$`"P```!R5
M`0`&````*)4!``L````OE0$``@```#N5`0`&````/I4!``8```!%E0$`%0``
M`$R5`0`0````8I4!`!,```!SE0$`*P```(>5`0`"````LY4!``,```"VE0$`
M%````+J5`0`+````SY4!``L```#;E0$`!0```.>5`0`:````[94!``<````(
ME@$`!@```!"6`0`>````%Y8!``L````VE@$`!P```$*6`0`)````2I8!``4`
M``!4E@$`"0```%J6`0`&````9)8!`!````!KE@$`!0```'R6`0`&````@I8!
M``T```")E@$`$````)>6`0`.````J)8!``4```"WE@$`$0```+V6`0`)````
MSY8!``<```#9E@$`&@```.&6`0`L````_)8!`%`````IEP$`,````'J7`0`Q
M````JY<!``<```#=EP$`"@```.67`0`$````\)<!``D```#UEP$`"0```/^7
M`0`7````"9@!``H````AF`$`!@```"R8`0`-````,Y@!``8```!!F`$`!```
M`$B8`0!&````39@!`$0```"4F`$`0P```-F8`0`B````'9D!``4```!`F0$`
M%0```$:9`0`+````7)D!``<```!HF0$`"````'"9`0`6````>9D!``\```"0
MF0$`%0```*"9`0`'````MID!``0```"^F0$`$P```,.9`0`$````UYD!``H`
M``#<F0$`&P```.>9`0`%`````YH!``@````)F@$`#P```!*:`0`'````(IH!
M`!,````JF@$`%````#Z:`0`3````4YH!``@```!GF@$`"0```'":`0`%````
M>IH!`$0```"`F@$`-0```,6:`0`^````^YH!`"P````ZFP$`2P```&>;`0!%
M````LYL!`#$```#YFP$`4@```"N<`0`W````?IP!`#H```"VG`$`)````/&<
M`0`1````%IT!`!8````HG0$`#````#^=`0`S````3)T!`"L```"`G0$`)P``
M`*R=`0`J````U)T!``@```#_G0$`"P````B>`0`*````%)X!``<````?G@$`
M+P```">>`0`R````5YX!`#D```"*G@$`"@```,2>`0`:````SYX!`"0```#J
MG@$`&`````^?`0`5````*)\!``<````^GP$`$````$:?`0`.````5Y\!`!$`
M``!FGP$`#P```'B?`0!-````B)\!`(L```#6GP$`=P```&*@`0`3````VJ`!
M`!8```#NH`$`&`````6A`0`0````'J$!`!(````OH0$`%P```$*A`0`&````
M6J$!`!4```!AH0$`$@```'>A`0`1````BJ$!`!4```"<H0$`&````+*A`0`U
M````RZ$!`'@````!H@$`%P```'JB`0`$````DJ(!`!@```"7H@$`"0```+"B
M`0`$````NJ(!``P```"_H@$`)````,RB`0`6````\:(!``T````(HP$`$@``
M`!:C`0`3````*:,!`!8````]HP$`-@```%2C`0`V````BZ,!`#0```#"HP$`
M-````/>C`0`P````+*0!`#````!=I`$`%P```(ZD`0!4````IJ0!`!4```#[
MI`$`%0```!&E`0`5````)Z4!`!4````]I0$`%````%.E`0`8````:*4!`!@`
M``"!I0$`%````)JE`0`4````KZ4!`#````#$I0$`&@```/6E`0`<````$*8!
M`#L````MI@$`$P```&FF`0`&````?:8!``X```"$I@$`'P```).F`0`4````
MLZ8!`!4```#(I@$`$P```-ZF`0`;````\J8!`"`````.IP$`&P```"^G`0`9
M````2Z<!`!T```!EIP$`%````(.G`0`>````F*<!`"(```"WIP$`%````-JG
M`0`;````[Z<!`!D````+J`$`$P```"6H`0`>````.:@!`!D```!8J`$`&```
M`'*H`0`8````BZ@!``H```"DJ`$`%0```*^H`0`$````Q:@!``0```#*J`$`
M!P```,^H`0`*````UZ@!`!````#BJ`$`!@```/.H`0`(````^J@!``@````#
MJ0$`!@````RI`0`(````$ZD!``<````<J0$`!0```"2I`0`6````*JD!``8`
M``!!J0$`"````$BI`0`'````4:D!``0```!9J0$`"0```%ZI`0`'````:*D!
M``D```!PJ0$`$````'JI`0`0````BZD!``H```"<J0$`$P```*>I`0`%````
MNZD!`#````#!J0$`$@```/*I`0`0````!:H!`!0````6J@$`$P```"NJ`0`,
M````/ZH!`!8```!,J@$`-@```&.J`0`'````FJH!``@```"BJ@$`#0```*NJ
M`0`,````N:H!``\```#&J@$`!@```-:J`0`,````W:H!``T```#JJ@$`!@``
M`/BJ`0`$````_ZH!``X````$JP$`)0```!.K`0`0````.:L!`!8```!*JP$`
M%P```&&K`0`F````>:L!`!L```"@JP$`"````+RK`0`#````Q:L!``P```#)
MJP$`*0```-:K`0`%`````*P!``8````&K`$`#0````VL`0`1````&ZP!``<`
M```MK`$`!@```#6L`0`'````/*P!``4```!$K`$`#0```$JL`0`-````6*P!
M``P```!FK`$`(````'.L`0`1````E*P!``\```"FK`$`&@```+:L`0`3````
MT:P!`!8```#EK`$`!0```/RL`0`$`````JT!`!4````'K0$`3````!VM`0`%
M````:JT!``T```!PK0$`*````'ZM`0`:````IZT!``\```#"K0$`$P```-*M
M`0`4````YJT!`!````#[K0$`#P````RN`0`8````'*X!`!`````UK@$`%0``
M`$:N`0`9````7*X!`",```!VK@$`)P```)JN`0`W````PJX!``L```#ZK@$`
M"`````:O`0`-````#Z\!``\````=KP$`#P```"VO`0`$````/:\!``D```!"
MKP$`+P```$RO`0`+````?*\!``D```"(KP$`$P```)*O`0!K````IJ\!`!,`
M```2L`$`"@```":P`0`%````,;`!``8````WL`$`&@```#ZP`0`9````6;`!
M`!D```!SL`$`"@```(VP`0`"````F+`!`!8```";L`$`,P```+*P`0`#````
MYK`!``4```#JL`$`%P```/"P`0`*````"+$!``4````3L0$`"````!FQ`0`:
M````(K$!``X````]L0$`!@```$RQ`0`(````4[$!``@```!<L0$`!````&6Q
M`0`%````:K$!`$H```!PL0$`#P```+NQ`0`2````R[$!`!T```#>L0$`!```
M`/RQ`0`%`````;(!`"4````'L@$`.0```"VR`0`-````9[(!``H```!UL@$`
M$0```("R`0`*````DK(!``L```"=L@$`%@```*FR`0`;````P+(!`"\```#<
ML@$`+@````RS`0`B````.[,!`!````!>LP$``P```&^S`0`'````<[,!``H`
M``![LP$`!P```(:S`0`.````CK,!`!8```"=LP$`!P```+2S`0!:````O+,!
M``\````7M`$`#P```">T`0`+````-[0!`"<```!#M`$`70```&NT`0`;````
MR;0!``<```#EM`$`(P```.VT`0`I````$;4!``@````[M0$`!P```$2U`0`;
M````3+4!``8```!HM0$`"0```&^U`0`N````>;4!`"T```"HM0$`-P```-:U
M`0`&````#K8!``8````5M@$`+````!RV`0!F````2;8!`!<```"PM@$`)```
M`,BV`0`7````[;8!``(````%MP$`$0````BW`0`&````&K<!`!0````AMP$`
M#@```#:W`0`&````1;<!``@```!,MP$`!@```%6W`0`(````7+<!``T```!E
MMP$`#0```'.W`0`*````@;<!`!$```",MP$`.P```)ZW`0`%````VK<!`!<`
M``#@MP$`%````/BW`0`A````#;@!`!<````ON`$`"P```$>X`0`1````4[@!
M`!$```!EN`$`#````'>X`0`+````A+@!``P```"0N`$`"@```)VX`0`@````
MJ+@!`!4```#)N`$`$@```-^X`0`5````\K@!`!@````(N0$`"P```"&Y`0`;
M````+;D!``@```!)N0$`%0```%*Y`0`#````:+D!``<```!LN0$`!0```'2Y
M`0`%````>KD!``@```"`N0$`%@```(FY`0`7````H+D!`"0```"XN0$`(P``
M`-VY`0`>`````;H!`!H````@N@$`&P```#NZ`0`B````5[H!`!L```!ZN@$`
M!@```):Z`0`&````G;H!`!(```"DN@$`$@```+>Z`0`-````RKH!`"4```#8
MN@$`$````/ZZ`0`4````#[L!`"<````DNP$`)0```$R[`0`9````<KL!``D`
M``",NP$`!@```):[`0`'````G;L!`!(```"ENP$`$0```+B[`0`(````RKL!
M``D```#3NP$`!0```-V[`0`'````X[L!``0```#KNP$`!````/"[`0`#````
M];L!`$@```#YNP$`-@```$*\`0`E````>;P!`"H```"?O`$`00```,J\`0`,
M````#+T!`$`````9O0$`-@```%J]`0`Y````D;T!`#D```#+O0$`/@````6^
M`0`8````1+X!`!L```!=O@$`%````'F^`0`3````CKX!`!P```"BO@$`(```
M`+^^`0`4````X+X!`!,```#UO@$`%@````F_`0`:````(+\!`#L````[OP$`
M.P```'>_`0`_````L[\!`#0```#SOP$`.P```"C``0`X````9,`!`'L```"=
MP`$`'@```!G!`0`8````.,$!``T```!1P0$`&@```%_!`0`,````>L$!`!(`
M``"'P0$`.````)K!`0`S````T\$!`"H````'P@$`#0```#+"`0!3````0,(!
M`$P```"4P@$`!0```.'"`0`>````Y\(!`!8````&PP$`"P```!W#`0`/````
M*<,!`!8````YPP$`!P```%##`0`)````6,,!``D```!BPP$`#@```&S#`0`/
M````>\,!``<```"+PP$`$P```)/#`0`%````I\,!`"8```"MPP$`"````-3#
M`0`&````W<,!`!0```#DPP$`$@```/G#`0`1````#,0!`$0````>Q`$``@``
M`&/$`0`%````9L0!`!````!LQ`$`!0```'W$`0`'````@\0!`!4```"+Q`$`
M!@```*'$`0`]````J,0!`!,```#FQ`$`(P```/K$`0`$````'L4!`#@````C
MQ0$`)@```%S%`0`F````@\4!`%T```"JQ0$`(`````C&`0!-````*<8!`"H`
M``!WQ@$`%@```*+&`0`'````N<8!``\```#!Q@$`#P```-'&`0`,````X<8!
M`!<```#NQ@$`#`````;'`0`=````$\<!`!L````QQP$`!0```$W'`0`3````
M4\<!`!L```!GQP$`+````(/'`0`1````L,<!`!<```#"QP$`%0```-K'`0`1
M````\,<!`!T````"R`$`"````"#(`0`0````*<@!`!D````ZR`$`$@```%3(
M`0`4````9\@!`!(```!\R`$`'````(_(`0`3````K,@!`!,```#`R`$`%P``
M`-3(`0`1````[,@!``L```#^R`$`"`````K)`0`%````$\D!`!T````9R0$`
M!@```#?)`0`9````/LD!``@```!8R0$`%0```&')`0`,````=\D!`"0```"$
MR0$`%@```*G)`0`S````P,D!`!X```#TR0$`#@```!/*`0`/````(LH!`"H`
M```RR@$`!@```%W*`0`?````9,H!``8```"$R@$`&@```(O*`0`)````ILH!
M``L```"PR@$`)P```+S*`0`X````Y,H!``H````=RP$`*0```"C+`0`2````
M4LL!``L```!ERP$`'@```''+`0`4````D,L!``4```"ERP$`!P```*O+`0`+
M````L\L!``D```"_RP$`!@```,G+`0`(````T,L!``8```#9RP$`"@```.#+
M`0`<````Z\L!`"T````(S`$`,0```#;,`0`E````:,P!`#,```".S`$`)@``
M`,+,`0!'````Z<P!`"$````QS0$`)P```%/-`0`^````>\T!`%P```"ZS0$`
M,````!?.`0`'````2,X!``D```!0S@$`"````%K.`0`(````8\X!`!<```!L
MS@$`%@```(3.`0`L````F\X!`"X```#(S@$`&0```/?.`0`P````$<\!`#H`
M``!"SP$`"````'W/`0`?````AL\!``L```"FSP$`!@```++/`0`K````N<\!
M`!,```#ESP$`%````/G/`0`+````#M`!``@````:T`$`%P```"/0`0`'````
M.]`!``L```!#T`$`#0```$_0`0`;````7=`!`"$```!YT`$`/````)O0`0`*
M````V-`!`!,```#CT`$`!0```/?0`0`'````_=`!``4````%T0$`&P````O1
M`0`/````)]$!``4````WT0$`$@```#W1`0`:````4-$!``<```!KT0$`#@``
M`'/1`0`0````@M$!`!,```"3T0$`!````*?1`0`$````K-$!``P```"QT0$`
M'@```+[1`0!:````W=$!`!\````XT@$`"@```%C2`0`K````8](!`"````"/
MT@$`%@```+#2`0`6````Q](!``D```#>T@$`"0```.C2`0`1````\M(!`"X`
M```$TP$`!P```#/3`0`/````.],!`!(```!+TP$`%````%[3`0`0````<],!
M`$$```"$TP$`"@```,;3`0`<````T=,!`!4```#NTP$`&@````34`0`Y````
M']0!`",```!9U`$`3````'W4`0!0````RM0!`$D````;U0$`$0```&75`0`#
M````=]4!`!T```![U0$`(@```)G5`0`=````O-4!``D```#:U0$`$P```.35
M`0`A````^-4!``<````:U@$`)0```"+6`0`>````2-8!``H```!GU@$`!@``
M`'+6`0`0````>=8!`!$```"*U@$`'````)S6`0`$````N=8!``@```"^U@$`
M"P```,?6`0`0````T]8!`!````#DU@$`%P```/76`0`7````#=<!``D````E
MUP$`!@```"_7`0!`````-M<!`#0```!WUP$`,P```*S7`0`&````X-<!``8`
M``#GUP$`!@```.[7`0`=````]=<!`!8````3V`$`+````"K8`0`.````5]@!
M`!````!FV`$`)````'?8`0`#````G-@!``8```"@V`$`$0```*?8`0`"````
MN=@!``T```"\V`$`&@```,K8`0`,````Y=@!`!@```#RV`$`'P````O9`0`2
M````*]D!`!(````^V0$`"P```%'9`0`4````7=D!`!4```!RV0$`#P```(C9
M`0`+````F-D!`!(```"DV0$`#@```+?9`0`7````QMD!`&@```#>V0$`(@``
M`$?:`0`_````:MH!``T```"JV@$`!P```+C:`0`)````P-H!`!0```#*V@$`
M%P```-_:`0`5````]]H!`"`````-VP$`)````"[;`0`7````4]L!`"4```!K
MVP$`$0```)';`0`O````H]L!`!,```#3VP$`%0```.?;`0"0````_=L!`"0`
M``".W`$`(````+/<`0`Q````U-P!`"0````&W0$`(P```"O=`0`D````3]T!
M`"4```!TW0$`)````)K=`0`=````O]T!``L```#=W0$`!P```.G=`0`(````
M\=T!``D```#ZW0$`%`````3>`0`/````&=X!`#<````IW@$`&P```&'>`0`6
M````?=X!``@```"4W@$`#````)W>`0!J````JMX!`$(````5WP$`2@```%C?
M`0"`````H]\!``T````DX`$`,0```#+@`0`Q````9.`!``H```"6X`$`!0``
M`*'@`0`&````I^`!`$4```"NX`$`"````/3@`0!F````_>`!`#4```!DX0$`
M*````)KA`0`4````P^$!`"<```#8X0$`'@````#B`0`M````'^(!`#<```!-
MX@$`1````(7B`0`W````RN(!`!L````"XP$`!P```![C`0`;````)N,!`!<`
M``!"XP$`%0```%KC`0`)````<.,!`#0```!ZXP$`#````*_C`0`*````O.,!
M``D```#'XP$`%P```-'C`0`)````Z>,!``8```#SXP$`%@```/KC`0`)````
M$>0!``@````;Y`$`!0```"3D`0`/````*N0!`!`````ZY`$`)````$OD`0`@
M````<.0!`!,```"1Y`$`-````*7D`0`,````VN0!``<```#GY`$`$@```._D
M`0`;`````N4!``X````>Y0$`#@```"WE`0`9````/.4!`"8```!6Y0$`#@``
M`'WE`0`@````C.4!`#8```"MY0$`"````.3E`0`*````[>4!`!D```#XY0$`
M!P```!+F`0`(````&N8!`!,````CY@$`$@```#?F`0`2````2N8!`!$```!=
MY@$`!@```&_F`0`)````=N8!``@```"`Y@$`"0```(GF`0`.````D^8!`!``
M``"BY@$`!@```+/F`0`4````NN8!``,```#/Y@$`!0```-/F`0`0````V>8!
M`!\```#JY@$`"P````KG`0`"````%N<!`"$````9YP$`!0```#OG`0`%````
M0><!`'(```!'YP$`!@```+KG`0`&````P><!`!P```#(YP$`1@```.7G`0`>
M````+.@!`!P```!+Z`$`6P```&CH`0`[````Q.@!`$\`````Z0$`(````%#I
M`0`5````<>D!``8```"'Z0$`"````([I`0`/````E^D!`!$```"GZ0$`"@``
M`+GI`0`/````Q.D!`!<```#4Z0$`$0```.SI`0`1````_ND!`!0````0Z@$`
M"````"7J`0`*````+NH!`!T````YZ@$`#@```%?J`0`:````9NH!``D```"!
MZ@$`!0```(OJ`0`&````D>H!`",```"8Z@$`!@```+SJ`0`N````P^H!``4`
M``#RZ@$`!@```/CJ`0`-````_^H!``8````-ZP$`#P```!3K`0`+````).L!
M`!4````PZP$`$@```$;K`0`5````6>L!``8```!OZP$`&0```';K`0`*````
MD.L!``@```";ZP$`!P```*3K`0`&````K.L!`!,```"SZP$`)0```,?K`0`+
M````[>L!``X```#YZP$`*`````CL`0`8````,>P!`!H```!*[`$`!0```&7L
M`0`*````:^P!`!,```!V[`$`#0```(KL`0`"````F.P!``X```";[`$`"0``
M`*KL`0`E````M.P!`!\```#:[`$`.@```/KL`0`K````->T!`#@```!A[0$`
M+````)KM`0!G````Q^T!`!L````O[@$`8````$ON`0`X````K.X!`$H```#E
M[@$`60```##O`0`O````BN\!`#$```"Z[P$`*P```.SO`0`Q````&/`!`"\`
M``!*\`$`)@```'KP`0`]````H?`!`"("``#?\`$`(P````+S`0`8````)O,!
M`$H````_\P$`@0```(KS`0`S````#/0!`"\```!`]`$`0````'#T`0!:````
ML?0!`%`````,]0$`.0```%WU`0`C````E_4!`!<```"[]0$`+````-/U`0`A
M`````/8!`",````B]@$`,P```$;V`0`D````>O8!`"H```"?]@$`-@```,KV
M`0`;`````?<!`!$````=]P$`5````"_W`0`K````A/<!`"T```"P]P$`)P``
M`-[W`0`B````!O@!`"T````I^`$`60```%?X`0`U````L?@!`%0```#G^`$`
M.@```#SY`0`\````=_D!`$X```"T^0$`;P````/Z`0!8````<_H!`$<```#,
M^@$`2@```!3[`0!)````7_L!`&L```"I^P$`=0```!7\`0!I````B_P!`&8`
M``#U_`$`/P```%S]`0`M````G/T!`"P```#*_0$`,````/?]`0!W````*/X!
M`&8```"@_@$`=0````?_`0#`````??\!`!D````^``(`*@```%@``@`]````
M@P`"`#(```#!``(`4@```/0``@`D````1P$"`%L```!L`0(`(````,@!`@`)
M````Z0$"`+T```#S`0(`2@```+$"`@`C````_`("`#T````@`P(`)@```%X#
M`@`A````A0,"`#X```"G`P(`"````.8#`@`'````[P,"``4```#W`P(`#0``
M`/T#`@`.````"P0"`!0````:!`(`#@```"\$`@`%````/@0"`!,```!$!`(`
M`0```%@$`@!Y````6@0"``L```#4!`(`$P```.`$`@`$````]`0"``<```#Y
M!`(`!@````$%`@`%````"`4"`#P````.!0(`!````$L%`@`4````4`4"``L`
M``!E!0(`$0```'$%`@`,````@P4"``(```"0!0(`!P```),%`@`'````FP4"
M`!$```"C!0(`#````+4%`@`7````P@4"``8```#:!0(`%0```.$%`@`,````
M]P4"``,````$!@(`+0````@&`@`$````-@8"``<````[!@(`!P```$,&`@`I
M````2P8"`$8```!U!@(`0@```+P&`@!!````_P8"`!X```!!!P(`-@```&`'
M`@`Y````EP<"`"0```#1!P(`&P```/8'`@`D````$@@"`"T````W"`(`)@``
M`&4(`@`C````C`@"`"T```"P"`(`*0```-X(`@`N````"`D"`#P````W"0(`
M)@```'0)`@`W````FPD"`#````#3"0(`*0````0*`@`O````+@H"`"T```!>
M"@(`)@```(P*`@`P````LPH"`"H```#D"@(`+`````\+`@`O````/`L"`"H`
M``!L"P(`)@```)<+`@`J````O@L"`"\```#I"P(`(P```!D,`@`M````/0P"
M`#@```!K#`(`.P```*0,`@`@````X`P"`"P````!#0(`/@```"X-`@`I````
M;0T"`"X```"7#0(`+0```,8-`@`L````]`T"`"8````A#@(`(````$@.`@`H
M````:0X"`"H```"2#@(`0P```+T.`@`O`````0\"`#P````Q#P(`"0```&X/
M`@`7````>`\"`!P```"0#P(`-0```*T/`@`B````XP\"``X````&$`(`#P``
M`!40`@`3````)1`"``L````Y$`(`"@```$40`@`?````4!`"``8```!P$`(`
M!P```'<0`@`B````?Q`"`"4```"B$`(`(````,@0`@`J````Z1`"`!@````4
M$0(`"````"T1`@#X````-A$"`!H````O$@(`'0```$H2`@`(````:!("``L`
M``!Q$@(`%@```'T2`@`6````E!("`"4```"K$@(`!P```-$2`@!3````V1("
M`!H````M$P(`&@```$@3`@`'````8Q,"`!D```!K$P(`#````(43`@!,````
MDA,"``L```#?$P(`,````.L3`@`?````'!0"`!@````\%`(`'P```%44`@`\
M````=10"`!T```"R%`(`$0```-`4`@`G````XA0"`!,````*%0(`%````!X5
M`@`6````,Q4"``L```!*%0(`&@```%85`@`(````<14"`"P```!Z%0(`"```
M`*<5`@`I````L!4"`"\```#:%0(`!P````H6`@`9````$A8"``<````L%@(`
M"````#06`@`)````/18"`$4```!'%@(`!P```(T6`@`3````E18"`!,```"I
M%@(`%````+T6`@`*````TA8"``H```#=%@(`!P```.@6`@`4````\!8"``<`
M```%%P(`&0````T7`@`-````)Q<"`!D````U%P(`&P```$\7`@`*````:Q<"
M``T```!V%P(`%P```(07`@`&````G!<"`#0```"C%P(`#````-@7`@`0````
MY1<"``D```#V%P(``@`````8`@`0`````Q@"`!H````4&`(`"P```"\8`@`#
M````.Q@"``@````_&`(`#@```$@8`@`)````5Q@"``X```!A&`(`#0```'`8
M`@`7````?A@"`!@```"6&`(`$0```*\8`@`\````P1@"`"4```#^&`(`(P``
M`"09`@`7````2!D"``X```!@&0(`-````&\9`@`'````I!D"`!4```"L&0(`
M60```,(9`@`2````'!H"`!`````O&@(`"0```$`:`@`$````2AH"``0```!/
M&@(`$0```%0:`@`>````9AH"``8```"%&@(`!P```(P:`@`'````E!H"`!,`
M``"<&@(`!P```+`:`@`7````N!H"`!<```#0&@(`0@```.@:`@`T````*QL"
M`#@```!@&P(`!0```)D;`@`;````GQL"`"$```"[&P(`&0```-T;`@`B````
M]QL"`!$````:'`(``@```"P<`@`$````+QP"`!$````T'`(`#````$8<`@`%
M````4QP"``,```!9'`(`#@```%T<`@!6````;!P"`#(```##'`(`'````/8<
M`@!!````$QT"`#8```!5'0(`6````(P=`@`9````Y1T"`'L```#_'0(`*```
M`'L>`@!(````I!X"`"0```#M'@(`1P```!(?`@`L````6A\"`"P```"''P(`
M+P```+0?`@`N````Y!\"`"X````3(`(`.````$(@`@`L````>R`"`#0```"H
M(`(`+0```-T@`@`U````"R$"`!D```!!(0(`(P```%LA`@`8````?R$"`'H`
M``"8(0(`"0```!,B`@#+````'2("`)````#I(@(`?````'HC`@`M````]R,"
M`&X````E)`(`'0```)0D`@`F````LB0"`!,```#9)`(`$P```.TD`@`6````
M`24"`"H````8)0(`0````$,E`@`A````A"4"`"4```"F)0(`<0```,PE`@`<
M````/B8"`!<```!;)@(`"P```',F`@`%````?R8"``8```"%)@(`"````(PF
M`@`%````E28"`!8```";)@(`%0```+(F`@`9````R"8"`"0```#B)@(`$```
M``<G`@`/````&"<"`!(````H)P(`"0```#LG`@`4````12<"``@```!:)P(`
M!0```&,G`@`9````:2<"``H```"#)P(`#````(XG`@`8````FR<"``@```"T
M)P(`#````+TG`@`0````RB<"``X```#;)P(`%@```.HG`@`-`````2@"`!$`
M```/*`(`%````"$H`@`&````-B@"``4````]*`(`*````$,H`@`<````;"@"
M``L```")*`(`+````)4H`@`7````PB@"`"4```#:*`(`&@`````I`@`(````
M&RD"`!$````D*0(`!P```#8I`@`'````/BD"`!D```!&*0(`"0```&`I`@`#
M````:BD"``(```!N*0(`$@```'$I`@`-````A"D"``H```"2*0(`%@```)TI
M`@`9````M"D"``<```#.*0(`)@```-8I`@`"````_2D"``,`````*@(`$@``
M``0J`@`9````%RH"``H````Q*@(`"P```#PJ`@`2````2"H"``8```!;*@(`
M(0```&(J`@`)````A"H"`!<```".*@(`%P```*8J`@`2````OBH"``(```#1
M*@(`!````-0J`@`.````V2H"``\```#H*@(`$````/@J`@`O````"2L"``8`
M```Y*P(`"````$`K`@`7````22L"``4```!A*P(``P```&<K`@`+````:RL"
M``$```#3!```'`0``#$%``!?`P```````)P!``!M`@``H`0```````"4`P``
MQP$``/L&``!\``````````````"&`@``*0<```L!````````@0<``,$```!W
M!0``%00``/`%```L````VP,``,$&```C!P``"`(```$$``"\!0```@<``#$#
M````````I@(``.\%``!D`@``L@(```\$``"!`P``````````````````````
M`-8$``!1!0``A00`````````````]@$``'`"`````````````'\"```N!```
M`````",!``"D!0```````&('``#C!0``CP8``"4!``!P!@``]00``&X"``!P
M`0``,P<``,(!``#1`@``+P0``&\#``!.!P``6@```*(!```S`0``B0<`````
M``![`0``ZP```)8&``#`!0``7`<``$H%``#,!@```````)0$``!B`@``\@``
M`"D"``!F`@```````-L$``"$!@``W04`````````````I0``````````````
M`````)@#````````0````.0&````````S0$```````"=!```2`(``+\%````
M````_0(``(@'````````#`4```````!/!```RP4``.P"```F!0``%P``````
M```T````6````+P!`````````````+4"``!:!```90,``&H#``!?`0``@@<`
M`````````````````/H!``!D`P``;P```-8!````````?08````````(!P``
MD`````````!-`P``FP(````````<`P``708``/0!``#?````*`,``-P!``#0
M`0``M@,``$<#````````&P<``!$'```E`P``\0```+`%``#2!```````````
M``"K`P``I`````````#*!0``80,``'D#``"5!```"@0```````"*!@``P`$`
M``````#A!```>`<``-D#``#G`0```````/X%``!*!P``J0$``%@$``#D`0``
M`````$\```"^`0``````````````````+P,``&P'````````L@````````"8
M!0``9P0``*0&``#B`0``1@8````````J````^P$``&@!``!4!P``V@,``"@&
M``"C!```5`8``%8$``"O!@```````)T"``!;````D@8``(L#``"I````````
M`*P%``#3````H`,``'H!``!G`@``P@,``"@'``![`P``*P`````````V````
M```````````Q`@``@P```.0$````````]@0``'D$``!$!P```````/<`````
M`````````),"``"Z!0```````!<%``"J`P``*P(``'H'````````=`0``#L"
M`````````````)`"``".`0``B@0``-P```!\!P``5P4``)H#```#`@``.P<`
M`%X#```&`0```````$4$````````+0<``)\#``"E`0````````````!G!0``
M<0$`````````````0@8``-L````]!P``2@`````````"`@```````"D!````
M````5@,```````"<!````````,P!``!A!```%@,````````G!```80``````
M````````)00``'<```#N`P``9@8```````"<!@``_P4``'L`````````&`8`
M`+$$```#`````P<``-P%``"W!@``R0,``'P"```6!P``[```````````````
M8P$```````#N`@``F@```)(```">`P```````)L!```K!0``<0(``/,#``!&
M`P``O@(``+H!``#=!```U@8``+0#``#C!```R@0``*H$````````&`<``!<"
M``"_!```&`$``+$"`````````````.(#``"/`@```````'X!``#]!0``:0$`
M`!8&``#X`0``*@,``$L#``!R`P``1P0``)8!``!'````R`$``'$#``!.!@``
M.@```&`&``!3````U08``'8"````````+@4``"8"``!S!@``[0````H&```$
M````Y`(``'X#``"#!0``B0$``),$``#^`@``9`<``.8%```7`0```````)\!
M```-!P``>P(``'X````%!```"0<``"T&```T!@```````%("``"_````````
M`'<#``#_`P````````L````S!0````````````!F!P``)P8``-T`````````
M]`(``#\'````````V`,``-H$`````````````&@````-`@``<@8```````#3
M!@``Q08``'$```"@````_`8``$("````````FP0``+D#``#`````!`0```X&
M``!,`0``E`(``+D%``"@`0``P0$````````%`````````$P'``#6`@``8P``
M``````#$````````````````````\@0```````!`!0``;P<```````#-!@``
M`````!<#``"!!@````````````!2!0````````````#S!```=P0``*,&``!O
M!```"````%X```!(!P``N@,``'8%``#>````A`,``"0$```[!0``]P8``)P#
M``!W`@```````&H!```^`@``O@8``.T%``"^!````````&\&````````B0``
M`*4"````````,P8````````<!P```````%4!```B!```.`$```````!M!```
M`````(<"``!Y!0``@`4``-8`````````(0(``$\&```W!```,P(`````````
M````EP,``/\$````!P``!P,``&D&````````\0$``,8```#P`P``CP```%L'
M`````````````.<&``"%`P````````````#=`@``+@,``%<!``#T!@``````
M`.4!``#^````30```,T$```0!0```````#8!``"0`P``?0$``)<```!9!```
M?P0``',```"G!0``6`(``(("````````008``'8!``#^`0```````.<$````
M````)`````````#X!```:P0``,8$``!9`0``(00```8```"?`@``7@(`````
M`````````P8``)0%````````X08``(X#```^````*P$``!0"``#7`P``D08`
M`$`'````````;`,```````".!```HP````````#%`P``40```+T"```L!```
M(`0``.D$````````+`8``/8"```N!@``6`4``````````````````*D"```D
M`P````````````"S`0```````'T````G`P```````'('````````D00`````
M``#.`0``\`8```@!`````````````````````0``3`4``#@&````````R`4`
M`!$!``!?!```^@,``)P```"P`P``Q`$```````!U!```<00``-<"``#)!0``
M?`$``(P!``````````````````#\!0``-00````````^!P``I08``-`#``"H
M!@``[0$``*8`````````[P(``````````````````*T$``#K`0``^00``-\#
M```H!````````&8$``"?````#P8``+D$``#J`P```````,D$``!;`@``C`0`
M``````#$`@``O@4``$(%``!T!P``U04``),&````````8P<`````````````
M&P0```````#T`P``5````-D`````````2````)8`````````5@(``#<````?
M!@``/`(``',"````````\P(````````(!```MP(``*4$``!W!P```````-H&
M```5`````````-D$````````_``````````?!0``BP4``/<!``#V!0``?`,`
M`-@&``"T!0``E04```,%````````````````````````@P0``+\"``#.`@``
M#`<``)D#``#_`@```````/0$```_`@``4P$```````#%!```,@$```````#+
M`@``C```````````````2P$`````````````N@8```D!``#>`0``)@0``*0#
M``#,!0``<P$``#,$```0!@``BP0``&(`````````+P```*`&```X`@``60(`
M`'\'``!'!P``C04``!D`````````K0```.\#``#1!@``?`4``#(```"]!0``
MR@(```````#V!@``M@8``%L%``!$`0`````````````=`@``'@<``-L&````
M````#@4```````!@`0``.0(``$,"``"[`0``@`,````````J`0``1@```-`"
M```3!@```````'\```!"`P``-0<``"T!```Q!```X0$```````#1!0``M`(`
M`.@!``!4`P``^`,``'T$````````H@,``-0"``!B`P``Z@4`````````````
M7P```!\"```R`P``_`(```````!S!````````(`&```W!0``.@4``!@$````
M````=@```*,#````````EP4``&(%```2`@``;`$``"(!````````C@``````
M``!J!0```````,4%```:`0``X`$```````"3`P``F`````````"%!0``&```
M```````L!0``A@0````````<````F08``&@&``#[`@``A0$```````!,`P``
M:`<``'H$```0!```90```%0%``#$!@``=`(``.```````````````+<#``!U
M`P````````````````````````````!<`0```````#@'``!^`@``;```````
M````````B`(```````#.!@``"P(```\%``!M`0``+0(``-\%``#G`@``3P,`
M``T!``!@````9P````````"_!@``V0(``+D&``````````````````#J````
ML@0``"@`````````+P<```````#S````J@4``/T!``#5!```&@``````````
M`````````&($````````R`8``%\&``!.`````````!,"`````````````$H$
M```5!@``(P```#\```""!0``J`0``+@"``"1!0``Y````$($````````N`4`
M`$$%```?`0``N`$```````";!0```````+4````!!P``*P<`````````````
ML`0```````!I!P``>P4``&8```````````````````#.!```!P$``%<&````
M`````````-\&``!@!P``.P$``#L$``!U`@``ZP8``#D$```?!P``_08``'$&
M```,`0```````$<&``"=!@``O`0``&4&```)!0``10<`````````````````
M`',#``"+````>0<``-(#```!`@``HP$``"P#````````LP0````````D!P``
M`0,``.L"``!P````;08``-@````1!@``10,``%T'``#R!0``Z`8``-$$```_
M`P```````/H%``!E!P``GP8``-("````````:P$``-$```")!@``,````,@"
M``"A!```[`$``.(```!J`@``I@$``%P"````````.`,```````!;!@``*P0`
M`&`#``#@!0```````,\```"6!0``UP8``$4"`````````````)4!````````
M``````8&``!&!0``_@8```````!)`P``;`4``%,'``#3`0``@`$`````````
M````````````````````_00``&P$```&!```/@,``!\$``#?!````````%P#
M``!^!```$0(``"L&``#+!```&P,```````!^!@``=0````4#``"1`0``````
M`*P`````````!`(``'D!```I!```-`<```````!Z````=```````````````
M8@$``%0!```-````/P$``-X#``"T!@``-P<`````````````)@``````````
M`````````(@%``"/!````````$8$````!@```````+,```!0`0``D`8``+(!
M```6`@``4`(``(<#``!N!P``]0(``+8```#R!@``\0,``%$!``#B!```[P0`
M``````#/!@```````"\"````````"P<``%``````````5`(```````!+!@``
M@0(````````;!@```````/,&``"+!@``NP```%P&````````^0$``(0```!%
M!@```````'4!`````````````$0"``!(`0``%0,````````D`0``60,``/4`
M``":!0``4P4``-P&```Y`0``&0<```````"(`0``7`4``%<$``!!!P``F@(`
M`#T#```1`P``K@4``$D!````````GP0````````^`0``:@```'X%``"G`P``
MIP8``"``````````K@```$L````2````I@0```$!``!X!@```````-4!``"Z
M````Y`,``+8!`````````````&@$`````````````+X```"Y````<@0`````
M```1````7P4``.8$```@`P``JP$``.8````B`@``G@8``+T!``#R`0``.08`
M`((&````````@0```!($``"[`@``/00``'\!```;````LP(```````"]`P``
M=04``&4"``"%`````````,T"``##!@``?P4```````!7`@``GP4``/`!``"M
M`P```````(H%``!R`0``L0```($$````````[P8````````0!P``;P(`````
M``#M`P```````!`"```4`0``+0,``$0$````````U0,``-\"````````>P8`
M`$D%````````V@4``(<$````````L08``/<"``"O!```!0(````````A````
M^P4``'<!```\`P``"08``/,%``#P`@``<04``+@#````````U`,``.@"``!8
M!@```````'L$``!!`P```````"H"``"<!0``Q@4``-D%``!A!0``````````
M``#_!@``>@4``$<"```\````O```````````````#P,`````````````#P<`
M`#8&```4!`````````````!A`@``!P<``#,#````````0`$``#T%````````
MF@8`````````````AP$``,D```#I`P``XP8``+T```"+`0``O00````````V
M`P``-0(``!T%````````A@8``*X$```'`@``ZP0``+\#````````````````
M``!)!```4`8``+4$``!S!0``Q`,```````!K`P``V@$``+`!````````DP4`
M``````#)!@``H@4````````)`P``?0,``!,````-!```Q0$```L$````````
M00(``%4```#B!0```````*P#```#`P``&00```4&`````````````.H$``#K
M!0``"@,``*@%``"W!```%@```%0$```W`0``504``*0"``#Y`@```````(`"
M```C!0``^P,``$,!``!J!``````````````_!0``$P$```````#R`P``QP0`
M`+T&````````2`,```````#-`P``704``'P$```\!@``^0```!X%``!&`0``
M`````*L```!6`0``Z`0``(T`````````S@,``#<&`````````````,L```"'
M````W0,`````````````S`0```````!1!P```````!D%````````YP,``#$`
M``#,`P``B04``!`!```.````:@<``*<```#/!```80<``!<&``#:````(0$`
M`*("``"8`@``7@0``"T$```B!P``90$``'@"```3!P``'00``-@%``"<`@``
M70````````#@!```9@4``#X&``#F`@```````+(%````````!`,``!X$````
M```````````````$!0```````),!``"%!@``=`,``*\#``#Y!@```````)($
M``"%`@``'08```````#<`P```````%L!``!:!P``%`,``/$"```R!P``=`4`
M`*@#``!=`0``*@8``````````````````*X&``#@`P``3@,``/P$```Y!P``
M>`0````````O!0``9P8``-0```"@`@``^0,````````H!0``A0<``.P%``!R
M`@```````"D`````````!@(````````*!P``Y00```````!1!@``````````
M```F!P```08```````!&`@``````````````````UP$``,T````W`P``!`$`
M```````J!P``<0<``&(&````````@04``&X!``"O`@``Q`0``"X"``!5!```
M````````````````A`4``!,$``"1`@``5@8``-(```"N`P``2`8``#8'``![
M!P```````-`$```;!0```````+H$`````````````((!`````````````","
M``!:`0```````!H'```Q!P``(`(``*@"```E!P```````#H$``")`@``:P``
M`/$&```Y!0``/`$``!$%````````Y`4``(H````<`0``JP0``(D#```&!0``
M`````"(%``!=`@```````.H!````````^@0```````#?`0``1P4````````2
M!@``B````.D"```T!```Y0,``*L%``#-!0``QP,````````_!```````````
M````````Z@(``*$#``#^`P``&`4``#,```#U!0``=@<```````!N!@``````
M`,L#``!O`0``'@,``%D%````````A@```(,!````````M````(\#``"$!```
M,`0``+<!``"9`@``H`4``+8"``#E`@```````#($``"A````+`(``,@#```+
M`P```````(P%````````&@8``*P$``````````````````!K!0```````-@!
M````````#@0```<&````````)0```.$#``">``````````````!R!0``'@8`
M```````5`0``/@4``!T```#,`@``G@4``(@&``".`@``(04``)8"````````
M/P8``$`&``"A`0``H04``"<"`````````````"T```!)!P``E0(``%($````
M`````````#0"``#W!0``=`$``%T#```U`0```````$X$``!6!0``H@0```D`
M``##!0``@P,```````!8`0``:0(``.P#```9`@```````,("``!9!P``0P,`
M`#P$``"0`0``Y@$``.,#``!1!`````````````"L`@``#@(``!P"``!.`0``
M2`0```H`````````3`8``/P!```N````C0$````````L!P``[0(``.D!``#/
M`0``;`(`````````````V@(``,,"```G````LP,``)(%````````;@```!``
M````````C00``!L!``!P!```=0<````#``#>!0``4@<``+(#```&!P``C0,`
M``````"-`@``9P$``((#``"_`0``=@8``&X$``"J````3@(``&0%````````
MC`,``"X'``""!````````+P#```^!```&`(````````W`@``D@,``((`````
M!```````````````````#P(``!4"``#"````NP,```````#0!@``,`4``.X`
M``#!!0```````$@%```2!P``6`<```($``!>`0````````````#9`0``208`
M`/$$``!L!@``.`4``#H'``":`0``X0```+P"``"^`P``%@0`````````````
MF04``.D%``#U`P```````$('```9`P``[`0``)4#```"`P``"`8``(T&````
M````:P8``%\'```N`0``)08```````!D!@``:0,```````!>!@``M0,```H"
M``!)`@``'P````L&``!D`0````````````!/`@````````````"F!0``,`8`
M`+$!```,!@``T@$``#4%``"&`0``7``````````Z!@``Y@,``!H%``"[!```
MK0(```````"`````>@,``(<&````````@P8``-T!```U`P``[P$`````````
M````#````)8#``!C`@``G@(``/$%``````````````````!D!```````````
M``#I````M@4``*$&````````'@$``,$#```[!@``<`4``(0!``!K`@``````
M`$T$``#F!@```````,8&``"/`0```````,,````=!P```````&,$``!S!P``
M``````T%```]`0``3P<``&T#```A!@``1````!4'`````````````-@"``!)
M````.P,``!<$````````[P```&H&````````"@4``%,#```'!0``)`4``+4&
M``"I!```!P0``$<!``!#!@``````````````````(`4```````"P````KP``
M`"\&``#N!@``XP`````````B!@``$@,``,$$``#9!@````````````!_`P``
M#`0``!@#``"L`0```````+D!``#B!@``S@````````"2`0``?@<``,4"```"
M!0```````#0!````````J````"P!```.`P```````)`$```9`0``H@```%`%
M````````Z08``-4"```````````````````)!```F0$``)L#``"J`0``#`(`
M`-0%``#T!0``]0$```T#````````G0$``,4`````````Q@(``%<````X````
M*`(`````````````_0,``*<$``"[!0```````,(%````````3P$``!T!``#L
M!@``^`8``)8$``!0!````````*T!`````````````*0!``"I!0``L`(``&,&
M````````U@,``!8%``"F`P```````!H"````!0```````(8'``"`!P``T`4`
M`.,!``"L!@``XP(``,`&``"K`@``<`,``)`%``"O`0```````-(%``"B!@``
M`````+4%````````S@4``&T%````````^`(```````#=!@`````````````?
M`P``?0<``+0$``"F!@```````,0%``"G`0``0P```)T#```;`@```````$P$
M`````````@$``)<"``!/!0``0`,``'D&``#<`@```````$8'``!C!0``?P8`
M`$0#``#E````304``,(&````````````````````````T````%L#``"W````
M>0(``$,%````````4@8``-8%``!*`@``/0```"T%````````>@8``.`"``!@
M!```&@,``````````````````,,$````````TP,``.("``!X`P``E````(<'
M```:!````````````````````````$$$```9!@````````````!0!P``````
M`"D#``#]````5P,`````````````(0<``%$#```Z`@``DP```/,!``!5`@``
M```````````-!@```````)D$````````0@$``%\"``!+!```2P<``&X%``"Q
M`P```````(0"``!-!@```````"8!````````VP$```````"Q!0``<`<``-P$
M``!I!0``LP8``"<%```\!P``0P<``$H#``!I!```SP,```````!H`@``KP4`
M`(`$``!V`P``T0,``%`#``"8`0``X0(``$P"``#"!````````(@$``!K!P``
M<@```````````````````/H"````````,@4``&@#```%!P``(P,``'P&````
M````Z`,``)<$``"U`0``R@8``,\"```H`0``EP$``,L!````````5@<``%,"
M``!:`P``A@4````````P`@``^````)D`````````S````*X"```T!0``````
M`-<`````````I04``````````````````"0&``"8!@``[@$``"$#```[````
MEP8``$$!``#&`P``C`(```0'```5!0``904``````````````````"(#``"*
M`@``'@```(,'``!5!P``K04``$4```!U!@``.`0``,,!``#4`0``0@```&4$
M```G!P``;P4``/4&``!6````#@$``/D%``!-`@``_@0``%H"``"C!0``!`8`
M`.@%```B````104```````!*!@``F`0``)L&``#!`@```P0`````````````
MO`8``&X#```4!@``[08```````!]!0``Z````#0#``!:!0``$@4```\!```>
M`@```````&@%````````+P$``#T"``!-`0``,`$``"4"``#5`````````"4%
M``!F`P``]@```'H"``".!@````````````"C`@```````*X!``#\`P``80$`
M`+@```"1````````````````````E0```"8#```/``````````````"*`P``
M`````'T"``#'!0``Q@$```````"&`P``(`<``)X!````````VP(``,D!```*
M`0``50,``'D```#4!```PP,```````#*`0``$P,``````````````````&T'
M``#P!```=@0```@#````````/08``-@$````````H0(``&T```"/!0``%P<`
M``````!7!P``*@0```(```!@`@``'`4```````#X!0``3@4```````#(````
M#`,``(L"````````I0,```@%````````.0,``/\!```.!P``700```D"````
M````3````)H$``#1`0``*04``.<%````````>`````````!F`0``\````.X%
M``!+`@``MP4```4%````````4@```.L#``!+!0``U`8``#D```#(!```G04`
M`,`"``!>!P```P$``'<&``!$!0``W@8`````````````!P```#8%```K`P``
M^@```,<&```4!P```@8``,H```!X`0``$@$``/<#``#E!0``J@8``%,$``!2
M`0````````8#``"Y`@``30<``!0```"1`P``J@(``%P$``#7!```.@,``#`#
M``#T````0`0```````#>`@``L`8`````````````VP4``&$&``#``P``R@,`
M`.T$``!;!```E`$``(@#``!G!P``A`<`````````````$P4``(P&``"D!```
M,`<``(H!``!#!```FP```"`&``#R`@``=`8`````````````M@0````````0
M`P``Z@8``&`%````````^P0``)0&``#A!0``*08`````````````]P0`````
M``"Z`@```````+0!``!$!@```````*T&``!5!@``/`4```````!!````-@0`
M```````R`@````````$%````````C@4``!T#``"G`@````````````!2`P``
M)@8``-,%``#Z!@```````*@!``!C`P``$00`````````````4P8``"<!``"S
M!0```````.4&``#3`@```````(<%``"#`@``N`8``%@#``"!`0```````.X$
M```D`@``T@8````````U````NP8``,D"``"I`P``60`````````Q`0``````
M`.`&``"R!@``"P4``$4!``!:!@``N`0``#4&````````608```````!D````
M(P8``,<"````````G0```/\````%`0``0`(``(D$``!I````UP4``"`!``">
M!````````)("```4!0```````#H!``#/!0```````!8!````````>`4``,<`
M``#+!@````````````!>!0``(P0``/8#```J!0``YP```,`$``"I!@``'`8`
M`$H!```Q!@````(``&<#``#>!```-@(`````````````^P```*L&``"5!@``
M40(````````R!@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@
M*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y
M*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A
M('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@
M2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N
M`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A
M<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N
M;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D
M("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S
M<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S
M($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O
M9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@
M:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S
M(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.
M;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G
M=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O
M("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA
M=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!2
M86EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!
M8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO
M;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG
M`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D
M($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A
M(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M
M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I
M9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@
M8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E
M<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N
M;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S
M($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`
M06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N
M=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@
M9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T
M=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT
M97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT
M97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`
M06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@
M4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN
M;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL
M80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A
M;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI
M8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V
M90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V
M*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A
M;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%2
M35-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T
M`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@
M8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB
M=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD
M87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S
M97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2
M041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D
M+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"
M86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@
M9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"
M96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I
M<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U
M;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O
M;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N
M:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E
M="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U
M<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0
M;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@
M8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B
M`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F
M:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T
M`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S
M(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I
M;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N
M9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#
M96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC
M("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI
M8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$
M971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`
M0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!
M<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA
M;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N
M9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE
M87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I
M;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP
M=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@
M4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O
M`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C
M=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#
M;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O
M;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#
M;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O
M<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B
M)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L
M9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D
M("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@
M(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@
M8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R
M961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E
M<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I
M<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I
M=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER
M:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H
M<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E
M<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L
M96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU
M;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L
M971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T
M92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E
M(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT
M`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER
M96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS
M`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`
M1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN
M:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_
M(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L
M:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L
M(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2
M`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M
M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@
M)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S
M(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@
M4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S
M<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE
M(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@
M=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE
M87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;&5T
M=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%
M<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A
M;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G
M971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S
M(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI
M;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@
M-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M
M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3
M:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O
M=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#
M;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O
M<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@
M=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E
M('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O
M<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@
M`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I
M9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT
M.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&
M:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO
M861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF
M`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U
M<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N
M97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC
M90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0
M;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O
M;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'
M86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB
M:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'
M96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO
M8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R
M8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL
M86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'
M=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S
M=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`
M2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`
M2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE
M<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO
M7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!
M9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N
M9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.
M;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT
M86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L
M=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S
M`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!
M4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U
M;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D
M($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2
M;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O
M;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE
M="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G
M92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A
M;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S
M`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV
M:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T
M97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`
M26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D
M9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O
M<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E
M<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M
M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A
M<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN
M:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G
M97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A
M;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T
M8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI
M8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED
M(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES
M<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D
M92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`
M26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`
M26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T
M:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES
M;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A
M;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S
M=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y
M(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W
M8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`
M2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N
M9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(
M86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P
M9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`
M3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP
M='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F
M="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA
M;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A
M:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I
M;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,
M:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O
M.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP
M(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI
M<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES
M="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES
M=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM
M93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS
M`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N
M9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T
M:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`
M34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U3
M1P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L
M:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S
M('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@
M9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I
M="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU
M;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO
M='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-
M97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@
M<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-
M97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE
M=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@
M0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&
M961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM
M=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI
M<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`
M36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C
M:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL
M`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO
M;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@
M>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L
M9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R
M;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@0VQO=61Y
M(&%N9"!7:6YD>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-
M;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U
M90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P
M`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF
M;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.
M3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O
M;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.
M971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`
M3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R
M;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE
M9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@
M<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.
M;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S
M`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R
M;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T
M('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@
M;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE
M8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E
M<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E
M<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/
M<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@
M4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E
M<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S
M:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I
M;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@
M8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S
M=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S
M=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!0
M87-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A
M<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B
M)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N
M<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A
M:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A
M;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H
M:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y
M($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R
M96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R
M97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N
M<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0
M=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E
M<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`475E<GD`475O=&$`4E-!
M(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I
M;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!2
M86EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE
M<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO
M;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!2
M96UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M
M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T
M:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E
M('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R
M;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B
M92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!6
M1E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T
M(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U
M97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S
M=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H
M="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A
M=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE
M<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I
M;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C
M:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!3
M96QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C
M="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E
M;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I
M82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)
M1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@
M>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T
M(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A
M8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S
M=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S
M:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@
M=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P
M:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W
M965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I
M;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K
M97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S
M`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@
M=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I
M>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N
M;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO
M=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E
M;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@
M069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(
M96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@
M8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A
M8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#
M:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@
M<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T
M('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T
M`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B
M9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P
M<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B
M)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@
M9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D
M96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO
M;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P
M9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R
M>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS
M970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P
M;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3
M=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`
M4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M
M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L92!0<F]P97)T:65S`%1A
M8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I
M;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F
M;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E
M("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT
M`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S
M(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU
M;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T
M(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A
M=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES
M(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R
M97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W
M<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE
M<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA
M;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA
M<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@
M86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4
M:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH
M86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D
M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE
M9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE
M("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I
M9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E
M8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN
M('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F
M<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG
M("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H
M:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES
M("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O
M<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H
M=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI
M;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O
M:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@
M9'5R:6YG('1H92!L87-T(&UI;G5T97,N`%1O<`!4;W`@9G)A;64@*%]T;W`I
M`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L
M<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R
M:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP
M92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R
M('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K
M<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E
M<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C
M=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I
M;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A
M;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD
M;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@
M*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5
M;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA
M;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T
M960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D
M871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L
M;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V
M97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5
M<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A
M<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A
M;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@
M=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L
M=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA
M`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6
M97)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y
M($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@
M=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R
M($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O
M;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M
M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7
M:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I
M;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`
M5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O
M9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@
M16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M
M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@
M9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT
M96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!9
M97,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\
M/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@
M)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@
M96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I
M;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E
M92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@
M82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T
M:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@
M;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU
M;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I
M;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S
M<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T
M;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT
M(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N
M=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N
M`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)
M`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0
M<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D
M<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U
M='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N
M9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E9&ET
M`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM
M;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O
M9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI
M;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE
M="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI
M960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R
M=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V
M:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP
M;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T
M:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(&9R7T92"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-BTP,RTS,2`R,CHS,"LP,C`P"DQA<W0M5')A;G-L871O<CH@5&AI97)R
M>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N;F5T/@I,86YG=6%G92U496%M.B!&
M<F5N8V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M
M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@,2D["@`@*&EL('D@82`E<R!J
M;W5R<RD`("A4;W5C:&4@9"=A8V/H<R!R87!I9&4@)7,I`"`H9&%N<R`E<R!J
M;W5R<RD`("AA=6IO=7)D)VAU:2D`("AD96UA:6XI`"`H:&EE<BD`(.`@`*N@
M)7.@NR!N)V5S="!P87,@=6X@9&]S<VEE<@"KH"5SH+L@;B=E<W0@<&%S('5N
M(&-H;VEX('9A;&ED92X`JZ`E<Z"[(&XG97-T('!A<R!C;VYF:6=U<ND@9&%N
M<R!L92!R96=I<W1R92!D92!(;W)D92X`3"=I;G1E<G!RZ71E=7(@9"=A<F)R
M92"KH"5SH+L@;B=A('!A<R#I=.D@=')O=7;I+@"KH"5SH+L@82#I=.D@86IO
M=73I(&%U('-Y<W3H;64@9&5S(&=R;W5P97,N`*N@)7.@NR!A(.ETZ2!A:F]U
M=.D@874@<WES=.AM92!D97,@<&5R;6ES<VEO;G,N`*N@)7.@NR!N)V$@<&%S
M(.ETZ2!C<NGIH#H@)7,N`"4N,F:@36\@=71I;&ESZ7,@<W5R("4N,F:@36\@
M<&5R;6ES("@E+C)FH"4E*0`E9"`E<R!E="`E<P`E9"!J;W5R<R!A=F%N="!L
M)V5X<&ER871I;VX@9&4@=F]T<F4@;6]T(&1E('!A<W-E+@`E9"UP<NEV:7-I
M;VX@9'4@:F]U<@`E<R`M($YO=&EC90!%;7!R96EN=&4@4$=0(&1E("5S`"5S
MH$MO`"5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4@)FYD87-H.R!#;VYF
M:7)M871I;VX`0V]N9FEG=7)A=&EO;B`E<P!);G-C<FEP=&EO;B!D92`E<P!#
M;VYD:71I;VYS(&0G=71I;&ES871I;VX@9&4@)7,`)7,@97AI<W1E(&3I:N`N
M`"`E<Z#@("5S("5S`"5S(&5S="!P<NIT(.`@969F96-T=65R(&QE<R!O<.ER
M871I;VYS(&1E(&UA:6YT96YA;F-E(&-O8VCI97,@8VDM9&5S<V]U<RX@4^EL
M96-T:6]N;F5Z(&QA(&]U(&QE<R!O<.ER871I;VXH<RD@<75E('9O=7,@=F]U
M;&5Z(&5F9F5C='5E<B!C971T92!F;VES+6-I+@`E<R!E<W0@;V)L:6=A=&]I
M<F4`)7,@;6EN=71E<P`E<R!N;VX@=')O=7;I`"5SH.`@)7,@9&4@)7,`0V%R
M;F5T(&0G861R97-S97,@9&4@)7,`06=E;F1A(&1E("5S`$)L;V,M;F]T97,@
M9&4@)7,`3&ES=&4@9&4@=.)C:&5S(&1E("5S`"5SH#H@)7,`)7.@.B!L)^EM
M971T975R(&1E(&-E(&UE<W-A9V4@82!P=2#J=')E(&9A;'-I9FGI+B!!='1E
M;G1I;VX@96X@<W5I=F%N="!L97,@;&EE;G,@<74G:6P@8V]N=&EE;G0@;W4@
M96X@9F]U<FYI<W-A;G0@9&5S(&EN9F]R;6%T:6]N<R!P97)S;VYN96QL97,@
MX"!L)^EM971T975R+@`L(&5N(')A9F%L92``<F%F86QE("5S("5S`'9A<FEA
M8FQE(&1U("5S(&%U("5S`"TM(%/I;&5C=&EO;FYE<B`M+0!&;W)M870@,3(@
M:&5U<F5S`$9O<FUA="`R-"!H975R97,`,C0@:&5U<F5S`#Q0<NECZ61E;G0`
M56YE(&)A<V4@9&4@9&]N;NEE<R!P<FEN8VEP86QE("AB86-K96YD*2!E<W0@
M;NEC97-S86ER92!P;W5R(&-E(&)L;V,`56YE(&5R<F5U<B!F871A;&4@<R=E
M<W0@<')O9'5I=&4`56YE(&-L968@<'5B;&EQ=64@4$=0(&5S="!NZ6-E<W-A
M:7)E('!O=7(@8VAI9F9R97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ
M=64@4$=0(&5S="!NZ6-E<W-A:7)E('!O=7(@=NER:69I97(@;&$@<VEG;F%T
M=7)E(&0G=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4$=0+"!U;F4@
M8VQE9B!P<FEVZ64@4$=0+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!N
MZ6-E<W-A:7)E<R!P;W5R(&3I8VAI9F9R97(@=6X@;65S<V%G92X`56YE(&-L
M968@<'5B;&EQ=64@4$=0+"!U;F4@8VQE9B!P<FEVZ64@4$=0+"!E="!U;F4@
M<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R('-I9VYE<B!U
M;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!3+TU)344L('5N92!C;&5F
M('!R:7;I92!3+TU)344L(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT(&[I
M8V5S<V%I<F5S('!O=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E+@!5;F4@8VQE
M9B!P=6)L:7%U92!3+TU)344L('5N92!C;&5F('!R:7;I92!3+TU)344L(&5T
M('5N92!P:')A<V4@<V5C<NAT92!S;VYT(&[I8V5S<V%I<F5S('!O=7(@<VEG
M;F5R('5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%,O34E-12!E<W0@
M;NEC97-S86ER92!P;W5R(&-H:69F<F5R('5N(&UE<W-A9V4N`$YU86=E<R!L
M92!M871I;@!0;'5I92!LZ6?H<F4@;&4@;6%T:6X`4&QU:64@;&4@;6%T:6X`
M079E<G-E<R!L92!M871I;@!#:'5T97,@9&4@;F5I9V4@;&4@;6%T:6X`04TO
M4$T`05!)($E$`,`@<')O<&]S(&1E(&-E="#I9&ET975R`,`@<')O<&]S+BXN
M`$)A<R!A8G-O;'4`36EL:65U(&%B<V]L=0!!8V/H<R!R969U<^D@;&]R<R!D
M92!L82!C<NEA=&EO;B!D92!RZ7!E<G1O:7)E(%9&4R`N`$%C8^AS(')E9G5S
MZ2!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1E(&9I8VAI97(@5D93+@!$;VYNZ65S
M('!E<G-O;FYE;&QE<P!-;W0@9&4@<&%S<V4@9'4@8V]M<'1E`$-O;7!T92!I
M;F%C=&EF`$-O;7!T97,`06IO=71E<@!!:F]U=&5R('5N('-O=7,M9W)O=7!E
M`$%J;W5T97(@=6YE(&YO=79E;&QE('-O=7,M<&5R;6ES<VEO;@!!:F]U=&5R
M(&EC::`Z`$%J;W5T97(@=6X@;F]U=F5A=2!G<F]U<&4`06IO=71E<B!U;F4@
M;F]U=F5L;&4@<&5R;6ES<VEO;@!!:F]U=&5R('5N(&=R;W5P92!F:6QS(.`@
MJZ`E<Z"[`$%J;W5T97(@=6YE('!E<FUI<W-I;VX@9FEL;&4@X""KH"5SH+L`
M06IO=71E<B!U;B!N;W5V96P@=71I;&ES871E=7*@.@!!:F]U=&5R('5N92!C
M;VQO;FYE`$%J;W5T97(@9&4@;F]U=F5A=7@@;65M8G)E<P!!:F]U=&5R('5N
M92!P86ER90!!:F]U=&5R(&QE(&UE;G4@)7,@X"!L82!B87)R92!D92!-;WII
M;&QA`$%J;W5T97(@874@8V%R;F5T(&0G861R97-S97.@.@!!:F]U=&5R(.`@
M;6]N(&-A<FYE="!D)V%D<F5S<V5S`$%J;W5T97(@=6X@=71I;&ES871E=7(`
MJZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S>7-TZ&UE+"!M86ES(&PG86IO=70@
M9"=I;F9O<FUA=&EO;B!S=7!P;.EM96YT86ER97,@)7,@;B=E<W0@<&%S('!O
M<W-I8FQE+@"KH"5SH+L@82#I=.D@86IO=73I+B!6;W5S('!O=79E>B!V;W5S
M(&-O;FYE8W1E<BX`3&$@9F]N8W1I;VX@9"=A:F]U="!D)W5T:6QI<V%T975R
M<R!E<W0@9.ES86-T:7;I92X`061R97-S90!#87)N970@9"=A9')E<W-E<P!!
M9&UI;FES=')A=&5U<B`M(&%J=7-T97(@;&5S('!E<FUI<W-I;VYS('!O=7(@
M9"=A=71R97,@=71I;&ES871E=7)S`$%D;6EN:7-T<F%T:6]N`%!U8G,`069G
M:&%N:7-T86X`06QB86YI90!!;&?I<FEE`$%L:6%S`$%L:6=N97(`06QI9VYE
M;65N=*`Z`%1O=70`5&]U<R!L97,@<&%R=&EC:7!A;G1S(&%U=&AE;G1I9FGI
M<P!4;W5S(&QE<R!G<F]U<&5S`%1O=71E<R!L97,@<&5R;6ES<VEO;G,`3&5S
M('%U871R92!C]'3I<P!097)M971T<F4@9&5S(&%D<F5S<V5S(&1E(&-O=7)R
M:65L(&UU;'1I<&QE<P!!=71O<FES97(@;&$@;6ES92!E;B!P;&%C92!D92!L
M:7-T97,@;G5MZ7)O=.EE<Z`_`$5X:7-T92!DZ6K@`$YO;2!D)W5T:6QI<V%T
M975R($E-4U`@86QT97)N871I9@!-;W0@9&4@<&%S<V4@24U34"!A;'1E<FYA
M=&EF`$YO;2!D)W5T:6QI<V%T975R($E-4U`@86QT97)N871I9@!!9')E<W-E
M(&1E(&-O=7)R:65L(&%L=&5R;F%T:79E`$%U=')E<R!M;V3H;&5S`%1E>'1E
M(&%L=&5R;F%T:6:@.@!386UO82!!;>ER:6-A:6X`56YE('9A;&5U<B!I;&SI
M9V%L92!A(.ETZ2!S<.EC:69IZ64N`%5N92!E<G)E=7(@:6YC;VYN=64@<R=E
M<W0@<')O9'5I=&4N`$%N9&]R<F4`06YG;VQA`$%N9W5I;&QA`%!R;WAY(&%N
M;VYY;64`4NEP;VYS90!!;G1A<F-T:7%U90!!;G1I9W5A+65T+4)A<F)U9&$`
M07!P;&EC871I;VX`3&ES=&4@9"=A<'!L:6-A=&EO;G,`3"=A<'!L:6-A=&EO
M;B!E<W0@<'+J=&4`07!P;&EQ=65R(&%U>"!P87)T86=E<R!F:6QS`$%P<')O
M=7;I`%1A:6QL92!A<'!R;WAI;6%T:79E`$%V<FEL`$%R86)E("A7:6YD;W=S
M+3$R-38I`%1A:6QL92!D=2!F:6-H:65R(&%R8VAI=F4`3F]M(&1E(&PG87)C
M:&EV90#*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER('-U<'!R:6UE<B!C
M971T92!R97%UZG1E(&0G:6YS8W)I<'1I;VX@('!O=7(@)7.@/P#*=&5S+79O
M=7,@8V5R=&%I;B!D92!V;W5L;VER(&5F9F%C97(@JZ`E<Z"[(&5T('-E<R!S
M;W5S+6=R;W5P97.@/P!!<F=E;G1I;F4`07)MZ6YI90!!<FWI;FEE;B`H05)-
M4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N("C.;&4I`$%R="!!4T-)20!2
MZ6=I;VX@07-I92]086-I9FEQ=64`1&5M86YD97(@=6YE(&-O;F9I<FUA=&EO
M;B!A=F%N="!D92!L86YC97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N
M8V6@/P!#;VQO;FYE<R!D97,@=.)C:&5S`%1E;G1A=&EV92!D)V5F9F%C96UE
M;G0@9"=U;B!G<F]U<&4@:6YE>&ES=&%N="X`5&5N=&%T:79E("!D)V5F9F%C
M96UE;G0@9"=U;F4@<&5R;6ES<VEO;B!I;F5X:7-T86YT92X`5&5N=&%T:79E
M(&1E(&UO9&EF:6-A=&EO;B!D)W5N92!P97)M:7-S:6]N(&EN97AI<W1A;G1E
M+@!496YT871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6X@<&%R=&%G92!I;F5X
M:7-T86YT+@!0<F]P<FGI=.ES`$%O^W0`075S=')A;&EE`$%U=')I8VAE`$%U
M=&A?8WER=7.@.B!%>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE
M+@!!=71H7V-Y<G5SH#H@;&4@8F%C:V5N9"!N)V$@<&%S(&QE<R!C87!A8VET
MZ7,@<F5Q=6ES97,N`$%U=&A?8WER=7.@.B!E>'1E;G-I;VX@<F5Q=6ES92!)
M34%0(&YO;B!T<F]U=NEE`$%U=&A?9G1PH#H@97AT96YS:6]N(')E<75I<V4@
M1E10(&YO;B!T<F]U=NEE+B!);"!F875T(&-O;7!I;&5R(%!(4"!A=F5C(&PG
M;W!T:6]N("TM96YA8FQE+69T<"X`075T:%]I;6%PH#H@97AT96YS:6]N(')E
M<75I<V4@24U!4"!N;VX@=')O=7;I92X`075T:%]K<F(UH#H@97AT96YS:6]N
M(')E<75I<V4@:W)B-2!N;VX@=')O=7;I92X`075T:%]L9&%PH#H@;"=A:F]U
M="!D)W5T:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.D@879E8R!!8W1I
M=F4@1&ER96-T;W)Y`$%U=&A?;&1A<*`Z(&QE(')E=')A:70@9"=U=&EL:7-A
M=&5U<G,@;B=E<W0@<&%S('-U<'!O<G3I(&%V96,@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U
M=NEE+@!!=71H7VQD87"@.B!I;7!O<W-I8FQE(&0G86IO=71E<B!L)W5T:6QI
M<V%T975R("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U('-E<G9E=7*@.B``
M075T:%]L9&%PH#H@:6UP;W-S:6)L92!D92!S=7!P<FEM97(@;"=U=&EL:7-A
M=&5U<B`E<P!!=71H7VQD87"@.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D
M92!L)W5T:6QI<V%T975R("5S`$%U=&A?;&1A<*`Z(&QA(&UO9&EF:6-A=&EO
M;B!D97,@=71I;&ES871E=7)S(&XG97-T('!A<R!S=7!P;W)TZ64@879E8R!!
M8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86R@.B!E>'1E;G-I;VX@<F5Q=6ES
M92!-0T%,(&YO;B!T<F]U=NEE+@!!=71H7W-M8F%U=&B@.B!E>'1E;G-I;VX@
M<F5Q=6ES92!S;6)A=71H(&YO;B!T<F]U=NEE+@#)8VAE8R!D92!L)V%U=&AE
M;G1I9FEC871I;VX@874@<V5R=F5U<B!)34%0+@#)8VAE8R!D92!L)V%U=&AE
M;G1I9FEC871I;VX`R6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N("5S`$QE
M('-E<G9E=7(@4D%$2553(&$@<F5J973I(&PG875T:&5N=&EF:6-A=&EO;BX`
MR6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@1E10+@#)
M8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U<B!334(N`$-H
M86UP<R!D:7-P;VYI8FQE<Z`Z`$%Z97)B8>]D:F%N`$5X8W5S97,@0D]&2`!#
M;W5L975R(&1E(&9O;F0`0V]U;&5U<B!D92!F;VYD`$UO="!D92!P87-S92!+
M97)B97)O<R!E<G)O;NDN`$YO;2!D92!C;VYN97AI;VX@2V5R8F5R;W,@97)R
M;V[I+@!"86AA;6%S`$)A:')E[VX`0F%L=&4@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97-H`$)A<F)A9&4`4NEP97)T;VER92!D97,@9W)A<&AI<75E<R"KH"5S
MH+L@;F]N('1R;W5VZ2X`3&EG;F4@9&4@8F%S90!"Z6QA<G5S`$)E;&=I<75E
M`$)E;&EZ90!"Z6YI;@!"97)M=61E<P!":&]U=&%N`$%N;FEV97)S86ER90!"
M;&]C(*LE<R"[(&1E(&PG87!P;&EC871I;VX@JZ`E<Z"[(&EN8V]N;G4`4'+I
M9NER96YC97,@9&4@8FQO8P!4>7!E(&1E(&)L;V,`1W)A<P!";VQI=FEE`%-I
M9VYE=',`0F]R9'5R90#)<&%I<W-E=7(@9&4@;&$@8F]R9'5R9:`Z`$)O<F1S
M`$)O<VYI92U(97)ZZ6=O=FEN90!,97,@9&5U>`!";W1S=V%N80!"87,`0F]U
M=F5T`$)RZ7-I;`!497)R:71O:7)E<R!B<FET86YN:7%U97,@9&4@;"=/8^EA
M;B!);F1I96X`4W5L=&%N870@9'4@0G)U;NEI`$)U;&=A<FEE`$QI<W1E(.`@
M<'5C97,`0G5R:VEN82!&87-O`$)U<G5N9&D`1V5S=&EO;B!D92!C;VYT96YU
M`$-20P!$:7-T<FEB=71I;VX@9&5S('!O:6YT<R!,4D,@*$QI<W1E(&1E('+I
M=F]C871I;VX@9&5S(&-E<G1I9FEC871S*0!0<F]P<FGI=.ES(&1E(&QA($-?
M96QL=6QE`$PG:6YI=&EA;&ES871I;VX@9'4@8V%C:&4@;F4@<R=E<W0@<&%S
M('1E<FUI;NEE+@!!9V5N9&$`0V%L;64`0V%M8F]D9V4`0V%M97)O=6X`26UP
M;W-S:6)L92!D92!RZ6EN:71I86QI<V5R(&QE(&UO="!D92!P87-S92!A=71O
M;6%T:7%U96UE;G0L(&-O;G1A8W1E>B!V;W1R92!A9&UI;FES=')A=&5U<B!S
M>7-TZ&UE+@!);7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!F:6-H:65R(*N@
M)7.@NRX`26UP;W-S:6)L92!D)V%D;6EN:7-T<F5R(&1E<R!G97-T:6]N;F%I
M<F5S(&1E('-E<W-I;VX@97AT97)N97,N`,EC:&5C(&1E(&QA(&-O;FYE>&EO
M;B!A=2!S97)V975R($E-05"@.B`E<P!);7!O<W-I8FQE(&0G;W5V<FER(&QE
M(&9I8VAI97(@JZ`E<Z"[+@!#86YA9&$`06YN=6QE<@!!;FYU;&5R(&QE(')A
M<'!O<G0@9'4@<')O8FSH;64`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@
M9FEC:&EE<B"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@=')O=79E<B!U;B!RZ7!E
M<G1O:7)E('1E;7!O<F%I<F4`26UP;W-S:6)L92!D92!P<F]CZ61E<B!S86YS
M(&QE('!A<F%MZ'1R92"K('1A<F=E=$9I;&4@NP!);7!O<W-I8FQE(&1E('-U
M<'!R:6UE<B!L92!RZ7!E<G1O:7)E(*N@)7.@NRX`4W5P<')E<W-I;VX@:6UP
M;W-S:6)L92P@:6P@>2!A("5D(&5N<F5G:7-T<F5M96YT<R!F:6QS+@!);7!O
M<W-I8FQE(&1E('+I;W)D;VYN97(L(&QE(&YO;6)R92!D)^ELZ6UE;G1S(.`@
M<NEO<F1O;FYE<B!N92!C;W)R97-P;VYD('!A<R!A=2!N;VUB<F4@9"?I;.EM
M96YT<R!E;G)E9VES='+I<RX`3F4@<&5U="!D:7)I9V5R(&QE(&UE<W-A9V4@
M=F5R<R!L92!N;VUB<F4@<W#I8VEF:>DN`$-A<"U697)T`$SI9V5N9&4`5')A
M;G-P;W)T975R`$-A=.EG;W)I97,@970@R71I<75E='1E<P#.;&5S($-A[VUA
M;@!4Z6SI<&AO;F4@8V5L;'5L86ER90!0<F]P<FGI=.ES(&1E(&QA(&-E;&QU
M;&4`4F5M<&QI<W-A9V4@875T;W5R(&1E(&QA(&-E;&QU;&6@.@!0<F]P<FGI
M=.ES(&1E(&QA(&-E;&QU;&4`17-P86-E;65N="!D92!L82!C96QL=6QEH#H`
M5.ELZ7!H;VYE(&-E;&QU;&%I<F4@`$-E;'1E("A)4T\M.#@U.2TQ-"D`0V5N
M=')E<@!2Z7!U8FQI<75E(&-E;G1R869R:6-A:6YE`$5U<F]PZ65N(&-E;G1R
M86P@*$E33RTX.#4Y+3(I`$3I=&%I;',@9'4@8V5R=&EF:6-A=`!0<F]P<FGI
M=&%I<F4@9'4@8V5R=&EF:6-A=`!0;VQI=&EQ=64@9&4@8V5R=&EF:6-A=&EO
M;@!48VAA9`!-;V1I9FEE<@!-;V1I9FEE<B!V;W1R92!M;W0@9&4@<&%S<V4`
M0VAA;F=E<B!L92!N;VTL(&PG861R97-S92!E="!L82!S:6=N871U<F4@<75E
M(&QE<R!P97)S;VYN97,@=F]I96YT('%U86YD(&5L;&5S(&QI<V5N="!E="!R
MZ7!O;F1E;G0@X"!V;W,@;65S<V%G97,N`$QA(&UO9&EF:6-A=&EO;B!D92!V
M;W1R92!M;W0@9&4@<&%S<V4@;B=E<W0@<&%S('-U<'!O<G3I92!A=F5C(&QA
M(&-O;F9I9W5R871I;VX@86-T=65L;&4N($-O;G1A8W1E>B!V;W1R92!A9&UI
M;FES=')A=&5U<BX`0VAA<@!6Z5]R:69I97(@;&4@;&EE;@!#:&EL:0!#:&EN
M90!#:&EN;VES('-I;7!L:69IZ2`H1T(R,S$R*0!#:&EN;VES('1R861I=&EO
M;FYE;"`H0FEG-2D`0VAO:7-I<B!L)V%P<&QI8V%T:6]NH#H`0VAO:7-I<B!U
M;B!M;W0@9&4@<&%S<V4`0VAO:7-I<B!U;B!N;VT@9&4@8V]N;F5X:6]N`$-H
M;VES:7(@;&4@;6]D92!D)V%F9FEC:&%G92!D97,@9&%T97.@.@!#:&]I<VER
M(&QE('-T>6QE(&1E(&QI<W1E("AP;W5R(&QE<R!L:7-T97,@;G5MZ7)I<75E
M<RD`SFQE<R!#:')I<W1M87,`1.EF:6YI=&EO;B!D92!L82!C;&%S<V4@9&4@
M)7,@;F]N('1R;W5VZ64N`$5F9F%C97(`3F5T=&]Y97(@;&5S(&)A;&ES97,@
M35,M3V9F:6-E`$5F9F%C97(@;&$@<F5Q=>IT90!2971I<F5R(&PG=71I;&ES
M871E=7(Z("5S`$5F9F%C97(@;"=U=&EL:7-A=&5U<@!%9F9A8V5R(&QE<R!D
M;VYNZ65S(&1E(&PG=71I;&ES871E=7(`R6-L86ER8VEE<R!T87)D(&1A;G,@
M;&$@:F]U<F[I90!#;&EQ=65R('!O=7(@<&]U<G-U:79R90!#;&EC:V%T96QL
M('9I82!(5%10`$9E<FUE<B!L82!F96[J=')E`$YU86=E<P!.=6%G97,@;6%T
M:6YA=7@`3G5A9V5U>`#.;&5S($-O8V]S`%)E<&QI97(@;&$@8F%R<F4@9&4@
M8_1TZ0!2Z61U:7)E(&QE<R!B;W)D<P!#;VQO;6)I90!#;W5L975R`%!A;&5T
M=&4@9&4@8V]U;&5U<G,`4^EL96-T:6]N(&0G=6YE(&-O=6QE=7(`0V]L<Z`Z
M`%1I=')E<R!D92!C;VQO;FYE`$(N1"X`0V]M;6%N9&4`0V]M;6%N9&4@<VAE
M;&P`0V]M;65N=&%I<F4`3F]M('5S=65L`$-O;6]R97,`4V]C:>ETZ0!/<F1I
M;F%T975R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!$:69FZ7)E;F-E<R!D92!C
M;VYF:6=U<F%T:6]N`%-Y;F-H<F]N:7-A=&EO;B!D97,@87-S:7-T86YT<R!P
M97)S;VYN96QS+"`\23YS;6%R='!H;VYE<SPO23X@970@3W5T;&]O:RX`3&$@
M8V]N9FEG=7)A=&EO;B!N)V5S="!P87,@X"!J;W5R+@!#;VYF:6=U<F5R("5S
M`$-O;F9I<FUE<B!L92!M;W0@9&4@<&%S<V4`0V]N9V\`4NEP=6)L:7%U92!D
MZ6UO8W)A=&EQ=64@9'4@0V]N9V\`R6-H96,@9&4@;&$@8V]N;F5X:6]N`,EC
M:&5C(&1E(&QA(&-O;FYE>&EO;J`Z(`!#;VYN97AI;VX@874@<V5R=F5U<B!D
M92!C;&5F<R!P=6)L:6,@<F5F=7/I92X`0V]N;F5X:6]N(&%U('-E<G9E=7(@
M9&4@8VQE9G,@<'5B;&EC(')E9G5SZ64N(%)A:7-O;J`Z("`E<R`H)7,I`,EC
M:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R($944`!#;VYT86-T<P!#
M97,@8V]N=&%C=',@;VYT(&)I96X@Z73I(&%J;W5TZ7,@X"!V;W1R92!C87)N
M970@9"=A9')E<W-E<RX`5'EP92!D92!C;VYT96YU(&1U(&9I8VAI97(@8V]M
M<')E<W/IH#H@`$-O;G1E;G4@9&4@JZ`E<Z"[`%!O=7)S=6EV<F4`SFQE<R!#
M;V]K`%3I;6]I;B`H8V]O:VEE*0!#;W!I97(`R6-H96,@9&4@;&$@8V]P:66@
M.B`E<P!3Z6QE8W1I;VX@9"=U;F4@8V]P:64`260N(&-O^W0`0V]S=&$@4FEC
M80!#]'1E(&0G279O:7)E`$EM<&]S<VEB;&4@9&4@8VAI9F9R97(@;&4@;65S
M<V%G9:`Z(`!3:6=N871U<F4@4$=0(&1U(&UE<W-A9V4@:6UP;W-S:6)L9:`Z
M(`!);7!O<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE<W-A9V4@879E8R!3+TU)
M344N`%-I9VYA='5R92!3+TU)344@9'4@;65S<V%G92!I;7!O<W-I8FQE+@!!
M:F]U="!D=2!C;VYT86-T("5S(&EM<&]S<VEB;&4N(`!.92!P975T('-E(&-O
M;FYE8W1E<B!A=2!S97)V975R($Q$05`N`%;I<FEF:6-A=&EO;B!D92!L82!B
M86QA;F-E("5S(&EM<&]S<VEB;&4N(`#)8VAE8R!D92!L82!C;VYN97AI;VX@
M874@<V5R=F5U<B!,1$%0+@#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R
M=F5U<B"KH"5SH+L@=FEA($944*`Z("5S`$-RZ6%T:6]N(&1E(&QI<W1E(&1E
M(&1I<W1R:6)U=&EO;B!I;7!O<W-I8FQE+B`E<P!);7!O<W-I8FQE(&1E(&3I
M8VAI9F9R97(@;&5S(&1O;F[I97,@4$=0H#H@`$EM<&]S<VEB;&4@9&4@9.EC
M:&EF9G)E<B!L97,@9&]N;NEE<R!3+TU)344N`$YE('!E=70@<&%S('-U<'!R
M:6UE<B!L92!C;VYT86-T("5S`$YE('!E=70@<&%S('-U<'!R:6UE<B!L82!L
M:7-T92!D92!D:7-T<FEB=71I;VX@)7,`3F4@<&5U="!P87,@<W5P<')I;65R
M(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B"KH"5SH+LN`$3I=&5R;6EN871I
M;VX@9&4@;"=A9')E<W-E(&1U(&1E<W1I;F%T86ER92!I;7!O<W-I8FQE+@!.
M92!P975T('+I8W5PZ7)E<B!T;W5T(&QE(&-A<FYE="!D)V%D<F5S<V4N`$YE
M('!E=70@<NEC=7#I<F5R('1O=71E(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO
M;BX`3B=A('!A<R!P=2!RZ6-U<.ER97(@;&$@;&ES=&4@8V]M<&SH=&4@9&4@
M;&ES=&5S(&1E(&1I<W1R:6)U=&EO;BX`26UP;W-S:6)L92!D92!C:&%R9V5R
M(&QA('-T<F%TZ6=I92"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I97(@;&4@
M<NEP97)T;VER92"KH"5SH+LN`$EM<&]S<VEB;&4@9"=O8G1E;FER(&QA(&-L
M968@<'5B;&EQ=64@X"!P87)T:7(@9'4@<V5R=F5U<B!D92!C;&5F<RX`3W5V
M97)T=7)E(&1E(*N@)7.@NR!I;7!O<W-I8FQE(&5N(.EC<FET=7)E+@!/=79E
M<G1U<F4@9&4@)7,@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D)V]U=G)I<B!L
M92!M;V1U;&4@36%I;G1E;F%N8V5?5&%S:R`E<P!/=79E<G1U<F4@9'4@9&]S
M<VEE<B"KH"5SH+L@:6UP;W-S:6)L92X`26UP;W-S:6)L92!D)V%T=&5I;F1R
M92!L92!S97)V975R($Q$05`N`$QE8W1U<F4@9&4@)7,@:6UP;W-S:6)L92X@
M`$XG82!P=2!R96UE='1R92#@('KI<F\@;&4@;6]T(&1E('!A<W-E('!O=7(@
M;"=U=&EL:7-A=&5U<B!D96UA;F3I+B!#97)T86EN<R`H;W4@=&]U<RD@;&5S
M(&3I=&%I;',@;F4@<V]N="!P87,@8V]R<F5C=',N(%+I97-S87EE>B!O=2!C
M;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(@<&]U<B!D92!L)V%I9&4N
M`%+I8W5PZ7)A=&EO;B!D97,@04-,(&EM<&]S<VEB;&4`3F4@<&5U="!RZ6-U
M<.ER97(@;&4@8V%R;F5T(&0G861R97-S97,N("5S`$YE('!E=70@<NEC=7#I
M<F5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@)7,`3F4@<&5U="!RZ6-U
M<.ER97(@;&5S(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN("5S`$YE('!E=70@
M<NEC=7#I<F5R(&QE<R!P;W-S:6)I;&ETZ7,@9'4@<V5R=F5U<@!.92!P975T
M('!A<R!R979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E+@!%
M9F9A8V5M96YT(&1U(&1O<W-I97(@JZ`E<Z"[(&EM<&]S<VEB;&4N(`!.92!P
M975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N("5S`$YE('!E
M=70@<&%S(&5N<F5G:7-T<F5R('5N92!S875V96=A<F1E(&1E(&QA(&-O;F9I
M9W5R871I;VXN`$EM<&]S<VEB;&4@9"=E;G)E9VES=')E<B!U;F4@8V]P:64@
M9&4@;&$@8V]N9FEG=7)A=&EO;J`Z("5S`$EM<&]S<VEB;&4@9"=E;G)E9VES
M=')E<B!L92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@9&%N<Z`Z(*N@)7.@NRX`
M26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R('5N92!C;W!I92!D=2!F:6-H:65R
M(&1E(&-O;F9I9W5R871I;VX@)7,N`$EM<&]S<VEB;&4@9"=E;G)E9VES=')E
M<B!L92!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N(%9O=7,@<&]U=F5Z
M('-O:70@=71I;&ES97(@=6YE(&1E<R!O<'1I;VYS('!O=7(@<V%U=F5R(&QE
M(&-O9&4@<W5R("5S('-O:70@8V]P:65R(&UA;G5E;&QE;65N="!L92!C;V1E
M(&-I+61E<W-O=7,@9&%N<R`E<RX`3F4@<&5U="!P87,@<F5C:&5R8VAE<B!L
M92!S97)V975R($Q$05`N`%-U<'!R97-S:6]N(&1E(*N@)7.@NR!I;7!O<W-I
M8FQE+@!-:7-E(.`@:F]U<B!D=2!C;VYT86-T(&EM<&]S<VEB;&4N("5S`$YE
M('!E=70@;65T=')E(.`@:F]U<B!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN
M("5S`$YE('!E=70@<&%S(&5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I;VX@
M<&]U<B"KH"5SH+N@.B`E<P!.92!P975T('1R;W5V97(@;&$@8F%R<F4@9&4@
M36]Z:6QL82X@($%S<W5R97HM=F]U<R!Q=2=E;&QE(&5S="!A8W1I=F4N`$YE
M('!E=70@871T<FEB=65R(&-E<R!D<F]I=',@X"!L)W5T:6QI<V%T975R(*N@
M)7.@NR`@<W5R(&QE(&1O<W-I97(@JZ`E<Z"[H#H@)7,`5&5X=&4@8V]M<'3I
M`%!A>7,`0V]U<G,`0W+I97(`0W+I97(@=6X@;&EE;@!#<NEE<B!U;B!N;W5V
M96%U`$-RZ65R('5N('-O=7,M9&]S<VEE<@!097)M:7-S:6]N<R!$92!#<NEA
M=&5U<@!.=6WI<F\@9&4@8V%R=&4@9&4@8W+I9&ET`$-R;V%T:64`0W5B80`T
M('!H87-E<R!C;W5R86YT97,`4V5S<VEO;G,@96X@8V]U<G,`2&5U<F4@86-T
M=65L;&4`3"=A9')E<W-E(%523"!A8W1U96QL92!E<W0`571I;&ES871E=7)S
M(&%C='5E;',`3V)S97)V871I;VYS(&%C='5E;&QE<P!#;VYD:71I;VX@86-T
M=65L;&6@.B``4W1Y;&4@8V]U<F%N=`!$Z69I;FER(&QE<R!TXF-H97,@X"!E
M9F9E8W1U97(@;&]R<R!D92!L82!C;VYN97AI;VX@X"`E<RX`0V]U<&5R`$-O
M=7!E<B!L82!SZ6QE8W1I;VX`0VAY<')E`$-Y<FEL;&EQ=64@*$M/23@M4BD`
M0WER:6QL:7%U92`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI<75E+U5K<F%I;FEE
M;B`H2T])."U5*0!2Z7!U8FQI<75E(%1C:.AQ=64`2DH`1%-.("A#9BX@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*0!#:&%Q=64@:F]U<@!.879I9V%T975R(&1E($1A
M=&%4<F5E`$%L:6%S(&1E(&QA(&)A<V4`1&%T90!$871E(&1E('+I8V5P=&EO
M;@!3Z6QE8W1I;VX@9"=U;F4@9&%T90!*;W5R`%-U<'!R:6UE<B!?;&$@8V]L
M;VYN90!$Z6-E;6)R90!.;VUB<F5S(&3I8VEM875X`$1I;6EN=65R(&PG:6YD
M96YT871I;VX`1.EF875T`$-O=6QE=7(@<&%R(&3I9F%U=`!)9&5N=&ETZ2!P
M87(@9.EF875T`$EN=&5R<'+I=&5U<B!D92!C;VUM86YD92!P87(@9.EF875T
M`$3I9FEN:71I;VYS`$5F9F%C97(`169F86-E<B!L82!C96QL=6QE`%-U<'!R
M:6UE<B!U;B!G<F]U<&4`169F86-E<B!L82!T<F%C90!3=7!P<FEM97(@=6YE
M('!E<FUI<W-I;VX`4W5P<')I;65R(&5T('!U<F=E<B!L97,@;65S<V%G97,`
M169F86-E<B!L82!C96QL=6QE`$5F9F%C97(@;&$@8V]L;VYN90!3=7!P<FEM
M97(@=6X@875T<F4@;6]DZ&QE(&5X:7-T86YT`%-U<'!R:6UE<B!L97,@;65S
M<V%G97,`4W5P<')I;65R(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NP#*
M=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER(&5F9F%C97(@JZ`E<Z"[(&5T
M('-E<R!S;W5S+7!E<FUI<W-I;VYSH#\`169F86-E<B!L82!R86YGZ64`4W5P
M<')I;65R(&PG:61E;G1I=.D@<^EL96-T:6]N;NEE`%-U<'!R:6UE<B!U;B!S
M;W5S+61O<W-I97(`169F86-E<B!L82!C;VQO;FYE(&%C='5E;&QE`$5F9F%C
M97(@;&$@<F%N9^EE(&%C='5E;&QE`%-C<FEP="!D92!C;VYF:6=U<F%T:6]N
M(&1E(&UI<V4@X"!J;W5R('-U<'!R:6WI(*N@)7.@NRX`2&5U<F4@9&4@;&EV
M<F%I<V]N`$1A;F5M87)K`$3I8W)I<F4@;&4@<')O8FSH;64`1&5S8W)I<'1I
M;VX`1.ET86EL<R`H875S<VD@9&%N<R!L92!F:6-H:65R(&1E('1R86-E<R!D
M92!(;W)D92F@.@!,97,@9.ET86EL<R!O;G0@Z73I(&-O;G-I9V[I<R!P;W5R
M(&PG861M:6YI<W1R871E=7(N`$3I=F5L;W!P96UE;G0`4&]I;G0@9&4@<F]S
MZ64`4&]I;G0@9&4@<F]SZ64@<&]U<B!L82!D97)N:>AR92!H975R9:`Z(`!0
M;VEN="!D92!R;W/I9:`Z(`!$92!G875C:&4@X"!D<F]I=&4`1&4@9')O:71E
M(.`@9V%U8VAE`%+I<&5R=&]I<F4`069F:6-H97(@<W5R(#(T(&AE=7)E<Z`_
M`$]P=&EO;G,@9"=A9F9I8VAA9V4`069F:6-H97(@;&$@<'+I=FES:6]N(&3I
M=&%I;&SI90!!9F9I8VAE<B!L82!P<NEV:7-I;VX@*%1!1BD`1F]R;6%T(&0G
M869F:6-H86=E`$%V:7,@9&4@;&EV<F%I<V]N`$1J:6)O=71I`$YE('!A<R!S
M=7!P<FEM97(`3F4@<&%S(&%C8^ED97(@9&ER96-T96UE;G0@X"!M86EN=&5N
M86YC92YP:'``3&4@<')E;6EE<B!E;G)E9VES=')E;65N="!C;VYT:65N="UI
M;"!L92!N;VT@9&5S(&-H86UP<Z`_($1A;G,@;"=A9F9I<FUA=&EV92P@8V]C
M:&5Z(&-E='1E(&)O[G1EH#H`1&]M:6YI<75E`%+I<'5B;&EQ=64@9&]M:6YI
M8V%I;F4`5F]U<R!N)V%V97H@<&%S(&1E(&-O;7!T9:`_($5N<F5G:7-T<F5Z
M+79O=7,N`%3I;.EC:&%R9V5R`%3I;.EC:&%R9V5R("5S`%3I;.EC:&%R9V5R
M(&QA(&-O;F9I9W5R871I;VX@9^ENZ7+I92!C;VUM92!U;B!S8W)I<'0@4$A0
M`$QI<W1E(&3I<F]U;&%N=&4`1')O9W5E<P!#;W5R<FEE<B#I;&5C=')O;FEQ
M=64`4&EL;W1E(&1E('!A<W-E<F5L;&4@8V]U<G)I97(@+R!335,L('!O=7(@
M;&5S(&9O=7)N:7-S975R<R!D92!C92!S97)V:6-E+@!%4E(`R7%U871E=7(`
M36]D:69I97(`R61I=&5R(&QE(&)L;V,`R61I=&5R('5N(&=R;W5P90#)9&ET
M97(@=6YE('!E<FUI<W-I;VX`R61I=&5R(&QE<R!P97)M:7-S:6]N<P#)9&ET
M97(@;&5S('!E<FUI<W-I;VYS('!O=7(@JZ`E<Z"[`,ED:71E<B!L97,@;W!T
M:6]N<R!P;W5RH#H`R61I=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@
MNP#)9&ET97(@;&5S('!E<FUI<W-I;VYS('!O=7(@)7,`R61U8V%T:6]N`,EG
M>7!T90!386QV861O<@#);.EM96YT+BXN`$5M`$%D<F5S<V4@Z6QE8W1R;VYI
M<75E`$%D<F5S<V4@Z6QE8W1R;VYI<75E`$QE<R!A9')E<W-E<R#I;&5C=')O
M;FEQ=65S(&1O:79E;G0@8V]R<F5S<&]N9')E+@!#;W5R<FEE<B!A=F5C(&-O
M;F9I<FUA=&EO;@!087-S97)E;&QE(&-O=7)R:65R("\@4TU3`,EM;W1I8_1N
M97,`365S<V%G92!V:61E+@!2Z7-U;'1A="!V:61E+@!497)M97,@9&4@<F5C
M:&5R8VAE('9I9&4`06-T:79E<B!L)VEN<V5R=&EO;B!D)VEM86=E<R!V96YA
M;G0@9&5S(&%L8G5M<R!P:&]T;W,@9&%N<R!L92!T97AT9:`_`$%C=&EV97(@
M;&4@;65N=2!C;VYT97AT=65L(&%V96,@=6X@8VQI8R!D<F]I=*`_`$9I;B!D
M92!L)V%N;NEE`$%G<F%N9&ER(&PGZ61I=&5U<@#)8W)I=F5Z('5N92!Q=65S
M=&EO;B!D92!SZ6-U<FETZ2!Q=2=O;B!V;W5S('!O<V5R82!S:2!V;W5S(&1E
M=F5Z(')E;65T=')E(.`@>NER;R!V;W1R92!M;W0@9&4@<&%S<V4L('!A<B!E
M>&5M<&QE(*L@475E;"!E<W0@;&4@;F]M(&1E('9O=')E(&%N:6UA;"!P<NEF
MZ7+IH#^@NZ`Z`$EN<V-R:79E>B!L)V%D<F5S<V4@55),(&1E(&PG:6UA9V4@
M:6-I`$5N=')E>B!L97,@;&5T=')E<R!C:2UD97-S;W5SH#H`1W5I;NEE(.EQ
M=6%T;W)I86QE`,ER>71H<NEE`$5R<F5U<@!%<G)E=7(@;&]R<R!D92!L82!C
M<NEA=&EO;B!D=2!B;&]CH#H@)7,`17)R975R(&QO<G,@9&4@;&$@<W5P<')E
M<W-I;VX@9&4@;"=A;F-R92!D92!S>6YC:')O;FES871I;VZ@.B`E<P!%<G)E
M=7(@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D=2!J;W5R;F%L(&1E('-Y;F-H
M<F]N:7-A=&EO;J`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA('+I8W5PZ7)A=&EO
M;B!D=2!C;VYT96YUH#H@)7,`17)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO
M=7(@9'4@;6]T(&1E('!A<W-EH#H@)7,`17)R975R(&%V96,@;&4@;65S<V%G
M92X`17)R975R(&QO<G,@9&4@;"=E;G)E9VES=')E;65N="!D92"KH"5SH+LN
M`$5S=&]N:64`R71H:6]P:64`171H;FEQ=64`175R;W!E`%1O=7,@;&5S("9F
M<F%C,30[(&0G:&5U<F4`5&]U=&5S(&QE<R`R(&UI;G5T97,`5&]U=&5S(&QE
M<R`S,"!S96-O;F1E<P!4;W5T97,@;&5S(#4@;6EN=71E<P#`(&-H87%U92!C
M;VYN97AI;VX`5&]U=&5S(&QE<R`F9G)A8S$R.R!H975R97,`5&]U=&5S(&QE
M<R!M:6YU=&5S`$5X96UP;&4@9&4@=F%L975R<Z`Z`$5XZ6-U=&5R`$3I=F5L
M;W!P97(`1.EP;&EE<B!L82!B87)R92!D92!C]'3I`*L@*2"[(&%T=&5N9'5E
M`%5N('-E=6P@;6]T(&]U(&5X<')E<W-I;VX@96YT<F4@9W5I;&QE;65T<R!A
M='1E;F1U<P!$871E(&0G97AP:7)A=&EO;@!297!RZ7-E;G1A;G0`0V]U;&5U
M<B!D)V%V86YT+7!L86X`5.ELZ6-H87)G96UE;G0@=F5R<R!L92!S97)V975R
M(&1E(&QA(&-O;F9I9W5R871I;VX@<&%R($944`!,96-T=7)E(&1E<R!P<NEF
MZ7)E;F-E<R!I;7!O<W-I8FQE+@#)8VAE8R!D92!L82!C;VYN97AI;VX@874@
M<V5R=F5U<B!,1$%0+@#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U
M<B!334(N`,EC:&5C(&1E(&QA(&-O<&EE(&1E<'5I<R"KH"5SH+LN`,EC:&5C
M(&1E(&QA(&-O<&EE('9E<G,@(*N@)7.@NRX`26UP;W-S:6)L92!D92!C<NEE
M<B!U;F4@;F]U=F5L;&4@8V]N;F5X:6]N(%-!4TP`R6-H96,@9'4@9.EP;&%C
M96UE;G0@=F5R<R"KH"5SH+LN`,EC:&5C(&QO<G,@9&4@;&$@<NEC=7#I<F%T
M:6]NH#H@)7,`0F5A=0#.;&5S($9A;&ML86YD("A-86QO=6EN97,I`,YL97,@
M1NER;^D`17)R975R(&9A=&%L9:`Z`$9A>`!4Z6SI8V]P:65S`$;I=G)I97(`
M5&5M<.ER871U<F4@<F5S<V5N=&EE`%1E;7#I<F%T=7)E(')E<W-E;G1I9:`Z
M(`!1=65L<75E<R!A=F5R<V5S`%%U96QQ=65S(&-H=71E<R!D92!N96EG90!-
M871R:6-E(&1E<R!C:&%M<',`1FEG;&5T($-!4%1#2$$`4&]L:6-E(&1E(&QA
M(#Q)/F9I9VQE=#PO23X`1FED:FD`1FEC:&EE<@!.;VUB<F4@9&4@9FEC:&EE
M<G.@.B`E<P!.;VUB<F4@9&4@9FEC:&EE<G.@.B`E<P!'97-T:6]N;F%I<F4@
M9&4@9FEC:&EE<G,`3F]M(&1U(&9I8VAI97(`0VAO:7@@9&4@9FEC:&EE<@!4
MZ6SI8VAA<F=E;65N="!D92!F:6-H:65R`$PG96YV;VD@9&4@9FEC:&EE<G,@
M;B=E<W0@<&%S('!R:7,@96X@8V]M<'1E+@!&:6QT<F5S`$9I;FQA;F1E`%!R
M96UIZ')E(&1E;6EE`%!R96UI97(@<75A<G1I97(`1FEX97(@;&4@<F%T:6\`
M4F5T;W5R;F5R`$9L;W1T86YT`$)R;W5I;&QA<F0`1&]S<VEE<B`E<R!I;F5X
M:7-T86YT+@!#;W5L975R(&1E('!O;&EC90!.;W5R<FET=7)E`%!O=7(@;&5S
M(&YA=FEG871E=7)S(&YE('-U<'!O<G1A;G0@<&%S(&QE<R!I;6%G97,`4'+I
M=FES:6]N("A4048I`$IO=7)S(&1E('!RZ79I<VEO;B`H;F]T97H@<75E(&QE
M<R!P<NEV:7-I;VYS(&9O=7)N:65S(&1O;FYE;G0@;&4@:F]U<B!E="!L82!N
M=6ETH#L@=6X@9W)A;F0@;F]M8G)E(&EC:2!P975T(&9A:7)E('5N(&)L;V,@
M='+H<R!L87)G90!6;W5S(&%V97H@;W5B;&GI('9O=')E(&UO="!D92!P87-S
M9:`_`$9O<FUU;&%I<F5S`$-I=&%T:6]N`%1Y<&4@9&4@8VET871I;VX`0VET
M871I;VYS`$-I=&%T:6]N<R`R`$9O<G5M<P!2961I<F5C=&EO;@!690!#861R
M97,`1G)A;F-E`$9R86YC92!MZ71R;W!O;&ET86EN90!'=7EA;F4@9G)A;N=A
M:7-E`%!O;'ENZ7-I92!F<F%NYV%I<V4`5&5R<F5S(&%U<W1R86QE<R!E="!A
M;G1A<F-T:7%U97,@9G)A;N=A:7-E<P!$90!$=2``1&5S8W)I<'1I;VX@8V]M
M<&SH=&4`4&QE:6YE(&QU;F4`3F]M(&-O;7!L970`1V%B;VX`06QB=6T@9"=O
M<FEG:6YE(&1E(&PG:6UA9V4`06QB=6V@.@!'86UB:64`1^ENZ7)E<B!L82!C
M;VYF:6=U<F%T:6]N(&1E("5S`$-O9&4@9^ENZ7+I`$?I;W)G:64`06QL96UA
M9VYE`$=H86YA`$=I8G)A;'1A<@!0<NEN;VT`3W!T:6]N<R!G;&]B86QE<P!!
M;&QE<@!';V5D96P`0V%R=&5S($=O;V=L90!296-H97)C:&4@1V]O9VQE`$YI
M=F5A=2!D92!G<FES`$=RZ&-E`$=R96,@*$E33RTX.#4Y+3<I`$=R;^MN;&%N
M9`!'<F5N861E`$%D;6EN:7-T<F%T:6]N(&1E<R!G<F]U<&5S`$QE<R!N;VUS
M(&1E(&=R;W5P92!N92!P975V96YT('!A<R#J=')E('9I9&5S`$=R;W5P7VQD
M87"@.B!I;7!O<W-I8FQE(&0G86IO=71E<B!L92!G<F]U<&4@)7,N($-E8VD@
M97-T(&QA('+I<&]N<V4@9'4@<V5R=F5U<J`Z`$=R;W5P7VQD87"@.B!S=7!P
M<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&=R;W5P92`E<P!'<F]U<%]L9&%PH#H@
M;6]D:69I8V%T:6]N(&EM<&]S<VEB;&4@9'4@9W)O=7!E("5S`$=R;W5P97,`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;F5S97D`4&5R;6ES<VEO
M;G,@9&5S(&EN=FETZ7,`3&EV<F4@9"=O<@!'=6ENZ64`1W5I;NEE+4)I<W-A
M=0!'=7EA;F$`2%1-3`!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P
M<')I;65R(&QA(&1E<FYIZ')E(&-E;&QU;&4@9&4@;&$@<F%N9^EE`$A434Q!
M<F5A(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@
M8V]L;VYN92!D=2!T86)L96%U`$A434Q!<F5A(')E9G5S92!BZG1E;65N="!D
M92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@<F%N9^EE(&1U('1A8FQE874`075T
M:&5N=&EF:6-A=&EO;B!(5%10(&YO;B!T<F]U=NEE+@!(8>]T:0!!;&=O<FET
M:&UE(&1E(&AA8VAA9V4`0G)U;64@<^AC:&4`16XM=.IT90!%;BUTZG1E<P#.
M;&5S($AE87)D(&5T($UC1&]N86QD`$]R86=E<R!V:6]L96YT<P!(Z6)R974@
M*$E33RTX.#4Y+3@M22D`2&%U=&5U<@!!:61E`$%I9&4@<&]U<B!L)^ED:71E
M=7(`06ED90!(Z6UI<W!HZ')E`%9O:6-I(&QE(&3I8G5T(&1U(&9I8VAI97*@
M.@!(875T90!!7V-C=65I;`!#:73I(&1U(%9A=&EC86X`06-C=65I;`!!9')E
M<W-E('!E<G-O;FYE;&QE`%+I<&5R=&]I<F4@<&5R<V]N;F5L`%3I;.EP:&]N
M92!P97)S;VYN96P`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO
M;&%BH#H@9&]N;NEE<R!834P@)7,@:6YV86QI9&5S(')E=')O=7;I97,@9&%N
M<R!L92!M97-S86=E("5S`$AO<F1E+TMO;&%BH#H@875C=6X@;65S<V%G92!N
M92!C;W)R97-P;VYD(&%U('-U:F5T("5S`$AO<F1E+TMO;&%BH#H@<&%S(&0G
M;V)J970@9&4@='EP92`E<R!T<F]U=ND@9&%N<R!L92!M97-S86=E("5S`$AO
M<F1E+TMO;&%BH#H@)7,@<W5P<')I;>D@JZ`E<Z"[(&%V96,@<W5C8^AS`$AO
M<F1E+TMO;&%BH#H@;&4@;6]T975R(&0G:6YTZ6=R871I;VX@;NEC97-S:71E
M(&PG97AT96YS:6]N("=D;VUX;6PG(&1E(%!(4`!(;W)D92]+;VQA8J`Z(&EM
M<&]S<VEB;&4@9&4@8W+I97(@=6X@;F]U=F5L(&%R8G)E(%A-3"!P;W5R(&PG
M;V)J970@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&0G96YL979E<B`E
M<R"KH"5SH+N@.B`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<NEC
M=7#I<F5R(&PG:61E;G1I9FEA;G0@34E-12!P;W5R(&QA('!A<G1I92!D92!T
M>7!E("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D92!S>6YC:')O;FES
M97(@)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E
M('-Y;F-H<F]N:7-E<B!L97,@<&%R=&%G97.@.B`E<P!(;W)D92]+;VQA8J`Z
M('!A<G1A9V4@:6YC;VYN=2"KH"5SH+L`3&EG;F4@:&]R:7IO;G1A;&4`4F5M
M<&QI<W-A9V4@:&]R:7IO;G1A;`!(;W)I>F]N=&%LH#H`0V]M;65N="#J=&5S
M+79O=7,@87)R:7;I(&EC::`_("A35E`@<F%P<&]R=&5Z+6QEH"$I`$-O;6)I
M96X@9&4@8V]L;VYN97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5RH#\`0V]M8FEE
M;B!D92!C:&%M<',@*&-O;&]N;F5S*2!Y(&$M="UI;*`_`$-O;6)I96X@9&4@
M<F%N9^EE<R!V;W5L97HM=F]U<R!F=7-I;VYN97*@/P!(=6UI9&ETZ0!(=6UI
M9&ETZ:`Z(`!(=6UO<FES=&5S`$AO;F=R:64`R6-H96,@;&]R<R!D92!L82!C
M<NEA=&EO;B!D92!L82!B;^YT92!)34%0H#H@)7,`R6-H96,@;&]R<R!D92!L
M82!S=7!P<F5S<VEO;B!D92!L82!B;^YT92!)34%0H#H@)7,`R6-H96,@;&]R
M<R!D92!L82!C<NEA=&EO;B!D=2!Q=6]T82!S=7(@;&$@8F_N=&4@24U!4*`Z
M("5S`$%D<F5S<V4@25``061R97-S92!)4"!N;VX@9&ES<&]N:6)L92X`061R
M97-S92!)4"!H;W)S(&1U(&)L;V,@0TE$4B!A;&QO=>DN`%9I;VQA=&EO;B!D
M92!B;&]C86=E($E0+@!)7VYSZ7)E<B!R86YGZ64@879A;G0`27-L86YD90!)
M8_1N97,@<V5U;&5M96YT`$EC]&YE<R!P;W5R("5S`$EC]&YE<R!P;'5S('1E
M>'1E`$YO;2!D=2!C;VUP=&6@.@!3:2!L)V%F9FEC:&%G92!N)V5S="!P87,@
M8V]R<F5C="P@)7,@<&]U<B!L)V]U=G)I<B!D86YS('5N92!N;W5V96QL92!F
M96[J=')E+@!3:2!V;W5S(&YE('9O>65Z(&%U8W5N(&EC]&YE(&5N('5T:6QI
M<V%N="!);G1E<FYE="!%>'!L;W)E<BP@=F]U<R!P;W5V97H@879O:7(@X"!C
M;V-H97(@8V5T=&4@8V%S92!P;W5R(&3I<V%C=&EV97(@;&$@=')A;G-P87)E
M;F-E(&1E<R!03D<N`%-I('9O=7,@=F]Y97H@8V4@;65S<V%G92!M86ES(&%U
M8W5N92!I;6%G92P@;"=I;6%G92!Q=64@=F]U<R!V;W5L97H@96YV;WEE<B!N
M92!P975T(.IT<F4@869F:6-HZ64@<&%R('9O=')E(&YA=FEG871E=7(N`$%P
M97+G=2!D92!L)VEM86=EH#H`061R97-S92!54DP@9&4@;"=I;6%G90!!9')E
M<W-E(%523"!D92!L)VEM86=EH#H`26UA9V4@9&4@;"=A;&)U;0!);6%G92!D
M92!L)V%L8G5MH#H`5.ELZ6-H87)G96UE;G0@9"=I;6%G97,`26UA9V5S`$EM
M<&]R=&%T:6]N+"#I=&%P92`E9`!#:&%M<"!I;7!O<G3IH#H@)7,`0VAA;7!S
M(&EM<&]R=.ESH#H`26Y?<^ER97(@<F%N9^EE(&%P<NAS`$-O9&4@9"=A8W1I
M;VX@:6YC;W)R96-T+@!.;VT@9"=U=&EL:7-A=&5U<B!E="]O=2!V;W1R92!M
M;W0@9&4@<&%S<V4@:6YC;W)R96-T+@!.;VT@9"=U=&EL:7-A=&5U<B!O=2!A
M9')E<W-E(&%L=&5R;F%T:79E(&EN8V]R<F5C="X@(%+I97-S87EE>B!O=2!C
M;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(@<WES=.AM92!P;W5R(&1E
M(&PG86ED92X`075G;65N=&5R(&PG:6YD96YT871I;VX`26YD90!5=&EL:7-A
M=&5U<G,@:6YD:79I9'5E;',`26YD;V[I<VEE`$EN9F\`26YF;W)M871I;VYS
M`$PG:6YF;W)M871I;VX@;B=E<W0@<&QU<R!D:7-P;VYI8FQE+@!);G/I<F5R
M(&-?;VQO;FYE(&%P<NAS`$EN<^ER97(@:6UA9V4`26YSZ7)E<B!U;B!T86)L
M96%U`$EN<^ER97(@=6X@;&EE;B!W96(`26YSZ7)E<B!?8V]L;VYN92!A=F%N
M=`!);G/I<F5R('5N92!N;W5V96QL92!C;VQO;FYE(&%P<NAS(&QA(&-O;&]N
M;F4@86-T=65L;&4`26YSZ7)E<B!U;F4@;F]U=F5L;&4@8V]L;VYN92!A=F%N
M="!L82!C;VQO;FYE(&%C='5E;&QE`$EN<^ER97(@=6YE(&YO=79E;&QE(')A
M;F?I92!A<'+H<R!L82!R86YGZ64@86-T=65L;&4`26YSZ7)E<B!U;F4@;F]U
M=F5L;&4@<F%N9^EE(&%V86YT(&QA(')A;F?I92!A8W1U96QL90!);G/I<F5R
M('5N('!A<F%G<F%P:&4@87!RZ',@;&4@;B9O96QI9SMU9"!A8W1U96P`26YS
MZ7)E<B!U;B!P87)A9W)A<&AE(&%V86YT(&QE(&XF;V5L:6<[=60@86-T=65L
M`$EN<^ER97(@=6X@875T<F4@;6]DZ&QE`$EN<V-R:79E>B!U;F4@861R97-S
M92!D92!C;W5R<FEE<B#@(&QA<75E;&QE('9O=7,@<F5C979R97H@;&4@;F]U
M=F5A=2!M;W0@9&4@<&%S<V6@.@!);G/I<F5R(&-E;&QU;&4@87!RZ',`26YS
MZ7)E<B!C96QL=6QE(&%V86YT`$EN<^ER97(@8V]L;VYN92!A<'+H<P!);G/I
M<F5R(&-O;&]N;F4@879A;G0`26YSZ7)E<B!L97,@;65S<V%G97,`26YSZ7)E
M<B!P87)A9W)A<&AE(&%P<NAS`$EN<^ER97(@<&%R86=R87!H92!A=F%N=`!)
M;G/I<F5R(')A;F?I92!A<'+H<P!);G/I<F5R(')A;F?I92!A=F%N=`!);G-C
M<FEV97H@;&$@<NEP;VYS92#@(&QA('%U97-T:6]N(&1E('/I8W5R:73IH#H`
M26YSZ7)E<B]-;V1I9FEE<B!U;F4@:6UA9V4`26YSZ7)E<B]-;V1I9FEE<B!U
M;B!L:65N('=E8@!#<NED:70@:6YS=69F:7-A;G0@<&]U<B!E;G9O>65R(.`@
M;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+@!#<NED:70@:6YS=69F:7-A;G0N
M`$5N=&EE<@!,:7-T92!C;VUP;.AT90!51$@@*%5S97(@1&%T82!(96%D97(I
M(&EN=F%L:61E`$1O;F[I92!:25`@:6YV86QI9&4N`$%P<&QI8V%T:6]N(&EN
M=F%L:61E+@!'<F]U<&4@240@:6YV86QI9&4N`$5N=F]I(&1E(&1O;F[I97,@
M:6YV86QI9&5S+@!!9')E<W-E(&1E(&1E<W1I;F%T:6]N(&EN=F%L:61E+@!&
M;W)M870@9&4@9FEC:&EE<B!I;G9A;&ED92X`0VQE9B!D92!L:6-E;F-E(&EN
M=F%L:61E+@!%;7!L86-E;65N="!I;F1I<77I(&EN=F%L:61E+@"K;7-G7W1Y
M<&6[(&EN=F%L:61E+@"K87!I7VEDNR!I;G9A;&ED92!O=2!M86YQ=6%N="X`
M4&%R86WH=')E<R!I;G9A;&ED97,@;W4@;6%N<75A;G1S+@!097)M:7-S:6]N
M(&EN=F%L:61E+@!)9"X@9&4@<&%R=&5N86ER92!I;G9A;&ED92X`0V]D92!D
M92!P<F]D=6ET(&EN=F%L:61E+@!0<F]T;V-O;&4@:6YV86QI9&4N`$1E<W1I
M;F%T86ER92!I;G9A;&ED9:`Z(*N@)7.@NP!/8FIE="!D92!P87)T86=E(&EN
M=F%L:61E`$%D<F5S<V4@<V]U<F-E(&EN=F%L:61E+@!$;VYNZ64@56YI8V]D
M92!I;G9A;&ED92X`26YV96YT86ER90!);G9E<G-E<B!L82!SZ6QE8W1I;VX`
M27)A;@!)<F%K`$ER;&%N9&4`SFQE(&1E($UA;@!496UPZG1E<R!I<V]LZ65S
M`$ES<F'K;`#);65T=&5U<@!)=&%L:7%U90!)=&%L:64`2F%M8>]Q=64`2F%N
M=FEE<@!*87!O;@!*87!O;F%I<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D
M86YI90!*=6EL;&5T`$IU:6X`2G5S=&EF:65R`$-E;G1R97(`2G5S=&EF:65R
M`$%L:6=N97(@X"!G875C:&4`06QI9VYE<B#@(&1R;VET90!+87IA:VAS=&%N
M`$=A<F1E<B!L)V]R:6=I;F%LH#\`2V5N>6$`3&4@<V5R=F5U<B!+97)B97)O
M<R!A(')E:F5TZ2!L)V%U=&AE;G1I9FEC871I;VXN`$3I8G5T86YT<R!D=2!N
M;WEA=0!#<NEA=&EO;B!D92!C;&5F`$5M<')E:6YT92!D92!L82!C;&5F`$QO
M;F=U975R(&1E(&QA(&-L968`5'EP92!D92!C;&5F`%5T:6QI<V%T:6]N(&1E
M(&QA(&-L968`3&$@8VQE9B!S92!T<F]U=F4@9.EJX"!S=7(@;&4@<V5R=F5U
M<B!D92!C;&5F<R!P=6)L:6,N`$5N9F%N=',`2VER:6)A=&D`0V]RZ64@9'4@
M3F]R9`!#;W+I92!D=2!3=60`0V]RZ65N("A%54,M2U(I`$MO=V7O=`!+:7)G
M:&EZ:7-T86X`4'+I7W-E;G1A=&EO;@!,86YG=64`3&%O<P!$97)N:>AR92!D
M96UI90!$97)N:>AR92!M;V1I9FEC871I;VX@9'4@;6]T(&1E('!A<W-E`$1E
M<FYI97(@<75A<G1I97(`1&5R;FGH<F4@;6ES92#@(&IO=7*@.@!$97)N:>AR
M92!C;VYN97AI;VZ@.B`E<P!$97)N:>AR92!C;VYN97AI;VZ@.B`E<R#@('!A
M<G1I<B!D92`E<P!$97)N:>AR92!C;VYN97AI;VZ@.B!J86UA:7,`3&5T=&]N
M:64`3&]I`%!RZ7-E;G1A=&EO;@!,86ES<V5R('9I9&4@<&]U<B!N92!P87,@
M879O:7(@9&4@8F]R9'5R90!,:6)A;@!'875C:&4`16YTZG1E(&=A=6-H90!6
M86QE=7)S(&1E(&=A=6-H90!,97-O=&AO`$YI=F5A=0!,:6+I<FEA`$QI8GEE
M`$QI96-H=&5N<W1E:6X`0G)U:6YE(&SI9^AR90!0;'5I92!LZ6?H<F4`4&QU
M:64@;.EGZ')E('3T="!D86YS(&QA(&IO=7)NZ64`4&QU:64@;.EGZ')E('1A
M<F0`079E<G-E<R!LZ6?H<F5S`%!L=6EE(&SI9^AR92!A=F5C('1O;FYE<G)E
M`$YE:6=E(&EN=&5R;6ET=&5N=&4`079E<G-E(&1E(&YE:6=E(&SI9^AR90!2
M:6UE<P!,:65N`$QE(&QI96X@<&]I;G1E('9E<G.@.@!,:64@;"=A9')E<W-E
M(&1E(&-O=7)R:65L(.`@;&$@<&%G92!D92!C;VUP;W-I=&EO;B!D=2!M97-S
M86=E(&5N(&PG869F:6-H86YT`$QI96YS`$)I<V-U:70@3&EN=7@`3&ES=&4@
M+2!U=&EL:7-A=&5U<B!P975T('9O:7(@;&4@9&]S<VEE<@!,:7-T92!D97,@
M8F%S97,@9&4@9&]N;NEE<P!);F1E>"!D92!L)V%I9&4`069F:6-H97(@;&5S
M('1A8FQE<P!!<F-H:79E<R!D92!L82!L:7-T90!!:61E(&1E(&QA(&QI<W1E
M`$ED+B!D92!L82!L:7-T90!0<F]P<FGI=&%I<F4@9&4@;&$@;&ES=&4`16YV
M;VD@X"!L82!L:7-T90!!8F]N;F5M96YT(.`@;&$@;&ES=&4`1.ES86)O;FYE
M;65N="!D92!L82!L:7-T90#)8VAE8R!D92!L82!L:7-T92!D97,@<V5S<VEO
M;G.@.B`E<P#)8VAE8R!D92!L82!L:7-T92!D97,@=71I;&ES871E=7)SH#H@
M)7,`3"=A9F9I8VAA9V4@9&4@;&$@;&ES=&4@9&5S('5T:6QI<V%T975R<R!E
M<W0@9.ES86-T:7;I+@!,:71TZ7)A='5R90!,:71U86YI90!#:&%R9V5M96YT
M+BXN`$AE=7)E(&QO8V%L9:`Z(`!(975R92!E="!L;V-A;&4`3&EE=0!#;VYN
M97AI;VX`5')A8V4@9&4@;&$@9&5R;FGH<F4@<V5S<VEO;B!D92!S>6YC:')O
M;FES871I;VX`1.EC;VYN97AI;VX`0V]N;F5X:6]N`%3B8VAE<R!D92!C;VYN
M97AI;VX`3&$@8V]N;F5X:6]N(&5S="!R969U<^EE+B!);"!E<W0@<')O8F%B
M;&4@<75E('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&]U('9O=')E(&UO="!D
M92!P87-S92!A(.ETZ2!M86P@<V%I<VD`R6-H96,@9&4@8V]N;F5X:6]N+@!4
M97AT92!L;VYG`$%M;W5R`$9A:6)L90!,971T<F4@9W)E8W%U97,@;6EN=7-C
M=6QE<P!,971T<F4@;&%T:6YE<R!M:6YU<V-U;&5S`$YO;6)R92!R;VUA:6YS
M(&UI;G5S8W5L97,`3'5X96UB;W5R9P!-30!-97-S86=E(&1U(&IO=7(@*$U/
M5$0I`$QA('!IZ&-E(&IO:6YT92!-4RU43D5&(&YE(&-O;G1E;F%I="!A=6-U
M;F4@9&]N;NEE+@!-4T<`36%C86\`4NEP=6)L:7%U92!D92!-86/I9&]I;F4`
M36%D86=A<V-A<@!-86=I90!#;W5R<FEE<@!!9&UI;FES=')A=&EO;B!D=2!C
M;W5R<FEE;`!&86ER92!U;B!L:65?;@!-86QA=VD`36%L86ES:64`36%L9&EV
M97,`36%L:0!-86QT90!!9&UI;FES=')E>B!L82!L:7-T92!D92!C873I9V]R
M:65S(&5T(&QE<R!C;W5L975R<R!L:>EE<R#@(&-E<R!C873I9V]R:65S+@!#
M87)T92"K($UA<#(T(+L`0V%R=&4@JR!-87!Q=65S=""[`$-O<G)E<W!O;F1A
M;F-E<R!E;G)E9VES='+I97,N`$UA<G,`36%R9V4`36%R<75E<B!A=F5C(&1E
M<R#I=&EQ=65T=&5S(%9U+TYO;B!V=0!-87)Q=65R(&%V96,@9"=A=71R97,@
MZ71I<75E='1E<R`H97@N.B!);7!O<G1A;G0O4NEP;VYD=2D`SFQE<R!-87)S
M:&%L;`!-87)T:6YI<75E`$-H86UP<R!A<'!A<F5N=.ES`$UA=7)I=&%N:64`
MSFQE($UA=7)I8V4`0W+I9&ET(&UA>&EM=6T@86QL;W7I+@!,:6UI=&4@9'4@
M;65S<V%G92!DZ7!A<W/I92X`5&5M<.ER871U<F4@;6%X:6UA;&4@9&5S(#(T
M(&1E<FYIZ')E<R!H975R97.@.B``5&5M<.ER871U<F4@;6%X:6UA;&4@9&5S
M(#8@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!.;VUB<F4@;6%X:6UU;2!D92!B;&]C
M<R!D=2!P;W)T86EL`$QO;F=U975R(&UA>&EM=6T`36%I`$UA>6]T=&4`3>ED
M:6-A;65N=`!-96UB<F5S`%1Y<&4@9&4@;65N=:`Z`$9U<VEO;FYE<B!L97,@
M8V5L;'5L97,`365S<V%G90!6Z7)I9FEC871I;VX@9'4@;65S<V%G92!RZ75S
M<VEE+"!M86ES(&QE(&-E<G1I9FEC870@9'4@<VEG;F%T86ER92!N)V$@<&%S
M('!U(.IT<F4@=NER:69IZ2X`365S<V%G92!E>'!I<NDN`%1Y<&4@9&4@;65S
M<V%G90!-Z73I;R!-971A<@!,92!B;&]C(*L@365T87(@NR!N)V5S="!P87,@
M9&ES<&]N:6)L92X`3&4@8FQO8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I<W!O
M;FEB;&4N("!,97,@9.ET86EL<R!O;G0@Z73I(&-O;G-I9V[I<R!P;W5R(&PG
M861M:6YI<W1R871E=7(N`$UE=&%R1$(@;B=E<W0@<&%S(&-O;FYE8W3I+@!-
MZ71H;V1E`$QA(&WI=&AO9&4@JZ`E<Z"[(&XG97-T('!A<R!DZ69I;FEE`$WI
M=&AO9&4@;F]N(&3I9FEN:64N($WI=&AO9&4@87!P96SI9:`Z("5S`$WI=')I
M<75E`$UE>&EQ=64`R71A=',@9NEDZ7+I<R!D92!-:6-R;V[I<VEE`$UI;&EE
M=0!4>7!E($U)344`5&5M<.ER871U<F4@;6EN:6UU;2!D97,@,C0@9&5R;FGH
M<F5S(&AE=7)E<Z`Z(`!496UPZ7)A='5R92!M:6YI;75M(&1E<R`V(&1E<FYI
MZ')E<R!H975R97.@.B``3&$@9'5RZ64@;6EN:6UA;&4@9'4@;6]T(&1E('!A
M<W-E(&XG82!P87,@96YC;W)E(&5X<&ERZ0!-:7)O:7(`5F%R:>ES`$QE('!A
M<75E=&%G92!(5%107W)E<75E<W0@4$5!4B!E<W0@;6%N<75A;G0N`$-O;F9I
M9W5R871I;VX@:6YE>&ES=&%N=&4N(%9O=7,@9&5V97H@;&$@9^ENZ7)E<B!M
M86EN=&5N86YT('-I('9O=7,@=F]U;&5Z('5T:6QI<V5R(&-E='1E(&%P<&QI
M8V%T:6]N+@!)1"!D=2!M97-S86=E(&UA;G%U86YT+@!,92!P87%U971A9V4@
M4$5!4B!-86EL(&5S="!M86YQ=6%N="X`240@9&4@<V5S<VEO;B!M86YQ=6%N
M="X`3'4`0V]U<G)I96P@<V%N<R!F:6P`36]DZ7+I`$1A=&4@9&4@;6]D:69I
M8V%T:6]N`$UO9&EF:65R(&PG55),`$UO9'5L;P!-;VQD879I90!-;VYA8V\`
M36]N9V]L:64`36]I<R!E="!A;F[I90!-96YS=65L;&5M96YT`$UO;G1S97)R
M870`4&AA<V5S(&1E(&QA(&QU;F4`0VAA;7!S('-U<'!LZ6UE;G1A:7)E<R!T
M<F]U=NES(.`@;&$@;&EG;F4@)60@*&%T=&5N9'5S("5D*2X`36%R;V,`1^EN
MZ7)A;&5M96YT(&5N<V]L96EL;.D`1^ENZ7)A;&5M96YT(&YU86=E=7@`4')I
M;F-I<&%L96UE;G0@;G5A9V5U>"!E="!V96YT975X`$?I;NER86QE;65N="!E
M;G-O;&5I;&SI`%9E<G,@;&4@8F%S`$3I<&QA8V5R(.`@9V%U8VAE`$3I<&QA
M8V5R(.`@9')O:71E`%9E<G,@;&4@:&%U=`!697)S(&QE(&)A<P!697)S(&QE
M(&AA=70`36]Z86UB:7%U90!,:7-T97,@9.ER;W5L86YT97,@;75L=&DM;FEV
M96%U>`!#87)T92"KH$UU;'1I;6%P(%5+H+L`4^EL96-T:6]N(&UU;'1I<&QE
M`%!A<F%MZ71R86=E(&1U(&-O;7!T90!-97,@9&]N;NEE<R!P97)S;VYN96QL
M97,`36]N('!O<G1A:6P`4'+I<V5N=&%T:6]N(&1E(&UO;B!P;W)T86EL`$)I
M<FUA;FEE`$Y/3BP@:F4@;B=A8V-E<'1E('!A<P!.;VT`3F%M:6)I90!.875R
M=0!.Z7!A;`!087ES+4)A<P!!;G1I;&QE<R!NZ65R;&%N9&%I<V5S`%523"!D
M92!B87-E(&1E($YE='-C87!E`%523"!D92!RZ79O8V%T:6]N(&1E(&PG02Y#
M+B!.971S8V%P90!54DP@9&4@;&$@<&]L:71I<75E(&0G02Y#+B!.971S8V%P
M90!54DP@9&4@<F5N;W5V96QL96UE;G0@3F5T<V-A<&4`55),(&1E('+I=F]C
M871I;VX@3F5T<V-A<&4`3F]M(&1U('-E<G9E=7(@4U-,($YE='-C87!E`$-O
M;6UE;G1A:7)E(&1U(&-E<G1I9FEC870@3F5T<V-A<&4`5'EP92!D=2!C97)T
M:69I8V%T($YE='-C87!E`%+I<V5A=0!*86UA:7,`3F]U=F5L;&4M0V%LZ61O
M;FEE`$YO=79E;&QE(&-A=.EG;W)I90!.;W5V96QL92!L=6YE`$YO=79E874@
M;F]M(&1E(&-O;FYE>&EO;B`H9F%C=6QT871I9BD`3F]U=F5L;&4M6NEL86YD
M90!.;W5V96%U(&UO="!D92!P87-S90!,92!N;W5V96%U(&UO="!D92!P87-S
M92!E>'!I<F5R82!L92`E>"X`3&5S(&YO=79E875X(&UO=',@9&4@<&%S<V4@
M9&EF9NAR96YT+@!.;W5V96QL92!F96[J=')E("A?8FQA;FLI`$YO=79E;&QE
M<P!&;W)U;7,`4W5I=F%N=``T('!H87-E<R!S=6EV86YT97,`3W!T:6]N<R!S
M=6EV86YT97,`4W5I=F%N=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3G5I
M=`!.:75E`$YO;@!087,@9&4@9&]N;NEE<R!D92!C;VYF:6=U<F%T:6]N('!O
M=7(@;&5S<75E;&QE<R!M;VYT<F5R(&QE<R!D:69FZ7)E;F-E<RX`4&%S(&1E
M('-T<F%TZ6=I92!D:7-P;VYI8FQE('!O=7(@9F%I<F4@9&5S(&EM86=E<R!)
M4T\N`%!A<R!D92!G86)A<FET(&5N('1R86ET96UE;G0@<&%R(&QO="X`075C
M=6X@8FQO8R!N)V5X:7-T92#@(&QA('!O<VET:6]N(&1E;6%N9.EE`%!A<R!D
M92!N;VT@9&4@8V%L96YD<FEE<B!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC
M871I;VX@<&%R($U#04PN`$YO;B!M;V1I9FGI+@!!=6-U;F4@<V]U<RUP97)M
M:7-S:6]N(&XG82!B97-O:6X@9"?J=')E(&%J;W5TZ64@<V]U<R!C92!N:79E
M874N`$%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N('-PZ6-I
M9FGI92!P;W5R("5S+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A
M=&EO;B!F;W5R;FEE('!O=7(@1E10(%9&4RX`075C=6YE(&EN9F]R;6%T:6]N
M(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R(%-13"!61E,N`$%U8W5N
M92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!3
M44PM1FEL92!61E,N`$%U8W5N(&-RZ61I="!D:7-P;VYI8FQE+@!!=6-U;F4@
M9&5S=&EN871I;VX@=')O=7;I92X`075C=6X@9FEC:&EE<B!E;G9O>>D`075C
M=6X@:6/T;F4@=')O=7;I+@!!=6-U;B!L:65U(&XG97-T('/I;&5C=&EO;F[I
M`$%U8W5N(&5M<&QA8V5M96YT(&XG97-T(&EN9&EQ=>DN`$%U8W5N(&UE<W-A
M9V4@9F]U<FYI`$%U8W5N(&YO;2!S<.EC:69IZ2X`075C=6X@;F]M8G)E('-P
MZ6-I9FGI+@!087,@9"=A<&AO<FES;65S(&-H;W%U86YT<P!!=6-U;B!M;W0@
M9&4@<&%S<V4@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!(
M5%10+@!!=6-U;B!M;W0@9&4@<&%S<V4@9F]U<FYI('!O=7(@;"=A=71H96YT
M:69I8V%T:6]N('!A<B!)34%0+@!!=6-U;B!M;W0@9&4@<&%S<V4@9F]U<FYI
M('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!+97)B97)O<RX`075C=6X@
M;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N
M+@!!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF:>D@<&]U<B!L)V%U=&AE;G1I
M9FEC871I;VX@4$%34U=$+@!!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF:>D@
M<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@4TU"+@!!=6-U;B!C:&5M:6X@=F5R
M<R!L92!B:6YA:7)E($]P96Y34TP@9F]U<FYI+B!,92!B:6YA:7)E(&0G3W!E
M;E-33"!E<W0@;NEC97-S86ER92!P;W5R(&9O;F-T:6]N;F5R(&%V96,@9&5S
M(&1O;F[I97,@4$M#4R`Q,BX`075C=6YE(&-O;F9I<FUA=&EO;B!E;B!A='1E
M;G1E`%!A<R!D92!Q=6]T82!P;W-I=&EO;F[I+@!087,@9&4@<NAG;&5S`$%U
M8W5N('/I<&%R871E=7(@<W#I8VEF:>DN`%!A<R!D92!C]'3I<P!&:6-H:65R
M(&EN97AI<W1A;G0`075C=6X@<NEP97)T;VER92!T96UP;W)A:7)E(&5S="!D
M:7-P;VYI8FQE('!O=7(@;&$@8V%C:&4`075C=6X@;F]M(&0G=71I;&ES871E
M=7(@970@+V]U(&UO="!D92!P87-S92!E;G9O>>DN`$%U8W5N92!D;VYNZ64@
M6$U,('9A;&ED92!N)V$@Z73I(')E=&]U<F[I90!087,@9&4@=F%L975R`%!A
M<R!D92!V97)S:6]N('1R;W5VZ64@9&%N<R!L82!C;VYF:6=U<F%T:6]N(&]R
M:6=I;F%L92X@4NEGZ6[I<F5Z(&QA(&-O;F9I9W5R871I;VXN`%!A<R!D92!V
M97)S:6]N('1R;W5VZ64@9&%N<R!V;W1R92!C;VYF:6=U<F%T:6]N+B!2Z6?I
M;NER97H@;&$@8V]N9FEG=7)A=&EO;BX`075C=6X`075C=6X@*'5T:6QI<V5R
M(&EM<&QI8VET96UE;G0I`$YO<F1I<75E("A)4T\M.#@U.2TQ,"D`SFQE($YO
M<F9O;&L`2.EM:7-P:.AR92!.;W)D`,YL97,@36%R:6%N;F5S(&1U(&YO<F0`
M3F]R=NAG90!087,@87!RZ',`4&%S(&%V86YT`%!A<R!U;B!D;W-S:65R`$YO
M;B!I;7!LZ6UE;G3I+@!);F%C=&EF`$YO;B!P<FES(&5N(&-O;7!T92X`3F]T
M97,`4FEE;B#@(&YA=FEG=65R+"!R971O=7)N97H@96X@87)R:>AR92X`3F]V
M96UB<F4`3F]M8G)E`$YO;6)R92!D92!C87)A8W3H<F5S`$YO;6)R92!D92!C
M;VQO;FYE<P!.;VUB<F4@9&4@<F%N9^EE<P!.;VUB<F4@;F]N('-PZ6-I9FGI
M('!O=7(@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES=&4@9&4@9&ES=')I8G5T
M:6]N+@!/2P!/8FIE=`!#<NEA=&5U<B!D)V]B:F5T`$]C=&%L`$]C=&]B<F4`
M1FEL=')E(&%N=&DM;V9F96YS86YT`$)U<F5A=0!,)V%N8VEE;B!E="!L92!N
M;W5V96%U(&UO=',@9&4@<&%S<V4@9&]I=F5N="#J=')E(&1I9F;I<F5N=',N
M`$%N8VEE;B!M;W0@9&4@<&%S<V4`3"=A;F-I96X@;6]T(&1E('!A<W-E(&5S
M="!I;F-O<G)E8W0`3VUA;@!3975L(&QE<R!S97)V975R<R!)34%0('-U<'!O
M<G1E;G0@;&5S(&1O<W-I97)S('!A<G1A9^ES+@!3975L96UE;G0@;&5S(*N@
M9F]R='5N97.@NR!O9F9E;G-A;G1E<P!5;F4@<V5U;&4@861R97-S92!D92!C
M;W5R<FEE;"!P97)M:7-E+@!3975L<R!L92!P<F]P<FGI=&%I<F4@;W4@;"=A
M9&UI;FES=')A=&5U<B!S>7-TZ&UE('!E=70@;6]D:69I97(@;&5S('!E<FUI
M<W-I;VYS(&0G=6X@<&%R=&%G92X`3W5V<FER(&1A;G,@=6YE(&YO=79E;&QE
M(&9E;NIT<F4`17)R975R($]P96Y34TR@.B!I;7!O<W-I8FQE(&0G97AT<F%I
M<F4@;&5S(&1O;F[I97,@9&4@;&$@<&%R=&EE('-I9V[I92!3+TU)344`3W5V
M<FER(&QE<R!L:65N<R!D86YS('5N92!N;W5V96QL92!F96[J=')E`%-Y<W3H
M;64@9"=E>'!L;VET871I;VX`3W!T:6]N<P!/<'1I;VYS('!O=7(@)7,`3&ES
M=&4@;G5MZ7)O=.EE`$]R9V%N:7-A=&EO;@!5;FETZ2!O<F=A;FES871I;VYN
M96QL90!/<F=A;FES871I;VX`36]DZ&QE(&]R:6=I;F%L(&0G87!P;&EC871I
M;VX`36]DZ&QE<R!O<FEG:6YA=7@@9&%N<R`E<Z`Z`$%U=')E`$%U=')E<R!I
M;F9O<FUA=&EO;G,`4&5R;6ES<VEO;G,@9'4@<')O<')IZ71A:7)E`$PG875T
M:&5N=&EF:6-A=&EO;B!004T@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`$UO9'5L
M92!014%2.CI-86EL`%-I9VYA='5R92!N=6WI<FEQ=64@4$=0`$1O;F[I97,@
M4$=0(&-H:69F<NEE<P!#;&5F('!U8FQI<75E(%!'4`!$;VYNZ65S(%!'4"!S
M:6=NZ65S+V-H:69F<NEE<P!#;V1E(%!(4`!);G1E<G!RZ71E=7(@4$A0`%!L
M=6EE(&SI9^AR92!L)V%P<NAS+6UI9&D`4&QU:64@;"=A<'+H<RUM:61I`$%V
M97)S97,@;"=A<'+H<RUM:61I`$YE:6=E(&PG87!RZ',M;6ED:0!#:'5T97,@
M9&4@;F5I9V4@;"=A<'+H<RUM:61I`%-O;&5I;"!L)V%P<NAS+6UI9&D`3W)A
M9V5S(&PG87!RZ',M;6ED:0!%>'1E;G-I;VX@4$]325@@86)S96YT90!);G1E
M<G!RZ71E=7(@4%](4`!296UP;&ES<V%G90!086MI<W1A;@!"96QA=0!086QE
M<W1I;F4@*'1E<G)I=&]I<F4@;V-C=7#I*0!086YA;6$`4&%P;W5A<VEE+4YO
M=79E;&QE+4=U:6[I90!087)A9W5A>0!087)T:65L;&5M96YT(&YU86=E=7@`
M36]T(&1E('!A<W-E`$-H86YG96UE;G0@9'4@;6]T(&1E('!A<W-E(&5F9F5C
M='7I+@!-;W0@9&4@<&%S<V4@:6YC;W)R96-T`$UO="!D92!P87-S92!R97%U
M:7,@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@4D%$2553+@!-;W0@9&4@<&%S
M<V4@879E8R!C;VYF:7)M871I;VX`36]T(&1E('!A<W-EH#H`36]T(&1E('!A
M<W-EH#H@`$QE<R!M;W1S(&1E('!A<W-E(&1O:79E;G0@ZG1R92!I9&5N=&EQ
M=65S+@!#;VQL97(`0V]L;&5R(&1E<'5I<R!L92!P<F5S<V4M<&%P:65R<P!#
M:&5M:6X`0V]N9FER;6%T:6]N<R!E;B!A='1E;G1EH#H`4&5R<V]N;F5S`%!O
M=7)C96YT86=E`$5F9F5C='5E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N
M86YC90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4@
MX"!L82!C;VYN97AI;VZ@/P!097)M:7-S:6]N`$QA('!E<FUI<W-I;VX@JZ`E
M<Z"[(&XG97-T('!A<R!S=7!P<FEMZ64N`%!E<FUI<W-I;VX@<F5F=7/I90!0
M97)M:7-S:6]N<P!!9&UI;FES=')A=&EO;B!D97,@<&5R;6ES<VEO;G,`1&]N
M;NEE<R!P97)S;VYN96QL97,`4.ER;W4`06YI;6%U>`!0:&EL:7!P:6YE<P!4
MZ6SI<&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%-6
M4"!C;&EQ=65Z(&1A;G,@=6YE(&-E;&QU;&4`4U90(&-O;F9I<FUE>B!L82!S
M=7!P<F5S<VEO;B!D92!C970@Z6SI;65N=*`Z`%-64"!C;VYF:7)M97H@<75E
M('9O=7,@=F]U;&5Z(&3I;&EE<B!C970@Z6SI;65N="X`5F5U:6QL97H@<V%I
M<VER('5N(&UO:7,@970@=6YE(&%N;NEE+@!6975I;&QE>B!S86ES:7(@=6X@
M;F]M('!O=7(@;&$@;F]U=F5L;&4@8V%TZ6=O<FEEH#H`5F5U:6QL97H@96YT
M<F5R('5N92!A9')E<W-E($E0('9A;&ED92X`5F5U:6QL97H@96YT<F5R('5N
M92!D871E('9A;&ED9:`[(';I<FEF:65Z(&QE(&YO;6)R92!D92!J;W5R<R!D
M=2!M;VES+B``5F5U:6QL97H@96YT<F5R('5N92!H975R92!V86QI9&4N`%9E
M=6EL;&5Z(&9O=7)N:7(@=6X@<NES=6WI(&1U('!R;V)LZ&UE+@!6975I;&QE
M>B!F;W5R;FER('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&5T('9O=')E(&UO
M="!D92!P87-S90!6975I;&QE>B!L:7)E(&QE('1E>'1E('-U:79A;G0N(%9O
M=7,@9&5V97H@86-C97!T97(@;&5S(&-O;F1I=&EO;G,@<&]U<B!U=&EL:7-E
M<B!L92!S>7-TZ&UE+@!6975I;&QE>B!E;G1R97(@;&4@;F]U=F5A=2!N;VV@
M9&4@;&$@8V%TZ6=O<FEEH#H`4&]L;V=N90!0;VQI=&EQ=64`4V-R=71I;G,`
M4&]R='5G86P`4&]S:71I;VX@9&4@8V5T=&4@:6UA9V4`4&]S:71I;VX@9&4@
M8V4@=&%B;&5A=0!%;G9O>65R(.`@8V4@9&]S<VEE<B`H;F]N(&%P<&QI<77I
M('!A<B!)34%0*0!0<NEC:7!I=&%T:6]N<R!P;W5R(&QE<R`E<R!D97)N:>AR
M97,@:&5U<F5SH#H@`%!R;V)A8FEL:73I/&)R("\^9&4@<&QU:64`4')E9G-?
M;&1A<*`Z(&5X=&5N<VEO;B!R97%U:7-E($Q$05`@;F]N('1R;W5VZ64N`%!R
M969S7W-E<W-I;VZ@.B!E>'1E;G-I;VX@<F5Q=6ES92"KH'-E<W-I;VZ@NR!N
M;VX@=')O=7;I92X`4')E<W-I;VX`4')E<W-I;VX@874@;FEV96%U(&1E(&QA
M(&UE<J`Z(`!0<F5S<VEO;J`Z(`!!<&5RYW4`07!E<N=U(&1E(&PG:6UA9V4@
M9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R90!/<'1I;VYS('!RZ6/I9&5N=&5S
M`$EM<')I;65R(&QE(&1O8W5M96YT`$-L968@<')I=NEE`%!R;V)LZ&UE`$1E
M<V-R:7!T:6]N(&1U('!R;V)LZ&UE`%!R;VIE=',`5&5X=&4@8V]U<G0`0VQE
M9B!P=6)L:7%U90!!;&=O<FET:&UE(&1E(&-L968@<'5B;&EQ=64`26YF;W)M
M871I;VYS('-U<B!L82!C;&5F('!U8FQI<75E`,EC:&5C(&1E(&QA(&?I;NER
M871I;VX@9&4@;&$@<&%I<F4@9&4@8VQE9G,@<'5B;&EQ=64O<')I=NEE+@!0
M;W)T;R!2:6-O`%!U<F=E<B!L97,@;65S<V%G97,`46%T87(`4F5Q=>IT90!1
M=6]T80!#;&5F('!U8FQI<75E(%)302`H)60@8FET<RD`4^EL96-T:6]N(')A
M9&EO`%!L=6EE`%!L=6EE('3T="!L92!M871I;@!0;'5I92!T87)D(&1A;G,@
M;&$@:F]U<F[I90!!=F5R<V5S`%!L=6EE(&5T(&YE:6=E`%!L=6EE('!U:7,@
M;F5I9V4`07!H;W)I<VUE(&%U(&AA<V%R9`!4875X`$QI<F4`365S<V%G97,@
M;'5S`%-U<'!R97-S:6]N(&3I9FEN:71I=F4@9&4@)7.@/P!3=7!P<F5S<VEO
M;B!DZ69I;FET:79E(&1E<R!D;VYNZ65S('!O=7(@;"=U=&EL:7-A=&5U<B`E
M<Z`_($-E='1E(&]PZ7)A=&EO;B!E<W0@9.EF:6YI=&EV92X`4F5P<F5N9')E
M('9O=')E(&1E<FYIZ')E(&%C=&EO;@!2869R8>YC:&ER`%)A9G)A[F-H:7(@
M;&5S(.ELZ6UE;G1S(&1U(&UE;G4@9'EN86UI<75EH#H`4F%F<F'N8VAI<B!L
M)^EC<F%N(&1U('-O;6UA:7)EH#H`17AP<F5S<VEO;B!R871I;VYN96QL90!.
M879I9V%T975R(')E;&%T:6]N;F5L`%)E8VAA<F=E<@!296UA<G%U97,`4V5R
M=F5U<G,@9&ES=&%N=',`55),(&1I<W1A;G1E("AH='1P.B\O=W=W+F5X96UP
M;&4N8V]M+VAO<F1E+RF@.@!2971I<F5R`%)E=&ER97(@;&4@8FQO8P!2971I
M<F5R(&QA(&-O;&]N;F4`4F5T:7)E<B!L92!F;W)M871A9V4`4F5T:7)E<B!L
M82!P86ER90!%;FQE=F5R(&QE('-C<FEP="!E;G)E9VES='+I(&1U('+I<&5R
M=&]I<F4@=&5M<&]R86ER92!D=2!S97)V975R+@!2971I<F5R(&QE`%)E=&ER
M97(@8V4@;F]E=60@9'4@9&]C=6UE;G0`4F5T:7)E<B!L)W5T:6QI<V%T975R
M`%)E=&ER97(@;"=U=&EL:7-A=&5U<J`Z("5S`$%U8W5N92!RZ7!O;G-E(.`@
M=F]T<F4@<F5Q=>IT92X@0V]D92!D)V5R<F5U<B!R971O=7)NZ:`Z(`!,92!S
M97)V:6-E(&1E;6%N9.D@97-T(&EN=')O=79A8FQE+@!,92!P87)A;>AT<F4@
M;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA
M(&-O;F9I9W5R871I;VX@)7,N`$QE('!A<F%MZ'1R92!O8FQI9V%T;VER92"K
MH"5SH+L@;B=E<W0@<&%S('-PZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO
M;B!D=2!61E,N`$QE('!A<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@;B=E
M<W0@<&%S('-PZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO;BX`0VAA;7`@
M;V)L:6=A=&]I<F4`4L!:`%)E;6ES92#@('KI<F\@9'4@;6]T(&1E('!A<W-E
M`%)E;65T=')E(.`@>NER;R!V;W1R92!M;W0@9&4@<&%S<V4`4F5V96YI<B#@
M(&QA(&1E<FYIZ')E(')E<77J=&4`4NES=6QT871S`%)E=F5N:7(@875X(&]P
M=&EO;G,`4NDM96YT<F5R(&QE(&YO=79E874@;6]T(&1E('!A<W-E`%+I=6YI
M;VX`4F5V96YI<B#@(&QA(&-O;F9I9W5R871I;VX@<'+I8^ED96YT90!/<'1I
M;VYS(&1E(&PGZ61I=&5U<B!2:6-H(%1E>'0`1&5V:6YE='1E<P!$<F]I=&4`
M16YTZG1E(&1E(&1R;VET90!686QE=7)S(&-O<G)E8W1E<P!0<F]P<FGI=.ES
M(&1E(&QA(')A;E]GZ64@+BXN`%+T;&4`4F]U;6%N:64`4&EV;W1E<B`Q.#``
M4&EV;W1E<B#@(&=A=6-H90!0:79O=&5R(.`@9')O:71E`%!R;W!R:>ETZ7,@
M9&4@;&$@<F%N9^EE`%!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE`%)A;F?I97.@
M.@!2Z&=L97,`1&5S(&9I;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@=&]U=&5S
M(&QE<R!R86YGZ65S(&5T(&QE<R!C;VQO;FYE<P!$97,@9FEL971S(&%P<&%R
M8>YT<F]N="!E;G1R92!L97,@8V]L;VYN97,@<V5U;&5M96YT`$1E<R!F:6QE
M=',@87!P87)A[G1R;VYT(&5N=')E(&QE<R!R86YGZ65S('-E=6QE;65N=`!,
M86YC97(`4G5S<VEE`%)W86YD80!3:6=N871U<F4@Z6QE8W1R;VYI<75E(%,O
M34E-10!-97-S86=E(&-H:69F<ND@4R]-24U%`$PG875T:&5N=&EF:6-A=&EO
M;B!305-,(&XG97-T('!A<R!D:7-P;VYI8FQE`$UE<W-A9V5R:64@4TU3`$EN
M=&5R<'+I=&5U<B!344P`3W)D<F4@4U%,('!O=7(@<F5T;W5R;F5R(&QE<R!V
M86QE=7)S`%-32`!354-#R%,`26YT97)P<NET975R(%-?44P`4V$`4V%I;G1E
M+4CI;.AN90!386EN="U#:')I<W1O<&AE+65T+4YIZ7;H<P!386EN=&4M3'5C
M:64`4V%I;G0M4&EE<G)E(&5T($UI<75E;&]N`%-A:6YT+59I;F-E;G0M970M
M;&5S($=R96YA9&EN97,`3>IM92!C861R92`H7W-E;&8I`%-A;6]A(&]C8VED
M96YT86QE<P!386EN="U-87)I;@!386\M5&]MZ2UE="U0<FEN8VEP90!&;W5R
M;FES<V5U<B!S871E;&QI=&4`07)A8FEE(%-A;W5D:71E`$5N<F5G:7-T<F5R
M`$5N<F5G:7-T<F5R(*N@)7.@NP!%;G)E9VES=')E<B`E<P!%;G)E9VES=')E
M<B!L97,@;W!T:6]N<P!%;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N(&?I
M;NERZ64@8V]M;64@=6X@<V-R:7!T(%!(4"!D86YS(&QE('+I<&5R=&]I<F4@
M=&5M<&]R86ER92!D92!V;W1R92!S97)V975R+@!%;G)E9VES=')E<B!L82!C
M;VYF:6=U<F%T:6]N(&1E("5S`%-C<FEP="!D92!M:7-E(.`@:F]U<B!D92!C
M;VYF:6=U<F%T:6]N(&5N<F5G:7-T<ND@<V]U<Z`Z(*L@)7.@NP!/<F%G97,@
M:7-O;.ES`%-C:65N8V4`4F5C:&5R8VAE`$UO=&5U<G,@9&4@<F5C:&5R8VAE
M`$-H;VES:7-S97H@;&5S(&9I8VAI97)S`%/I;&5C=&EO;FYE>B!U;F4@9&%T
M90!3Z6QE8W1I;VYN97H@=6X@9W)O=7!E(.`@86IO=71E<@!3Z6QE8W1I;VYN
M97H@=6X@;F]U=F5A=2!P<F]P<FGI=&%I<F4`4^EL96-T:6]N;F5Z('5N('-E
M<G9E=7(`4^EL96-T:6]N;F5Z('5N('5T:6QI<V%T975R(.`@86IO=71E<@!4
M;W5T('/I;&5C=&EO;FYE<@!3Z6QE8W1I;VYN97H@=&]U=&5S(&QE<R!C;VUP
M;W-A;G1E<R!D92!L82!D871E+@!#:&]I<VES<V5Z('5N(&]B:F5T`$YE('/I
M;&5C=&EO;FYE<B!A=6-U;@!3Z6QE8W1I;VYN97H@;&5S(&-A<F%C=.AR97,@
M9&]N="!V;W5S(&%V97H@8F5S;VEN(.`@;"=A:61E(&1E(&PG;W5T:6P@8VDM
M9&5S<V]U<RX@5F]U<R!P;W5V97H@96YS=6ET92!L97,@8V]P:65R(&5T(&QE
M<R!C;VQL97(@9&%N<R!V;W1R92!T97AT92X`4^EL96-T:6]N;F5Z(&QE(&3I
M;&EM:71E=7(@9&4@9&%T9:`Z`%/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@
M9&%T9:`Z`%/I;&5C=&EO;FYE<B!L92!P<F]F:6P@<75E('9O=7,@9.ES:7)E
M>B!M;V1I9FEE<CH`4^EL96-T:6]N;F5Z(&QE(&3I;&EM:71E=7(@9"=H975R
M9:`Z`%/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@;"=H975R9:`Z`%/I;&5C
M=&EO;FYE>B!D975X(&-H86UP<R!A<'!A<F5N=.ES+@!3Z6QE8W1I;VYN97H@
M=F]T<F4@=&CH;64@9&4@8V]U;&5U<G,N`%/I;&5C=&EO;FYE>B!V;W1R92!L
M86YG=64@<'+I9NERZ66@.@!%;G9O>65R(&QE(')A<'!O<G0@9"=A;F]M86QI
M90!%;G9O>65R(%--4P!3Z6[I9V%L`%-O;F1EH#H@`%-E<'1E;6)R90!397)B
M:64@970@36]N=&5N96=R;P!.=6WI<F\@9&4@<^ER:64`3&5S(&1O;F[I97,@
M9'4@<V5R=F5U<B!S;VYT(&9A=7-S97,@;W4@;F]N(&1I<W!O;FEB;&5S+@!!
M9&UI;FES=')A=&EO;B!D97,@<V5S<VEO;G,`260N(&1E('-E<W-I;VX@97AP
M:7+I+@!397-S:6]N<P!3Z6QE8W1I;VYN97(`0V]N9FEG=7)E<B!L97,@;W!T
M:6]N<R!P;W5R('9O=7,@<&5R;65T=')E(&1E(')E;65T=')E(.`@>NER;R!V
M;W1R92!M;W0@9&4@<&%S<V4@<VD@:F%M86ES('9O=7,@;"=O=6)L:65Z+@!#
M;VYF:6=U<F5R(&QE<R!S97)V975R<R!D:7-T86YT<R!A8V-E<W-I8FQE<R!D
M97!U:7,@=F]T<F4@<&]R=&%I;"X`4^EL96-T:6]N;F5Z('9O=')E(&QA;F=U
M92!P<NEFZ7+I92P@9G5S96%U(&AO<F%I<F4@970@;&5S(&]P=&EO;G,@9&4@
M9&%T92X`1.EF:6YI<W-E>B!L82!P<F5M:>AR92!A<'!L:6-A=&EO;B!L86YC
MZ64L(&QE('1HZ&UE(&1E(&-O=6QE=7)S+"!L92!R869R8>YC:&ES<V5M96YT
M(&1E<R!P86=E<RP@970@9"=A=71R97,@;W!T:6]N<R!D)V%F9FEC:&%G92X`
M0V]N9FEG=7)A=&EO;@!38W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E
M(.`@:F]U<B!D:7-P;VYI8FQE`%!L=7-I975R<R!E;F1R;VET<R!P;W-S:6)L
M97,@879E8R!L92!P87)A;>AT<F6@.B``4V5Y8VAE;&QE<P!!8VAA=`!2Z7-U
M;>D`1&]I="UO;B!DZ69I;FER(&1E<R!T;W5C:&5S(&1E(')A8V-O=7)C:7,@
M<&]U<B!L82!P;'5P87)T(&1E<R!L:65N<Z`_`$%F9FEC:&5R`$UO;G1R97(@
M;&5S(&1I9F;I<F5N8V5S(&5N=')E(&QA(&-O;F9I9W5R871I;VX@96YR96=I
M<W1RZ64@86-T=65L;&5M96YT(&5T(&-E;&QE(&YO=79E;&QE;65N="!GZ6[I
M<NEE+@!-;VYT<F5R(&PG:&5U<F4@9&4@;&$@9&5R;FGH<F4@8V]N;F5X:6]N
M(.`@;"=E;G1RZ66@/P!-;VYT<F5R(&PG;W!T:6]N(&1E(&-O;G-E<G9E<B!L
M)V]R:6=I;F%L`$UO;G1R97(@;&4@<^EL96-T975R`$%F9FEC:&5R(&QA(&)A
M<G)E(&1E(&UE;G4@9&4@=&%B;&5A=7B@/P!!9F9I8VAE<B!L92!M96YU("5S
M(.`@9V%U8VAEH#\`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@=&%B
M;&5A=2!C96QL=6QE`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E
M<R!P<F]P<FGI=.ES(&1U('1A8FQE874`069F:6-H97(@;&$@8F_N=&4@9&4@
M9&EA;&]G=64@9&5S('!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE(&1U('1A8FQE
M874`069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ET
MZ7,@9&4@;"=I;6%G90!!9F9I8VAE<B!L)V5N=F]I(&1E(&9I8VAI97(`079E
M<G-E<P!!=F5R<V5S('3T="!D86YS(&QA(&IO=7)NZ64`079E<G-E<R!T87)D
M(&5N(&IO=7)NZ64`079E<G-E<R!A=7@@86QE;G1O=7)S`%)E<W-E<G)E<@!2
M97-S97)R97(@;W4@9.EG86=E<B!D)V%B;W)D(&QE*',I(&)L;V,H<RD@=F]I
M<VEN*',I`%-I97)R82!,96]N90!3)VEN<V-R:7)E`%-I9VYA='5R90!!;&=O
M<FET:&UE(&1E('-I9VYA='5R90!3:6YG87!O=7(`5&%I;&QE`$%N;G5L97(@
M;&$@;6%I;G1E;F%N8V4`4VQO=F%Q=6EE`%-L;W;I;FEE`$YE:6=E`$%V97)S
M92!D92!N96EG90!!=F5R<V5S(&1E(&YE:6=E`$%V97)S97,@9&4@;F5I9V4@
M=/1T(&1A;G,@;&$@:F]U<F[I90!!=F5R<V5S(&1E(&YE:6=E('1A<F0@96X@
M:F]U<F[I90!(875T975R(&1E(&YE:6=EH#H@`%%U86YT:73I(&0G96%U(.EQ
M=6EV86QE;G1E(.`@;&$@<75A;G1I=.D@9&4@;F5I9V6@.B``SFQE<R!386QO
M;6]N`%-O;6%L:64`0VAA;G-O;G,@970@<&_H;65S`%/I;&5C=&EO;B!D92!L
M)V]R9')E(&1E('1R:0!!9')E<W-E('-O=7)C90!!9G)I<75E(&1U('-U9`!3
M=60M975R;W#I96X@*$E33RTX.#4Y+3,I`$?I;W)G:64M9'4M<W5D(&5T(.YL
M97,@4V%N9'=I8V@M9'4M<W5D`$CI;6ES<&CH<F4@4W5D`$5S<&%C92!E;G1R
M92!C96QL=6QE<R!A9&IA8V5N=&5S`$5S<&%C92!E;G1R92!L92!C;VYT96YU
M(&5T(&QA(&)O<F1U<F4@9&%N<R!U;F4@8V5L;'5L90!%<W!A8V5U<@!%<W!A
M8V5M96YT`$5S<&%C96UE;G0@970@<F5M<&QI<W-A9V4`17-P86=N90!0;W5R
M<FEE;`!#87)A8W3H<F5S('-PZ6-I875X`%-C:6YD97(@;&$@8V5L;'5L90!3
M8VEN9&5R(&QA(&-O;&]N;F4`4V-I;F1E<B!L82!R86YGZ64`4W!O<G1S`%-R
M:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`06YNZ64@9&4@9.EB=70`R71A
M="!O=2!P<F]V:6YC90!3=&%T=70`1F]R;6%T(&1E('-A=79E9V%R9&4`4G5E
M`$)A<G+I`$QI<W1E(&1E(&-H8>YN97,`4F5T:7)E<B!L92!D;VUA:6YE(&1E
M(&PG861R97-S90!3='EL92!;0U-370!$:0!3;W5S+7+I<&5R=&]I<F4@JZ`E
M<Z"[(&YO;B!T<F]U=ND`4W5J970`16YV;VD`3&$@9&5M86YD92!D)V%J;W5T
M(&1E(*N@)7.@NR!A=2!S>7-TZ&UE(&$@Z73I('-O=6UI<V4N(%9O=7,@;F4@
M<&]U<G)E>B!P87,@=F]U<R!C;VYN96-T97(@:G5S<74GX"!S;VX@87!P<F]B
M871I;VXN`$EN9&EC90!3=6-CZ',`JZ`E<Z"[(&$@8FEE;B#I=.D@86IO=73I
M*&4I+@!,97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R(*N@)7.@NR!O;G0@
M8FEE;B#I=.D@<F5T:7+I97,@9'4@<WES=.AM92XN`*N@)7.@NR!A(&)I96X@
MZ73I('-U<'!R:6WI*&4I+@"KH"5SH+L@82!B:65N(.ETZ2!R971I<NDH92DN
M`%)E=&]U<B#@(&QA(&-O;F9I9W5R871I;VX@:6YI=&EA;&4@<NEU<W-I+B`@
M4F%F<F'N8VAI<B!L82!P86=E('!O=7(@=F]I<B!L97,@;6]D:69I8V%T:6]N
M<RX`16YR96=I<W1R96UE;G0@9&4@;&$@8V]N9FEG=7)A=&EO;B!D92!L82!S
M875V96=A<F1E('+I=7-S:2X`16YR96=I<W1R96UE;G0@<NEU<W-I(&1E(&QA
M(&-O<&EE(&1E('-A=79E9V%R9&4@9'4@9FEC:&EE<B!D92!C;VYF:6=U<F%T
M:6]N("5S+@"KH"5SH+L@82!B:65N(.ETZ2!M:7,H92D@X"!J;W5R+@#)8W)I
M='5R92!D92`E<R!RZ75S<VD`4V]U9&%N`%-O;6UA:7)E`$QE=F5R(&1U(%-O
M;&5I;`!#;W5C:&5R(&1U(%-O;&5I;`!%;G-O;&5I;&SI`$QE=F5R(&1U(%-O
M;&5I;`!,979E<B]#;W5C:&5R(&1U(%-O;&5I;`!,979E<B!D=2!3;VQE:6PZ
M(`!#;W5C:&5R(&1U(%-O;&5I;`!#;W5C:&5R(&1U(%-O;&5I;*`Z(`!%>'!O
M<V%N=`!!<W-I<W1A;F-E`%-U<FEN86T@;W4@1W5Y86YE(&AO;&QA;F1A:7-E
M`$YO;2!D92!F86UI;&QE`,YL97,@4W9A;&)A<F0@970@2F%N($UA>65N`%-W
M87II;&%N9`!3=>AD90!3=6ES<V4`2F]U<FYA;"!D92!S>6YC:')O;FES871I
M;VX@<W5P<')I;>D`4WEN8TU,`$5R<F5U<B!D92!S>6YT87AE(&1A;G,@;&5S
M('1E<FUE<R!D92!R96-H97)C:&4`4WER:64`3W)A9V5S`$]R86=E(&5T('9E
M;G0`3W)A9V5S`$]R86=E<R!M871I;F%U>`!&:6-H:65R(%135@!0<F]P<FGI
M=.ES(&1U('1A8FQE874`5&%B;&5A=2!D92!V86QE=7)S`%!R;W!R:>ETZ7,@
M9'4@=&%B;&5A=0!48>]W86X`5&'O=V%N+"!P<F]V:6YC92!D92!#:&EN90!4
M86II:VES=&%N`%1A;GIA;FEE`$-I8FQEH#H`5.)C:&5S`$YU;>ER;R!D92!T
MZ6SI<&AO;F4`5&5M<.ER871U<F4@<&]U<B!L82!D97)N:>AR92!H975R9:`Z
M(`!496UPZ7)A='5R90!496UPZ7)A='5R9:`Z(`!496UPZ7)A='5R93QB<B`O
M/B@E<TAA)7,O)7-"825S*2`F9&5G.R5S`%!R;V9I;""KH"5SH+L@;F]N('1R
M;W5VZ0!!9&UI;FES=')A=&EO;B!D97,@;6]DZ&QE<P!497AT90!497AT92!S
M975L`$%L:6=N96UE;G0@9'4@=&5X=&4`5&5X=&4@96X@:&%U=`!*90!4:&'O
M("A425,M-C(P*0!4:&'O;&%N9&4`3"=E>'1E;G-I;VX@1E10(&XG97-T('!A
M<R!D:7-P;VYI8FQE+@!,)VAI<W1O<FES871I;VX@97-T(&3I<V%C=&EVZ64N
M`$QE(&UO=&5U<B!D)VEN=.EG<F%T:6]N($AO<F1E+TMO;&%B(&YE('-U<'!O
M<G1E('!A<R"KH"5SH+L`3&4@:F]U<FYA;"!)35-0(&XG82!P87,@<'4@ZG1R
M92!I;FET:6%L:7/I+@!,82!C;&%S<V4@36%I;G1E;F%N8V4Z.B!N)V$@<&%S
M(.ETZ2!C:&%R9^EE(&-O<G)E8W1E;65N=`!,82!F96[J=')E(&1E<R!O<'1I
M;VYS(',G97-T(&9E<FWI92X@4V]R=&EE+@!,)V%D;6EN:7-T<F%T975R(&1O
M:70@8V]N9FEG=7)E<B!U;B!B86-K96YD('!E<FUA;F5N="!P;W5R(&QE<R!P
M97)M:7-S:6]N<R!S:2!V;W5S('9O=6QE>B!L97,@96UP;&]Y97(N`$QA(&)O
M<F1U<F4@9'4@8F%S('-E=6QE;65N=`!,)TE$(&1U(&-O;G1A8W0@;B=A('!A
M<R#I=.D@<W#I8VEF:>DL(&QA:7-SZ2!V:61E(&]U(&XG82!P87,@Z73I('1R
M;W5VZ2!D86YS(&QA(&)A<V4@9&4@9&]N;NEE<RX`0V4@8V]N=&%C="!A(&)I
M96X@Z73I(&%J;W5TZ2#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+B``3&4@
M8FQO8R!D92!S:6=N871U<F4@4$=0('/I<&%RZ2!E<W0@;NEC97-S86ER92!P
M;W5R(';I<FEF:65R(&QA('-I9VYA='5R92X`3"=)1"!D92!L82!L:7-T92!N
M)V$@<&%S(.ETZ2!S<.EC:69IZ2P@;&%I<W/I('9I9&4@;W4@;F]N('1R;W5V
MZ2!D86YS(&QA(&)A<V4@9&4@9&]N;NEE<RX`3&$@;&ES=&4@9&4@9&ES=')I
M8G5T:6]N(&XG82!P87,@Z73I('-PZ6-I9FGI92X`3&4@8VAI9F9R96UE;G0@
M;NEC97-S:71E('5N92!C;VYN97AI;VX@<^EC=7)I<^EE+@!,92!F:6-H:65R
M("5S(&1O:70@8V]N=&5N:7(@;&5S(&]P=&EO;G,@)7,N`$QE(&9I8VAI97(@
M)7,@9&]I="!C;VYT96YI<B!C97)T86EN97,@;W!T:6]N<R`E<RX`3&4@9FEC
M:&EE<B!N92!P975T('!A<R#J=')E(&-O<&GI('-U<B!L=6DM;>IM92X`3&4@
M9FEC:&EE<B!N92!C;VYT96YA:70@875C=6YE(&1O;F[I92X`0V4@<75I('-U
M:70@<V]N="!L97,@96XM=.IT97,@<&]U<B!C92!M97-S86=E(&UE<W-A9V4O
M4D9#.#(R+@!,92!M;V1E('!L96EN(.EC<F%N(&-A=7-E(&1E<R!P<F]B;.AM
M97,@879E8R!);G1E<FYE="!%>'!L;W)E<B!D^R#@(&1E<R!B;V=U97,@9'4@
M;F%V:6=A=&5U<B!Q=6D@;B=O;G0@<'4@ZG1R92!C;VYT;W5R;NES+B!6;W5S
M('!O=79E>B#J=')E(&-O;F9R;VYTZ7,@X"!D92!L)V%F9FEC:&%G92!D92!C
M87)A8W3H<F5S(.ET<F%N9V5S+"!A=2!N;VXM9F]N8W1I;VYN96UE;G0@9&5S
M(&-E<G1A:6YE<R!F;VYC=&EO;G,@970O;W4@874@<&QA;G1A9V4@86SI871O
M:7)E(&1U(&YA=FEG871E=7(N(%-I('9O=')E('-Y<W3H;64@97-T('5N(%=I
M;F1O=W,@.7@L(&EL(&5S="!T<NAS('!O<W-I8FQE('%U92!V;W5S(&%U<F5Z
M('5N92`G1F%U=&4@9^ENZ7)A;&4@9&4@<')O=&5C=&EO;B<@970@<75E('9O
M=7,@9&5V<F5Z(')E9.EM87)R97(@=F]T<F4@;W)D:6YA=&5U<BY<;EQN5F]U
M<R!A=F5Z(.ETZ2!P<NEV96YU<RX@4U90(&%P<'5Y97H@<W5R($]+('-I('9O
M=7,@=F]U;&5Z('1O=6IO=7)S(&5S<V%Y97(@;&4@;6]D92!P;&5I;B#I8W)A
M;B!D92!L)^ED:71E=7(`3"=I9&5N=&ETZ2"KH"5SH+L@(&$@Z73I('-U<'!R
M:6WI92X`3&4@8_1TZ2!G875C:&4@<V5U;&5M96YT`$PG96UP;&%C96UE;G0@
M9'4@<')O9W)A;6UE($=N=5!'(&1O:70@ZG1R92!F;W5R;FD@X"!L82!C;&%S
M<V4@0W)Y<'1?<&=P.CHN`$QE(&UE<W-A9V4@96YV;WGI(&QE("5S(.`@)7,@
M879E8R!C;VUM92!S=6IE=""KH"5SH+L@82#I=.D@869F:6-HZ2X@"DEL(&XG
M>2!A(&%U8W5N92!G87)A;G1I92!Q=64@8V4@;65S<V%G92!A(.ETZ2!L=2!O
M=2!C;VUP<FES+@!,92!N;VT@X"!U=&EL:7-E<B!E;B!L:6%N="#@(&QA('!A
M9V4@9&4@8V]M<&]S:71I;VX`3&4@;F]M8G)E(&1E(&-H86UP<R!D;VET(.IT
M<F4@=6X@;F]M8G)E('9A;&ED92X`3&4@;6]D=6QE($]P96Y34TP@97-T(')E
M<75I<R!P;W5R(&QA(&-L87-S92!(;W)D95]#<GEP=%]S;6EM93HZ+@!,82!P
M<NEFZ7)E;F-E(*N@)7.@NR!N)V$@<&%S('!U(.IT<F4@96YR96=I<W1RZ64@
M8V%R('-A('1A:6QL92!DZ7!A<W-E(&QE(&UA>&EM=6T@875T;W)I<^D`3&4@
M<')O9W)A;6UE('5T:6QI<^D@<&]U<B!V:7-U86QI<V5R(&-E('1Y<&4@9&4@
M9&]N;NEE<R`H)7,I(&XG82!P87,@Z73I('1R;W5VZ2X`3&4@8V%R86-TZ')E
M(&1E('!R;W1E8W1I;VX@9&]I="#J=')E('5N(&-A<F%C=.AR92!U;FEQ=64N
M`$QE<R!C]'3I<R!G875C:&4@970@9')O:70@<V5U;&5M96YT`$QE(&/T=.D@
M9')O:70@<V5U;&5M96YT`$QE('/I<&%R871E=7(@9&]I="#J=')E('5N(&-A
M<F%C=.AR92!U;FEQ=64N`$QE('-E<G9E=7(@JZ`E<Z"[(&$@Z73I('-U<'!R
M:6WI+@!,92!S97)V975R(*N@)7.@NR!A(.ETZ2!E;G)E9VES='+I+@!,82!R
M97%UZG1E(&0G96YR96=I<W1R96UE;G0@<&]U<B`E<R!A(.ETZ2!DZ7!L86/I
M92X`3&$@;&EG;F4@9&5M86YDZ64@*"5D*2!N)V5X:7-T92!P87,N`$QE(&9I
M8VAI97(@=&5M<&]R86ER92"K("5SH+L@;B=E>&ES=&4@<&%S+@!,92!T97AT
M92!E;G1RZ2!N92!C;W)R97-P;VYD('!A<R!A=2!T97AT92!S=7(@;"?I8W)A
M;BX`3&4@:&%U="!E="!L92!B87,@<V5U;&5M96YT`$QE(&AA=70@<V5U;&5M
M96YT`$QE<R!D;VYNZ65S('3I;.EC:&%R9^EE<R!V97)S(&QE('-E<G9E=7(@
M;VYT(.ETZ2!P97)D=65S(&1E<'5I<R!L)^ET87!E('!RZ6/I9&5N=&4N(`!,
M92!F:6-H:65R(.EM:7,@;B=A('!A<R!P=2#J=')E(&5N<F5G:7-T<NDN`$QE
M(&)L;V,@JZ!W96%T:&5R+F-O;:"[(&XG97-T('!A<R!D:7-P;VYI8FQE+@!2
MZ7!E<G1O:7)E(&1E<R!T:.AM97,@JZ`E<Z"[(&YO;B!T<F]U=ND`26P@;B=Y
M(&$@<&%S(&0G;W!T:6]N<R!D:7-P;VYI8FQE<P!!=6-U;F4@<&%R=&EE(&YE
M('!E=70@ZG1R92!A9F9I8VCI92!E;B!L:6=N92X`26P@>2`@82!T<F]P(&1E
M(&-A<F%C=.AR97,@9&%N<R!C92!C:&%M<"X@5F]U<R!E;B!A=F5Z(&5N='+I
M("5SH#L@:6P@96X@9F%U="!M;VEN<R!D92`E<RX`56X@<')O8FSH;64@97-T
M(&%P<&%R=2!L;W)S(&1E(&PG86IO=70@9&4@JZ`E<Z"[H#H@)7,`56X@<')O
M8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E<R!D
M;VYNZ65S(&1E(&PG=71I;&ES871E=7(@JZ`E<Z"[H#H@`%5N('!R;V)LZ&UE
M(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D92"KH"5SH+N@
M.B``56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA(&UI<V4@X"!J
M;W5R(&1E(*N@)7.@NZ`Z("5S`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R
M<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!A=6-U;B`E<R!N)V$@Z73I('1R
M86YS;6ES+@!5;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S(&1E(&PG96YV
M;VD@9'4@9FEC:&EE<J`Z(&QE("5S(.ET86ET('!L=7,@9W)O<R!Q=64@;&4@
M;6%X:6UU;2!A=71O<FESZ2`H)60@;V-T971S*2X`56YE(&5R<F5U<B!E<W0@
M<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L92`E<R!A
M(.ETZ2!T<F%N<VUI<R!P87)T:65L;&5M96YT+@!5;F4@97)R975R(',G97-T
M('!R;V1U:71E(&QO<G,@9&4@;"=A9F9I8VAA9V4@9&4@8V5T=&4@<&%R=&4@
M9'4@;65S<V%G90!5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@
M;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<R!D92!C92!C;VYT86-T+@!5;F4@
M97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D
M92!C971T92!C87)T92!I0V%L96YD87(N`$EL('D@879A:70@=6YE(&5R<F5U
M<B!D86YS(&QE(&9O<FUU;&%I<F4@9&4@8V]N9FEG=7)A=&EO;BX@4&5U="WJ
M=')E(&%V97HM=F]U<R!L86ES<^D@=6X@8VAA;7`@<F5Q=6ES('9I9&4N`%5N
M92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L)V5XZ6-U=&EO;B!D
M92!C971T92!F;VYC=&EO;B!D=2!C87)N970@9"=A9')E<W-E+B!35E`@97-S
M87EE<B#@(&YO=79E874@<&QU<R!T87)D+@!);"!Y(&$@974@=6YE(&5R<F5U
M<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1E<R!I;F9O<FUA=&EO;G,@<W5R
M(&QE(&-O;G1A8W0N("!6975I;&QE>B!E<W-A>65R(.`@;F]U=F5A=2X`26P@
M>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D92!L
M82!L:7-T92!D92!D:7-T<FEB=71I;VXN("!6975I;&QE>B!E<W-A>65R(&1E
M(&YO=79E874N`$QE('!RZ7-E;G0@<V5R=F5U<B!)34%0(&YE('-U<'!O<G1E
M('!A<R!L92!P87)T86=E(&1E(&1O<W-I97)S+@#'82!N92!S96UB;&4@<&%S
M(.IT<F4@=6YE(&%R8VAI=F4@4D%2('9A;&ED92X`QV$@;F4@<V5M8FQE('!A
M<R#J=')E('5N(&9I8VAI97(@6DE0('9A;&ED92X`QV$@;F4@<V5M8FQE('!A
M<R#J=')E('5N(&YU;>ER;R!D92!C87)T92!V86QI9&4N`$-E('!I;&]T92!P
M97)M970@;"=E;G9O:2!D92!M97-S86=E<R#@('1R879E<G,@;&$@<&%S<V5R
M96QL92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&5N('5T
M:6QI<V%N="!L)T%022!(5%10`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D
M92!M97-S86=E<R!V:6$@;&$@<&%S<V5R96QL92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144`!#92!P:6QO=&4@<&5R
M;65T(&PG96YV;VD@9&4@;65S<V%G97,@X"!T<F%V97)S(&QA('!A<W-E<F5L
M;&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@96X@=71I;&ES
M86YT(&PG05!)($A45%``0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE
M<W-A9V5S('!A<B!33510(.`@=')A=F5R<R!L82!P87-S97)E;&QE(%9O9&%F
M;VYE($ET86QI92P@<V5U;&5M96YT(&%U>"!N=6WI<F]S(%9O9&%F;VYE+B!#
M96QA(&[I8V5S<VET92!U;B!C;VUP=&4@9&4@8V]U<G)I96P@5F]D869O;F4@
M271A;&EE("AH='1P.B\O=W=W+C$Y,"YI="DN`$-E(&-H86UP(&5S="!O8FQI
M9V%T;VER92X`0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S(&5N
M=&EE<G,N`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!N;VUB
M<F5S(&5T(&QE<R!D975X+7!O:6YT<RX`0V4@8VAA;7`@;F4@9&]I="!C;VYT
M96YI<B!Q=64@9&5S('9A;&5U<G,@;V-T86QE<RX`0V4@8VAA;7`@9&]I="!C
M;VYT96YI<B!U;F4@;&ES=&4@9"=E;G1I97)S('/I<&%RZ7,@<&%R(&1E<R!V
M:7)G=6QE<R!O=2!D97,@97-P86-E<P!#92!C:&%M<"!D;VET(.IT<F4@=6X@
M;F]M8G)E('9A;&ED92X`0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;B!C;V1E
M(&1E(&-O=6QE=7(@874@9F]R;6%T(%)'0B!H97AA9.EC:6UA;"P@<&%R(&5X
M96UP;&4@)R,Q,C,T868G+@!#92!F;W)M=6QA:7)E(&$@9.EJX"#I=.D@=')A
M:73I+@!#)V5S="`E<RX`0V5C:2!E<W0@=6X@;V)J970@2V]L86(@1W)O=7!W
M87)E+B!0;W5R('9O:7(@8V5T(&]B:F5T+"!V;W5S(&1E=G)E>B!A=F]I<B!U
M;B!C;&EE;G0@9&4@8V]U<G)I96P@<75I(&-O;7!R96YD(&QE(&9O<FUA="!+
M;VQA8B!'<F]U<'=A<F4N(%!O=7(@=6YE(&QI<W1E(&1E(&-E<R!C;&EE;G1S
M(&1E(&-O=7)R:65L+"!V:7-I=&5Z("5S`$-E(&UE<W-A9V4@82#I=.D@Z6-R
M:70@9&%N<R!U;B!C;V1E(&1E(&-A<F%C=.AR97,@*"5S*2!A=71R92!Q=64@
M;&4@=O1T<F4N`$-E(&YO;6)R92!D;VET(.IT<F4@<W5PZ7)I975R(.`@=6XN
M`$-E('-E<G9E=7(@;F4@<&5U="!P87,@9.EC;VUP<F5S<V5R(&QE<R!F:6-H
M:65R<R!:25`@970@9WII<"X`0V4@<WES=.AM92!E<W0@<'+I<V5N=&5M96YT
M(&3I<V%C=&EVZ2X`0V5T=&4@=F%L975R(&1O:70@ZG1R92!U;B!N;VUB<F4N
M`$-E='1E(&9E;NIT<F4@9&]I="#J=')E(&%P<&5LZ64@9&5P=6ES('5N92!F
M96[J=')E(&1E<R!O<'1I;VYS`%1O;FYE<G)E`%1I8VME=',`2&5U<F4`4W5I
M=FD@:&]R86ER90!&;W)M870@9"=H975R90!3Z6QE8W1I;VX@9&4@;"=H975R
M90!4:6UO<B!O<FEE;G1A;`!4:71R90!4:71R92`H:6YF;V)U;&QE*:`Z`,``
M4&]U<B!SZ6QE8W1I;VYN97(@<&QU<VEE=7)S(&ET96US(.`@;&$@9F]I<RP@
M;6%I;G1E;F5Z(&5N9F]N8^D@;&4@8F]U=&]N(*N@0W1R;*"[("A00RD@;W4@
MJZ!#;VUM86YD9:"[("A-86,I(&5N(&-L:7%U86YT+@!!=6IO=7)D)VAU:0!6
M;VER(&QA('-O=7)C92!(5$U,`%1O9V\`5&]K96QA=0!$96UA:6X`5&]N9V$`
M5')O<"!D92!C;VYN97AI;VYS(&EN9G)U8W1U975S97,@9&%N<R!L97,@9&5R
M;FGH<F5S(&UI;G5T97,N`$AA=70`0V%D<F4@9'4@:&%U="`H7W1O<"D`5')A
M9'5C=&EO;G,`5')I;FETZ2UE="U4;V)A9V\`5G)A:2!O=2!F875X`$UA`%1U
M;FES:64`5'5R<75I90!4=7)C("A)4T\M.#@U.2TY*0!4=7)K;>EN:7-T86X`
MSFQE<R!4=7)Q=65S(&5T($-A[W%U97,`5'5V86QU`$5N=')E>B!V;W1R92!C
M:&]I>*`Z(`!);F1I8V4@55:@.B``55),`%523"!P;W5R('9O=')E(')A<'!O
M<G0@9&4@;&EV<F%I<V]N(&1U('-C<FEP=`!54DPZ`$]U9V%N9&$`56MR86EN
M90!);7!O<W-I8FQE(&0G871T96EN9')E(&QE('+I<&5R=&]I<F4@5D93+@!)
M;7!O<W-I8FQE(&0G86IO=71E<B!D97,@:6YF;W)M871I;VYS(&-O;7!LZ6UE
M;G1A:7)E<R#@(&PG:6YS8W)I<'1I;VXN`$EM<&]S<VEB;&4@9&4@;6]D:69I
M97(@;&5S('!E<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[
M+@!);7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N<R!P;W5R
M(&QE(&9I8VAI97(@5D93("5S+R5S+@!);7!O<W-I8FQE(&1E(&-H86YG97(@
M<&]U<B`E<RX`26UP;W-S:6)L92!D92!VZ7)I9FEE<B!L82!T86EL;&4@9'4@
M9FEC:&EE<B!D92"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@=NER:69I97(@;&$@
M=&%I;&QE(&1U(&9I8VAI97(@9&4@JR`E<R\E<R"[+@!#;VYN97AI;VX@:6UP
M;W-S:6)L92!A=2!S97)V975R(%-13"X`0V]N;F5X:6]N(&EM<&]S<VEB;&4@
M96X@4U-,`$EM<&]S<VEB;&4@9&4@8V]P:65R('5N(&9I8VAI97(@5D93+@!)
M;7!O<W-I8FQE(&1E(&-RZ65R('5N('+I<&5R=&]I<F4@5D93(*N@)7.@NRX`
M26UP;W-S:6)L92!D92!C<NEE<B!U;B!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S
M:6)L92!D92!C<NEE<B!L92!F:6-H:65R(%9&4RX`26UP;W-S:6)L92!D92!C
M<NEE<B!L92!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@
M8W+I97(@=6X@9FEC:&EE<B!61E,@=FED92X@`$]U=F5R='5R92!I;7!O<W-I
M8FQE(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+B``4W5P<')E<W-I;VX@:6UP
M;W-S:6)L92!D92"KH"5SH+LL(&QE(&1O<W-I97(@;B=E<W0@<&%S('9I9&4N
M`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[H#H@)7,N`%-U<'!R
M97-S:6]N(&EM<&]S<VEB;&4@9&4@)7,L(&QE(&1O<W-I97(@;B=E<W0@<&%S
M('9I9&4`4W5P<')E<W-I;VX@<NEC=7)S:79E(&1U(&1O<W-I97(@5D93(&EM
M<&]S<VEB;&4N`%-U<'!R97-S:6]N(&1U('+I<&5R=&]I<F4@5D93(&EM<&]S
M<VEB;&4N`$EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&QE('+I<&5R=&]I<F4@
M5D93H#H@)7,N`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9FEC:&EE<B!6
M1E,@JZ`E<Z"[+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I8VAI97(@
M5D93+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U('+I<&5R=&]I<F4@5D93
M(*N@)7.@NRX`4W5P<')E<W-I;VX@5D93('+I8W5R<VEV92!I;7!O<W-I8FQE
MH#H@)7,N`$EM<&]S<VEB;&4@9&4@9.ET97)M:6YE<B!L92!D;W-S:65R(&-O
M=7)A;G0N`$EM<&]S<VEB;&4@9"=E>'1R86ER92!L97,@9.ET86EL<R!D=2!C
M97)T:69I8V%T`$EM<&]S<VEB;&4@9&4@8VAA<F=E<B!L82!DZ69I;FET:6]N
M(&1E("5S+@!);7!O<W-I8FQE(&1E(&3I<&QA8V5R(&QE(&9I8VAI97(@5D93
M+@!);7!O<W-I8FQE(&0G;W5V<FER(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`
M26UP;W-S:6)L92!D)V]U=G)I<B!U;B!F:6-H:65R(%9&4R!E;B#I8W)I='5R
M92X`26UP;W-S:6)L92!D)V]U=G)I<B!U;B!F:6-H:65R(%9&4RX`3W5V97)T
M=7)E(&EM<&]S<VEB;&4@9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N`$EM<&]S
M<VEB;&4@9&4@;&ER92!L92!F:6-H:65R(%9&4R`HZ6-H96,@9&4@9FEL97-I
M>F4H*2DN`$EM<&]S<VEB;&4@9&4@;&ER92!L92!F:6-H:65R(%9&4R`HZ6-H
M96,@9&4@9V5T1FEL95-I>F4H*2DN`$EM<&]S<VEB;&4@9&4@;&ER92!L92!F
M:6-H:65RH#H@`$QE8W1U<F4@9'4@<NEP97)T;VER92!R86-I;F4@5D93(&EM
M<&]S<VEB;&4N`$EM<&]S<VEB;&4@9&4@<F5N;VUM97(@)7,@96X@)7.@.B!L
M92!D;W-S:65R(&-I8FQE(&5X:7-T92!DZ6K@`$EM<&]S<VEB;&4@9&4@<F5N
M;VUM97(@;&4@<NEP97)T;VER92!61E,N`$EM<&]S<VEB;&4@9&4@<F5N;VUM
M97(@;&4@<NEP97)T;VER92!61E.@.B`E<RX`26UP;W-S:6)L92!D92!R96YO
M;6UE<B!L92!F:6-H:65R(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@<F5N
M;VUM97(@;&4@9FEC:&EE<B!61E,@)7,O)7,N`$EM<&]S<VEB;&4@9&4@<F5N
M;VUM97(@;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9"=E>.EC=71E<B`G
M;6MI<V]F<R<N`$EM<&]S<VEB;&4@9&4@=')A9'5I<F4@8V4@9&]C=6UE;G0@
M5V]R9"X`26UP;W-S:6)L92!D)^EC<FER92!L92!F:6-H:65R(%9&4R"KH"5S
MH+LN`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O;F[I97,@9'4@9FEC:&EE
M<B!61E,@*&-O<'DH*2!I;7!O<W-I8FQE*2X`26UP;W-S:6)L92!D)^EC<FER
M92!L97,@9&]N;NEE<R!D=2!F:6-H:65R(%9&4RX`26UP;W-S:6)L92!D)^EC
M<FER92!L92!F:6-H:65R(%9&4RP@;&4@<75O=&$@<V5R86ET(&3I<&%S<^DN
M`%-O=6QI9VYE<@!!;FYU;&5R(&QE<R!C:&%N9V5M96YT<P!!;FYU;&4@=F]T
M<F4@9&5R;FGH<F4@86-T:6]N`%+I<&]N<V4@:6YA='1E;F1U92!D=2!S97)V
M975R(&QO<G,@9&4@;&$@8V]N;F5X:6]NH#H@`%+I<&]N<V4@:6YA='1E;F1U
M92!D=2!S97)V975R(."@.B``2&]R<R!C873I9V]R:64`56YI8V]D92`H551&
M+3@I`,EM:7)A=',@07)A8F5S(%5N:7,`4F]Y875M92U5;FD`R71A=',M56YI
M<P#.;&5S(&5X=.ER:65U<F5S(&1E<R#)=&%T<RU5;FES`%5N:73I<P!);F-O
M;FYU`&%P:6US9VED(&EN8V]N;G4@*$%022!-97-S86=E($E$*2X`8VQI;7-G
M:60@:6YC;VYN=2`H0VQI96YT($UE<W-A9V4@240I+@!%;7!L86-E;65N="!S
MZ6QE8W1I;VYNZ2!I;F-O;FYU+@!.;VT@9"=U=&EL:7-A=&5U<B!O=2!M;W0@
M9&4@<&%S<V4@:6YC;VYN=2X`1.EL:65R(&PGZ6SI;65N="!C;W5R86YT`%-A
M;G,@;F]M`$QE<R!S8W)I<'1S(&YO;BUP<FEV:6SI9VGI<R!N92!P975V96YT
M(&%C8^ED97(@875X(&9O;F-T:6]N<R!C;W5P97(O8V]P:65R+V-O;&QE<B!P
M;W5R(&1E<R!R86ES;VYS(&1E('/I8W5R:73I+B!!<'!U>65Z('-U<B!/2R!P
M;W5R('9O:7(@=6YE(&YO=&4@=&5C:&YI<75E('-U<B!M;WII;&QA+F]R9R!Q
M=6D@=F]U<R!E>'!L:7%U97)A(&-O;6UE;G0@875T;W)I<V5R('5N('-C<FEP
M="#@('5T:6QI<V5R(&QE('!R97-S92UP87!I97)S`%)E;65T=')E(&QA(&-O
M=6QE=7(@X"!ZZ7)O`$5X=&5N<VEO;B!N;VX@<')I<V4@96X@8V]M<'1E`$UO
M9&EF:65R`$UO9&EF:65R("5S`$UO9&EF:65R(&PG=71I;&ES871E=7(`36ES
M92#@(&IO=7(@9&4@JZ`E<Z"[+@!,92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@
M97-T('-U<'!R:6WI`$-H87)G97(`5&]U<R!L97,@9FEC:&EE<G,@9&4@8V]N
M9FEG=7)A=&EO;B!D97,@87!P;&EC871I;VYS(&]N="#I=.D@96YV;WGI<R!S
M=7(@;&4@<V5R=F5U<BX`3&5T=')E<R!L871I;F5S(&UA:G5S8W5L97,`3F]M
M8G)E<R!R;VUA:6YS(&UA:G5S8W5L97,`57)U9W5A>0!%;7!L;WGI(&%C='5E
M;&QE;65N=*`Z("5S`%5T:6QI<V5R(%-33`!5=&EL:7-E<B!S:2!L92!N;VT@
M9"=U=&EL:7-A=&5U<B]M;W0@9&4@<&%S<V4@97-T(&1I9F;I<F5N="!D=2!S
M97)V975R($E-4U`N`%5T:6QI<V%T975R`$PG=71I;&ES871E=7(@)7,@;B=A
M('!A<R!L)V%U=&]R:7-A=&EO;B!P;W5R("5S+@!!9&UI;FES=')A=&EO;B!D
M97,@=71I;&ES871E=7)S`%!RZ6;I<F5N8V5S('!E<G-O;FYE;&QE<P!%;G)E
M9VES=')E;65N="!D97,@=71I;&ES871E=7)S`$PG96YR96=I<W1R96UE;G0@
M9"=U=&EL:7-A=&5U<B!E<W0@9.ES86-T:7;I('-U<B!C92!S>7-TZ&UE+@!#
M;VUP=&4@=71I;&ES871E=7(@;F]N('1R;W5VZ0!.;VT@9"=U=&EL:7-A=&5U
M<@!,92!N;VT@9&4@8V]N;F5X:6]N(*N@)7.@NR!E>&ES=&4@9.EJX"X`3F]M
M(&0G=71I;&ES871E=7*@.@!.;VT@9"=U=&EL:7-A=&5U<J`Z(`!5=&EL:7-A
M=&5U<G,@9.EF:6YI<Z`Z`$]U>F+I:VES=&%N`%+I<&5R=&]I<F4@5D93(&EN
M97AI<W1A;G0N`$%B<V5N8V5S`$QE<R!E;7!L86-E;65N=',@=F%L:61E<R!T
M<F]U=NES(&EN8VQU96YTH#H@`%9A;&ED:73I`%9A;&5U<B!E;B!M:6YU=&5S
M(.`@<&%R=&ER(&1E(&UA:6YT96YA;G0N`%9A;&5U<B!S=7#I<FEE=7)E(.`@
M;&$@;&]N9W5E=7(@;6%X:6UA;&4@9&4@)7,N`%9A;&5U<G,`5F%L975R<R#@
M('/I;&5C=&EO;FYE<B!D90!686YU871U`%9A<FEA8FQE`%;I;NEZ=65L80#)
M8VAE8R!D92!L82!VZ7)I9FEC871I;VX@)FUD87-H.R!C92!M97-S86=E(&$@
M<&5U="WJ=')E(.ETZ2!F86QS:69IZ2X`5F5R<VEO;@!#;VYT<O1L92!D92!V
M97)S:6]N`$%L:6=N96UE;G0@=F5R=&EC86P`4F5M<&QI<W-A9V4@=F5R=&EC
M86P`5F5R=&EC86R@.@!4<NAS(&AA=71E`%9I971N86T`5FGJ="UN86UI96X@
M*%9)4T-)22D`5F]I<B`E<P!6;VER('5N92!P86=E('=E8B!E>'1E<FYE`%9O
M:7(@8V]M;64@)7,`SFQE<R!6:65R9V5S(&)R:71A;FYI<75E<P#.;&5S(%9I
M97)G97,@9&5S(,ET871S+55N:7,`5FES:6)I;&ETZ0!6:7-I8FEL:73IH#H@
M`%9O9&%F;VYE($ET86QY('9I82!33510`$Y/5$E#10!!5%1%3E1)3TXA(2$@
M(%-54%!224U%4B!,12!30U))4%0@34%.545,3$5-14Y4($1%("5S`%=)3B!V
M:6$@2%144`!786QL:7,@970@1G5T=6YA`$%T=&5N=&EO;@!-90!0<NEV:7-I
M;VYS(&WI=.EO`$1O;F[I97,@;>ETZ6\@9F]U<FYI97,@<&%R`%=E871H97(N
M8V]M`%=E8@!3:71E('=E8@!#:&%Q=64@<V5M86EN90!":65N=F5N=64`0FEE
M;G9E;G5E(.`@)7,`0FEE;G9E;G5E+"`E<P!/8V-I9&5N=&%L("A)4T\M.#@U
M.2TQ*0!/8V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4V%H87)A($]C8VED96YT
M86P`475E;&QE(&%P<&QI8V%T:6]N("5S(&1O:70M:6P@<'+I<V5N=&5R(&%P
M<NAS(&QA(&-O;FYE>&EO;J`_`%%U96P@97-T(&QE(&-A<F%C=.AR92!D92!S
MZ7!A<F%T:6]NH#\`475E;"!E<W0@;&4@8V%R86-TZ')E(&1E(&-I=&%T:6]N
MH#\`0V%R=&4@5VAE<F5I<R!!=7-T<F%L:64`475E;&QE<R!P:&%S97,`475E
M;&QE<R!E>'1E;G-I;VYS(&%C=&EV97(@<&]U<B!L)^ED:71E=7(@4FEC:"!4
M97AT+@!,87)G975R`$QA<F=E=7(@96X@=6YI=.ES($-34P!,87)G975R(&1U
M(&UE;G4@9&4@9V%U8VAE("5S("`H;&$@8V]N9FEG=7)A=&EO;B!P<F5N9')A
M(&5F9F5T(.`@;&$@<')O8VAA:6YE(&-O;FYE>&EO;BF@.@!,87)G975R(&1U
M('1A8FQE874`56YI=.D@9&4@;&%R9V5U<@!,87)G975RH#H`5VEK:0!696YT
M`%9E;G0@=/1T(&QE(&UA=&EN`%9I=&5S<V4@9'4@=F5N="!E;B!N)F]E;&EG
M.W5D<P!696YTH#H`5F5N=*`Z(`!386=E<W-E`$QI<W1E(&1E('8F;V5L:6<[
M=7@`5')A=F%I;`!!9')E<W-E('!R;V9E<W-I;VYN96QL90!4Z6SI<&AO;F4@
M<')O9F5S<VEO;FYE;`!.;VUB<F4@9&4@8VAA;7!S(&EN8V]R<F5C="#@(&QA
M(&QI9VYE("5D+B`E9"!A='1E;F1U<RP@)60@=')O=7;I<RX`3F]M8G)E(&1E
M(&-H86UP<R!I;F-O<G)E8W0N("5D(&%T=&5N9'5S+"`E9"!T<F]U=NES+@!$
MZ6-A;&%G92`E9"!I;F-O<G)E8W0@;&]R<R!D92!L82!L96-T=7)E(&1E(&9I
M8VAI97(@5D93+@!8+5)E9@!#;VYT<F%I;G1E<R!B87-I<75E<R!8-3`Y=C,`
M571I;&ES871I;VX@9&4@8VSI(.ET96YD=64@6#4P.78S`$%U=')E(&YO;2!D
M=2!S=6IE="!8-3`Y=C,`261E;G1I9FEA;G0@9&4@8VSI(&1U('-U:F5T(%@U
M,#EV,P!%>'1E;G-I;VYS(%@U,#EV,P!!00!!04%!`$-A<G1E(*N@66%H;V^@
M(:"[`$%N;G5E;&QE;65N=`!9Z6UE;@!/=6D`3W5I+"!J)V%C8V5P=&4`5F]U
M<R#J=&5S(&5N(&UO9&4@JZ!497AT9:"[+B!5=&EL:7-E>B!L92!B;W5T;VX@
M6SP^72!P;W5R(')E=F5N:7(@874@;6]D92"KH%=94TE764>@NRX`5F]U<R!N
M)^IT97,@<&%S(&%U=&]R:7/I(.`@8W+I97(@<&QU<R!D92`E9"!B;&]C<RX`
M5F]U<R!N)^IT97,@<&%S(&%U=&AE;G1I9FGI+@!6;W5S(&YE('!O=79E>B!P
M87,@879O:7(@;&4@8V%R86-TZ')E(*M<NR!D86YS('9O=')E(&YO;2!C;VUP
M;&5T+@!6;W5S(&XG879E>B!P87,@<V%I<VD@=6YE(&%D<F5S<V4@Z6QE8W1R
M;VYI<75E('9A;&ED92X`5F]U<R!N)V%V97H@<&%S(&%S<V]C:>D@;&5S(&-H
M86UP<R!D=2!F:6-H:65R(&EM<&]R=.D@875X(&-H86UP<R!C;W)R97-P;VYD
M86YT<R!D86YS("5S+@!6;W5S(&%V97H@Z73I(&3I8V]N;F5C=.DN`%9O=7,@
M9&5V97H@:6YS8W)I<F4@=6X@;G5MZ7)O(&1E(&-E;&QU;&%I<F4@=F%L:61E
M+"!S975L<R!D97,@;F]M8G)E<R!E="!U;B"KH"N@NR!O<'1I;VYN96P@<&]U
M<B!L97,@87!P96QS(&EN=&5R;F%T:6]N875X+@!6;W5S(&XG879E>B!P87,@
M<V%I<VD@=6YE(&5N='+I92!V86QI9&4N`%9O=7,@9&5V97H@8V]N9FEG=7)E
M<B!U;B!B86-K96YD($1A=&%4<F5E('!O=7(@=71I;&ES97(@;&5S(&EN<V-R
M:7!T:6]N<P!6;W5S(&1E=F5Z(&-O;F9I9W5R97(@=6X@;6]D=6QE(%9&4RX`
M5F]U<R!D979E>B!DZ6-R:7)E(&QE('!R;V)LZ&UE(&%V86YT(&1E(&YO=7,@
M9F%I<F4@<&%R=F5N:7(@;&4@<F%P<&]R="X`5F]U<R!D979E>B!E;G1R97(@
M=6YE(%523"!O^2!P;VEN=&4@9&4@;&EE;BX`26P@9F%U="!SZ6QE8W1I;VYN
M97(@=6X@<V5R=F5U<B#@('-U<'!R:6UE<BX`5F]U<R!D979E>B!S<.EC:69I
M97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+B``5F]U<R!D979E>B!S<.EC
M:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+@!6;W5S(&1E=F5Z('-P
MZ6-I9FEE<B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(N`%9O=7,@9&5V97H@
M<W#I8VEF:65R(&QE(&YO;2!D92!L)W5T:6QI<V%T975R(.`@;6]D:69I97(N
M`%9O=7,@9&5V97H@:6YD:7%U97(@<75E;&QE(&%C=&EO;B!A8V-O;7!L:7(N
M`%9O=7,@9&5V97H@Z6-R:7)E('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A
M=.EG;W)I92X`5F]U<R!D979E>B!F;W5R;FER('5N(&ZP(&1E('3I;.EP:&]N
M92!I=&%L:65N`%9O=')E('-E<W-I;VX@)7,@82!E>'!I<NDN(%9E=6EL;&5Z
M('9O=7,@<F5C;VYN96-T97(N`%9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96P`
M5F]T<F4@861R97-S92!D92!C;W5R<FEE;""K($1E.B"[H#H`5F]S(&1O;F[I
M97,@<&5R<V]N;F5L;&5S`%9O=')E(&%D<F5S<V4@26YT97)N970@82!C:&%N
M9^D@9&5P=6ES(&PG;W5V97)T=7)E(&1E('9O=')E('-E<W-I;VX@)7,N("!0
M;W5R('9O=')E('/I8W5R:73I+"!V;W5S(&1E=F5Z('9O=7,@<F5C;VYN96-T
M97(N`%9O=')E(&YO;0!6;W1R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N
M(&YE('-U<'!O<G1E('!A<R!L)V%J;W5T(&0G=71I;&ES871E=7)S+"!3:2!V
M;W5S('-O=6AA:71E>B!U=&EL:7-E>B!(;W)D92!P;W5R(&%D;6EN:7-T<F5R
M(&QE<R!C;VUP=&5S('5T:6QI<V%T975R<RP@=F]U<R!D979E>B!U=&EL:7-E
M<B!U;B!A=71R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N+@!6;W1R92!M
M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N(&XG97-T('!A<R!E;B!M97-U<F4@
M9"?I=&%B;&ER('5N92!L:7-T92!D97,@=71I;&ES871E=7)S+"!O=2!C971T
M92!F;VYC=&EO;B!A(.ETZ2!R971I<NEE('!O=7(@=6YE(&%U=')E(')A:7-O
M;BX`5F]T<F4@;F%V:6=A=&5U<B!S96UB;&4@879O:7(@8VAA;F?I(&1E<'5I
M<R!L92!DZ6)U="!D92!V;W1R92!S97-S:6]N("5S+B`@4&]U<B!V;W1R92!S
MZ6-U<FETZ2P@=F]U<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R92!N
M879I9V%T975R(&YE('-U<'!O<G1E('!A<R!C971T92!O<'1I;VX`5F]T<F4@
M;F%V:6=A=&5U<B!N92!P<F5N9"!P87,@96X@8V]M<'1E(&-E='1E(&]P=&EO
M;B!D)VEM<')E<W-I;VXN(%!R97-S97H@0V]N='+T;&4O0V]M;6%N9&4@*R!0
M('!O=7(@:6UP<FEM97(`5F]T<F4@9G5S96%U(&AO<F%I<F4@86-T=65LH#H`
M5F]T<F4@<')O9FEL('!A<B!DZ69A=70@82#I=.D@;6]D:69IZ2X`4')O9FEL
M('!A<B!DZ69A=72@.@!6;W1R92!N;VT@8V]M<&QE=*`Z`%9O=')E(&-O;7!T
M92!A(&5X<&ERZ2X`5F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@<&]U<B`E
M<R!E<W2@.B5S`%9O<R!O<'1I;VYS(&]N="#I=.D@;6ES97,@X"!J;W5R('!O
M=7(@;&$@9'5RZ64@9&4@8V5T=&4@<V5S<VEO;BX`5F]S(&]P=&EO;G,@;VYT
M(.ETZ2!M:7-E<R#@(&IO=7(N`%9O=')E(&UO="!D92!P87-S92!A(.ETZ2!R
M96UI<R#@('KI<F\`5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES(.`@
M>NER;RP@=NER:69I97(@=F]T<F4@8V]U<G)I97(@970@8V]N;F5C=&5Z+79O
M=7,@879E>B!V;W1R92!N;W5V96%U(&UO="!D92!P87-S92X`5F]T<F4@;6]T
M(&1E('!A<W-E(&$@97AP:7+I+@!6;W,@<V5R=F5U<G,@9&ES=&%N='.@.@!9
M;W5G;W-L879I90!:8>]R90!:86UB:64`6FEM8F%B=V4`6FEP<'D`6T-A8VAE
M<B!L97,@8VET871I;VYS70!;4F%P<&]R="!D92!P<F]B;.AM95T`6T%F9FEC
M:&5R(&QE('1E>'1E(&-I=.D@+0!;069F:6-H97(@;&4@=&5X=&4@8VETZ2`M
M("5S(&QI9VYE<UT`6VQI9VYE("5S(&1E("5S70!?061M:6YI<W1R871I;VX`
M3&EG;F4@9&4@7V-O;6UA;F1E`%]$871A5')E90!3=7!P<FEM97(@;&$@7W)A
M;F?I90!?1W)O=7!E<P!?06ED90!0<F]P<E]IZ73I<R!D92!L)VEM86=E+BXN
M`%]#;VYN97AI;VX`7T3I8V]N;F5X:6]N`%]-;V1I9FEE<B!U;B!L:65N('=E
M8BXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E=&ER97(@=6X@;&EE;@!?
M0V]N9FEG=7)A=&EO;@!0<F]P<FGI=.ES(&1U(%]T86)L96%U`%]5=&EL:7-A
M=&5U<G,`8V%R;F5T(&0G861R97-S97,`9&5S=&EN871A:7)E(&EN8V]N;G4`
M86=E;F1A`&-A;&UE`&EM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!D
M92!S;W)T:64`:6UP;W-S:6)L92!D)V]U=G)I<B!L)V5N='+I90!C;&EQ=65Z
M(&EC:0!E<G)E=7(@9"=U=&EL:7-A=&EO;B!D92!L82!L:6=N92!D92!C;VUM
M86YD90!E<G)E=7(@9&4@8V]N9FEG=7)A=&EO;@!A8G-E;F-E(&-R:71I<75E
M(&0G=6X@9FEC:&EE<B!S>7-TZ&UE`&5R<F5U<B!D92!F;W)M870@9&4@9&]N
M;NEE`&UO9&EF:65R`&5N='+I92!N;VX@=')O=7;I`'1O;6)A;G0`9FEC:&EE
M<@!D97!U:7,@;&4@)7,@*"5S*2#@("5S("5S`&5N(')A9F%L90!HH#H`:&@`
M;F]M(&0G:/1T92!I;F-O;FYU`&EM;>ED:6%T96UE;G0`:6YC;W)P;W+I90!E
M<G)E=7(@9"=E;G1RZ64O<V]R=&EE`&5R<F5U<B!L;V=I8VEE;&QE(&EN=&5R
M;F4`;&EG;F5S70!E<G)E=7(@;6MI<V]F<R!C;V1E("5D(&5N(&-RZ6%N="!L
M)TE33P!M;0!N;VT`;F]N('!R:7,@96X@8V]M<'1E`'!A<R!E;F-O<F4@<')I
M<R!E;B!C;VUP=&4`8FQO8RUN;W1E<P!P;W5R8V5N=&%G90!P97)M:7-S:6]N
M(')E9G5SZ64`<&EX96QS`&5R<F5U<B!D:7-T86YT92!D86YS(&QE('!R;W1O
M8V]L90!S)^EL979A;G0`<V5R=FEC92!N;VX@9&ES<&]N:6)L92X`;6]N=')E
M<B!L97,@9&EF9NER96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`&9I>&4`
M97)R975R('-Y<W3H;64`;&ES=&4@9&4@=.)C:&5S`.EC:&5C('1E;7!O<F%I
M<F4`96YT<F5Z(&QE(&UO="!D92!P87-S92!D975X(&9O:7,@<&]U<B!C;VYF
M:7)M97(`=6YI9FGI`'-A;G,@;F]M`%/I;&5C=&EO;B!D)W5T:6QI<V%T975R
M`'9#87)D`&R@.@!W96%T:&5R+F-O;0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V9R7T92+VAE;'`N>&UL````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#`R,P`Q,#4Q-30S,3`V,0`P,C`S,3,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,2(_/@H\(2TM
M("1(;W)D93H@:&]R9&4O;&]C86QE+V9R7T92+VAE;'`N>&UL+'8@,2XR+C$P
M+C$@,C`P-2\Q,B\P-2`Q,#HS,#HT-2!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X
M8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U(CX*/'1I=&QE/DQA('!A
M9V4@<&]R=&%I;"`\+W1I=&QE/@H@/'!A<F$^"B`@0V5T=&4@<&%G92!P;W)T
M86EL('9O=7,@9F]U<FYI="!U;B!RZ7-U;>D@9&4@=F]S(&EN9F]R;6%T:6]N
M<R!I;7!O<G1A;G1E<RX@4&%R(&5X96UP;&4L(&-E;&$@<&]U<G)A:70@=F]U
M<R!P97)M971T<F4@9"=A9F9I8VAE<B!L92!N;VUB<F4@9&4@;F]U=F5A=7@@
M;65S<V%G97,@9&%N<R!V;W1R92!B;^YT92!D92!RZ6-E<'1I;VXL(&QE<R!N
M;W5V96%U>"#I=NAN96UE;G1S(&1E('9O=')E(&-A;&5N9')I97(L(&QE<R!T
MXF-H97,@9&4@=F]T<F4@;&ES=&4@9&4@=')A=F%U>"#@(&9A:7)E+"!L97,@
M9W)A;F1S('1I=')E<R!D92!N;W5V96QL97,L(&5T8RX@3&$@<&QU<&%R="!D
M97,@<NES=6WI<R!C;VYT:65N9')O;G0@9&5S(')A8V-O=7)C:7,@=F5R<R!D
M97,@9F]N8W1I;VYS(&-L87-S:7%U97,@8V]M;64@;&$@8V]M<&]S:71I;VX@
M9"=U;B!N;W5V96%U(&UE<W-A9V4L(&QA(&-RZ6%T:6]N(&0G=6X@;F]U=F5L
M(.EVZ&YE;65N="!D86YS(&QE(&-A;&5N9')I97(@;W4@9"=U;F4@;F]U=F5L
M;&4@=.)C:&4N"B`\+W!A<F$^"B`\<&%R83X*("!,92!C;VYT96YU(&1E(&-E
M='1E('!A9V4@<&]R=&%I;"!P975T(.IT<F4@<&5R<V]N;F%L:7/I(.`@;"=A
M:61E(&1U(&)O=71O;B`G4'+I<V5N=&%T:6]N)RX@4&%R(&5X96UP;&4L('9O
M=7,@<&]U=F5Z(&-H;VES:7(@;&5S('!O:6YT<R!P<NES96YT<R!S=7(@8V5T
M=&4@<&%G92!P;W)T86EL(&5T(&PG;W)D<F4@9&%N<R!L97%U96P@:6QS('-E
M<F]N="!P<NES96YTZ7,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)N879B87(B('-T871E/2)U<'1O9&%T92(@;60U/2)B.&-F,&%E,3EE-3=D
M9F$P8S)B.38R934Q-C<X,F8T-R(^"CQT:71L93Y,92!M96YU($AO<F1E/"]T
M:71L93X*(#QP87)A/@H@(%-U<B!L92!C]'3I(&=A=6-H92!D92!L82!P86=E
M('-E('1R;W5V92!L92!M96YU($AO<F1E+@H@($-L:7%U97H@<W5R(&QE<R!I
M8_1N97,@9&4@8V4@;65N=2!(;W)D92!P;W5R(&%C8^ED97(@<F%P:61E;65N
M="!E="!S:6UP;&5M96YT(&%U>"!A<'!L:6-A=&EO;G,@9&ES<&]N:6)L97,N
M(`H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I
M;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)D9#DU9&8P-V$P,S`S
M,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^4'+I9NER96YC97,Z
M($UA:6YT96YA;F-E.B!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I
M;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3:2!V;W5S('9O=6QE
M>B!E9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4@X"!L
M82!C;VYN97AI;VXL(&-O8VAE>B!C971T92!C87-E+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC
M92(@<W1A=&4](G5P=&]D871E(B!M9#4](F$R,3$V,F-D9F8S8C%D.&9A96%D
M8C<R.38R-#`P,S9E(CX*("`@(#QT:71L93Y0<NEFZ7)E;F-E<SH@36%I;G1E
M;F%N8V4Z($-O;F9I<FUE<CPO=&ET;&4^"B`@("`\<&%R83X*("`@(%-I('9O
M=7,@=F]U;&5Z(&1E=F]I<B!C;VYF:7)M97(@879A;G0@9&4@;&%N8V5R(&QE
M<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E+"!C;V-H97H@8V5T=&4@8V%S
M92X@4VD@=F]U<R!N92!L82!C;V-H97H@<&%S+"!T;W5T97,@;&5S(&]PZ7)A
M=&EO;G,@9&4@;6%I;G1E;F%N8V4@<V5R;VYT(&%U=&]M871I<75E;65N="!L
M86YCZ65S(.`@;&$@8V]N;F5X:6]N('-A;G,@875C=6YE(&-H86YC92!D)V%N
M;G5L871I;VXN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V=L7T53+P``````````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`V,0`P,38V-#``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9VQ?
M15,O3$-?34534T%'15,O````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#8Q`#`R,#0R-0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]G;%]%4R],0U]-15-304=%4R]H;W)D92YM;P``````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30P,C4`,3`U,34T,S$P-C$`,#(R,#8R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````-X2
M!)4`````9````!P````\`P``B0```%P&````````@`@``"@```"!"```"```
M`*H(```%````LP@```@```"Y"```!P```,((```%````R@@``!\```#0"```
M$0```/`(```(`````@D```@````+"0``%0```!0)```*````*@D```P````U
M"0``!P```$()```I````2@D```(```!T"0``!0```'<)```0````?0D``!0`
M``"."0``+P```*,)```/````TPD``"8```#C"0``!0````H*```-````$`H`
M``4````>"@``$````"0*```0````-0H```\```!&"@``"P```%8*```/````
M8@H```P```!R"@``#P```'\*```>````CPH``"$```"N"@```P```-`*```$
M````U`H```P```#9"@``"@```.8*```%````\0H``!(```#W"@``$`````H+
M```(````&PL``!`````D"P``!@```#4+```'````/`L```(```!$"P``!```
M`$<+```/````3`L```<```!<"P``!P```&0+```$````;`L```4```!Q"P``
M!0```'<+```'````?0L``!$```"%"P``"````)<+```>````H`L```4```"_
M"P``*````,4+```I````[@L``!,````8#```"P```"P,```1````.`P```0`
M``!*#```#````$\,```:````7`P``!<```!W#```%P```(\,```;````IPP`
M`!\```###```$P```.,,```0````]PP``!<````(#0``!P```"`-```%````
M*`T``"$````N#0``'````%`-```%````;0T```,```!S#0``(````'<-```F
M````F`T```P```"_#0``#````,P-```(````V0T```<```#B#0``!@```.H-
M```-````\0T```L```#_#0``#`````L.```*````&`X```(````C#@``!@``
M`"8.``!%````+0X``#````!S#@``$````*0.```?````M0X``!````#5#@``
M#P```.8.```%````]@X``&\!``#\#@``*@```&P0```(````EQ````4```"@
M$```#@```*80```(````M1````8```"^$```)````,40```3````ZA````L`
M``#^$```"@````H1```?````%1$```X````U$0``#P```$01```(````5!$`
M`#(```!=$0```@```)`1```+````DQ$``!D```"?$0``%@```+D1```O````
MT!$``!@`````$@``*P```!D2```2````11(```X```!8$@``!````&<2```/
M````;!(``!````!\$@``#@```(T2```5````G!(```\```"R$@``"P```,(2
M```3````SA(``",```#B$@``(P````83```#````*A,```4````N$P``$P``
M`#03```3````2!,```4```!<$P``$P```&(3```2````=A,```8```")$P``
M&````)`3```&````J1,```\```"P$P```@```,`3```&````PQ,``!8```#*
M$P``!P```.$3```,````Z1,```0```#V$P``!0```/L3```%`````10```<`
M```'%```$0````\4```/````(10``"$````Q%```"````%,4```>````7!0`
M`"\```![%```%@```*L4```+````PA0``!,```#.%```!P```.(4```1````
MZA0``"$```#\%```'0```!X5```=````/!4``"4```!:%0``%````(`5```=
M````E14``!,```"S%0``'P```,<5```-````YQ4```<```#U%0``(@```/T5
M```;````(!8```8````\%@```P```$,6```J````1Q8``"\```!R%@``$P``
M`*(6```2````MA8```<```#)%@``!0```-$6```,````UQ8```P```#D%@``
M#0```/$6```4````_Q8``!0````4%P```@```"D7```*````+!<``"X````W
M%P``/````&87```1````HQ<``!\```"U%P``%0```-47```/````ZQ<``!D`
M``#[%P```0```"0`````````3@```!T```!/````%P```$4````'````(@``
M``````!-````(0````````!+````8@````H````1``````````P````R````
M4P```#$`````````)0```$8```!=`````````%(```!"````50````````!'
M````+````"\```!6````40```#4````0````"````#X```!!````7P```"L`
M```/````.0```$H````C````&````#,```!`````*````&`````+````````
M``````!4```````````````]````"0`````````N````2````%P````Z````
M``````X`````````60`````````V`````````!L````_````'````!H````-
M````.P`````````$````!0`````````2`````````!,`````````5P```"T`
M````````)@``````````````%0````8`````````6P```#<````9````````
M`%X`````````.````#0`````````20```!\```!:````1``````````>````
M``````````!C`````````%@````I`````````#```````````````#P```!D
M````4``````````6````(``````````#````80```$,````J````)P```$P`
M```"`````````!0`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;@`R-"!H;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S`$%L
M:6%S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`079A:6QA8FQE
M(&9I96QD<SH`0FER=&AD87D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@4F5P
M;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F
M875L="!)9&5N=&ET>0!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7-P;&%Y
M($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'``16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S
M`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN
M`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M92!!9&1R97-S`$AO
M;64@4&AO;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I
M96QD<SH`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G(&]U
M=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UO;G1H;'D`3F%M
M90!.979E<@!.;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W
M;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S
M8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3
M879E($]P=&EO;G,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT96YA
M;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`5&%S:W,`5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BX`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($]P=&EO;G,`57-E<FYA;64`5V%R
M;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D
M9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E
M<UT`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C$*4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$
M871E.B`R,#`S+3`X+3$Y(#$S.C,U1TU4*S$*3&%S="U4<F%N<VQA=&]R.B!3
M97)V:6-I;R!D92!.;W)M86QI>F%C:6]N($QI;F=U:7-T:6-A(#QS;FQU<V-`
M=7-C+F5S/@I,86YG=6%G92U496%M.B!'86QE9V\*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O
M<CH@2T)A8F5L(#`N.2XU"@!/<&5R86-I\VYS(&1E(&UA;G1E;65N=&\@)7,@
M+2!#;VYF:7)M86-I\VX`,C0@:&]R87,`04TO4$T`16YG861I<B!U;B!P87(`
M16YD97)E>F\`06QC=6UE`$\@=F%L;W(@<75E(&5S<&5C:69I8V]U(&YO;B#I
M(';A;&ED;P!#86UP;W,@9&ES<&_Q:6)L97,Z`$%N:79E<G-A<FEO`$-A;&5N
M9&%R:6\`0V%N8V5L87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<P!496SI9F]N
M;R!M\V)I;`!096-H87(@82!X86YE;&$`0V]M<&'Q[6$`1F%L;&\@\R!A8G)I
M<B!O(&WS9'5L;R!D92!T87)E9F%S(&1E(&UA;G1E;65N=&\@)7,`1$0`1&EA
M<FEA;65N=&4`261E;G1I9&%D92!P<F5D971E<FUI;F%D80!$97-C<FEC:?-N
M(&1O('!R;V)L96UA`%)E>&ES='+A<F]N<V4@;W,@9&5T86QL97,@<&%R82!O
M(&%D;6EN:7-T<F%D;W(N`$]P8VGS;G,@9&4@=FES=6%L:7IA8VGS;@!.;VX@
M86-C961A(&1I<F5C=&%M96YT92!A(")M86EN=&5N86YC92YP:'`B`$-O<G)E
M;R!E;&5C='+S;FEC;P!396X@<F5S=6QT861O+@!%<G)O`$-A9&$@,34@;6EN
M=71O<P!#861A(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU=&]S`$-A9&$@:6YI
M8VEO(&1E('-E<VGS;@!#861A(&UE9&EA(&AO<F$`0V%D82!M:6YU=&\`17AE
M;7!L;R!D92!V86QO<F5S.@!&86QL;W4@\R!R96-U<&5R87(@87,@<')E9F5R
M96YC:6%S+@!&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0+@!&
M87@`07AU9&$`16YD97)E>F\@<&%R=&EC=6QA<@!496SI9F]N;R!P87)T:6-U
M;&%R`$AO<F1E`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D
M;W,Z`$QI;F=U80!,:7-T87(@;W,@=&5M87,@9&4@87AU9&$`16YT<F%R`%!E
M8VAA<B!A('-E<VGS;@!-30!#;W)R96\`0V%M<&]S(&-O<G)E<W!O;F1E;G1E
M<P!-96YS87AE`$UE;G-U86QM96YT90!.;VUE`$YU;F-A`$YO=&%S`$]P8VGS
M;G,`3W5T<F$@:6YF;W)M86-I\VX`0VAA=F4@9&4@86-C97-O`%)E86QI>F%R
M(&]P97)A8VGS;G,@9&4@;6%N=&5M96YT;P!496SI9F]N;P!!8VAE9W5E('5N
M(')E<W5M;R!D;R!P<F]B;&5M82X`06-H96=U92!O('-E=2!N;VUE(&1E('5S
M=6%R:6\@92!C:&%V92!D92!A8V-E<V\`1&5S8W)I8VGS;B!D;R!P<F]B;&5M
M80!386-A<B!O('!A<@!296=R97-A<B#A<R!O<&-I\VYS`$9U;F-I\VX`1V%R
M9&%R(&%S(&]P8VGS;G,`4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A(&1A
M=&$Z`%-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&1A=&$Z`%-E;&5C8VEO;F4@
M;R!F;W)M871O(&1A(&AO<F$Z`%-E;&5C8VEO;F4@9&]U<R!C86UP;W,@<75E
M(&-O:6YC:61A;BX`4V5L96-C:6]N92!A(&QI;F=U83H`16YV:6%R(&\@:6YF
M;W)M92!D92!P<F]B;&5M87,`3VUI=&ER(&\@;6%N=&5M96YT;P!%;G1R861A
M(&1E(&-A<F%C=&5R97,@97-P96-I86ES`$-O<G)E8W1A;65N=&4`5&%R969A
M<P!/(&[Z;65R;R!D96)E('-E<B!P;VQO(&UE;F]S('5N(#$N`$\@=F%L;W(@
M9&5B92!S97(@=6X@;OIM97)O+@!4[71U;&\`55),`$YO;B!F;VD@<&]S:6)L
M92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+@!.;VX@9F]I('!O<VEB;&4@
M=')A9'5C:7(@97-T92!D;V-U;65N=&\@9&4@5V]R9`!$97-F86-E<B!O<R!C
M86UB:6]S`$]P8VGS;G,@9&\@=7-U87)I;P!5<W5A<FEO`$%V:7-O`%-E;6%N
M86QM96YT90!"96YV:61A(&$@)7,`0F5N=FED;R]A+"`E<P!%;F1E<F5Z;R!D
M;R!T<F%B86QL;P!496SI9F]N;R!D;R!T<F%B86QL;P!!00!!;G5A;&UE;G1E
M`$1E<V-R:6)A(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@:6YF;W)M
M92X`0V%D=6-O=2!A('/Z82!S97-I\VX@96X@)7,@97AP:7)O=2X@26YI8VEE
M('5N:&$@;F]V82!S97-I\VXN`$$@<_IA(&EN9F]R;6%C:?-N`$%C='5A;&EZ
MX7)O;G-E(&%S('/Z87,@;W!C:?-N<RX`6TEN9F]R;64@9&\@4')O8FQE;6%=
M`%ML:?%A("5S(&1E("5S70!487)X971A(&1E('9I<VET82`H=D-A<F0I````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:&5?24PO````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8Q`#`Q-C8R-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H
M95])3"],0U]-15-304=%4R\`````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-C$`,#(P-#$T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+VAE7TE,+TQ#7TU%4U-!1T53+VAO<F1E+FUO````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S,P,@`Q,#4Q-30S,3`V,0`P,C(P
M-3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0````"I````'````&0%``#C````K`H````````X#@``#````#D.```+
M````1@X```<```!2#@``!P```%H.```*````8@X```D```!M#@``!P```'<.
M```)````?PX```<```")#@``!P```)$.```'````F0X```H```"A#@``!P``
M`*P.```&````M`X```<```"[#@``"````,,.```&````S`X``!$```#3#@``
M!P```.4.```(````[0X```@```#V#@``!@```/\.```&````!@\```H````-
M#P``&````!@/```$````,0\```4````V#P``!0```#P/```%````0@\```8`
M``!(#P``"````$\/```%````6`\```H```!>#P``!````&D/```&````;@\`
M``X```!U#P``!P```(0/```2````C`\```<```"?#P``!0```*</```+````
MK0\```@```"Y#P``!````,(/```'````QP\```,```#/#P``!@```-,/```%
M````V@\```8```#@#P``!P```.</```'````[P\```4```#W#P```@```/T/
M```&`````!````<````'$```"0````\0```&````&1````8````@$```!0``
M`"<0```-````+1````0````[$```'0```$`0```(````7A````@```!G$```
M"@```'`0```'````>Q````<```"#$```!0```(L0```)````D1```!D```";
M$```!````+40```'````NA````8```#"$```!0```,D0```'````SQ````4`
M``#7$```!@```-T0```%````Y!````8```#J$```!P```/$0```'````^1``
M`!8````!$0``"@```!@1```*````(Q$```8````N$0``"````#41```(````
M/A$```0```!'$0``!0```$P1```*````4A$```D```!=$0``!@```&<1```&
M````;A$```@```!U$0``!P```'X1```*````AA$```0```"1$0``!0```)81
M```+````G!$```L```"H$0``"0```+01```%````OA$```<```#$$0``!@``
M`,P1```$````TQ$```<```#8$0``!0```.`1```(````YA$```8```#O$0``
M"````/81```(````_Q$```D````($@``"@```!(2```$````'1(```L````B
M$@``!@```"X2```(````-1(```4````^$@``!P```$02```2````3!(```8`
M``!?$@``#````&82```&````<Q(```<```!Z$@``"@```((2```,````C1(`
M``D```":$@``!P```*02```,````K!(```4```"Y$@``"0```+\2```%````
MR1(```@```#/$@``"0```-@2```&````XA(```L```#I$@``%````/42```<
M````"A,```@````G$P``!0```#`3```3````-A,```<```!*$P``!@```%(3
M```#````61,```0```!=$P``!@```&(3```'````:1,``!0```!Q$P``#@``
M`(83```-````E1,```8```"C$P``!P```*H3```(````LA,```<```"[$P``
M"0```,,3```'````S1,```@```#5$P``!````-X3```%````XQ,```8```#I
M$P``!0```/`3```*````]A,```8````!%```"`````@4```%````$10```@`
M```7%```"````"`4```,````*10```0````V%```3@$``#L4```3````BA4`
M`!````">%0``#````*\5```,````O!4``!\```#)%0``$````.D5```,````
M^A4``!`````'%@``#@```!@6```1````)Q8```P````Y%@``#````$86```*
M````4Q8```@```!>%@``#@```&<6```.````=A8```H```"%%@``#````)`6
M```.````G18```X```"L%@``"@```+L6```(````QA8```8```#/%@``#P``
M`-86```N````YA8```0````5%P``"````!H7```&````(Q<``!,````J%P``
M%P```#X7```0````5A<```H```!G%P``$P```'(7```(````AA<```X```"/
M%P``"````)X7```(````IQ<``"D```"P%P``#@```-H7```*````Z1<``!4`
M``#T%P``#@````H8```(````&1@```P````B&```"````"\8```(````.!@`
M``@```!!&```"@```$H8```,````51@```P```!B&```!@```&\8```$````
M=A@```@```![&```"@```(08```.````CQ@```H```">&```"@```*D8```*
M````M!@``!P```"_&```"````-P8```*````Y1@```X```#P&```"````/\8
M```)````"!D```X````2&0``#````"$9```(````+AD``!(````W&0``"```
M`$H9```(````4QD```P```!<&0``#````&D9```,````=AD```P```"#&0``
M!@```)`9```(````EQD```@```"@&0``#````*D9```*````MAD```P```#!
M&0``!@```,X9```2````U1D```P```#H&0``"@```/49```.`````!H``!\`
M```/&@``!@```"\:```(````-AH``!(````_&@``$@```%(:```,````91H`
M``H```!R&@``$````'T:```*````CAH```X```"9&@``!````*@:```&````
MK1H```H```"T&@``$P```+\:```0````TQH```@```#D&@``#````.T:```0
M````^AH```H````+&P``$````!8;```&````)QL```P````N&P``"````#L;
M```.````1!L```H```!3&P``"P```%X;```,````:AL```8```!W&P``%```
M`'X;```*````DQL```X```">&P``!@```*T;```,````M!L```H```#!&P``
M#````,P;```5````V1L```H```#O&P``"````/H;```3`````QP``!4````7
M'```#@```"T<```,````/!P``!<```!)'```"````&$<```/````:AP```@`
M``!Z'```#````(,<```0````D!P```P```"A'```"@```*X<```*````N1P`
M``P```#$'```#````-$<```@````WAP``!L```#_'```#@```!L=```.````
M*AT```8````Y'0``!P```$`=```,````2!T``!````!5'0``(P```&8=```;
M````BAT``!<```"F'0``"@```+X=```0````R1T``!P```#:'0``#````/<=
M```.````!!X```H````3'@``#P```!X>```&````+AX```<````U'@``"```
M`#T>```(````1AX``!(```!/'@``#````&(>```0````;QX```@```"`'@``
M#@```(D>```0````F!X``!,```"I'@``!````+T>```!````H````$``````
M``````````````"F````HP```"D````3`````````&(````8````$````$P`
M````````!P```#H````R````8P```(T````:`````````$H```!:````7@``
M`$<```!J````#````%\````D````%0```"@````P````@@```'4```!"````
MD@```%L```"1````F````#T````Q````"@````8````9````<P``````````
M`````````"X````>`````````",````"````````````````````````````
M```Y````5P`````````<````:0``````````````9````'$````K````)@``
M`%T```!W````3@```$D````T````@0```'@`````````9P```&\```"#````
M!````*D```".````%@```"T```!F````#0```)H````B````'0```!(```!+
M````I0````````"*`````````"P```!Y````G@``````````````/P``````
M``"6````80```'P```!E````:`````````"%````-0```'L```"`````)P``
M`!\````;`````````%8````O````AP```)<`````````?P```'X`````````
M4@```*0```!L````!0```#P```"=``````````,````````````````````[
M````````````````````4````````````````````*$```!<`````````$4`
M``!&````,P``````````````%P````````"B````0P````````!K````%```
M`#<```!!``````````\````@````F0```(@```!5````)0```!$```"$````
M```````````)````;@``````````````=````'H``````````````#X```!3
M````J```````````````G````$\````V````C````(\```!@````E0``````
M``!8````BP````````")````2````)\```!V`````````$T```"4````1```
M`"H`````````(0```&T```"3````"P```*<```!P````40```%D```";````
M"`````````!]````5````)````!R````.`````````"&````#@````!!9&1R
M97-S($)O;VL`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%N=&%R8W1I
M8V$`07)G96YT:6YA`$%R;65N:6$`075S=')A;&EA`$%U<W1R:6$`0F%H86UA
M<P!"86AR86EN`$)A;F=L861E<V@`0F5L9VEU;0!"96QI>F4`0F]L:79I80!"
M;W1S=V%N80!"<F%Z:6P`0G)U;F5I($1A<G5S<V%L86T`0G5R=6YD:0!#86UB
M;V1I80!#86UE<F]O;@!#86YA9&$`0V%N8V5L`$-A<&4@5F5R9&4`0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC`$-H860`0VAI;&4`0VAI;F$`0VQE87(`0VQO
M=61Y`$-O;&]M8FEA`$-O;F=O`$-O<W1A(%)I8V$`0W5B80!#>7!R=7,`0WIE
M8V@@4F5P=6)L:6,`1&5N;6%R:P!$;VUI;FEC86X@4F5P=6)L:6,`16-U861O
M<@!%9WEP=`!%;"!386QV861O<@!%=&AI;W!I80!&:6II`$9I;FQA;F0`1F]G
M`$9R86YC90!'86)O;@!'86UB:6$`1V5O<F=I80!'97)M86YY`$=H86YA`$=O
M`$=R965C90!'<F5N861A`$=U871E;6%L80!'=6EN96$`1W5Y86YA`$AA:71I
M`$AE879Y(%0M4W1O<FT`2&5L<`!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*0!(;VYD=7)A<P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;F=A<GD`26-E
M;&%N9`!);F1I80!);F1O;F5S:6$`27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9@!)<F%Q`$ER96QA;F0`27-R865L`$ET86QY`$IA;6%I8V$`2F%P86X`2F]R
M9&%N`$ME;GEA`$MU=V%I=`!,96)A;F]N`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,=7AE;6)O=7)G`$UA9&%G87-C87(`36%L87=I`$UA;&%Y
M<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%U<FET86YI80!-875R:71I=7,`
M365X:6-O`$UO;F%C;P!-;VYG;VQI80!-;W)O8V-O`$UO>F%M8FEQ=64`3F%M
M90!.97!A;`!.971H97)L86YD<P!.97<@6F5A;&%N9`!.:6-A<F%G=6$`3FEG
M97(`3FEG97)I80!.;W)W87D`3VUA;@!/<'1I;VYS`$]T:&5R`%!A:VES=&%N
M`%!A;F%M80!087)A9W5A>0!087-S=V]R9`!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!097)U`%!H:6QI<'!I;F5S`%!O;&%N9`!0;W)T=6=A;`!1871A<@!2;VUA
M;FEA`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4V%U9&D@07)A8FEA`%-E
M87)C:`!396YE9V%L`%-E>6-H96QL97,`4VEE<G)A($QE;VYE`%-I;F=A<&]R
M90!3;VUA;&EA`%-O=71H($%F<FEC80!3<&%I;@!3<FD@3&%N:V$`4W5D86X`
M4W5R:6YA;64`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>7)I86X@
M07)A8B!297!U8FQI8P!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1H
M86EL86YD`%1O;F=A`%1R:6YI9&%D(&%N9"!4;V)A9V\`5'5N:7-I80!4=7)K
M97D`55),`%523#H`56=A;F1A`%5K<F%I;F4`56YI=&5D($%R86(@16UI<F%T
M97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5<&QO860`57)U9W5A
M>0!5<V5R;F%M90!686YU871U`%9E;F5Z=65L80!697)S:6]N`%9I970@3F%M
M`%=I;F0`5VEN9#H`5VEN9#H@`%EE;65N`%EU9V]S;&%V:6$`6F%M8FEA`%II
M;6)A8G=E`%](96QP`%],;V<@;W5T`%]/<'1I;VYS`&%D9')E<W,@8F]O:P!N
M86UE`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXR+6-V<PI297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-BTP,BTP-R`P-#HP."TP-3`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#(M,#<@,#0Z,#@M,#4P,`I,87-T+51R86YS;&%T;W(Z($UA
M='0@4V5L<VMY(#QS96QS:WE`8V]L=6UB:6$N961U/@I,86YG=6%G92U496%M
M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]551&+3@*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`UZ'7I->H(->;UZK7E=>1UY77J@#7
MD->DUY+7H->9UZ'7JM>?`->0UYS7D=>@UYG7E`#7D-><UY+7J->9UY0`UYG7
MD=>IUZKB@)/7D->@UYC7D->HUZ?7F->9UZ?7E`#7D->HUY+7H->8UYG7H->4
M`->0UZC7GM>@UYG7E`#7D->5UZ'7F->HUYS7F=>4`->0UY77H=>8UZC7F=>4
M`->0UYG7F>*`D]>1UY37GM>4`->1UY?7J->9UYG7GP#7D=>@UY+7G->3UZD`
MUY'7G->2UYG7E`#7D=><UYG7E@#7D=>5UYS7F=>1UYG7E`#7D=>5UZ;7E=>5
MUZ#7E`#7D=>HUY;7F=><`->1UZC7E=>@UYG7F0#7D=>5UZC7E=>@UY/7F0#7
MI]>>UY'7E=>3UYG7E`#7I]>>UZC7E=>?`->GUZ#7D]>4`->IUZ#7E`#7I]>D
MUY0@UY77J->3UY0`UY37I]>4UYG7G->9UYG7E"#7E->>UZC7F]>6XH"3UY#7
MI->HUYG7I]>@UYG7J@#7IM>3`->FUYG7G->9`->AUYG7GP#7J=>>UYG7G2#7
MD=>4UYG7J->=`->IUY[7F=>=(->>UZ+7E=>@UZ#7F=>=`->GUY77G->5UY[7
MD=>9UY0`UZ?7E=>@UY+7E0#7I]>5UZ'7F->4(->HUYG7I]>4`->GUY77D=>4
M`->GUZ37J->9UZ'7F=>?`->FUYO7F=>4`->3UZ#7F=>4`->4UZC7I->5UY'7
MG->9UZ?7E"#7E->3UY77GM>9UZ#7F=>GUZ#7F=>J`->0UZ?7E=>5UY/7E=>H
M`->>UZ;7J->9UYT`UY#7G.*`D]>AUYS7E=>5UY/7E=>H`->0UZK7F=>5UZ37
MF=>4`->DUYG7DM>9`->DUYG7H-><UZ#7DP#7HM>HUZ37G`#7IM>HUZ37J@#7
MDM>1UY77GP#7DM>>UY'7F=>4`->2UY77J->2UYG7E`#7DM>HUY[7H->9UY0`
MUY+7H->4`-><UYH`UYG7E=>5UY\`UY+7J->@UY/7E`#7DM>5UY#7F->>UYS7
ME`#7DM>9UZ#7D->4`->2UYG7D->@UY0`UY37D->9UYC7F0#7H=>5UZ37JN*`
MD]>HUZ+7GM>9UYT@UZ+7EM>4`->BUY;7J->4`->5UYC7F=>GUY\`UY37E=>@
MUY/7E=>HUZ$`UYS7E]>5UZH`.M><UY?7F=>J`->4UY77H->2UZC7F=>4`->0
MUYG7H=><UZ#7DP#7E->5UY/7E0#7D->9UZ#7D]>5UZ#7EM>9UY0`UY#7F=>H
MUY\`UZ+7F=>HUZ<`UY#7F=>HUYS7H->3`->9UZG7@=>HUY#7G`#7D->9UYC7
MG->9UY0`UY+7GM>9UYG7I]>4`->9UZ37GP#7F=>HUY/7GP#7I]>@UYG7E`#7
MF]>5UY77F=>9UZH`UYS7D=>@UY77GP#7G->9UY'7J->9UY0`UYS7E=>1`-><
MUY77F]>AUY[7D=>5UZC7D@#7GM>3UY+7H=>GUZ@`UY[7G->5UY77F0#7GM><
MUYG7F=>6UYG7E`#7E->0UYG7F=>=(->4UY[7G->3UYG7E=>5UYG7F=>=`->>
MUYS7F0#7GM><UYC7E`#7GM>0UY77J->9UYC7H->9UY0`UY[7D->5UZC7F=>F
MUYG7E=>A`->>UYO7H=>9UZ?7E0#7GM>5UZ#7I]>5`->>UY77H->2UY77G->9
MUY0`UY[7J->5UZ?7E0#7GM>5UY;7GM>1UYG7IP#7J=>=`->@UZ37G`#7E->5
MUYS7H->3`->@UYG7E>*`D]>6UYG7G->@UY,`UZ#7F=>GUZC7DM>5UY#7E`#7
MH->9UY;7J`#7H->9UY+7J->9UY0`UZ#7E=>HUY77E=>2UYG7E`#7HM>5UY[7
MD->?`->0UZ37J=>HUY77F=>5UZH`UY#7E]>H`->DUZ?7F=>AUZK7GP#7I->@
MUY[7E`#7I->HUY+7E=>0UYG7F0#7H=>9UZ'7GM>0`->AUYG7H=>>UY`Z`->A
MUYG7H=>>UY`Z(`#7I->HUY4`UZ37F=><UYG7I->9UZ#7F=>9UYT`UZ37E=><
MUYG7GP#7I->5UZC7F->5UY+7G`#7I]>8UZ@`UZC7E=>>UZ#7F=>4`->HUY77
MH=>9UY0`UZC7E=>0UZ#7D]>4`->BUZC7D2#7E->AUZ+7E=>3UYG7J@#7E]>9
MUZ37E=>I`->AUZ#7DM><`->0UYG7F>*`D]>AUYG7F=>IUYP`UZ?7F=>9UZC7
ME"#7G->9UY#7E=>?`->AUYG7H->2UZ37E=>H`->AUY77GM><UYG7E`#7D]>H
MUY77G>*`D]>0UZ37J->9UZ?7E`#7H=>DUZC7DP#7H=>HUYD@UYS7H->GUY0`
MUZ'7E=>3UY\`UZ'7E=>HUYG7H->=`->AUY77E=>6UYG7G->@UY,`UZG7E=>5
MUY/7F=>4`->IUY77E=>9UZ4`UZ'7E=>HUYG7E`#7F->@UY;7H->9UY0`UZK7
MD->9UYS7H->3`->GUY'7E=>FUZKB@)/7D->9UYGB@)/7F->5UZ#7DM>4`->8
MUZC7F=>@UYG7D]>3(->5UYC7E=>1UY+7E0#7F->5UZ#7F=>AUYG7E`#7F->5
MUZC7I]>9UYG7E`#7D->JUZ@`UY#7JM>H.@#7D->5UY+7H->3UY0`UY#7E=>G
MUZC7F=>9UZ#7E`#7E->0UY[7F=>HUY77F=>5UZH@UY37GM>0UY77E]>3UY77
MJ@#7E->>UY[7G->;UY0@UY37GM>0UY77E]>3UZH`UY#7J->FUY77JN*`D]>4
MUY'7J->9UZH`UY37HM><UY#7E`#7D->5UZC7E=>2UY77E=>9`->GUY77DR#7
MEM>9UY37E=>9(->>UZG7JM>>UZD`UY77H->5UY#7F->5`->5UZ#7EM>5UY#7
MG->4`->2UYG7J->AUY0`UY77F=>9UYCB@)/7H->=`->HUY77EP#7J->5UY<Z
M`->HUY77ESH@`->JUYG7GM>?`->9UY77DM>5UZ'7G->1UYG7E`#7EM>>UY'7
MF=>9UY0`UY;7F=>>UY'7D=>5UY77E`#7HM>6UZC7E`#7E->JUZ#7JM>GUY77
MJ@#7D->DUZG7J->5UYG7E=>J`->AUZ37J"#7F]>JUY77D=>5UZH`UZG7G0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]I9%])1"\`````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C$`,#$V-C$W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+VED7TE$+TQ#7TU%4U-!1T53+P``````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,0`P,C`T,#0`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:61?240O3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,38T,#$V`#$P-3$U-#,Q
M,#8Q`#`R,C`T-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````'4#```<````Q!L``)T$``!L-P```````.!)```$
M````X4D``"0```#F20``*0````M*```9````-4H``"8```!/2@``#````'9*
M```D````@TH```\```"H2@``"P```+A*```H````Q$H```@```#M2@``%0``
M`/9*```+````#$L``(4````82P``"@```)Y+```.````J4L```\```"X2P``
M&````,A+```.````X4L```X```#P2P``"````/]+```N````"$P```D````W
M3```#0```$%,```'````3TP```H```!73```#P```&),```%````<DP``!$`
M``!X3```"````(I,```)````DTP```D```"=3```$P```*=,```0````NTP`
M``H```#,3````P```-=,```/````VTP```D```#K3```#0```/5,```/````
M`TT```\````330``"````"--```D````+$T```@```!130``&0```%I-```,
M````=$T```X```"!30```P```)!-```%````E$T```H```":30```P```*5-
M```7````J4T```H```#!30``#@```,Q-```C````VTT``!0```#_30``%P``
M`!1.```7````+$X``!<```!$3@``$P```%Q.```/````<$X```8```"`3@``
M"P```(=.```0````DTX``!4```"D3@``%0```+I.```'````T$X```4```#8
M3@``%0```-Y.```[````]$X``!0````P3P```P```$5/```)````24\``#D`
M``!33P``)P```(U/```L````M4\``"H```#B3P``)0````U0```&````,U``
M`!$````Z4```#````$Q0```*````65```!````!D4```%````'50```(````
MBE````X```"34```"@```*)0```$````K5````D```"R4```!@```+Q0```1
M````PU````<```#54```!````-U0```&````XE````T```#I4````P```/=0
M```3````^U````@````/40``!````!A1``!!````'5$```8```!?40``%0``
M`&91```'````?%$``!4```"$40``#P```)I1```-````JE$```\```"X40``
M#0```,A1```4````UE$```8```#K40``'0```/)1```&````$%(``!0````7
M4@``5````"Q2``!D````@5(```0```#F4@``#@```.M2```;````^E(``!H`
M```64P``'````#%3```J````3E,```4```!Y4P``$P```']3```2````DU,`
M``H```"F4P``#P```+%3```-````P5,``!$```#/4P``#````.%3```&````
M[E,```P```#U4P``!@````)4```0````"50``!$````:5```!0```"Q4```,
M````,E0```4````_5```!@```$54```'````3%0```T```!45```"0```&)4
M```)````;%0```H```!V5```&0```(%4```=````FU0```P```"Y5```$```
M`,94```(````UU0```@```#@5```!@```.E4```$````\%0```X```#U5```
M'0````15```@````(E4``*(```!#50``'P```.95```@````!E8``#`````G
M5@``D@```%A6``!!````ZU8```<````M5P``!@```#57```-````/%<``!``
M``!*5P``#````%M7```.````:%<```\```!W5P``$P```(=7```-````FU<`
M`"@```"I5P```P```-)7```-````UE<``!$```#D5P``%P```/97```;````
M#E@```(````J6```$````"U8```-````/E@```,```!,6```#@```%!8```(
M````7U@```\```!H6```#P```'A8```'````B%@```T```"06```#0```)Y8
M```+````K%@```8```"X6```"P```+]8```,````RU@```L```#86```#0``
M`.18```B````\E@```H````560``&````"!9```9````.5D``!8```!360``
M%````&I9```+````?UD```L```"+60``"0```)=9```9````H5D```L```"[
M60``%P```,=9```7````WUD```D```#W60``%@````%:```/````&%H``!D`
M```H6@``%@```$):```F````65H``$,```"`6@``'P```,1:```O````Y%H`
M``4````46P``!````!I;```*````'UL```H````J6P``$````#5;```7````
M1EL``!$```!>6P``%P```'!;```)````B%L```H```"26P```@```)U;```-
M````H%L``#@```"N6P``(````.=;```.````"%P``'L````77```&````)-<
M```%````K%P``!L```"R7```!@```,Y<```0````U5P```\```#F7```$```
M`/9<```/````!UT```\````770``#````"==```/````-%T```<```!$70``
M#@```$Q=```(````6UT``!,```!D70``!````'A=```%````?5T```@```"#
M70``"@```(Q=```,````EUT```L```"D70``$````+!=```,````P5T```<`
M``#.70``"@```-9=```-````X5T```4```#O70```P```/5=```*````^5T`
M``0````$7@``)@````E>```.````,%X``'P````_7@``%0```+Q>```%````
MTEX```<```#87@``#````.!>```(````[5X```H```#V7@``!@````%?```(
M````"%\```(````17P``!@```!1?```)````&U\``!`````E7P``"0```#9?
M```)````0%\``!H```!*7P``"````&5?```9````;E\```X```"(7P```@``
M`)=?```&````FE\```T```"A7P``$@```*]?```4````PE\```8```#77P``
M$0```-Y?```)````\%\``#D```#Z7P``/0```#1@```Z````<F````0```"M
M8```%0```+)@```&````R&````0```#/8```$0```-1@```*````YF```"(`
M``#Q8```!````!1A```%````&6$```X````?80``!0```"YA```/````-&$`
M`!(```!$80``"P```%=A```F````8V$``"D```"*80``)````+1A```F````
MV6$```@`````8@``"@````EB```)````%&(``!(````>8@``"@```#%B```,
M````/&(```\```!)8@``$````%EB``!P````:F(```X```#;8@``"0```.IB
M```*````]&(``!(```#_8@``$P```!)C```&````)F,```\````M8P``$@``
M`#UC```0````4&,``!$```!A8P``:@```'-C```/````WF,``!````#N8P``
M"P```/]C```@````"V0``!0````L9```#````$%D```,````3F0```\```!;
M9```%0```&MD```I````@60``"H```"K9```)@```-9D```G````_60``"D`
M```E90``*@```$]E```9````>F4``$(```"490``$0```-=E```2````Z64`
M`!,```#\90``%````!!F```6````)68``!<````\9@``$````%1F```1````
M968``#0```!W9@``$P```*QF```2````P&8``!0```#39@``&@```.AF```)
M`````V<``!$````-9P``!@```!]G```'````)F<``!8````N9P``!````$5G
M```$````2F<```<```!/9P``#@```%=G```,````9F<```P```!S9P``#0``
M`(!G```.````CF<```0```"=9P``#P```*)G```'````LF<```@```"Z9P``
M"0```,-G```4````S6<```P```#B9P``#0```.]G```#````_6<```8````!
M:```&0````AH```$````(F@```T````G:```"@```#5H```0````0&@```\`
M``!1:```$0```&%H```7````<V@```H```"+:```$0```)9H```(````J&@`
M``\```"Q:```#````,%H```.````SF@``!````#=:```"P```.YH```:````
M^F@```H````5:0``#````"!I```/````+6D```@````]:0``!@```$9I```'
M````36D```4```!5:0``"P```%MI```$````9VD```,```!L:0``$P```'!I
M```3````A&D``!,```"8:0```@```*QI```$````KVD```4```"T:0``!```
M`+II```*````OVD```T```#*:0``:````-AI```%````06H```8```!':@``
M#P```$YJ```8````7FH``!<```!W:@``'P```(]J```#````KVH```@```"S
M:@``!P```+QJ```*````Q&H```L```#/:@``#0```-MJ```:````Z6H``$H`
M```$:P``!@```$]K```&````5FL``!@```!=:P``%P```'9K```-````CFL`
M`%<```"<:P```@```/1K```+````]VL```@````#;```"@````QL```+````
M%VP```P````C;```#0```#!L```,````/FP```H```!+;```%@```%9L```)
M````;6P``!````!W;```$@```(AL```'````FVP```4```"C;```#````*EL
M```(````MFP``!<```"_;```#````-=L```:````Y&P``!,```#_;```!```
M`!-M```*````&&T```0````C;0``!0```"AM```X````+FT```H```!G;0``
M#P```')M```3````@FT``!4```"6;0``$P```*QM```(````P&T```@```#)
M;0``*P```-)M``!%````_FT``$$```!$;@``!````(9N```3````BVX``!0`
M``"?;@``$P```+1N```'````R&X```4```#0;@``&P```-9N```(````\FX`
M`!$```#[;@``#@````UO```"````'&\```X````?;P``!P```"YO```.````
M-F\```8```!%;P``*````$QO```,````=6\``!P```"";P``%P```)]O``!<
M````MV\``!0````4<```'P```"EP```0````27````<```!:<```#@```&)P
M```,````<7````H```!^<```'0```(EP```9````IW````4```#!<```$0``
M`,=P```1````V7````@```#K<```"0```/1P```-````_G````H````,<0``
M!P```!=Q```/````'W$```8````O<0``"P```#9Q```:````0G$```H```!=
M<0``!P```&AQ```-````<'$```@```!^<0``'@```(=Q```)````IG$```H`
M``"P<0``%0```+MQ```%````T7$``!0```#7<0``!````.QQ```0````\7$`
M``8````"<@``!P````ER```>````$7(``"@````P<@``'````%ER```:````
M=G(``!0```"1<@``!````*9R```&````JW(```8```"R<@``"@```+ER```;
M````Q'(``#0```#@<@``-````!5S```I````2G,``"@```!T<P``*0```)US
M``!0````QW,```@````8=```!0```"%T```9````)W0``!D```!!=```(P``
M`%MT```9````?W0```@```"9=```%P```*)T```*````NG0```<```#%=```
M(0```,UT```.````[W0``!,```#^=```"````!)U```%````&W4```4````A
M=0``!````"=U```*````+'4```D````W=0``"P```$%U```-````374```P`
M``!;=0``#@```&AU```$````=W4``#(```!\=0``10```*]U```7````]74`
M`!X````-=@``%````"QV```'````078```X```!)=@``*@```%AV```&````
M@W8```P```"*=@``$0```)=V```+````J78``#8```"U=@``"@```.QV```B
M````]W8```L````:=P``#P```"9W```%````-G<```X````\=P``$P```$MW
M```'````7W<``!$```!G=P``$P```'EW```4````C7<``!@```"B=P``!P``
M`+MW```%````PW<``!(```#)=P``#@```-QW```.````ZW<```4```#Z=P``
M!0````!X```N````!G@``"8````U>```(P```%QX```#````@'@```T```"$
M>```"0```))X```#````G'@```H```"@>````@```*MX```2````KG@```0`
M``#!>```!P```,9X```,````SG@``%(```#;>```%P```"YY```2````1GD`
M``<```!9>0``!@```&%Y```.````:'D``!4```!W>0``$@```(UY```/````
MH'D``!0```"P>0``:0```,5Y```:````+WH``!<```!*>@``)P```&)Z```:
M````BGH``!<```"E>@``&P```+UZ```9````V7H``!\```#S>@``$P```!-[
M```(````)WL```D````P>P``1@```#I[```_````@7L``#<```#!>P``5P``
M`/E[```%````47P``!\```!7?```+P```'=\```(````IWP```T```"P?```
M+0```+Y\```$````['P``$\```#Q?```)0```$%]```?````9WT``!T```"'
M?0``)0```*5]```@````RWT``"0```#L?0``(````!%^```'````,GX```T`
M```Z?@``#````$A^```7````57X``!````!M?@``!````'Y^```+````@WX`
M``P```"/?@``$@```)Q^```1````KWX```P```#!?@``&@```,Y^```-````
MZ7X``!L```#W?@``$P```!-_```<````)W\``"@```!$?P``!P```&U_```3
M````=7\```0```")?P``%P```(Y_```*````IG\```P```"Q?P``"0```+Y_
M```&````R'\```@```#/?P``"0```-A_```&````XG\```T```#I?P``"P``
M`/=_```"`````X````D````&@```!P```!"````:````&(```#L````S@```
M*````&^````T````F(```!4```#-@```!P```..````(````ZX````<```#T
M@```!0```/R````'`````H$```X````*@0``"0```!F!```&````(X$```@`
M```J@0``"P```#.!```'````/X$```<```!'@0``$0```$^!```(````88$`
M`!````!J@0``$````'N!```'````C($```4```"4@0``%````)J!```+````
MKX$```T```"[@0``*````,F!```7````\H$```D````*@@``"@```!2"```'
M````'X(```(````G@@``#@```"J"```Q````.8(``"<```!K@@``%````)."
M``"I`0``J((``",```!2A```%P```':$```=````CH0``!@```"LA```(0``
M`,6$```?````YX0``"L````'A0``'0```#.%```1````484``"<```!CA0``
M5````(N%```+````X(4``#$```#LA0``!P```!Z&```'````)H8```T````N
MA@``"P```#R&```%````2(8``!````!.A@``!0```%^&```2````988```@`
M``!XA@```P```(&&```0````A88```P```"6A@```@```*.&```4````IH8`
M``P```"[A@```P```,B&```$````S(8``!H```#1A@``"0```.R&```,````
M]H8``!<````#AP``!P```!N'```/````(X<```4````SAP``&@```#F'``#'
M````5(<```L````<B```!@```"B(```)````+X@```L````YB```#0```$6(
M```7````4X@```8```!KB```,P```'*(```3````IH@``!,```"ZB```,@``
M`,Z(```3`````8D``!$````5B0``,@```">)```6````6HD```@```!QB0``
M"0```'J)```*````A(D``!0```"/B0``"````*2)```(````K8D```\```"V
MB0``#@```,:)```0````U8D```D```#FB0``"0```/")```3````^HD``!D`
M```.B@``"@```"B*```,````,XH``"H```!`B@``!P```&N*```"````<XH`
M`!````!VB@``&````(>*```#````H(H```@```"DB@``!P```*V*```-````
MM8H```L```##B@``%````,^*```5````Y(H``"\```#ZB@``(````"J+```<
M````2XL```P```!HBP``,0```'6+```%````IXL``#\```"MBP``$@```.V+
M```*`````(P```8````+C```!````!*,```$````%XP```H````<C```$P``
M`">,```%````.XP```8```!!C```!@```$B,```(````3XP```0```!8C```
M!0```%V,```"````8XP```P```!FC```10```'.,```R````N8P``$4```#L
MC```,````#*-```H````8XT``"D```",C0``)@```+:-```E````W8T``"@`
M```#C@``$@```"R.```3````/XX``!````!3C@``"0```&2.``!S````;HX`
M`"L```#BC@``%P````Z/```G````)H\``!8```!.CP``#P```&6/```?````
M=8\``!P```"5CP``40```+*/```4````!)````4````9D```$@```!^0```0
M````,I```!,```!#D```#P```%>0```$````9Y````D```!LD```"P```':0
M```'````@I```!0```"*D```#P```)^0```,````KY````\```"\D```!@``
M`,R0```4````TY````8```#HD```!````.^0```'````])```!D```#\D```
M!P```!:1```&````'I$```8````ED0``!````"R1```'````,9$```8````Y
MD0``!@```$"1```0````1Y$```8```!8D0``(@```%^1```'````@I$```L`
M``"*D0``1@$``):1```&````W9(``"P```#DD@``+````!&3```6````/I,`
M`$````!5DP``#````):3```P````HY,``!4```#4DP``$@```.J3```D````
M_9,```@````BE```&P```"N4```-````1Y0``+\```!5E```"````!65```.
M````'I4``!4````ME0``&````$.5```-````7)4```T```!JE0``!@```'B5
M```K````?Y4```H```"KE0``"@```+:5```(````P94```H```#*E0``$```
M`-65```%````YI4``!(```#LE0``"P```/^5```Z````"Y8``#P```!&E@``
M$0```(.6```-````E98```D```"CE@``!@```*V6```0````M)8```X```#%
ME@``$````-26```5````Y98``!,```#[E@``#P````^7```M````'Y<```\`
M``!-EP``)0```%V7```,````@Y<```P```"0EP``!0```)V7```$````HY<`
M``@```"HEP``!0```+&7```3````MY<```H```#+EP``$````-:7```R````
MYY<``!0````:F```%````"^8```<````1)@``!8```!AF```$@```'B8```/
M````BY@```<```";F```"````*.8```/````K)@``!0```"\F```&P```-&8
M```)````[9@```4```#WF```$P```/V8``!)````$9D``!,```!;F0``!```
M`&^9```*````=)D``#T```!_F0``+````+V9```L````ZID``"L````7F@``
M+0```$.:```'````<9H``!0```!YF@``"P```(Z:```.````FIH``!0```"I
MF@``%````+Z:```Y````TYH```\````-FP``"0```!V;```+````)YL``!0`
M```SFP``!@```$B;```0````3YL```8```!@FP``"````&>;```%````<)L`
M``T```!VFP```P```(2;```-````B)L```@```"6FP``!@```)^;``!5````
MIIL```4```#\FP``&`````*<```+````&YP``!(````GG```#````#J<```Q
M````1YP```P```!YG```%@```(:<```4````G9P```8```"RG```&0```+F<
M```$````TYP```\```#8G```9@```.B<``!H````3YT```@```"XG0``#P``
M`,&=```7````T9T``!<```#IG0``)0````&>```S````)YX```D```!;G@``
M%@```&6>```6````?)X``!(```"3G@``%P```*:>```8````OIX``!$```#7
MG@``#0```.F>```'````]YX``!0```#_G@``!P```!2?```8````')\```\`
M```UGP``!0```$6?```-````2Y\```4```!9GP``!@```%^?```'````9I\`
M``T```!NGP``"````'R?```'````A9\```<```"-GP``%0```)6?```H````
MJY\```L```#4GP``$````."?```&````\9\```8```#XGP``!@```/^?```%
M````!J````T````,H```)@```!J@```D````0:```+L```!FH```(P```"*A
M```E````1J$``#$```!LH0``O0```)ZA``!4````7*(```8```"QH@``!```
M`+BB```)````O:(```D```#'H@``#@```-&B```3````X*(```X```#TH@``
M$0````.C```-````%:,``#<````CHP``!0```%NC```-````8:,``!$```!O
MHP``%P```(&C```;````F:,```(```"UHP``$````+BC```0````R:,```0`
M``#:HP``"P```-^C```(````ZZ,```T```#THP``$`````*D```'````$Z0`
M``T````;I```#0```"FD```(````-Z0```4```!`I```"0```$:D```*````
M4*0```D```!;I```"P```&6D```G````<:0```L```"9I```'0```*6D```9
M````PZ0``!D```#=I```$````/>D```)````"*4```P````2I0``"P```!^E
M```?````*Z4```L```!+I0``$@```%>E```2````:J4```D```!]I0``%P``
M`(>E```1````GZ4``!T```"QI0``'0```,^E```I````[:4``%8````7I@``
M*@```&ZF```X````F:8```L```#2I@``!````-ZF```+````XZ8```D```#O
MI@``"0```/FF```2`````Z<``!,````6IP``$@```"JG```*````/:<```D`
M``!(IP```@```%*G```,````5:<``$$```!BIP``(0```*2G```/````QJ<`
M`)T```#6IP``&@```'2H```)````CZ@``"8```"9J```!````,"H```/````
MQ:@```X```#5J```#P```.2H```.````]*@``!,````#J0``#````!>I```3
M````)*D```@````XJ0``%P```$&I```(````6:D``!8```!BJ0``!0```'FI
M```#````?ZD```@```"#J0``!P```(RI```(````E*D``!````"=J0``%@``
M`*ZI```,````Q:D```8```#2J0``'P```-FI```?````^:D```4````9J@``
M"````!^J```-````**H```<````VJ@``+P```#ZJ```3````;JH``)\```""
MJ@``%P```"*K```(````.JL```<```!#JP``#````$NK```'````6*L```D`
M``!@JP``!0```&JK```*````<*L```,```![JP``!0```'^K```$````A:L`
M`!$```"*JP``#0```)RK```,````JJL``"(```"WJP``!@```-JK```<````
MX:L``!0```#^JP``"````!.L```&````'*P``!`````CK```$P```#2L```1
M````2*P```0```!:K```"0```%^L```)````::P``$X```!SK```4````,*L
M``!0````$ZT```@```!DK0``%0```&VM```&````@ZT```<```"*K0``&@``
M`)*M```,````K:T``!\```"ZK0``!@```-JM```%````X:T```X```#GK0``
M!0```/:M```>````_*T``#L````;K@``"P```%>N```Z````8ZX``"X```">
MK@``)````,VN```N````\JX```H````AKP``"P```"RO```'````.*\``!D`
M``!`KP``"@```%JO```-````9:\``!````!SKP``#P```(2O``":````E*\`
M``T````OL```"@```#VP```+````2+```!(```!4L```$P```&>P```-````
M>[```!$```")L```%@```)NP```3````LK```!D```#&L```DP```."P```.
M````=+$``!````"#L0``"0```)2Q```A````GK$``!D```#`L0``#P```-JQ
M```.````ZK$``!$```#YL0``&0````NR```T````);(``#0```!:L@``-```
M`(^R```T````Q+(``#````#YL@``,````"JS```;````6[,``$$```!WLP``
M%P```+FS```7````T;,``!D```#ILP``&0````.T```<````';0``!P````Z
MM```&0```%>T```9````<;0``#P```"+M```%````,BT```2````W;0``!4`
M``#PM```%P````:U```*````'K4``#D````IM0``#````&.U```'````<+4`
M`!0```!XM0``!````(VU```$````DK4```0```"7M0``"P```)RU```3````
MJ+4```D```"\M0``"@```,:U```.````T;4```D```#@M0``#@```.JU```(
M````^;4```8````"M@``(`````FV```8````*K8``"````!#M@``$@```&2V
M```%````=[8```@```!]M@``'@```(:V```$````I;8```<```"JM@``!P``
M`+*V```4````NK8``!H```#/M@``!P```.JV```6````\K8```@````)MP``
M#0```!*W```-````(+<``!$````NMP``#````$"W```/````3;<``!0```!=
MMP``#````'*W```?````?[<```T```"?MP``#````*VW```:````NK<```8`
M``#5MP``!0```-RW```'````XK<```4```#JMP``"P```/"W```%````_+<`
M``8````"N```&0````FX```8````([@``!D````\N````@```%:X```$````
M6;@```4```!>N```!0```&2X```+````:K@```P```!VN```;````(.X```%
M````\+@```8```#VN```$0```/VX```N````#[D``"P````^N0``*0```&NY
M```#````E;D```L```"9N0``!P```*6Y```*````K;D```T```"XN0``#```
M`,:Y```<````T[D``$4```#PN0``!@```#:Z```&````/;H``"P```!$N@``
M*P```'&Z```)````G;H``'(```"GN@```P```!J[```+````'KL```8````J
MNP``"````#&[```*````.KL``!0```!%NP``%@```%J[```4````<;L```H`
M``"&NP``%````)&[```(````IKL``!$```"ONP``&````,&[```'````VKL`
M``P```#BNP``#0```.^[```*````_;L``!P````(O```"@```"6\```7````
M,+P``!0```!(O```!@```%V\```+````9+P```H```!PO```!0```'N\``!+
M````@;P``!0```#-O```'@```.*\```=`````;T``"(````?O0``(P```$*]
M```0````9KT```X```!WO0``-P```(:]``!@````OKT``%L````?O@``"0``
M`'N^```B````A;X``!D```"HO@``$@```,*^```,````U;X```<```#BO@``
M+P```.J^```(````&K\```P````COP``#````#"_```"````/;\```X```!`
MOP``!P```$^_```2````5[\```8```!JOP``(@```'&_```*````E+\``!<`
M``"?OP``'@```+>_``!K````UK\``!D```!"P```(@```%S````.````?\``
M``<```".P```$````);````4````I\````@```"\P```%@```,7````:````
MW,````D```#WP```#@````'!```,````$,$```@````=P0``"0```";!```*
M````,,$```H````[P0``"P```$;!```0````4L$```@```!CP0``*@```&S!
M```>````E\$```D```"VP0``%P```,#!```0````V,$```4```#IP0``%@``
M`._!```&````!L(```8````-P@``$@```!3"```%````)\(``!<````MP@``
M!````$7"```9````2L(```4```!DP@``!@```&K"```A````<<(``#,```"3
MP@``)````,?"```1````[,(``!$```#^P@``$P```!##```$````),,```4`
M```IPP``#P```"_#```B````/\,``#L```!BPP``1````)[#```O````X\,`
M`"D````3Q```+0```#W$``!B````:\0```<```#.Q```!P```-;$```7````
MWL0``!8```#VQ```(@````W%```<````,,4```<```!-Q0``'````%7%```(
M````<L4```4```![Q0``)P```('%```-````J<4``!$```"WQ0``!@```,G%
M```%````T,4```4```#6Q0``!0```-S%```2````XL4``!@```#UQ0``!P``
M``[&```2````%L8``!P````IQ@``#````$;&```$````4\8``#T```!8Q@``
M7````);&```9````\\8``!P````-QP``%0```"K'```(````0,<```T```!)
MQP``*0```%?'```)````@<<``!````"+QP``%0```)S'```2````LL<``$4`
M``#%QP``"0````O(```?````%<@``!(````UR```%@```$C(```-````7\@`
M`!(```!MR```%P```(#(```%````F,@``!(```">R```%@```+'(```6````
MR,@``!@```#?R```"0```/C(```%`````LD``!$````(R0``#@```!K)```.
M````*<D```8````XR0``!@```#_)```V````1LD``"P```!]R0``+````*K)
M```(````U\D```D```#@R0``"0```.K)```#````],D```H```#XR0```P``
M``/*```7````!\H```8````?R@``"0```";*```.````,,H``%\````_R@``
M'@```)_*```I````OLH``!````#HR@``"0```/G*```/`````\L``!D````3
MRP``$@```"W+```,````0,L``!T```!-RP``>0```&O+```4````Y<L``!4`
M``#ZRP``+````!#,```2````/<P``!,```!0S```&P```&3,```8````@,P`
M`"````"9S```%0```+K,```'````T,P```D```#8S```7@```.+,```Z````
M0<T``$````!\S0``5````+W-```%````$LX``!T````8S@``+@```#;.```'
M````9<X``!````!MS@``.0```'[.```)````N,X``%4```#"S@``,0```!C/
M```C````2L\``"(```!NSP``(P```)'/```?````M<\``"4```#5SP``(```
M`/O/```'````'-```!0````DT```&@```#G0```9````5-```!,```!NT```
M!0```(+0```-````B-````T```"6T```&@```*30```@````O]```!````#@
MT```(@```/'0```,````%-$``!H````AT0``%````#S1```@````4=$``"@`
M``!RT0``"P```)O1```G````I]$```0```#/T0``&0```-31```,````[M$`
M``X```#[T0``#@````K2```(````&=(```<````BT@``$@```"K2```&````
M/=(``"H```!$T@``"@```&_2```#````>M(``#@```!^T@``"````+?2```;
M````P-(``$D```#<T@``*P```";3```S````4M,``!L```"&TP``"0```*+3
M```/````K-,``!$```"\TP``!0```,[3```/````U-,``"$```#DTP``$```
M``;4```1````%]0``!(````IU```,0```#S4```(````;M0``"<```!WU```
M+0```)_4```G````S=0```X```#UU```#@````35```'````$]4```4````;
MU0``&````"'5```$````.M4```4````_U0``(0```$75```5````9]4```H`
M``!]U0``#0```(C5```0````EM4```,```"GU0``#@```*O5```M````NM4`
M`"P```#HU0``%P```!76```=`@``+=8``!T```!+V```%@```&G8```@````
M@-@``!<```"AV```(P```+G8```D````W=@``#L````"V0``(````#[9```6
M````7]D``"4```!VV0``7@```)S9```.````^]D``"X````*V@``!0```#G:
M```%````/]H```\```!%V@``#````%7:```%````8MH``!@```!HV@``"```
M`(':```1````BMH```4```"<V@``!````*+:```1````I]H```D```"YV@``
M`P```,/:```2````Q]H```L```#:V@```P```.;:```$````ZMH``"4```#O
MV@``"P```!7;```2````(=L``!L````TVP``$````%#;```/````8=L```0`
M``!QVP``)P```';;```9`0``GML``!(```"XW```"@```,O<```-````UMP`
M`!,```#DW```&````/C<```=````$=T```8````OW0``,P```#;=```8````
M:MT``!D```"#W0``.@```)W=```5````V-T``!0```#NW0``.0````/>```@
M````/=X```T```!>W@``#@```&S>```.````>]X``!D```"*W@``!P```*3>
M```(````K-X```T```"UW@``-@```,/>```Q````^MX```D````LWP``#0``
M`#;?```0````1-\``!@```!5WP``#0```&[?```.````?-\``#D```"+WP``
M"@```,7?```$````T-\```T```#5WP``&@```./?```#````_M\```@````"
MX```#@````O@```4````&N```!(````OX```%````$+@```5````5^```#,`
M``!MX```)0```*'@```I````Q^````X```#QX```/`````#A```%````/>$`
M`$<```!#X0``"P```(OA```*````E^$```8```"BX0``!````*GA```%````
MKN$``!(```"TX0``'0```,?A```&````Y>$```8```#LX0``#@```//A```0
M`````N(```D````3X@``!0```!WB```"````(^(```\````FX@``8@```#;B
M```V````F>(``$X```#0X@``-0```!_C```N````5>,``#L```"$XP``.P``
M`,#C```S````_.,``#<````PY```$0```&CD```2````>N0```X```"-Y```
M"0```)SD``!\````IN0``"T````CY0``&0```%'E```D````:^4``!<```"0
MY0``$@```*CE```C````N^4``!T```#?Y0``80```/WE```3````7^8```4`
M``!SY@``'````'GF```1````EN8``!H```"HY@``#0```,/F```$````T>8`
M``D```#6Y@``"P```.#F```%````[.8``!(```#RY@``#`````7G```$````
M$N<``!$````7YP``!@```"GG```1````,.<```@```!"YP``!@```$OG```%
M````4N<``!<```!8YP``#0```'#G```6````?N<```8```"5YP``!````)SG
M```&````H><```4```"HYP``!````*[G```3````L^<```4```#'YP``*0``
M`,WG```*````]^<```L````"Z````0```,\```!<`@``'`(``-$"````````
MDP```!0```!``@``.@,``&P!``"P````2`,``-P"````````B@(``"@#```2
M````;@,`````````````7P,```````#A`````````.0"```:`@```````'D`
M``!'`@````````````#B````3@(``+\"```\`0```````-<!``#R````D@$`
M`(`!```O`@``<````#0#``!K````2P``````````````G`$``.X```!R`P``
M\0$``%4"```0`0```P````````!K`0```````'P````G````I@$```<"``!]
M`@``F````+P"````````&P$``&@````,``````````X!```_`@```````'0!
M`````````````)<"````````'P``````````````````````````````-@``
M`',!``"&`@``^P```(L"``#W`@``)0,``&("``"\`0``FP$``#4```"?````
M&P````````"9`@``Y@```"4````%`P``AP$``(\!````````/0(````````)
M````30(``%T```!F`@``@0(``&,```"3`0``<P,```````!<`P```````#<#
M``!3````%P````````#P`0``JP````("```'````5@,``*P!``"?`0``````
M`/\"````````_@(```X#``"/`@``!@(``/,!``"'````<`(``%D#````````
MF@```$\```#&`@``(P```+,`````````U0(```````"A`0``0P```.H```!V
M`@```````,P!```6`0``N@```$\!```,`0``9`$``#(#```P````N@$``*T!
M```S`P``$0$``-$!````````!P,````````A````E0$``!$"```[`@``2@$`
M``````#L`0```````,4"```D`0`````````````F`````````.\!``"T````
M]`$``(<"```H`@``W@$``,H```!]`````````(,!```R`0``S@```+$!``!J
M`0``_P```/T!``!P`P``7P```)`!````````:`,``+L!```W`@``\0```&@"
M``!C`@``N`(``.`!``#,`@```````&\```"V`````````.H"````````E0(`
M````````````'`````````#[`0```````-@"``!K`P``$P(``$0#``![`0``
M80(``&,#``!R`0``Y`$``#H"````````:0$`````````````9P,```````#M
M`@```````*P```!W`@``=P$``+X!``!5`P``W`$``$,!````````7P$``$\"
M``!%`@```````%,"``"]`0``;0,```X"``!A`P``%`$``(L````B`P``$`(`
M`"$#``"L`@``TP(``````````````````'\"``"S`@``````````````````
M`````.L```#4`0```````.(!``"I````MP(````````(`0```````*@"```!
M`P`````````````:`P``W@```)0!``!R````+````,X!````````0@(``#X"
M``"``@```````"T#``"/`````````'T!``""````D0(``-0`````````F`$`
M`'@!``!G`0``(`,``,`!``"N`0```````.4`````````DP(``.@!````````
M<P```$D!``!.````00(````````U`0```````#("``"9`0``QP(``+L"``!D
M`@````````````!Q`@``1`$``'$`````````)0(``'\```#+````C0```#T#
M``#7`@```````&(````5`P``!P$`````````````@P```*,"``"D`@``^@(`
M````````````A0```%D!``"%`0```````'4#````````3`,```````!F`0``
MEP$````````(````9P````$"``"=`0``B0$``!4"``#:`0```````/$"```V
M`0``=P```"L!````````]P````8```!\`0```````!8"``!U````````````
M`````````````!H!``":`0``8P$```````#X````8````#$"```P`@``````
M`%("``!,`@``N0```'X!```>`P```````"$!```I````1@,``,L"```H````
M-`(```4```"T`0``4@$``-`!``!N`0``1P$``)\"`````````````"<!```$
M`0``/@````````!=`@```````#@!``#U````WP```&$!````````4@```(4"
M``"!````C@(``!T````5`0``&`(``"D#``#2`0``V@````````"@`0``\P``
M`*4!```/`@``F`(```````!0`@``I@```!0#``")`@```````.P"``!8````
M``````````#]````,`,`````````````4`$``"0```#P````@`````````#5
M`````````#4"```\`P``/````,@!``#1``````````````#3````OP``````
M``"X`````@,`````````````B`(``#@#``!*`P``]P$```````#:`@``````
M`'H```!E`@``=0(``'H"``#%`0`````````````H`0``P@```*\!``#=`0``
M'0$```````#2````!0$``$L#````````Q0```!,#``#H````RP$``#$#``#A
M`@``1`(``*H!``"C``````````0"``#!`0``D@(``%`````]````?@(``!$`
M``!'````^0```-4!``#'````>`(``+4`````````E@``````````````#P,`
M`&`"``"R`@``,P$``.<````C`@``+@(``'H!``!-````(P$``$<#````````
M``````````"I`@```````%<```"H`0```````',"`````````````&H#``"=
M````.@$```````#N`0``*P,````````@`@``%@```"8!``!>`P````````(!
M``#=````K0(``.D`````````;0$``*$"``#O`@``:@(`````````````^@``
M`$,#```@````1@```&D```````````````````"U`@``_P$`````````````
M#0```&D#``#;`0``!0(``!,`````````^`$``-D```"6`0``J0$``&P`````
M````+@````````#N`@``60```#D#````````Y0$``%@"```L`0``M`(`````
M```?`@``F@(``($!``!%`P``9@```+8!``!J````2`$``+X"```J`0``2@(`
M`"(```!I`@``+`,``%$````-`0``=````&\"`````````````)X"``!B`0``
M``````T#`````````````#$```""`@``^0$``.8"```````````````````S
M````MP``````````````O`````````!K`@``3P,``)D```````````````H"
M``"@````K@````````!:`0``=`(``.\```![`@``XP(``#X#``!N`@``40,`
M```````.`````````#L```!)`@``+@$``*<!````````6P$``)X!``"+`0``
MFP```$P`````````*@(````````Z`````````$````#I`@`````````````7
M`0``$@$``'`!``!5`````````-\"``!:`@``]@```#@"`````````````#`!
M``#-````-@(``"D"``!1`@``+P$``/4"``!"`0``B0```/8!````````>0$`
M`&T"``"5````60(````````"````$````'P"```8`P``$P$``(0`````````
M)@,``!$#````````O@`````#`````````````$T!``"*`0``90```+D!``!V
M````7@```#0!``#4`@``C`$````````E`0``I@(``#@```"N`@```````,``
M``!;``````````````!A````[0$``(X!``"X`0````````L!``!H`0``"@,`
M`%0#```T````'0(``$4````W````Q````#\!```*```````````````9`@``
M.0(``,D!```B`@``V0(```8!```:````YP(```P"``!7`0```````)<`````
M````MP$``"X#````````J@```"T```!``0``Z`(``!8#`````````````,<!
M````````I0(``"T"```>````L0(``/0```##`0````````````"@`@``7P(`
M`)$````>`0``N@(```````"K`0``6P,```````#8````/`(```0```!+`0``
M#`,``!P#````````;P,`````````````1````/L"```*`0``-0,````````S
M`@``1@$```D#````````O0(``)$!``#*`0``(0(`````````````PP```/`"
M``"#`@``P0(```\``````@``O0```/4!````````P@(```````!;`@``````
M`'8!````````L`$``",#``!<`0``3@,``!L"``!"`````````/(!``#9`0``
MT`(``.("````````S0$``$D```"Y`@``&`$``/D"``#T`@``Y0(``!D!``#&
M````.0$``"<"``!#`@``*P(``$4!`````````````(P```"(`0```````&P"
M````````D@```.<!``#/`0``D`(``/T"`````````````&\!``!M````````
M`+(!```9````V`$``!(#``!>`@``6`$``(8```!3`0```P$`````````````
M.P,``&4#``"&`0``_@```!L#``#K`@``JP(``'("``#/`@``TP$````````0
M`P``?@```,`"``#M````)`(``+,!``!!`````````*\"`````````````-8!
M``````````````````"A``````````8#``!E`0``G0(``"D!``"$`0``M0$`
M``L"```R`````````+`"``````````````````!&`@```````*<````(`@``
ME````,P```#.`@``?P$``"(!```[`0```````)P"```G`P``5P,```````"B
M`````````/X!``!)`P``T@(```````"<````;`,`````````````\P(``$(#
M```_`P``ZP$``.0```".`````````.`"````````.0`````````F`@``50$`
M`'0#``"-`0``>P```%H#``#$`0```````"\````9`P```````/8"````````
MR0```%$!````````5`(```````"D````/0$```````#<`````````"L```!N
M````70,``!0"```7`P```````*(!```_````0`,``(P"``##`@```````/P!
M````````T`````0#````````U@(``/P`````````L@```-\!``!3`P``2`(`
M````````````>0(```L#``!@`0``5@(``,@"``#&`0``/@$``#8#```)`0``
M70$``&<"``!!`P``%P(```````#$`@``J@(``-8```!.`0``R````-T"````
M`````````%X!``!X````KP```````````0``(`$````````<`0``HP$`````
M```5````+P,``-L```"6`@``E`(``"H#```````````````````+````<0$`
M`(H```"[```````````````/`0``\@(``-<``````````````#<!````````
M2P(``,T"``#!````'@(``-L"``";`@``H@(```````!7`@``_`(``)````!B
M`P``'0,``!("``"G`@``X0$``$T#````````[````/H!```#`@```````+\!
M````````R0(``(T"``!4`0``XP``````````````3`$`````````````B```
M`&`#```)`@``A`(``$H```#F`0``<0,``"0#``!D````5````$$!``!<````
M+0$``.,!````````@@$``,H"``!8`P``4@,```$!```J````I`$``.``````
M````=0$````````-`@``Z@$```````!:````9@,`````````````5@```$@`
M```L`@``I0```+$````8````````````````````9`,``/@"``!6`0``,0$`
M`+8"``">````'P,``%`#```?`0``"`,```,#``#"`0``Z0$`````````````
MK0``````````````J````-X"````(&%T(``B)7,B('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F
M34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@
M)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A
M>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%1E<FUS(&]F($%G<F5E
M;65N=``E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N`"5S(&UI;G5T97,`)7,@=&\@)7,@;V8@)7,`+"!G
M=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`Q,B!(;W5R
M($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$%-($-L;W5D<P!!
M32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E
M<G,`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M
M`$%B<VUI9&1L90!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O
M<F0`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!(97)E.@!!
M9&0@3F5W($=R;W5P`$%D9"!A(&YE=R!U<V5R.@!!9&0@;F5W(&UE;6)E<G,`
M061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<R!"
M;V]K`$%D;6EN:7-T<F%T:6]N`$%D<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!
M;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!F;W5R('-I
M9&5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L=&5R
M;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R
M;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L
M=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%N<W=E<@!!<'!L
M:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y
M+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@
M*%=I;F1O=W,M,3(U-BD`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)M96YI86X@*$%235-#
M24DM."D`07)T`$%S8VEI($%R=`!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"
M3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A;'1I
M8R`H25-/+3@X-3DM,3,I`$)A<V5L:6YE`$)L;V-K(%-E='1I;F=S`$)L;V-K
M(%1Y<&4`0F]L9`!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z
M`$)O<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@3&ES=`!#35,`0U]E;&P@
M4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%P=&EO;@!#871E
M9V]R:65S(&%N9"!,86)E;',`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L=&EC("A)4T\M
M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R
M9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A
M=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?
M:R!,:6YK+BXN`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*0!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A
M<FQY`$-L;W5D>0!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQS.@!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;G1A8W1S
M`$-O;G1I;G5E`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO
M="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C;VYN96-T('1O(&QD
M87`@<V5R=F5R`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O
M<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA
M;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!O;F4`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A
M=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M
M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E
M;&5C=&EO;@!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`1$0`1&%T851R964@
M0G)O=W-E<@!$871E(%)E8V5I=F5D`$1A>0!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`
M1&5F875L="!#;VQO<@!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T
M90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E(&-E;&P`1&5L971E
M(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E
M;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$97-C<FEB
M92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$979E;&]P;65N=`!$97<@4&]I
M;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E
M8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$
M:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO
M;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T
M("A4048I`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]N)W0@:&%V92!A;B!A8V-O=6YT
M/R!3:6=N('5P+@!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+@!$<G5G<P!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U
M<`!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A
M=&EO;@!%;&5M96YT+BXN`$5M`$5M86EL($%D9')E<W,`16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YL87)G92!%9&ET
M;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%<G)O<@!%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,`171H;FEC`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S
M`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y(&AA;&8@
M:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP
M86YD(%-I9&5B87(`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86ER
M`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3
M:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEL92!-86YA9V5R`$9I;'1E<G,`
M1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9L;V%T`$9O9P!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O
M;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'
M;P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F5E:R`H25-/+3@X-3DM-RD`1W)O
M=7`@061M:6YI<W1R871I;VX`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U
M97-T8F]O:P!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N`$AA>F4`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;64@1&ER96-T;W)Y
M`$AO<F1E`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R
M:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED
M:71Y.B``2'5M;W)I<W1S`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY
M`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE
M.@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U
M<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EM86=E(%!R979I97<Z`$EM86=E
M(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M
M(&=A;&QE<GDZ`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE
M;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:79I9'5A;"!5<V5R
M<P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A
M8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS
M97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O
M;'5M;B!B969O<F4`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R
M86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F
M;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y
M($QI;FL`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BX`26YV96YT;W)Y`$ES;VQA=&5D(%0M4W1O<FUS`$ET86QI8P!*
M86YU87)Y`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2G5L>0!*=6YE`$IU<W1I
M9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$ME<FYE;"!.97=B:65S`$MI9',`2V]R96%N("A%54,M
M2U(I`$QA7WEO=70`3&%N9W5A9V4`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@
M0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA=P!,87EO=70`
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,969T`$QI9VAT($1R:7IZ;&4`
M3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,
M:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H
M="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL@<&]I;G1S
M('1O.@!,:6YU>"!#;V]K:64`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O
M<&EC<P!,:7-T(%1A8FQE<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,
M:71E<F%T=7)E`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I
M;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]V90!,;W<`
M3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R
M(')O;6%N(&YU;6)E<G,`34T`34]41`!-86=I8P!-86EL`$UA:6P@061M:6X`
M36%K92!L:6Y?:RXN+@!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-87)G:6X`36%T
M8VAI;F<@9FEE;&1S`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO
M8VMS`$UA>0!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L
M;',`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971R:6,`36ED9&QE`$UI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-:7-C96QL86YE;W5S`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M(&%P<&QI8V%T:6]N+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9GD@
M55),`$UO;VX@4&AA<V5S`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO
M<W1L>2!3=6YN>0!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`
M37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`3D\L($D@1&\@3D]4($%G<F5E
M`$YE='=O<FL`3F5V97(`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R
M;F%M92`H;W!T:6]N86PI`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F1S(&1O
M;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P
M<P!.97AT`$YI9VAT`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@
M=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&-H86YG92X`3F\@:6-O;G,@
M9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;V9F96YS:79E(&9O<G1U
M;F5S`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N
M90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO
M<G1H97)N($AE;6ES<&AE<F4`3F]T('-E=`!.;W1E<P!.;W1H:6YG('1O(&)R
M;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R(&]F(&-O;'5M;G,`3G5M
M8F5R(&]F(')O=W,`3TL`3V)J96-T($-R96%T;W(`3V-T;V)E<@!/9F9E;G-E
M(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@
M9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C
M;W)R96-T+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@
M;F5W('=I;F1O=P!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P
M97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D
M($QI<W0`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R
M;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!(4"!#;V1E`%!(4"!3:&5L;`!0
M32!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E
M<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S
M:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!087)T;'D@0VQO=61Y`%!A<W-W;W)D
M`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9#H`4&%S
M<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O
M;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C
M96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX@(B5S
M(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R
M<V]N86P@26YF;W)M871I;VX`4&5T<P!0:&]T;W,`4&EX96QS`%!L871I='5D
M97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!O;&ET:6-S`%!O;&QS`%!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L90!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C
M:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R97-S=7)E`%!R97-S=7)E(&%T('-E
M82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<`4')I;G0@9&]C=6UE;G0`4')O8FQE;2!$97-C
M<FEP=&EO;@!0<F]J96-T<P!1=65R>0!1=6]T80!286EN`%)A:6X@16%R;'D`
M4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3
M;F]W`%)A;F1O;2!&;W)T=6YE`%)E860`4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296UA
M<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!F
M;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`
M4F5M;W9E('5S97(Z("5S`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO
M=7(@4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@
M;F5W('!A<W-W;W)D`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)O7W<@4')O<&5R=&EE<RXN
M+@!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!335,@365S<V%G
M:6YG`%-13"!3:&5L;`!34T@`4U]13"!3:&5L;`!380!386UE(&9R86UE("A?
M<V5L9BD`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I
M;VXN`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@
M16YG:6YE<P!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W
M;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE
M8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L
M;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YS;W(Z(`!3
M97!T96UB97(`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z(`!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A
M8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H
M;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H
M92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO
M9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R
M<R!I;B!T:&4@5FEC:6YI='D`4VMI<"!-86EN=&5N86YC90!3;F]W`%-N;W<@
M4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3
M:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@`%-O;F=S("8@4&]E;7,`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y
M+3,I`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%M`%-P96-I86P@
M0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET
M(')O=P!3<&]R=',`4W1A;F1A<F0`4W1A<B!4<F5K`%-T871U<P!3=')I:V5T
M:')O=6=H`%-T>6QE(%M#4U-=`%-U`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E
M<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C
M97-S9G5L;'D@=W)O=&4@)7,`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%0M4W1O<FT`5"U3=&]R;2!A
M;F0@5VEN9'D`5"U3=&]R;7,`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P
M97)T:65S`%1A<F=E=#H`5&%S:W,`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M
M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI
M)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`
M5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'D`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE
M('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`
M5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&ES(&ES("5S
M+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE(%1R86-K:6YG`%1I;64@9F]R
M;6%T`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&]D87D`5&]G9VQE($A434P@
M4V]U<F-E`%1O;6]R<F]W`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T
M:6]N<P!4=0!4=7)K:7-H("A)4T\M.#@U.2TY*0!5+E8N(&EN9&5X.B``55),
M`%523#H`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F9I;&5D`%5N
M:6-O9&4@*%541BTX*0!5;FET<P!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M=`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@
M86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP
M="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E
M='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`
M57!P97(@<F]M86X@;G5M8F5R<P!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U
M;F0`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE
M('-Y<W1E;3H`5F%C871I;VX`5F%R:6%B;&4`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65T;F%M97-E("A625-#24DI`%9I97<@86X@97AT97)N86P@=V5B
M('!A9V4`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A<FYI;F<`5V4`5V5A=&AE
M<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5B`%=E8B!3
M:71E`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B
M;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%@M4F5F`%E9`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9
M;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN
M9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`
M66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y
M(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U
M<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`6FEP
M<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`
M7T1E;&5T92!2;W<`7T=R;W5P<P!?26UA9V4@4')O<&5R=&EE<RXN+@!?36]D
M:69Y($QI;FLN+BX`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T
M=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&-A;&T`9F%L;&EN9P!F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:6YL:6YE`&QI;F5S
M70!N86UE`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S
M`'-T96%D>0!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N
M:69I960`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B`R,#`U+3`X
M+3`S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-2TP."TP-"`P.3HQ,"LP,C`P"DQA<W0M5')A
M;G-L871O<CH@2F%M97,@/&IA;65S0&%C=&EO;FUE<W-A9V4N8V]M/@I,86YG
M=6%G92U496%M.B!I9"`\:61`;&DN;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]55,M05-#24D*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@-V)I=`H`('!A9&$@`"(E<R(@<W5D
M86@@9&ET86UB86AK86X@:V4@9&%L86T@<VES=&5M(&=R=7`N`"(E<R(@<W5D
M86@@9&ET86UB86AK86X@:V4@9&%L86T@:7II;B!S:7-T96TN`"(E<R(@8F5L
M=6T@9&EB=6%T.B`E<RX`)2XR9DU"('-U9&%H(&1I9W5N86MA;B!D87)I("4N
M,F9-0B!Y86YG('-U9&%H(&1I:6II;FMA;B`H)2XR9B4E*0`E9"`E<R!D86X@
M)7,`)60@:&%R:2!S86UP86D@<V%N9&D@86YD82!H86)I<R!M87-A(&)E<FQA
M:W5N>6$N`"5D+6AA<FD@<F%M86QA;B!C=6%C80`E<R`M(%!E;6)E<FET86AU
M86X`2V]N9FER;6%S:2`M($]P97)A<VD@4&5M96QI:&%R86%N("5S`"5S(%-E
M='5P`"5S(%-Y87)A="US>6%R870@4&5R:F%N:FEA;@`E<R!P861A("5S("5S
M`"5S('-I87`@=6YT=6L@;65L86MS86YA:V%N(&]P97)A<VD@<&5M96QI:&%R
M86%N('EA;F<@<W5D86@@9&ET86YD86D@9&D@8F%W86@@:6YI+B!"97)I;&%H
M('1A;F1A('!A9&$@:V]T86L@=&5R<V5B=70@=6YT=6L@;W!E<F%S:2!M86YA
M<'5N('EA;F<@86YD82!I;F=I;FMA;B!U;G1U:R!D:6QA:W-A;F%K86X@<&%D
M82!W86MT=2!I;FDN`"5S(&UE;FET`"5S('5N='5K("5S("5S`"P@86YG:6X@
M:V5N8V%N9R`E<R`E<P`L('9A<FEA8FQE(&1A<FD@)7,@:V4@)7,`1F]R;6%T
M(#$R($IA;0!&;W)M870@,C0@2F%M`#(T(&IA;0!$871A8F%S92!B86-K96YD
M(&1I<&5R;'5K86X@=6YT=6L@87)E82!I;FDN`$%-($UE;F1U;F<`04T@1V5R
M:6UI<P!!32!(=6IA;@!!32!'97)I;6ES`$%-($=E<FEM:7,@4V%L:G4`04TO
M4$T`5&5N=&%N9R!E9&ET;W(@:6YI`%1E;G1A;F<N+BX@`$IA<F%K(&%N=&%R
M82!B86=I86X@8F%W86@@8F%R:7,@9&5N9V%N(&)A9VEA;B!B87=A:"!G86UB
M87(`2F%R86L@86YT87)A(&)A9VEA;B!T96YG86@@8F%R:7,@9&5N9V%N(&)A
M9VEA;B!T96YG86@@9V%M8F%R`$EN9F]R;6%S:2!!8V-O=6YT`%-A;F1I($%C
M8V]U;G0`06MU;G1A;G-I`%1A;6)A:`!486UB86@@1W)U<"!!;F%K`%1A;6)A
M:"!$:7-I;FDZ`%1A;6)A:"!'<G5P($)A<G4`5&%M8F%H('!E;F=G=6YA(&)A
M<G4Z`%1A;6)A:"!A;F=G;W1A(&)A<G4`5&%M8F%H('!A<V%N9V%N`%1A;6)A
M:"!-96YU("5S('-E8F%G86D@4&%N96P@;F%V:6=A<VD@36]Z:6QL80!486UB
M86@@<&5N9V=U;F$`4&5N86UB86AA;B!P96YG9W5N82!T:61A:R!D:6%K=&EF
M:V%N+@!"=6MU($%L86UA="``061M:6YI<W1R87-I`$EK;&%N`%)A=&$`4&5R
M871A86X`4V5M=6$`4V5M=6$@4&5N9V=U;F$@07-L:0!396UU82!'<G5P`%-E
M;75A(&5M<&%T('-I<VD`27II;FMA;B!P96YG871U<F%N(&1A<FD@=&EP92!D
M869T87(@;F]M;W(@8F5R=7)U=#\`4&5N9V=A;G1I($QO9VEN($E-4U``4&5N
M9V=A;G1I(%-A;F1I($E-4U``4&5N9V=A;G1I($YA;6$@4&5N9V=U;F$@24U3
M4`!096YG9V%N=&D@86QA;6%T(&5M86EL`%!E;F=G86YT:2!T96UP;&%T90!0
M96YG9V%N=&D@=&5K<SH`2F%W86)A;@!!<&QI:V%S:0!$869T87(@07!L:6MA
M<VD`07!L:6MA<VD@<W5D86@@<VEA<"X`1&EG=6YA:V%N('5N='5K($)A9VEA
M;B!!;F%K`$1I<V5T=6IU:0!!<')I;`!!<F%B("A7:6YD;W=S+3$R-38I`$%P
M86MA:"!A;F1A('EA:VEN(&%N9&$@:6YG:6X@;65M:6YD86AK86X@<&5R;6]H
M;VYA;B!P96YD869T87)A;B!U;G1U:R`E<S\`07)M96YI82`H05)-4T-)22TX
M*0!396YI`$MO9&4@07-C:6D`365M:6YT82!K;VYF:7)M87-I('-E8F5L=6T@
M;65L86MS86YA:V%N(&]P97)A<VD@<&5M96QI:&%R86%N/P!-96YC;V)A('5N
M='5K(&UE;F=H87!U<R!G<G5P('EA;F<@=&ED86L@861A+@!-96YC;V)A('5N
M='5K(&UE;F=H87!U<R!I>FEN('EA;F<@=&ED86L@861A+@!-96YC;V)A('5N
M='5K(&UE;F=U8F%H(&EZ:6X@>6%N9R!T:61A:R!A9&$N`$UE;F-O8F$@=6YT
M=6L@;65N9W5B86@@8F%G:6%N('EA;F<@=&ED86L@861A+@!!9W5S='5S`$MO
M;&]M('EA;F<@=&5R<V5D:6$Z`$%L87-A;B!"3T9(`$QA=&%R($)E;&%K86YG
M`%=A<FYA($QA=&%R($)E;&%K86YG`$)A;'1I8R`H25-/+3@X-3DM,3,I`$IA
M<F%K(&%N=&%R82!B86=I86X@8F%W86@@9V%M8F%R(&1E;F=A;B!G87)I<R!D
M87-A<B!B87)I<P!096YG871U<F%N($%R96$`5&EP92!!<F5A`$AU<G5F(%1E
M8F%L`%!E='5N:G5K(&AA;&%M86X@=V5B`$)O<F1E<@!+971E8F%L86X@0F]R
M9&5R`$)O<F1E<@!+961U86YY80!"87=A:`!$869T87(@0G5L;&5T`$--4P!0
M<F]P97)T:2!37V5L`$MA;&5N9&5R`%1E;F%N9P!4:61A:R!D87!A="!M96YG
M871U<B!U;&%N9R!S86YD:2!S96-A<F$@;W1O;6%T:7,L('-I;&%K86X@:'5B
M=6YG:2!A9&UI;FES=')A=&]R(&%N9&$N`$)A=&%L`$)A=&%L:V%N($QA<&]R
M86X@36%S86QA:`!*=61U;"!486)E;`!+871E9V]R:2!D86X@3&%B96P`4')O
M<&5R=&D@4V5L`$IA<F%K('-P87-I(&1A<FD@8F]R9&5R(&1E;F=A;B!T96MS
M(&1I(&1A;&%M('-E;#H`<')O<&5R=&D@<V5L`$IA<F%K('-P87-I(&%N=&%R
M('-E;"X`0V5L=&EC("A)4T\M.#@U.2TQ-"D`5&5N9V%H`$5R;W!A(%1E;F=A
M:"`H25-/+3@X-3DM,BD`56)A:`!58F%H(%-A;F1I($%N9&$`56)A:"!N86UA
M(&1A;B!A;&%M870@<V5H:6YG9V$@;W)A;F<@9&%P870@;65L:6AA=&YY82!K
M971I:V$@;65R96MA(&UE;6)A8V$@9&%N(&UE;6)A;&%S(&ME(&5M86EL(&%N
M9&$N`$UE;F=U8F%H('-A;F1I(&%N9&$@=&ED86L@9&ED=6MU;F<@9&5N9V%N
M(&MO;F9I9W5R87-I('EA;F<@<V5K87)A;F<N(%-I;&%K86X@:'5B=6YG:2!A
M9&UI;FES=')A=&]R(&%N9&$N`$MA<F%K=&5R`%!E<FEK<V$@3&EN:RXN+@!#
M:6YA(%-E9&5R:&%N82`H1T(R,S$R*0!#:6YA(%1R861I<VEO;FEL("A":6<U
M*0!0:6QI:"!C87)A('5N='5K(&UE;F%M<&EL:V%N('1A;F=G86PZ`%!I;&EH
M(&1A9G1A<B!T:7!E(&=A>6$@*'5N='5K(&1A9G1A<B!N;VUO<B!B97)U<G5T
M*0!"97)S:6AK86X`0F5R<VEH:V%N('1A9R!-4T]F9FEC90!"97)S:6AK86X@
M<&5N9V=U;F$Z("5S`$)E<G-I:&MA;B!P96YG9W5N80!"97)S:6AK86X@9&%T
M82!P96YG9W5N80!#97)A:"!B96)E<F%P82!S86%T(&QA9VD`2VQI:R!U;G1U
M:R!,86YJ=70`5'5T=7`@2F5N9&5L80!-96YD=6YG`$UE;F1U;F<@9&D@<&%G
M:2!H87)I`$)E<F%W86X`4&5R8F5S87(@4&%N96P@3F%V:6=A<VD@`%!E<F)E
M<V%R(&)O<F1E<@!787)N80!096UI;&EH(%=A<FYA`$MO;&]M`$-O;6EC<P!#
M;VUM86YD`$-O;6UA;F0@4VAE;&P`2V]M<'5T97(`2V]N9&ES:0!+;VYD:7-I
M`%!E<F)E9&%A;B!+;VYF:6=U<F%S:0!+;VYF:6=U<F%S:2!S=61A:"!H86)I
M<R!M87-A(&)E<FQA:W5N>6$N`$UE;F=A='5R("5S`$MO;F9I<FUA<VD@4V%N
M9&D`2V]N=&%K`$QA;FIU=`!#;V]K:64`4V%L:6X`4V%L:6X@4&EL:6AA;@!4
M:61A:R!D87!A="!T97)I:V%T(&1E;F=A;B!S97)V97(@;&1A<`!4:61A:R!D
M87!A="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD87``5&ED86L@9&%P870@;65N
M9V%T=7(@=6QA;F<@=6YT=6L@<&5N9V=U;F$@>6%N9R!D:6UI;G1A+B!"96)E
M<F%P82!A=&%U('-E;75A(&1E=&EL('1I9&%K(&)E;F%R+B!#;V)A(&QA9VD@
M871A=2!S:6QA:V%N(&AU8G5N9VD@861M:6YI<W1R871O<B!A;F1A(&II:V$@
M86YD82!M96UE<FQU:V%N(&)A;G1U86X@;&5B:6@@;&%N:G5T+@!4:61A:R!D
M87!A="!K96UB86QI(&ME(&MO;F9I9W5R87-I+@!4:61A:R!D87!A="!M96YY
M:6UP86X@:V]N9FEG=7)A<VD@)7,N`%1I9&%K(&1A<&%T(&UE;GEI;7!A;B!F
M:6QE(&MO;F9I9W5R87-I(&)A8VMU<"`E<RX`5&ED86L@9&%P870@;65N>6EM
M<&%N(&9I;&4@:V]N9FEG=7)A<VD@)7,N($%N9&$@9&%P870@;65N9V=U;F%K
M86X@<V%L86@@<V%T=2!D87)I('!I;&EH86X@=6YT=6L@;65N>6EM<&%N(&MO
M9&4@=&5R<V5B=70@:V5M8F%L:2!K92`E<R!A=&%U<'5N(&UE;GEA;&EN(&MO
M9&4@9&D@8F%W86@@:6YI('-E8V%R82!M86YU86P@:V4@)7,N`%1I9&%K(&1A
M<&%T(&UE;F5M=6MA;B!086YE;"!.879I9V%S:2!-;WII;&QA+B!087-T:6MA
M;B!P86YE;"!N879I9V%S:2!S=61A:"!T97)B=6MA+@!+=7)S=7,`0G5A=`!"
M=6%T(&QI;FL`0G5A="!B87)U`%=A:W1U(%-E:V%R86YG`%523"!396MA<F%N
M9R!A9&%L86@`0W5A8V$@4V5K87)A;F<`2V]N9&ES:2!396MA<F%N9SH`1V%Y
M82!396MA<F%N9P!+;W-T=6UI<V%S:2!T=6=A<R!U;G1U:R!D:6IA;&%N:V%N
M('-E8F5L=6T@;&]G;VX@:V4@)7,N`$AA<'5S`$AA<'5S('!I;&EH86X`0WER
M:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A=&%4<F5E($)R;W=S97(`5&%N
M9V=A;"!$:71E<FEM80!(87)I`$AA<'5S($MO;&]M`$1E<V5M8F5R`$%N9VMA
M($1E<VEM86P`365N9W5R86YG:2!);F1E;@!$969A=6QT`$1E9F%U;'0@5V%R
M;F$`1&5F875L="!3:&5L;`!$969I;FES:0!(87!U<P!(87!U<R!396P`2&%P
M=7,@1W)U<`!(87!U<R!S96P`2&%P=7,@:V]L;VT`2&%P=7,@<&5N9V=A;G1I
M('1E;7!L871E('EA;F<@<W5D86@@861A`$AA<'5S(&)A<FES`$AA<'5S(&ED
M96YT:71A<R!Y86YG('1E<G!I;&EH`$AA<'5S(&MO;&]M('EA;F<@<V5K87)A
M;F<`2&%P=7,@8F%R:7,@>6%N9R!S96MA<F%N9P!*96QA<VMA;B!-87-A;&%H
M`$1E<VMR:7!S:0!097)K96UB86YG86X`5&ET:6L@16UB=6X`5&ET:6L@16UB
M=6X@=6YT=6L@:F%M('1E<F%K:&ER.@!4:71I:R!%;6)U;@!!<F%H(&MI<FD@
M:V4@:V%N86X`07)A:"!K86YA;B!K92!K:7)I`$1I<F5K=&]R:0!486UP:6QK
M86X@=V%K='4@,C0@:F%M/P!486UP:6QK86X@4&EL:6AA;@!486UP:6QK86X@
M9&5T:6P@<F%M86QA;B!C=6%C80!486UP:6QK86X@<F%M86QA;B!C=6%C82`H
M5$%&*0!*86YG86X@;&%N9W-U;F<@;65N9V%K<V5S(&UA:6YT96YA;F-E+G!H
M<`!!<&%K86@@8F%R:7,@>6%N9R!P97)T86UA('1E<F1I<FD@9&%R:2!K;VQO
M;2!N86UA/R!J:6MA('EA+"!B97)I('1A;F1A('!A9&$@:V]T86L@:6YI.@!4
M:61A:R!M96UI;&EK:2!A8V-O=6YT/R!3:6QA:V%N(&UE;F1A9G1A<BX`1&]W
M;FQO860@:V]N9FEG=7)A<VD@>6%N9R!D:6AA<VEL:V%N('-E8F%G86D@<V-R
M:7!T(%!(4"X`3V)A="UO8F%T86X`56)A:`!58F%H($)L;VMI<@!58F%H($=R
M=7``56)A:"!)>FEN`%5B86@@27II;B!U;G1U:R`E<P!58F%H('!I;&EH86X@
M=6YT=6LZ`%5B86@@:7II;B!U;G1U:R`E<P!096YD:61I:V%N`$5L96UE;BXN
M+@!%;0!!;&%M870@16UA:6P`06MT:69K86X@<&5N>6ES:7!A;B!G86UB87(M
M9V%M8F%R(&1A<FD@1V%L97)I($9O=&\@9&D@9&%L86T@=&5K<S\`06MT:69K
M86X@:VQI:R!K86YA;B!M96YU(&MO;G1E:W,_`%!E<F)E<V%R($5D:71O<@!-
M87-U:VMA;B!P97)T86YY86%N(&ME86UA;F%N(&1I;6%N82!A;F1A(&%K86X@
M9&ET86YY86MA;B!A<&%B:6QA(&%N9&$@<&5R;'4@=6YT=6L@;65N9V%T=7(@
M=6QA;F<@<V%N9&D@86YD82P@(&-O;G1O:"`G87!A:V%H(&YA;6$@8FEN871A
M;F<@:V5S87EA;F=A;B!A;F1A/R<Z`$UA<W5K:V%N(%523"!G86UB87(@9&ES
M:6YI`$ME<V%L86AA;@!+97-A;&%H86X@<V%A="!M96UP97)B86AA<G5I('-A
M;F1I.B`E<P!3=6MU`%-E=&EA<"`Q-2!M96YI=`!3971I87`@,B!M96YI=`!3
M971I87`@,S`@9&5T:6L`4V5T:6%P(#4@;65N:70`4V5T:6%P('-E=&5N9V%H
M(&IA;0!3971I87`@;65N:70`0V]N=&]H(&YI;&%I+6YI;&%I.@!*86QA;FMA
M;@!097)B97-A<B!086YE;"!.879I9V%S:0!787)N82!&1P!&5%`@=7!L;V%D
M('5N='5K('-E='5P`$-E<F%H`$9A>`!&96)R=6%R:0!397!E<G1I`%-E<&5R
M=&DZ`$=E<FEM:7,@4V5B86=I86X`1V5R:6UI<R!386QJ=2!396)A9VEA;@!&
M:6QE($UA;F%G97(`1FEL=&5R`$9A<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@
M0G5L86X`1F%S92!P97)T86UA(&1A<FD@4V5P87)U:"!"=6QA;@!&;&]A=`!"
M97)K86)U=`!787)N82!4=6QI<V%N`$UA:V%N86X`56YT=6L@8G)O=W-E<B!Y
M86YG('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!G86UB87(`4F%M86QA;B!C=6%C
M82`H5$%&*0!(87)I(%)A;6%L86X@0W5A8V$@*&-A=&%T86X@8F%H=V$@<F%M
M86QA;B!C=6%C82!Y86YG(&1I:V5M8F%L:6MA;B!A:V%N(&UE;F=E;6)A;&EK
M86X@8F%I:R!S:6%N9R!A=&%U(&UA;&%M(&AA<FDL('-E:G5M;&%H(&%N9VMA
M(&1A<&%T(&1I:&%S:6QK86X@<&%D82!A<F5A(&EN:2D`3'5P82!D96YG86X@
M<V%N9&D@86YD83\`1F]R;75L:7(`4F%M86QA;@!4:7!E(%)A;6%L86X`4F%M
M86QA;@!286UA;&%N(#(`1F]R=6T`1&ET97)U<VMA;@!*;70`1G)A;64`1&%R
M:0!$97-K<FEP<VD@3&5N9VMA<`!"=6QA;B!0=7)N86UA`$YA;6$@3&5N9VMA
M<`!'86QE<FD@=6YT=6L@;65N9V%M8FEL(&=A;6)A<B!D87)I`$=A;&5R:0!-
M96YG:&%S:6QK86X@)7,@2V]N9FEG=7)A<VD@`$MO9&4@>6%N9R!D:6AA<VEL
M:V%N`$IA;&%N:V%N`$=O961E;`!096YC87)I86X@1V]O9VQE`%EU;F%N:2`H
M25-/+3@X-3DM-RD`061M:6YI<W1R87-I($=R=7``1W)U<`!)>FEN('1A;74`
M0G5K=2!T86UU`$A434Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L86L@=6YT=6L@
M;65N9VAA<'5S('-E;"!Y86YG('1E<F%K:&ER(&1I(&1A;&%M(&)A<FES+@!(
M5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H87!U<R!K
M;VQO;2!Y86YG('1E<F%K:&ER(&1I(&1A;&%M('1A8F5L+@!(5$U,07)E82!D
M96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H87!U<R!B87)I<R!Y86YG
M('1E<F%K:&ER(&1I(&1A;&%M('1A8F5L+@!"97)K86)U=`!986AU9&D@*$E3
M3RTX.#4Y+3@M22D`5&EN9V=I`$)A;G1U86X`0F%N='5A;B!M96YG9W5N86MA
M;B!E9&ET;W(`0F5L86AA;B!"=6UI`$EN:2!A9&%L86@@<&5R;75L86%N(&1A
M<FD@9FEL93H`5&EN9V=I`$AO7VUE`$1I<F5K=&]R:2!(;VUE`$AO<F1E`$=A
M<FES($AO<FES;VYT86P@9&D@9&%L86T@2%1-3`!*87)A:R!G87)I<R!H;W)I
M>F]N=&%L(&1A<FD@8F]R9&5R(&1E;F=A;B!T96MS(&1I(&1A;&%M('-E;`!(
M;W)I>F]N=&%L.@!"86=A:6UA;F$@8V%R82!A;F1A(&)I<V$@<V%M<&%I(&1I
M<VEN:3\@*%-I;&%K86X@;65L87!O<B$I`$)E<F%P82!B86YY86L@:V]L;VT@
M>6%N9R!I;F=I;B!A;F1A(&=A8G5N9VMA;C\`0F5R87!A(&)A;GEA:R!K;VQO
M;2!Y86YG(&%D82!D:7-A;F$_`$)E<F%P82!B86YY86L@8F%R:7,@>6%N9R!I
M;F=I;B!A;F1A(&=A8G5N9VMA;C\`2V5L96UB86)A;@!+96QE;6)A8F%N.@!0
M96QA=V%K`$UA<W5K:V%N($)A<FES(%-E8F5L=6UN>6$`2&%N>6$@:6MO;@!)
M:V]N('5N='5K("5S`$EK;VX@9&5N9V%N('1E:W,`3F%M82!)9&5N=&ET87,Z
M`$II:V$@86YD82!T:61A:R!M96QI:&%T(&EK;VX@;6%N87!U;B!D96YG86X@
M;65N9V=U;F%K86X@26YT97)N970@17AP;&]R97(L(&%N9&$@;75N9VMI;B!P
M97)L=2!U;G1U:R!M96YA;F1A:2!K;W1A:R!I;FD@=6YT=6L@;65N;VXM86MT
M:69K86X@:V5L96UA:&%N(%!.1RX`3&EH870@1V%M8F%R.@!54DP@1V%M8F%R
M`%523"!'86UB87(Z`$=A;6)A<B!D87)I(&=A;&5R:0!'86UB87(@9&%R:2!G
M86QE<FDZ`$=A;6)A<BUG86UB87(`26UP;W(L($QA;F=K86@@)60`2V]L;VT@
M>6%N9R!D:6EM<&]R.B`E<P!+;VQO;2!Y86YG(&1I:6UP;W(Z`$UA<W5K:V%N
M($)A<FES($)E<FEK=71N>6$`3F%M82!P96YG9W5N82!A=&%U(&%L86UA="!E
M;6%I;"!P96YG9V%N=&D@=&ED86L@8F5N87(N($-O8F$@;&%G:2!A=&%U('-I
M;&%K86X@:'5B=6YG:2!A9&UI;FES=')A=&]R(&%N9&$@:FEK82!A;F1A(&UE
M;65R;'5K86X@8F%N='5A;B!L96)I:"!L86YJ=70N`$UE;F%M8F%H($EN9&5N
M`%!E;F=G=6YA(%!R:6)A9&D`26YF;W)M87-I`$EN9F]R;6%S:2!S=61A:"!T
M:61A:R!D:7-E9&EA:V%N+@!-87-U:VMA;B!+;VQO;2!"97)I:W5T;GEA`$UA
M<W5K:V%N($=A;6)A<@!-87-U:VMA;B!486)E;`!-87-U:VMA;B!796(@3&EN
M:P!-87-U:VMA;B!+;VQO;2!396)E;'5M;GEA`$UA<W5K:V%N(&MO;&]M('EA
M;F<@8F%R=2!S971E;&%H(&MO;&]M('EA;F<@<V5K87)A;F<`36%S=6MK86X@
M:V]L;VT@>6%N9R!B87)U('-E8F5L=6T@:V]L;VT@>6%N9R!S96MA<F%N9P!-
M87-U:VMA;B!B87)I<R!Y86YG(&)A<G4@<V5T96QA:"!B87)I<R!Y86YG('-E
M:V%R86YG`$UA<W5K:V%N(&)A<FES('EA;F<@8F%R=2!S96)E;'5M(&MO;&]M
M('EA;F<@<V5K87)A;F<`36%S=6MK86X@<&%R86=R868@<V5T96QA:"!P87)A
M9W)A9B!Y86YG('-E:V%R86YG`$UA<W5K:V%N('!A<F%G<F%F('-E8F5L=6T@
M<&%R86=R868@>6%N9R!S96MA<F%N9P!-87-U:VMA;B!T96UP;&%T92!P96YG
M9V%N=&D`36%S=6MK86X@86QA;6%T(&5M86EL(&1I;6%N82!A;F1A(&1A<&%T
M(&UE;F5R:6UA('-A;F1I('EA;F<@8F%R=3H`36%S=6MK86X@<V5L(&)E<FEK
M=71N>6$`36%S=6MK86X@<V5L('-E8F5L=6UN>6$`36%S=6MK86X@:V]L;VT@
M8F5R:6MU=&YY80!-87-U:VMA;B!K;VQO;2!S96)E;'5M;GEA`$UA<W5K:V%N
M('!A<F%G<F%F(&)E<FEK=71N>6$`36%S=6MK86X@<&%R86=R868@<V5B96QU
M;6YY80!-87-U:VMA;B!B87)I<R!B97)I:W5T;GEA`$UA<W5K:V%N(&)A<FES
M('-E8F5L=6UN>6$`36%S=6MK86X@:F%W86)A;B!Y86YG(&1I<&5R;'5K86X@
M=6YT=6L@<&5R=&%N>6%A86X@:V5A;6%N86XZ`$UA<W5K:V%N+U5B86@@1V%M
M8F%R`$UA<W5K:V%N+U5B86@@3&EN:P!!<&QI:V%S:2!T:61A:R!V86QI9"X`
M27II;B!I;F1U:R!T:61A:R!V86QI9"X`26YV96YT;W)I<P!(=6IA;B!P971I
M<B!D:7-E<G1A:2!A;F=I;B!R:6)U="!D:2!D865R86@@>6%N9R!T97)P96YC
M:6P`2'5R=68@36ER:6YG`$IA;G5A<FD`2F5P86YG("A)4T\M,C`R,BU*4"D`
M2G5L:0!*=6YI`%)A=&$`4F%T82!496YG86@`4F%T82!+:7)I(&1A;B!+86YA
M;@!2871A($MI<FD`4F%T82!+86YA;@!+97)N96P@3F5W8FEE<P!!;F%K+6%N
M86L`2V]R96$@*$550RU+4BD`5&%M<&EL86X`0F%H87-A`$9A<V4@=&5R86MH
M:7(@9&%R:2!397!A<G5H($)U;&%N`%!E<G5B86AA;B!386YD:2!497)A:VAI
M<@!&87-E('1E<F%K:&ER(&1A<FD@4V5P87)U:"!"=6QA;@!097)U8F%H86X@
M5&5R86MI<CH`2'5K=6T`5&%M<&EL86X`5&EN9V=A;&MA;B!K;W-O;F<@=&%N
M<&$@8F]R9&5R`$MI<FD`1V5R:6UI<P!'97)I;6ES`$=E<FEM:7,@9&D@<&%G
M:2!H87)I`$=E<FEM:7,@8F5B97)A<&$@<V%A="!L86=I`$=E<FEM:7,`1V5R
M:6UI<R!D:7-E<G1A:2!P971I<@!"97)S86QJ=0!'97)I;6ES(%-A;&IU`%!A
M;G1U;B!*96YA:V$`3&EN:R!M96YU;FIU:R!K93H`3&EN=7@@0V]O:VEE`$1A
M9G1A<B!$871A8F%S90!$869T87(@5&]P:6L@0F%N='5A;@!$869T87(@5&%B
M96P`1&%F=&%R('!E;F=G=6YA(&1I;F]N+6%K=&EF:V%N+@!$869T87(@0F%C
M86%N`%=A:W1U(&QO8V%L.@!496UP870@4&5R:7-T:7=A(&1A;B!786MT=0!,
M;VMA<VD`3&]G:6X`3&]G(&]U=`!,;V=I;@!4=6=A<R!,;V=I;@!#:6YT80!2
M96YD86@`4VEM8F]L($AU<G5F(&ME8VEL('EU;F%N:0!3:6UB;VP@2'5R=68@
M:V5C:6P@;&%T:6X`4VEM8F]L($AU<G5F(&ME8VEL(')O;6%W:0!-30!-3U1$
M`%-U;&%P`%-U<F%T`%-U<F%T($%D;6EN`$)U870@;&EN:RXN+@!-96YG871U
M<B!D869T87(@:V%T96=O<FD@>6%N9R!H87)U<R!D:6)E<FD@;&%B96P@:71E
M;2P@9&%N('=A<FYA('EA;F<@8F5R:'5B=6YG86X@(&1E;F=A;B!K871E9V]R
M:2!T97)S96)U="X`36%R970`36%R9VEN`$UE;F-O8V]K:V%N(&MO;&]M`"!3
M=6AU(&UA:W-I;75M('EA;F<@8F5R;&%N9W-U;F<@<V5L86UA(#(T(&IA;3H`
M4W5H=2!M86MS:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`V(&IA;3H`
M2G5M;&%H(&UA:W-I;75M(&1A<FD@<&]R=&%L('EA;F<@9&EB;&]K:7(`365I
M`$]B870M;V)A=&%N`$%N9V=O=&$`365N=2!M;V1E.@!'86)U;F=K86X@<V5L
M`"!#=6%C82!-971A<@!!<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K86XN`$%R
M96$@365T87(@=&ED86L@9&ES961I86MA;BX@1&5T:6P@=&5L86@@9&EC871A
M="!U;G1U:R!A9&UI;FES=')A=&]R+@!-971R:6L`5&5N9V%H`%-U:'4@;6EN
M:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ`%-U:'4@;6EN
M:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`V(&IA;3H`3&%I;BUL86EN
M`$MO;F9I9W5R87-I('1I9&%K(&1I=&5M=6MA;BX@06YD82!H87)U<R!M96YG
M:&%S:6MA;B!K;VYF:6=U<F%S:2!S96MA<F%N9R!J:6MA(&%N9&$@:6YG:6X@
M;65N9V=U;F%K86X@87!L:6MA<VD@:6YI+@!396X`36]B:6QE($UA:6P`4V5D
M86YG`%5B86@@55),`$9A<V4@0G5L86X`4V5B86=I86X@8F5S87(@0V5R86@`
M4V5B86=I86X@8F5S87(@0F5R87=A;@!396)A9VEA;B!B97-A<B!#97)A:`!!
M8V-O=6YT+6MU`$EN9F]R;6%S:2!!8V-O=6YT+6MU`%!O<G1A;&MU`%1A;7!I
M;&%N(%!O<G1A;&MU`%1)1$%++"!387EA(%1)1$%+(%-E='5J=0!.971W;W)K
M`%1I9&%K('!E<FYA:`!+871E9V]R:2!"87)U`$)U;&%N($)A<G4`3F%M82!0
M96YG9W5N82!"87)U("AP:6QI:&%N*0!386YD:2!"87)U`%-A;F1I(&)A<G4@
M=&ED86L@8V]C;VLN`%=I;F1O=R!"87)U("A?8FQA;FLI`$)E<FET80!'<G5P
M($)E<FET80!"97)I:W5T;GEA`$UA;&%M`%1I9&%K(&%D82!D871A(&MO;F9I
M9W5R87-I('EA;F<@=&5R<V5D:6$@=6YT=6L@;65N=6YJ=6MK86X@<&5R8F5D
M86%N('5N='5K+@!4:61A:R!A9&$@<&5R=6)A:&%N+@!4:61A:R!A9&$@:6MO
M;B!Y86YG(&1I=&5M=6MA;BX`5&ED86L@861A(&QO:V%S:2!Y86YG(&1I871U
M<BX`5&ED86L@861A(')A;6%L86X@>6%N9R!T:61A:R!S;W!A;@!4:61A:R!A
M9&$@<&5N9&%F=&%R86X@>6%N9R!D:71U;F1A+@!4:61A:R!A9&$@871U<F%N
M`%1I9&%K(&%D82!S:7-I`%1I9&%K(&%D82!D:7)E:W1O<FD@<V5M96YT87)A
M('EA;F<@=&5R<V5D:6$@=6YT=6L@8V%C:&4`5&ED86L@861A('9E<G-I('EA
M;F<@9&ET96UU:V%N(&1I(&1A;&%M(&MO;F9I9W5R87-I('EA;F<@87-L:2X@
M365N9VAA<VEL:V%N(&MO;F9I9W5R87-I(&ME;6)A;&DN`%1I9&%K(&%D82!V
M97)S:2!Y86YG(&1I=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!A;F1A
M+B!-96YG:&%S:6QK86X@:V]N9FEG=7)A<VD@:V5M8F%L:2X`5&ED86L@861A
M`%1I9&%K(&%D82`H9&EG=6YA:V%N('-E;&5N9VMA<&YY82D`4V-A;F1I;F%V
M:6$@*$E33RTX.#4Y+3$P*0!"96QA:&%N($)U;6D@571A<F$`0F5L=6T@9&EA
M='5R`$-A=&%T86X`5&ED86L@861A('EA;F<@9&%P870@9&EB<F]W<V4L('-I
M;&%K86X@:V5M8F%L:2X`3F]V96UB97(`2G5M;&%H(&MO;&]M`$IU;6QA:"!B
M87)I<P!/2P!096YC:7!T82!/8FIE:P!/:W1O8F5R`$9I;'1E<B!096QA;F=G
M87)A;@!+86YT;W(`4V%N9&D@;&%M82!D86X@8F%R=2!H87)U<R!B97)B961A
M+@!386YD:2!L86UA`%-A;F1I(&QA;6$@=&ED86L@8F5N87(N`$AA;GEA(')A
M;6%L86X@>6%N9R!T:61A:R!S;W!A;@!(86YY82!P96UI;&EK(&%T874@<VES
M=&5M(&%D;6EN:7-T<F%T;W(@<V%J82!Y86YG(&1A<&%T(&UE;F=U8F%H(&ME
M<&5M:6QI:V%N(&%T874@<&5M:6QI:R!I>FEN('5N='5K(&)A9VEA;@!"=6MA
M(&1I(&IE;F1E;&$@>6%N9R!B87)U`$)U:V$@;&EN:R!I;FD@9&D@:F5N9&5L
M82!Y86YG(&)A<G4`4VES=&5M($]P97)A<VD`4&EL:6AA;@!0:6QI:&%N('5N
M='5K("5S`$1A9G1A<B!.;VUO<B!"97)U<G5T`$UE;F=A='5R`$%P;&EK87-I
M('1E;7!L871E(&%S;&D`5&5M<&QA=&4@87-L:2!D:2!D86QA;2`E<SH`3&%I
M;BUL86EN`$EN9F]R;6%S:2!,86EN`$EZ:6X@4&5M:6QI:P!+;V1E(%!(4`!0
M2%`@4VAE;&P`4$T@1V5R:6UI<P!032!'97)I;6ES`%!-($)E<G-A;&IU`%!-
M($=E<FEM:7,@4V%L:G4`4$T@0V5R86@`4$T@2'5J86X@<&5T:7(@9&ES97)T
M86D@9&5N9V%N(&%N9VEN(')I8G5T`$5K<W1E;G-I(%!/4TE8('1I9&%K(&1I
M=&5M=6MA;@!02%`@4VAE;&P`2F%R86L@<W!A<VD@9&%R:2!B;W)D97(`4V5B
M86=I86X@0F5R87=A;@!386YD:0!386YD:2!B97)H87-I;"!D:75B86@N`%-A
M;F1I.@!386YD:3H`4V%N9&D@:&%R=7,@8V]C;VLN`%-A;&EN`$QE:V%T:V%N
M(&1A<FD@8VQI<&)O87)D`%!A=&@`4&5N9&%F=&%R86X@>6%N9R!D:71U;F1A
M.@!/<F%N9P!097)S96X`365L86MS86YA:V%N($]P97)A<VD@4&5M96QI:&%R
M86%N`$UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;B!P861A('=A
M:W1U(&QO9VEN/P!)>FEN('5N='5K("(E<R(@=&ED86L@9&%P870@9&EH87!U
M<RX`27II;B!!9&UI;FES=')A<VD`26YF;W)M87-I(%!R:6)A9&D`0FEN871A
M;F<@2V5S87EA;F=A;@!&;W1O`%!I>&5L`$MA=&$M:V%T82!K;&ES90!3:6QA
M:V%N(&ML:6L@:V4@9&%L86T@8F5B97)A<&$@<V5L`%-I;&%K86X@:V]N9FER
M;6%S:2!B86AW82!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N(&5L96UE;B!I;FDZ
M`%-I;&%K86X@:V]N9FER;6%S:2!B86AW82!A;F1A(&EN9VEN(&UE;F=H87!U
M<R!L:6YK('5N='5K(&5L96UE;B!I;FDN`%-I;&%K86X@;6%S=6MK86X@;F%M
M82!U;G1U:R!K871E9V]R:2!Y86YG(&)A<G4Z`%-I;&%K86X@;6%S=6MK86X@
M<FEN9VMA<V%N('5N='5K(&UA<V%L86@N`%-I;&%K86X@;6%S=6MK86X@;F%M
M82!P96YG9W5N82!D86X@<V%N9&D@86YD80!3:6QA:V%N(&UE;6)A8V$@=&5K
M<R!B97)I:W5T(&EN:2X@06YD82!(05)54R!S971U:G4@9&5N9V%N('-Y87)A
M="US>6%R870@=6YT=6L@;65N9V=U;F%K86X@<VES=&5M+@!0;VQI=&EK`%!O
M;&QI;F<`4&]S:7-I('5N='5K(&=A;6)A<B!I;FD`4&]S:7-I('5N='5K('1A
M8F5L(&EN:0!(=6IA;B!S86QJ=2!U;G1U:R`E<R!J86T@=&5R86MH:7(Z`$ME
M;75N9VMI;F%N(#QB<B\^2'5J86X@<V%L:G4`5&5K86YA;@!496MA;F%N('!A
M9&$@<&5R;75K86%N(&QA=70Z`%1E:V%N86XZ`$QI:&%T`$QI:&%T(&=A;6)A
M<B!D:2!D86QA;2!J96YD96QA('EA;F<@8F%R=0!#971A:R!D;VMU;65N`$1E
M<VMR:7!S:2!-87-A;&%H`%!R;VIE:P!1=65R>0!+=6]T80!(=6IA;@!(=6IA
M;B!D:2!P86=I(&AA<FD`2'5J86X@8F5B97)A<&$@<V%A="!L86=I`$=E<FEM
M:7,`2'5J86X@9&%N($)E<G-A;&IU`$AU:F%N(&)E<F-A;7!U<B!D96YG86X@
M<V%L:G4`4F%M86QA;B!!8V%K`$)A8V$`66%K:6X@=6YT=6L@;65N9VAA<'5S
M("5S/R!/<&5R87-I(&EN:2!T:61A:R!D87!A="!D:6)A=&%L:V%N+@!986MI
M;B!U;G1U:R!M96UI;F1A:&MA;B!D871A('!E;F=G=6YA('5N='5K('!E;F=G
M=6YA("5S/R!/<&5R87-I(&EN:2!T:61A:R!D87!A="!D:6)A=&%L:V%N+@!5
M;&%N9VD@86MS:2!T97)A:VAI<B!A;F1A`%)E9G)E<V@@16QE;65N($UE;G4@
M1&EN86UI<SH`4F5F<F5S:"!,:6AA="!0;W)T86PZ`$1I=&%N9&%I`%)E;6]T
M92!397)V97(`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92D`4&EN9&%H:V%N`%!I;F1A:&MA;B!";&]K:7(`4&EN9&%H:V%N($-A
M<F$@1F]R;6%T`%!I;F1A:&MA;B!P87-A;F=A;@!0:6YD86AK86X@<V-R:7!T
M('EA;F<@<W5D86@@9&ES:6UP86X@9&%R:2!D:7)E:W1O<FD@<V5R=F5R('-E
M;65N=&%R82X`4&EN9&%H:V%N`%!I;F1A:&MA;B!N;V1E(&EN:2!D87)I(&1O
M:W5M96X`4&EN9&%H:V%N('!E;F=G=6YA`%!I;F1A:&MA;B!P96YG9W5N83H@
M)7,`071U<B!K96UB86QI(`!!='5R(&ME;6)A;&D@4V%N9&D`071U<B!K96UB
M86QI(%-A;F1I($%N9&$`2&%S:6P`2V5M8F%L:2!K92!0:6QI:&%N`$ME=&EK
M('5L86YG('-A;F1I(&)A<G4`2V5M8F%L:2!K92!+;VYF:6=U<F%S:0!0:6QI
M:&%N($5D:71O<B!2:6-H(%1E>'0`5&5K82UT96MI`$MA;F%N`%!R;W!E<G1I
M($)A<FES+BXN`%!R;W!E<G1I($)A<FES`%!R;W!E<G1I(&)A<FES`$)A<FES
M.@!!='5R86X`071U<F%N(&%K86X@9&ET86UP:6QK86X@9&EA;G1A<F$@<V5M
M=6$@8F%R:7,@9&%N(&MO;&]M`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&AA
M;GEA(&1I86YT87)A(&MO;&]M`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&AA
M;GEA(&1I86YT87)A(&)A<FES`$IA;&%N:V%N`%!E<V%N(%--4P!344P@4VAE
M;&P`4U-(`%-?44P@4VAE;&P`4V)T`$9R86UE('EA;F<@<V%M82`H7W-E;&8I
M`%-I;7!A;@!3:6UP86X@)7,`4VEM<&%N(%!I;&EH86X`4VEM<&%N(&MO;F9I
M9W5R87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!02%`@:V4@
M9&%L86T@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A<F$@86YD82X`2V]N9FEG
M=7)A<VD@)7,@<W5D86@@9&ES:6UP86XN`%-E8F%G:6%N($AU:F%N('!E=&ER
M(&1I<V5R=&%I(&%N9VEN(')I8G5T`$EL;74@4&5N9V5T86AU86X`4&5N8V%R
M:6%N`$UE<VEN(%!E;F-A<FEA;@!0:6QI:"!G<G5P('5N='5K(&1I=&%M8F%H
M`%!I;&EH('!E;6EL:6L@8F%R=0!0:6QI:"!S97)V97(`4&EL:6@@<&5N9V=U
M;F$@=6YT=6L@9&ET86UB86@`4&EL:6@@:V%R86MT97(@>6%N9R!A;F1A('!E
M<FQU:V%N(&1A<FD@:V]T86LM:V]T86L@9&EB87=A:"!I;FDN($%N9&$@9&%P
M870@;65N>6%L:6X@9&%N(&UE;&5K871K86YN>6$@:V4@9&%L86T@87)E82!T
M96MS+@!0:6QI:"!B871A<R!T86YG9V%L.@!0:6QI:"!F;W)M870@=&%N9V=A
M;#H`4&EL:6@@:61E;G1I=&%S('EA;F<@:6YG:6X@9&EU8F%H(&]L96@@86YD
M83H`4&EL:6@@8F%T87,@=V%K='4Z`%!I;&EH(&9O<FUA="!W86MT=3H`4&EL
M:6@@9'5A(&MO;&]M('EA;F<@8V]C;VLN`%!I;&EH('=A<FYA('-C:&5M92!A
M;F1A+@!0:6QI:"!B86AA<V$@>6%N9R!A;F1A(&EN9VEN:V%N.@!+:7)I;2!,
M87!O<F%N($UA<V%L86@`4V5N<V]R.@!397!T96UB97(`071U<B!P:6QI:&%N
M('5N='5K(&UE;F=I>FEN:V%N(&%N9&$@9&%P870@;65N9V%T=7(@=6QA;F<@
M:V5M8F%L:2!S86YD:2!A;F1A(&%P86)I;&$@86YD82!L=7!A+@!!='5R(')E
M;6]T92!S97)V97(@>6%N9R!I;F=I;B!A;F1A(&%K<V5S(&1A<FD@<&]R=&%L
M(&%N9&$N`$%T=7(@8F%H87-A+"!Z;VYA('=A:W1U(&1A;B!P:6QI:&%N('1A
M;F=G86PL('EA;F<@86YD82!I;F=I;FMA;BX`071U<B!A<&QI:V%S:2!A=V%L
M(&%N9&$L('=A<FYA('-C:&5M92P@:&%L86UA;B!R969R97-H(&1A;B!P:6QI
M:&%N('1A;7!I;&%N(&QA:6YN>6$N`%-E='5P`%-C<FEP="!S971U<"!U<&=R
M861E('1E<G-E9&EA`$)E8F5R87!A(&QO:V%S:2!Y86YG(&UU;F=K:6X@9&5N
M9V%N('!A<F%M971E<CH`0F5L86YJ80!2:6YG:V%S86X@4&5N9&5K`%!E<FQU
M:V%H(&MU;F-I(&%K<V5S(&1I9&5F:6YI<VEK86X@=6YT=6L@:V5B86YY86MA
M;B!L:6YK/P!486UP:6QK86X`5&%M<&EL:V%N('!E<F)E9&%A;B!D:6%N=&%R
M82!K;VYF:6=U<F%S:2!Y86YG(&)A<G4@9&ES:6UP86X@9&%N('EA;F<@8F%R
M=2!D:6AA<VEL:V%N+@!486UP:6QK86X@=V%K='4@;&]G:6X@=&5R86MH:7(@
M:V5T:6MA(&%N9&$@;&]G:6X_`%1A;7!I;&MA;B!P86YE;"!M96YU('1A8F5L
M(&]P97)A<VD_`%1A;7!I;&MA;B!-96YU("5S(&1I('-E8F5L86@@:VER:3\`
M5&%M<&EL:V%N(&1I86QO9R!0<F]P97)T:2!396P@5&%B96P`5&%M<&EL:V%N
M(&1I86QO9R!0<F]P97)T:2!486)E;`!486UP:6QK86X@9&EA;&]G(%!R;W!E
M<G1I($)A<FES(%1A8F5L`%1A;7!I;&MA;B!D:6%L;V<@<')O<&5R=&D@9V%M
M8F%R`$=E<FEM:7,`1V5R:6UI<R!D:2!P86=I(&AA<FD`1V5R:6UI<R!B96)E
M<F%P82!S86%T(&QA9VD`1V5R:6UI<R!D:2!S96MI=&%R(&1A97)A:`!,97=A
M=&D@4&5M96QI:&%R86%N`%-A;&IU`$=E<FEM:7,@4V%L:G4`1V5R:6UI<R!3
M86QJ=0!'97)I;6ES(%-A;&IU(&1I('!A9VD@:&%R:0!'97)I;6ES(%-A;&IU
M(&)E8F5R87!A('-A870@;&%G:0!+961A;&%M86X@4V%L:G4Z`%!E<F)A;F1I
M;F=A;B!S86QJ=2!D:2`H9&%L86TI(&%I<CH`3&%G=2`F(%-A:F%K`$5R;W!A
M(%-E;&%T86X@*$E33RTX.#4Y+3,I`$)E;&%H86X@0G5M:2!396QA=&%N`$IA
M<F%K(&%N=&%R82!S96P@>6%N9R!B97)D96MA=&%N`$IA<F%K(&%N=&%R82!I
M<VD@9&%N(&)O<F1E<B!D:2!D86QA;2!S96P`2F%R86L@<W!A<VD`2F%R86L@
M<W!A<VD@9&%N(&IA<F%K('-P87-I(&1A<FD@8F]R9&5R`%-P86T`36%S=6MK
M86X@2V%R86MT97(@4W!E<VEA;`!0:7-A:&MA;B!396P`4&ES86AK86X@:V]L
M;VT`4&ES86AK86X@8F%R:7,`3VQA:')A9V$`4W1A;F1A<@!097)J86QA;F%N
M($)I;G1A;F<`4W1A='5S`$%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I8F5R
M:2!T86YD82!G87)I<P!'87EA(%M#4U-=`$UI;@!!;F=K82]H=7)U9B]S:6UB
M;VP@>6%N9R!D:71U;&ES(&1I8F%W86@@9V%R:7,@8F%R:7,@=&5K<P!"97)H
M87-I;``B)7,B<W5D86@@8F5R:&%S:6P@9&EH87!U<RX`2V]N9FEG=7)A<VD@
M<W5D86@@8F5R:&%S:6P@9&EK96UB86QI:V%N+B!5;&%N9VD@=6YT=6L@;65L
M:6AA="!P97)U8F%H86XN(`!"86-K=7`@:V]N9FEG=7)A<VD@<W5D86@@8F5R
M:&%S:6P@9&ES:6UP86XN`$9I;&4@0F%C:W5P($MO;F9I9W5R87-I("5S('-U
M9&%H(&)E<FAA<VEL(&1I<VEM<&%N+@`G)7,G('-U9&%H(&)E<FAA<VEL(&1I
M='5L:7,`4FEN9VMA<V%N`$UA=&%H87)I(%1E<F)I=`!-871A:&%R:2!497)B
M96YA;0!#97)A:`!-871A:&%R:2!497)B:70`36%T86AA<FD@5&5R8FET+TUA
M=&%H87)I(%1E<F)E;F%M`$UA=&%H87)I(%1E<F)I=#H`36%T86AA<FD@5&5R
M8F5N86T`36%T86AA<FD@5&5R8F5N86TZ`$%N9VMA+VAU<G5F+W-I;6)O;"!Y
M86YG(&1I='5L:7,@9&EA=&%S(&)A<FES('1E:W,`1'5K=6YG86X`2'5J86X@
M<&5T:7(@9&ES97)T86D@9&5N9V%N(&%N9VEN(')I8G5T`$AU:F%N('!E=&ER
M(&1I<V5R=&%I(&1E;F=A;B!B861A:2!A;F=I;B!R:6)U=`!(=6IA;B!P971I
M<B!D:7-E<G1A:2!D96YG86X@86YG:6X@<FEB=70`4')O<&5R=&D@5&%B96P`
M4')O<&5R=&D@=&%B96P`5&%R9V5T.@!4=6=A<P!3=6AU('5N='5K(&IA;2!T
M97)A:VAI<CH`4W5H=0!3=6AU.@!3=6AU/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,`5&5M<&QA=&4@061M:6YI<W1R87-I`$AA;GEA(%1E:W,`4&5R
M871A86X@5&5K<P!496MS($)A9VEA;B!!=&%S`$MM<P!4:&%I("A425,M-C(P
M*0!096UE;&EH87)A86XZ.B!C;&%S<R!T:61A:R!B97)H87-I;"!D:7!A;F=G
M:6P`5VEN9&]W(%!I;&EH86X@<W5D86@@9&ET=71U<"X@4VEL86MA;B!+96QU
M87(`2&%N>6$@<VES:2!B86=I86X@8F%W86@`36]D92!,87EA<B!096YU:"!D
M:6ME;F%L(&1A<&%T(&UE;GEE8F%B:V%N(&UA<V%L86@@9&5N9V%N($EN=&5R
M;F5T($5X<&QO<F5R+"!J=6=A('5N='5K(&UE;F-A<FD@:V5S86QA:&%N('EA
M;F<@;65N>65B86)K86X@86YD82!T:61A:R!M86UP=2!B96ME<FIA(&1E;F=A
M;B!B86EK+B!!;F1A(&UU;F=K:6X@<&5R;F%H(&UE;F=A;&%M:2!T86UP:6QA
M;B!Y86YG(&)U<G5K+"!K96MU<F%N9V%N(&1A<FD@9G5N9W-I(&5D:71O<B!D
M86XO871A=2!B<F]W<V5R('EA;F<@<V5R:6YG(&MA;&D@<G5S86L@9&%N(&AA
M<G5S(&1I=6QA;F<@:V5M8F%L:2X@2FEK82!S:7-T96T@86YD82!A9&%L86@@
M5VEN9&]W<R`Y>"!A9&$@:V5M=6YG:VEN86X@86YD82!A:V%N(&UE;F1A<&%T
M:V%N("=+97-A;&%H86X@4&5R;&EN9'5N9V%N(%5M=6TG(&1A;B!P97)L=2!U
M;G1U:R!M92UR97-T87)T(&MO;7!U=&5R(&%N9&$N7&Y<;B!!;F1A('-U9&%H
M(&1I<&5R:6YG871I+B!3:6QA:V%N(&ML:6L@3TL@:FEK82!A;F1A(&EN9VEN
M(&UE;F-O8F$@961I=&]R(&QA>6%R('!E;G5H+@!)9&5N=&ET87,@(B5S(B!S
M=61A:"!D:6AA<'5S+@!(86YY82!S:7-I(&)A9VEA;B!K:7)I`$AA;GEA('-I
M<VD@8F%G:6%N(&MA;F%N(&1A;B!K:7)I`$AA;GEA('-I<VD@8F%G:6%N(&MA
M;F%N`%-E<G9E<B`B)7,B('-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N`%-E<G9E
M<B`B)7,B('-U9&%H(&)E<FAA<VEL(&1I<VEM<&%N+@!097)M:6YT86%N('!E
M;F1A9G1A<F%N('5N='5K("5S('-U9&%H(&)E<FAA<VEL(&1I<&EN9&%H:V%N
M+@!(86YY82!S:7-I(&)A9VEA;B!A=&%S(&1A;B!B87=A:`!(86YY82!S:7-I
M(&)A9VEA;B!A=&%S`$%R96$@:V4@=V5A=&AE<BYC;VT@=&ED86L@9&ES961I
M86MA;BX`061A(&ME<V%L86AA;B!D:2!D86QA;2!F;W)M=6QI<B!K;VYF:6=U
M<F%S:2X@375N9VMI;B!A;F1A('1I9&%K(&UE;F=I<VD@:V]L;VT@>6%N9R!D
M:7!E<FQU:V%N+@!);FD@861A;&%H("5S+@!7:6YD;W<@:6YI(&AA<G5S(&1I
M<&%N9V=I;"!D87)I(%!I;&EH86X@5VEN9&]W`%!E=&ER`%1I:V5T`$UE;F=I
M:W5T:2!786MT=0!&;W)M870@5V%K='4`2G5D=6P`2G5D=6P@*$-A=&%T86X@
M<&5T=6YJ=6LI`$AA<FD@26YI`$=A;G1I(%-O=7)C92!(5$U,`$)E<V]K`$%T
M87,`1G)A;64@071A<R`H7W1O<"D`5')A;G-L87-I`%-E;`!4=7)K:2`H25-/
M+3@X-3DM.2D`26YD96MS(%4N5CH`55),`%523#H`5&ED86L@9&%P870@=6YT
M=6L@;65N9VAA<'5S("(E<R(Z("5S+@!'87)I<R!B87=A:`!"871A;&MA;B!0
M97)U8F%H86X`0F%T86QK86X@86MS:2!T97)A:VAI<B!A;F1A`%1I9&%K(&1I
M87)S:7!K86X`56YI8V]D92`H551&+3@I`%5N:70`0F%T86QK86X@;&EN:R!P
M861A(&5L96UE;B!Y86YG('-E:V%R86YG`%-C<FEP="!Y86YG('1I9&%K(&UE
M;7!U;GEA:2!H86L@:7-T:6UE=V$@=&ED86L@9&%P870@;65N9V%K<V5S($AA
M<'5S+U-A;&EN+TQE:V%T:V%N('-E<W5A:2!R96YC86YA('5N='5K(&%L87-A
M;B!K96%M86YA;BY+;&EK($]+('5N='5K(&UE;&EH870@8V%T871A;B!T96MN
M:7,@<&%D82!M;WII;&QA+F]R9R!D:6UA;F$@86YD82!A:V%N(&1I<&5R;&EH
M871K86X@8V%R82!B86=A:6UA;F$@=6YT=6L@;65N9VEZ:6YK86X@<V-R:7!T
M('5N='5K(&1A<&%T(&UE;F=A:W-E<R!K92!C;&EP8F]A<F0N`%=A<FYA(&)E
M;'5M(&1I871U<@!097)B86AA<G5I`%!E<F)A:&%R=6D@)7,`4&5R8F%H87)U
M:2!P96YG9W5N80`B)7,B('-U9&%H(&1I<&5R8F%H87)U:2X`4V-R:7!T('5P
M9W)A9&4@<W5D86@@9&EH87!U<RX`57!L;V%D`%-E;75A(&9I;&4@<V5T=7`@
M87!L:6MA<VD@<W5D86@@9&EU<&QO860@:V4@<V5R=F5R+@!3:6UB;VP@:'5R
M=68@8F5S87(@;&%T:6X`4VEM8F]L(&AU<G5F(&)E<V%R(')O;6%W:0!'=6YA
M:V%N;&%H(&II:V$@;F%M82]S86YD:2!A;F1A(&)E<F)E9&$@=6YT=6L@<V5R
M=F5R($E-4U`N`$%D;6EN:7-T<F%S:2!096YG9W5N80!096YD869T87)A;B!0
M96YG9W5N80!096YD869T87)A;B!096YG9W5N82!S=61A:"!D:6YO;BUA:W1I
M9FMA;B!U;G1U:R!S:71E(&EN:2X`06-C;W5N="!096YG9W5N82!T:61A:R!D
M:71E;75K86X`3F%M82!096YG9W5N80!.86UA(%!E;F=G=6YA.@!.86UA(%!E
M;F=G=6YA.@!096YG9W5N82!D:2!D86QA;2!S:7-T96TZ`$QI8G5R86X`5F%R
M:6%B;&4`5F5R<VD@2V]N=')O;`!*87)A:R!P;W-I<VD@=F5R=&EK86P@86YT
M87)A(&=A<FES(&1A<V%R(&1E;F=A;B!G86UB87(`2F%R86L@<&]S:7-I('9E
M<G1I:V%L(&%N=&%R82!B;W)D97(@9&5N9V%N(&=A;6)A<@!697)T:6MA;#H`
M4V%N9V%T(%1I;F=G:0!6:65T;F%M("A625-#24DI`$QI:&%T('=E8B!P86=E
M(&5K<W1E<FYA;`!*87)A:R!086YD86YG`$IA<F%K(%!A;F1A;F<Z`%!%4DE.
M1T%404XA(2$@4$E.1$%(2T%.(%-#4DE05"!)3DD@4T5#05)!($U!3E5!3"!$
M05))("5S+@!097)I;F=A=&%N`%)A8G4`4F%M86QA;B!#=6%C80!$871A($-U
M86-A(&1I<V5D:6%K86X@;VQE:`!796(`5V5B(%-I=&4`4V5L86UA="!$871A
M;F<`4V5L86UA="!D871A;F<@:V4@)7,`4V5L86UA="!D871A;F<L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!!<&%K
M86@@87!L:6MA<VD@)7,@<&5R;'4@9&ET86UP:6QK86X@<V5T96QA:"!L;V=I
M;C\`07!A:V%H('EA;F<@;65R=7!A:V%N(&)A=&%S(&MA<F%K=&5R/P!!<&%K
M86@@>6%N9R!M97)U<&%K86X@:V%R86MT97(@:6YD96YT87-I/P!&87-E('EA
M;F<@;6%N80!0;'5G:6X@;6%N86MA:"!Y86YG(&1A<&%T(&1I86MT:69K86X@
M=6YT=6L@961I=&]R(%)I8V@@5&5X="X`3&5B87(`3&5B87(@;65N=2`E<R!P
M861A(&)A9VEA;B!K:7)I("AA:V%N(&)E<G!E;F=A<G5H('!A9&$@;&]G:6X@
M8F5R:6MU=&YY82D`3&5B87(@=&%B96P`3&5B87(@=6YI=`!,96)A<CH`5VEK
M:0!!;F=I;@!!;F=I;B!D:2!P86=I(&AA<FD`2V5C97!A=&%N(&%N9VEN(&1I
M(&1A;&%M(&MN;W0`06YG:6XZ`$%N9VEN.@!+871A($)I:F%K<V%N80!$869T
M87(@2V5I;F=I;F%N`%!E:V5R:F%A;@!8+5)E9@!960!982P@4T%902!31515
M2E4`06YD82!B97)A9&$@9&D@9&%L86T@34]$12!414M3+B!'=6YA:V%N('1O
M;6)O;"!;/#Y=('5N='5K(&UE;F=G86YT:2!K96UB86QI(&ME(&1A;&%M(&UO
M9&4@5UE325=91RX`06YD82!T:61A:R!D:6EZ:6YK86X@=6YT=6L@;65M8G5A
M="!L96)I:"!D87)I("5D(&%R96$N`$%N9&$@:&%R=7,@;65N:F5L87-K86X@
M;6%S86QA:"!S96)E;'5M(&%N9&$@9&%P870@;65N9VER:6UK86X@;&%P;W)A
M;B!M87-A;&%H+@!!;F1A(&AA<G5S(&UE;6%S=6MK86X@55),(&1I;6%N82!L
M:6YK(&EN:2!M96YU;FIU:R!K90!!;F1A(&AA<G5S(&UE;6EL:6@@<V5R=F5R
M('5N='5K(&1A<&%T(&1I:&%P=7,N`$%N9&$@:&%R=7,@;65N971A<&MA;B!N
M86UA('!E;F=G=6YA('EA;F<@:6YG:6X@9&EB97)S:6AK86XN`$%N9&$@:&%R
M=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('EA;F<@:6YG:6X@9&EP:6YD
M86AK86XN`$%N9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('5N
M='5K(&1I=&%M8F%H+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG
M9W5N82!U;G1U:R!D:7!E<F)A:&%R=6DN`$%L86UA="!%;6%I;"!!;F1A`$%N
M9&$@1&%R:3H@86QA;6%T.@!);F9O<FUA<VD@06YD80!.86UA($%N9&$`0F%C
M:V5N9"!A<VQI(&%N9&$@=&ED86L@9&%P870@;65N9'5K=6YG('!E;F1A9G1A
M<F%N('!E;F=G=6YA+"!A=&%U(&9I='5R(&EN:2!S=61A:"!D:6YO;BUA:W1I
M9FMA;B!U;G1U:R!B96)E<F%P82!A;&%S86X@;&%I;@!"<F]W<V5R(&%N9&$@
M=&ED86L@;65N9'5K=6YG('5N='5K(&9I='5R(&EN:2X`6F]N82!786MT=2!!
M;F1A(%-E:V%R86YG.@!$969A=6QT(&ED96YT:71A<R!A;F1A('-U9&%H(&1I
M=6)A:"X`1&5F875L="!I9&5N=&ET87,@86YD83H`3F%M82!L96YG:V%P(&%N
M9&$Z`%-A;F1I(&)A<G4@86YD82!U;G1U:R`E<R!A9&%L86@Z("5S`%-A;F1I
M(&%N9&$@<W5D86@@9&EA='5R('5L86YG`%-A;F1I(&%N9&$@<W5D86@@9&EA
M='5R('5L86YG+"!P97)I:W-A;&%H(&5M86EL(&%N9&$@9&%N(&QO9VEN(&1E
M;F=A;B!M96YG9W5N86MA;B!S86YD:2!B87)U(&%N9&$`4F5M;W1E('-E<G9E
M<B!A;F1A.@!#97)I80!;4V5M8G5N>6EK86X@26YD96YT87-I(%1E:W-=`%M,
M87!O<F%N($UA<V%L86A=`%M486UP:6QA;B!);F1E;G1A<VD@5&5K<R`M`%]!
M9&UI;FES=')A<VD`7T-,20!?1&%T851R964`2&%P=7,@0F%R:7,`7T=R=7``
M4')O<&5R=&D@1V%M8F%R+BXN`%5B86@@3&EN:RXN+@!)>FEN`%!I;F1A:&MA
M;B!,:6YK+BXN`%]3971U<`!0<F]P97)T:2!486)E;"XN+@!096YG9W5N80!4
M96YA;F<`:F%T=6@`1&%R:2`E<R`H)7,I('!A9&$@)7,@)7,`86YG:6X@:V5N
M8V%N9P!M87-I:"!D:2!D86QA;2!A;G1R:6%N`&)A<FES70!N86UA`'!E<G-E
M;@!P:7AE;`!N86EK`'1A;7!I;&MA;B!P97)B961A86X`=&5T87``2V5T:6L@
M<V%N9&D@9'5A(&MA;&D@=6YT=6L@;65N9VMO;F9I<FUA<VD`;65N>6%T=6MA
M;@!W96%T:&5R+F-O;0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]H=5](52\`````````````````````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C(`,#$V-C8P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+VAU7TA5+TQ#7TU%4U-!1T53+P``````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V
M,0`P,C`T-#0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:'5?2%4O
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M-#(S,3`U`#$P-3$U-#,Q,#8R`#`R,C$P-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````','```<````M#L``.\)
M``!,=P````````B?```.````"9\```\````8GP``#0```"B?```(````-I\`
M``L````_GP``#````$N?```$````6)\``!@```!=GP``&P```':?```M````
MDI\``!T```#`GP``)````-Z?```I`````Z```!D````MH```)@```$>@```,
M````;J```"0```![H```#P```*"@```+````L*````X```"\H```*````,N@
M```(````]*````H```#]H```%0````BA```2````'J$```L````QH0``A0``
M`#VA```.````PZ$```H```#2H0``#0```-VA```.````ZZ$``!$```#ZH0``
M#0````RB```,````&J(```T````GH@``E````#6B```*````RJ(```\```#5
MH@``&````.6B```,````_J(```X````+HP``#@```!JC```(````*:,```D`
M```RHP``+@```#RC```:````:Z,``#(```"&HP``.````+FC``!4````\J,`
M`%$```!'I```6@```)FD``!7````]*0``#0```!,I0``"0```(&E```-````
MBZ4```<```"9I0``"@```*&E```/````K*4```4```"\I0``!@```,*E```1
M````R:4```@```#;I0``"0```.2E```)````[J4``"4```#XI0``(````!ZF
M```3````/Z8``!````!3I@``#P```&2F```*````=*8```,```!_I@``#P``
M`(.F```4````DZ8```D```"HI@``#0```+*F```2````P*8``!D```#3I@``
M'@```.VF```/````#*<```H````<IP``#P```">G```(````-Z<``"0```!`
MIP``%````&6G```6````>J<```@```"1IP``3@```)JG```M````Z:<``!D`
M```7J```!P```#&H```,````.:@``"P```!&J```#@```'.H```#````@J@`
M``L```"&J```!P```)*H```'````FJ@```4```"BJ```!0```*BH```*````
MKJ@```,```"YJ```%P```+VH```*````U:@```\```#@J```#@```/"H```8
M````_Z@``",````8J0``#@```#RI```4````2ZD``!<```!@J0``%P```'BI
M```7````D*D``!,```"HJ0``#P```+RI```.````S*D``!\```#;J0``'0``
M`/NI```'````&:H```8````AJ@``"````"BJ```/````,:H```8```!!J@``
M"@```$BJ```3````4ZH```L```!GJ@``$````'.J```5````A*H``!4```":
MJ@``!P```+"J```0````N*H```4```#)J@``%0```,^J```1````Y:H```P`
M``#WJ@``.P````2K```X````0*L```D```!YJP``!P```(.K```4````BZL`
M``,```"@JP``!0```*2K```0````JJL```D```"[JP``$P```,6K```Y````
MV:L``!(````3K```)P```":L```L````3JP``"H```![K```)0```*:L```*
M````S*P```8```#7K```"0```-ZL```'````Z*P``"\```#PK```-P```""M
M```N````6*T``%4```"'K0``+0```-VM```M````"ZX``#T````YK@``/P``
M`'>N```M````MZX``$````#EK@``(P```":O```C````2J\``$````!NKP``
M+0```*^O```S````W:\``"4````1L```%0```#>P```9````3;```"D```!G
ML```)````)&P```H````MK```!$```#?L```"@```/&P```,````_+````H`
M```)L0``$````!2Q```6````);$``!8````\L0``!P```%.Q```'````6[$`
M`!0```!CL0``"@```'BQ```(````@[$``"<```",L0``"````+2Q```'````
MO;$```<```#%L0``!@```,VQ```%````U+$```<```#:L0``!@```.*Q```(
M````Z;$``"D```#RL0``#@```!RR```*````*[(```0````VL@``!P```#NR
M```)````0[(```8```!-L@``$0```%2R```'````9K(``!8```!NL@``!```
M`(6R```(````BK(```8```"3L@``#0```)JR```&````J+(``!X```"OL@``
M$0```,ZR```(````X+(```T```#IL@``#````/>R```'````!+,```,````,
MLP```P```!"S```7````%+,``!,````LLP``'0```$"S```(````7K,```0`
M``!GLP``"````&RS```(````=;,``$$```!^LP``&@```,"S```K````V[,`
M`"`````'M```%0```"BT```&````/K0```8```!%M```%0```$RT```8````
M8K0``"(```![M```+@```)ZT```=````S;0``"$```#KM```5`````VU```I
M````8K4```H```",M0``!P```)>U```'````G[4``!4```"GM0``#@```+VU
M```*````S+4```\```#7M0``#0```.>U```/````];4```T````%M@``"0``
M`!.V```4````';8```8````RM@``&````#FV```=````4K8``!,```!PM@``
M$0```(2V```4````EK8```0```"KM@``!@```+"V```4````M[8``%0```#,
MM@``9````"&W```$````AK<```X```"+MP``!0```)JW```%````H+<``!L`
M``"FMP``&@```,*W```3````W;<``!$```#QMP``$0````.X```<````%;@`
M`"H````RN```$````%VX```A````;K@```4```"0N```$P```):X```+````
MJK@``!(```"VN```"@```,FX```/````U+@```T```#DN```$0```/*X```3
M````!+D```P````8N0``!@```"6Y```,````++D```8````YN0``%P```$"Y
M```0````6+D``!$```!IN0``"````'NY```%````A+D```P```"*N0``$```
M`)>Y```%````J+D```T```"NN0``!@```+RY```'````P[D```T```#+N0``
M!P```-FY```+````X;D```<```#MN0``!P```/6Y```)````_;D```D````'
MN@``"@```!&Z```9````'+H``#T````VN@``'0```'2Z```,````DKH``!``
M``"?N@``!0```+"Z```E````MKH``!(```#<N@``$P```.^Z```K`````[L`
M`#L````ONP``(````&N[```(````C+L``#8```"5NP``(0```,R[```0````
M[KL```@```#_NP``#`````B\```&````%;P```0````<O```#P```"&\```.
M````,;P```<```!`O```"@```$B\```-````4[P``!\```!AO```'````(&\
M```A````GKP``!X```#`O```&0```-^\```>````^;P``!L````8O0``(0``
M`#2]```N````5KT``"8```"%O0``'````*R]```>````R;T``!P```#HO0``
M)@````6^```K````++X``#,```!8O@``)@```(R^```K````L[X``#@```#?
MO@``'0```!B_```5````-K\``"\```!,OP``(````'R_```2````G;\``"D`
M``"POP``'@```-J_```@````^;\``!(````:P```H@```"W````6````T,``
M`",```#GP```*`````O!```I````-,$``"@```!>P0``'P```(?!```5````
MI\$``"````"]P0``)0```-[!```H````!,(``"T````MP@``,````%O"``"2
M````C,(``"$````?PP``%@```$'#```<````6,,``"8```!UPP``*@```)S#
M``!!````Q\,``$0````)Q```#````$[$```'````6\0```<```!CQ```!@``
M`&O$```-````<L0``!````"`Q```$@```)'$```3````I,0``!(```"XQ```
M!P```,O$```$````T\0``!````#8Q```$````.G$```,````^L0```X````'
MQ0``#0```!;%```/````),4``!,````TQ0``#0```$C%```H````5L4```,`
M``!_Q0``#0```(/%```&````D<4``!$```"8Q0``%P```*K%```;````PL4`
M``X```#>Q0```@```.W%``!)````\,4```4````ZQ@``$````$#&```/````
M4<8```0```!AQ@``#0```&;&```.````=,8```,```"#Q@``#@```(?&```(
M````EL8```\```"?Q@``#P```*_&```'````O\8```T```#'Q@``$````-7&
M```-````YL8```L```#TQ@``!@````#'```+````!\<```P````3QP``"@``
M`"#'```1````*\<``!D````]QP``"P```%?'```-````8\<``"(```!QQP``
M#P```)3'```;````I,<``#0```#`QP``"@```/7'```8`````,@``!(````9
MR```&0```"S(```6````1L@``"(```!=R```#0```(#(```'````CL@``!0`
M``"6R```"P```*O(```B````M\@``"\```#:R```"P````K)```)````%LD`
M`!D````@R0``"P```#K)```7````1LD``!<```!>R0``"0```';)```6````
M@,D```\```"7R0``&0```*?)```6````P<D```X```#8R0``&````.?)```(
M`````,H```T````)R@``)@```!?*``!#````/LH```@```""R@``$@```(O*
M```?````GLH```@```"^R@``"P```,?*```O````T\H```X````#RP``!0``
M`!++```&````&,L``$4````?RP```P```&7+```'````:<L```0```!QRP``
M"@```';+```*````@<L```\```",RP``$````)S+```7````K<L``!$```#%
MRP``&0```-?+```7````\<L```D````)S```!0```!/,```+````&<P```H`
M```ES````@```##,```%````,\P```T````YS```&P```$?,```7````8\P`
M`!0```![S```"0```)#,```.````FLP```T```"IS```$@```+?,```X````
MRLP``"`````#S0``"````"3-```.````+<T``'L````\S0``&````+C-```8
M````T<T``!$```#JS0``!P```/S-```%````!,X``!@````*S@``'@```"/.
M```;````0LX``!D```!>S@``&P```'C.```9````E,X``!,```"NS@``!P``
M`,+.```(````RLX```8```#3S@``!@```-K.```0````X<X```\```#RS@``
M$`````+/```/````$\\```L````CSP``#P```"_/```,````/\\```\```!,
MSP``!P```%S/```&````9,\```X```!KSP``#````'K/```H````A\\```\`
M``"PSP``"````,#/```(````R<\``!,```#2SP``'@```.;/```A````!=``
M`"`````GT```&0```$C0```7````8M```"4```!ZT```%P```*#0```6````
MN-````0```#/T```&P```-30```-````\-````P```#^T````P````O1```%
M````#]$```@````5T0``"@```![1```,````*=$```L````VT0``$````$+1
M```,````4]$```X```!@T0``!````&_1```$````=-$``!,```!YT0``%```
M`(W1```,````HM$```D```"OT0``#@```+G1```+````R-$``!L```#4T0``
M!P```/#1```'````^-$```H`````T@``#0````O2```)````&=(```0````C
MT@```P```"C2```8````+-(```H```!%T@``!````%#2```F````5=(```X`
M``!\T@``?````(O2```5````"-,```4````>TP``!P```"33```,````+-,`
M``@````YTP``"@```$+3```&````3=,```@```!4TP```@```%W3```&````
M8-,```8```!GTP``%````&[3```-````@],``!````"1TP``&P```*+3```$
M````OM,```D```##TP``$````,W3```)````WM,```D```#HTP``!0```/+3
M```:````^-,```@````3U```!@```!S4```9````(]0```X````]U```!P``
M`$S4```'````5-0```4```!<U```"0```&+4```*````;-0```X```!WU```
M`@```(;4```&````B=0```L```"0U```#0```)S4```)````JM0```8```"T
MU```$@```+O4```)````SM0```<```#8U```%````.#4```=````]=0``$(`
M```3U0``)0```%;5```E````?-4```8```"BU0``"@```*G5```$````M-4`
M``D```"YU0``"````,/5```1````S-4```D```#>U0``!@```.C5```-````
M[]4```8```#]U0``.0````36```]````/M8``#H```!\U@``'@```+?6```%
M````UM8```X```#<U@``!````.O6```&````\-8```<```#WU@``(0```/_6
M```-````(=<``!4````OUP``!@```$77```$````3-<``!$```!1UP``!@``
M`&/7```*````:M<``"(```!UUP``!````)C7```%````G=<``!T```"CUP``
M!````,'7```,````QM<```X```#3UP``"@```.+7```(````[=<```D```#V
MUP``!0````#8```Z````!M@``#````!!V```-0```'+8```I````J-@``$<`
M``#2V```.````!K9```I````4]D``#\```!]V0``+@```+W9```M````[-D`
M`!\````:V@``#P```#K:```2````2MH```L```!=V@``)@```&G:```I````
MD-H``"0```"ZV@``)@```-_:```(````!ML```H````/VP``"0```!K;```'
M````)-L``"`````LVP``(````$W;```F````;ML```H```"5VP``&0```*#;
M```I````NML``!8```#DVP``$@```/O;```'````#MP```H````6W```#```
M`"'<```/````+MP``!`````^W```0````$_<``!P````D-P``&8````!W0``
M#@```&C=```)````=]T```H```"!W0``$@```(S=```3````G]T```P```"S
MW0``!@```,#=```/````Q]T``!(```#7W0``$````.K=```1````^]T``!P`
M```-W@``(P```"K>``!J````3MX```\```"YW@``!0```,G>```0````S]X`
M``D```#@W@``!````.K>```+````[]X``"````#[W@``%````!S?```,````
M,=\```P````^WP``#P```$O?```5````6]\``"D```!QWP``*@```)O?```F
M````QM\``"<```#MWP``*0```!7@```J````/^```!D```!JX```0@```(3@
M```1````Q^```!(```#9X```$P```.S@```4`````.$```\````5X0``%@``
M`"7A```7````/.$``!````!4X0``$0```&7A```T````=^$``!,```"LX0``
M$@```,#A```U````T^$``!0````)X@``!P```![B```,````)N(``"`````S
MX@``$````%3B```4````9>(``!$```!ZX@``%P```(SB```<````I.(``!,`
M``#!X@``%````-7B```:````ZN(``!$````%XP``&@```!?C```>````,N,`
M`!H```!1XP``$P```&SC```5````@.,``!$```"6XP``%P```*CC```4````
MP.,``!<```#5XP``%0```.WC```)`````^0``!`````-Y```&0```![D```$
M````..0```<````]Y```"P```$7D```1````4>0```8```!CY```!@```&KD
M```&````<>0```4```!XY```!P```'[D```'````AN0```4```".Y```%@``
M`)3D```&````J^0```8```"RY```!````+GD```$````ON0```<```##Y```
M#@```,OD```,````VN0```P```#GY```#0```/3D```*`````N4```X````-
MY0``!0```!SE```H````(N4```X```!+Y0``#````%KE```/````9^4```H`
M``!WY0``"````(+E```)````B^4``"L```"5Y0``!````,'E```(````QN4`
M`"8```#/Y0``$@```/;E```/````">8```8````9Y@``"@```"#F```'````
M*^8```@````SY@``(````#SF```)````7>8``!0```!GY@``#````'SF```-
M````B>8```X```"7Y@``%@```*;F```1````O>8```8```#/Y@```P```-;F
M```&````VN8``!D```#AY@``!P```/OF```$`````^<```L````(YP``"P``
M`!3G```'````(.<```4````HYP``!P```"[G```6````-N<```T```!-YP``
M#0```%OG```*````:><``!````!TYP``#P```(7G```1````E><``!<```"G
MYP``"@```+_G```1````RN<```0```#<YP``#P```.'G```Z````\><```4`
M```LZ```#````#+H```>````/^@```X```!>Z```$````&WH```+````?N@`
M``P```"*Z```"0```)?H```'````H>@```H```"IZ```"0```+3H```.````
MON@``!````#-Z```&P```-[H```8````^N@``!H````3Z0``"@```"[I```)
M````.>D```H```!#Z0``#````$[I```/````6^D```@```!KZ0``!@```'3I
M```<````>^D```<```"8Z0``!0```*#I```+````IND``$<```"RZ0``#0``
M`/KI```)````".H```0````2Z@```P```!?J```3````&^H``!,````OZ@``
M$P```$/J```*````5^H```(```!BZ@``!````&7J```E````:NH```,```"0
MZ@``!0```)3J```J````FNH```H```#%Z@``!0```-#J```$````UNH```H`
M``#;Z@``#0```.;J```&````].H```@```#[Z@``"`````3K```$````#>L`
M``4````2ZP``:````!CK```)````@>L```P```"+ZP``$````)CK```%````
MJ>L```8```"OZP``&P```+;K```O````TNL``!`````"[```"@```!/L```/
M````'NP```H````N[```"0```#GL```3````0^P``!L```!7[```&````'/L
M```7````C.P``!\```"D[```#@```,3L```#````T^P```<```#7[```"```
M`-_L```'````Z.P```H```#P[```"P```/OL```'````!^T``%$````/[0``
M$````&'M```,````<NT```T```!_[0``&@```(WM``!*````J.T``!D```#S
M[0``!@````WN```:````%.X``"4````O[@``!@```%7N```&````7.X``!\`
M``!C[@``!@```(/N```)````BNX``!@```"4[@``%P```*WN```H````Q>X`
M``8```#N[@``#0```/7N```B`````^\``%<````F[P``$P```'[O```C````
MDN\``!,```"V[P```@```,KO```+````S>\```@```#9[P``#0```.+O```*
M````\.\```<```#[[P``%`````/P```&````&/````@````?\```#@```"CP
M```'````-_````H````_\```"P```$KP```R````5O````<```")\```#```
M`)'P```-````GO````P```"L\```"0```+GP```)````P_````H```#-\```
M!P```-CP```)````X/````<```#J\```"@```/+P```;````_?````\````9
M\0``$@```"GQ```*````//$``!8```!'\0``"0```%[Q```0````:/$```<`
M``!Y\0``$@```('Q```$````E/$```<```"9\0``!0```*'Q```%````I_$`
M``L```"M\0``%````+GQ```1````SO$``!H```#@\0``%@```/OQ```4````
M$O(``!<````G\@``&````#_R```<````6/(``!D```!U\@``!P```(_R```%
M````E_(```T```"=\@``#````*OR```1````N/(```@```#*\@``%P```-/R
M```+````Z_(```P```#W\@``'P````3S```:````)/,``!,````_\P``!```
M`%/S```*````6/,```0```!C\P``#0```&CS```,````=O,```4```"#\P``
M"0```(GS```%````D_,```<```"9\P``!0```*'S```$````I_,```(```"L
M\P``.````*_S```L````Z/,``!(````5]```*0```"CT```R````4O0```H`
M``"%]```+````)#T```N````O?0``#,```#L]```,P```"#U```X````5/4`
M``\```"-]0``&````)WU```0````MO4```\```#']0``$P```-?U```5````
MZ_4``!0````!]@``$@```!;V```4````*?8``!4````^]@``+0```%3V```M
M````@O8``#$```"P]@``+@```.+V```O````$?<``"P```!!]P``8@```&[W
M```3````T?<```T```#E]P``"````//W```7````_/<```@````4^```#```
M`!WX```K````*O@``"$```!6^```&@```'CX```)````D_@``$4```"=^```
M00```./X```$````)?D``!,````J^0``%````#[Y```.````4_D``!,```!B
M^0``&````';Y```&````C_D```D```"6^0``"@```*#Y```/````J_D``!``
M``"[^0``!P```,SY```.````U/D```4```#C^0``&P```.GY```(````!?H`
M``8````.^@``%````!7Z```1````*OH```X````\^@``.````$OZ```"````
MA/H```8```"'^@``#@```([Z```%````G?H```<```"C^@``#@```*OZ```&
M````NOH``"@```#!^@``#````.KZ```<````]_H```0````4^P``*0```!G[
M```7````0_L``!\```!;^P``7````'O[```4````V/L``#X```#M^P``'P``
M`"S\```0````3/P```<```!=_```#@```&7\```,````=/P```P```"!_```
M$P```([\```*````HOP``!T```"M_```&0```,O\```%````Y?P``!$```#K
M_```$0```/W\```D````#_T``!(````T_0``%0```$?]```2````7?T```X`
M``!P_0``&0```'_]```(````F?T```T```"B_0``!P```+#]```*````N/T`
M``<```##_0``#P```,O]```&````V_T```L```#B_0``&@```.[]```'````
M"?X```@````1_@``!0```!K^```?````(/X```8```!`_@``$````$?^```(
M````6/X```T```!A_@``"````&_^```>````>/X``!(```"7_@``+````*K^
M```:````U_X```D```#R_@``"@```/S^```5````!_\```4````=_P``%```
M`"/_```$````./\``!`````]_P``!@```$[_```'````5?\``!X```!=_P``
M*````'S_```*````I?\``!P```"P_P``$0```,W_```+````W_\``!H```#K
M_P``%`````8``0`$````&P`!``0````@``$`"P```"4``0`%````,0`!``8`
M```W``$`"````#X``0`&````1P`!``H```!.``$`&P```%D``0`T````=0`!
M`#0```"J``$`(````-\``0`I``````$!`"`````J`0$`00```$L!`0`:````
MC0$!`"@```"H`0$`*0```-$!`0!0````^P$!`"(```!,`@$`!@```&\"`0`(
M````=@(!``4```!_`@$`"````(4"`0`9````C@(!`!D```"H`@$`*@```,("
M`0`C````[0(!`!D````1`P$`+@```"L#`0`T````6@,!``@```"/`P$`%P``
M`)@#`0`*````L`,!``<```"[`P$`(0```,,#`0`0````Y0,!``X```#V`P$`
M"P````4$`0`'````$00!`!,````9!`$`"````"T$`0`+````-@0!``H```!"
M!`$`%````$T$`0`/````8@0!`#(```!R!`$`"P```*4$`0`.````L00!``4`
M``#`!`$`!0```,8$`0`%````S`0!`!<```#2!`$`#P```.H$`0`$````^@0!
M``H```#_!`$`"0````H%`0`+````%`4!``T````@!0$`#````"X%`0`.````
M.P4!``4```!*!0$`!````%`%`0`-````504!`#(```!C!0$`10```)8%`0`7
M````W`4!``<```#T!0$`'@```/P%`0`4````&P8!`!0````P!@$`!@```$4&
M`0`'````3`8!``X```!4!@$`*@```&,&`0`&````C@8!``P```"5!@$`#0``
M`*(&`0`1````L`8!``L```#"!@$`-@```,X&`0`*````!0<!`"(````0!P$`
M"P```#,'`0`/````/P<!`#(```!/!P$`)0```(('`0`P````J`<!`#$```#9
M!P$`+0````L(`0`.````.0@!``4```!("`$`#@```$X(`0`3````70@!`!(`
M``!Q"`$`!P```(0(`0`1````C`@!`!,```">"`$`!P```+((`0`4````N@@!
M`!@```#/"`$`!P```.@(`0`%````\`@!``P```#V"`$`#`````,)`0`2````
M$`D!``0````C"0$`!P```"@)`0`*````,`D!``L````["0$`#````$<)`0`.
M````5`D!``X```!C"0$`!0```'()`0`%````>`D!`"X```!^"0$`)@```*T)
M`0`C````U`D!``,```#X"0$`$@```/P)`0`&````#PH!`!X````6"@$`&```
M`#4*`0`E````3@H!``T```!T"@$`'P```((*`0`#````H@H!``<```"F"@$`
M`@```*X*`0`,````L0H!`!4```"^"@$`"P```-0*`0`9````X`H!`"````#Z
M"@$`$@```!L+`0`%````+@L!``H````T"P$`%0```#\+`0`2````50L!``P`
M``!H"P$`!````'4+`0`)````>@L!``<```"$"P$`#````(P+`0!2````F0L!
M`!<```#L"P$`)`````0,`0`2````*0P!``<````\#`$`!@```$0,`0`.````
M2PP!``P```!:#`$`#0```&<,`0`5````=0P!`!(```"+#`$`#P```)X,`0`4
M````K@P!``H```###`$`&P```,X,`0`0````Z@P!``L```#[#`$`:0````<-
M`0`:````<0T!`!<```",#0$`)P```*0-`0`:````S`T!`!<```#G#0$`&P``
M`/\-`0`9````&PX!`!\````U#@$`$P```%4.`0`(````:0X!``<```!R#@$`
M"````'H.`0`)````@PX!`!4```"-#@$`#0```*,.`0`C````L0X!``T```#5
M#@$`$P```.,.`0`(````]PX!``,`````#P$`1@````0/`0`_````2P\!`#<`
M``"+#P$`5P```,,/`0`%````&Q`!`!\````A$`$`+P```$$0`0`*````<1`!
M``@```!\$`$`#0```(40`0`M````DQ`!``0```#!$`$`3P```,80`0`E````
M%A$!`!P````\$0$`"P```%D1`0`?````91$!`!T```"%$0$`)0```*,1`0`@
M````R1$!`"0```#J$0$`(`````\2`0`+````,!(!``<````\$@$`#0```$02
M`0`,````4A(!`!<```!?$@$`!@```'<2`0`Y````?A(!``P```"X$@$`!P``
M`,42`0`)````S1(!`!,```#7$@$`"0```.L2`0`$````]1(!`!````#Z$@$`
M"`````L3`0`(````%!,!``0````=$P$`"P```"(3`0`,````+A,!`!(````[
M$P$`$0```$X3`0`,````8!,!`!H```!M$P$`#P```(@3`0`'````F!,!``T`
M``"@$P$`%````*X3`0`.````PQ,!``P```#2$P$`&P```-\3`0`L````^Q,!
M`!,````H%`$`'````#P4`0`H````610!``8```""%`$`!P```(D4`0`3````
MD10!``4```"E%`$`!````*L4`0`7````L!0!``H```#(%`$`#````-,4`0`)
M````X!0!``8```#J%`$`"0```/$4`0`(````^Q0!``D````$%0$`"@````X5
M`0`1````&14!``8````K%0$`#@```#(5`0`.````014!``T```!0%0$`"P``
M`%X5`0`=````:A4!``L```"(%0$``@```)05`0`<````EQ4!``<```"T%0$`
M!@```+P5`0!D````PQ4!``D````H%@$`!P```#(6`0`F````.A8!`#@```!A
M%@$`&@```)H6`0`J````M18!`#L```#@%@$`*````!P7`0`T````11<!`!D`
M``!Z%P$`%0```)07`0`%````JA<!``<```"P%P$`"````+@7`0`'````P1<!
M``4```#)%P$`!P```,\7`0`.````UQ<!``D```#F%P$`!@```/`7`0`(````
M]Q<!``L`````&`$`!P````P8`0`(````%!@!``<````=&`$`%@```"48`0`)
M````/!@!``8```!&&`$`"P```$T8`0`0````61@!`!P```!J&`$`%````(<8
M`0`'````G!@!`!$```"D&`$`"````+88`0`.````OQ@!``@```#.&`$`!0``
M`-<8`0`0````W1@!`!````#N&`$`!@```/\8`0`9````!AD!``H````@&0$`
M'````"L9`0`'````2!D!``4```!0&0$`$````%89`0`4````9QD!``L```!\
M&0$`#0```(@9`0`H````EAD!`!@```"_&0$`%P```-@9`0`$````\!D!``D`
M``#U&0$`"@```/\9`0`'````"AH!``(````2&@$`#@```!4:`0`(````)!H!
M`",````M&@$`'P```%$:`0`X````<1H!`"8```"J&@$`,0```-$:`0`G````
M`QL!`&0````K&P$`%````)`;`0!5````I1L!`#@```#[&P$`2@```#0<`0!;
M````?QP!`"@```#;'`$`.`````0=`0`H````/1T!`"P```!F'0$`)@```),=
M`0`;````NAT!`#X```#6'0$`J0$``!4>`0`C````OQ\!`!<```#C'P$`2```
M`/L?`0"%````1"`!`#````#*(`$`)0```/L@`0!!````(2$!`%L```!C(0$`
M20```+\A`0`Q````"2(!`!T````[(@$`&````%DB`0`K````<B(!`"$```">
M(@$`'P```,`B`0`K````X"(!`"8````,(P$`)P```#,C`0`Z````6R,!`!T`
M``"6(P$`$0```+0C`0`S````QB,!`"4```#Z(P$`)P```"`D`0`@````2"0!
M`!\```!I)`$`,````(DD`0!I````NB0!`#$````D)0$`00```%8E`0`S````
MF"4!`"4```#,)0$`/0```/(E`0!E````,"8!`$T```"6)@$`+P```.0F`0`N
M````%"<!`#````!#)P$`5````'0G`0!:````R2<!`$@````D*`$`2@```&TH
M`0`R````N"@!`"\```#K*`$`+````!LI`0`M````2"D!`'$```!V*0$`9@``
M`.@I`0!O````3RH!`+,```"_*@$`%P```',K`0`E````BRL!`#(```"Q*P$`
M*0```.0K`0`^````#BP!`"(```!-+`$`4@```'`L`0`E````PRP!``L```#I
M+`$`L0```/4L`0!%````IRT!`"$```#M+0$`,`````\N`0`E````0"X!`!P`
M``!F+@$`,0```(,N`0`'````M2X!``<```"]+@$`!````,4N`0`-````RBX!
M``L```#8+@$`#@```.0N`0`+````\RX!``4```#_+@$`$`````4O`0`"````
M%B\!`%D````9+P$`!0```',O`0`2````>2\!``0```",+P$`!P```)$O`0`(
M````F2\!``4```"B+P$``P```*@O`0`0````K"\!``P```"]+P$`$P```,HO
M`0`-````WB\!``(```#L+P$`!P```.\O`0`&````]R\!`!0```#^+P$`#```
M`!,P`0`8````(#`!``8````Y,`$`$@```$`P`0`,````4S`!``,```!@,`$`
M*@```&0P`0`$````CS`!``8```"4,`$`!P```)LP`0`?````HS`!`#4```##
M,`$`+@```/DP`0`O````*#$!`!<```!8,0$`(@```'`Q`0`E````DS$!`"``
M``"Y,0$`&P```-HQ`0`8````]C$!`"0````/,@$`'P```#0R`0`:````5#(!
M`"$```!O,@$`(````)$R`0`:````LC(!`#(```#-,@$`&@`````S`0`O````
M&S,!`"L```!+,P$`'P```'<S`0`C````ES,!`!\```"[,P$`&@```-LS`0`A
M````]C,!`"4````8-`$`)@```#XT`0`E````930!`"0```"+-`$`&````+`T
M`0`=````R30!`"0```#G-`$`&`````PU`0`B````)34!`"P```!(-0$`+P``
M`'4U`0`5````I34!`"4```"[-0$`/````.$U`0`?````'C8!`",````^-@$`
M'P```&(V`0`@````@C8!`!H```"C-@$`&````+XV`0`F````US8!`!X```#^
M-@$`*0```!TW`0`>````1S<!`#$```!F-P$`"0```)@W`0`,````HC<!`!<`
M``"O-P$`+P```,<W`0`D````]S<!``<````<.`$`#P```"0X`0`4````-#@!
M``X```!).`$`#0```%@X`0`D````9C@!``4```"+.`$`!P```)$X`0`B````
MF3@!`"4```"\.`$`&@```.(X`0`=````_3@!`!H````;.0$`!P```#8Y`0#'
M````/CD!``L````&.@$`%0```!(Z`0`&````*#H!``D````O.@$`"P```#DZ
M`0`-````13H!`!<```!3.@$`!@```&LZ`0`S````<CH!`!,```"F.@$`$P``
M`+HZ`0`'````SCH!``\```#6.@$`!P```.8Z`0`R````[CH!``0````A.P$`
M(0```"8[`0`3````2#L!``P```!<.P$`$0```&D[`0`R````>SL!`!8```"N
M.P$`"````,4[`0`=````SCL!``D```#L.P$`"@```/8[`0`4`````3P!``H`
M```6/`$`'0```"$\`0`(````/SP!`!\```!(/`$`"````&@\`0`:````<3P!
M`"<```",/`$`!@```+0\`0`5````NSP!``<```#1/`$`"````-D\`0`)````
MXCP!`#\```#L/`$`!P```"P]`0`/````-#T!``X```!$/0$`$````%,]`0`)
M````9#T!``D```!N/0$`"````'@]`0`3````@3T!``<```"5/0$`&0```)T]
M`0`*````MST!`!<```#"/0$`%````-H]`0`*````[ST!``P```#Z/0$`%P``
M``<^`0`$````'SX!`"H````D/@$`#````$\^`0`1````7#X!``<```!N/@$`
M`@```'8^`0`0````>3X!`!@```"*/@$``P```*,^`0`(````ISX!``8```"P
M/@$`!P```+<^`0`-````OSX!``L```#-/@$`%````-D^`0`5````[CX!``X`
M```$/P$`+P```!,_`0`@````0S\!`!P```!D/P$`%0```($_`0`,````ES\!
M`#$```"D/P$`!0```-8_`0`2````W#\!`#\```#O/P$`$@```"]``0`*````
M0D`!``8```!-0`$`!````%1``0`$````64`!``H```!>0`$`$P```&E``0`%
M````?4`!``8```"#0`$`!@```(I``0`(````D4`!``0```":0`$`#````)]`
M`0`*````K$`!`#D```"W0`$`+@```/%``0`I````($$!``4```!*00$`&```
M`%!!`0`9````:4$!`!\```"#00$`'0```*-!`0`1````P4$!``(```#300$`
M!````-9!`0`*````VT$!``8```#F00$`!0```.U!`0`#````\T$!``P```#W
M00$`10````1"`0`R````2D(!`!H```!]0@$`-````)A"`0`H````S4(!`%,`
M``#V0@$`&0```$I#`0!R````9$,!`"````#70P$`-0```/A#`0`A````+D0!
M`$4```!01`$`,````)9$`0`H````QT0!`"D```#P1`$`)@```!I%`0`E````
M044!`"@```!G10$`*````)!%`0`B````N44!`"L```#<10$`,`````A&`0`2
M````.48!`!,```!,1@$`$````&!&`0!Y````<48!``D```#K1@$`H0```/5&
M`0!S````ET<!`'P````+2`$`*P```(A(`0!4````M$@!`!<````)20$`)P``
M`"%)`0`6````24D!``\```!@20$`%P```'!)`0`?````B$D!`$````"H20$`
M'P```.E)`0`<````"4H!`%$````F2@$`&@```'A*`0`4````DTH!``H```"H
M2@$`!0```+-*`0`&````N4H!``@```#`2@$`$@```,E*`0`0````W$H!`!,`
M``#M2@$`'0````%+`0`/````'TL!``\````O2P$`!````#]+`0`+````1$L!
M``<```!02P$`!0```%A+`0`4````7DL!``<```!S2P$`"````'M+`0`/````
MA$L!``@```"42P$`#````)U+`0`/````JDL!``8```"Z2P$`%````,%+`0`&
M````UDL!``P```#=2P$`$0```.I+`0`(````_$L!``0````%3`$`&0````I,
M`0`1````)$P!``H````V3`$`&````$%,`0`3````6DP!`!P```!N3`$`$0``
M`(M,`0`$````G4P!``\```"B3`$`!P```+),`0`$````NDP!`!D```"_3`$`
M!P```-E,`0`"````X4P!`!$```#D3`$`"0```/9,`0`2`````$T!`!<````3
M30$`!@```"M-`0`G````,DT!``0```!:30$`#P```%]-`0`3````;TT!``<`
M``"#30$`!P```(M-`0`1````DTT!``8```"E30$`&````*Q-`0`&````Q4T!
M`!,```#,30$`$````.!-`0`2````\4T!``8````$3@$`#`````M.`0`)````
M&$X!`!$````B3@$`(@```#1.`0`'````5TX!``L```!?3@$`!0```&M.`0`"
M````<4X!`&,!``!T3@$`%````-A/`0`3````[4\!``\````!4`$`!0```!%0
M`0`)````%U`!``D````A4`$``P```"M0`0`4````+U`!`!P```!$4`$`+```
M`&%0`0`K````CE`!`"$```"Z4`$`+0```-Q0`0`<````"E$!`#,````G40$`
M"P```%M1`0`L````9U$!`!0```"440$`$P```*E1`0`+````O5$!`"@```#)
M40$`#````/)1`0`5````_U$!`!L````54@$`(0```#%2`0`*````4U(!`(,`
M``!>4@$`%@```.)2`0`'````^5(!`!$````!4P$`%0```!-3`0`.````*5,!
M``H````X4P$`#P```$-3`0`1````4U,!`)H```!E4P$`#0````!4`0`5````
M#E0!`!D````D5`$`#P```#Y4`0`0````3E0!`!````!?5`$`!@```'!4`0`&
M````=U0!`#P```!^5`$`'@```+M4`0`Y````VE0!`$P````450$`:P```&%5
M`0!G````S54!`'$````U5@$`;0```*=6`0`\````%5<!`!(```!25P$`$P``
M`&57`0`,````>5<!`!$```"&5P$`$@```)A7`0`%````JU<!`"L```"Q5P$`
M$@```-U7`0`*````\%<!``D```#[5P$`"@````58`0`S````$%@!`"T```!$
M6`$`&0```')8`0`&````C%@!`"$```"36`$`"0```+58`0`'````OU@!`!4`
M``#'6`$`(@```-U8`0`1`````%D!`!8````260$`&@```"E9`0`=````1%D!
M`"H```!B60$`&P```(U9`0`4````J5D!`!(```"^60$`$0```-%9`0`N````
MXUD!`!P````26@$`'0```"]:`0`9````35H!`&4```!G6@$`0@```,U:`0`P
M````$%L!``,```!!6P$`"@```$5;`0`\````4%L!``X```"-6P$`"@```)Q;
M`0`+````IUL!``<```"S6P$`!P```+M;`0`%````PUL!``H```#)6P$`"0``
M`-1;`0`+````WEL!`!T```#J6P$`#@````A<`0`2````%UP!`"`````J7`$`
M&P```$M<`0`S````9UP!``L```";7`$`'P```*=<`0`2````QUP!`!X```#:
M7`$`#P```/E<`0`3````"5T!`!(````=70$`#P```#!=`0`B````0%T!`!@`
M``!C70$`!P```'Q=`0`&````A%T!``@```"+70$`*````)1=`0`&````O5T!
M``H```#$70$`$@```,]=`0`*````XET!`!0```#M70$`$P````)>`0`M````
M%EX!``H```!$7@$`$0```$]>`0`'````85X!`!,```!I7@$`'````'U>`0`:
M````FEX!`#T```"U7@$`.@```/->`0`)````+E\!``P````X7P$`$@```$5?
M`0`(````6%\!``4```!A7P$`!P```&=?`0`,````;U\!`!H```!\7P$`20``
M`)=?`0`7````X5\!`"D```#Y7P$`+0```"-@`0`T````46`!`#D```"&8`$`
M#0```,!@`0`)````SF`!``H```#88`$`"````.-@`0`T````[&`!`$@````A
M80$`,P```&IA`0!>````GF$!`#(```#]80$`,@```#!B`0!%````8V(!`#X`
M``"I8@$`,@```.AB`0!&````&V,!`"X```!B8P$`.P```)%C`0!"````S6,!
M`#(````09`$`.````$-D`0`Z````?&0!`"4```"W9`$`*````-UD`0`Y````
M!F4!`#H```!`90$`.0```'ME`0`;````M64!``P```#190$`(````-YE`0`&
M````_V4!``L````&9@$`'@```!)F`0`F````,68!``<```!89@$`!P```&!F
M`0`3````:&8!``D```!\9@$`"````(9F`0`U````CV8!``L```#%9@$`$```
M`-%F`0`'````XF8!``8```#J9@$`!0```/%F`0`'````]V8!``8```#_9@$`
M"P````9G`0`M````$F<!`!8```!`9P$`$@```%=G`0`(````:F<!``<```!S
M9P$`$````'MG`0`%````C&<!``\```"29P$`!P```*)G`0`3````JF<!``D`
M``"^9P$`"````,AG`0`$````T6<!``T```#69P$`"````.1G`0`:````[6<!
M`!$````(:`$`"````!IH`0`*````(V@!``P````N:`$`!P```#MH`0`5````
M0V@!``,```!9:`$`+````%UH`0`3````BF@!`"D```">:`$`!@```,AH`0`'
M````SV@!``D```#7:`$`!P```.%H`0!`````Z6@!`!X````J:0$`.P```$EI
M`0`J````A6D!`"0```"P:0$`!@```-5I`0`%````W&D!`!H```#B:0$`(0``
M`/UI`0`_````'VH!`#L```!?:@$`(P```)MJ`0`B````OVH!`%<```#B:@$`
M+````#IK`0`2````9VL!``H```!Z:P$`"P```(5K`0`7````D6L!``\```"I
M:P$`#0```+EK`0`2````QVL!`!(```#::P$`$@```.UK`0`3`````&P!``T`
M```4;`$`$P```")L`0`%````-FP!`!D````\;`$`&@```%9L`0`7````<6P!
M`!D```");`$`)````*-L`0`$````R&P!``L```#-;`$`$P```-EL`0!$````
M[6P!`%P````R;0$`"````(]M`0`2````F&T!``4```"K;0$`!````+%M`0`>
M````MFT!`!D```#5;0$`'0```.]M`0`1````#6X!`!X````?;@$`+0```#YN
M`0`V````;&X!`!(```"C;@$`*````+9N`0`&````WVX!`!D```#F;@$`%```
M``!O`0`6````%6\!`!4````L;P$`'P```$)O`0`0````8F\!`"0```!S;P$`
M*````)AO`0`1````P6\!``D```#3;P$`$0```-UO`0`*````[V\!``\```#Z
M;P$`'0````IP`0`1````*'`!``@````Z<`$`!````$-P`0`,````2'`!``T`
M``!5<`$`"0```&-P`0`1````;7`!``8```!_<`$`!P```(9P`0`0````CG`!
M``H```"?<`$`#@```*IP`0`/````N7`!``,```#)<`$`#````,UP`0`1````
MVG`!`!$```#L<`$`'0```/YP`0!8````''$!`"````!U<0$`$0```)9Q`0`5
M````J'$!``4```"^<0$`'P```,1Q`0`7````Y'$!`!@```#\<0$`-@```!5R
M`0!#````3'(!`"P```"0<@$`"0```+UR`0`T````QW(!`!X```#\<@$`#0``
M`!MS`0`)````*7,!``T````S<P$`!````$%S`0`+````1G,!`!H```!2<P$`
M&````&US`0`4````AG,!``H```";<P$`$````*9S`0`L````MW,!`"\```#D
M<P$`/@```!1T`0`Q````4W0!`"P```"%=`$`'@```+)T`0!$````T70!`"P`
M```6=0$`/@```$-U`0`L````@G4!`#T```"O=0$`/P```.UU`0`B````+78!
M`"@```!0=@$`-P```'EV`0`Q````L78!`"T```#C=@$`+P```!%W`0`\````
M07<!`"(```!^=P$`)P```*%W`0`_````R7<!`"L````)>`$`'````#5X`0`I
M````4G@!`"8```!\>`$`'@```*-X`0`1````PG@!`,0```#4>`$`.@```)EY
M`0`I````U'D!`"L```#^>0$`+0```"IZ`0`O````6'H!`#4```"(>@$`(P``
M`+YZ`0`H````XGH!`"X````+>P$`,0```#I[`0`Y````;'L!`#0```"F>P$`
MD````-M[`0`T````;'P!`!@```"A?`$`+0```+I\`0`K````Z'P!`"\````4
M?0$`1````$1]`0!*````B7T!``\```#4?0$`!@```.1]`0`*````ZWT!``H`
M``#V?0$`$`````%^`0`.````$GX!`!0````A?@$`*````#9^`0`/````7WX!
M``P```!O?@$`!````'Q^`0`1````@7X!`"(```"3?@$`"@```+9^`0`/````
MP7X!`!8```#1?@$`$@```.A^`0`>````^WX!`!`````:?P$`2P```"M_`0`'
M````=W\!`!@```!_?P$`!@```)A_`0`/````GW\!`!4```"O?P$`%0```,5_
M`0`0````VW\!``(```#L?P$`70```.]_`0`'````38`!`!$```!5@`$`&0``
M`&>``0`%````@8`!`!$```"'@`$`$@```)F``0`&````K(`!``X```"S@`$`
M"````,*``0`&````RX`!`!````#2@`$`#P```..``0`?````\X`!`"$````3
M@0$`%0```#6!`0`*````2X$!``8```!6@0$`#P```%V!`0`1````;8$!`!<`
M``!_@0$`%0```)>!`0`/````K8$!``\```"]@0$`$0```,V!`0`H````WX$!
M`!$````(@@$`'0```!J"`0`^````.((!``T```!W@@$`(````(6"`0`3````
MIH(!`!H```"Z@@$`%P```-6"`0`K````[8(!`!(````9@P$`!0```"R#`0`;
M````,H,!``8```!.@P$`+P```%6#`0!!````A8,!``H```#'@P$`"@```-*#
M`0`5````W8,!``P```#S@P$`$@````"$`0`2````$X0!``8````FA`$`,@``
M`"V$`0`9````8(0!`"4```!ZA`$`)@```*"$`0`6````QX0!`"8```#>A`$`
M"`````6%`0`+````#H4!`"P````:A0$`0````$>%`0`(````B(4!`!4```"1
MA0$`)P```*>%`0`(````SX4!``\```#8A0$`/0```.B%`0`/````)H8!``P`
M```VA@$`!0```$.&`0!1````288!``0```";A@$`!P```*"&`0`)````J(8!
M``\```"RA@$`$0```,*&`0`5````U(8!`!@```#JA@$`'@````.'`0`=````
M(H<!`"````!`AP$`'@```&&'`0`'````@(<!``@```"(AP$`"````)&'`0`'
M````FH<!`!8```"BAP$`!0```+F'`0`)````OX<!`"$```#)AP$`%P```.N'
M`0`0`````X@!``X````4B`$`#````".(`0`,````,(@!`!D````]B`$`0P``
M`%>(`0`V````FX@!``P```#2B`$`%@```-^(`0!Z````]H@!`!H```!QB0$`
M&@```(R)`0`1````IXD!``<```"YB0$`!````,&)`0`G````QHD!`#8```#N
MB0$`/0```"6*`0`B````8XH!`"P```"&B@$`&````+.*`0`G````S(H!``H`
M``#TB@$`!P```/^*`0`,````!XL!``8````4BP$`#0```!N+`0`,````*8L!
M`!(````VBP$`#````$F+`0`7````5HL!``L```!NBP$`"@```'J+`0`.````
MA8L!``L```"4BP$`#````*"+`0`?````K8L!`!L```#-BP$`30```.F+`0`7
M````-XP!``8```!/C`$`!````%:,`0`G````6XP!`#$```"#C`$`'@```+6,
M`0`=````U(P!`"L```#RC`$`*@```!Z-`0`L````28T!`"T```!VC0$`'```
M`*2-`0`&````P8T!`!P```#(C0$`#@```.6-`0`7````](T!``,````,C@$`
M`P```!".`0`'````%(X!`!`````<C@$`$@```"V.`0`-````0(X!`!8```!.
MC@$`"P```&6.`0`F````<8X!``8```"8C@$`!````)^.`0`2````I(X!`!(`
M``"WC@$`#@```,J.`0`'````V8X!``X```#AC@$`#P```/".`0`A`````(\!
M``8````BCP$`"@```"F/`0`(````-(\!``L````]CP$`%@```$F/`0`1````
M8(\!``,```!RCP$`%````':/`0`(````BX\!``8```"4CP$`.0```)N/`0`8
M````U8\!`(P```#NCP$`&0```'N0`0`,````E9`!``8```"BD`$`#@```*F0
M`0`(````N)`!``H```#!D`$`!P```,R0`0`,````U)`!``(```#AD`$`"```
M`.20`0`-````[9`!``T```#[D`$`#@````F1`0`1````&)$!`!8````JD0$`
M!@```$&1`0`'````2)$!`!````!0D0$`"````&&1`0`*````:I$!``4```!U
MD0$`(````'N1`0`+````G)$!``8```"HD0$`)````*^1`0`1````U)$!``8`
M``#FD0$`"P```.V1`0`%````^9$!``D```#_D0$`"@````F2`0`4````%)(!
M``4````ID@$`!0```"^2`0`-````-9(!``X```!#D@$`#````%*2`0`+````
M7Y(!`!(```!KD@$`"````'Z2`0`'````AY(!`!8```"/D@$`'````*:2`0!#
M````PY(!`"L````'DP$`.````#.3`0`)````;),!``H```!VDP$`!````(&3
M`0`)````AI,!``@```"0DP$`%````)F3`0`+````KI,!``8```"ZDP$`#0``
M`,&3`0`&````SY,!`$````#6DP$`10```!>4`0!"````790!`"L```"@E`$`
M!0```,R4`0`/````TI0!``,```#BE`$`!@```.:4`0`&````[90!`!L```#T
ME`$`#````!"5`0`4````'94!``@````RE0$`"````#N5`0`C````1)4!``@`
M``!HE0$`!P```'&5`0`0````>94!``0```"*E0$`"````(^5`0`,````F)4!
M``@```"EE0$`"P```*Z5`0`4````NI4!``\```#/E0$`"````-^5`0`(````
MZ)4!``4```#QE0$`-````/>5`0`W````+)8!`#<```!DE@$`+````)R6`0!%
M````R98!`$,````/EP$`+P```%.7`0!8````@Y<!`#0```#<EP$`2@```!&8
M`0`M````7)@!`!````"*F`$`$````)N8`0`+````K)@!`",```"XF`$`)```
M`-R8`0`7`````9D!`"`````9F0$`#````#J9`0`.````1YD!``H```!6F0$`
M#````&&9`0`N````;ID!`"H```"=F0$`/P```,B9`0`&````")H!`!X````/
MF@$`,````"Z:`0`<````7YH!`!8```!\F@$`!@```).:`0`+````FIH!``H`
M``"FF@$`$````+&:`0`E````PIH!`$8```#HF@$`D0```"^;`0!T````P9L!
M``\````VG`$`#````$:<`0`-````4YP!`!L```!AG`$`%P```'V<`0`.````
ME9P!``4```"DG`$`%0```*J<`0`5````P)P!`!,```#6G`$`%@```.J<`0`7
M`````9T!`#0````9G0$`C0```$Z=`0`0````W)T!``4```#MG0$`$@```/.=
M`0`)````!IX!``H````0G@$`"@```!N>`0`H````)IX!`!<```!/G@$`$```
M`&>>`0`5````>)X!`!````".G@$`%@```)^>`0`7````MIX!`!8```#.G@$`
M$P```.6>`0`3````^9X!`!P````-GP$`&P```"J?`0`@````1I\!`#\```!G
MGP$`&0```*>?`0`8````P9\!`!<```#:GP$`%@```/*?`0`2````":`!`!P`
M```<H`$`&P```#F@`0`3````5:`!`!,```!IH`$`,````'V@`0`;````KJ`!
M`!P```#*H`$`0@```.>@`0`?````*J$!``4```!*H0$`%````%"A`0`M````
M9:$!`",```"3H0$`(0```+>A`0`F````V:$!`"4`````H@$`'0```":B`0`C
M````1*(!`",```!HH@$`'````(RB`0`B````J:(!`$$```#,H@$`(@````ZC
M`0`G````,:,!`"<```!9HP$`(````(&C`0`@````HJ,!`",```##HP$`*0``
M`.>C`0`B````$:0!`",````TI`$`#0```%BD`0`7````9J0!`!@```!^I`$`
M!````)>D`0`(````G*0!``H```"EI`$`%````+"D`0`&````Q:0!`!4```#,
MI`$`!````.*D`0`+````YZ0!``<```#SI`$`!@```/ND`0`%`````J4!`!,`
M```(I0$`!@```!RE`0`(````(Z4!``8````LI0$`!@```#.E`0`*````.J4!
M`!````!%I0$`&@```%:E`0`0````<:4!`!$```""I0$`"@```)2E`0`8````
MGZ4!``4```"XI0$`.0```+ZE`0`6````^*4!`!$````/I@$`$0```"&F`0`.
M````,Z8!``L```!"I@$`$@```$ZF`0`O````8:8!``@```"1I@$`"````)JF
M`0`D````HZ8!`!(```#(I@$`#P```-NF`0`&````ZZ8!``P```#RI@$`"0``
M`/^F`0`%````":<!`"0````/IP$`"@```#2G`0`6````/Z<!``T```!6IP$`
M$P```&2G`0`8````>*<!`",```"1IP$`)P```+6G`0`*````W:<!``,```#H
MIP$`"@```.RG`0`B````]Z<!``<````:J`$``P```"*H`0`1````)J@!`!(`
M```XJ`$`!P```$NH`0`%````4Z@!``<```!9J`$`*@```&&H`0`-````C*@!
M`!(```":J`$`"@```*VH`0`3````N*@!`!<```#,J`$`#````.2H`0`.````
M\:@!``X`````J0$`#@````^I`0`$````'JD!`!$````CJ0$`0P```#6I`0`&
M````>:D!``4```"`J0$`)P```(:I`0`6````KJD!`#0```#%J0$`%0```/JI
M`0`.````$*H!`!,````?J@$`#P```#.J`0`0````0ZH!``\```!4J@$`'@``
M`&2J`0`?````@ZH!`#4```"CJ@$`*P```-FJ`0`F````!:L!``@````LJP$`
M"````#6K`0`+````/JL!``L```!*JP$`$0```%:K`0`$````:*L!``T```!M
MJP$`*@```'NK`0`-````IJL!``T```"TJP$`)@```,*K`0!1````Z:L!`!T`
M```[K`$`#0```%FL`0`(````9ZP!``@```!PK`$`#@```'FL`0`.````B*P!
M`!4```"7K`$`"0```*VL`0`"````MZP!``T```"ZK`$`(P```,BL`0`&````
M[*P!``4```#SK`$`"0```/FL`0`+`````ZT!``D````/K0$`"0```!FM`0`4
M````(ZT!``X````XK0$`!@```$>M`0`(````3JT!``\```!7K0$`!````&>M
M`0`%````;*T!`&L```!RK0$`#````-ZM`0`/````ZZT!`"````#[K0$`!P``
M`!RN`0`%````)*X!`"H````JK@$`,0```%6N`0`1````AZX!``H```"9K@$`
M&0```*2N`0`*````OJX!``D```#)K@$`*@```-.N`0`>````_JX!`"D````=
MKP$`*````$>O`0`K````<*\!``\```"<KP$`!0```*RO`0`'````LJ\!``T`
M``"ZKP$`!0```,BO`0`3````SJ\!`!8```#BKP$`!@```/FO`0!9`````+`!
M`!X```!:L`$`$````'FP`0`6````BK`!`"0```"AL`$`9@```,:P`0`8````
M+;$!``<```!&L0$`'P```$ZQ`0`P````;K$!``@```"?L0$`!@```*BQ`0`>
M````K[$!``4```#.L0$`"@```-2Q`0`N````W[$!`"T````.L@$`.P```#RR
M`0`3````>+(!``8```",L@$`)````).R`0!6````N+(!`!\````/LP$`'```
M`"^S`0`Y````3+,!``(```"&LP$`&0```(FS`0`'````H[,!`!(```"KLP$`
M$0```+ZS`0`'````T+,!`!0```#8LP$`!@```.VS`0`(````]+,!``L```#]
MLP$`!P````FT`0`*````$;0!``L````<M`$`+````"BT`0`'````5;0!`!``
M``!=M`$`$````&ZT`0`/````?[0!``D```"/M`$`#````)FT`0`-````IK0!
M``H```"TM`$`"0```+^T`0`*````R;0!``@```#4M`$`&P```-VT`0`>````
M^;0!`!0````8M0$`&@```"VU`0`6````2+4!`!8```!?M0$`(````':U`0`'
M````E[4!`!8```"?M0$``P```+:U`0`'````NK4!``4```#"M0$`!0```,BU
M`0`)````SK4!`!````#8M0$`$@```.FU`0`S````_+4!`"X````PM@$`(@``
M`%^V`0`D````@K8!`!<```"GM@$`'P```+^V`0`9````W[8!``<```#YM@$`
M!`````&W`0`,````!K<!``P````3MP$`$0```""W`0`&````,K<!`!X````Y
MMP$`"0```%BW`0`)````8K<!`"L```!LMP$`)0```)BW`0`/````OK<!``4`
M``#.MP$`#````-2W`0`)````X;<!`!$```#KMP$`$````/VW`0`*````#K@!
M``D````9N`$`!0```".X`0`'````*;@!``<````QN`$`!````#FX`0`#````
M/K@!`%D```!"N`$`+0```)RX`0!$````RK@!`!L````/N0$`/0```"NY`0`/
M````:;D!`$````!YN0$`*0```+JY`0`>````Y+D!`!X````#N@$`(P```"*Z
M`0`V````1KH!``T```!]N@$`,````(NZ`0`9````O+H!`!4```#6N@$`%0``
M`.RZ`0`/`````KL!`!0````2NP$`%0```">[`0`A````/;L!`#T```!?NP$`
M/@```)V[`0!!````W+L!`#X````>O`$`/P```%V\`0`]````G;P!`&T```#;
MO`$`'@```$F]`0`6````:+T!`!H```!_O0$`)0```)J]`0`/````P+T!`!``
M``#0O0$`.P```.&]`0`K````';X!`"T```!)O@$`"@```'>^`0`I````@KX!
M`"L```"LO@$`!0```-B^`0`F````WKX!`!8````%OP$`#@```!R_`0`.````
M*[\!`!<````ZOP$`"````%*_`0`*````6[\!``P```!FOP$`#@```'._`0`O
M````@K\!``\```"ROP$`#P```,*_`0`,````TK\!`"8```#?OP$`"`````;`
M`0`$````#\`!`!`````4P`$`#@```"7``0`+````-,`!`#4```!`P`$``@``
M`';``0`(````><`!`!<```""P`$`#````)K``0`'````I\`!``8```"OP`$`
M$0```+;``0`K````R,`!``T```#TP`$`'`````+!`0`$````'\$!`#<````D
MP0$`(P```%S!`0`>````@,$!`'<```"?P0$`%P```!?"`0!(````+\(!`"<`
M``!XP@$`$@```*#"`0`&````L\(!``X```"ZP@$`%````,G"`0`)````WL(!
M`!$```#HP@$`#@```/K"`0`>````"<,!`!4````HPP$`!0```#[#`0`0````
M1,,!`!H```!5PP$`,@```'##`0`5````H\,!`!4```"YPP$`&````,_#`0`3
M````Z,,!`!\```#\PP$`!P```!S$`0`7````),0!``L````\Q`$`%````$C$
M`0`4````7<0!`!8```!RQ`$`$````(G$`0`6````FL0!`!@```"QQ`$`"P``
M`,K$`0`)````UL0!``4```#@Q`$`'0```.;$`0`&````!,4!``\````+Q0$`
M"````!O%`0`2````),4!``8````WQ0$`)````#[%`0`4````8\4!`#,```!X
MQ0$`%0```*S%`0`'````PL4!``@```#*Q0$`'@```-/%`0`+````\L4!`!L`
M``#^Q0$`!P```!K&`0`C````(L8!``<```!&Q@$`"````$[&`0`D````5\8!
M`#L```!\Q@$`"P```+C&`0`E````Q,8!`"<```#JQ@$`#0```!+'`0`:````
M(,<!`!`````[QP$`!````$S'`0`.````4<<!``X```!@QP$`!P```&_'`0`.
M````=\<!``@```"&QP$`!0```(_'`0`)````E<<!`!T```"?QP$`)@```+W'
M`0`_````Y,<!`"@````DR`$`)0```$W(`0`?````<\@!`#L```"3R`$`'@``
M`,_(`0`J````[L@!`#(````9R0$`70```$S)`0`E````JLD!``T```#0R0$`
M"````-[)`0`*````Y\D!``H```#RR0$`$0```/W)`0`6````#\H!`$<````F
MR@$`)0```&[*`0`:````E,H!`#@```"OR@$`0````.C*`0`)````*<L!`"8`
M```SRP$`"P```%K+`0`4````9LL!`"<```![RP$`#````*/+`0`9````L,L!
M``P```#*RP$`#@```-?+`0`.````YLL!``\```#URP$`$`````7,`0`/````
M%LP!`!L````FS`$`&@```$+,`0`U````7<P!``L```"3S`$`&@```)_,`0`%
M````NLP!`!4```#`S`$`!0```-;,`0`>````W,P!`!<```#[S`$``P```!/-
M`0`,````%\T!`!`````DS0$`!0```#7-`0`.````.\T!``@```!*S0$`#P``
M`%/-`0`%````8\T!``<```!IS0$`$````''-`0!)````@LT!`%````#,S0$`
M)P```!W.`0`)````1<X!`#(```!/S@$`*P```(+.`0`1````KLX!``D```#`
MS@$`#````,K.`0`0````U\X!`#(```#HS@$`!@```!O/`0`-````(L\!``X`
M```PSP$`%0```#_/`0`-````5<\!`%P```!CSP$`"@```,#/`0`E````R\\!
M`!4```#QSP$`%@````?0`0`L````'M`!`"8```!+T`$`/@```'+0`0!!````
ML=`!`#L```#ST`$`#@```"_1`0`%````/M$!`!,```!$T0$`'````%C1`0`@
M````==$!``@```"6T0$`$P```)_1`0`;````L]$!``<```#/T0$`'P```-?1
M`0`7````]]$!`!`````/T@$`!````"#2`0`2````)=(!`!,````XT@$`%```
M`$S2`0`&````8=(!``<```!HT@$`$P```'#2`0`.````A-(!``\```"3T@$`
M$0```*/2`0`1````M=(!``8```#'T@$`!P```,[2`0`H````UM(!`"0```#_
MT@$`(````"33`0`(````1=,!``\```!.TP$`!@```%[3`0`8````9=,!`"D`
M``!^TP$`*0```*C3`0`*````TM,!`!@```#=TP$``P```/;3`0`(````^M,!
M``,````#U`$`$@````?4`0`4````&M0!``L````OU`$`&````#O4`0`C````
M5-0!`!<```!XU`$`!@```)#4`0`*````E]0!`!0```"BU`$`%P```+?4`0`,
M````S]0!``8```#<U`$`#````./4`0`*````\-0!`!4```#[U`$`>0```!'5
M`0`?````B]4!`"\```"KU0$`%````-O5`0`(````\-4!``<```#YU0$`%P``
M``'6`0`7````&=8!`!@````QU@$`(@```$K6`0`=````;=8!`!(```"+U@$`
M)0```)[6`0`1````Q-8!`"8```#6U@$`&````/W6`0`7````%M<!`(,````N
MUP$`*````++7`0`?````V]<!`#@```#[UP$`)P```#38`0`>````7-@!`"L`
M``![V`$`(P```*?8`0`G````R]@!`!0```#SV`$`"P````C9`0`(````%-D!
M``D````=V0$`"@```"?9`0`5````,MD!``L```!(V0$`.P```%39`0`I````
MD-D!`#<```"ZV0$`%@```/+9`0`&````"=H!`$4````0V@$`50```%;:`0`T
M````K-H!`)P```#AV@$`"P```'[;`0`W````BML!`"\```#"VP$`$@```/+;
M`0`(````!=P!`!,````.W`$`1````"+<`0`,````9]P!`%@```!TW`$`2```
M`,W<`0`H````%MT!`!0````_W0$`(@```%3=`0`B````=]T!`"P```":W0$`
M(@```,?=`0`K````ZMT!`!\````6W@$`%0```#;>`0`'````3-X!`!````!4
MW@$`%````&7>`0`-````>MX!``L```"(W@$`40```)3>`0`,````YMX!`!X`
M``#SW@$`$0```!+?`0`?````)-\!``D```!$WP$`!0```$[?`0`8````5-\!
M``D```!MWP$`"0```'??`0`'````@=\!``<```")WP$`"0```)'?`0`2````
MF]\!`!P```"NWP$`#P```,O?`0`?````V]\!`!````#[WP$`"`````S@`0`-
M````%>`!`"8````CX`$`"P```$K@`0`*````5N`!`!@```!AX`$`)@```'K@
M`0`,````H>`!`"(```"NX`$`*P```-'@`0`+````_>`!``@````)X0$`(0``
M`!+A`0`-````-.$!`!D```!"X0$`&P```%SA`0`4````>.$!`!8```"-X0$`
M$@```*3A`0`%````M^$!``D```"]X0$`"````,?A`0`)````T.$!``H```#:
MX0$`%````.7A`0`'````^N$!`!`````"X@$`"@```!/B`0`(````'N(!``P`
M```GX@$`(0```#3B`0`,````5N(!``(```!CX@$`(P```&;B`0`%````BN(!
M``H```"0X@$`>@```)OB`0`*````%N,!``@````AXP$`*@```"KC`0`Z````
M5>,!`!H```"0XP$`+@```*OC`0!=````VN,!`",````XY`$`,P```%SD`0`O
M````D.0!`"4```#`Y`$`!@```.;D`0`-````[>0!``@```#[Y`$`"0````3E
M`0`%````#N4!``@````4Y0$`$@```!WE`0`*````,.4!``D````[Y0$`"P``
M`$7E`0`+````4>4!`!H```!=Y0$`"````'CE`0`)````@>4!`!4```"+Y0$`
M"@```*'E`0`*````K.4!``4```"WY0$`+@```+WE`0`F````[.4!`!@````3
MY@$`!P```"SF`0`2````-.8!``D```!'Y@$`#P```%'F`0`S````8>8!``@`
M``"5Y@$`&````)[F`0`8````M^8!``8```#0Y@$`!@```-?F`0`-````WN8!
M`!P```#LY@$`!@````GG`0`)````$.<!``L````:YP$`'````";G`0`+````
M0^<!``T```!/YP$`*@```%WG`0`?````B.<!`!@```"HYP$`!@```,'G`0`+
M````R.<!`!````#4YP$`#0```.7G`0`#````\^<!``X```#WYP$`"`````;H
M`0`=````#^@!`"\````MZ`$`,````%WH`0`J````CN@!`"X```"YZ`$`+@``
M`.CH`0".````%^D!`!8```"FZ0$`8P```+WI`0`X````(>H!`&$```!:Z@$`
M:0```+SJ`0`A````)NL!`$T```!(ZP$`/````);K`0!'````T^L!`!X````;
M[`$`&````#KL`0`C````4^P!`/T!``!W[`$`'0```'7N`0`=````D^X!`$D`
M``"Q[@$`H````/ON`0`T````G.\!`"D```#1[P$`1P```/OO`0!:````0_`!
M`&0```">\`$`,@````/Q`0`@````-O$!`!X```!7\0$`-````';Q`0`<````
MJ_$!`!\```#(\0$`)````.CQ`0`@````#?(!`"8````N\@$`+P```%7R`0`:
M````A?(!`!8```"@\@$`,0```+?R`0`J````Z?(!`"0````4\P$`/````#GS
M`0`:````=O,!`#(```"1\P$`<0```,3S`0`[````-O0!`#H```!R]`$`,@``
M`*WT`0`I````X/0!`$<````*]0$`;0```%+U`0!?````P/4!`#`````@]@$`
M,````%'V`0`S````@O8!`$X```"V]@$`9@````7W`0!-````;/<!`%,```"Z
M]P$`20````[X`0`G````6/@!`"<```"`^`$`)````*CX`0!X````S?@!`&T`
M``!&^0$`=P```+3Y`0#.````+/H!`!P```#[^@$`+````!C[`0`V````1?L!
M`"X```!\^P$`4````*O[`0`<````_/L!`$`````9_`$`/P```%K\`0`%````
MFOP!`,@```"@_`$`1@```&G]`0`B````L/T!`#X```#3_0$`)P```!+^`0`<
M````.OX!`"P```!7_@$`"0```(3^`0`6````COX!``,```"E_@$`%@```*G^
M`0`,````P/X!``T```#-_@$`"P```-O^`0`'````Y_X!``T```#O_@$`!P``
M`/W^`0!U````!?\!``(```![_P$`%@```'[_`0`$````E?\!``<```":_P$`
M!@```*+_`0`%````J?\!``4```"O_P$`%0```+7_`0`*````R_\!`!(```#6
M_P$`#P```.G_`0`"````^?\!``<```#\_P$`"P````0``@`2````$``"``T`
M```C``(`&0```#$``@`&````2P`"`!D```!2``(`"@```&P``@`#````=P`"
M`%L```![``(`!````-<``@`&````W``"``<```#C``(`)P```.L``@!,````
M$P$"`$8```!@`0(`1P```*<!`@`J````[P$"`"X````:`@(`,0```$D"`@`=
M````>P("`"(```"9`@(`'````+P"`@`R````V0("`"H````,`P(`)````#<#
M`@`F````7`,"`"<```"#`P(`+@```*L#`@`K````V@,"`!X````&!`(`*0``
M`"4$`@`J````3P0"`!\```!Z!`(`(P```)H$`@`A````O@0"`!D```#@!`(`
M(@```/H$`@`L````'04"`#(```!*!0(`,P```'T%`@`G````L04"`!T```#9
M!0(`)````/<%`@`I````'`8"`!T```!&!@(`)P```&0&`@`X````C`8"`#L`
M``#%!@(`&0````$'`@`C````&P<"`#H````_!P(`(@```'H'`@`F````G0<"
M`"0```#$!P(`)0```.D'`@`<````#P@"`"0````L"`(`,````%$(`@`>````
M@@@"`#$```"A"`(`(0```-,(`@`V````]0@"``D````L"0(`$````#8)`@`B
M````1PD"`$<```!J"0(`+````+()`@`,````WPD"``\```#L"0(`%P```/P)
M`@`2````%`H"`!`````G"@(`)P```#@*`@`&````8`H"``H```!G"@(`)0``
M`'(*`@`H````F`H"`!L```#!"@(`*````-T*`@`<````!@L"``\````C"P(`
M]````#,+`@`5````*`P"`!<````^#`(`"0```%8,`@`7````8`P"`"(```!X
M#`(`'0```)L,`@`>````N0P"``D```#8#`(`/@```.(,`@`/````(0T"`!8`
M```Q#0(`!P```$@-`@`;````4`T"`!$```!L#0(`3@```'X-`@`0````S0T"
M`"(```#>#0(`'`````$.`@`8````'@X"`",````W#@(`80```%L.`@`G````
MO0X"`!````#E#@(`)P```/8.`@`1````'@\"`!(````P#P(`&````$,/`@`+
M````7`\"`!T```!H#P(`*0```(8/`@`?````L`\"``L```#0#P(`,P```-P/
M`@`]````$!`"``<```!.$`(`$P```%80`@`'````:A`"``<```!R$`(`"0``
M`'H0`@!)````A!`"``8```#.$`(`#0```-40`@`0````XQ`"`!8```#T$`(`
M"P````L1`@`,````%Q$"``<````D$0(`$0```"P1`@`/````/A$"`!P```!.
M$0(`%P```&L1`@`4````@Q$"`!@```"8$0(`#````+$1`@`.````OA$"`"P`
M``#-$0(`#@```/H1`@`V````"1("`!H```!`$@(`$````%L2`@`.````;!("
M``,```![$@(`%````'\2`@`;````E!("``,```"P$@(`"0```+02`@`'````
MOA("``H```#&$@(`#@```-$2`@`.````X!("`!L```#O$@(`'`````L3`@`.
M````*!,"`#0````W$P(`&@```&P3`@`5````AQ,"`!D```"=$P(`#0```+<3
M`@`R````Q1,"``D```#X$P(`%P````(4`@!6````&A0"`!4```!Q%`(`&0``
M`(<4`@`*````H10"``0```"L%`(`!````+$4`@`6````MA0"`!4```#-%`(`
M!0```.,4`@`&````Z10"``H```#P%`(`#0```/L4`@`%````"14"``X````/
M%0(`$@```!X5`@`_````,14"`#(```!Q%0(`*0```*05`@`@````SA4"`!P`
M``#O%0(`(P````P6`@`H````,!8"`"````!9%@(`%0```'H6`@`"````D!8"
M``0```"3%@(`#0```)@6`@`&````IA8"``4```"M%@(`!````+,6`@`1````
MN!8"`'@```#*%@(`)````$,7`@`M````:!<"`"\```"6%P(`(P```,87`@!(
M````ZA<"`!D````S&`(`C@```$T8`@`B````W!@"`%0```#_&`(`(0```%09
M`@!7````=AD"`"X```#.&0(`*0```/T9`@!`````)QH"`#,```!H&@(`+P``
M`)P:`@`_````S!H"`!T````,&P(`)0```"H;`@`H````4!L"`$T```!Y&P(`
M$````,<;`@`;````V!L"`!0```#T&P(`=0````D<`@`*````?QP"`-8```"*
M'`(`A0```&$=`@!^````YQT"`#@```!F'@(`>@```)\>`@`<````&A\"`#<`
M```W'P(`*@```&\?`@`2````FA\"`"4```"M'P(`)````-,?`@!&````^!\"
M`"(````_(`(`'````&(@`@!9````?R`"`"\```#9(`(`)@````DA`@`+````
M,"$"``4````\(0(`!@```$(A`@`(````22$"`"(```!2(0(`#@```'4A`@`@
M````A"$"`"@```"E(0(`"P```,XA`@`/````VB$"``L```#J(0(`"0```/8A
M`@`*`````"("``D````+(@(`%@```!4B`@`-````+"("``X````Z(@(`%```
M`$DB`@`'````7B("``X```!F(@(`$0```'4B`@`,````AR("`!8```"4(@(`
M#0```*LB`@`*````N2("`!0```#$(@(`!@```-DB`@`'````X"("`"4```#H
M(@(`(@````XC`@`.````,2,"`!````!`(P(`$@```%$C`@`D````9","`!$`
M``")(P(`"0```)LC`@`5````I2,"``<```"[(P(`!````,,C`@`C````R","
M``L```#L(P(``@```/@C`@`5````^R,"``@````1)`(`$0```!HD`@`1````
M+"0"``0````^)`(`20```$,D`@`#````C20"`"\```"1)`(`+P```,$D`@`+
M````\20"``@```#])`(`'`````8E`@`%````(R4"`!T````I)0(`"0```$<E
M`@`D````424"`!H```!V)0(`(````)$E`@`+````LB4"``P```"^)0(`#```
M`,LE`@`-````V"4"`"D```#F)0(`"@```!`F`@`?````&R8"``4````[)@(`
M`P```$$F`@`!````Q04``,("``#7!0``DP(``/H#``!D!@```````$H&``#:
M!0``(00``)\```!:`P``X@8```````"?`0``<04````````>`P```````$X!
M``!O!```]P4``&8!``#R`0``T0,```P&````````(@(``,L`````````6@4`
M`'<%```K!@```````$@"``"T!```8`,``-T```#<!`````````````"M!0``
M`````-@&````````H@8``+(!``"@!0``0````/<!````````]00``,@```#H
M!0``90<```````"X`0``"08```````````````````````"$!@``M@``````
M``!?!```2P````````"L`0``@`$``-\&``#+`@``L0```"`%``!'````2@,`
M`,P%``!D`@``LP0```T"``"W!```;`(``.@!````````O08``%@"```U````
MA@4````````]`P``!0$``'P```!#!0``>@$``$(!```2`P``-@(``"@'```]
M`@``G08``'$```#'!0``Q`,````````*`0``J@```+L&````````P08``%4`
M``!E`````````````````````````%0!``!Z!@``T`$``"X#```#`@``````
M``````#1`@``%@$``+H&```(`````````.P$``"7!0``#P<````!````````
M`````"$```#F`P``1````/($`````````0$``'D$```Q`0``)@(``"0#```3
M`P``Q0$``(4#````````D04``"T!``!:!P``WP```'`!``#'`0``?@0``+@#
M````````H0$```P$``!S!0``Y`,`````````````I`(`````````````9@4`
M`-H!```!!0````````P"``#I````[0,```````#*!```*`$``,P"````````
MH`0``,H#``!1````3@0``*4````'`0```````*\!``#.!@``NP,``+8#``"7
M`P``'@4``(P`````````!`4``(`%``!2````9@<``/\``````````````)0!
M``!#!@```````%T'````````7`,`````````````7`(```8"```-!@``LP4`
M`)4%````````S0```&`'``"6!```?`0``$P#`````````````'H%``!S!P``
M`````$L$``"S`P``M0(`````````````L`,``-L!````````?P,``+X`````
M````]@4```````!B`0``#04```````#C!@`````````````.`@```````*H#
M``"Z`0``908``#(```#A`@```````-0"````````7@$``#(%``"J!0``AP(`
M`#,'```A!0``\P0``(H```!Z````Q0(``!X'```*!0``M0````````#A!@``
M.@(``-8"``!H!```N08``.D"``!#!`````````8%```X`````````&T$``!]
M````^P$``*\````9`P``J@8``.L"``#S`P```````-4&````````R0,`````
M````````>0,``!,%``#I!```.P````````#_`@``"04``"(%````````M```
M`*`#```\!P``@@8```````"O`@```````-T"````````U@,``"4"```+!@``
M`````$T#```E!0``B0,``.`#``!=````Q00``&X"``"F````90$``$T%```[
M`0``W@0``.,%``#K````&P<``,(&``"K!0``#P0``,X#````````00$``(D&
M``````````````8#``#G!@```````$H`````````]P,``,,$``"U!0``````
M`,0!``!%!P``P`0```````!%`0``7````/T!``!]`0````````8$````````
M`````/H&``!K`P```````$@%```4`0``C@$``+8$``"#!0``D@(```P#``#&
M!`````````````#3`0```````%`%``#V!```"`<``,X!``!E!```Y08``#L"
M``````````0``'8%``!@`@```````&D!```U`@``/P4``$4"``"%`@``60<`
M`&P'``!J````+@4``"8'``!&!```D0(````````E!```3@(``%8```#[!```
M`````.P&``!P!0```````(T#```'!0``C@,```````!K!```#`<``*<&``#O
M`0``%P,````````^````D`4``.D%``#;!@```````%H&``"M!```@`8`````
M``#J!0``>P0``.8`````````````````````````Y0```'8!``"L!```V`$`
M`+$%```2!@``50<``$D!``#1!0```````+H````>!````````!8&``#2````
MC@```.P#``"'`0``L`8``&T'`````````````"<!```4!@````````````#O
M````(0$`````````````<@(``'8$``!%!@``(P$``(`#``"$`@``````````
M``"E!0``````````````````R`,``(X&````````W@```-8!```8!```````
M`%\!```0!```.`,``!("```?`P``'`4``&(````&!@``AP```.H#``"?!@``
M``````````!8````VP0````````/````4P8`````````````008`````````
M````%P0``,D```#@!0``E`0``(4`````````!04```````!"!0``N`4`````
M``!^!0```````,0$``"*`P``T00``#L%``""`````````-,```"%`0```P,`
M```````>`@``S0,``/D%````````+`0``"$"``"B!0```````!\!``!%!```
MXP(``$@```#Y`@``>04``%D$````````9`4``)X%``#T!@```````*`!``"O
M`P```````$<%``#5````)P,``%\```#8````/`$``"@"``!Q`@``HP(``),!
M``!O!@``+00``+0"````````J0$``$4#``#7`@``UP$``*4!````````````
M`.X&````````&0(``#\"```W`0``NP$``'T#``#E!```&@$```````!=!0``
ME0(``%T!```8`P``RP8``&D$```T!```D@```.H&```K````?P```&P%```R
M`@``\@`````````:!0``G@```*<$``!Y`@```````+<&``!%``````4`````
M```R!P```````$T"````````M08``%4#``!/!@``7P8```````"Z`@``\0$`
M`,T!````````5P```/0#``#%`P``\@,````````9!```$00````````@````
M`````#`%```F`P``S`$```````"@!@``-0,``$8````^`0```````"4`````
M````7@<``+(%```=!```"@,``)X&````````<`````````#N`0``D````*0#
M```T!0``W@(``.H$``"O!@``B`4``/D&``"G`P``HP```,\```"S!@``ZP8`
M`"L$``!)`P``)@4``'P"``#;``````````0&``#U!0``!`(``',!``"2`P``
M``````````!F````70(``"<```"!!0``2@<``,T%``!$`P```````,@!``"+
M`@``&`8``!T"``"-!````````#`!````````L`$``.T``````````````)T#
M```+!P````````````#:`P``$`8```$"``"A!@``/`,``(<%````````/`4`
M````````````LP$``.H``````````````'X"``"?`@```````+P"````````
M:@8``,P```!1`0``````````````````B````'L&```_!````````'L%````
M````W````#0&```;!```$0$```````"S````AP0``)H%``"E!@``VP4``&4"
M```0`@```````,<&```\!@``Y```````````````.P0``,X`````````,`8`
M`)D&``!H`P``5P8```````#O`@``CP4``,\%```2!0``?P$```L#````````
ML`````````#$````;0,``'X#``````````````````!Z`@``*@4``%$#```9
M!0``8P````````"`!```<P```(T```#&````?P(``/`%``!``P``Q`4``&<&
M````````^0$```````````````````L%```V````3`<``!`#```L````@P(`
M`&\````T`````````'D&```<````X`8``)`&``!O`0``;04``,@%````````
M)P8``#T'```.``````````````"<!0```````#$"``!3`````````%<'``!X
M!```H@```&`!````````W@,````````)````%@0``-@#``!#`@``````````
M````````P@,``$\"```I`@``^@(``(P&``"5````+P$``%8"``!7!0``7`4`
M`&$&```C!0``=P$```````":`P```0,``*$$````````XP```!P&``#"!0``
M"@(``+L%````````.04```H&``!'`P``````````````````JP8``$,#``"K
M````!0<``&0```"]````@P8```````";`P``JP,```````"A`@``L0$``,($
M``"8!```*```````````````$0(``/@&```S`````P8``#@%``!<!P``V@0`
M`#8$``"^!@``BP$```````"&`P``&@0``````````````````$$#``#"````
M``````D'``"E!````````-T#````````D@8``)$#````````Y0$``#\'``!W
M!```;`$``$@'````!@``````````````````A@8```````!R````0`<```\&
M````````-`(``",`````````[04``*P&``!3`P``9`,``,8%``!*!```R@(`
M`%D````Q!P``%`4`````````````_P4```````!U`P```````*@$````````
M`````.("````````.0,`````````````_P$``(P%```\`@``O`8``"(&``#'
M!```4`8`````````````>@0``(0#``#6````[P8``%D!``";!```N00``*8%
M``#^`0``+`4````````%!@``R@```#D&````````SP(```````"\````;P,`
M`%\#```K`P``U`8``#,&```*````700```````#*!@``;@0``"D$``#O`P``
M)0,``+$$```<`0```````'$$```V`0```````*T`````````A`4``'L!``#V
M!@``9P<````````>!@```````-4$````````NP0``'8#``!)!0``````````
M``!1`@``%0(``/$$``"%!````````*T!``!Y````T`0``$,````@`P``3`0`
M``0````-`P``608``'<#``!`!@``X0```"H```#9`0```````"P#``"A````
M(P,``!($``!T`@``[P0``)D$`````````````/4&``!C`@``504`````````
M`````@<```$$``"H`@``OP(``#P``````````````!(```#N!```,00`````
M``#H!@``%00```````!7`@``OP$``(X%``#Y`````````-`%````````@0$`
M``T'``!H````Y`$``-0!```4!P``L`(``($$``"Y!0``-`<````````V!0``
M_P8``-H"``")!0``]`0```````"/`@``!P,``,8!```P!```*P<``&0$```R
M!````````/("``"(`@``"@<``-\"``!5!@``<`(`````````````TP8``,$#
M``!,``````````````#M`@``7`8``+4!```X!@``B@0``"`!``!+!P``5P0`
M`-`"``#2`P```````!\'```Z!```,@,``&`&````````8P,```````#2!0``
M4@0``+\#``````````````````!*`@``%P$``,X"```V!@``BP```,$"``"]
M`0```````"8$``!,!0```````(@#````````IP```%L'```D!P``\0```/@%
M``#Z`0```````#8#``"[`````P````````"B`@``4@<``/<"``">`@``8```
M`'X```!<`0````````````!/````<@0```````!2`P``&@8``!0"``"<`@``
MS00```````"'!@```````&8$``"2!````````)T"``##!@``\`````````"\
M!0``P`8``.`!```N`@``6P(```````"9!0``<`,``$`%``":````=`4```P!
M```W!0``!`,```````!J`@```````/0!``"G`@``````````````````````
M````````````5`(``)D#```_`0``G@0``"T%```:`````````)4$```V!P``
M\`$`````````````U`4````````-`0```````,D&````````00<``+<"````
M``````````````#,!@``'0```#H#`````````````(L#``"L!0``4P(``"X$
M``!K`0```````,\$```L!P``6`$``",$``"6`0````````````"]`@``#@<`
M`&L"``!A`````````&$"``"6````$0```)`!``!6!``````````````8````
MX0$```````!H`0``,`,``.4"```?````?`$```````#S!0``)0<``,D%```H
M!0``%@<```````#^`@``M`,``.0$````````9`<``#T!``!+`P``*`0``*0!
M````````PP(````````0````PP,``(8"````````O@$`````````````20<`
M`/L#```8`@``@@4``&4#``!H!@``U@0`````````````W`$`````````````
MOP8``-$&``"4!@``"P```#0!``#E!0``>P,``+8"````````K@8``"@&``#D
M!@``%0<```````"B`0````````````#$!@``V@````@"``!T!```%@,`````
M``!7`P``)08``"('`````````````/`#```%`P```````!D```!L`P``YP0`
M`,L!``#Z!```E0$``',$``#?`0``T@$``-X!````````^@```*(#``!3!0``
M`````+0!````````]````'P#``#5`0``D`,```````"?!0```````!L&```%
M!```Z08```,$````````:@<``&,!``"H!@``P````,$```!4!```604``'(#
M``#'`@````````````"-`@``G`,``!8%``#Q!0``-0$``(D"``"/````_@``
M`/H%`````````````,,!``!D`0```````)<$``"6`P``_@0``.$$``#0`P``
MK0,``,L%``#=`0```````&T&``"W``````````````!(!````````$\'``!1
M!```Q@8````````7`@```````*D`````````4`(``+T$```Z`0``50(``","
M``#2`@``#````)4&``"O!```MP$``"(!````````0P$``'('```.!0``````
M`'0!```^!@``[`(``"H#````````6P0``-($``#&`@````````````"B!```
M?@$``(D$````````M00``%8'````````004``)(%``#J`0``5`<``)@%```'
M!P```````.<#``"I`P``E0,``/P&``!"`P``&P(``"H$````````:P<``&<!
M```_!@``FP(``"\'``!_!0``O`$````````+!````````#H````K`@``#00`
M`%X$``#R!@```````&$#``"]`P``1`8``,@"````````>`,```````!?!0``
M1P8``'\$``#6!0``C08``.D#``"^`P``P`(``!('````````C04``!,````P
M!P```````-$````K!0```````"H'``!6`P```````%@%``":`@```@8``#P$
M`````````@(``&@'`````````````.````!J!```T````%\"``"[`@``````
M`)T```"G!0``:`(``*D$``"6`@``(`0``#$%``#B!```WP,``/<$``!X````
M`````!,'``#]`P``<@4``/P#`````````````,L#``!&`P``LP(```````#4
M!```"00``&P$```=!@````````\%``!)`@``@0(``#T&``"(!@``````````
M```A`P``(08``#H&``!6!@``,`````````"/`0``*@$```````"R`@``````
M```````J!@``W`(```@!``!>`@``\P(``-D&````````[@4```````"3````
M`````%H$`````````````,@&`````````````)<!``!;!0``'@```$\#``#M
M`0``'@$``&$'``````````````````#%!@``%0,``(T!````````?00``"0%
M````````J04``*P"```G!P````````8'`````````````+8%```<`@``V0(`
M``````"=`0``5P$```(!``!&`@``3P0``.L%``!*!0```````&X'````````
M"@0``,<`````````(@0``'@&``""`0``200``.T&``!K`````````'8&````
M````ZP,``,\!``#3`@``%````)<"`````````````-<#````````#@0``),%
M````````-P<``"<"``!K!@```````(4%``"_!```.0```$X#``#'`P``;P(`
M`)L```"E`@```````/P"``";!@``7@```$`$``!]!0``*P$``*D"````````
MF0```-D#```1!0``]P```#@"``"R````R@4```````#9!0````````````#P
M!`````````````#G!0````````````!'`@``+P4```````"Q`@```````&D#
M````````_P,```,%```@!@``1@8``!$#````````G`0``/0%``!V````7P<`
M`)\$````````K@,``$$"``";!0``"0,`````````````3`8```````!6!0``
M``````````#C!```MP4``"X&``#9````$`<``',&````````Z0$``#4$``!L
M!@``/@<``*,$``!G`````````'T&``"E`P````<``!T%``"Y`P```````%0%
M``!H!0``>P(`````````````>`(``(X$``")````@@,``),#``!J`0``;@,`
M`/D$``#``0``4@(``(,#``#H!```@````#X"```U!@``1`4``#0#```)`0``
MJ`4`````````````F@0```````!O!P``X0,``#L#`````````````-8&````
M````D0$```````"X!@``<08``!P$``#V`@``O04``'L```"!!@``J@$`````
M``!Q`P``"P$``.8"```[!@``-0<`````````````A````!T#```;!0``,P$`
M`"T```"7!@``R00````````L`@``EP```!H'```(`P```````(\$````````
MSP,```````"+!```)0$```````!0`````````%@'``!3!P``6@```&D"````
M````#@,``$0!``!;`P``/@0````````:`@```````*X```"X````````````
M``!B!@``U04``!\&``!4`P``?`8``$8!``"^!```.`<`````````````````
M`-H&``"$!```00```"D#``!1!P``M@$``-T$``!G`P```````,4```":`0``
M`````!4```!4````YP$``/$&``"=!```*`,``-<$``#X!```D00```````"9
M`0``.0$``&`$````````,P,``+\````,!0``Z`,``-L"``"2`0``\0,``+`$
M``#/!@``?@8``$(````9`0```````(\&``!C!@``A@0``&D%````````ZP$`
M`&('``"+!@``;0(```(#`````````````,$!``"Q!@``[@(````````M!@``
MFP$```````#B`````````%`'````````%`0``#$&``"F`P``1P<``/\$``!"
M!P``^`$```(```!'`0``<P,``"<%````````%P4``$\!```8`0``AP,`````
M``!;!@``B0$`````````````````````````````=`8```````"/`P``````
M`.X#``"F`@``XP,```@&```3!```2P4``&<"```$!P````````T````#`0``
M]P8``*8$``!B!0``TP,```````#0!@``S0(``*,!``!(!@``3`$``-<````^
M!0```````$D```!R!@``*@(```````"``@``_`$``/P%`````````````'<`
M```'!@``U````!L!``#.!0````````8```#]!0``%P8``*T&``#8`@``4P$`
M`*X!``!O!0``W@4``*$#``#\!`````````````!I!P``[00``(P!``"#!```
M``(``$T`````````0@(``+X"``"(`0``X@$```````#8!0``)````#,%```X
M`0``A`$``````````````````+H#```Q````E````)`$``!$`@```````"\`
M````````?P8``"\&``":!@``````````````````&@,``-<&``"G`0``]0``
M````````````J````$(&``"T!@``C`(``#4%`````````````%P$``!2!0``
M`````.(%``"?`P```P<````````?`@``TP0``"\$```Y`@```````+(&````
M````\`8``+@$``#*`0``-P,``*\%````````=0```#X#``!W`@```````(@$
M``#"`0``````````````````L`4``%X%```R`0``I`4``$$$``!0!```````
M`#\````D!```_@4`````````````DP0`````````````JP0``'4%``#U`@``
MTP4```````!T`P``K@4``.4#``"Y`0``'P4```````#)`0````````````!+
M`0```````"D'``"Z!```O@4``&P```!@!0```````&X!```C!@``!P0`````
M``!5!```L0,``!8"``!.!0```````.L$``""`@``$`4``)X#``#A!0``````
M`'@!``!I````@0,``.8%````````YP```$`!```.`0````````````!V`@``
MB@8``,$%```O`@````````````````````````````!&!P```````'4$``!'
M!```>@,``/`"````````0@0``/0"`````````````$,'``#?!0``&0<``"0"
M``"8`@``408``%$%``!0`P``\0(``````````````````$H!``!(`P``.0<`
M`%T#``"C!0````````````"#`0``(0<``&(#````````0`(````````F`0``
M3@```*L!````````B@4``$T&``!P!@``708``#,"``!-!```Q@,``,L$````
M````M`4``!<'```8!0``6@$``'4!```&`0``P00``#,$`````````````,T&
M``!$!```BP4``,0"`````````````,`%``#H`@``X`(``!,&``"0`@``Z@(`
M`"X!```R!@``F0(`````````````;0```%8!``!A!```L@,```````!Q`0``
M:08``-P#````````\P```%L!```5!@``YP(``+D"``"8!@``;0$```````!C
M!P``4P0``*X"````````D0```!4!````````HP8```````#;`P``9P4``"X`
M``#F`0````````````"R!```K````"`"``!R`0``\P$`````````````208`
M`.P!````````E@4```````#F!@``M@8```````"&````*0$```````#1`0``
MN`(``$0'```Z!0```````/L"```'`````````+D````1!@``!`$``!P'````
M````Y`4```````",!```!0(``%X#```2`0``_00````````3`@``@@0`````
M``#U`P``J08``)T%``#,!```&P```&($``#?!```\@4``*8!```F!@``?0(`
M```````<`P``"`0```````!C!```O`0``$X'``#(!```W@8```````#^`P``
MS`,``#@$```G!`````,```````#X`@``````````````````6`,``!\$```)
M`@``HP,```````"M`@```````#$#``!(`0``O`,``)0#``"<`0```````%4!
M``#O!0``XP$``*L"``!2`0``904```````!&!0``!0```'$'```Z!P``````
M`#<"```(!0``J`$``.0"````````80$``&X&````````^````(4&``#\````
MJ@(``/@#```7````/P,``)@#```]!0``X`0```````"D!`````````````!;
M````Y@0``,,````Y!```8P4``-D$```P`@```@4``*$%````````X@,```<"
M``"6!@``$0<``*0````L!@``%@```"T#````````#P(``/8````+`@``3@8`
M`&X%``"8`0``_08``#<&``!P!```E`4````````!!P``R0(``$\%````````
M`````%(&``#<!0```@0``%`!``#=!0```````"0!``!K!0````````````!B
M`@```````/L&```I!@``I@8```````#S!@``;@``````````````)`8```$&
M```=!P```````&<$``#V`P```````',"```4`P``)@````````!F`P``J@0`
M`"D```!4!@``%04``/4!```W!```+0<``/T````O`P``Z````+4#````````
M`````!`!`````````````-(&````````6`8````````=`0``=0(```\!``"#
M````2P(``/L```#<!@``7@8``#T````;`P``K@0```````#5`P``=P8``-@$
M``"_!0``A@$``)0"```B````+@<``,X$``!:`@```````*@#``!8!```````
M``````!A!0```````*0&``!F!@```````(H!``"W`P``<`<``(X"``">`0``
MU`,``*P#``"<!@``F````$P"``#``P``30$``/L%```]!```G````/D#``!Y
M`0``=08``&H#```M`@``]@$``.X`````````U0(````````$!````````'@%
M``!\!0```````"P!```9!@```````/T"``"1!@``_@8``(H"``!T````(P<`
M`$L&````````#@8``$4%````````9@(``%D"```[!P```````),&``"Z!0``
M:@4``"D%``"@````W08``````````````````$T'``",`P``#P,``"`'```3
M`0``60,``.P````B`P``-P```*`"````````````````````````PP4``($`
M``#L!0``&`<````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI
M;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`
M(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V
M86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO
M<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B
M)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@
M861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T
M(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H
M)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W
M;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&
M:6YG97)P<FEN=``E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I
M<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E
M<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E
M<R=S(%1A<VML:7-T`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M
M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N
M>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H
M(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I
M;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M
M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E
M=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`
M04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O
M<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W
M;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@
M1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O
M("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R
M871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!
M;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!
M;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G
M:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E
M<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L
M871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O
M>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L
M:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y
M+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3
M:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@
M4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`
M07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R
M=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S
M=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U
M:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET
M:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE
M;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG
M<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R
M;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y
M+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E
M<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I
M;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`
M0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V
M:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL
M`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S
M86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O
M<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE
M;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T
M97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D
M80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@
M9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E
M9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#
M96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`
M0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`
M0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC
M871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H
M86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S
M=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`
M0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE
M<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO
M;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G
M<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#
M;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU
M90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO
M=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL
M87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T
M:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O
M;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N
M`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U
M<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD
M($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I
M9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O
M;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`
M0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D
M.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D
M)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R
M>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#
M;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T
M('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@
M;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A
M9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP
M:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T
M<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N
M;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U
M;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@
M<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O
M;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L
M9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S
M97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N
M<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL
M>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV
M92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A
M=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@
M9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E
M<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I
M;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S
M`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@
M<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K
M=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L
M971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@
M26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y
M`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL
M`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O
M;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T
M92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@
M<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O
M<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T
M(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!2
M97!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL
M;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I
M;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W
M:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%
M9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R
M;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS
M(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N
M="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU3
M35,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S
M=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET
M;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U
M871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI
M;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M
M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y
M($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V
M86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D
M("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D
M(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE
M9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E
M=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I
M:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I
M;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL
M92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`
M1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L
M:7``1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O
M;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R
M96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE
M('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`
M1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I
M86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N
M`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'
M86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE
M<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I
M=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S
M`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X
M-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M
M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`
M2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG
M;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U
M.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(
M96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`
M2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE
M`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(
M;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ
M`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@
M9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I
M80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N
M`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L
M=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E
M8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O
M<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!)
M;G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@
M<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@
M8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D
M:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E
M<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A
M;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV
M86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`
M26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`
M26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D
M=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT
M.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D
M9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T
M('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E
M;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S
M=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE
M<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T
M:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R
M;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@
M3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B
M;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y
M;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`
M3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F
M<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A
M9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@
M07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,
M:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI
M9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT
M(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EN:P!,:6YK('!O:6YT<R!T;SH`
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T
M+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M
M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z
M(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@
M=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN
M(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/
M5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`
M36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC
M(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN
M7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S
M=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I
M96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N
M`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB
M97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T
M90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S
M<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I
M9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S
M<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H
M;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A
M;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C
M96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`
M36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I
M="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI
M<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-
M;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD
M;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE
M87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C
M8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO
M=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W
M;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI
M<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C
M;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T
M86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M
M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I
M;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N
M(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@
M55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V
M97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E
M(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA
M`$YE=R!#871E9V]R>0!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R
M;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI
M8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N
M9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`
M3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU
M;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@
M4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E
M="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`
M3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.
M;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O
M;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D
M:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T
M960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E
M<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M
M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C
M="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E
M`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD
M('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z
M($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A
M<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG
M(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/
M<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%
M05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N
M8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$`4$A0($-O9&4`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H
M;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O
M<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!A9&1I;F<`4&%K:7-T
M86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA
M;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A
M<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R
M9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H
M96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O
M<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A
M<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P
M;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S
M:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$
M96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`
M4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H
M;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I
M8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`
M4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T
M97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME
M>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R
M`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E
M;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R
M`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A
M=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE
M=SH`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO
M=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H
M90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U
M<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O
M<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP
M92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H
M96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O
M;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W
M(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T
M:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-A`%-A:6YT($AE;&5N80!3
M86EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M
M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I
M80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I
M9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B
M+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N
M9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O
M=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`
M4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@
M=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--
M4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E
M;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`
M4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P
M(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@
M>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM
M97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L
M:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O
M=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R
M:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET
M:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3
M=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A
M<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I
M;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R
M90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I
M;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3
M;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,
M871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3
M;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D
M97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T
M:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN
M9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`
M4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E
M(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D
M<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E
M<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@
M:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B
M+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`
M4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`
M4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z
M(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M
M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W
M961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R
M;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!4
M4U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I
M97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A
M;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`
M5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A
M='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L
M871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`
M5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@
M:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I
M9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA
M<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E
M(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T
M:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I
M;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@
M=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G
M<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI
M9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@
M=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE
M(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN
M9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E
M<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A
M<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E
M<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@
M8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E
M;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`
M5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O
M;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4
M:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S
M:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE
M('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A
M(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A
M9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@
M<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A
M9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I
M9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E
M9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N
M=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@
M;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T
M('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T
M(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@
M9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R
M:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R
M(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM
M90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I
M;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G
M9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4
M;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD
M(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI
M<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X
M.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T
M:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O
M("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!3
M4TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE
M('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`
M56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@
M;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E
M961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O
M.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T
M97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N
M<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@
M9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U
M<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P
M<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E
M(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N
M86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5
M<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U
M`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@
M*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I
M97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N
M9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A
M;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.
M54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA
M`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O
M=FED960@8GD`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE
M`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG
M(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P
M.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE
M;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO
M8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA
M=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N
M92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P
M:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ
M(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@
M=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S
M+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C
M:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N
M9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W
M:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I
M<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,
M20!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S
M+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS
M`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0
M<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N
M:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE
M`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S
M86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M
M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO
M="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<P!G=7-T:6YG`&@Z`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;G!U
M="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=
M`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!N86UE
M`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`
M<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R
M(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@
M9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!S>7-T96T@
M97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YN86UE9`!U<V5R('-E;&5C=`!V
M0V%R9`!W.@!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,0I297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-BTP,BTQ-R`Q,#HP,"LP,3`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#(M,3<@,3`Z,S@K,#$P,`I,87-T+51R86YS;&%T;W(Z($QA
M<WIL;R!,+B!4;W)N;V-I(#QT;W)L87-Z0'AE;FEA+G-O=&4N:'4^"DQA;F=U
M86=E+51E86TZ($AU;F=A<FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*`"`H)7,@;F%P<&%L(&5Z96SU='0I`"`H06QT+6)I;&QE;G1Y^R`E<RD`
M("@E<R!N87`@;?IL=F$I`"`H;6$I`"`H:&]L;F%P*0`@*'1E9VYA<"D`(#H@
M`"(E<R(@;F5M(&%L:_9N>79TX7(N`"(E<R(@;F5M(.ER=NEN>65S(';A;&%S
M>G3A<RX`(B5S(B!N:6YC<R!K;VYF:6=U<N%L=F$@82!(;W)D92!296=I<W1R
M>6)E;BX`(B5S(B!F87-T<G5K=/IR82UM96=J96QE;NUT]2!N96T@=&%LX6QH
M873S+@`B)7,B+70@:&]Z>N%A9'1U:R!A(&-S;W!O<G1O:VAO>BX`(B5S(BUT
M(&AO>GKA861T=6L@82!J;V=O<W5L='/A9VD@<F5N9'-Z97)H97HN`"(E<R(M
M="!N96T@:&]Z='5K(&SI=')E.B`E<RX`)2XR9DU"(&9E;&AA<WINX6QT(&$@
M)2XR9DU"(&UE9V5N9V5D971T8O5L("@E+C)F)24I`"5D("5S(.ES("5S`"5D
M(&YA<"!M^FQV82!L96KA<B!J96QS>F%VX6YA:R#I<G;I;GEE<W/I9V4N`"5D
M(&YA<&]S(&5L]7)E:F5L>NES`"5S("T@1FEG>65L;65Z=&5TZ7,`)7,@;&5N
M>6]M870`)7,@:V%R8F%N=&%R=.%S:2!F96QA9&%T;VL@+2!M96=E<O5S[73I
M<P`E<R!B9>%L;.UTX7,`)7,@;&]G:6X@;NEV(&EGZ6YY;.ES`"5S('-Z;VQG
MX6QT873A<VD@9F5L=.ET96QE:P!!("(E<R(@;F5V^R#A;&QO;>%N>2!MX7(@
M;.ET97II:RX`)7,@.B`E<R`E<P!!*'HI("5S(&OI<WIE;B#A;&P@87H@86SA
M8F)I(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K(&5L=NEG>NESZ7)E+DIE;/9L
M:F4@:VD@87IO:V%T(&$@9F5L861A=&\H:V$I="P@86UI*&ME*70@;6]S="!E
M;"!K[7;A;B!VZ6=E>FYI+@`E<R!K:73V;'3I<V4@<WK\:W/I9V5S`"5S('!E
M<F,`)7,@;F5M('1A;.%L:&%T\RX`)7,@+2`E<R`H]G-S>F5S96X@)7,I`"5S
M(&/M;6IE9WEZZ6ME`"5S(&YA<'3A<F$`)7,@9F5L:F5G>7KI<V5I`"5S(&9E
M;&%D871L:7-TX6IA`"5S.B!,96AE='/I9V5S+"!H;V=Y(&5Z(&$@;&5VZ6P@
M=F%L\VKA8F%N(&YE;2!A(&UE9V%D;W1T(&9E;&%D\W3S;"!S>N%R;6%Z:6LN
M($=O;F1O;&IA(&UE9RP@;6EE;/5T="!RX6MA='1I;G0@=F%L86UI<F4L('9A
M9WD@<WIE;>EL>65S(&EN9F]R;>%C:?-T(&%D(&UE9RX`+"!S>NEL;/9KZ7-E
M:P`L("5S("5S+7,@<WKI;&SV:^ES96L`+"!VX6QT;WKS("5S(.ES("5S(&OV
M>O9T=``M+2!VX6QA<W-Z;VX@+2T`,3(@\W+A<R!F;W)MX71U;0`R-"#S<N%S
M(&9O<FWA='5M`#(T(/-R80`\16SU>O4`17IE;B!B;&]K:R!H87-Z;N%L873A
M:&]Z(&5G>2!A9&%T8N%Z:7,@86QR96YD<WIE<B!S>OQK<^EG97,N`$AE;'ER
M96AO>FAA=&%T;&%N(&AI8F$@=/9R=.EN=`!!(&QE=NEL('1I=&MO<^UTX7/A
M:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E<RX`02!D:6=I
M=.%L:7-A;B!A;.'M<G0@;&5VZ6P@96QL96[U<GKI<^EH97H@96=Y(&YY:6QV
MX6YO<R!01U`@:W5L8W,@<WK\:W/I9V5S+@!!('1I=&MO<^UT;W1T(&QE=NEL
M(&1E:_-D;VSA<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,L(&5G>2!T
M:71K;W,@4$=0(&MU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+@!!
M(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S(%!'
M4"!K=6QC<RP@96=Y('1I=&MO<R!01U`@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A
M="!S>OQK<^EG97,N`$$@=&ET:V]S[71O='0@;&5VZ6P@9&5K\V1O;.%SX6AO
M>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<RP@96=Y('1I=&MO<R!3+TU)
M344@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N`$$@;&5VZ6P@
M9&EG:73A;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU
M;&-S+"!E9WD@=&ET:V]S(%,O34E-12!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T
M('-Z_&MSZ6=E<RX`02!L97;I;"!T:71K;W/M=.%SX6AO>B!E9WD@;GEI;';A
M;F]S(%,O34E-12!K=6QC<R!S>OQK<^EG97,N`$3I;&5L]71T(&)O<G5L="#I
M9P!$Z6QE;/5T="!G>65N9V4@97/U`$3I;&5L]71T(&5S]0!$Z6QE;/5T=&D@
M>N%P;W)O:P!$Z6QE;/5T="!H\WKA<&]R;VL`9&4O9'4`05!)($E$("AA('!R
M;V=R86UO>N%S:2!F96S\;&5T(&%Z;VYO<^UT\VIA*0!%<G+U;"!A>B!E9&ET
M;W)R\VP`3NEV:F5G>2XN+@!A8G-Z(&%L=6P`86)S>B!K]GKI<`!.:6YC<R!J
M;V=O<W5L='/A9V$@82!61E,@86QK]FYY=G3A<B!LZ71R96AO>N%SX6AO>BX`
M3FEN8W,@:F]G;W-U;'1SX6=A(&$@5D93(&;A:FP@;.ET<F5H;WKA<^%H;WHN
M`$)E:F5L96YT:V5ZZ7-I(&EN9F]R;>%C:?,`2F5L<WKS`$$@:F]G;W-U;'1S
MX6<@9F5L('9A;B!F_&=G97-Z='9E+@!0Z6YZ_&=Y96L`0F5V:71E;`!!;&-S
M;W!O<G0@;.ET<F5H;WKA<V$`2F]G;W-U;'1SX6=I(&%L8W-O<&]R="!LZ71R
M96AO>N%S80!!9&1J=6L@:&]Z>N$@:71T.@#::B!C<V]P;W)T(&SI=')E:&]Z
MX7-A`-IJ(&IO9V]S=6QT<^%G(&SI=')E:&]ZX7-A`$%L8W-O<&]R="!H;WIZ
MX6%DX7-A("(E<R(M:&5Z`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@:&]Z>N%A
M9.%S82`B)7,B+6AE>@#::B!F96QH87-Z;N%L\R!LZ71R96AO>N%S83H`VFH@
M;W-Z;&]P(&AO>GKA863A<V$`VFH@=&%G;VL@9F5L=NET96QE`-IJ('#A<B!H
M;WIZX6%DX7-A`$$H>BD@)7,@;65N_'0@861J=6L@:&]Z>N$@82!-;WII;&QA
M(&UE;OQS;W)H;WH`061J=6L@:&]Z>N$@82!C[6UJ96=Y>NEK:&5Z.@!!9&IU
M:R!H;WIZX2!A(&/M;6IE9WEZZ6ME;6AE>@#::B!F96QH87-Z;N%L\R!H;WIZ
MX6%DX7-A`"(E<R(@9F5L:&%S>F[A;/-T(&AO>GKA861T=6L@82!R96YD<WIE
M<FAE>BP@9&4@;F5M('-I:V5R_&QT(&$@=/9B8FD@8F5J96QE;G1K97KI<VD@
M861A="!TX7)O;.%S83H@)7,N`"(E<R(@9F5L:&%S>F[A;/-T(&9E;'9E='3I
M:R!A(')E;F1S>F5R8F4N($UO<W0@;>%R(&)E:F5L96YT:V5Z:&5T+@!!(')E
M;F1S>F5R:&5Z(&YE;2!A9&AA=/-K(&AO>GKA(/IJ(&9E;&AA<WINX6SS:RX`
M0^UM`$/M;6IE9WEZZ6L`061M:6YI<WIT<N%C:?,@+2!J;V=O<W5L='/A9V]K
M(&%DX7-A('1O=N%B8FD@9F5L:&%S>F[A;/-K;F%K`$%D;6EN:7-Z='+A8VGS
M`$AI<F1E=.ES96L`069G86YI<WITX6X`06QBX6YI80!!;&?I<FEA`$%L:6%S
M`$5L:&5L>65ZZ7,`4F5N9&5ZZ7,Z`&%Z(/9S<WIE<V5T`$UI;F1E;B!N96T@
M=F5N9.EG(&9E;&AA<WINX6SS`$UI;F1E;B!C<V]P;W)T`$UI;F1E;B!J;V=O
M<W5L='/A9P!-:6YD(&$@;NEG>2!O;&1A;&]N(&QE9WEE;B!K97)E=`!%;F=E
M9&K\;FL@;65G('3V8F(@8^UM970@:7,`02!S;W)S>N%M;W,@9F5L<V]R;VSA
M<R!T[7!U<V$@=N%L=&]Z=&%T:&%T\R!L96=Y96X_`$WA<B!LZ71E>FEK`$E-
M4U`@8F5J96QE;G1K97KI<VD@<&%R86WI=&5R96L`3>%S:6LL($E-4U`@:F5L
M<WKS`$WA<VEK+"!)35-0(&)E:F5L96YT:V5ZZ7-I(&[I=@!-X7-I:R!E;6%I
M;"!C[6T`06QT97)N873M=B!S86)L;VYO:P!!;'1E<FYA=.UV('-Z]G9E9SH`
M06UE<FEK86D@4WIA;6]A`$$@;65G861O='0@Z7)TZ6L@;F5M(&9O9V%D:&%T
M\R!E;"X`27-M97)E=&QE;B!H:6)A('3V<G3I;G0N`$%N9&]R<F$`06YG;VQA
M`$%N9W5I;&QA`$%N;VYI;2!P<F]X>6X@:V5R97-Z=/QL:2!I;G1E<FYE="!E
M;.ERZ7,`5N%L87-Z`$%N=&%R:W1I<WH`06YT:6=U82#I<R!"87)B=61A`$%L
M:V%L;6%ZX7,`06QK86QM87KA<V]K(&QI<W3A:F$`07H@86QK86QM87KA<R!K
MZ7-Z+@!!(&OV>O9S('3A<G1E<OQL970@86QC<V]P;W)T:F%I<F$@:7,@Z7)V
MZ6YY97,`2O-VX6AA9WGA<P!+]G+\;&)E;/QL:2!MZ7)E=`#A<')I;&ES`&%R
M86(@*%=I;F1O=W,M,3(U-BD`02!T]FWV<NUT971T(.%L;&]MX6YY(&WI<F5T
M90!!('3V;?9R[71E='0@X6QL;VWA;GD@;F5V90!":7IT;W,@8F5N;F4L(&AO
M9WD@=/9R]FQN:2!K[7;A;FIA("5S(&)E:F5L96YT:V5ZZ7-I(&EGZ6YYZ70_
M`$)I>G1O<RP@:&]G>2!T]G+V;&YI(&%K87)J82`B)7,B+70@86QC<V]P;W)T
M:F%I=F%L(&5G>?QT=#\`07)G96YT[6YA`-9R;>EN>6]R<WKA9P#V<FWI;GD@
M*$%235-#24DM."D`3?MVZ7-Z970`07)U8F$`4&]H;G!E:0!!<V-I:2!R86IZ
M;VL`P7IS:6$O0W-E;F1E<RWS8V7A;FD@<NEG:?,`2^ER:F5N(&$@<F5N9'-Z
M97(@;65G97+U<^UTZ7-T(&$@:V%R8F%N=&%R=.%S:2!F96QA9&%T;VL@96QV
MZ6=ZZ7-E(&5L]71T/P!(;WIZX7)E;F1E;.ES:2!O<WIL;W!O:P!.96ULZ71E
M>O4@8W-O<&]R=&]T(&OM<^ER96QT(&UE9R!T]G+V;&YI+@!.96ULZ71E>O4@
M:F]G;W-U;'1SX6=O="!K[7/I<F5L="!M96<@=/9R]FQN:2X`3F5M;.ET97KU
M(&IO9V]S=6QT<^%G;W0@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+@!.
M96ULZ71E>O4@:_9Z]G,@=.%R=&5R_&QE=&5T(&OM<^ER96QT(&UE9R!M96=V
MX6QT;WIT871N:2X`5'5L86ID;VYSX6=O:P!A=6=U<WIT=7,`075S>G1RX6QI
M80!!=7-Z=')I80!!=71H7V-Y<G-Q;#H@82!S>OQK<^EG97,@:6UA<"!B]7;M
M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?8WER=7,Z(&$@:.%T=.ER<WIO;&?A
M;'1A=.%S(&YE;2!R96YD96QK97II:R!A(&OM=N%N="!KZ7!E<W/I9V5K:V5L
M+@!!=71H7V-Y<G5S.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A
M;.%L:&%T\RX`075T:%]F='`Z(&$@<WK\:W/I9V5S(&9T<"!B]7;M=.ES(&YE
M;2!T86SA;&AA=/,N($9O<F3M='-A(&QE(&$@4$A0+70@87H@+2UE;F%B;&4M
M9G1P(&]P8VGS=F%L+@!!=71H7VEM87`Z(&$@<WK\:W/I9V5S(&EM87`@8O5V
M[73I<R!N96T@=&%LX6QH873S+@!!=71H7VMR8C4Z(&$@<WK\:W/I9V5S(&MR
M8C4@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7VQD87`Z(&YE;2!H;WIH
M873S:R!LZ71R92#Z:B!F96QH87-Z;N%L\VL@06-T:79E($1I<F5C=&]R>2!E
M<V5TZ6X`075T:%]L9&%P.B!F96QH87-Z;N%L\VL@;F5M('3V<O9L:&5T]6L@
M06-T:79E($1I<F5C=&]R>2!E<V5TZ6X`075T:%]L9&%P.B!A('-Z_&MSZ6=E
M<R!,1$%0(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]L9&%P.B`E<R!F
M96QH87-Z;N%L\R!H;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R
M(';A;&%S>F$Z(`!!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS('3V<FSI<V4@
M;F5M('-I:V5R_&QT`$%U=&A?;&1A<#H@)7,@9F5L:&%S>F[A;/,@861A=&%I
M;F%K(&UE9_IJ[73A<V$@;F5M('-I:V5R_&QT`$%U=&A?;&1A<#H@82!F96QH
M87-Z;N%L\VL@;F5M(&WS9&]S[71H873S:R!!8W1I=F4@1&ER96-T;W)Y(&5S
M973I;@!!=71H7VUC86PZ(&$@<WK\:W/I9V5S($U#04P@8O5V[73I<R!N96T@
M=&%LX6QH873S+@!!=71H7W-M8F%U=&@Z(&$@<WK\:W/I9V5S('-M8F%U=&@@
M8O5V[73I<R!N96T@=&%LX6QH873S+@!.96T@<VEK97+\;'0@87H@24U!4"!S
M>F5R=F5R96X@=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$$@9F5L:&%S
M>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="X`02!F96QH87-Z;N%L\V%Z
M;VYO<^UTX7,@;F5M('-I:V5R_&QT+B`E<P!!(&9E;&AA<WINX6SS(&%Z;VYO
M<^UTX7/A="!A(%)!1$E54R!S>F5R=F5R(&5L=71A<^UT;W1T82X`3F5M('-I
M:V5R_&QT(&%Z($944"!S>F5R=F5R:&5Z('9A;/,@9F5L:&%S>F[A;/-A>F]N
M;W/M=.%S+@!.96T@<VEK97+\;'0@87H@4TU"('-Z97)V97)E;B!V86SS(&9E
M;&AA<WINX6SS87IO;F]S[73A<RX`02!R96YD96QK97KI<W)E(.%L;/,@;65Z
M]6LZ`$%Z97)B86ID>G/A;@!!(&=O;F]S>B!R96YD<WIE<F=A>F1A(&UE;G1S
MZ6=E:0!(X71TZ7(`2.%T=.ER('-Z[6X`3F5M(&UE9V9E;&5L]2!K97)B97)O
M<R!J96QS>O,N`$YE;2!M96=F96QE;/4@:V5R8F5R;W,@9F5L:&%S>F[A;/-N
MZ78N`$)A:&%MX6L`0F%H<F5I;@!B86QT:2`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<P!"87)B861O<P!!(&=R869I:W5S(.%L;&]MX6YY;VL@(B5S(B!A;&OV
M;GEV=.%R82!N96T@=&%LX6QH873S+@!A;&%P=F]N86QO;@!&96CI<F]R;W-Z
M;W)S>N%G`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=.%N`%-Z
M_&QE=.ES;F%P`$$@(B5S(B!B;&]K:R!A("(E<R(@<')O9W)A;6UA;"!N96T@
M=&%LX6QH873S+@!+Z7!E<FYY]7+I<WH@8F7A;&SM=.%S`$OI<&5R;GGU<NES
M>B!T[7!U<P!FZ6QK]G;I<@!";VSM=FEA`$ME9'9E;F,@=V5B8^UM96L`2V5R
M970`2V5R971V87-T86=SX6<Z`$ME<F5T96L`0F]S>FYI82U(97)C96=O=FEN
M80!-:6YD:V5T=/4`0F]T<W=A;F$`86QU;`!";W5V970M<WII9V5T`$)R87KM
M;&EA`$)R:70@26YD:6%I+?-C9>%N:2!497+\;&5T`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&?A<FEA`$9E;'-O<F]LX7,`0G5R:VEN82!&87-O`$)U<G5N9&D`
M5V5B;VQD86P@:V%R8F%N=&%R=.%S`$-20P!!('1A;OIS[71VX6YY=FES<WIA
M=F]NX7-I(&QI<W3A:R`H0U),*2!C[6UE:0!#96QL82!T=6QA:F1O;G/A9V]K
M`$$@8V%C:&4@:6YI8VEA;&EZX6SA<V$@;F5M(&9E:F5Z]63V='0@8F4N`$YA
M<'3A<@!.>75G;V1T`$MA;6)O9'IS80!+86UE<G5N`$YE;2!S:6ME<OQL="!A
M(&IE;'-Z\W0@X73A;&SM=&%N:2P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87ID
MX6AO>BX`02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2#M<FAA=/,N`$$@:_QL<_4@
M9F5L:&%S>F[A;/-K87!C<V]L870M:V5Z96SU:R!N96T@861M:6YI<WIT<N%L
M:&%T\VLN`$$@:_9V971K97KU($E-05`@<WIE<G9E<B!N96T@Z7)H973U(&5L
M.B`E<P!!*'HI("(E<R(@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE9RX`2V%N
M861A`$WI9W-E`$WI9W-E(&O\;&3V:R!H:6)A:F5L96YTZ7-T`$$H>BD@(B5S
M(B#A;&QO;>%N>2!N96T@=/9R]FQH973U+@!.96T@=&%LX6QH873S(&%Z(&ED
M96EG;&5N97,@X6QL;VWA;GEO:V%T('1A<G1A;&UA>O,@86QK]FYY=G3A<BX`
M02`G=&%R9V5T1FEL92<@<&%R86WI=&5R(&UE9V%DX7-A(&[I;&O\;"!N96T@
M9F]L>71A=&AA=&IU:RX`02AZ*2`B)7,B(&%L:_9N>79TX7(@;F5M('3V<O9L
M:&5T]2X`3F5M('3V<O9L:&5T]2P@)60@86QC<V]P;W)T:F$@=F%N+@!!>B#Z
M:B!S;W)B87)E;F1E>NES(&YE;2!L96AE='/I9V5S+"!A(&UE9V%D;W1T(&%D
M871O:R!S>N%M82!N96T@96=Y97II:R!A('3A<F]L=&%KZ79A;"X`02!M96=A
M9&]T="!S>N%M<F$@;F5M(&O\;&1H973U(&5L(&%Z(/QZ96YE="X`6O9L9"UF
M;VMI+7-Z:6=E=&5K`,%B<F%S>O9V96<`4WIO;&?A;'1A=/,`2V%T96?S<FGA
M:R#I<R!J96SV;.ES_&L`2V%J;>%N+7-Z:6=E=&5K`$UO8FEL('1E;&5F;VX`
M0V5L;&%T=6QA:F1O;G/A9V]K`$-E;&QA(&)E;'/U(&UA<F?S.@!#96QL871U
M;&%J9&]N<^%G;VL`0V5L;.%K(&OV>O9T=&D@<NES.@!-;V)I;"!T96QE9F]N
M`&ME;'1A("A)4T\M.#@U.2TQ-"D`:_9ZZ7``2_9ZZ7`M869R:6MA:2!+]GIT
MX7)S87/A9P!K96QE="UE=7+S<&%I("A)4T\M.#@U.2TR*0!!('1A;OIS[71V
MX6YY('+I<WIL971E:0!!('1A;OIS[71VX6YY('1U;&%J9&]N;W-A`%1A;OIS
M[71VX6YY(&9E;&AA<WINX6SA<VD@:7+A;GEE;'9E:P!#<^%D`%;A;'1O>G1A
M=.%S`$$@:F5L<WKS(.%TX6QL[73A<V$`07H@UFX@X6QT86P@96QK_&QD]G1T
M(&QE=F5L96ME;B!S>F5R97!L]2!NZ78@Z7,@8^UM(&UE9W;A;'1O>G1A=.%S
M82X`02!J96QE;B!K;VYF:6=U<N%C:?-B86X@;F5M(&QE:&5T<^EG97,@82!J
M96QS>F%V86L@;?-D;W/M=.%S82X@1F]R9'5L:F]N(&$@<F5N9'-Z97)G87ID
MX6AO>BX`2V%R86MT97(`3&EN7VME;&QE;O5R>NES+BXN`$-H:6QE`$OM;F$`
M:^UN86DL(&5G>7-Z97+[<^UT971T("A'0C(S,3(I`&OM;F%I+"!H86=Y;VWA
M;GEO<R`H0FEG-2D`5N%L87-S>F]N(&MI(&5G>2!A;&MA;&UA>N%S=#H`5N%L
M87-S>F]N(&IE;'-Z\W0`5N%L87-S>F]N(&5G>2!F96QH87-Z;N%L\VYE=F5T
M`%;A;&%S<WIA(&MI(&$@9.%T=6UO:R!M96=J96QE;NUTZ7-I(&9O<FWA:N%T
M.@!6X6QA<W-Z82!K:2!A(&9E;'-O<F]LX7,@=.UP=7/A="`H<WKA;6]Z;W1T
M(&QI<W3A:V[A;"D`2V%RX6-S;VYY+7-Z:6=E=&5K`$$H>BD@)7,@8VQA<W,@
M9&5F:6[M8VGS:F$@;F5M('1A;.%L:&%T\RX`1&5R_&QT`%3V<FQI(&%Z($U3
M3V9F:6-E('1A9V5K970`02!L96OI<F1E>NES('3V<FSI<V4`)7,@9F5L:&%S
M>F[A;/,@=/9R;.ES90!!(&9E;&AA<WINX6SS('3V<FSI<V4`02!F96QH87-Z
M;N%L\R!A9&%T86EN86L@=/9R;.ES90!%<W3I<F4@9&5R_&QT(.EG`$$@9F]L
M>71A=.%S:&]Z(&MA='1I;G1S;VX@87H@96?I<G)E;`!#;&EC:V%T96QL('-Z
M;VQGX6QT873A<R!(5%10+6X@:V5R97-Z=/QL`$%Z(&%B;&%K(&)E>N%RX7-A
M`$)O<G5L="#I9P!296=G96P@9F5L:/5S(&ED]0!&96QH]7,@:63U`$OS:W5S
M>BUS>FEG971E:P!4_&YT97-S_&L@96P@87H@;VQD86QS\R!M96[\=`#6<W-Z
M97KA<G0@:V5R971E:P!+;VQU;6)I80!3>NUN`%-Z[6YVX6QA<WIT\P!3>NUN
M=N%L87-Z=.%S`$]S>FQO<&]K.@!!>B!O<WIL;W!O:R!C[6UE:0!6:6-C96L`
M4&%R86YC<P!087)A;F-SZ7)T96QM97KU`$UE9VIE9WEZZ7,`3NEV+"!E;&YE
M=F5ZZ7,`0V]M;W)E+7-Z:6=E=&5K`$/I9P!3>N%M[73S9^EP96L`263U:N%R
MX7-I(&AE;'EZ970`263U:N%RX7-I(&AE;'EZ970`2_QL]FYB<^EG96L@82!K
M;VYF:6=U<N%C:?-B86X`2^EZ:7-ZX6WM=/-GZ7!E:VME;"P@;VMO<W1E;&5F
M;VYO:VMA;"P@3W5T;&]O:VMA;"!V86SS(&%D871S>FEN:W)O;FEZX6SA<R!K
M;VYF:6=U<N%C:?-J80!!(&MO;F9I9W5RX6-I\R!MX7(@;F5M(.ER=NEN>65S
M+@`E<R!K;VYF:6=U<N%C:?-J80!!(&IE;'-Z\R!M96=E<O5S[73I<V4`2V]N
M9_,`2V]N9_-I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9P!3:6ME<G1E;&5N
M(&$@:V%P8W-O;&%T+@!3:6ME<G1E;&5N(&$@:V%P8W-O;&%T.B``02!N>6EL
M=N%N;W,@:W5L8W-O:R!S>F5R=F5R92!E;'5T87/M=&IA(&$@:V%P8W-O;&%T
M;W0N`$$@;GEI;';A;F]S(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A
M(&MA<&-S;VQA=&]T+B!/:V$Z("5S("@E<RD`4VEK97)T96QE;B!A>B!&5%`@
M<WIE<G9E<G)E;"!V86SS(&MA<&-S;VQA="X`4&%R=&YE<F5K`$$@<&%R=&YE
M<F5K970@<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ96=Y>NEKZ6AE>BX`
M02!T]FWV<NUT971T(.%L;&]MX6YY('3M<'5S83H@`"(E<R(@=&%R=&%L;6$`
M1F]L>71A=.%S`$-O;VLM<WII9V5T96L`4_QT:0!-X7-O;&IU:R#A=`!!(&WA
M<V]LX7,@;F5M('-I:V5R_&QT.B`E<P!!(&MI:F5L]FQT('+I<WH@;>%S;VSA
M<V$`4WKA;6SA>N%S:2!A>F]N;W/M=/,`0V]S=&$@4FEC80!%;&5FX6YT8W-O
M;G1P87)T`$YE;2!S:6ME<OQL="!01U`M=F5L('1I=&MO<^UT86YI(&$@;&5V
M96QE=#H@`$$@;&5V96QE="!N96T@<VEK97+\;'0@4$=0(&%LX>URX7-S86P@
M96QLX71N:3H@`$$@;&5V96QE="!N96T@<VEK97+\;'0@87H@4R]-24U%('-Z
M86)VX6YY('-Z97)I;G0@=&ET:V]S[71A;FDN`$$@;&5V96QE="!N96T@<VEK
M97+\;'0@4R]-24U%(&%LX>URX7-S86P@96QLX71N:2X`02!P87)T;F5R(&%D
M871A:70@;F5M('-I:V5R_&QT(&5L=.%R;VQN:2X@)7,`07H@3$1!4"!S>F5R
M=F5R(&YE;2#I<FAE=/4@96PN`$YE;2!S:6ME<OQL="!E;&QE;O5R:7IN:2!A
M('-ZX6ULX6KA;B!R96YD96QK97KI<W)E(.%L;/,@]G-S>F5G970N("5S`$YE
M;2!S:6ME<OQL="!A>B!,1$%0('-Z97)V97)H97H@:V%P8W-O;/-D;FDN`$YE
M;2!S:6ME<OQL="!A*'HI("(E<R(@<WIE<G9E<G)E;"!&5%`@:V%P8W-O;&%T
M;W0@9F5L=F5N;FDZ("5S`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@:_9R
M;&5VZ6QL:7-TX70N("5S`$%Z(&%D871O:R!01U`@=&ET:V]S[73A<V+S;"!T
M]G)TZ6[U(&1E:_-D;VSA<V$@;F5M('-I:V5R_&QT.B``07H@861A=&]K(%,O
M34E-12!T:71K;W/M=.%S8O-L('3V<G3I;O4@9&5K\V1O;.%S82!N96T@<VEK
M97+\;'0N`$$@<&%R=&YE<B!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@)7,`02!K
M]G)L97;I;&QI<W1A('3V<FSI<V4@;F5M('-I:V5R_&QT+B`E<P!.96T@<VEK
M97+\;'0@=/9R]FQN:2!A*'HI("(E<R(@<V5T=7`@=7!G<F%D92!P<F]G<F%M
M;W0N`$YE;2!S:6ME<OQL="!M96?A;&QA<.UT86YI(&$@8^UM>F5T="!E;6%I
M;"!C[6WI="X`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A('1E;&IE<R!C[6UJ
M96=Y>NEK970N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@:_9R
M;&5VZ6QL:7-TX70N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I
M;&QI<W3A:R!T96QJ97,@9F5L<V]R;VSA<^%T+@!!*'HI("(E<R(@<W1R873I
M9VEA(&YE;2!T86SA;&AA=/,N`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!H
M;WIH873S(&SI=')E+@!!(&YY:6QVX6YO<R!K=6QC<V]T(&YE;2!S:6ME<OQL
M="!M96=S>F5R97IN:2!A(&MU;&-S<WIE<G9E<G+U;"X`3F5M('-I:V5R_&QT
M("(E<R(M="#M<N%S:2!CZ6QL86P@;65G;GEI=&YI+@!.96T@<VEK97+\;'0@
M)7,M="!M96=N>6ET;FDN`$$@)7,@:V%R8F%N=&%R=.%S:2!M;V1U;"!N96T@
M;GEI=&AA=/,@;65G`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!N>6ET:&%T
M\R!M96<N`$%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+@`E<R!N96T@
M;VQV87-H873S+@!.96T@<VEK97+\;'0@82!K[7;A;G0@9F5L:&%S>F[A;/,@
M:F5L<WIA=N%T(.%TX6QL[71A;FDN($%Z(&UE9V%D;W1T(&%D871O:R!N96T@
M=F%G>2!N96T@=&5L:F5S96X@9F5L96QN96L@;65G+B!0<O-BX6QJ82#Z:G)A
M+"!V86=Y(&AA('1O=N%B8FD@<V5G[71SZ6=R92!V86X@<WK\:W/I9V4L(&9O
M<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN`$YE;2!S:6ME<OQL="!M96=H
M873A<F]Z;FD@87H@96SI<NES:2!J;V=O<W5L='/A9V]K870@*$%#3"D`3F5M
M('-I:V5R_&QT(&)E;VQV87-N:2!A(&/M;6IE9WEZZ6ME="X@)7,`3F5M('-I
M:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE=NEL;&ES=.%T+B`E<P!.96T@<VEK
M97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5VZ6QL:7-TX6MA="X@)7,`3F5M('-I
M:V5R_&QT(&UE9VAA=.%R;WIN:2!A('-Z97)V97(@:^EP97-SZ6=E:70`3F5M
M('-I:V5R_&QT('9I<W-Z8>%L;.UT86YI(&5Z(&5R961E=&D@:V]N9FEG=7+A
M8VGS="X`02AZ*2`B)7,B(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2X`3F5M
M('-I:V5R_&QT(&5L;65N=&5N:2`E<R!K;VYF:6=U<N%C:?-T+@!.96T@<VEK
M97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I\W0N`$YE;2!S
M:6ME<OQL="!E;&UE;G1E;FD@82!B86-K=7`@:V]N9FEG=7+A8VGS=#H@)7,`
M3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A*'HI("(E<R(@<V5T=7`@=7!G<F%D
M92!P<F]G<F%M;W0N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82AZ*2`E<R!B
M86-K=7`@:V]N9FEG=7+A8VGS="X`02AZ*2`E<R!K;VYF:6=U<N%C:?-S(.%L
M;&]MX6YY="!N96T@<VEK97+\;'0@96QM96YT96YI+B!686=Y(&AA<WINX6QJ
M82!A("5S(&]L9&%L;VX@;&5V]2!L96AE=/5SZ6=E:V5T+"!V86=Y(&WA<V]L
M:F$@X70@87H@86SA8F)I(&OS9&]T(&ED93H@)7,N`$%Z($Q$05`@<WIE<G9E
M<F5N(&YE;2!S:6ME<OQL="!E;';I9V5Z;FD@82!K97)E<^ES="X`(B5S(B!N
M96T@=F]L="!T]G+V;&AE=/4N`$$@<&%R=&YE<B!A9&%T86ET(&YE;2!S:6ME
M<OQL="!M\V1O<^UT86YI+B`E<P!.96T@<VEK97+\;'0@82!K]G)L97;I;&QI
M<W1A(&WS9&]S[73A<V$N("5S`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@(B5S
M(B!K;VYF:6=U<N%C:?-JX70Z("5S`$$@36]Z:6QL82!M96[\<V]R(&YE;2!T
M86SA;&AA=/,N($5L;&5N]7)I>GIE+"!H;V=Y(&UE9R!V86XM92!N>6ET=F$N
M`$YE;2!S:6ME<OQL="`B)7,B(&9E;&AA<WINX6SS;F%K(&IO9V]S=6QT<^%G
M;W0@861N:2!A*'HI("(E<R(@;6%P<.%H;WHZ("5S`$MO<FSA=&]S('-Z]G9E
M9P!/<G-ZX6<`5.%V;VMT873A<P!,Z71R96AO>N%S`$QI;FL@;.ET<F5H;WKA
M<V$`VFH@;.ET<F5H;WKA<V$`06QM87!PX6L@;.ET<F5H;WKA<V$`07H@;V)J
M96MT=6T@;.ET<F5H;WKS:N%N86L@:F]G;W-U;'1SX6=A:0!(:71E;&OA<G1Y
M87-ZX6T`2&]R=N%T;W)S>N%G`$MU8F$`2F5L96YL96=I(#0@9N%Z:7,`02!J
M96QE;FQE9VD@9F5L:&%S>F[A;/-K87!C<V]L871O:P!0;VYT;W,@:63U`$$@
M:F5L96YL96=I(%523`!*96QE;FQE9VD@9F5L:&%S>F[A;/-K`$IE;&5N;&5G
M:2!I9/5JX7+A<P!!(&IE;&5N;&5G:2!I9/5JX7+A<VD@:&5L>7IE=#H`2F5L
M96YL96=I('-T[6QU<P!-:6QY96X@<&%R86YC<V]K(&9U<W-A;F%K(&QE(&%U
M=&]M871I:W5S86X@82`E<V)E('3V<G3I;O4@8F5J96QE;G1K97KI<VMO<BX`
M2VEVX6?A<P!!(&MI:F5L]FQT('+I<WH@:VEVX6?A<V$`0VEP<G5S`&-I<FEL
M;"`H2T])."U2*0!C:7)I;&P@*%=I;F1O=W,M,3(U,2D`8VER:6QL+75K<N%N
M("A+3TDX+54I`$-S96@@2_9Z=.%R<V%SX6<`1$0`1%-.("AA9&%T9F]R<N%S
M;&7M<O,@+2!LX7-D.B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`&YA<&]N=&$`1&%T
M851R964@8O9N9^ES>O4`061A=&+A>FES8F%N('9A;/,@:V5R97/I<P!$X71U
M;0!!(&)EZ7)K97KI<R!N87!J80!$X71U;2!K:7;A;&%S>G3A<V$`;F%P<&%L
M`$]S>FQO<"!T]G)LZ7-E`&1E8V5M8F5R`'-ZX6UO:P!"96ME>F3I<R!K:6IJ
M96)B`$%L87#I<G1E;&UE>F5T=`!!>B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT
M:2!S>NUN`$%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\P!!;&%P
MZ7)T96QM97IE='0@<VAE;&P`1&5F:6[M8VGS:P!4]G)LZ7,`02!C96QL82!T
M]G)LZ7-E`$$@8W-O<&]R="!T]G)LZ7-E`$$@;F%P;//A;&QO;>%N>2!T]G)L
MZ7-E`$$@:F]G;W-U;'1SX6<@=/9R;.ES90!,979E;&5K('3V<FSI<V4`02!C
M96QL82!T]G)LZ7-E`$%Z(&]S>FQO<"!T]G)LZ7-E`%3V<O9L:OQK(&MI(&$@
M;65G;.EV]2!A;'1E<FYA=.UV('-A8FQO;G0`02!L979E;&5K('3V<FSI<V4`
M(B5S(B!J;V=O<W5L='/A9V%I;F%K('3V<FSI<V4`5/9R]FQJ_&L@(B5S(B!J
M;V=O<W5L='/A9V%I="#I<R!E;FYE:R!E<V5T;&5G97,@86QC<V]P;W)T:F%I
M=#\`02!S;W(@=/9R;.ES90!!(&MI=N%L87-Z=&]T="!A>F]N;W/M=/,@=/9R
M;.ES90!!>B!A;&UA<'#A:R!T]G)LZ7-E`$$@:F5L96YL96=I(&]S>FQO<"!T
M]G)LZ7-E`$$@:F5L96YL96=I('-O<B!T]G)LZ7-E`%3V<O9L=/QK(&$H>BD@
M(B5S(B!S971U<"!U<&=R861E('!R;V=R86UO="X`02!KZ7IB97/M=.ES(&ED
M96IE`$3A;FEA`$%D:F]N(&QE[7+A<W0@82!P<F]B;.EMX7+S;`!,9>URX7,`
M4NES>FQE=&5K("AA($AO<F1E(&QO9V;A:FQB86X@:7,@;65G=&%LX6QH873S
M*3H`02!RZ7-Z;&5T96L@82!R96YD<WIE<F=A>F1A('-ZX6WA<F$@:^ES>OQL
M]2!N87!L\V;A:FQB82!K97+\;'1E:RX`1F5J;&5S>G3I<P!(87)M871P;VYT
M`$AA<FUA='!O;G0@:F5L96YL96<Z(`!(87)M871P;VYT.B``8F%L<O-L(&IO
M8F)R82#M<N%S`&IO8F)R\VP@8F%L<F$@[7+A<P!#[6UTX7(`07H@:63U<&]N
M=&]K870@,C0@\W+A<R!F;W)MX71U;6)A;B!J96QE;NUT<_QK(&UE9S\`365G
M:F5L96[M=.ES:2!B9>%L;.UTX7-O:P!!('+I<WIL971E<R!E;/5R96IE;'KI
M<R!M96=J96QE;NUTZ7-E`$5L]7)E:F5L>NES(&UE9VIE;&5N[73I<V4@*')E
M</QL]73I<FDI`$UE9VIE;&5N[73I<VD@9F]R;>%T=6T`R7)T97/M=.ES(&$@
M:^EZ8F5S[71E='0@;&5VZ6P@<V]R<^%R\VP`1'IS:6)U=&D`3F4@=/9R]FQJ
M_&L`02!M86EN=&5N86YC92YP:'`@;F5M(.ER:&5T]2!E;"!K]GIV971L96[\
M;"X`07H@96QS]2!S;W(@82!M97KU:R!N979E:70@=&%R=&%L;6%Z>F$_($AA
M(&EG96XL(&IE;/9L:F4@:VD@97IT.@!$;VUI;FEK80!$;VUI;FEK86D@2_9Z
M=.%R<V%SX6<`3FEN8W,@;>EG(&QO9VEN(&YE=F4_($EGZ6YY96QJ96X@96=Y
M970N`$QE=/9L=.ES`%3V;'1S_&L@;&4@)7,M=`!4]FQT<_QK(&QE(%!(4"!P
M<F]G<F%M(&9O<FWA:N%B86X@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0N
M`$QE9_9R9/QL]2!L:7-T80!+X6+M=/-S>F5R96L`96UA:6P`16UA:6QB]6P@
M4TU3+6O\;&3U(&UE9VAA:G3S+"!H82!A('1E;&5F;VYTX7)S87/A9R!B:7IT
M;W/M=&IA(&5Z="!A('-Z;VQGX6QT873A<W0N`$A)0D$`16-U861O<@!-\V1O
M<^UTX7,`0FQO:VL@;?-D;W/M=.%S`$-S;W!O<G0@;?-D;W/M=.%S`$IO9V]S
M=6QT<^%G(&WS9&]S[73A<P!*;V=O<W5L='/A9V]K(&WS9&]S[73A<V$`)7,@
M:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A`$UE;'EI:R!O<&-I\VMA="!V
MX6QT;WIT87-S=6LZ`"(E<R(@:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A
M`"5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80!/:W1A=.%S`$5G>6EP
M=&]M`%-A;'9A9&]R`$5L96TN+BX`87H@)VTG(&)E=/L@<WKI;&5S<^EG90!%
M;6%I;`!%;6%I;"!C[6T`07H@96UA:6P@8^UM96MN96L@96=Y97IN:?QK(&ME
M;&PN`$5M86EL('9I<W-Z86EG87IO;.%S<V%L`$5M86EL+5--4R#A=&KA<O,`
M2&%N9W5L871I:V]N;VL`W')E<R#\>F5N970N`$YI;F-S(&EL>65N+@!4]G+V
M;&K\:R!K:2!A(&ME<F5SZ7-E:V5T`$5N9V5D:OQK(&UE9RP@:&]G>2!KZ7!E
M:V5T(&EL;&5S<WK\;FL@82!S>O9V96=B92!A($9O=/-G86SI<FGA:V+S;#\`
M3&5G>65N(&IO8F(@96?I<F=O;6)B86P@96SI<FAE=/4L(&MO;G1E>'1U<V;\
M9V?U(&UE;OP_`$%Z('5T;VQS\R#I=@#!=';A;'3A<R!K_&SV;B!A8FQA:W)A
M`$%D:F$@;65G(&%Z="!A(&)I>G1O;G/A9VD@:^ER9.ES="P@86UE;'ER92!M
M86ID(';A;&%S>F]L;FEA(&ME;&P@:F5L<WIA=N%N86L@X73A;&SM=.%SX6AO
M>BP@<&PN("=H;V=Y(&CM=FKA:R!A(&MU='GA:N%T/R<Z`$%D:F$@;65G(&$@
M:^EP(%523"UJZ70@:71T`,UR:F$@8F4@87H@86SA8F)I(&)E=/MK970Z`$5G
M>65N;.UT]6DM1W5I;F5A`$5R:71R96$`2&EB80!(:6)A('3V<G3I;G0@82!B
M;&]K:R!LZ71R96AO>N%S86MO<CH@)7,`2&EB82!T]G)TZ6YT(&%Z(&%D871S
M>FEN:W)O;FEZX6-I\W,@:F5L('3V<FSI<V5K;W(Z("5S`$%Z(&%D871S>FEN
M:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>2!T]G)LZ7-E(&YE;2!S:6ME<OQL
M=#H@)7,`2&EB82!T]G)TZ6YT(&%Z(&%D871L96OI<NES8F5N.B`E<P!(:6)A
M('3V<G3I;G0@82!J96QS>O,@;65G=N%L=&]Z=&%TX7-A:V]R.B`E<P!(:6)A
M(&%Z(&5M86EL(/QZ96YE=&)E;BX`02AZ*2`B)7,B(.%L;&]MX6YY<F$@;F5M
M('-I:V5R_&QT(.UR;FDN`,ES>G1O<G-ZX6<`171I\W!I80!.96UZ971I<^EG
M96L`175R\W!A`#$U('!E<F-E;FOI;G0`,B!P97)C96YKZ6YT`#,P(&WA<V]D
M<&5R8V5N:^EN=``U('!E<F-E;FOI;G0`;6EN9&5N(&)E:F5L96YT:V5ZZ7-K
M;W(`9NEL\W+A;FOI;G0`<&5R8V5N:^EN=`!0Z6QD82#I<G3I:V5K.@!6Z6=R
M96AA:G3A<P!.>6ES<W5K('-ZZ70`2F5L96[M='/\:R!M96<@87H@;VQD86QS
M\R!M96[\=`!)='0@)RDG(&ME;&QE;F4@:_9V971K97IZ96X`271T(&-S=7!A
M<WH@<WKS;F%K('9A9WD@:63I>O5J96QB96X@;&5V]2!K97)E<^ES:2!K:69E
M:F5ZZ7-N96L@:V5L;&5N92!L96YN:64`07H@Z7)VZ6YY97-SZ6<@;&5JX7)A
M=&$`2VET97;U`%-Z[6X`02!K;VYF:6=U<N%C:?,@1E10+6X@X70@=F%L\R!F
M96QT]FQTZ7-E`$$@<WIE;>EL>65S(&)EX6QL[73A<V]K870@;F5M('-I:V5R
M_&QT(&)E;VQV87-N:2X`07H@3$1!4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN
M`$%Z(%--0B!S>F5R=F5R(&YE;2#I<FAE=/4@96PN`$YE;2!S:6ME<OQL="!A
M*'HI("(E<R(M8O5L('3V<G3I;O4@;>%S;VSA<RX`3F5M('-I:V5R_&QT(&$H
M>BD@(B5S(BUB92!T]G)TZ6[U(&WA<V]LX7,N`$YE;2!S:6ME<OQL="#Z:B!3
M05-,(&MA<&-S;VQA=&]T(&SI=')E:&]Z;FDN`$YE;2!S:6ME<OQL="!A*'HI
M("(E<R(M8F4@=/9R=.EN]2#A=&AE;'EE>NES+@#!;&QO;>%N>6AO>GKA9NER
MZ7-I(&AI8F$Z("5S`%1I<WIT80!&86QK;&%N9"US>FEG971E:R`H36%L=FEN
M87,I`$9A<F]E+7-Z:6=E=&5K`$AE;'ER96AO>FAA=&%T;&%N(&AI8F$Z`$9A
M>`!&87@`9F5B<G7A<@!(]6WI<G/I:VQE=.ER>F5T`$CU;>ER<^EK;&5TZ7)Z
M970Z(`!%9WDM96=Y('KA<&]R`%-Z\W)VX6YY;W-A;B!H\WKA<&]R;VL`365Z
M]2!MX71R:7@`1FEG;&5T($-!4%1#2$$@*&)E=/MK:7)A:_,@:'5MX6YT97-Z
M="D`1FED>G-I`$;A:FP`02!FX6IL;VL@<WKA;6$Z("5S`$$@9N%J;&]K('-Z
MX6UA.B`E<P!&X6IL(&UE;F5D>G-E<@!&X6IL;NEV`$;A:FP@:VEJ96SV;.ES
M`$;A:FP@9F5L=/9L=.ES90!&X6IL;VL@9F5L=/9L=.ES92!N96T@;&5H971S
MZ6=E<RX`4WK[<O5K`$9I;FYO<G-ZX6<`96QS]2!FZ6P`96QS]2!N96=Y960`
M5N%L=&]Z871L86X@;>ER971A<N%N>0!4_&MR]GKI<R`H9O9L+VQE*0!+]F0`
M)7,@;6%P<&$@;F5M(&SI=&5Z:6L`0F5T^W-Z[6X`R71E;&5K`$]L>6%N(&+V
M;F?I<WKU:R!S>N%MX7)A+"!A;6EK(&YE;2!J96QE;NUT:6L@;65G(&$@:^EP
M96ME=`!%;/5R96IE;'KI<R`H<F5P_&SU=.ER:2D`07H@96SU<F5J96QZZ7,@
M:63U=&%R=&%M82!N87!O:V)A;B`H87H@96SU<F5J96QZZ7,@;F%P<&%L:2#I
M<R#I:G-Z86MA:2!A9&%T;VMA="!T87)T86QM87HL(&5ZZ7)T(&$@;F%G>2!S
M>N%M;VL@<WKI;&5S(&)L;VMK;W0@97)E9&WI;GEE>FYE:RD`16QF96QE:G1E
M='1E(&$@:F5L<WIA=N%T/P#;<FQA<&ME>F5LZ7,`263I>F5T`$EDZ7IE="!F
M86ITX6IA`$EDZ7IE=&5K`$EDZ7IE=&5K(#(`1O-R=6UO:P!4;W;A8F+M=.%S
M;VL`4.D`1G)A;64M96L`1G)A;F-I86]R<WKA9P!&<F%N8VEA;W)S>N%G`$9R
M86YC:6$@1W5Y86YA`$9R86YC:6$@4&]L:6[I>FEA`$9R86YC:6$@1.EL:2!4
M97+\;&5T96L`1F5L863S`$ERX6YY.B``4NES>FQE=&5S(&QE[7+A<P!T96QI
M:&]L9`!496QJ97,@;NEV`$=A8F]N`$UE;'EI:R!G86SI<FGA8O-L('9E9WG\
M:R!A(&OI<&5T`$OI<&=A;.ER:6$Z`$=A;6)I80!(;WIZ=6L@;.ET<F4@82AZ
M*2`E<R!K;VYF:6=U<N%C:?-JX70`02!K96QE=&ME>F5T="!K\V0`1W+Z>FEA
M`$[I;65T;W)S>N%G`$=HX6YA`$=I8G)A;'3A<@!+97)E<WIT;NEV`$=L;V+A
M;&ES(&)EX6QL[73A<V]K`$UE:&5T`$?V9&5L`$=O;V=L92!TZ7)KZ7``1V]O
M9VQE(&ME<F5SZ7,`1F5K971E+V9E:.ER`$?V<O9G;W)S>N%G`&?V<O9G("A)
M4T\M.#@U.2TW*0!'<O9N;&%N9`!'<F5N861A`$-S;W!O<G0@861M:6YI<WIT
M<N%C:?,`02!C<V]P;W)T;NEV(&UA<F%D:&%T(/QR97-E;@!'<F]U<%]L9&%P
M.B`E<R!C<V]P;W)T(&AO>GKA863A<V$@;F5M('-I:V5R_&QT+B!!('-Z97)V
M97(@=N%L87-Z83H@`$=R;W5P7VQD87`Z("5S(&-S;W!O<G0@=/9R;.ES92!N
M96T@<VEK97+\;'0`1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!A9&%T86EN86L@
M;65G^FKM=.%S82!N96T@<VEK97+\;'0`0W-O<&]R=&]K`$=U861E;&]U<&4`
M1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`5F5N9.EG(&IO9V]S=6QT<^%G;VL`
M5F5N9.EG:_9N>78`1W5I;F5A`$)I<W-A=2U'=6EN96$`1W5Y86YA`$A434Q!
M<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('-O<B!U=&]L<_,@8V5L
M;.%JX70@=/9R]FQN:2X`2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA:FQA
M;F3S(&$@=.%B;.%Z870@=71O;'/S(&]S>FQO<.%T('3V<O9L;FDN`$A434Q!
M<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('3A8FSA>F%T('5T;VQS
M\R!S;W+A="!T]G+V;&YI+@!!($A45%`@9F5L:&%S>F[A;/-A>F]N;W/M=.%S
M(&YE;2!T86SA;&AA=/,N`$AA:71I`$AA<V@@86QG;W)I=&UU<P!+]F0`1F5J
M;.EC`$9E:FSI8P!(96%R9"T@Z7,@36-$;VYA;&0M<WII9V5T96L`17+U<R!Z
M:79A=&%R`&CI8F5R("A)4T\M.#@U.2TX+4DI`$UA9V%S<^%G`%-E9^UT<^EG
M`%-E9^UT<^EG(&$@<WIE<FME<WIT]2!H87-Z;N%L873A:&]Z`%-E9^UT<^EG
M`$;I;'1E:V4`17H@82!FX6IL(&5L96IE.@!N86=Y`$ME>F3U;&%P`%9A=&EK
MX6YVX7)O<P!+97ID]6QA<`!/='1H;VYI(&/M;0!3>F5MZ6QY97,@86QK]FYY
M=G3A<@!/='1H;VYI('1E;&5F;VX`2&]N9'5R87,`2&]N9VMO;F<`2&]R9&4`
M2&]R9&4O2V]L86(Z(&AI8N%S("5S(%A-3"!A9&%T('9A;B!A*'HI("5S(/QZ
M96YE=&)E;@!(;W)D92]+;VQA8CH@;FEN8W,@82AZ*2`E<R!O8FIE:W1U;6YA
M:R!M96=F96QE;/4@_'IE;F5T`$AO<F1E+TMO;&%B.B!N:6YC<R`E<R!T[7!U
M<_H@;V)J96MT=6T@82AZ*2`E<R#\>F5N971B96X`2&]R9&4O2V]L86(Z(%-I
M:V5R97-E;B!T]G+V;'3\:R!E>G0Z("5S("(E<R(`2&]R9&4O2V]L86(Z(&%Z
M(&EN=&5G<N%L\R!P<F]G<F%M:&]Z('-Z_&MSZ6=E<R!A("=D;VUX;6PG(%!(
M4"!B]7;M=.ES`$AO<F1E+TMO;&%B.B!N96T@<VEK97+\;'0@^FH@6$U,(&;A
M="!LZ71R96AO>FYI(&$H>BD@)7,@;V)J96MT=6UH;WH`2&]R9&4O2V]L86(Z
M($YE;2!S:6ME<OQL="!T]G+V;&YI("5S+70@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(&YE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@82!-24U%($E$+6KA="!A
M(&OV=F5T:V5Z]2!T[7!U<_H@;65L;.EK;&5T;F5K.B`E<P!(;W)D92]+;VQA
M8CH@3F5M('-I:V5R_&QT('-Z:6YK<F]N:7KA;&YI("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@82!K]G9E=&ME>O4@:_9Z]G,@=.%R
M=&5R_&QE="!S>FEN:W)O;FEZX6SA<V$Z("5S`$AO<F1E+TMO;&%B.B!I<VUE
M<F5T;&5N(&OV>O9S('3A<G1E<OQL970@(B5S(@!6[7IS>FEN=&5S('9O;F%L
M`%;M>G-Z:6YT97,@;6%R9_,`5NUZ<WII;G1E<SH`2&]G>2!J=71O='0@:61E
M/R`H2^ER:OQK(.UR:F$@;65G(2D`2.%N>2!O<WIL;W!O="!K[7;A;B#V<W-Z
M96]L=F%S>G1A;FD_`$CA;GD@;65Z]2`H;W-Z;&]P*2!V86X_`$CA;GD@<V]R
M="!K[7;A;B#V<W-Z96]L=F%S>G1A;FD_`%#A<F%T87)T86QO;0!0X7)A=&%R
M=&%L;VTZ(`!(=6UO<FES=.%K`$UA9WEA<F]R<WKA9P!!>B!)34%0(&QE=NEL
M;.%D82!LZ71R96AO>N%S82!N96T@<VEK97+\;'0Z("5S`$%Z($E-05`@;&5V
MZ6QLX61A('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E<P!!>B!)34%0(&QE=NEL
M;.%DX6AO>B!T87)T;WKS(&MV\W1A(&SI=')E:&]ZX7-A(&YE;2!S:6ME<OQL
M=#H@)7,`25`@8^UM`$%Z($E0(&/M;2!N96T@:&%TX7)O>FAA=/,@;65G+@!!
M>B!)4"!C[6T@;FEN8W,@82!M96=E;F=E9&5T="!#2412('1A<G1O;>%N>6)A
M;BX`5&EL=&]T="]M96=VX6QT;WIO='0@25`@8^UM+@!3;W(@8F5I;&QE<WIT
MZ7-E(&5F]FSI`$EZ;&%N9`!C<V%K(&EK;VYO:P`E<R!I:V]N:F%I`&EK;VYO
M:R#I<R!S>O9V96<`07H@87IO;F]S[73S:&]Z(';A;&%S>G1O='0@96QN979E
M>NES.@!(82!A(&UE9VIE;&5N[73I<R!N96T@;65G9F5L96SU+"`E<R!E9WD@
M^FH@86)L86MB86X@=F%L\R!M96=N>6ETX7-H;WHN`$AA(-9N($EN=&5R;F5T
M($5X<&QO<F5R="!H87-Z;N%L+"#I<R!N96T@:F5L96YN96L@;65G(&%Z(&EK
M;VYO:RP@86MK;W(@=N%L87-S>F$@97IT(&%Z(&]P8VGS="P@;65L;'EE;"!K
M:6MA<&-S;VQJ82!A(%!.1R!KZ7!E:R!T<F%N<WIP87)E;F-IX6KA="X`2&$@
M;.%T:F$@97IT(&$@<WKV=F5G970L(&1E(&$@:^EP970@;F5M+"!A:VMO<B!B
M]FYGZ7-Z]7!R;V=R86UJ82!N96T@:^EP97,@;65G:F5L96[M=&5N:2!A('-Z
M97)V97)R92!K_&QD96YD]2!KZ7!E="X`16SU>F5T97,@;NEZ970Z`$$@:^EP
M(%523"UJ90!!(&OI<"!54DPM:F4Z`$UE;'EI:R!G86SI<FGA8O-L('9A;B!A
M(&OI<`!+Z7`@96)B]6P@82!G86SI<FGA8O-L.@!+Z7`@9F5L=/9L=.ES90!+
MZ7!E:P!);7!O<G3A;.%S+"`E9"X@;.EPZ7,`07H@:6UP;W)TX6QT(&UE>O4Z
M("5S`$%Z(&EM<&]R=.%L="!M97KU:SH`4V]R(&)E:6QL97-Z=.ES92!E>F%L
MX0!(:6+A<R!P87)A;F-S<&%R86WI=&5R+@!.96T@;65G9F5L96SU(&$@8F5J
M96QE;G1K97KI<VD@;NEV(.ES+W9A9WD@82!J96QS>O,N`$YE;2!M96=F96QE
M;/4@82!F96QH87-Z;N%L\VD@;NEV('9A9WD@87H@86QT97)N873M=B!C[6TN
M(%!R\V+A;&IA(/IJ<F$@=F%G>2!F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A
M:&]Z+"!H82!T;W;A8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+@!"96ME
M>F3I<R!B96QJ96)B`$EN9&EA`$5G>65S(&9E;&AA<WINX6SS:P!);F1O;NEZ
M:6$`26YF;W)MX6-I\P!);F9O<FWA8VGS`$%Z(&EN9F]R;>%C:?,@;>%R(&YE
M;2#A;&P@<F5N9&5L:V5ZZ7-R92X`3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6X`
M2^EP(&)E:6QL97-Z=.ES90!4X6)LX7IA="!B96EL;&5S>G3I<V4`3&EN:R!L
MZ71R96AO>N%S80!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`$]S>FQO<"!B97-Z
M^G+A<V$@97IU=.%N`$]S>FQO<"!B97-Z^G+A<V$@97IE;.D`4V]R(&)E<WKZ
M<N%S82!E>F%LX0!3;W(@8F5S>OIRX7-A(&5F]FSI`$)E:V5Z9.ES(&)E:6QL
M97-Z=.ES92!E>G5TX6X`0F5K97IDZ7,@8F5I;&QE<WITZ7-E(&5Z96SI`$AO
M>GIU;FL@;.ET<F4@86QT97)N873M=B!S86)L;VYT`$%D:F]N(&UE9R!E9WD@
M96UA:6P@8^UM970L(&UE;'ER92!E;&O\;&1H973U(&%Z(-9N(/IJ(&IE;'-Z
M879A.@!#96QL82!B96EL;&5S>G3I<V4@97IU=.%N`$-E;&QA(&)E:6QL97-Z
M=.ES92!E>F5LZ0!/<WIL;W`@8F5S>OIRX7-A(&5Z=73A;@!/<WIL;W`@8F5S
M>OIRX7-A(&5Z96SI`$QE=F5L96L@8F5MX7-O;.%S80!"96ME>F3I<R!B96EL
M;&5S>G3I<V4@97IU=.%N`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5LZ0!3
M;W(@8F5S>OIRX7-A(&5Z86SA`%-O<B!B97-Z^G+A<V$@96;V;.D`061J82!M
M96<@82!K[7;A;G0@=N%L87-Z="!A(&)I>G1O;G/A9VD@:^ER9.ES<F4Z`$OI
M<"!B96EL;&5S>G3I<V4O;?-D;W/M=.%S80!,:6YK(&)E:6QL97-Z=.ES92]M
M\V1O<^UTX7-A`$$@<WKA;6SA:N%N(&YI;F-S(&5LZ6<@9F5D97IE="#\>F5N
M971E="!K_&QD96YI(&$@:_9R;&5VZ6QL:7-TX7)A+@!!('-ZX6ULX6KA;B!N
M:6YC<R!E;.EG(&9E9&5Z970N`$5GZ7-Z`$5GZ7-Z('-ZX6UO:R!L:7-TX6IA
M`$AI8N%S+V5L9F]G861H871A=&QA;B!51$@@*%5S97(@1&%T82!(96%D97(I
M+@!(:6+A<R]E;&9O9V%D:&%T871L86X@6DE0('3V;?9R[73I<P!(:6+A<R]E
M;&9O9V%D:&%T871L86X@86QK86QM87KA<RX`2&EBX7,O96QF;V=A9&AA=&%T
M;&%N(&)A=&-H(&%Z;VYO<^UT\RX`02!K_&QD]G1T(&%D870@:&EBX7,O96QF
M;V=A9&AA=&%T;&%N+@!(:6+A<R]E;&9O9V%D:&%T871L86X@8^UM>NES+@!(
M:6+A<R]E;&9O9V%D:&%T871L86X@9N%J;"!F;W)MX71U;0!(:6+A<R]E;&9O
M9V%D:&%T871L86X@;&EC96YS>FMU;&-S+@!(:6+A<R]E;&9O9V%D:&%T871L
M86X@=N%R;W,N`$AI8N%S+V5L9F]G861H871A=&QA;B#\>F5N971T[7!U<RX`
M2&EBX7,O96QF;V=A9&AA=&%T;&%N('9A9WD@:&GA;GEZ\R!P<F]G<F%M;WKA
M<VEF96S\;&5T+6%Z;VYO<^UT\RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N('!A
M<F%MZ71E<F5K+@!(:6+A<R!A>B!O8FIE:W1U;2!E;.ERZ7-I(&IO9V]S=6QT
M<^%G82X`2&EBX7,O96QF;V=A9&AA=&%T;&%N('!A<G1N97)A>F]N;W/M=/,N
M`$AI8N%S+V5L9F]G861H871A=&QA;B!T97)MZ6MK\V0N`$AI8N%S+V5L9F]G
M861H871A=&QA;B!P<F]T;VMO;&PN`$AI8N%S+V5L9F]G861H871A=&QA;B!C
M[6UZ971T.B`B)7,B`$AI8N%S+V5L9F]G861H871A=&QA;B!M96=O<WIT;W1T
M(&]B:F5K='5M`$AI8N%S+V5L9F]G861H871A=&QA;B!F96QA9/-I(&/M;2X`
M2&EBX7,O96QF;V=A9&AA=&%T;&%N('5N:6-O9&4@861A="X`3GEI;';A;G1A
M<G3A<P!!(&MI:F5L]FSI<R!I;G9E<G3A;.%S80!)<N%N:2!)<WILX6T@2_9Z
M=.%R<V%SX6<`27)A:P#-<F]R<WKA9P!-86XM<WII9V5T`%-Z\W)VX6YY;W,@
M>FEV871A<F]K`$EZ<F%E;`!!('1A;OIS[71VX6YY(&MI863S:F$`9/5L=`!/
M;&%S>F]R<WKA9P!*86UA:6-A`&IA;G7A<@!*87#A;@!J87#A;B`H25-/+3(P
M,C(M2E`I`$IE<G-E>0!*;W)DX6YI80!J^FQI=7,`:OIN:75S`%-O<FMI>N%R
MX7,`:_9ZZ7!R92!R96YD97KI<P!S;W)K:7KA<N%S(&UI;F1KZ70@;VQD86QR
M80!S;W)K:7KA<N%S(&)A;')A`'-O<FMI>N%RX7,@:F]B8G)A`$MA>F%H<WIT
MX6X`5&%R='-U:R!M96<@87H@97)E9&5T:70_`$ME;GEA`$$@:V5R8F5R;W,@
M<WIE<G9E<B!E;'5T87/M=&]T=&$@82!F96QH87-Z;N%L\V%Z;VYO<^UTX7-T
M+@!+97ID]2!K97)N96QF96IL97-Z=/5K`$MU;&-S(&SI=')E:&]ZX7-A`$$@
M:W5L8W,@;&5N>6]M871A`$MU;&-S:&]S<WKZ<^%G`$MU;&-S('3M<'5S`$$@
M:W5L8W,@:&%S>F[A;&%T80!!(&MU;&-S(&WA<B!LZ71E>FEK(&$@;GEI;';A
M;F]S(&MU;&-S<WIE<G9E<F5N+@!'>65R96ME:P!+:7)I8F%T:0!+;W)E86D@
M3NEP:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<`2V]R96%I($OV>G3A<G-A
M<^%G`&MO<F5A:2`H155#+4M2*0!+=79A:70`2VER9VEZ:7-Z=.%N`%]497)V
M97KI<P!.>65L=@!,86]S>FD@3NEP:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%S
MX6<`=71O;'/S(&;I;`!!>B!U=&]L<_,@:F5L<WKS=N%L=.%S`'5T;VQS\R!N
M96=Y960`571O;'/S(';A;'1O>G1A=.%S.@!5=&]L<_,@8F5J96QE;G1K97KI
M<SH@)7,`571O;'/S(&)E:F5L96YT:V5ZZ7,Z("5S+"`E<R!C[6UR]6P`571O
M;'/S(&)E:F5L96YT:V5ZZ7,Z(&WI9R!S;VAA(&YE;2!V;VQT`$QE='1O<G-Z
MX6<`2F]G`$5L:&5L>65ZZ7,`2&%G>6IA(/QR97-E;BP@:&$@;F5M(&%K87(@
M:V5R971E=`!,:6)A;F]N`&)A;`!"86P@;VQD86QI(&9E:FSI8P!"86P@;VQD
M86QI(.ER=.EK96L`3&5S;W1H;P!3>FEN=`!,:6+I<FEA`$SM8FEA:2!!<F%B
M(%-Z;V-I86QI<W1A($YA9WD@3NEP:2!+]GKV<W/I9P!,:65C:'1E;G-T96EN
M`$=Y96YG92!S>FETX6SS(&5S]0!'>65N9V4@97/U`$3I;&5L]71T(&=Y96YG
M92!E<_4`1.EL=73A;B]E<W1E(&=Y96YG92!E<_4`1WEE;F=E('KA<&]R`$=Y
M96YG92!Z:79A=&%R`$=Y96YG92!H879A>N%S`$=Y96YG92!H\WKA<&]R`$QI
M;FL`02!L:6YK(&ED92!M=71A=#H`365G:F5L96[M=.ES:V]R(&UU=&%S<V]N
M(&5G>2!L:6YK(&$@;&5VZ6QC[6UR]6P@82!L97;I;.UR\R!A8FQA:VAO>@!,
M:6YK96L`3&EN=7@`3&ES=.%ZX7,@+2!A(&9E;&AA<WINX6SS(&SA=&IA(&$@
M;6%P<.%T`$%Z(&%D871BX7II<V]K(&QI<W3A:F$`07IO:VYA:R!A('3I;>%K
M;F%K(&$@;&ES=.%J82!A;6ER]6P@<V5G[71SZ6<@:V%P:&%T\P!!>B!A9&%T
M=.%B;.%K(&QI<W3A:F$`3&ES=&$@87)C:.UV=6T`3&ES=&$@<V5G[71SZ6=K
MZ7+I<P!,:7-T82!A>F]N;W/M=/,`3&ES=&$@='5L86ID;VYO<P!,:7-T82!L
M97;I;.URX7,`3&ES=&$@9F5L:7)A=&MO>N%S("AS=6)S8W)I8F4I`$QI<W1A
M(&QE:7)A=&MO>N%S("AU;G-U8G-C<FEB92D`02!F96QH87-Z;N%L\VMA<&-S
M;VQA=&]K(&MI;&ES=.%ZX7-A(&YE;2!S:6ME<OQL=#H@)7,`02!F96QH87-Z
M;N%L\VL@:VEL:7-TX7KA<V$@;F5M('-I:V5R_&QT.B`E<P!!(&9E;&AA<WIN
MX6SS:R!K:6QI<W3A>N%S82!T:6QT=F$@=F%N+@!)<F]D86QO;0!,:71VX6YI
M80!,973V;'3I<RXN+@!(96QY:2!I9/4Z(`!.>65L=BP@9.%T=6TL(&ED]0!(
M96QY`$)E:F5L96YT:V5ZZ7,`07H@96SU>O4@861A='-Z:6YK<F]N:7KA8VGS
M(&YA<&SSX6QL;VWA;GEA`$MI:F5L96YT:V5ZZ7,`0F5J96QE;G1K97KI<P!"
M96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S(&9E;&%D871O:P!!(&)E:F5L
M96YT:V5ZZ7,@;F5M('-I:V5R_&QT+"!M97)T(')O<W-Z(&9E;&AA<WINX6SS
M;F5V970@=F%G>2!J96QS>O-T(&%D;W1T(&UE9RX`02!B96IE;&5N=&ME>NES
M(&YE;2!S:6ME<OQL="X`2&]S<WKZ('-Z]G9E9P!3>F5R96QE;0!A;&%C<V]N
M>0!G]G+V9R!K:7-B973[:P!L871I;B!K:7-B973[:P!K:7-B973[<R!R\VUA
M:2!S>N%M;VL`3'5X96UB=7)G`$U-`$YA<&D@_'IE;F5T96L`07H@35,M5$Y%
M1B!M96QLZ6ML971B96X@;FEN8W,@861A="X`W%I%3D54`$UA:V'S`$UA:V5D
M\VYI80!-861A9V%S>FOA<@!687+A>G-L870`3&5V96QE>NES`$5M86EL(&1O
M;6%I;B!K97IE;.ES`$QI;FL@:^ES>NUTZ7-E`$UA;&%W:0!-86QA:GII80!-
M86QD[78M<WII9V5T96L`36%L:0!-X6QT80!!9&%T86ET(&MA=&5G\W)IX6MB
M82!S;W)O;&AA=&IA+B!%>F5K(&ET="!D969I;FGA;&AA=/-K+"!M\V1O<^UT
M:&%T\VLL('1O=N%B8N$@<WKM;F5K(')E;F1E;&AE=/5K(&AO>GKA:G5K+@!-
M87`R-"!TZ7)KZ7``36%P475E<W0@=.ER:^EP`$$@:&]Z>N%R96YD96SI<V5K
M970@96QM96YT971T_&LN`&WA<F-I=7,`36%R9_,`07H@3VQV87-O='0O3VQV
M87-A=&QA;B!J96QZ971E:R!H87-Z;N%L871A`$WA<R!J96QZ971E:R`H<&PN
M($9O;G1O<R]-96=VX6QA<WIO;'0I(&AA<WINX6QA=&$`36%R<VAA;&PM<WII
M9V5T96L`36%R=&EN:7%U90!%9WEMX7-N86L@;65G9F5L96SU(&UE>O5K`$UA
M=7)I=.%N:6$`36%U<FET:75S`$UA>&EMX6QI<R!R96YD96QK97KI<W)E(.%L
M;/,@<WKA;6QA]G-S>F5G+@!!>B#\>F5N970@=/IL('-O:R!RZ7-Z8O5L(.%L
M;"X`07H@96QM^FQT(#(T(/-R82!M87AI;>%L:7,@:/5MZ7)SZ6ML971E.B``
M07H@96QM^FQT(#8@\W)A(&UA>&EMX6QI<R!H]6WI<G/I:VQE=&4Z(`!!>B#V
M<W-Z96?U;VQD86P@8FQO:VMJ86EN86L@;6%X:6WA;&ES('-ZX6UA`$UA>&EM
MX6QI<R!H;W-S>@!MX6IU<P!-87EO='1E`$]R=F]S='5D;VWA;GD`5&%G;VL`
M02!M96[\(&UE9VIE;&5NZ7-E.@!#96QLX6L@96=Y8F5O;'9A<WITX7-A`-QZ
M96YE=`!!(&1I9VETX6QI<V%N(&%LX>UR="#\>F5N970@:&ET96QE<RP@9&4@
M87H@86SA[7+S('1A;OIS[71VX6YYX70@;F5M('-I:V5R_&QT(&5L;&5N]7)I
M>FYI+@!,96KA<G0@87H@_'IE;F5T(.ER=NEN>65S<^EG92X`07H@_'IE;F5T
M('3M<'5S80!-971A<B!I9/5JX7+A<VIE;&5N=.ES`$$@365T87(@8FQO:VL@
M;F5M(.%L;"!R96YD96QK97KI<W)E+@!!($UE=&%R(&)L;VMK(&YE;2#A;&P@
M<F5N9&5L:V5ZZ7-R92X@02!RZ7-Z;&5T96L@82!R96YD<WIE<F=A>F1A('-Z
MX6WA<F$@:^ES>OQL]2!N87!L\V;A:FQB82!K97+\;'1E:RX`02!-971A<D1"
M(&YE;2#I<FAE=/4@96PN`$WS9'-Z97(`02AZ*2`B)7,B(&WS9'-Z97(@9&5F
M:6YIX6QA=&QA;@!!(&WS9'-Z97(@9&5F:6YIX6QA=&QA;BX@02!M96=H[79O
M='0@;?-D<WIE<CH@)7,`365T<FEK=7,`365X:6OS`$UI:W)O;NEZ:6%I(%-Z
M]G9E='/I9VD@P6QL86UO:P!K]GKI<`!-24U%('3M<'5S`$%Z(&5L;?IL="`R
M-"#S<F$@;&5G86QA8W-O;GEA8F(@:/5MZ7)SZ6ML971E.B``07H@96QM^FQT
M(#8@\W)A(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T93H@`$WI9R!N96T@
M=&5L="!E;"!A(&UI;FEMX6QI<R!I9/4@82!J96QS>O,@;65G=N%L=&]Z=&%T
MX7/A:&]Z`%3\:W+V>NES("AJ;V)B+V)A;"D`5F5G>65S`$AIX6YY>FEK(&$@
M2%144%]297%U97-T(%!%05(@8W-O;6%G+@!+;VYF:6=U<N%C:?,@<WK\:W/I
M9V5S+B!%>G0@;6]S="!K96QL(&SI=')E:&]Z;FEA+"!H82!H87-Z;N%L;FD@
M86MA<FIA(&%Z(&%L:V%L;6%ZX7-T+@!(:>%N>7II:R!A>B#\>F5N970@87IO
M;F]S[73S:F$N`$AIX6YY>FEK(&$@36%I;"!014%2(&-S;VUA9RX`2&GA;GEZ
M:6L@82!F96QH87-Z;N%L\VMA<&-S;VQA="!A>F]N;W/M=/-J82`H<V5S<VEO
M;B!)1"DN`$CI`$QE=F5L97KI<R!M;V)I;'1E;&5F;VYR\VP`2_9Z97!E<P!!
M(&WS9&]S[73A<R!DX71U;6$`07H@55),(&WS9&]S[73A<V$`36]D=6QU<P!-
M;VQD;W9A:2!+]GITX7)S87/A9P!-;VYA8V\`36]N9_-L:6$`2/-N87`@Z7,@
MZ78`:&%V;VYT80!-;VYT<V5R<F%T`$AO;&1FX7II<V]K`$$@)60N('-O<F)A
M;B!T]F)B(&UE>O4@=F]L="P@;6EN="!A(';A<G0@)60N`$UA<F]K:_,`5/9B
M8FYY:7)E(&1E<OQL=`!4]F)B;GEI<F4@8F]R=6QT`%3V8F)N>6ER92!N87!O
M<P!V:6=Y_&L@;&4`=FEG>?QK(&)A;')A`'9I9WG\:R!J;V)B<F$`=FEG>?QK
M(&;V;`!V:6=Y_&L@;&4`=FEG>?QK(&;V;`!-;WIA;6)I:P!4]F)B<WII;G3[
M(&QE9_9R9/QL]2!L:7-TX6L`375L=&EM87`@3F%G>2U"<FET86YN:6$@=.ER
M:^EP`%3V8F)S>O9R]G,@=N%L87-Z=.%S`$)E:F5L96YT:V5ZZ7-I(&)EX6QL
M[73A<V]K`$)E:F5L96YT:V5ZZ7-I(&%D871A:6T`4V%JX70@]G-S>F5G>O4@
M;VQD86QA;0!386KA="#V<W-Z96=Z]2!O;&1A;&%M('1E<G9E>NES90!-:6%N
M;6%R`$Y%32P@;F5M(&5G>65Z96T@8F5L92X`3NEV`$YA;>UB:6$`3F%U<G4`
M3F5PX6P`2&]L;&%N9&EA`$AO;&QA;F0@06YT:6QLX6L`3F5T<V-A<&4@8N%Z
M:7,M55),`$YE='-C87!E('1A;OIS[71VX6YY:VEA9.%S:6IO9RA#02DM=FES
M<WIA=F]NX7-I(%523`!.971S8V%P92!T86[Z<^UT=N%N>69E;&AA<WINX6SA
M<VD@:7+A;GEE;'8@55),`$YE='-C87!E('1A;OIS[71VX6YY;65G^FKM=.%S
M:2!54DP`3F5T<V-A<&4@=&%N^G/M=';A;GEV:7-S>F%V;V[A<VD@55),`$YE
M='-C87!E(%-33"!S>F5R=F5R;NEV`$YE='-C87!E('1A;OIS[71VX6YY(&UE
M9VIE9WEZZ7,`3F5T<V-A<&4@=&%N^G/M=';A;GET[7!U<P!(X6SS>F%T`'-O
M:&$`VFHM2V%L963S;FEA`-IJ(&MA=&5G\W)I80#::B!L97;I;"`E<R!C[6UR
M90#Z:FAO;&0`VFH@9F5L:&%S>F[A;/-NZ78@*&]P8VEO;N%L:7,I`-IJ+5KI
M;&%N9`#::B!J96QS>O,`07H@^FH@:F5L<WKS(.ER=NEN>65S<^EG92!E:VMO
M<B!JX7(@;&4Z("5X+@!!(&UE9V%D;W1T(/IJ(&IE;'-Z879A:R!N96T@96=Y
M97IN96LN`-IJ(&%B;&%K("C\<F5S*0!([7)E:P!([7)C<V]P;W)T;VL`2_9V
M971K97KU`$OV=F5T:V5Z]2`T(&;A>FES`$OV=F5T:V5Z]2!O<&-I\VL`2_9V
M971K97KU/@!.:6-A<F%G=6$`3FEG97(`3FEGZ7)I80#I:G-Z86MA`$YI=64`
M3F5M`$YI;F-S(')E;F1E;&ME>NES<F4@X6QL\R!K;VYF:6=U<N%C:?,L(&%M
M:6AE>B!KZ7!E<W0@82!K_&SV;F)SZ6=E:V5T(&UE9R!L96AE=&YE(&UU=&%T
M;FDN`$YI;F-S(&QE:&5T]7/I9R!)4T\@X6QL;VWA;GEO:R!LZ71R96AO>N%S
MX7)A+@!(:>%N>7II:R!A(&OV=&5G96QT(&9E;&1O;&=O>N%S:&]Z('-Z_&MS
MZ6=E<R!M:6YT82`H8F%T8V@@=&5M<&QA=&4I+@!!(&OM=N%N="!H96QY96X@
M;FEN8W,@8FQO:VL`07H@34-!3"!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@
M;FEN8W,@;65G861V82!A(&YA<'3A<B!N979E+@!.:6YC<R!VX6QT;WKA<RX`
M16AH97H@82!J;V=O<W5L='/A9VAO>B!N96T@:&]Z:&%T\R!LZ71R92!J;V=O
M<W5L='/A9VD@86QC<V]P;W)T+@!(:>%N>6]Z;F%K(&$@:V]N9FEG=7+A8VGS
M<R!A9&%T;VL@)7,M:&5Z+@!!>B!&5%`@5D93(&YI;F-S(&MO;F9I9W5RX6QV
M82X`07H@4U%,(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N`$%Z(%-13"U&:6QE
M(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N`$%Z(-9N('-ZX6ULX6KA;B!E;&9O
M9WEO='0@82!R96YD96QK97KI<W)E(.%L;/,@]G-S>F5G+@!.:6YC<R!C[6UZ
MZ7,N`$$@<WIE<G9E<G)E(&YE;2!T]FQT]63V='0@9F5L('-E;6UI;'EE;B#A
M;&QO;>%N>0!!>B!I:V]N;VL@;F5M('1A;.%L:&%T\VLN`$YI;F-S(&UE9V%D
M=F$@82!H96QY+@!.:6YC<R!M96=A9'9A(&$@:&5L>2X`07H@_'IE;F5T(/QR
M97,N`$YI;F-S(&UE9V%D=F$@82!NZ78N`$YI;F-S(&UE9V%D=F$@82!S>N%M
M+@!.92!L96=Y96X@;65G8F]T<N%N:V]Z=&%T\R!I9.EZ970`3FEN8W,@:F5L
M<WKS(&UE9V%D=F$@82!(5%10(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M
M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V82!A>B!)34%0(&%L87#Z(&9E
M;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V
M82!A($ME<F)E<F]S(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z
M+@!.:6YC<R!J96QS>O,@;65G861V82!A($QO9VEN(&%L87#Z(&9E;&AA<WIN
MX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V82!A(%!!
M4U-71"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@
M:F5L<WKS(&UE9V%D=F$@87H@4TU"(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N
M;W/M=.%S:&]Z+@!.:6YC<R!M96=A9'9A(&%Z($]P96Y34TP@<')O9W)A;2!E
M;.ERZ7-I(/IT=F]N86QA+B!!>B!/<&5N4U-,('!R;V=R86T@<WK\:W/I9V5S
M(&$@4$M#4R`Q,B!A9&%T;VL@:V5Z96SI<^EH97HN`$YI;F-S(/IJ(&)E:F5L
M96YT:V5ZZ7-I(&EGZ6YY+@!.:6YC<R!K=O-T82!B9>%L;.UT=F$N`$YE(&QE
M9WEE;F5K('9O;F%L86L@<V5H;VPN`$YI;F-S(&1E9FEN:>%L=F$@96QVX6QA
M<WIT\R!K87)A:W1E<BX`3F4@;&5G>65N(&ME<F5T`$YI;F-S(&EL>65N(&;A
M:FP`3FEN8W,@:61E:6=L96YE<R#A;&QO;>%N>6]K('3A<F]LX7/A<F$@<WIO
M;&?A;/,@86QK]FYY=G3A<BX`2&GA;GEZ:6L@82!F96QH87-Z;N%L\V[I=B#I
M<R]V86=Y(&$@:F5L<WKS+@!!('9I<W-Z86MA<&]T="!A9&%T;VL@;F5M(.ER
M=NEN>65S(%A-3"!A9&%T;VL`3FEN8W,@861A=`!.:6YC<R!MZ6<@:V]N9FEG
M=7+A8VGS+"!G96YE<N%L:F]N(&5G>65T+@!.:6YC<R!MZ6<@:V]N9FEG=7+A
M8VGS:F$L(&=E;F5RX6QJ;VX@96=Y970N`&YI;F-S`&YI;F-S(&UE9V%D=F$@
M*&QE9WEE;B!A;&%PZ7)T96QM97IE='0I`&YO<F1I:W5S("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:RUS>FEG970`R7-Z86MI(&;I;'1E:V4`R7-Z86MI+4UA<FEA
M;F$M<WII9V5T96L`3F]R=NEG:6$`3F5M(&OI<_5B8@!.96T@:V]RX6)B86X`
M3F5M(&%L:_9N>79TX7(`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI
M;F-S(&UE9W9A;/-S[71V82X`3FEN8W,@8F7A;&SM='9A`$YE;2!TX6UO9V%T
M;W1T+@!&96QJ96=Y>NES96L`3FEN8W,@8O9N9^ES>FAE=/4@861A="P@=.ER
M:F5N('9I<W-Z82X`;F]V96UB97(`4WKA;0!+87)A:W1E<F5K('-ZX6UA`$]S
M>FQO<&]K('-ZX6UA`%-O<F]K('-ZX6UA`$$@:_9R;&5VZ6QL:7-T82!M\V1O
M<^UTX7/A:&]Z(&YE;2!A9&]T="!M96<@<WKA;6]K870N`$]+`$]B:F5K='5M
M`$%Z(&]B:F5K='5M(&SI=')E:&]Z\VIA`$]K=.%L:7,@<WKA;0!O:W3S8F5R
M`%-Z^W+I<P!(:79A=&%L+VUU;FMA:&5L>0!!('+I9VD@Z7,@87H@^FH@:F5L
M<WKS;F%K(&O\;/9N8O9Z;FEE(&ME;&PN`$$@<NEG:2!J96QS>O,`02!RZ6=I
M(&IE;'-Z\R!N96T@;65G9F5L96SU+@!/;>%N`$-S86L@87H@24U!4"!S>F5R
M=F5R96L@=.%M;V=A=&KA:R!A(&UA<'#A:R!M96=O<WITX7/A="X`0W-A:R!M
M96=B;W1RX6YK;WIT873S(&EDZ7IE="!L96=Y96X`0W-A:R!E9WD@96UA:6P@
M8^UM(&%D:&%T\R!M96<N`$-S86L@82!T=6QA:F1O;F]S('9A9WD@82!R96YD
M<WIE<F=A>F1A(';A;'1O>G1A=&AA=&IA(&UE9R!E9WD@:_9Z]G,@=.%R=&5R
M_&QE="!T=6QA:F1O;F]SX70@=F%G>2!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET
M`$YY:7-S=6L@;65G(/IJ(&%B;&%K8F%N`$]P96Y34TP@:&EB83H@3F5M('-I
M:V5R_&QT(&MI;GEE<FYI(&%Z(&%D871O:V%T(&%Z(&%LX>UR="!3+TU)344@
M<NES>F+U;`!.>6ES<W5K(&UE9R!E>G0@82!C[6UE="!E9WD@^FH@86)L86MB
M86X`3W!E<N%C:?-S(')E;F1S>F5R`$]P8VGS:P`E<R!B9>%L;.UTX7-A:0!3
M;W)S>N%M;W,@9F5L<V]R;VSA<P!3>F5R=F5Z970`4WIE<G9E>F5T:2!E9WES
MZ6<`375N:V%S>F5R=F5ZZ7,`07H@86QK86QM87KA<R!E<F5D971I('-A8FQO
M;FIA`"5S(&5R961E=&D@<V%B;&]N:F%I.@!%9WGI8@!%9WGI8B!I;F9O<FWA
M8VGS`$$@='5L86ID;VYO<R!J;V=O<W5L='/A9V%I`$$@4$%-(&9E;&AA<WIN
MX6SS87IO;F]S[73A<R!N96T@X6QL(')E;F1E;&ME>NES<F4N`%!%05(Z.DUA
M:6P@86QR96YD<WIE<@!01U`@9&EG:73A;&ES(&%LX>URX7,`4$=0+79E;"!T
M:71K;W/M=&]T="!A9&%T`%!'4"!N>6EL=N%N;W,@:W5L8W,`4$=0+79E;"!A
M;.'M<G0O=&ET:V]S[71O='0@861A=`!02%`@:_-D`$3I;'5TX6XO97-T92!G
M>65N9V4@97/U`$3I;'5TX6X@97/U`$3I;'5TX6XO97-T92!ZX7!O<F]K`$3I
M;'5TX6XO97-T92!H879A>N%S`$3I;'5TX6XO97-T92!H\WKA<&]R;VL`1.EL
M=73A;B!N87!S_'3I<P!$Z6QU=.%N+V5S=&4@>FEV871A<F]K`$AIX6YY>FEK
M(&$@4$]325@@8O5V[73I<P!B96QS]2!M87)G\P!086MI<WITX6X`4&%L874`
M4&%L97-Z=&EN(%1E<OQL970@*&UE9W-ZX6QL="D`4&%N86UA`%#A<'5A(-IJ
M+4=U:6YE80!087)A9W5A>0!-Z7)SZ6ME;'1E;B!B;W)U;'0`2F5L<WKS`$$@
M:F5L<WKS="!S:6ME<F5S96X@;65G=N%L=&]Z=&%T='5K+@!.96T@;65G9F5L
M96SU(&IE;'-Z\P!!(%)!1$E54R!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@
M:F5L<WKS('-Z_&MSZ6=E<RX`2F5L<WKS(&UE9V5R]7/M=.ES<V5L`$IE;'-Z
M\SH`2F5L<WKS.B``02!J96QS>F%V86MN86L@96=Y97IN:?QK(&ME;&PN`$)E
M:6QL97-Z=.ES`$)E:6QL97-Z=.%S(&$@=N%G\V%S>G1A;'+S;`#:='9O;F%L
M`-IJ(&9E;&AA<WINX6SS;F%K(&)E:F5L96YT:V5Z971T96LZ`$5M8F5R96L`
M<WKA>F%LZ6L`2V%R8F%N=&%R=.%S:2!F96QA9&%T;VL@=NEG<F5H86ITX7-A
M`$)E:F5L96YT:V5ZZ7-K;W(@:&%J='-U:R!VZ6=R92!A(&MA<F)A;G1A<G3A
M<VD@9F5L861A=&]K870_`$IO9V]S=6QT<^%G`$$H>BD@(B5S(B!J;V=O<W5L
M='/A9V]T(&YE;2!T]G+V;'3\:RX`UFYN96L@;FEN8W,@96AH97H@96QE9V5N
M9/4@:F]G;W-U;'1SX6=A`$IO9V]S=6QT<^%G;VL`2F]G;W-U;'1SX6<@861M
M:6YI<WIT<N%C:?,`4WIE;>EL>65S(&%D871O:P!097)U`,%L;&%T:V5D=F5N
M8V5K`$;\;/9P+7-Z:6=E=&5K`%1E;&5F;VX`1NEN>6OI<&=A;.ER:6$`4&ET
M8V%I<FX`<&EX96P`2_9Z:&5L>65K`$MA='1I;G1S;VX@=F%L86UE;'EI:R!C
M96QLX7)A`$)I>G1O<V%N('3V<O9L;FD@86MA<FIA(&5Z="!A>B!E;&5M970Z
M`$OI<F5M(&5R]7/M='-E(&UE9RP@:&]G>2!V86SS8F%N('3V<O9L;FD@:^UV
MX6YJ82!E>G0@87H@96QE;65T+@!+Z7)E;2!A9&IO;B!M96<@96=Y(&CS;F%P
M;W0@Z7,@96=Y(.EV970N`$OI<F5M(&%D:F$@;65G(&%Z(/IJ(&MA=&5G\W)I
M82!N97;I=#H`2^ER96T@=F%L\W,@25`@8^UM970@861J;VX@;65G+@!+Z7)E
M;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE9RP@96QL96[U<FEZ>F4@82!H\VYA
M<"!N87!J86ET+@!+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE9RX`2^ER
M96T@<O9V:61E;B#M<FIA(&QE(&$@<')O8FSI;6$@;.EN>65GZ70N`$OI<F5M
M(&%D:F$@;65G(&$@8F5J96QE;G1K97KI<VD@;F5VZ70@Z7,@:F5L<WIA=N%T
M`$OI<F5M(&]L=F%S<V$@96P@82!K]G9E=&ME>O4@<WKV=F5G970N($$@<F5N
M9'-Z97(@:&%S>F[A;&%TX6YA:R!F96QTZ71E;&5I="!E;"!+14Q,(&9O9V%D
M;FEA+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R:6$@;F5VZ70Z`$QE
M;F=Y96QO<G-ZX6<`4&]L:71I:V$`4WIA=F%ZX7-O:P!0;W)T=6?A;&EA`$$@
M:^EP(&5L:&5L>65ZZ7-E`$$@=.%B;.%Z870@96QH96QY97KI<V4`2_9Z=F5T
M;&5N(&QE=NEL:_QL9.ES(&5B8F4@82!M87!PX6)A("A)34%0(&YE;2!M:6YD
M:6<@=F5S>FD@9FEG>65L96UB92D`07H@96QM^FQT("5S(/-R82!C<V%P863I
M:VUE;FYY:7/I9V4Z(`!#<V%P863I:SQB<B`O/G9A;/-S>NUN^W/I9P!0<F5F
M<U]L9&%P.B!N96T@=&%LX6QH873S(&$@<WK\:W/I9V5S($Q$05`@:VET97)J
M97-Z=.ES+@!0<F5F<U]S97-S:6]N.B!N96T@=&%LX6QH873S(&$@<WK\:W/I
M9V5S("AS97-S:6]N*2!K:71E<FIE<WITZ7,N`$SI9VYY;VWA<P!!('1E;F=E
M<G-Z:6YT;F5K(&UE9V9E;&5L]2!LZ6=N>6]MX7,Z(`!,Z6=N>6]MX7,Z(`!%
M;/5Z971E<R!M96=T96MI;G3I<P!!(&OI<"!E;/5Z971E<R!M96=T96MI;G3I
M<V4@^FH@86)L86MB86X`16SU>O4@;W!C:?-K`$$@9&]K=6UE;G1U;2!K:6YY
M;VUT873A<V$`5&ET:V]S(&MU;&-S`$AI8F%B96IE;&5N=.ES`$$@:&EB82!L
M9>URX7-A`%!R;VIE:W0@:V5Z96SI<P!!('!R;VUP="!S>O9V96=E`$YY:6QV
MX6YO<R!K=6QC<P!.>6EL=N%N;W,@:W5L8W/Z(&%L9V]R:71M=7,`3GEI;';A
M;F]S(&MU;&-S(&EN9F]R;>%C:?,`02!N>6EL=N%N;W,O=&ET:V]S(&MU;&-S
M<.%R="!N96T@<VEK97+\;'0@;.ET<F5H;WIN:2X`4'5E<G1O(%)I8V\`02!L
M979E;&5K(';I9VQE9V5S('3V<FSI<V4`2V%T87(`2V5R97/U+W!A<F%N8W,@
M<W1R:6YG`$MV\W1A`%)302!N>6EL=N%N;W,@:W5L8W,@*"5D(&)I=&5S*0!2
MX61I\V=O;6)O<R!K:7;A;&%S>G3A<P!%<_4`17/U(&3I;&5L]71T`$5S]2!D
MZ6QU=.%N+V5S=&4`6N%P;W(`17/U(.ES(&AA=F%ZX7,`2&%V87-E<_4`5NEL
M971L96X@:63I>F5T`$%RX6YY`$]L=F%SX7,`3&5V96QE:R!O;'9A<^%S80!4
MZ6YY;&5G('3V<O9L:OQK("5S(&9E;&AA<WINX6SS=#\@17H@82!VX6QT;WIT
M873A<R!N96T@9F]R9.UT:&%T\R!V:7-S>F$N`%3I;GEL96<@=/9R]FQJ_&L@
M)7,@9F5L:&%S>F[A;/,@861A=&%I=#\@17H@82!VX6QT;WIT873A<R!N96T@
M9F]R9.UT:&%T\R!V:7-S>F$N`-IJ<F$@=NEG<F5H86IT:F$@87H@=71O;'/S
M(';A;'1O>G1A=.%S=`!&<FES<^UTZ7,`02!M96[\(&1I;F%M:6MU<R!E;&5M
M96EN96L@9G)I<W/M=.ES:2!G>6%K;W)I<^%G83H`07H@]G-S>F5G>O5O;&1A
M;"!F<FES<^UTZ7/I;F5K(&=Y86MO<FESX6=A.@!/8FIE:W1U;2!B]FYGZ7-Z
M]0!&<FES<^UTZ7,`365G:F5G>7KI<V5K`%3A=F]L:2!S>F5R=F5R96L`02!T
MX79O;&D@55),("AP;"X@:'1T<#HO+W=W=RYV86QA;6DN:'4O;65G=F%L86UI
M*3H`5/9R;.ES`$)L;VMK('3V<FSI<V4`3W-Z;&]P('3V<FSI<V4`02!F;W)M
M871TX6SA<R!T]G)LZ7-E`$$@<.%R('3V<FSI<V4`5/9R]FQJ_&L@87H@96QM
M96YT971T('!R;V=R86UO="!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N
M>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%RX6+S;"X`5F5G>?QK(&MI(`!6
M96=Y_&L@:VD@97IT(&$@<NES>G0@82!D;VMU;65N='5M8O-L`$$@9F5L:&%S
M>F[A;/,@=/9R;.ES90`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E`$$@:^ERZ7,@
M;F5M('1E;&IE<^UT:&5T]2X@02!K87!O='0@:&EB86OS9#H@`$$@:V5R97-E
M='0@<WIO;&?A;'1A=.%S(&YE;2!T86SA;&AA=/,N`$$@:_9T96QE>O5E;B!M
M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P96P@)7,@:V]N9FEG=7+A8VGS:N%B
M86XN`$$@:_9T96QE>O5E;B!M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P96P@
M82!61E,@:V]N9FEG=7+A8VGS:N%B86XN`$$@:_9T96QE>O5E;B!M96=A9&%N
M9/,@(B5S(B!N96T@<WIE<F5P96P@82!K;VYF:6=U<N%C:?-B86XN`%-Z_&MS
MZ6=E<R!M97KU`%)E<V5T`$$@:F5L<WKS(.%TX6QL[73A<V$`07H@UFX@:F5L
M<WIA=N%N86L@X73A;&SM=.%S80!!>B!U=&]L<_,@:V5R97/I<R!V:7-S>F'A
M;&SM=.%S80!%<F5D;>EN>0!6:7-S>F$@87H@;W!C:?-K:&]Z`$%Z(/IJ(&IE
M;'-Z\W0@[7)J82!B92!I<VWI=`!2Z75N:6]N`,%L;.UT<W5K('9I<W-Z82!A
M(&MO;F9I9W5RX6-I\W0`4FEC:"!497AT($5D:71O<B!O<&-I\VL`5&%LX6SS
M<R!KZ7)DZ7-E:P!J;V)B`$IO8F(@;VQD86QI(&9E:FSI8P!*;V)B(&]L9&%L
M:2#I<G3I:V5K`%-O<B!T=6QA:F1O;G/A9V]K+BXN`%-Z97)E<`!2;VWA;FEA
M`$9O<F=A=.%S(#$X,"!F;VMK86P`0F%L<F$@9F]R9V%TX7,`2F]B8G)A(&9O
M<F=A=.%S`%-O<B!T=6QA:F1O;G/A9V]K`%-O<B!T=6QA:F1O;G/A9V]K`%-O
M<F]K.@!6;VYA;&%K`$UI;F1E;B!S;W(@Z7,@;W-Z;&]P(&OV>O9T="!L96=Y
M96X@=F]N86P`0W-A:R!A>B!O<WIL;W!O:R!K]GKV='0@;&5G>65N('9O;F%L
M`$-S86L@82!S;W)O:R!K]GKV='0@;&5G>65N('9O;F%L`$9U='1A=.%S`$]R
M;W-Z($;V9&5RX6-I\P!2=6%N9&$`4R]-24U%(&1I9VETX6QI<R!A;.'M<N%S
M`%,O34E-12!S>F%B=N%N>2!S>F5R:6YT('1I=&MO<^UT;W1T(&QE=NEL`%-!
M4TP@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!T86SA;&AA=/,N`%--4R!K
M_&QDZ7,`4U%,('!A<F%N8W,@82!K97)E<^ES:&5Z`%-32`!324M%4MQ,5`!3
M>F\`4WIE;G0@26QO;F$M<WII9V5T`%-A:6YT($MI='1S(.ES($YE=FES`%-A
M:6YT($QU8VEA`%-A:6YT(%!I97)R92#I<R!-:7%U96QO;@!386EN="!6:6YC
M96YT(.ES($=R96YA9&EN92US>FEG971E:P!59WEA;F%Z(&$@9G)A;64@*%]S
M96QF*0!3>F%M;V$`4V%N($UA<FEN;P!386\@5&]MZ2#I<R!0<NUN8VEP90!-
M^VAO;&1A<R!I;G1E<FYE=&5LZ7+I<P!3>F'Z9"U!<N%B:6$`365N=.ES`"(E
M<R(@;65N=.ES90`E<R!M96YTZ7-E`$$@8F7A;&SM=.%S;VL@;65N=.ES90!-
M96YT<_QK(&5L(&%Z(&5L:^ES>OQL="!K;VYF:6=U<N%C:?-T(%!(4"!P<F]G
M<F%M(&9O<FWA:N%B86X@82!S>F5R=F5R(&ED96EG;&5N97,@X6QL;VWA;GEO
M:V%T('1A<G1A;&UA>O,@86QK]FYY=G3A<N%B86XN`"5S(&MO;F9I9W5RX6-I
M\VKA="!E;&UE;G1E='3\:RX`16QM96YT971T_&L@82!S971U<"!U<&=R861E
M('!R;V=R86UO="!I9&4Z("(E<R(`4WKS<G;A;GEO<R!Z:79A=&%R;VL`5'5D
M;VWA;GD`2V5R97/I<P!+97)E<^ES:2!S>F]L9^%L=&%TX7-O:P#!;&QO;>%N
M>6]K(&MI=N%L87-Z=.%S80!6X6QA<W-Z;VX@:VD@96=Y(&3A='5M;W0`365L
M>6EK(&-S;W!O<G1O="!K[7;A;FIA(&AO>GKA861N:0!6X6QA<W-Z82!K:2!A
M>B#Z:B!T=6QA:F1O;F]S=`!6X6QA<W-Z;VX@<WIE<G9E<G0`365L>6EK(&9E
M;&AA<WINX6SS="!K[7;A;FIA(&AO>GKA861N:0!-:6YD970@:VEJ96SV;&K\
M:P!6X6QA<W-Z82!K:2!A>B#V<W-Z97,@9.%T=6WV<W-Z971E=O5T+@!6X6QA
M<W-Z;VX@96=Y(&]B:F5K='5M;W0`16=Y('-E(&QE9WEE;B!K:6IE;/9L=F4`
M5N%L87-S>F$@:VD@82!K[7;A;G0@:V%R86MT97(H96ME*70@87H@86SA8F)I
M(&QE:&5T]7/I9V5K(&OV>OQL+B!%>G5TX6X@(F-O<'DO<&%S=&4B(&WS9'-Z
M97)R96P@82!M96=F96QE;/4@:&5L>7)E(&WA<V]L:&%T:F$@]6ME="X`5N%L
M87-S>F$@:VD@82!DX71U;65L=N%L87-Z=/,@:V%R86MT97)T.@!6X6QA<W-Z
M82!K:2!A(&3A='5M(&9O<FWA='5MX70Z`%;A;&%S<WIA(&MI+"!M96QY:6L@
M87IO;F]S[73S:N%T(&OM=N%N:F$@;65G=N%L=&]Z=&%T;FDZ`%;A;&%S<WIA
M(&MI(&%Z(&ED]65L=N%L87-Z=/,@:V%R86MT97)T.@!6X6QA<W-Z82!K:2!A
M>B!I9/4@9F]R;>%T=6WA=#H`5N%L87-S>F]N(&MI(&OI="!E9WEMX7-N86L@
M;65G9F5L96SU(&UE>O5T+@!6X6QA<W-Z82!K:2!A(&OM=N%N="!S>NUN96=Y
M_'1T97-T+@!6X6QA<W-Z82!K:2!A>B#6;FYE:R!M96=F96QE;/4@;GEE;'9E
M=#H`2&EB86IE;&5N=.ES(&O\;&3I<V4`4TU3(&O\;&3I<V4`4WIE;F5GX6P`
M4WIE;GIO<CH@`'-Z97!T96UB97(`4WIE<F)I82#I<R!-;VYT96YE9W+S`%-O
M<F]Z871S>N%M`$$@<WIE<G9E<G3U;"!K87!O='0@861A="!H:6+A<RP@=F%G
M>2!N96T@X6QL(')E;F1E;&ME>NES<F4N`$$@9F5L:&%S>F[A;/-K87!C<V]L
M871O:R!A9&UI;FES>G1RX6-I\VIA`$QE:N%R="!A(&9E;&AA<WINX6SS:V%P
M8W-O;&%T(&%Z;VYO<^UT\VIA("AS97-S:6]N($E$*2X`1F5L:&%S>F[A;/-K
M87!C<V]L871O:P!(86QM87H`3&5H973U<^EG(&IE;'-Z87;A;F%K(.%TX6QL
M[73A<^%R82P@86)B86X@87H@97-E=&)E;BP@:&$@96QF96QE:G1E;NDN`%3A
M=F]L:2!S>F5R=F5R96L@96SI<NES92#A;&SM=&AA=/,@8F4L(&UE;'EE:V5T
M(&%Z(&EN9'5L\V]L9&%LX6X@:^UVX6X@;65G:F5L96[M=&5N:2X`02!K[7;A
M;G0@;GEE;'8L(&ED]7KS;F$@Z7,@9.%T=6UF;W)MX71U;2!B9>%L;.UTX7-A
M+@!"9>%L;.UT:&%T\RP@:&]G>2!M96QY:6L@86QK86QM87KA<R!J96QE;FIE
M;B!M96<@82!B96IE;&5N=&ME>NES('5TX6XL(&UI;'EE;B!S>NUN96=Y_'1T
M97-T+"!O;&1A;&9R:7-S[73I<VD@9WEA:V]R:7/A9V]T(&EL;"X@96=YZ6(@
M8F7A;&SM=.%S;VMA="!S>F5R971N92X`0F7A;&SM=.%S;VL`02!B9>%L;.UT
MX7-O:V%T(&UE9_IJ[73S('!R;V=R86UO:R#A;&QN86L@<F5N9&5L:V5ZZ7-R
M90!!(&UE9V%D;W1T('!A<F%MZ71E<B!T]F)B(&AE;'EE="!I<R!J96QE;G1H
M970Z(`!397EC:&5L;&4M<WII9V5T96L`5N%SX7)LX7,`4O9V:60@]G-S>F5F
M;V=L86SA<P!%;"!K[7;A;FIA(.ER;FD@87H@96=Y97,@9G5N:V-I\VMA="!!
M;'0M8FEL;&5N='G[+6MO;6)I;N%C:?-K:V%L(&ES/P!-96=J96QE;NUTZ7,`
M375T87-S=6L@;65G(&$@:_QL]FYB<^EG96ME="!A>B!E;&UE;G1E='0@Z7,@
M87H@^FIO;FYA;B!LZ71R96AO>F]T="!K;VYF:6=U<N%C:?,@:_9Z]G1T+@!-
M:6YD96X@8F5J96QE;G1K97KI<VMO<B#M<O-D:NEK(&MI(&$@:V]RX6)B:2!U
M=&]L<_,@8F5J96QE;G1K97KI<R!I9&5J93\`5N%L87-Z=&AA=/,@;&5G>65N
M(&%Z(&5R961E=&D@;65G=&%R=.%S80!,96=Y96X@9.%T=6UVX6QA<WIT\P!,
M96=Y96X@96=Y('3A8FSA>F%T:V5Z96SU(&UE;OQS;W(_`$UU=&%S<W5K(&$@
M)7,@;65N_'0@82!B86P@;VQD86QO;C\`3NEZ>OQK(&UE9R!TX6)LX7IA="!C
M96QLX6EN86L@='5L86ID;VYSX6=A:70`3NEZ>OQK(&UE9R!TX6)LX7IA="!T
M=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G('3A8FSA>F%T('-O<F%I;F%K('1U
M;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@82!KZ7`@='5L86ID;VYSX6=A:70`
M375T87-S=6L@82!F96QT]FQTZ7-T`%KA<&]R;VL`6N%P;W)O:R!DZ6QE;/5T
M=`!:X7!O<F]K(&3I;'5TX6XO97-T90!(96QY:2!ZX7!O<F]K`$MI8W-I;GGM
M=.ES`$5L]7-Z]G(@:VEC<VEN>>UT96YI92!K96QL+"!V86=Y(&5L(&ME;&P@
M;6]Z9.UT86YI82!A(&AE;'EE="!E;&9O9VQA;/,@8FQO:VMO:V%T+@!3:65R
M<F$@3&5O;F4`VFH@9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-E`$1I9VET
MX6QI<R!A;.'M<N%S`$$@9&EG:73A;&ES(&%LX>URX7,@86QG;W)I=&UU<V$`
M4WII;F=A</IR`$WI<F5T`$$@:V%R8F%N=&%R=.%S(&MI:&%G>>%S80!3>FQO
M=N%K:6$`4WIL;W;I;FEA`$AA=F%ZX7,`2/-ZX7!O<@!(\WKA<&]R;VL`2/-Z
MX7!O<F]K(&3I;&5L]71T`$OI<_4@9.EL=73A;FDO97-T:2!H\WKA<&]R;VL`
M02!H\R!MZ6QY<^EG93H@`$CS(';M>FUE;FYY:7/I9V5B96X@:VEF96IE>G9E
M.B``4V%L86UO;BUS>FEG971E:P!3>F]MX6QI80!$86QO:RP@=F5R<V5K`$$@
M<V]R8F%R96YD97KI<R!I<N%N>>%N86L@:VEVX6QA<WITX7-A`$9E;&%D\VD@
M8^UM`$3I;"U!9G)I:V$`9.EL+65U<O-P86D@*$E33RTX.#4Y+3,I`$3I;&DM
M1V5O<F=I82#I<R!$Z6QI(%-A;F1W:6-H+7-Z:6=E=&5K`$3I;&D@9NEL=&5K
M90!3>F]M<WKI9&]S(&-E;&SA:R!K]GKV='1I('3A=F]L<^%G`$$@8V5L;&$@
M=&%R=&%L;6$@Z7,@:V5R971E(&OV>O9T=&D@=.%V;VQSX6<`2&5L>6MI=/9L
M=/4`5.%V;VQSX6<`5.%V;VQSX6<@Z7,@8F5L<_4@;6%R9_,@8F7A;&SM=.%S
M`%-P86YY;VQO<G-ZX6<`4W!A;6%S<V%S<VEN92!B9>%L;.UTX7-O:P!3<&5C
M:>%L:7,@:V%R86MT97(@8F5V:71E;&4`02!C96QL82!K971TZ6)O;G3A<V$`
M07H@;W-Z;&]P(&ME='3I8F]N=.%S80!!('-O<B!K971TZ6)O;G3A<V$`4W!O
M<G0`4W+M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!!>B!E;'/U(.EV`,%L
M;&%M('9A9WD@=&%R=&]MX6YY`,%L;&%P;W0`365N=.ES:2!F;W)MX71U;0!#
M[6T@*'5T8V$I`.%T:/IZ;W1T`%-T<FEN9R!L:7-T80!4]G+V;&K\:R!A(&/M
M;6+U;"!A($`@=73A;FD@<NES>G0`4W3M;'5S(%M#4U-=`%9A`$$H>BD@(B5S
M(B!A;&OV;GEV=.%R(&YE;2!T86SA;&AA=/,N`%3A<F=Y`$O\;&1J_&L@96P`
M(B5S(B#Z:B!F96QH87-Z;N%L\R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T
M;W;A8F+M=&]T='5K+B#6;B!C<V%K(&OI<F5L;>EN96L@96QF;V=A9.%SX70@
M:_9V973U96X@='5D(&UA:F0@8F5J96QE;G1K97IN:2X`86QS\R!I;F1E>`!3
M:6ME<OQL=`!3:6ME<F5S96X@:&]Z>N%A9'1U:R`B)7,B+70@82!R96YD<WIE
M<FAE>BX`(B5S(B!F96QH87-Z;N%L\R!A9&%T86ET('-I:V5R97-E;B!T]G+V
M;'3\:R!A(')E;F1S>F5R8O5L+@!3:6ME<F5S96X@=/9R]FQT_&L@(B5S(BUT
M+@!3:6ME<F5S96X@96QTX79O;.UT;W1T=6L@(B5S(BUT(&$@<F5N9'-Z97)B
M]6PN`$$@:V]N9FEG=7+A8VGS="!S:6ME<F5S96X@=FES<WIAX6QL[71O='1U
M:RX@02!VX6QT;WKA<V]K(&UE9W1E:VEN=.ESZ6AE>B!F<FES<^UT<V4@87H@
M;VQD86QT+@!!(&)A8VMU<"!K;VYF:6=U<N%C:?-T(&5L;65N=&5T=/QK+@!3
M:6ME<F5S96X@96QM96YT971T_&L@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A
M8VGS="X`(B5S(B!A9&%T86EN86L@;?-D;W/M=.%S82!S:6ME<F5S96X@;65G
M=/9R=.EN="X`4VEK97)E<V5N(&5L;65N=&5T=/QK(&$@)7,@X6QL;VWA;GET
M+@!3>G5DX6X`UG-S>F5F;V=L86SA<P!.87!K96QT90!.87!N>75G=&$`;F%P
M;W,`3F%P:V5L=&4`3F%P:V5L=&4O;F%P;GEU9W1A`$YA<&ME;'1E.B``3F%P
M;GEU9W1A`$YA<&YY=6=T83H@`&9E;'/U(&EN9&5X`$]N;&EN92!K;VUM=6YI
M:^%C:?,@*&-H870I`%-U<FEN86UE`$-S86SA9&[I=@!3=F%L8F%R9"#I<R!*
M86X@36%Y96X`4WIVX7II9O9L9`!3=NED;W)S>N%G`%-VX6IC`$%Z(&%D871S
M>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N>70@=/9R]FQT_&L`4WII;G1A
M:W1I:V%I(&AI8F$@82!K97)E<_5K:69E:F5ZZ7-B96X`4WKM<FEA:2!!<F%B
M($OV>G3A<G-A<^%G`%II=F%T87(`6FEV871A<BP@97+U<R!S>NEL`%II=F%T
M87)O:P!+;W)A:2!Z:79A=&%R;VL`5%-6("A404(@:V%R86MT97)R96P@96QV
MX6QA<WIT;W1T(.ER=.EK96LI(.%L;&]MX6YY`%3A8FSA>F%T`$$@=.%B;.%Z
M870@='5L86ID;VYSX6=A:0!!('3A8FSA>F%T('1U;&%J9&]N<^%G86D`5&%J
M=F%N`%1A:G9A;@!4861Z<VEK:7-Z=.%N`%1A;GKA;FEA:2!%9WEE<_QL="!+
M:7+A;'ESX6<`02!CZ6PZ`$9E;&%D871O:P!496QE9F]N<WKA;0!!>B!E;&WZ
M;'0@\W)A(&CU;>ER<^EK;&5T93H@`$CU;>ER<^EK;&5T`$CU;>ER<^EK;&5T
M.B``2/5MZ7)SZ6ML970\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S
M`$$H>BD@(B5S(B!S86)L;VX@;F5M('1A;.%L:&%T\RX`4V%B;&]N;VL@861M
M:6YI<WITX6-I\VIA`%-Z]G9E9P!C<V%K('-Z]G9E9P!3>O9V96=E;&AE;'EE
M>NES`'-Z]G9E9R!T971E:F4`0W/\`'1H86D@*%1)4RTV,C`I`%1H86EF]FQD
M`$%Z(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$$@2&ES=&]R>2!R96YD
M<WIE<B!M^VOV9.ES92!N:6YC<R!E;F=E9.EL>65Z=F4N`$$@2&]R9&4O2V]L
M86(@:6YT96=RX6-I\R!E>G0@;F5M('3A;6]G871J83H@(B5S(@!!>B!)35-0
M(&YA<&SS>N%S="!N96T@<VEK97+\;'0@;65G:V5Z9&5N:2X`02!-86EN=&5N
M86YC93HZ(&]S>G3A;'D@8F5T]FQTZ7-E(&YE;2!S:6ME<OQL=`!!>B!/<&-I
M\R!A8FQA:R!B97KA<F]D;W1T+B!+:6SI<.ES(&OV=F5T:V5Z:6LN`$$@2F]G
M;W-U;'1SX6=O:R!H87-Z;N%L873A;F%K(&5L]69E;'3I=&5L92P@:&]G>2!A
M(')E;F1S>F5R9V%Z9&$@:V]N9FEG=7+A;&IO;B!E9WD@82!J;V=O<W5L='/A
M9VD@861A=&]K870@=&%R=/-S86X@=.%R;VQN:2!KZ7!E<R!A;')E;F1S>F5R
M="X`0W-A:R!A;'5L(&QE9WEE;B!K97)E=`!!('!A<G1N97(@87IO;F]S[73S
M<WKA;6$@;F5M('9O;'0@;65G861V82_\<F5S96X@;6%R861T('9A9WD@87H@
M861A=&+A>FES8F%N(&YE;2!V;VQT(&UE9W1A;.%L:&%T\RX`02!P87)T;F5R
M(&%D871A:70@<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ96=Y>NEKZ6AE
M>BX`2_QL]F[A;&SS(%!'4"!A;.'M<N%S:2!B;&]K:R!S>OQK<^EG97,@82!D
M:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T(&AI=&5L97-SZ6?I;F5K(&5L;&5N
M]7)ZZ7/I:&5Z+@!!(&OV<FQE=NEL;&ES=&$@87IO;F]S[73S<WKA;6$@;F5M
M('9O;'0@;65G861V82_\<F5S96X@;6%R861T('9A9WD@87H@861A=&+A>FES
M8F%N(&YE;2!V;VQT(&UE9W1A;.%L:&%T\RX`02!K]G)L97;I;&QI<W1A(&YE
M;2!V;VQT(&UE9V%D=F$N`$$@=&ET:V]S[73A<VD@<WIO;&?A;'1A=.%S;VMH
M;WH@8FEZ=&]N<^%G;W,@*'1I=&MO<^UT;W1T*2!W96(@:V%P8W-O;&%T(&ME
M;&PN`$$H>BD@)7,@X6QL;VWA;GEB86X@<WIE<F5P96QN:64@:V5L;&5N92!E
M9WD@)7,@8F7A;&SM=.%S;F%K+@!!*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E
M<&5L;FEE(&ME;&QE;F4@=F%L86UI;'EE;B`E<R!B9>%L;.UTX7,H;VLI;F%K
M+@!!(&;A:FP@;F5M(&WA<V]L:&%T\R#V;FUA9^%R82X`02!FX6IL8F%N(&YE
M;2!V;VQT(&%D870N`$%Z(/QZ96YE="!F96ILZ6-S;W)A:2!A(&OV=F5T:V5Z
M]6LN`$$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M;?-D('!R;V)LZ6WA:V%T(&]K
M;WIH870@87H@26YT97)N970@17AP;&]R97(@:&%S>F[A;&%T82!E<V5TZ6XL
M(&UE<G0@96)B96X@;VQY86X@<')O9W)A;6AI8N%K('9A;FYA:RP@86UI:V5T
M(&YE;2!T=61T=6YK(&UE9VME<OQL;FDN($$@:^EP97)N>?5J92!O;'9A<VAA
M=&%T;&%N;N$@=N%L:&%T+"!B:7IO;GEO<R!E9&ET;W(@9G5N:V-I\VL@:&GA
M;GEO>FAA=&YA:R#I<R]V86=Y(';A<F%T;&%N=6P@;&5F86=Y:&%T(&$@8O9N
M9^ES>O5P<F]G<F%M+B!7:6YD;W=S(#EX(&AA<WINX6QA=&$@97-E=.EN(&YA
M9WEO;B!V86SS<WKM;OLL(&AO9WD@)T=E;F5R86P@<')O=&5C=&EO;B!F875L
M="<@:&EB82!M:6%T="#Z:G)A(&ME;&P@:6YD[71A;FEA(&UA:F0@82!GZ7#I
M="Y<;EQN1FEG>65L;65Z=&5T=/QK(2!+871T:6YT<V]N(&%Z($]+(&=O;6)R
M82P@:&$@;>EG:7,@;65G(&OM=N%N:F$@:^USZ7)E;&YI(&$@=&5L:F5S(&OI
M<&5R;GGU<R#\>F5M;?-D;W0N`$$@(B5S(B!A>F]N;W/M=/-T(&MI=/9R]FQT
M_&LN`$-S86L@8F%L(&]L9&%L;VX@;&5G>65N(&ME<F5T`$$@1VYU4$<@<')O
M9W)A;2!H96QYZ70@;65G(&ME;&P@861N:2!A($-R>7!T7W!G<#HZ(&]S>G3A
M;'D@:&%S>F[A;&%TX6AO>BX`02!L97;I;"P@;65L>65T("5S(&YA<&KA;B!K
M_&QD]G1T("5S(&/M;7IE='1N96L@(B5S(B!TX7)G>6)A;BP@82!C[6UZ971T
M('-ZX6WM=/-GZ7#I;B!M96=J96QE;G0N($%R<F$@;FEN8W,@9V%R86YC:6$L
M(&AO9WD@96P@:7,@;VQV87-TX6L@:6QL+B!H;V=Y(&UE9^ER=&5T=.EK+@!-
M:2!L96=Y96X@82!L97;I;.UR\R!A8FQA:VAO>B!M=71A=/,@;&EN:R!E;&YE
M=F5ZZ7-E`$$@;65Z]6L@<WKA;6$@8W-A:R!N=6UE<FEK=7,@Z7)TZ6L@;&5H
M970N`$%Z(&]P96YS<VP@;6]D=6P@<WK\:W/I9V5S(&$@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN`$$@(B5S(B!S>F5MZ6QY
M97,@8F7A;&SM=.%S(&YE;2!M96YT:&5T]2!E;"P@;65R="!MZ7)E=&4@;65G
M:&%L861J82!A(&UE9V5N9V5D971T(&UA>&EM=6UO=`!.96T@=&%LX6QH873S
M(&%Z(&$@<')O9W)A;2!A('-Z97)V97)E;BP@86UI('-Z_&MSZ6=E<R!E;FYE
M:R!A>B!A9&%T=.UP=7-N86L@*"5S*2!A(&UE9VIE;&5N[73I<^EH97HN`$%Z
M(&EDZ7KU:F5L(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT97(@;&5H
M970N`$IO8F(@Z7,@8F%L(&]L9&%L;VX@;&5G>65N(&ME<F5T`$-S86L@:F]B
M8B!O;&1A;&]N(&QE9WEE;B!K97)E=`!!>B!E;';A;&%S>G3S(&MA<F%K=&5R
M(&-S86L@96=Y971L96X@:V%R86MT97(@;&5H970N`$$H>BD@(B5S(B!S>F5R
M=F5R="!T]G+V;'3\:RX`02AZ*2`B)7,B('-Z97)V97)T(&5L;65N=&5T=/QK
M+@`E<R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T]G+V;'3\:RX`02!M96=A
M9&]T="!S;W(@*"5D*2!N96T@;.ET97II:RX`02AZ*2`B)7,B(&ED96EG;&5N
M97,@9N%J;"!N96T@;.ET97II:RX`02!B9>UR="!S>O9V96<@;F5M(&5G>65Z
M:6L@82!KZ7!E<FYY]6X@;&5V]79E;"X`06QU;"#I<R!F]FS\;"!L96=Y96X@
M:V5R970`0W-A:R!F96YT(&QE9WEE;B!K97)E=`!!(&9E;'3V;'3V='0@861A
M=&]K(&%Z(&5L]7KU(&SI<.ES(/-T82!E;'9E<WIT96LN`$$@9F5L=/9L=/9T
M="!FX6IL="!N96T@<VEK97+\;'0@96QM96YT96YI+@!!('=E871H97(N8V]M
M(&)L;VMK(&YE;2!H87-Z;N%L:&%T\RX`02!M96=J96QE;NES:2!S=.UL=7,@
M*'1H96UE<RD@86QK]FYY=G3A<B`B)7,B(&YE;2!T86SA;&AA=/,N`$YI;F-S
M96X@=N%L87-Z=&AA=/,@;W!C:?,N`$YI;F-S(&$@;&5VZ6P@8F5L<V5JZ6)E
M;B!M96=J96QE;NUT:&5T]2!M96QLZ6ML970N`%3Z;"!S;VL@:V%R86MT97(@
M=F%N(&5B8F5N(&$@;65Z]6)E;BX@UFX@)7,@:V%R86MT97)T(&%D;W1T(&UE
M9SL@82!M87AI;>%L:7-A;B!M96=A9&AA=/,@<&5D:6<@:V5V97-E8F(L(&UI
M;G0@)7,N`"(E<R(@9F5L:&%S>F[A;/-N86L@82!R96YD<WIE<FAE>B!A9.%S
M86MO<B!H:6)A('3V<G3I;G0N("5S`"(E<R(@9F5L:&%S>F[A;/,@861A=&%I
M;F%K('3V<FSI<V4@<V]RX6X@:&EB82!LZ7!E='0@9F5L.B``(B5S(B!R96YD
M<WIE<F+U;"!V86SS('3V<FSI<V5K;W(@:&EB82!LZ7!E='0@9F5L.B``(B5S
M(B!M\V1O<^UTX7-A('-O<N%N(&AI8F$@;.EP971T(&9E;#H@)7,`07H@X6QL
M;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B`E
M<R!N96T@=/9L=/5D]G1T(&9E;"X`07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL
M="!A('-Z97)V97)R92!F96QT]FQT96YI+B`E<R!N86=Y;V)B+"!M:6YT(&$@
M;6%X:6WA;&ES86X@;65G96YG961E='0@;>ER970@*"5D(&+A:G0I+@!!>B#A
M;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@<WIE<G9E<G)E(&9E;'3V;'1E;FDN
M($$H>BD@)7,@9N%J;&YA:R!C<V%K(&5G>2!RZ7-Z92!T]FQT]63V='0@9O9L
M+@!!(&QE=NEL(&4@<NES>NEN96L@;65G:F5L96[M=.ES96MO<B!H:6)A('3V
M<G3I;G0`02!P87)T;F5R(&%D871O:R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A
M('3V<G3I;G0N`$%Z(&E#86QE;F1A<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]R
MX6X@:&EB82!T]G)TZ6YT+@!(:6+A<R!A(&UE9V%D;W1T(&MO;F9I9W5RX6-I
M\RX@3&5H970L(&AO9WD@;F5M('3V;'3V='0@:VD@96=Y('-Z_&MSZ6=E<R!M
M97KU="X`02!P87)T;F5R:F5G>7KI:VME;"!K87!C<V]L871O<R!F96QA9&%T
M(';I9W)E:&%J=.%S82!S;W+A;B!H:6)A(&SI<&5T="!F96PN($OI<F5M('!R
M\V+A;&IA(&UE9R!KZ7/U8F(N`$AI8F$@=/9R=.EN="!A('!A<G1N97(@861A
M=&%I;F%K(&9R:7-S[73I<V4@<V]RX6XN($OI<F5M('!R\V+A;&IA(&UE9R!K
MZ7/U8F(N`$$@:_9R;&5VZ6QL:7-T82!A9&%T86EN86L@9G)I<W/M=.ES92!S
M;W+A;B!H:6)A('3V<G3I;G0N($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N
M`$5Z(&%Z($E-05`@<WIE<G9E<B!N96T@=.%M;V=A=&IA(&$@;6%P<.%K:&]Z
M('9A;/,@:&]Z>N%FZ7+I<R!M96=O<WITX7/A="X`17H@;F5M('3[;FEK('-Z
M86+A;'EO<R!R87(@X6QL;VWA;GEN86LN`$5Z(&YE;2!T^VYI:R!S>F%BX6QY
M;W,@>FEP(.%L;&]MX6YY;F%K+@!%>B!N96T@=/MN:6L@Z7)VZ6YY97,@:^%R
M='EA<WKA;6YA:RX`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G
M>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&$@0VQI8VMA=&5L
M;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!S>F]L9^%L=&%T\VX@X70N`$5Z
M(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@2%144"UK87!C<V]L
M871O;B!335,M="!K_&QD:OQN:R!A(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M('-Z;VQGX6QT873S;B#A="X`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z
M:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&%Z('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI('-Z;VQGX6QT873S;B#A
M="X`17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!33510+6MA
M<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(%9O9&%F;VYE('-ZX6UO:W)A(&$@
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!S>F]L9^%L=&%T
M\VX@X70N($$@<WIO;&?A;'1A=.%S(&EGZ6YY8F5VZ71E;.EH97H@5F]D869O
M;F4@271A;'D@96UA:6P@8^UM('-Z_&MSZ6=E<RX`17H@82!M97KU(&YE;2!M
M87)A9&AA="#\<F5S+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M
M;VL@X6QL:&%T;F%K+@!%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S>N%M
M;VL@Z7,@:V5T=/5S<&]N="!L96AE="X`16)B96X@82!M97KU8F5N(&-S86L@
M;VMTX6QI<R!S>N%M;VL@X6QL:&%T;F%K+@!%>B!A(&UE>O4@8W-A:R!V97-S
M>O5V96P@=F%G>2!S>O-K]GIZ96P@96QVX6QA<WIT;W1T(&5GZ7-Z('-ZX6UO
M:V%T('1A<G1A;&UA>FAA=`!%>B!A>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N
M`$5B8F5N(&$@;65Z]6)E;B!H97AA9&5C:6WA;&ES(%)'0B!S>NUN:_-D(.%L
M;&AA="P@<&PN("<C,3(S-&%F)RX`17IE;B!A9&%T;VMK86P@:V%P8W-O;&%T
M;W,@9F5L861A=&]K870@82!S>F5R=F5R(&WA<B!E;';I9V5Z=&4N`$5Z("5S
M`$5Z(&5G>2!+;VQA8B!'<F]U<'=A<F4@;V)J96MT=6TN($%Z(&EL>65N(&]B
M:F5K='5M(&UE9VIE;&5N[73I<^EH97H@;VQY86X@96UA:6P@:VQI96YS<')O
M9W)A;2!S>OQK<^EG97,L(&%M96QY(&OI<&5S(&$@2V]L86(@1W)O=7!W87)E
M(&9O<FWA='5M(&ME>F5LZ7/I<F4N($EL>65N(&5M86EL(&ML:65N<V5K(&QI
M<W3A:F$@;.%T:&%T\R!I='0Z("5S`$5Z="!A(&QE=F5L970@;>%S(&MA<F%K
M=&5R:^ES>FQE='1E;"`H)7,I(.UR=.%K+"!M:6YT(&%M:70@UFX@:&%S>F[A
M;"X`17H@82!S>N%M(&YE;2!L96AE="!E9WENZ6P@:VES96)B+@!%>B!A('-Z
M97)V97(@;F5M(&OI<&5S(&MI8F]N=&%N:2!A('II<"!I;&PN(&=Z:7`@X6QL
M;VWA;GEO:V%T+@!%>B!A(')E;F1S>F5R(&IE;&5N;&5G(&EN86MT:7;A;'9A
M('9A;BX`17H@87H@Z7)TZ6L@8W-A:R!S>N%M(&QE:&5T+@!%>G0@87H@86)L
M86L@8W-A:R!A>B!/<&-I\VL@86)L86MB\VP@:.UV:&%T\P!6:6QLX6ULX7,`
M2&EB86)E:F5L96YTZ7,M:V5Z96SI<P!)9/4`375N:V%I9/4M;GEI;';A;G1A
M<G3A<P!)9/4@9F]R;>%T=6T`263U(';A;&%S>G3A<P!+96QE="U4:6UO<@!4
M:71U;'5S`$/M;2`H=&]O;'1I<"D`0^UM>F5T=`!(82!T]F)B(&5L96UE="!I
M<R!K:2!A:V%R(&IE;/9L;FDL('1A<G1S82!L96YY;VUV82!A($-O;G1R;VP@
M*%!#*2!V86=Y(&$@0V]M;6%N9"`H36%C*2!B:6QL96YT>?MT(&$@:V%T=&EN
M=.%S(&OV>F)E;BX`36$`2%1-3"!F;W)RX7-NZ7IE="!K:2]B90!4;V=O`%1O
M:V5L874`2&]L;F%P`%1O;F=A`&;V;/QL`$QE9V9E;'/U(&9R86UE("A?=&]P
M*0!&;W)D[73A<V]K`%1R:6YI9&%D(.ES(%1O8F%G;P!)9V%Z('9A9WD@:&%M
M:7,`2V4`5'5NZ7II80!4]G+V:V]R<WKA9P!T]G+V:R`H25-/+3@X-3DM.2D`
M5/QR:VUE;FES>G3A;@!4=7)K<RT@Z7,@0V%I8V]S+7-Z:6=E=&5K`%1U=F%L
M=0#-<FIA(&)E+"!M:70@=N%L87-Z=&]T=#H@`%56(&EN9&5X.B``55),`%52
M3"P@;65L>65N(&5G>2!P<F]G<F%M(&5L9F]G861J82!A('-Z;VQGX6QT873S
M(.%L=&%L(&O\;&3V='0@:_QL9/9T="!KZ7IB97/M=.ES:2!J96QE;G3I<W0`
M55),.@!59V%N9&$`56MR86IN80!.96T@<VEK97+\;'0@82!61E,@86QK]FYY
M=.%R8F$@8F5LZ7!N:2X`02!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A9R!I
M9^EN>6SI<V5K;W(@;F5M('-I:V5R_&QT(&%Z(&%D871O:R!E;'3A<F]LX7-A
M+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B(%9&4R!FX6IL(&5LZ7+I<VD@:F]G
M;W-U;'1SX6=A:70@;65G=N%L=&]Z=&%T;FDN`$YE;2!S:6ME<OQL="!A*'HI
M("5S+R5S(%9&4R!FX6IL(&5LZ7+I<VD@:F]G;W-U;'1SX6=A:70@;65G=N%L
M=&]Z=&%T;FDN`$YE;2!S:6ME<OQL="!A*'HI("5S(&%L:_9N>79TX7)B82!B
M96SI<&YI+@!!*'HI("(E<R(@X6QL;VWA;GD@;>ER971E(&YE;2#A;&QA<.UT
M:&%T\R!M96<N`$$H>BD@(B5S+R5S(B#A;&QO;>%N>2!MZ7)E=&4@;F5M(.%L
M;&%P[71H873S(&UE9RX`07H@4U%,('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`
M07H@4U-,(&MA<&-S;VQA="!N96T@Z7#M=&AE=/4@9F5L+@!!(%9&4R!FX6IL
M(&YE;2!MX7-O;&AA=/,@X70N`$YE;2!S:6ME<OQL="!A*'HI("(E<R(@5D93
M(&%L:_9N>79TX7)T(&SI=')E:&]Z;FDN`$YE;2!S:6ME<OQL="!LZ71R96AO
M>FYI(&$@5D93(&%L:_9N>79TX7)T+@!.96T@<VEK97+\;'0@;.ET<F5H;WIN
M:2!A(%9&4R!FX6IL="X`02AZ*2`B)7,B(%9&4R!M87!P82!N96T@:&]Z:&%T
M\R!LZ71R92X`3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@_')E<R!61E,@9N%J
M;'0N`$$@=/9M]G+M=&5T="#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&MI8F]N
M=&%N:2X`(B5S(B!N96T@=/9R]FQH973U+"!A>B!A;&OV;GEV=.%R(&YE;2#\
M<F5S+@`B)7,B('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E<RX`)7,@;F5M('3V
M<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N96T@_')E<RX`02!61E,@86QK]FYY
M=G3A<B!N96T@=/9R]FQH973U(')E:W5R>NUV86XN`$$@5D93(&%L:_9N>79T
MX7(@;F5M('3V<O9L:&5T]2X`02!61E,@86QK]FYY=G3A<B!N96T@=/9R]FQH
M973U.B`E<RX`02AZ*2`B)7,B(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N`$$@
M5D93(&;A:FP@;F5M('3V<O9L:&5T]2X`02AZ*2`B)7,B(%9&4R!M87!P82!N
M96T@=/9R]FQH973U+@!.96T@=NEG97IH973S(')E:W5R>NUV('3V<FSI<R!A
M(%9&4RUB96XZ("5S+@!.96T@:&%TX7)O>FAA=/,@;65G(&$@:F5L96YL96<@
MZ7)VZ6YY97,@86QK]FYY=.%R+@!!('1A;OIS[71VX6YY('+I<WIL971E<R!A
M9&%T86D@;F5M(&AA=.%R;WIH873S:R!M96<`3F5M('-I:V5R_&QT(&)E;VQV
M87-N:2`E<R!D969I;NUC:?-JX70N`$$@5D93(&;A:FP@;F5M(&AE;'EE>FAE
M=/,@X70N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G+@!!
M(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<@[7+A<VD@8^EL;&%L+@!!(%9&
M4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<@+@!!('3V;?9R[71E='0@X6QL;VWA
M;GD@;F5M(&YY:71H873S(&UE9RX`02!61E,@9N%J;"!N96T@;VQV87-H873S
M("AA(&9I;&5S:7IE*"D@<VEK97)T96QE;B!V;VQT*2X`02!61E,@9N%J;"!N
M96T@;VQV87-H873S("AA(&=E=$9I;&53:7IE*"D@<VEK97)T96QE;B!V;VQT
M*2X`17H@82!FX6IL(&YE;2!O;'9A<VAA=/,Z(`!!('9F<W)O;W0@86QK]FYY
M=G3A<B!N96T@;VQV87-H873S+@`E<R!N96T@;F5V97IH973U(.%T("5S(&[I
M=G)E.B!MX7(@;.ET97II:R!I;'EE;B!N97;[(&UA<'!A`$$@5D93(&%L:_9N
M>79TX7(@;F5M(&YE=F5Z:&5T]2#A="X`02!61E,@86QK]FYY=G3A<B!N96T@
M;F5V97IH973U(.%T.B`E<RX`02AZ*2`B)7,B(%9&4R!FX6IL(&YE;2!N979E
M>FAE=/4@X70N`$$H>BD@)7,O)7,@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A
M="X`02!61E,@9N%J;"!N96T@;F5V97IH973U(.%T+@!!>B`G;6MI<V]F<R<@
M<')O9W)A;2!N96T@9G5T=&%T:&%T\RX`3F5M('-I:V5R_&QT(&QE9F]R9.UT
M86YI(&5Z="!A(%=O<F0@9&]K=6UE;G1U;6]T`$$H>BD@(B5S(B!61E,@9N%J
M;"!N96T@[7)H873S+@!!(%9&4R!FX6IL(&YE;2#M<FAA=/,@*&$@8V]P>2@I
M('-I:V5R=&5L96X@=F]L="DN`$$@5D93(&;A:FP@861A=&%I(&YE;2#M<FAA
M=/-K(&MI+@!!(%9&4R!FX6IL(.URX7-A(&MV\W1A=/IL;.EPZ7,@;6EA='0@
M;F5M(&9E:F5Z:&5T]2!B92X`86SA:/IZ;W1T`$WI9W-E(&UE;G1S_&L@96P`
M5FES<WIA=F]N:F$@87H@=71O;'/S(';A;'1O>G1A=.%S=`!!(&MA<&-S;VQA
M="!F96QVZ71E;.ET(&OV=F5T]65N(';A<F%T;&%N(';A;&%S>B#I<FME>F5T
M="!A('-Z97)V97)T]6PZ(`!6X7)A=&QA;B!VX6QA<WH@Z7)K97IE='0@82!S
M>F5R=F5R=/5L(&5R<F4Z(`!"97-O<F]L871L86X`56YI8V]D92`H551&+3@I
M`$5G>65S_&QT($%R86(@16WM<G/I9V5K`$5G>65S_&QT($MI<N%L>7/A9P!%
M9WEE<_QL="#!;&QA;6]K`$5G>65S_&QT(,%L;&%M;VLL(&MI<V5B8B!K_&QS
M]2!S>FEG971E:P!E9WESZ6<`27-M97)E=&QE;@!)<VUE<F5T;&5N(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN`$ES;65R971L96X@8VQI;7-G:60@*$-L
M:65N="!-97-S86=E($E$*2X`02!M96=A9&]T="!H96QY(&ES;65R971L96XN
M`$ES;65R971L96X@9F5L:&%S>F[A;/-I(&[I=B!V86=Y(&IE;'-Z\RX`5.%V
M;VSM='-U:R!E;"!I;FYE;B!A(&QI;FME=`!.:6YC<R!E;&YE=F5Z=F4`0FEZ
M=&]N<^%G:2!O:V]K8O-L(&$@9F5L:&%S>F[A;/-I('!R;V=R86UO:R!N96T@
M:&%S>F[A;&AA=&KA:R!A($MI=N%GX7,O3>%S;VSA<R]"96EL;&5S>G3I<R!M
M\V1S>F5R="X@2V%T=&EN='-O;B!A>B!/2R!G;VUB<F$L(&AA(&$@;6]Z:6QL
M82YO<F<@=V5B;VQD86QO;B!E;"!K[7;A;FIA(&]L=F%S;FD@82!T96-H;FEK
M86D@;&7M<N%S="!M96QY(&UE9V%D:F$L(&AO9WEA;B!L96AE="!E>G0@;>EG
M:7,@96YG963I;'EE>FYI+@!!('-Z[6X@=FES<WIAX6QL[73A<V$`3F5M('3A
M;6]G871O='0@97AT96YZ:?,`3?-D;W/M=.%S`"5S(&%D871A:6YA:R!M\V1O
M<^UTX7-A`$$@9F5L:&%S>F[A;/,@861A=&%I;F%K(&WS9&]S[73A<V$`(B5S
M(B!VX6QT;WKA<V%I="!E;&UE;G1E='3\:RX`07H@=7!G<F%D92!P<F]G<F%M
M;W0@=/9R]FQT_&LN`$9E;'3V;'3I<P!!>B#V<W-Z97,@86QK86QM87KA<R!K
M;VYF:6=U<N%C:?-JX70@9F5L=/9L=/9T=/QK(&$@<WIE<G9E<G)E+@!L871I
M;B!N86=Y8F5T^VL`;F%G>6)E=/MS('+S;6%I('-ZX6UO:P!5<G5G=6%Y`$AA
M<WINX6QJ=6L@82!J96QE;FQE9VET.B`E<P!(87-Z;N%L:G5N:R!34TPM=`!!
M:VMO<B!H87-Z;N%L:G5K+"!H82!A>B!)35-0('-Z97)V97)E;B!MX7,@82!B
M96IE;&5N=&ME>NES:2!N97;\;FLO:F5L<WIA=G5N:RX`1F5L:&%S>F[A;/-I
M(&[I=@`E<R!F96QH87-Z;N%L\R!N96T@:F]G;W-U;'0@)7,M<F4N`$9E;&AA
M<WINX6SS:R!A9&UI;FES>G1RX6SA<V$`1F5L:&%S>F[A;/-I(&)EX6QL[73A
M<V]K`$)E:F5L96YT:V5ZZ7,@:F]G;W-U;'1SX6<@:6?I;GELZ7-E`$5Z96X@
M82!R96YD<WIE<F5N(&YI;F-S(&5N9V5DZ6QY97IV92!A>B#Z:B!F96QH87-Z
M;N%L\VL@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6?A;F%K(&EGZ6YY;.ES
M92X`07H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UT\R!N96T@=&%LX6QH873S`$9E
M;&AA<WINX6SS:2!NZ78`02AZ*2`B)7,B(&9E;&AA<WINX6SS:2!NZ78@;>%R
M(&SI=&5Z:6LN`$9E;&AA<WINX6SS:2!NZ78Z`$9E;&AA<WINX6SS:2!NZ78Z
M(`!!(')E;F1S>F5R(&9E;&AA<WINX6SS:3H`W'IB96=I<WITX6X`02!61E,@
M86QK]FYY=G3A<B!N96T@;.ET97II:RX`4WIA8F%D<^%G(&%L871T:2!A=71O
M;6%T:6MU<R!E;6%I;"UVX6QA<WH`02!K]G9E=&ME>O4@:&5L>65K970@=&%L
MX6QT=6LZ(`#)<G;I;GEE<W/I9P!!>B#I<G3I:V5K970@<&5R8V)E;B!A9&IU
M:R!M96<L(&UO<W1A;G3S;"!S>N%M[71V82X`02#I<G3I:R!N86=Y;V)B+"!M
M:6YT(&$@;&5G;F%G>6]B8B!M96=E;F=E9&5T="!H;W-S>OISX6<Z("5S+@#)
M<G3I:V5K`%;A;&%S>G1H873S(.ER=.EK96L`5F%N=6%T=0!VX6QT;WKS`%9E
M;F5Z=65L80!!(&AI=&5L97/M=.ES(&YE;2!S:6ME<OQL="`M(&QE:&5T+"!H
M;V=Y(&$@;&5V96QE="!V86QA:VD@;65G=N%L=&]Z=&%T=&$N`%9E<GII\P!6
M97)Z:?-K]G9E=.ES`$;\9V<N(&5L:&5L>65ZZ7,`1OQG9_5L96=E<R!B96QS
M]2!M87)G\P!F_&=G]6QE9V5S.@!N86=Y;VX@;6%G87,`5FEE=&YA;0!V:65T
M;F%M:2`H5DE30TE)*0`E<R!M96=T96MI;G3I<V4`2_QL<_4@=V5B;VQD86P@
M;65G:F5L96[M=.ES90!*96QE;NUT<_QK(&UE9RP@;6EN="`E<P!"<FET(%9I
M<F=I;BUS>FEG971E:P!!;65R:6MA:2!6:7)G:6XM<WII9V5T96L`3.%T\W3A
M=F]L<^%G`$SA=/-TX79O;'/A9SH@`%9O9&%F;VYE($ET86QY('-Z;VQGX6QT
M873A<R!33510+6X@:V5R97-Z=/QL`$9)1UE%3$U%6E1%5,E3`$9)1UE%3$U%
M6E1%5,E3(2!+R5I:14P@5,%63TS-5%-!($5,($$@4T-225!4150@)7,M4M5,
M+@!724X@<WIO;&?A;'1A=.%S($A45%`M;B#A=`!786QL:7,@Z7,@1G5T=6YA
M`$9I9WEE;&UE>G1E=.ES`%-Z90!)9/5JX7+A<R!E;/5R96IE;'KI<P!!>B!I
M9/5JX7+A<VD@861A=&]K(&9O<G+A<V$`5V5B`%=E8FAE;'EE:P!H971E;G1E
M`-QD=O9Z]FQJ_&L`W&1V]GKV;&K\:SH@)7,`W&1V]GKV;&K\:RP@)7,`;GEU
M9V%T+65U<O-P86D@*$E33RTX.#4Y+3$I`&YY=6=A="UE=7+S<&%I("A)4T\M
M.#@U.2TQ-2D`3GEU9V%T+5-Z86AA<F$`36EL>65N(&%L:V%L;6%ZX7-T(&UU
M=&%S<V]N("5S(&$@8F5J96QE;G1K97KI<R!U=.%N/P!-:2!A>B!E;';A;&%S
M>G3S(&MA<F%K=&5R/P!-:2!A>B!I9.EZ971K87)A:W1E<C\`5VAE<F5I<R!!
M=7-Z='+A;&EA('3I<FOI<`!-96QY:6L@8VEK;'5S`$UE;'EI:R!M;V1U;&]K
M870@86MT:7;A;&IU:R!A(%)I8V@@5&5X="!E9&ET;W)B86X_`%-ZZ6QE<W/I
M9P!3>NEL97-SZ6<@0U-3(&5G>7/I9V)E;@!!("5S(&UE;OP@<WKI;&5S<^EG
M92!A(&)A;"!O;&1A;&]N("AA(&OV=F5T:V5Z]2!B96IE;&5N=&ME>NES="!K
M]G9E=/5E;B!L97-Z(.ER=NEN>65S*0!!('3A8FSA>F%T('-ZZ6QE<W/I9V4`
M02!S>NEL97-SZ6<@;>ER=.EK96=Y<^EG90!3>NEL97-SZ6<Z`%=I:VD`4WKI
M;`!3>NEL(&$@<F5G9V5L:2#S<N%K8F%N`%-ZZ6QS96)E<W/I9R!C<V]M\V)A
M;@!3>NEL.@!3>NEL.B``0O9L8W-E<W/I9P!+[7;A;G/A9VQI<W1A`$UU;FMA
M`$UU;FMA:&5L>6D@8^UM`$UU;FMA:&5L>6D@=&5L969O;@!!("5D+B!S;W)B
M86X@;F5M(&UE9V9E;&5L]2!A(&UE>O5K('-ZX6UA+B!6X7)T.B`E9"P@=&%L
MX6QT.B`E9"X`3F5M(&UE9V9E;&5L]2!A(&UE>O5K('-ZX6UA+B!6X7)T.B`E
M9"P@=&%LX6QT.B`E9"X`2&EBX7,@;V9F<V5T("@E9"D@82!61E,@9N%J;"!O
M;'9A<^%S86MO<BX`3&EN=7@@9F]R<N%S:_-D(&ME<F5S>G)E9F5R96YC:6$`
M6#4P.78S(&%L87!V973U(&MO<FSA=&]ZX7-O:P!8-3`Y=C,@:VET97)J97-Z
M=&5T="!K=6QC<VAA<WINX6QA=`!8-3`Y=C,@='5L86ID;VYO<R!A;'1E<FYA
M=.UV(&UE9VYE=F5ZZ7-E`%@U,#EV,R!T=6QA:F1O;F]S(&MU;&-S87IO;F]S
M[73S`%@U,#EV,R!K:71E<FIE<WITZ7-E:P!960!965E9`%EA:&]O(2!TZ7)K
MZ7``Z79E;G1E`$IE;65N`$EG96X`26=E;BP@8F5L96=Y97IE;2X`36]S="!(
M5$U,(%1%6%0@;?-D8F%N('9A;BX@2&%S>F[A;&IA(&$@6SP^72!G;VUB;W0L
M(&AA('9I<W-Z82!A:V%R(';A;'1A;FD@82!S>F]KX7-O<R!G<F%F:6MU<R`H
M5UE325=91RD@;65G:F5L96[M=.ES<F4N`$YE;2!H;WIH870@;.ET<F4@)60@
M8FQO:VMNX6P@=/9B8F5T+@!!>B#6;B!F96QH87-Z;N%L\V%Z;VYO<^UTX7-A
M(&YE;2!T]G)TZ6YT(&UE9RX`02!T96QJ97,@;NEV8F5N(&YE;2!S>F5R97!E
M;&AE="!A("=<)R!K87)A:W1E<BX`3F5M(&%D;W1T(&UE9R#I<G;I;GEE<R!E
M;6%I;"!C[6UE="X`3F5M(&%D=&$@;65G(&$@;65G9F5L96QT973I<W0@87H@
M:6UP;W)TX6QT(&;A:FP@Z7,@82AZ*2`E<R!M97KU:2!K]GKV='0N`%-I:V5R
M97-E;B!K:6IE;&5N=&ME>F5T="X`16=Y(&UO8FEL=&5L969O;G-ZX6UO="!K
M96QL(&UE9V%D;FEA+"!C<V%K(&$@<WKA;6IE9WEE:V5T+"!E<V5T;&5G(&5G
M>2`G*R<@:V%R86MT97)R96P@:V5Z9'9E+"!H82!N96UZ971K]GII('3A<F-S
MX7KA<VD@;?-D;W0@:^UVX6X@:&%S>F[A;&YI+@!%;&9O9V%D:&%T\R#I<G3I
M:V5T(&ME;&P@;65G861N:6$N`$$@1&%T851R964@86QR96YD<WIE<G0@8F4@
M:V5L;"#A;&SM=&%N:2!A(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%G;VL@
M:6?I;GELZ7/I:&5Z+@!!(%9&4R!A;')E;F1S>F5R(&YI;F-S(&)EX6QL[71V
M82X`16SU8F(@;&4@:V5L;"#M<FYI82P@:&]G>2!M:6QY96X@<')O8FSI;>%T
M('1A<&%S>G1A;'0L(&UI96SU='0@96QK_&QD:2!A(&AI8F%J96QE;G3I<W0N
M`$UE9R!K96QL(&%D;FD@96=Y(%523"UT+"!A:&]V82!E>B!A(&QI;FL@;75T
M870`2VD@:V5L;"!VX6QA<WIT86YI(&5G>2!T]G)L96YD]2!S>F5R=F5R="X`
M365G(&ME;&P@861N:6$L(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS(&%D871A
M:70@:^UVX6YJ82!T]G+V;&YI+@!-96<@:V5L;"!A9&YI82!A>B!E;'3A=F]L
M[71A;F3S(&9E;&AA<WINX6SS:2!N979E="X`365G(&ME;&P@861N:6$@82!H
M;WIZX6%D86YD\R!F96QH87-Z;N%L\R!N97;I="X`365G(&ME;&P@861N:6$L
M(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS(&%D871A:70@:^UVX6YJ82#A=.UR
M;FDN`$UE9R!K96QL(&%D;FEA(&5G>2!P87)A;F-S;W0N`$UE9R!K96QL(&%D
M;FEA(&%Z(/IJ(&MA=&5G\W)I82!N97;I="X`3VQA<WIO<G-ZX6=I('1E;&5F
M;VYS>N%M;W0@:V5L;"!M96=A9&YI80!!>B#6;B`E<R!K87!C<V]L871A(&ED
M]73Z;&SI<.ES(&UI871T(&UE9W-Z86MA9'0N($OI<F5M(&IE;&5N=&ME>GIE
M;B!B92#Z:G)A+@!!>B#6;B!E;6%I;"!C[6UE`$%Z(-9N(&9E;&%D\VD@*$9R
M;VTZ*2!C[6UE.@!3>F5MZ6QY97,@:6YF;W)MX6-I\P!!>B#6;B`E<R!K87!C
M<V]L873A;F%K(&ME>F1E=&4@\W1A(&UE9W;A;'1O>F]T="!A>B!I;G1E<FYE
M="!C[6UE+B!":7IT;VYSX6?A;F%K(.ER9&5KZ6)E;B!I<VWI="!B92!K96QL
M(&IE;&5N=&ME>FYI92X`07H@UFX@;F5V90!!>B#6;B!F96QH87-Z;N%L\V%Z
M;VYO<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@87H@^FH@
M9F5L:&%S>F[A;/-K(&SI=')E:&]ZX7/A="X@2&$@82!(;W)D92!R96YD<WIE
M<G)E;"!K[7;A;FIA(&ME>F5L;FD@82!F96QH87-Z;N%L\VD@861A=&]K870L
M(&%K:V]R(&WA<VEK(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z97)R
M92!V86X@<WK\:W/I9V4N`$%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73S(&%L
M<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A(&9E;&AA<WINX6SS:R!L
M:7-TX7KA<^%T+"!V86=Y('9A;&%M:2!O:V+S;"!L971I;'1O='3A:R!E>G0@
M82!L96AE=/5SZ6=E="X`07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;65G=N%L
M=&]Z;W1T(&%Z(-9N("5S(&UU;FMA:V%P8W-O;&%TX6YA:R!K97ID971E(/-T
M82X@0FEZ=&]N<^%G82#I<F1E:^EB96X@:7-MZ70@8F4@:V5L;"!J96QE;G1K
M97IN:64N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T:F$@
M97IT(&$@;&5H973U<^EG970N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE
M;2!TX6UO9V%T:F$@97IT(&$@;GEO;71A=.%S:2!O<&-I\W0N(%!R\V+A;&IO
M;B!A($-T<FPM4"`H=F%G>2!#;VUM86YD+5`I(&QE;GEO;>%SX79A;"!N>6]M
M=&%T;FDN`$$@:F5L96YL96<@Z7)VZ6YY97,@:63U>O-N83H`07H@UFX@86QA
M<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S:F$@;65G=N%L=&]Z;W1T
M+@!!>B#6;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/-J83H`
M07H@UFX@=&5L:F5S(&YE=F4Z`$QE:N%R="!A(&)E:F5L96YT:V5ZZ7-I(&IO
M9V]S=6QT<^%G82X`07H@UFX@)7,M<F4@:&%S>F[A;'0@^FH@:F5L<WIA=F$Z
M("5S`$%Z(-9N(/IJ(&)EX6QL[73A<V%I="#I<G;I;GEE<^UT971T_&L@82!M
M;W-T86YI(&)E:F5L96YT:V5ZZ7,@:61E:NER92X`07H@UFX@^FH@8F7A;&SM
M=.%S86ET(&5L;65N=&5T=/QK+@!!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T
M='5K`$%Z(-9N(&IE;'-Z87;A="#A=.%L;.UT;W1T=6LL(&[I>GIE(&UE9R!A
M(&QE=F5L96ET+"!M86ID(&IE;&5N=&ME>GIE;B!B92!A>B#Z:B!J96QS>O-V
M86PN`$%Z(-9N(&IE;'-Z87;A;F%K(&QE:N%R="!A>B#I<G;I;GEE<W/I9VD@
M:61E:F4N`$%Z(-9N(.%L=&%L(&AA<WINX6QT('3A=F]L:2!S>F5R=F5R96LZ
M`$IU9V]S>FSA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;3F4@;75T87-S
M=6L@82!B96EDZ7IE='0@<WKV=F5G971=`%M(:6)A:F5L96YTZ7-=`%M-=71A
M<W-U:R!A(&)E:63I>F5T="!S>O9V96=E="`M`%M-=71A<W-U:R!A(&)E:63I
M>F5T="!S>O9V96=E="`M("5S('-O<ET`6R5S+R5S('-O<ET`7T%D;6EN:7-Z
M='+A8VGS`%]087)A;F-S<V]R`%-O<G3V<FSI<P!?0W-O<&]R=&]K`%-E7V?M
M='/I9P!!(&OI<"!T=6QA:F1O;G/A9V%I+BXN`$)E:F5L96YT:V5ZZ7,`7TMI
M:F5L96YT:V5ZZ7,`02!L:6YK(&WS9&]S[73A<V$N+BX`7T]P8VGS:P!?2F]G
M;W-U;'1SX6=O:P!!(&QI;FL@=/9R;.ES92XN+@!?0F7A;&SM=.%S;VL`5.%B
M;.%Z870@='5L86ID;VYSX6=O:P!?1F5L:&%S>F[A;/-K`&/M;6IE9WEZZ6L`
M82!C[6UZ971T(&ES;65R971L96X`;F%P=.%R`&YY=6=O9'0`82!K:6UE;F5T
M:2#A;&QO;>%N>2!N96T@:&]Z:&%T\R!LZ71R90!A(&)E;65N]2#A;&QO;>%N
M>2!N96T@;GEI=&AA=/,@;65G`&MA='1I;G1S;VX@:61E`'!A<F%N8W-S;W)I
M(&AI8F$`:V]N9FEG=7+A8VGS<R!H:6)A`&AIX6YY>FEK(&5G>2!F;VYT;W,@
M<F5N9'-Z97+A;&QO;>%N>0!A9&%T9F]R;>%T=6T@:&EB80!M\V1O<^UTX7,`
M87H@861A="!N96T@=&%LX6QH873S`&-S]FMK96X`9N%J;``E<R`H)7,I(&ER
MX6YY8O-L+"`E<R`E<R!S96)E<W/I9V=E;`!S>NEL;/9KZ7-E:P!M.@!A(&?I
M<"!N979E(&YE;2!I<VUE<G0`87IO;FYA;&D`:6YP=70O;W5T<'5T(&AI8F$`
M8F5L<_4@<')O9W)A;6AI8F$`<V]R70!!>B!M:W-I;V9S('!R;V=R86T@)60@
M:&EB86OS9&1A;"!L9>%L;'0@87H@25-/(.%L;&]MX6YY(&OI<WKM=.ES92!K
M]GIB96XN`&[I=@!!('!R;V=R86UN86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@
M;65G=F%L\W/M='9A+@!!('!R;V=R86UN86L@97H@82!RZ7-Z92!MZ6<@;FEN
M8W,@;65G=F%L\W/M='9A+@!J96=Y>F5T=/9M8@!S>N%Z86SI:P!N:6YC<R!M
M96=F96QE;/4@:F]G;W-U;'1SX6=A`'!I>&5L`&%D873A='9I=&5L:2`H<')O
M=&]K;VQL*2!H:6)A`&5M96QK961I:P!A('-Z;VQGX6QT873A<R!N96T@X6QL
M(')E;F1E;&ME>NES<F4`;NEZ>OQK(&UE9R!A(&O\;/9N8G/I9V5K970`<VUS
M,F5M86EL('-Z;VQGX6QT873A<R!(5%10+6X@X70`=N%L=&]Z871L86X`<F5N
M9'-Z97)H:6)A`&9E;&%D871L:7-T80#A=&UE;F5T:2!H:6)A`&UE9V5R]7/M
M=.ES:^EN="!KZ71S>F5R(.UR:F$@8F4@82!J96QS>O-T`&[I=B!NZ6QK_&P`
M82!F96QH87-Z;N%L\R#A;'1A;"!VX6QA<WIT:&%T\P!V0V%R9`!S>CH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H=5](52]H96QP+GAM;```````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P-S8`,3`U,34T,S$P
M-C(`,#(P,S,V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y
M+3(B/SX*/"$M+2!(;W)D92`S+C$@:&5L<#H@:'5?2%4@)$AO<F1E.B!H;W)D
M92]L;V-A;&4O:'5?2%4O:&5L<"YX;6PL=B`Q+C(N,3`N,R`R,#`V+S`S+S`S
M(#$S.C0T.C$P(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S
M=6UM87)Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-CAC83,S9C=F,&,Y86%E
M-&,Q,#-E8C0W-#DR8V1C,34B/@H\=&ET;&4^02!S>F5MZ6QY97,@]G-S>F5G
M>O4@*'!O<G3A;"D@;VQD86P\+W1I=&QE/@H@/'!A<F$^"B`@17H@87H@;VQD
M86P@9WEO<G,@]G-S>F5G>NES="!A9"!A>B#6;B!S>N%MX7)A(&9O;G1O<R!I
M;F9O<FWA8VGS:W+S;"X*("!0;"X@:F5L97IH971I+"!H;V=Y(&CA;GD@^FH@
M;&5V96QE('9A;B!A>B!)3D)/6"!M87!PX6)A;BP@;6EL>65N(`H@(&5L9F]G
M;&%L='/A9V%I('9A;FYA:R!B9>UR=F$@82!K]GIE;&KV=O5B96X@82!N87!T
MX7)B86XL(&UI;'EE;@H@(&5L:6YTZ7IE;F3U(&1O;&=O:R!V86YN86L@82!F
M96QA9&%T;&ES=.%JX6)A;BP@9&4@;65G:F5L96[M=&AE=/4*("!E9WGI8B!K
M_&QS]2!S>F]L9^%L=&%TX7-O:R!T87)T86QM82!I<RP@<W1B+B!%>F5K8O5L
M(&%Z(/9S<WIE9WKI<V5K8O5L"B`@<V]K<WIO<B!K]GIV971L96[\;"!I;F3M
M=&AA=/-K(&$@9WEA:W)A;B!H87-Z;N%L="!F=6YK8VGS:RP@<&PN"B`@^FH@
M;&5VZ6P@[7+A<V$L(/IJ(&)E:F5G>7KI<R!KZ7-Z[73I<V4@82!N87!TX7)B
M82!V86=Y(&$@9F5L861A=&QI<W3A8F$L(`H@('-T8BX*("`\+W!A<F$^"B`\
M<&%R83X*("!%('-Z96WI;'EE<R#V<W-Z96=Z]2!O;&1A;"!T87)T86QMX70@
M82!497)V97KI<R!G;VUB8F%L(&WS9&]S[71H871J82X*("!-96=A9&AA=&IA
M('!L+BP@:&]G>2!M:6QY96X@:6YF;W)MX6-I\VMA="!K[7;A;B!M96=J96QE
M;NUT96YI+"#I<PH@(&UI;'EE;B!E;')E;F1E>NES8F5N+@H@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\=&ET
M;&4^07H@86QK86QM87KA<W;A;&%S>G3S(&UE;OP\+W1I=&QE/@H@/'!A<F$^
M"B`@02!W96)O;&1A;"!B86P@;VQD86SA;B!E9WD@86QK86QM87KA<W;A;&%S
M>G3S(&UE;OP@=&%LX6QH873S+@H@($$@;65G9F5L96SU(&9E;&ER871O:W)A
M(&MA='1I;G1V82!G>6]R<V%N(.ES(&OV;FYY96X@X71U9V]R:&%T(&5G>6EK
M"B`@86QK86QM87KA<V+S;"!A(&WA<VEK8F$N"B`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P
M=&]D871E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P
M(CX*("`@(#QT:71L93Y/<&-I\VLZ($)E:F5L96YT:V5ZZ7-S96P@:V%P8W-O
M;&%T;W,@9F5L861A=&]K.B!VZ6=R96AA:G3A<SPO=&ET;&4^"B`@("`\<&%R
M83X*("`@($AA(&%Z="!S>F5R971NZ2P@:&]G>2!B96IE;&5N=&ME>NES:V]R
M(&9U<W-A;F%K"B`@("!L92!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K+"!J
M96SV;&IE(&)E(&$@;NEG>7IE=&5T+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4]
M(G5P=&]D871E(B!M9#4](F$R,3$V,F-D9F8S8C%D.&9A96%D8C<R.38R-#`P
M,S9E(CX*("`@(#QT:71L93Y/<&-I\VLZ($)E:F5L96YT:V5ZZ7-S96P@:V%P
M8W-O;&%T;W,@9F5L861A=&]K.B!M96=E<O5S[73I<SPO=&ET;&4^"B`@("`\
M<&%R83X*("`@($AA(&%Z="!S>F5R971NZ2P@:&]G>2!A(')E;F1S>F5R(&UE
M9V5R]7/M=.ES="!KZ7)J96X@UFYT]6P@;6EE;/5T=`H@("`@=NEG<F5H86IT
M86[A(&$@:V%R8F%N=&%R=.%S:2!F96QA9&%T;VMA="P@:F5L]FQJ92!B92!E
M>G0@82!NZ6=Y>F5T970N"B`@("!(82!N96T@:F5L]FQI(&)E+"!A(&MA<F)A
M;G1A<G3A<VD@9F5L861A=&]K(&)E:F5L96YT:V5ZZ7-K;W(@875T;VUA=&EK
M=7-A;B`*("`@(&QE(&9O9VYA:R!F=71N:2P@86[I;&O\;"P@:&]G>2!B969O
M;'GA<V]L:&%T;N$@]6ME="X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]J85]*4"\`````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C(`,#$V-C,S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+VIA7TI0+TQ#7TU%4U-!1T53+P``````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,C`T,C``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:F%?2E`O3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S$P,3<W`#$P-3$U-#,Q
M,#8R`#`R,C`V-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````*D%```<````9"T``(T'``"L6@```````.!X```.
M````X7@```\```#P>```#0````!Y```(````#GD```L````7>0``#````"-Y
M```8````,'D``!L```!)>0``+0```&5Y```=````DWD``"0```"Q>0``*0``
M`-9Y```9`````'H``"8````:>@``#````$%Z```D````3GH```L```!S>@``
M#@```']Z```%````CGH``"@```"4>@``"````+UZ```*````QGH``!4```#1
M>@``$@```.=Z``"%````^GH```X```"`>P``"@```(][```-````FGL```X`
M``"H>P``$0```+=[```-````R7L```P```#7>P``#0```.1[```&````\GL`
M`)0```#Y>P``#````(Y\```.````FWP```X```"J?```"````+E\```)````
MPGP``"X```#,?```&@```/M\```R````%GT``#@```!)?0``5````()]``!1
M````UWT``%H````I?@``5P```(1^```T````W'X```4````1?P``$0```!=_
M```E````*7\``"````!/?P``$P```'!_```0````A'\```\```"5?P``"@``
M`*5_```#````L'\```\```"T?P``%````,1_```)````V7\```T```#C?P``
M$@```/%_```9````!(```!X````>@```#P```#V````*````38````\```!8
M@```"````&B````D````<8```!0```"6@```%@```*N````(````PH```$X`
M``#+@```+0```!J!```9````2($```<```!B@0``#````&J!```L````=X$`
M``X```"D@0```P```+.!```+````MX$```<```##@0``!P```,N!```%````
MTX$```H```#9@0```P```.2!```7````Z($```H`````@@``#P````N"```8
M````&X(``",````T@@``#@```%B"```4````9X(``!<```!\@@``%P```)2"
M```7````K((``!,```#$@@``#P```-B"```.````Z((``!\```#W@@``'0``
M`!>#```'````-8,```8````]@P``"````$2#```/````38,```8```!=@P``
M"@```&2#```3````;X,```L```"#@P``$````(^#```5````H(,``!4```"V
M@P``!P```,R#```0````U(,```4```#E@P``$0```.N#```,````_8,``#L`
M```*A```.````$:$```)````?X0```<```")A```!0```)&$```0````EX0`
M`!,```"HA```.0```+R$```G````]H0``"P````>A0``*@```$N%```E````
M=H4```H```"<A0``!@```*>%```)````KH4```<```"XA0``+P```,"%```W
M````\(4``"X````HA@``50```%>&```M````K88``"T```#;A@``/0````F'
M```_````1X<``"T```"'AP``0````+6'```C````]H<``",````:B```0```
M`#Z(```M````?X@``#,```"MB```)0```.&(```5````!XD``!D````=B0``
M*0```#>)```D````88D``"@```"&B0``$0```*^)```*````P8D```H```#,
MB0``$````->)```6````Z(D``!8```#_B0``!P```!:*```'````'HH```H`
M```FB@``"````#&*```G````.HH```@```!BB@``!P```&N*```'````<XH`
M``8```![B@``!0```(**```'````B(H```8```"0B@``"````)>*```I````
MH(H```X```#*B@``"@```-F*```$````Y(H```<```#IB@``"0```/&*```&
M````^XH``!$````"BP``!P```!2+```6````'(L```@````SBP``#0```#R+
M```&````2HL``!X```!1BP``$0```'"+```(````@HL```T```"+BP``#```
M`)F+```'````IHL```,```"NBP```P```+*+```7````MHL``!,```#.BP``
M'0```.*+```(`````(P```@````)C```"````!*,``!!````&XP``!H```!=
MC```*P```'B,```@````I(P``!4```#%C```!@```-N,```&````XHP``!4`
M``#IC```&````/^,```B````&(T``"X````[C0``'0```&J-```A````B(T`
M`%0```"JC0``*0```/^-```*````*8X```<````TC@``!P```#R.```5````
M1(X```X```!:C@``"@```&F.```/````=(X```T```"$C@``#P```)*.```-
M````HHX```D```"PC@``!@```+J.```8````P8X``!,```#:C@``$0```.Z.
M```4`````(\```0````5CP``!@```!J/```4````(8\``%0````VCP``9```
M`(N/```.````\(\```4```#_CP``!0````60```3````"Y```!$````?D```
M$0```#&0```<````0Y```!````!@D```(0```'&0```3````DY````L```"G
MD```$@```+.0```*````QI````\```#1D```$0```.&0```,````\Y```!<`
M````D0``$````!B1```(````*9$```4````RD0``#````#B1```0````19$`
M``4```!6D0``#0```%R1```&````:I$```<```!QD0``#0```'F1```'````
MAY$```L```"/D0``!P```)N1```'````HY$``!D```"KD0``/0```,61```=
M`````Y(```P````AD@``$````"Z2```%````/Y(``"4```!%D@``$@```&N2
M```3````?I(``"L```"2D@``.P```+Z2```@````^I(```@````;DP``-@``
M`"23```A````6Y,``!````!]DP``"````(Z3```,````EY,```0```"DDP``
M#P```*F3```.````N9,```H```#(DP``#0```-.3```?````X9,``!P````!
ME```(0```!Z4```>````0)0``!D```!?E```'@```'F4```;````F)0``"$`
M``"TE```+@```-:4```F````!94``!P````LE0``'@```$F5```<````:)4`
M`"8```"%E0``*P```*R5```S````V)4``"8````,E@``*P```#.6```X````
M7Y8``!T```"8E@``%0```+:6```O````S)8``"````#\E@``$@```!V7```I
M````,)<``!X```!:EP``(````'F7```2````FI<``*(```"MEP``%@```%"8
M```C````9Y@``"@```"+F```*0```+28```H````WI@``!\````'F0``%0``
M`">9```@````/9D``"4```!>F0``*````(29```M````K9D``#````#;F0``
MD@````R:```A````GYH``!8```#!F@``'````-B:```F````]9H``"H````<
MFP``00```$>;```'````B9L```8```"1FP``$````)B;```2````J9L``!,`
M``"\FP``$@```-";```'````XYL```0```#KFP``$````/";```,`````9P`
M``X````.G```#0```!V<```H````*YP```,```!4G```#0```%B<```&````
M9IP```X```!MG````@```'R<```%````?YP``!````"%G```#P```):<```$
M````IIP```T```"KG```#@```+F<```.````R)P```@```#7G```#P```."<
M```/````\)P```<`````G0``#0````B=```0````%IT```T````GG0``!@``
M`#6=```+````/)T```P```!(G0``"@```%6=```1````8)T```L```!RG0``
M#0```'Z=```B````C)T```\```"OG0``&P```+^=```T````VYT```H````0
MG@``&````!N>```2````-)X``!D```!'G@``%@```&&>```B````>)X```T`
M``";G@``!P```*F>```4````L9X```L```#&G@``(@```-*>```O````]9X`
M``L````EGP``%P```#&?```7````29\``!8```!AGP``#P```'B?```(````
MB)\```T```"1GP``)@```)^?``!#````QI\```@````*H```$@```!.@```?
M````)J````@```!&H```"P```$^@```O````6Z````8```"+H```!P```)*@
M```$````FJ````H```"?H```"@```*J@```/````M:```!````#%H```%P``
M`-:@```1````[J```!D`````H0``%P```!JA```%````,J$```L````XH0``
M!0```$2A```-````2J$``!L```!8H0``%P```'2A```.````C*$```T```";
MH0``$@```*FA```X````O*$``"````#UH0``#@```!:B``![````):(``!@`
M``"AH@``$0```+JB```'````S*(```4```#4H@``&````-JB```;````\Z(`
M`!D````/HP``&P```"FC```9````1:,``!,```!?HP``!P```'.C```(````
M>Z,```8```"$HP``$````(NC```/````G*,``!````"LHP``#P```+VC```+
M````S:,```\```#9HP``#````.FC```/````]J,```<````&I```!@````ZD
M```.````%:0```P````DI```#P```#&D```(````0:0```@```!*I```$P``
M`%.D```>````9Z0``"$```"&I```(````*BD```9````R:0``!<```#CI```
M)0```/ND```7````(:4``!8````YI0``&P```%"E```-````;*4```P```!Z
MI0```P```(>E```%````BZ4```@```"1I0``!````)JE```$````GZ4``!,`
M``"DI0``%````+BE```,````S:4```D```#:I0``#@```.2E```+````\Z4`
M`!L```#_I0``!P```!NF```'````(Z8```T````KI@``&````#FF```*````
M4J8``"8```!=I@``%0```(2F```%````FJ8```8```"@I@```@```*>F```&
M````JJ8```8```"QI@``%````+BF```-````S:8``!````#;I@``&P```.RF
M```0````"*<```D````9IP``"0```".G```%````+:<``!H````SIP``"```
M`$ZG```&````5Z<``!D```!>IP``#@```'BG```'````AZ<```<```"/IP``
M!0```)>G```)````G:<```H```"GIP``#@```+*G```+````P:<```T```#-
MIP``!@```-NG```)````XJ<```<```#LIP``%````/2G```=````":@``$(`
M```GJ```)0```&JH```E````D*@```8```"VJ```"@```+VH```$````R*@`
M``D```#-J```"````->H```1````X*@```D```#RJ```!@```/RH```-````
M`ZD```8````1J0``'@```!BI```%````-ZD```X````]J0``!@```$RI```'
M````4ZD``"$```!;J0``!@```'VI```$````A*D```H```")J0``!0```)2I
M```=````FJD```0```"XJ0``#````+VI```.````RJD```H```#9J0``"```
M`.2I```)````[:D```4```#WJ0``.@```/VI```P````.*H``#4```!IJ@``
M*0```)^J``!'````R:H``#@````1JP``*0```$JK```_````=*L``"X```"T
MJP``+0```..K```?````$:P```\````QK```*0```$&L```D````:ZP``"8`
M``"0K```!P```+>L```@````OZP``"````#@K```)@````&M```*````**T`
M`!D````SK0``*0```$VM```6````=ZT```<```".K0``"@```):M```,````
MH:T```\```"NK0``$````+ZM``!`````SZT``'`````0K@``#@```(&N```)
M````D*X```H```":K@``!@```*6N```/````K*X``!(```"\K@``$````,^N
M```<````X*X``",```#]K@``:@```"&O```/````C*\```4```"<KP``$```
M`**O```)````LZ\```0```"]KP``"P```,*O```4````SJ\```P```#CKP``
M#````/"O```/````_:\``!4````-L```*0```".P```J````3;```"8```!X
ML```)P```)^P```I````Q[```"H```#QL```&0```!RQ``!"````-K$``!$`
M``!YL0``$@```(NQ```3````GK$``!0```"RL0``#P```,>Q```6````U[$`
M`!<```#NL0``$`````:R```1````%[(``#0````IL@``$P```%ZR```2````
M<K(``#4```"%L@``%````+NR```0````T+(``!0```#AL@``%P```/:R```<
M````#K,``!0````KLP``&@```$"S```:````6[,``!,```!VLP``%0```(JS
M```1````H+,``!<```"RLP``%````,JS```7````W[,``!4```#WLP``$```
M``VT```9````'K0```0````XM```!P```#VT```+````1;0```8```!1M```
M!@```%BT```&````7[0```4```!FM```!P```&RT```'````=+0```4```!\
MM```!@```(*T```&````B;0```0```"0M```!````)6T```'````FK0```X`
M``"BM```#````+&T```,````OK0```T```#+M```"@```-FT```.````Y+0`
M``4```#SM```*````/FT```,````(K4```\````OM0``"@```#^U```(````
M2K4``"L```!3M0``"````'^U```F````B+4``!(```"OM0``!@```,*U```*
M````R;4```<```#4M0``"````-RU```@````Y;4```P````&M@``#@```!.V
M```6````(K8``!$````YM@``!@```$NV```&````4K8```<```!9M@``!```
M`&&V```'````9K8```<```!NM@``%@```':V```-````C;8```0```";M@``
M.@```*"V```.````V[8``!````#JM@``"P```/NV```;````![<``!@````C
MMP``&@```#RW```)````5[<```H```!AMP``#````&RW```/````>;<```@`
M``")MP``!@```)*W```'````F;<```4```"AMP``"P```*>W``!'````L[<`
M``T```#[MP``$P````FX```3````';@``!,````QN```"@```$6X```"````
M4+@``"4```!3N```!0```'FX```J````?[@```H```"JN```!````+6X```&
M````NK@```@```#!N```"````,JX```$````T[@```4```#8N```:````-ZX
M```%````1[D``!````!-N0``"@```%ZY```/````:;D```H```!YN0``"0``
M`(2Y```#````CKD```<```"2N0``!P```)JY```*````HKD```L```"MN0``
M!P```+FY``!1````P;D```8````3N@``&@```!JZ```&````-;H``!\````\
MN@``"0```%RZ```B````9KH``%<```")N@``$P```.&Z```C````];H``!,`
M```9NP```@```"V[```+````,+L```T````\NP``%````$J[```&````7[L`
M``@```!FNP``!P```&^[```*````=[L```L```""NP``!P```(Z[```)````
MEKL```D```"@NP``"@```*J[```'````M;L```D```"]NP``!P```,>[```*
M````S[L```H```#:NP``%@```.6[```'````_+L``!(````$O```!````!>\
M```'````'+P```4````DO```!0```"J\```+````,+P``!0````\O```!P``
M`%&\```%````6;P```T```!?O```#````&V\```(````>KP``!<```"#O```
M"P```)N\```,````I[P``!\```"TO```&@```-2\```$````[[P```H```#T
MO```!````/^\```,````!+T```4````1O0``"0```!>]```%````(;T```<`
M```GO0``!````"^]```X````-+T```H```!MO0``+````'B]```N````I;T`
M`#,```#4O0``,P````B^```X````/+X```\```!UO@``&````(6^```0````
MGKX```\```"OO@``%0```+^^```4````U;X``!(```#JO@``%````/V^```M
M````$K\``"T```!`OP``,0```&Z_```N````H+\``"\```#/OP``+````/^_
M``!B````+,```!,```"/P```#0```*/````7````L<````P```#)P```(0``
M`-;````:````^,````D````3P0``10```!W!``!!````8\$```0```"EP0``
M#@```*K!```3````N<$``!@```#-P0``!@```.;!```)````[<$```H```#W
MP0``#P````+"```0````$L(```X````CP@``!0```#+"```(````.,(```8`
M``!!P@``%````$C"```1````7<(```X```!OP@``.````'["```"````M\(`
M``8```"ZP@``#@```,'"```'````T,(```8```#8P@``#````-_"```<````
M[,(```0````)PP``*0````[#```?````.,,``%P```!8PP``%````+7#```^
M````RL,```<````)Q```#@```!'$```,````(,0```P````MQ```$P```#K$
M```*````3L0``!T```!9Q```$0```'?$```1````B<0``"0```";Q```%0``
M`,#$```2````UL0```X```#IQ```&0```/C$```(````$L4```D````;Q0``
M&@```"7%```'````0,4```@```!(Q0``!0```%'%```?````5\4```8```!W
MQ0``$````'[%```(````C\4```@```"8Q0``'@```*'%```2````P,4``"P`
M``#3Q0``&@````#&```)````&\8```H````EQ@``%0```##&```%````1L8`
M`!0```!,Q@``!````&'&```0````9L8```<```!WQ@``'@```'_&```H````
MGL8```H```#'Q@``'````-+&```1````[\8```L````!QP``&@````W'```4
M````*,<```0````]QP``"P```$+'```%````3L<```@```!4QP``!@```%W'
M```@````9,<``"D```"%QP``00```*_'```H````\<<``"D````:R```4```
M`$3(```&````E<@```4```"<R```"````*+(```N````J\@``#0```#:R```
M!P````_)```A````%\D``!`````YR0``#@```$K)```+````6<D```<```!E
MR0``$P```&W)```*````@<D``!0```",R0``#P```*')```R````L<D```L`
M``#DR0``#@```/#)```%````_\D```4````%R@``!0````O*```7````$<H`
M``4````IR@``!````"_*```R````-,H``$4```!GR@``%P```*W*```>````
MQ<H``!0```#DR@``!@```/G*```.`````,L``"H````/RP``!@```#K+```,
M````0<L``!$```!.RP``"P```&#+```V````;,L```H```"CRP``(@```*[+
M```+````T<L```\```#=RP``,@```.W+```P````(,P``#$```!1S```+0``
M`(/,```%````L<P```X```"WS```$P```,;,```'````VLP``!$```#BS```
M$P```/3,```4````",T``!@````=S0``!0```#;-```$````/,T```<```!!
MS0``"@```$G-```+````5,T```P```!@S0``#@```&W-```.````?,T```4`
M``"+S0``!0```)'-```N````E\T``"8```#&S0``(P```.W-```#````$<X`
M`!(````5S@``!@```"C.```>````+\X``!@```!.S@``)0```&?.```)````
MC<X```,```"7S@``!P```)O.```"````H\X```P```"FS@``%0```+/.```+
M````R<X``!D```#5S@``(````._.```%````$,\```H````6SP``%0```"'/
M```,````-\\```0```!$SP``"0```$G/```'````4\\```P```!;SP``4@``
M`&C/```7````N\\``"0```#3SP``!@```/C/```.````_\\```P````.T```
M#0```!O0```5````*=```!(````_T```#P```%+0```4````8M````H```!W
MT```:0```(+0```:````[-```!<````'T0``)P```!_1```:````1]$``!<`
M``!BT0``&P```'K1```9````EM$``!\```"PT0``$P```-#1```(````Y-$`
M``<```#MT0``"0```/71```5````_]$```T````5T@``#0```"/2```(````
M,=(``$8````ZT@``/P```('2```W````P=(``%<```#YT@``!0```%'3```?
M````5],```H```!WTP``#0```(+3```M````D-,```0```"^TP``3P```,/3
M```E````$]0``!\````YU```'0```%G4```E````=]0``"````"=U```)```
M`+[4```@````X]0```8````$U0``.0````O5```,````1=4```<```!2U0``
M"0```%K5```3````9-4```D```!XU0``!````(+5```0````A]4```@```"8
MU0``"````*'5```/````JM4```<```"ZU0``%````,+5```.````U]4```P`
M``#FU0``+````//5```3````(-8``!P````TU@``*````%'6```'````>M8`
M`!,```""U@``!0```);6```7````G-8```H```"TU@``#````+_6```)````
MS-8```D```#6U@``$0```.#6```&````\M8```X```#YU@``#0````C7```+
M````%M<```(````BUP``'````"77```&````0M<```D```!)UP``!P```%/7
M```F````6]<``#@```""UP``&@```+O7```J````UM<``#L````!V```*```
M`#W8```T````9M@``!D```";V```%0```+78```%````R]@```<```#1V```
M"````-G8```'````XM@```X```#JV```"0```/G8```&`````]D```@````*
MV0``"P```!/9```'````']D```@````GV0``!P```##9```6````.-D```D`
M``!/V0``!@```%G9```+````8-D``!0```!LV0``"````('9```0````BMD`
M`!````";V0``!@```*S9```9````L]D```H```#-V0``'````-C9```%````
M]=D``!````#[V0``&`````S:```7````)=H```D````]V@``"@```$?:```'
M````4MH```(```!:V@``"````%W:```C````9MH``!\```"*V@``,0```*K:
M```G````W-H``&0````$VP``50```&G;```X````O]L``$H```#XVP``6P``
M`$/<```H````G]P``#@```#(W```*`````'=```L````*MT``"8```!7W0``
M&P```'[=```^````FMT``*D!``#9W0``(P```(/?``!(````I]\``"4```#P
MWP``00```!;@``!;````6.```$D```"TX```,0```/[@```K````,.$``"$`
M``!<X0``'P```'[A```F````GN$``"<```#%X0``,P```.WA```E````(>(`
M`"````!'X@``'P```&CB```P````B.(``&D```"YX@``,0```"/C``!!````
M5>,``#,```"7XP``)0```,OC```]````\>,``&4````OY```30```)7D```O
M````X^0``"X````3Y0``,````$+E``!4````<^4``%H```#(Y0``2````"/F
M``!*````;.8``#(```"WY@``+P```.KF```L````&N<``"T```!'YP``%P``
M`'7G```E````C><``#(```"SYP``*0```.;G```^````$.@``"(```!/Z```
M4@```'+H```E````Q>@``$4```#KZ```(0```#'I```P````4^D``"4```"$
MZ0``'````*KI```Q````Q^D```0```#YZ0``#0```/[I```+````#.H```L`
M```8Z@``!0```"3J``!9````*NH``!(```"$Z@``!````)?J```'````G.H`
M``4```"DZ@``,````*KJ```3````V^H```(```#OZ@``!P```/+J```&````
M^NH```P````!ZP``&`````[K```&````)^L``!(````NZP```P```$'K```&
M````1>L```<```!,ZP``'P```%3K```N````=.L``"\```"CZP``%P```-/K
M```B````Z^L``"4````.[```(````#3L```;````5>P``!@```!Q[```)```
M`(KL```?````K^P``!H```#/[```(0```.KL```@````#.T``!H````M[0``
M,@```$CM```:````>^T``"\```"6[0``*P```,;M```?````\NT``",````2
M[@``'P```#;N```:````5NX``"$```!Q[@``)0```)/N```F````N>X``"4`
M``#@[@``)`````;O```8````*^\``!T```!$[P``)````&+O```8````A^\`
M`"(```"@[P``+````,/O```O````\.\``!4````@\```)0```#;P```\````
M7/```!\```"9\```(P```+GP```?````W?```"````#]\```&@```![Q```F
M````.?$``!X```!@\0``*0```'_Q```>````J?$``#$```#(\0``"0```/KQ
M```,````!/(``!<````1\@``+P```"GR```D````6?(```<```!^\@``%```
M`(;R```.````F_(```T```"J\@``)````+CR```'````W?(``!T```#E\@``
M!P````/S``#'````"_,``!4```#3\P``!@```.GS```)````\/,```L```#Z
M\P``#0````;T```7````%/0```8````L]```,P```#/T```3````9_0``!,`
M``![]```!P```(_T```/````E_0```<```"G]```,@```*_T```$````XO0`
M`"$```#G]```$P````GU```,````'?4``!$````J]0``,@```#SU```6````
M;_4```@```"&]0``'0```(_U```)````K?4```H```"W]0``%````,+U```*
M````U_4```@```#B]0``"````.OU```'````]/4```D```#\]0``/P````;V
M```'````1O8```\```!.]@``#@```%[V```(````;?8```<```!V]@``&0``
M`'[V```7````F/8``!0```"P]@``$0```,7V```'````U_8```(```#?]@``
M!@```.+V```'````Z?8```T```#Q]@``"P```/_V```.````"_<``"\````:
M]P``(````$KW```<````:_<``#$```"(]P``!0```+KW```_````P/<``!(`
M````^```"@```!/X```&````'O@```@````E^```#````"[X```*````._@`
M`#D```!&^```+@```(#X```I````K_@``!@```#9^```&0```/+X```?````
M#/D``!T````L^0``$0```$KY```"````7/D```0```!?^0``!@```&3Y```%
M````:_D```,```!Q^0``#````'7Y``!%````@OD``#(```#(^0``&@```/OY
M```T````%OH``"@```!+^@``4P```'3Z```9````R/H``'(```#B^@``(```
M`%7[```U````=OL``"$```"L^P``10```,[[```P````%/P``"@```!%_```
M*0```&[\```F````F/P``"4```"__```*````.7\```H````#OT``"(````W
M_0``,````%K]```2````B_T``!,```">_0``$````++]``!Y````P_T```D`
M```]_@``H0```$?^``!S````Z?X``'P```!=_P``*P```-K_``!4````!@`!
M`!<```!;``$`)P```',``0`6````FP`!``\```"R``$`%P```,(``0`?````
MV@`!`$````#Z``$`'P```#L!`0`<````6P$!`%$```!X`0$`&@```,H!`0`4
M````Y0$!``H```#Z`0$`!0````4"`0`&````"P(!``@````2`@$`$````!L"
M`0`/````+`(!``\````\`@$`"P```$P"`0`'````6`(!``4```!@`@$`%```
M`&8"`0`'````>P(!``@```"#`@$`#P```(P"`0`(````G`(!``P```"E`@$`
M#P```+("`0`&````P@(!`!0```#)`@$`!@```-X"`0`,````Y0(!`!$```#R
M`@$`"`````0#`0`9````#0,!`!$````G`P$`"@```#D#`0`8````1`,!`!,`
M``!=`P$`'````'$#`0`1````C@,!``0```"@`P$`#P```*4#`0`$````M0,!
M`!$```"Z`P$`$@```,P#`0`7````WP,!``0```#W`P$`#P```/P#`0`3````
M#`0!``<````@!`$`!P```"@$`0`1````,`0!``8```!"!`$`&````$D$`0`3
M````8@0!`!````!V!`$`#````(<$`0`)````E`0!`!$```">!`$`(@```+`$
M`0`'````TP0!``4```#;!`$`.@$``.$$`0`*````'`8!``\````G!@$`#P``
M`#<&`0`'````1P8!``@```!/!@$`!P```%@&`0`E````8`8!`"$```"&!@$`
M+0```*@&`0`E````U@8!`"D```#\!@$`*@```"8'`0`@````40<!`"H```!R
M!P$`"P```)T'`0`@````J0<!``D```#*!P$`"P```-0'`0`%````X`<!`!$`
M``#F!P$`"0```/@'`0`/`````@@!``L````2"`$`%0```!X(`0!K````-`@!
M``T```"@"`$`!0```*X(`0`1````M`@!`!,```#&"`$`#P```-H(`0`+````
MZ@@!``L```#V"`$`$0````()`0`&````%`D!`)(````;"0$`"@```*X)`0`*
M````N0D!``H```#$"0$`!P```,\)`0`+````UPD!`"@```#C"0$`'`````P*
M`0`I````*0H!`#$```!3"@$`2@```(4*`0!$````T`H!`%`````5"P$`2@``
M`&8+`0`L````L0L!``4```#>"P$`%@```.0+`0`O````^PL!`"L````K#`$`
M#@```%<,`0`6````9@P!`!X```!]#`$`"@```)P,`0`$````IPP!`!(```"L
M#`$`%````+\,`0`+````U`P!`!0```#@#`$`&````/4,`0`:````#@T!`!P`
M```I#0$`$@```$8-`0`(````60T!`!(```!B#0$`"@```'4-`0`L````@`T!
M`!$```"M#0$`%@```+\-`0`,````U@T!`$X```#C#0$`-@```#(.`0`F````
M:0X!``0```"0#@$`"@```)4.`0`=````H`X!``0```"^#@$``P```,,.`0`.
M````QPX!``H```#6#@$`#````.$.`0`$````[@X!``H```#S#@$`!````/X.
M`0`,`````P\!``X````0#P$`$````!\/`0`4````,`\!`"H```!%#P$`#@``
M`'`/`0`4````?P\!`!8```"4#P$`%````*L/`0`4````P`\!`!(```#5#P$`
M#@```.@/`0`0````]P\!`!H````($`$`'@```",0`0`(````0A`!``X```!+
M$`$`"@```%H0`0`.````91`!``0```!T$`$`#````'D0`0`8````AA`!`!``
M``"?$`$`%````+`0`0`6````Q1`!`!````#<$`$`!````.T0`0`0````\A`!
M``0````#$0$`&`````@1`0`,````(1$!`#$````N$0$`,P```&`1`0`2````
ME!$!`!````"G$0$`!@```+@1`0`.````OQ$!`!(```#.$0$`+@```.$1`0`J
M````$!(!`"P````[$@$`+````&@2`0`F````E1(!``0```"\$@$`!````,$2
M`0`.````QA(!`!(```#5$@$`,0```.@2`0`V````&A,!`"X```!1$P$`:@``
M`(`3`0`I````ZQ,!`"D````5%`$`0@```#\4`0!"````@A0!`"D```#%%`$`
M-0```.\4`0`E````)14!`"4```!+%0$`0@```'$5`0`I````M!4!`"\```#>
M%0$`(@````X6`0`2````,18!`!8```!$%@$`*````%L6`0`?````A!8!`!\`
M``"D%@$`%@```,06`0`6````VQ8!``0```#R%@$`!@```/<6`0`@````_A8!
M`!X````?%P$`!@```#X7`0`*````11<!`!@```!0%P$`"@```&D7`0`T````
M=!<!``8```"I%P$`$````+`7`0`(````P1<!``@```#*%P$`#````-,7`0`2
M````X!<!``P```#S%P$`!@`````8`0`T````!Q@!``P````\&`$`#@```$D8
M`0`$````6!@!``X```!=&`$`#````&P8`0`"````>1@!``H```!\&`$``@``
M`(<8`0`8````BA@!``X```"C&`$`"````+(8`0`(````NQ@!``X```#$&`$`
M%@```-,8`0`*````ZA@!``@```#U&`$`#@```/X8`0`.````#1D!``,````<
M&0$``P```"`9`0`0````)!D!``T````U&0$`*````$,9`0`&````;!D!``H`
M``!S&0$`$````'X9`0!`````CQD!`!P```#0&0$`+````.T9`0`E````&AH!
M`!P```!`&@$`!@```%T:`0`*````9!H!`!@```!O&@$`(````(@:`0`B````
MJ1H!`"\```#,&@$`)@```/P:`0`F````(QL!`$@```!*&P$`,@```),;`0`2
M````QAL!``0```#9&P$`"````-X;`0`,````YQL!``P```#T&P$`"`````$<
M`0`(````"AP!``H````3'`$`"````!X<`0`*````)QP!``@````R'`$`!```
M`#L<`0`2````0!P!``P```!3'`$`#@```&`<`0`.````;QP!``P```!^'`$`
M!````(L<`0`0````D!P!`#````"A'`$`3@```-(<`0`5````(1T!``H````W
M'0$`#@```$(=`0`6````41T!`!````!H'0$`#@```'D=`0`.````B!T!``P`
M``"7'0$`(````*0=`0`9````Q1T!``@```#?'0$`$````.@=`0`*````^1T!
M`!`````$'@$`$@```!4>`0`2````*!X!``H````['@$`$````$8>`0`0````
M5QX!``(```!H'@$`!@```&L>`0`&````<AX!``0```!Y'@$`"@```'X>`0`*
M````B1X!``@```"4'@$`#@```)T>`0`(````K!X!``8```"U'@$`"@```+P>
M`0`$````QQX!``H```#,'@$`,@```-<>`0`8````"A\!``T````C'P$`$```
M`#$?`0`,````0A\!`!````!/'P$`"@```&`?`0`*````:Q\!`"8```!V'P$`
M,P```)T?`0`A````T1\!``8```#S'P$`)````/H?`0`@````'R`!``L```!`
M(`$`!````$P@`0`*````42`!``8```!<(`$`#@```&,@`0`0````<B`!`!``
M``"#(`$`%@```)0@`0`K````JR`!`"D```#7(`$`+@````$A`0`L````,"$!
M`"````!=(0$`)P```'XA`0`>````IB$!`",```#%(0$`+````.DA`0`F````
M%B(!`"4````](@$`*0```&,B`0`@````C2(!`"8```"N(@$`,@```-4B`0`R
M````"",!`"H````[(P$`+````&8C`0`L````DR,!`"P```#`(P$`&P```.TC
M`0`J````"20!`"T````T)`$`'P```&(D`0`J````@B0!`"@```"M)`$`'0``
M`-8D`0`5````]"0!`(P````*)0$`&@```)<E`0`D````LB4!`"8```#7)0$`
M)@```/XE`0`F````)28!`!P```!,)@$`)0```&DF`0`?````CR8!`"H```"O
M)@$`+````-HF`0`T````!R<!`#8````\)P$`?0```',G`0`=````\2<!`"4`
M```/*`$`(````#4H`0`F````5B@!`!\```!]*`$`0````)TH`0`"````WB@!
M``0```#A*`$`"````.8H`0`2````[R@!`!(````"*0$`%````!4I`0`0````
M*BD!``X````[*0$`$````$HI`0`*````6RD!``T```!F*0$`#@```'0I`0`O
M````@RD!``@```"S*0$`$@```+PI`0`.````SRD!``P```#>*0$``@```.LI
M`0`$````[BD!``T```#S*0$`$`````$J`0`$````$BH!``H````7*@$`"```
M`"(J`0`*````*RH!``0````V*@$`!@```#LJ`0`,````0BH!``H```!/*@$`
M#````%HJ`0`-````9RH!`!````!U*@$`!````(8J`0`(````BRH!``X```"4
M*@$`"@```*,J`0`0````KBH!``@```"_*@$`"````,@J`0`6````T2H!`!``
M``#H*@$`%P```/DJ`0`Y````$2L!``@```!+*P$`$````%0K`0`2````92L!
M`!(```!X*P$`$@```(LK`0`J````GBL!``@```#)*P$`"@```-(K`0`.````
MW2L!``0```#L*P$`(P```/$K`0`D````%2P!``0````Z+`$`"@```#\L`0`*
M````2BP!``H```!5+`$`#@```&`L`0`,````;RP!``H```!\+`$`+@```(<L
M`0!&````MBP!``@```#]+`$`#@````8M`0`B````%2T!``P````X+0$`$0``
M`$4M`0`Y````5RT!``H```"1+0$`$````)PM`0`$````K2T!``X```"R+0$`
M#@```,$M`0`0````T"T!`!````#A+0$`%0```/(M`0`2````""X!`!<````;
M+@$`%0```#,N`0`6````22X!`!0```!@+@$`"@```'4N`0`/````@"X!`"L`
M``"0+@$`$P```+PN`0`2````T"X!`!0```#C+@$`"@```/@N`0`N`````R\!
M`"0````R+P$`%@```%<O`0!:````;B\!``\```#)+P$`$````-DO`0`*````
MZB\!``8```#U+P$`%P```/PO`0`9````%#`!`!,````N,`$`&0```$(P`0`<
M````7#`!`!L```!Y,`$`$````)4P`0`*````IC`!``H```"Q,`$`!@```+PP
M`0`%````PS`!``8```#),`$`!0```-`P`0`*````UC`!``8```#A,`$`!0``
M`.@P`0`*````[C`!``0```#Y,`$`!````/XP`0`0`````S$!``H````4,0$`
M"````!\Q`0`$````*#$!``8````M,0$`'0```#0Q`0`D````4C$!`",```!W
M,0$`(@```)LQ`0`A````OC$!`!\```#@,0$`(``````R`0`=````(3(!`!8`
M```_,@$`)````%8R`0`,````>S(!``X```"(,@$``P```)<R`0`#````FS(!
M``0```"?,@$`$@```*0R`0`(````MS(!`!<```#`,@$`%P```-@R`0`2````
M\#(!``H````#,P$`#`````XS`0`4````&S,!`"X````P,P$`"````%\S`0`2
M````:#,!``@```![,P$`&@```(0S`0`&````GS,!`!X```"F,P$`(@```,4S
M`0`(````Z#,!``H```#Q,P$``@```/PS`0`"````_S,!``X````"-`$`$```
M`!$T`0`0````(C0!`!0````S-`$`$@```$@T`0`*````6S0!``0```!F-`$`
M!````&LT`0`,````<#0!`!@```!]-`$`#````)8T`0`.````HS0!`!4```"R
M-`$`$````,@T`0`.````V30!`!````#H-`$`#````/DT`0`,````!C4!``(`
M```3-0$`#@```!8U`0`-````)34!``L````S-0$`#@```#\U`0`.````3C4!
M``@```!=-0$`#````&8U`0`<````<S4!`#@```"0-0$`*````,DU`0`H````
M\C4!``@````;-@$`#@```"0V`0`(````,S8!`!`````\-@$`#````$TV`0`0
M````6C8!``P```!K-@$`#````'@V`0`2````A38!`!(```"8-@$`&P```*LV
M`0`,````QS8!`!0```#4-@$`!@```.DV`0`&````\#8!`!@```#W-@$`!```
M`!`W`0`&````%3<!``0````<-P$`!@```"$W`0`<````*#<!``8```!%-P$`
M"@```$PW`0`4````5S<!``X```!L-P$`$@```'LW`0`$````CC<!``4```"3
M-P$`0@```)DW`0`]````W#<!`#T````:.`$`)0```%@X`0`I````?C@!`#H`
M``"H.`$`*0```.,X`0`K````#3D!`"D````Y.0$`'P```&,Y`0`B````@SD!
M``8```"F.0$`&@```*TY`0`B````R#D!`!H```#K.0$`$`````8Z`0`K````
M%SH!`"L```!#.@$`,P```&\Z`0`+````HSH!`!D```"O.@$`,@```,DZ`0`0
M````_#H!`!(````-.P$`#````"`[`0`-````+3L!`!(````[.P$`"````$X[
M`0!%````5SL!`%D```"=.P$`#@```/<[`0`(````!CP!``D````//`$`!```
M`!D\`0`7````'CP!`!\````V/`$`'````%8\`0`L````<SP!`"@```"@/`$`
M5````,D\`0`,````'CT!``8````K/0$`"@```#(]`0`2````/3T!``0```!0
M/0$`$@```%4]`0`0````:#T!``H```!Y/0$`"````(0]`0`,````C3T!``X`
M``":/0$`&````*D]`0`6````PCT!`!@```#9/0$`%@```/(]`0`:````"3X!
M`!@````D/@$`%@```#T^`0`P````5#X!`!````"%/@$`#@```)8^`0`.````
MI3X!``X```"T/@$`$````,,^`0`0````U#X!``X```#E/@$`#@```/0^`0`,
M`````S\!`!X````0/P$`$````"\_`0`2````0#\!`"@```!3/P$`$````'P_
M`0`7````C3\!`!P```"E/P$`'0```,(_`0`<````X#\!`!H```#]/P$`'```
M`!A``0`<````-4`!`!@```!20`$`%@```&M``0`6````@D`!`!8```"90`$`
M%@```+!``0`:````QT`!`!D```#B0`$`"@```/Q``0`6````!T$!``P````>
M00$`#````"M!`0`&````.$$!``H````_00$`!@```$I!`0`$````44$!``X`
M``!600$`"@```&5!`0`$````<$$!``0```!U00$`#````'I!`0`(````AT$!
M``0```"000$`!````)5!`0`&````FD$!``@```"A00$`"````*I!`0`&````
MLT$!``8```"Z00$`$@```,%!`0`2````U$$!``P```#G00$`(P```/1!`0`(
M````&$(!``8````A0@$`!````"A"`0`&````+4(!`"@````T0@$`#@```%U"
M`0`6````;$(!``@```"#0@$`"@```(Q"`0`.````ET(!``P```"F0@$`!```
M`+-"`0`4````N$(!``@```#-0@$`$@```-9"`0`>````Z4(!`!0````(0P$`
M#@```!U#`0`$````+$,!``X````Q0P$``@```$!#`0`*````0T,!``X```!.
M0P$`+````%U#`0`6````BD,!``8```"A0P$`*````*A#`0`0````T4,!`!0`
M``#B0P$`"````/=#`0`>`````$0!`!H````?1`$`)````#I$`0`0````7T0!
M``L```!P1`$`"@```'Q$`0`*````AT0!``0```"21`$`"````)=$`0`*````
MH$0!``@```"K1`$`#P```+1$`0`^````Q$0!`!@````#10$`%@```!Q%`0`4
M````,T4!`!0```!(10$`%````%U%`0`"````<D4!`"T```!U10$`!@```*-%
M`0`@````JD4!`!(```#+10$`"@```-Y%`0`.````Z44!``H```#X10$`$```
M``-&`0`*````%$8!``P````?1@$`,````"Q&`0`$````748!`!0```!B1@$`
M#@```'=&`0`<````AD8!`!P```"C1@$`$@```,!&`0`$````TT8!``P```#8
M1@$`!@```.5&`0`.````[$8!``@```#[1@$`!`````1'`0!"````"4<!``@`
M``!,1P$`(````%5'`0`.````=D<!`!````"%1P$`"0```)9'`0`Q````H$<!
M`%@```#21P$`(````"M(`0`I````3$@!`"````!V2`$``@```)=(`0`*````
MFD@!``8```"E2`$`#@```*Q(`0`*````NT@!``@```#&2`$`!````,](`0`.
M````U$@!``0```#C2`$`#````.A(`0`$````]4@!``0```#Z2`$`!````/](
M`0`$````!$D!``0````)20$`!`````Y)`0`2````$TD!``H````F20$`#@``
M`#%)`0`.````0$D!``P```!/20$`!````%Q)`0`.````84D!``P```!P20$`
M#````'U)`0`,````BDD!`!@```"720$`#````+!)`0`$````O4D!`!H```#"
M20$`"````-U)`0`$````YDD!`!0```#K20$`$`````!*`0`0````$4H!`"P`
M```B2@$`(````$]*`0`(````<$H!`!````!Y2@$``@```(I*`0`.````C4H!
M``L```"<2@$`$````*A*`0`0````N4H!`!8```#*2@$`"````.%*`0`F````
MZDH!``H````12P$`,@```!Q+`0`C````3TL!`"@```!S2P$`*````)Q+`0`L
M````Q4L!`!(```#R2P$`'`````5,`0`D````(DP!`!8```!'3`$`&@```%Y,
M`0`@````>4P!`!H```":3`$`&@```+5,`0`C````T$P!`",```#T3`$`)P``
M`!A-`0`G````0$T!`"4```!H30$`*````(Y-`0!=````MTT!`!@````53@$`
M'@```"Y.`0`@````34X!`!````!N3@$`*@```'].`0`;````JDX!``8```#&
M3@$`1@```,U.`0!&````%$\!``0```!;3P$`#@```&!/`0`&````;T\!``X`
M``!V3P$`#@```(5/`0`*````E$\!``H```"?3P$`&@```*I/`0`4````Q4\!
M`!@```#:3P$`!````/-/`0`$````^$\!``(```#]3P$`!@````!0`0`$````
M!U`!``0````,4`$`-````!%0`0`"````1E`!``P```!)4`$`$@```%90`0`$
M````:5`!``@```!N4`$`#@```'=0`0`@````AE`!``@```"G4`$`,@```+!0
M`0`I````XU`!`$(````-40$`%````%!1`0!)````95$!``H```"O40$`#0``
M`+I1`0`.````R%$!``0```#740$`!````-Q1`0`$````X5$!`"````#F40$`
M%@````=2`0`2````'E(!`!H````Q4@$`#````$Q2`0`*````65(!``H```!D
M4@$`%P```&]2`0`)````AU(!``D```"14@$`&@```)M2`0`$````ME(!`!H`
M``"[4@$`#````-92`0`0````XU(!``P```#T4@$`&`````%3`0`0````&E,!
M``H````K4P$`(@```#93`0`<````65,!`",```!V4P$`$````)I3`0`+````
MJU,!``P```"W4P$`&@```,13`0`(````WU,!`!H```#H4P$`!`````-4`0`6
M````"%0!``H````?5`$`$@```"I4`0`D````/50!``H```!B5`$`*````&U4
M`0`8````EE0!``H```"O5`$`$````+I4`0`(````RU0!``P```#45`$`$```
M`.%4`0`$````\E0!``P```#W5`$`"`````15`0`:````#54!`"$````H50$`
M/@```$I5`0`B````B54!`"@```"L50$`6````-55`0`0````+E8!``8````_
M5@$`$````$96`0`P````5U8!`#,```"(5@$`"@```+Q6`0`<````QU8!``X`
M``#D5@$`!````/-6`0`&````^%8!``0```#_5@$`#@````17`0`&````$U<!
M`!(````:5P$`"@```"U7`0`E````.%<!``P```!>5P$`$@```&M7`0`(````
M?E<!``@```"'5P$`"````)!7`0`3````F5<!``(```"M5P$`!````+!7`0`T
M````M5<!`$,```#J5P$`%````"Y8`0`9````0U@!`!````!=6`$`"````&Y8
M`0`0````=U@!`"P```"(6`$`!````+58`0`.````NE@!``H```#)6`$`"@``
M`-18`0`R````WU@!``8````260$`(````!E9`0`,````.ED!`!````!'60$`
M%@```%A9`0`R````;UD!`#$```"B60$`+````-19`0`(`````5H!`!0````*
M6@$`'````!]:`0`$````/%H!`!````!!6@$`$@```%):`0`.````95H!`!X`
M``!T6@$``@```)-:`0`$````EEH!``H```";6@$`"0```*9:`0`(````L%H!
M``@```"Y6@$`!@```,):`0`&````R5H!``0```#06@$`!````-5:`0`<````
MVEH!`!(```#W6@$`$@````I;`0`$````'5L!``H````B6P$`"````"U;`0`/
M````-EL!``T```!&6P$`&P```%1;`0`*````<%L!``,```![6P$`!````'];
M`0`"````A%L!``X```"'6P$`&````)9;`0`,````KUL!`!@```"\6P$`*```
M`-5;`0`,````_EL!`!`````+7`$`'@```!Q<`0`2````.UP!``0```!.7`$`
M"P```%-<`0`)````7UP!`!````!I7`$`20```'I<`0`7````Q%P!`"H```#<
M7`$`!`````==`0`,````#%T!``X````970$`&````"A=`0`B````05T!`!X`
M``!D70$`&````(-=`0`@````G%T!``@```"]70$`4@```,9=`0`D````&5X!
M`!X````^7@$`$P```%U>`0`D````<5X!`!X```"67@$`*@```+5>`0`7````
MX%X!`!<```#X7@$`%@```!!?`0`(````)U\!``X````P7P$`!````#]?`0`6
M````1%\!``0```!;7P$`#@```&!?`0`*````;U\!`#8```!Z7P$`,@```+%?
M`0`@````Y%\!`%<````%8`$`!````%U@`0`2````8F`!`!````!U8`$`#```
M`(9@`0`\````DV`!``0```#08`$`-````-5@`0`N````"F$!`!X````Y80$`
M)````%AA`0`<````?6$!`!8```":80$`&@```+%A`0`:````S&$!``0```#G
M80$`,@```.QA`0`2````'V(!``P````R8@$`"````#]B`0`4````2&(!`!(`
M``!=8@$`!@```'!B`0`2````=V(!`!````"*8@$`$````)MB`0`,````K&(!
M`!(```"Y8@$`#````,QB`0`.````V6(!`!````#H8@$`(@```/EB`0`&````
M'&,!`!`````C8P$`$@```#1C`0`$````1V,!``H```!,8P$`"````%=C`0`.
M````8&,!``@```!O8P$`!@```'AC`0`&````?V,!`!P```"&8P$`"@```*-C
M`0`$````KF,!``@```"S8P$`"````+QC`0`.````Q6,!``(```#48P$`)```
M`-=C`0`$````_&,!``8````!9`$`!`````AD`0`A````#60!`",````O9`$`
M%P```%-D`0`C````:V0!`#0```"/9`$`*@```,1D`0`V````[V0!`!L````F
M90$`&P```$)E`0`.````7F4!``0```!M90$`!@```')E`0`(````>64!``\`
M``""90$`"````))E`0`$````FV4!``8```"@90$`!@```*=E`0`(````KF4!
M``X```"W90$``@```,9E`0`@````R64!`!````#J90$`$````/ME`0`*````
M#&8!`!0````79@$`"P```"QF`0`&````.&8!``8````_9@$`!````$9F`0`2
M````2V8!`!(```!>9@$`%````'%F`0`&````AF8!``@```"-9@$`(````)9F
M`0`2````MV8!``P```#*9@$`"````-=F`0`(````X&8!``(```#I9@$`"```
M`.QF`0`6````]68!`"(````,9P$`,@```"]G`0`N````8F<!`$P```"19P$`
M7````-YG`0`L````.V@!`#P```!H:`$`7````*5H`0`D`````FD!`"8````G
M:0$`)@```$YI`0`F````=6D!`"8```"<:0$`(@```,-I`0`L````YFD!`.,`
M```3:@$`&@```/=J`0!'````$FL!`"H```!::P$`.````(5K`0!'````OFL!
M`$H````&;`$`)````%%L`0`F````=FP!`!X```"=;`$`'@```+QL`0`>````
MVVP!`"````#Z;`$`,@```!MM`0`J````3FT!`"@```!Y;0$`(@```*)M`0`F
M````Q6T!`%X```#L;0$`+P```$MN`0`]````>VX!`"X```"Y;@$`)0```.AN
M`0!+````#F\!`%\```!:;P$`3P```+IO`0`H````"G`!`#(````S<`$`+P``
M`&9P`0!,````EG`!`$X```#C<`$`1@```#)Q`0!&````>7$!`#8```#`<0$`
M+0```/=Q`0`K````)7(!`"@```!1<@$`&@```'IR`0`J````E7(!`#(```#`
M<@$`*P```/-R`0!.````'W,!`"H```!N<P$`1@```)ES`0`D````X',!`$P`
M```%=`$`*0```%)T`0`Q````?'0!`"H```"N=`$`(@```-ET`0!"````_'0!
M``0````_=0$`#````$1U`0`(````474!`!8```!:=0$`"````'%U`0!;````
M>G4!`!(```#6=0$`#````.EU`0`,````]G4!``H````#=@$`+`````YV`0`:
M````.W8!``(```!6=@$`$````%EV`0`,````:G8!`!````!W=@$`%@```(AV
M`0`&````GW8!``8```"F=@$``P```*UV`0`.````L78!``H```#`=@$`)@``
M`,MV`0`P````\G8!`#$````C=P$`%0```%5W`0`J````:W<!`"\```"6=P$`
M'````,9W`0`6````XW<!`"````#Z=P$`*````!MX`0`B````1'@!`!X```!G
M>`$`*````(9X`0`C````KW@!`!@```#3>`$`-@```.QX`0`9````(WD!`#0`
M```]>0$`*@```')Y`0`B````G7D!`"0```#`>0$`)````.5Y`0`>````"GH!
M`"@````I>@$`(````%)Z`0`F````<WH!`!P```":>@$`'0```+=Z`0`>````
MU7H!`"````#T>@$`)@```!5[`0`:````/'L!`!X```!7>P$`+P```'9[`0`R
M````IGL!`!H```#9>P$`(@```/1[`0`Z````%WP!`"H```!2?`$`+````'U\
M`0`J````JGP!`"L```#5?`$`)`````%]`0`@````)GT!`"````!'?0$`*```
M`&A]`0`:````D7T!`#0```"L?0$`!````.%]`0`.````YGT!`!0```#U?0$`
M)@````I^`0`>````,7X!``8```!0?@$`$````%=^`0`$````:'X!``0```!M
M?@$`#@```')^`0`$````@7X!`"````"&?@$`!````*=^`0"\````K'X!`!P`
M``!I?P$`!````(9_`0`/````BW\!`!````";?P$`%0```*Q_`0`>````PG\!
M``P```#A?P$`1````.Y_`0`4````,X`!`!0```!(@`$`%````%V``0`2````
M<H`!``H```"%@`$`.P```)"``0`&````S(`!`"8```#3@`$`"@```/J``0`0
M````!8$!``H````6@0$`+@```"&!`0`B````4($!``@```!S@0$`'@```'R!
M`0`)````FX$!``H```"E@0$`%````+"!`0`4````Q8$!``0```#:@0$`!@``
M`-^!`0`.````YH$!`!H```#U@0$`,P```!""`0`"````1((!``X```!'@@$`
M!@```%:"`0`6````78(!``D```!T@@$`%P```'Z"`0`0````EH(!`!````"G
M@@$`&````+B"`0`$````T8(!``(```#6@@$`!````-F"`0`(````WH(!``T`
M``#G@@$`$0```/6"`0`(````!X,!`#`````0@P$`%@```$&#`0`4````6(,!
M`"P```!M@P$``@```)J#`0`Q````G8,!``8```#/@P$`"````-:#`0`$````
MWX,!``X```#D@P$`#````/.#`0`0`````(0!`#D````1A`$`,````$N$`0`_
M````?(0!``\```"\A`$`#P```,R$`0`3````W(0!`!<```#PA`$`#P````B%
M`0`"````&(4!``(````;A0$`!````!Z%`0`.````(X4!``0````RA0$`"@``
M`#>%`0`]````0H4!`#4```"`A0$`'````+:%`0`G````TX4!`"@```#[A0$`
M40```"2&`0`3````=H8!`&@```"*A@$`&@```/.&`0!.````#H<!`"H```!=
MAP$`.@```(B'`0`C````PX<!`"(```#GAP$`)`````J(`0`D````+X@!`"0`
M``!4B`$`)````'F(`0`F````GH@!`!X```#%B`$`00```.2(`0`2````)HD!
M`!<````YB0$`&@```%&)`0!H````;(D!``P```#5B0$`E0```.*)`0!V````
M>(H!`&X```#OB@$`,@```%Z+`0!B````D8L!``X```#TBP$`)@````.,`0`5
M````*HP!``P```!`C`$`&````$V,`0`<````9HP!`#@```"#C`$`&````+R,
M`0`@````U8P!`$X```#VC`$`&@```$6-`0`/````8(T!``X```!PC0$`(@``
M`'^-`0`.````HHT!`!````"QC0$`#````,*-`0`*````SXT!``8```#:C0$`
M"@```.&-`0`*````[(T!``@```#WC0$`$P````".`0`*````%(X!``P````?
MC@$`#````"R.`0`,````.8X!``P```!&C@$`#````%..`0`.````8(X!``@`
M``!OC@$`"````'B.`0`*````@8X!``X```",C@$`!@```)N.`0`<````HHX!
M`!@```"_C@$`#@```-B.`0`6````YXX!``H```#^C@$`'`````F/`0`0````
M)H\!``0````WCP$`$````#R/`0`(````38\!``X```!6CP$`#````&6/`0`8
M````<H\!``0```"+CP$`$@```)"/`0`6````HX\!``8```"ZCP$`"@```,&/
M`0`8````S(\!``@```#ECP$`'````.Z/`0`,````"Y`!``H````8D`$`#@``
M`".0`0`,````,I`!``X````_D`$`)0```$Z0`0`$````=)`!``4```!YD`$`
M`0```+8!``!2``````````H!```U`0``R`,``.0````E`0``````````````
M````]P(``-@$``#O!```O`$```````#C`0``[@,````````>````P0$``"\$
M``"1````#P(```````!``@``IP,``#D%``#N!```G`4``!0`````````````
M`"H#````````-0```(\$````````400``!0!``#-`@``=P(``%H$````````
MA0$```````"D`0``N00``'T%``````````````````!Z!````````(`#``#9
M`@````````````#L!```[@$``!0"``"U`0``&@,``/X$```#`@``G`0``/4`
M``#[`P``)P(``+````!W`0``500``'0%``#"````?P0``#$"``#(````^P(`
M`&L````"`0```````+P```"5!```````````````````C0(```4!```@````
MM@,``&P#```+`P``3P4``,,!``#Z`0```````%8#``#!`P``NP0```````!^
M`@``!@```,H"`````````````(0"```+`@``^@(``$P$```R`````````,\$
M``!A`0``Q@```$8`````````*0(``/<`````````U@,```````#>`@``J@``
M`(8%``"V````I`,``#H#```\!````````)\```"9`@```````$<$````````
MH@````````!O`@``F0$``*`%``!.!```2`4```````````````````4%````
M````-0(``/@#``#@````/P$``((%``#W`P``30,``&0`````````3`4`````
M```$`P``'`$``*P!``"-````Q@(``(,"``"N`P``S`,```````#T`0``````
M`&X$``#+!``````````````E`P```````-D$``#E`P``W`(```````#T````
MGP4``,X`````````=0``````````````^P$``-4"`````````````"@!``"S
M`0``G@4``.($``"9!0``;@(``*@!``!G`@``V0$```T$``#8`@``I0(`````
M``!S!```6P,```````"/`0``IP```&T#`````````````+4"``!0`P``````
M`&<```!]`0``0@,``#````"F!```,04``(X"``#4`@``90``````````````
M40(``%,!````````+`,``/X```!)`````````````````````````)4````N
M`0``.0`````````/!0``W````$<!````````Y@```%@%```/`0``B0,`````
M``"+`0```````*<"```-`@``.`0````````>`@``P0(``#`#``#Q`0``,P0`
M`&0%``"R!```SP```-L!````````:`4``'($``!U!```-04``"@"````````
MS@(``"0#``#U`0``?`(```````".!```-P(``#X#```9!```=`````H"```,
M````MP$``+T#``#U!````````$$````G`0``-`,``,0#``"8!```@@(``'`#
M```$!0``40,``$\#``#_`@```````*H!```2`0```````%@"````````>0$`
M````````````A00```````"^`@``8@````8!``"L````6@,``"D#``"/!0``
MJ`0```````!M`0```````$@!```0!0```````*T!````````/0````````!_
M`@``@00```8%```7`````````/0#``"6````^`(```````#;`P```````)@#
M````````E@0``"X"````````DP(``&H!````````O00``'$!````````*P,`
M``0```#?`0``XP```+@```#Y!```50```$<```!"``````````````!0!```
M`````*`#``!T`0````````````#0`0``'P0``/\```""!```=@0```,%````
M````*@4`````````````5`4```````#0!`````````````!"`0``=@``````
M``"W`P```````/(`````````*`0``$T"````````4@,```````!1````````
M`)@"``!4`@``<`(``-,$``"I`0``I00``-,!```F`0``H@4``$T!``!*`@``
M`````-X$```O`P``PP0````````F`P``W0,``.P"```,`P```0(``.`#````
M````C@```$8"``"G!```0@(``.@!``!4`0``K`(``+@"``#N`@```````.`!
M``#7````)0(``!8$```Z````Y@0``/T!``!6!0``#P,``*L`````````/`(`
M`%4"``!"!```"`4``.H#````````T`,``,L"``"[`P```````&X```##`P``
M`````(<!``!(`P``000``"(#``"%`P````````````!J!```&@$``%<````3
M`0``S@0``(P!````````PP(``)$$``#R`0``X@$``.(#``!I````+P4``'0#
M``#+`0``'@,`````````````4@4```````!G!0``ZP,``&`$```=````````
M`&,#``!@`0``U````(H!```?!0``0P4``+\#```)`@``(P0```````!#!```
M`````-T!```K`@``A````%H```#_`0```````'L#``">````800``'$"``!U
M!0``@`4``/,````F!0```````&D!````````=P,``-4$```6`0``+@```&X#
M``#7`0``6`,``#D!````````XP,``,H!````````6P````````!)`@``SP$`
M````````````1P(``%`"```_`P``,0$``&,"`````````@4````````M````
MG0(```````#E`@``G`(```````#Y`0``0`$``(,`````````1`0`````````
M`````````/P!```O````G@0``%D```#]`P``I`4``%P`````````CP,``&L"
M``!O````G@,``%H"``#G!````````+P$``#P`P``4`$```````"9`P``*P``
M`%,%```#`````````+`!``#)`P``,`4``"0"````````%@(````````X`@``
MH`$``!4```"2!0``;00``*`````E!```\P$```````"8!0``H@0``'8%```8
M!0``A`$``)``````````)`0``'X%``#`````Q`$`````````````7`$``(P"
M``!^!```````````````````KP0```````"Y`P``*P4``&P"````````````
M``H$```1`0``*````-4!`````````````+`"``";!````````$4#``":!0``
M`````,($````````T````/@$```9`0```P$``"8"``#A!`````````X%``!%
M`0````````````!$`P``/0(``-T$`````````````+T```",`P``````````
M``!Z`P``BP,`````````````@P$``'@%````````H00``!$"``#;!```````
M`+D!```O`@``B`(``,P$````````,@(````````[!0``(P,```````"O`0``
M$0,```("````````G0,````````=`P```````+P"``#<!```N@0``)L"``#,
M`@``N0```!$```"-`0``J00``'`!`````````````&X%``"C`@``HP4``),`
M`````````````,X!```Z`@```````-`"``!6`````````!L$``#&`0``60(`
M`#X!```%!```YP$``%@!````````20,``+@#`````````````$P#````````
MFP$```8$````````A@,```````#@!```H@,```````#8`0``GP$``$D%````
M`````````%,"```7`@``?P,``%P"``!$`@```````"$```"=`0````0``&\#
M````````!P,``!($``#5````O@,``(T$```W`P```````/4#``#L`0``5@(`
M`.\"````````00,``"@#``!R`0``8P$``$<#``"M`@``+0$`````````````
MK0,``%($```8`P````````<$``#:`@```````#`$``"V!```````````````
M````1```````````````60$````````:`@``#0,`````````````$P4``)8#
M````````(P$``+`$``!2`0``$`(``!\````?`P``<@````````!N`0``````
M`/\$```_`@``T@$``&(%``"D!```_0(``````````````````',````+````
MEP$``&D$```X`0``F@(``&\%````````Q0$`````````````]P$``%0$````
M`````````-\$````````%04```L!``#T`@``_````&4$````````=P0```D%
M````````<@,``(4```!#`P``/`$``+$"``!X```````````````+!0``````
M````````````0````"0%``![`@``@0(``%4!````````,P(``(T#``"O`P``
MF@,``$4$````````4P````````"!`P``10```-8"```)`````````,8#``":
M!`````````8"````````D`(``$H%``![`0``'0(```````#]!```````````
M``#K`0``;P$``,<#``"T````$00``%H%```I!```O0$``*L!````````T@0`
M`%H!``#D`P```````,0"```G``````````````!4`P``"`$`````````````
M``````````""````I@(``-8$``!O!```7@,``%4%``"_`@```````$H#``!`
M!0``D@0```````"Z````8`,``-H#````````(P```,L```#E````.P(``*H#
M``#2````K@(``*D``````````````#$#``!G`P````(```````"/`@``[0,`
M`/0$``"*`P``\0,``/H`````````2`(``)P```#R!```(`(``#L`````````
M<04``-H!````````1P4``%X"``#]````*04``#8$``!+````.`,``-<$```"
M!```<P4``!L```">`0``(0$``$X!``!]`@``%0(``&@$``"S````(`4``!(%
M``````````4``#8%``#>`0``$`,``&(#``"6`0``&@4``.<```#A`0``A`0`
M`,@"``"5`P``"@,`````````````>@4``*4#``#:!```>@(``,\"``"E`0``
M&0```.("``"C!```(@(`````````````3P0``*D%``";!0``B`,``,<```!7
M`P```````+P#``"I`@``'04```````#6````>00``*X$```-````%P$``'`%
M```"````K@```%8$````````2````&8$``#'`0``-@```$T```#I`@``/0$`
M`"D!```$!```9`0``$,!``#$!```/`4``'D%````````&P(``/D#````````
M!@,````````A`P``N@$``)0!``!M!0```````)<"``#9````9P0``!@!```<
M!0``WP(``'<`````````$P,```````!L`0```````,`#```B`````````.T!
M````````<0```"X#```-!0``OP$``'@!`````````````-<#``"Q!````0,`
M`*$#``##````%P4`````````````G`,`````````````<P(``%X$``!8````
M`````.<"``"A`0``M0``````````````)P4```````!<`P``F00```````"=
M````>P0``+T"``!;`@``1`4``#($``!7!0```````/("``!>`0```````.\!
M````````%P,``.H"``!+`0``V`,``-\```!^````/@0``.,$```X!0``````
M`*P#``#)!```E````(H%``"^`0``-P$``$8!``"(`````````(L"``!B!```
MLP0``%<!``!Y`P``\P(``$\"``!Q`P``Y@(``'4"``".`P``Q````*,!```>
M`0``MP(``)<#``!E`0```````!\!``!T!```TP,`````````````YP,`````
M``#<`0``Y`$``&8```#A`@``9@,``.0$``"R`@```````&8!``!1`0``R`0`
M`*8%``#J````BP4````````<`P````````````#*`````````!X$````````
M3@(``#T%``#1`````````,P!``#_`P``<@4```P%``````````````````!8
M!`````````X$``!H`P``[P,````````B!0```````/@`````````$P(``"T$
M``"4!0``C````'X#``")`@``U0,``#<%```4!0``2P4``!P$``!&!```````
M`/8$``!=````@04``'T$`````````````-(#``#D`@``NP```'\!``"F`0``
ME`(``)`$```P`@```````#\%```)`0```````%\```"T!````````$T%```S
M`P``S0$``-L````3````&0(``%T%``!Z`````````/`!``"G!0``"@```%T#
M``"1!0``NP(``'P$````````K0````````!]`P``&@0``/P"``"%`@``'0$`
M``````"E````9`(````````L`0``J@(``+4#``"O`@``S@,``,T`````````
M```````!``!^`0``$@```.@"````````(`,``#X```!A`@```````#0"``!D
M`0``SP,``%0```````````````````"4`P``7@```$4"```@`0``F0```/$"
M````````B0$```L$``#6`0``600``!``````````VP(`````````````D`,`
M`-,```#L`P``A`,``-P#``!*!```700``#T#``"6!0```````!<$``#``0``
M``````````#)`@``L`,``+D"````````TP(```4```"#`P``8`4``((!```(
M````;````"$%``!+`P``"@4``!,$``!E`@``AP(``.D#``#F`P``>P4``,@!
M````````H`0```X#```Z`0``"0,``````````````````*0````>!0``\P0`
M`)$"```;`P``$`0``&`"``"/````M`(```````!H`@``$@,``$X#``#4`0``
M6P$``$4%``";`P``B@0``%T!````````%`,``"@%``!S`P``/```````````
M`````@,``)("``"R`0``B`4``'@"``#7`@``"`0```,$````````/@4`````
M```6`P``2`0``#H$``!)!```-````#L#```/````%0,``*\```!\`0``80``
M`+,"``#V`0``3P```.T$``#[````'`(```<"``!K`0``)@```)(#````````
M*@$``"0!``"K`P``:```````````````D0,``$,```#A`P``BP````D$``!$
M`0``:0,``),$```W`````````.,"``#V`P``P@(````````T`0```````"T"
M``!?`0``20$```````"R`P``\@,``&P%```C!0``&`(```````"N`0``````
M`,8$````````V0,``+$#``#[!```00(```@#````````=@$``,T$````````
MB@(``#@```#Y```````````````[!```B00``&8%```0`0``C@4``/H#``!=
M`@``@0```(8!```I`````````.@```!_!0``C`0``#H%``!6`0``W@```)@!
M````````:@,``,4$``#%`@``404``"T#``!X!`````````````!?!```C`4`
M````````````A@0````````'!0``U`0```````"3`P``5P(`````````````
M2@$``&H```"H!0``GP,``!L%``!P!```M@(``$X````?`@``````````````
M````6P0``#\```"6`@```````````````````````*(!``"W````+`4``/``
M````````<00``'\`````````:P,``!@$``!W!0``/P0```````"F````*@0`
M`)\$``#"`0``N`$``)<$``"U!```A@`````````%`P``B0```$,"``!S`0``
ME0(``(H````G`P``E`0``+$!``#Q`````````)L```"Q````V````-H`````
M````Z0````````"G`0``OP````0!``!J!0```````/<$``#Z!```$@(``*@"
M````````ZP(```````"W!```_`,``!$%``````````````````"2`0``````
M`,H#```M!0``3````!D#````````3`$``.T```#'!```\00``$$%``!E`P``
M-@,``","````````T00``"`$````````=`(``/`$``!!`0``P@,``"L$````
M````%0$``(<$``"T`0```````/8"````````BP0```````!D`P``80,`````
M``"1`0``9@(``$T$``!A!0```````'4!``"K!`````````````"#!```#0$`
M``````"X!```0`,``#,```#A````<@(``%("``#!````A@(``'D"``!&!0``
MI@,``'L```!;!0``.00```````#,``````,``&D"``#?`P``.0(```````#B
M````!P`````````!!````````"H"``"-!0```````.4!````````AP4``"H`
M`````````````"($``!7!````````*@```#-`P``F````)H!``!<!0``T@(`
M`.L```#1`P``D@```*$`````````;0```$`$```;`0```````*H$``!G`0``
M`````!T$```R`0```````#(#````````=0,``"0```"``@``DP$````````T
M!0``3P$``'D````/!```7P4```4"````````_@,```````#N`````````!P`
M```E!0``````````````````B04``````````````````)T$````````?0``
M`*,````.`````````(X!``#=`@```````&,$``!\````904``%,#```!!0``
M,0```-0#``#S`P``Z0$``!@```"(!```G`$``(@!```Q!```4`4``!8```!?
M`@``H@(```````!V`P``,P4``!8%``#+`P``604````````A`@``\`(``!0$
M``!"!0``&@```!D%``"[`0``-00``(<#```^`@````````````!J`@``8@$`
M``P"``!C!0```````,4`````````A`4``"(!`````````````#<$````````
MJP(```0"````````_@(```````"M!```60,``+H"``"%!0````````````"L
M!````````$P"``#M`@``@`````X"```L!```]@```%4#``"0!0``HP,`````
M`````````````)\"``#I!```!P$`````````````T0$``/@!```V`0``,@4`
M``````!K!0``EP4``"<$```A!````````.@#````````@@,```````#L````
M4P0`````````````2P0``-$"```K`0``)@0```````#F`0``>@$`````````
M``````````````"^!```I`(`````````````J`,``&,`````````-`0`````
M````````DP4``#P#``#K!````````.H!`````````````#8"``!.!0``?`,`
M`,D`````````F@```*4%``"7````:04``,`"````````?`4``'@#````````
M@`0``*$%````````R0$``'8"``"'````7`0``"P"```N!```.P$``"\!``!&
M`P``H`(``/X!``#H!```8@(``(`!````````O@```#D#````````4````($!
M````````;`0``/P$```E````Q0,````````,`0``G04```````#O````7P,`
M`+(```"0`0``M`,``,<"```.`0```P,``,`$``#=````G@(`````````````
ME04``&@!``#@`@``]0(``.H$``!+`@``-0,``"P`````````/00````````P
M`0``<````*$"``#*!```%00```@"````````,P$``*D#``!M`@``LP,``.4$
M````````P00`````````````:P0``)4!```!`0``#`0``-X#````````N@,`
M`"X%``#Y`@````````````"_!```8````$H```"#!0``7@4````@*"5S(&1A
M>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y
M*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(B5S(B!I<R!N;W0@82!D:7)E
M8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E<R`M($YO=&EC
M90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R
M;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I
M<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E
M<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E
M<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"TM('-E;&5C="`M
M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E
M=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!32]030!!8F]U="!T:&ES(&5D:71O<@!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!
M8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P
M`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B
M`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E
M<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S
M(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VYM
M96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!
M;&P@4&5R;6ES<VEO;G,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S
M`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I
M8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG
M=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!
M<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P
M<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G
M96YT:6YA`$%R;65N:6$`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<VEA+U!A
M8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R
M:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N
M=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE
M(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I
M:F%N`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@
M<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR
M86EN`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"
M96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!"
M;W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$`0F]T<W=A;F$`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA
M`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;6)O9&EA
M`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@
M=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`
M0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`
M0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L
M;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL
M<&AO;F4`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#97)T:69I
M8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H;V]S92!!<'!L:6-A=&EO
M;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:')I<W1M87,@27-L86YD`$-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<B!-4T]F9FEC92!T
M86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R
M`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7:6YD
M;W<`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#
M;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]N9FEG
M=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A
M<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O
M9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S
M960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA
M;F1S`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A
M(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC
M92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U
M;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD
M(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B
M+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N
M;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD
M(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D("5S
M+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I
M979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T
M('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S
M(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N
M9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`
M0V]U;G1R>0!#<F5A=&4`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O
M;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`
M0W)O871I80!#=6)A`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R
M=7,`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$
M871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T
M:6]N`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$
M96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@
M261E;G1I='D`1&5F875L="!3:&5L;`!$96QE=&4`1&5L971E($-E;&P`1&5L
M971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E
M(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ES<&QA
M>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&II8F]U=&D`1&\@
M;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A
M;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O
M=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$4M36%I;`!%8W5A9&]R`$5D:70`161I
M="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI
M<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F
M;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N
M<R!F;W(@)7,`16=Y<'0`16P@4V%L=F%D;W(`16UA:6P`16UA:6P@061D<F5S
M<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF
M:7)M871I;VX`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S
M96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O
M;G1E>'0@;65N=3\`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<75A
M=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T
M=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`
M17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N
M`$5S=&]N:6$`171H:6]P:6$`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E
M<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S
M`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA
M;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X
M<&5C=&5D("<I)P!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`
M1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R
M;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R
M96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B
M)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X
M97,`1F5B<G5A<GD`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T(%%U87)T97(`1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O
M<FUS`$9O<G5M<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`
M1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A
M;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R
M871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV
M96X@3F%M90!';&]B86P@3W!T:6]N<P!';V]G;&4@36%P<P!';V]G;&4@4V5A
M<F-H`$=R965C90!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A
M=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U
M<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R
M;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T
M(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'
M=7EA;F$`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA
M<V@M06QG;W)I=&AM`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@
M36-$;VYA;&0@27-L86YD<P!(96EG:'0`2&5L<`!(96UI<W!H97)E`$AO7VUE
M`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R
M97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N
M8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A
M9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL
M)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E
M<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@
M4G5L90!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5N9V%R>0!)34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L
M971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L
M92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`
M25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)8V5L86YD`$EC;VYS($]N;'D`26-O
M;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!);6%G
M92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G97,`26UP;W)T
M+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z
M`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S
M92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF
M;P!);F9O<FUA=&EO;@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA
M9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M
M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC
M:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E
M;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T
M97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R
M="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS
M97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E
M<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R
M="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN
M<W5F9FEC:65N="!C<F5D:70N`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A
M<'!L:6-A=&EO;BX`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A
M;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E
M+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!)
M;G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!)
M;G9A;&ED('5N:6-O9&4@9&%T82X`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)
M<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P
M86X`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E
M;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`
M2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V
M97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME>2!#<F5A=&EO;@!+97D@
M1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI<FEB871I`$MO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U
M8FQI8R!O9@!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@475A<G1E<@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,87EO=70`3&5B86YO;@!,969T`$QE<V]T:&\`
M3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`
M3&EN:P!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S
M`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C
M86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO
M9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A
M:6QE9"X`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S
M`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA8V%O`$UA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA
M:6P`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E
M('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E
M;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RX`36%R8V@`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA
M=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87D`36%Y;W1T
M90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365T:&]D`$UE=&AO
M9"`B)7,B(&ES(&YO="!D969I;F5D`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F`$UI;64@5'EP90!-:7-S:6YG(%!%05(@<&%C:V%G
M92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`
M36\`36]B:6QE($UA:6P`36]D:69I960@1&%T90!-;VQD;W9A+"!297!U8FQI
M8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@
M4&AA<V5S`$UO<F]C8V\`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!->2!!8V-O
M=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37EA;FUA<@!.3RP@22!$;R!.
M3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S
M`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='=O<FL`3F5V97(`3F5W($-A;&5D
M;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I
M;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W
M:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`
M3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YI=64`3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N
M`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO
M(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G
M92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C
M:69I960N`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN
M87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y
M('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P
M<RX`3F\@<75O=&$@<V5T+@!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S
M=6-H(&9I;&4`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;W)F
M;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA
M;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@
M9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-U<'!O<G1E9"X`3F]T
M97,`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E
M<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B
M:F5C=`!/8FIE8W0@0W)E871O<@!/8W1O8F5R`$]F9FEC90!/;&0@<&%S<W=O
M<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M
M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`
M3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I
M9VYE9"!3+TU)344@<&%R="X`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E
M<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G
M86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/=&AE<B!)
M;F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'
M4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!03U-)6"!E>'1E;G-I
M;VX@:7,@;6ES<VEN9P!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN
M96$`4&%R86=U87D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I
M<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M
M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG
M(%-I9VYU<',Z`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI
M<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`
M4&AO;F4`4&ET8V%I<FX`4&EX96QS`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T
M96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N
M=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN
M9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE('-Y<W1E;2X`4&]L86YD`%!O;&QS`%!O<G1U9V%L`%!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V
M:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP
M86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0
M=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME
M>2`H)60@8FET*0!2871I;P!296%D`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5L;V%D
M`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!F;W)M
M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M
M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297-E=`!297-E="!087-S
M=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P
M=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FEG:'0`4F]L90!2;VUA;FEA
M`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P
M97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2
M=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%-13"!3:&5L;`!34T@`4U5#0T534P!380!386EN="!(96QE
M;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I
M;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z("(E<R(N`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL
M97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T
M(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O
M(&%D9`!396QE8W0@86QL`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E
M9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD
M('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M
M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L
M96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5P=&5M8F5R`%-E<F)I82!A
M;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I;VX@061M:6X`4V5S
M<VEO;G,`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N
M+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I
M<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V
M86EL86)L90!397EC:&5L;&5S`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S
M<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`
M4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N
M871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP
M($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S
M`%-O=71H($%F<FEC80!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;`!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A
M:6X`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-R:2!,86YK80!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3='EL92!;0U-3
M70!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FUI=`!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B
M+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`
M4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`
M4W5N(%-E=`!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WER:6%N($%R86(@4F5P=6)L:6,`5%-6(&9I;&4`5&%B;&4@4')O<&5R
M=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7!L871E("(E<R(@;F]T
M(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT($]N;'D`5&5X
M="!A;&EG;@!497AT=&]P`%1H`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A
M8FQE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U
M8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI
M=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+@!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T
M:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H
M92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O
M;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L
M;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R
M,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V
M97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T
M:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E
M96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RX`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M
M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y
M<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S<&5C:69I960@
M<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@
M8V]U;&0@;F]T(&)E('-A=F5D+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T
M(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E
M(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4
M:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9
M;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R
M(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S
M(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W
M87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T
M:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A
M(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN
M9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V
M97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@
M9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES
M(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A
M8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UO
M<BU,97-T90!4:71L90!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H
M:6QE(&-L:6-K:6YG+@!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U
M`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S
M="!M:6YU=&5S+@!4<FEN:61A9"!A;F0@5&]B86=O`%1U`%1U;FES:6$`5'5R
M:V5Y`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V
M86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!54DP`56=A;F1A`%5K<F%I;F4`56YA
M8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S
M(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A
M:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I
M(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5
M;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI=&5D
M($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YK;F]W;@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FYA;65D`%5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@
M=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"X`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP
M="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E
M='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`
M57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5
M<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@
M24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F
M;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@
M4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E
M<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z
M`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!6
M86-A=&EO;@!686QI9&ET>0!686YU871U`%9E;F5Z=65L80!697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI
M9VX`5FEE="!.86T`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5E:VQY`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N(%-A:&%R80!7:&%T
M(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q
M=6]T92!C:&%R86-T97(_`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:7-H;&ES
M=`!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8-3`Y=C,@
M0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8
M-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T
M($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`665A
M<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C
M86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9
M;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC
M871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA
M`%IA:7)E`%IA;6)I80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%ML:6YE
M("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T1E;&5T92!2;W<`7T=R;W5P
M<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T
M`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V
M92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`
M861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;FYO
M="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@
M:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E
M<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T
M(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9I;&4`:&]S="!N86UE('5N
M:VYO=VX`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R
M<F]R`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VP`<V5R=FEC92!U;F%V86EL86)L90!S:&]W
M(&1I9F9E<F5N8V5S`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y
M(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+C`*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-#<K,#$P,`I03RU2
M979I<VEO;BU$871E.B`R,#`V+3`S+3(R(#$R.C`P*S`Y,#`*3&%S="U4<F%N
M<VQA=&]R.B!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N
M:G`^"DQA;F=U86=E+51E86TZ($IA<&%N97-E(#QU;FMN;W=N0'5N:VYO=VXN
M9&]M86EN/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]4TA)1E1?2DE3"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:70*`"`H)7,@D_J13RD`@T&#3H-:@UB#3(-#("5S`(%I)7,@
MD_J"S)/@@LF!:@`@*(VAD_HI`(%IEKZ3^H%J`"`HC?"3^BD`)R5S)R""S8-F
M@T*#C(-.@V>#BH%;@L6"S8*@@NB"W(*Y@O&!0@`B)7,B((+-D+."M8*BD4F1
M\(+%@LV"H(+H@MR"N8+Q@4(`(B5S(B""S2!(;W)D92"#C(-7@UB#9X.*@LF0
MW9+H@K."ZH+$@J*"W(*Y@O$N`"(E<R(@@V.#BH%;E5R.IHM`E%R"JHRIE72"
MJ8+H@MR"N8+Q@4(`(B5S(B""JH-/@XN!6X-V@U:#6(-E@X""R9+'B<&"LX+J
M@MR"M8*]@4(`(B5S(B""JH-!@TZ#6H-8C*"#5H-8@V6#@(+)DL>)P8*S@NJ"
MW(*U@KTN`"(E<R(@@LV-[)"L@K."ZH+<@KF"\8+%@K6"O3H@)7,N`)=EE\H@
M)3(D+C)F34(@DH:"S"`E,20N,F9-0B".9Y=P*"4S)"XR9B4E*0`E9"`E<R""
MQB`E<P"#<(-8@X^!6X-H@LV"H(+&("5D()/ZETR,^(+%@K>!0@"2RI)M("T@
M)7,`)7,@DV2.<8YWEN0`)7,@2T(`)7,@E=N.YY&`C>R"S(IME$8`)7,@@LR0
MW9+H`"5S((-4@T.#DX-!@V*#=@`E<R"3KXC3C_"-@``E<R""S8KY@LF1MHW=
M@K6"W(*W@4(`)7,@@LV.GX+)CG>2Z(*S@NJ"Q(*B@NF5VX[GD8"-[(+PCL"-
M<X*W@NF/@)3U@JJ0KH*B@MR"M8*]@4*.P(US@K6"O8*BD8"-[(+,@WN#8H-.
M@UB"\(-@@T:#8H-.@K6"Q(*M@KZ"LX*B@4(`)7,@@JJ52Y=V@L6"MP`E<R"5
MJ@`E<R""JH*@@NB"W(*Y@O&!0@`E<R""J8+G("5S@4&-AXQV("5S`"5S((+,
M@T&#:(.,@UB2H``E<R""S)=<DNB57``E<R""S(.!@X*2H``E<R""S(->@UB#
M3H.*@UB#9P`E<SH@)7,`)7,Z((*Q@LR#@8-B@UJ!6X-7@LV.IH*S@NJ"Q(*B
M@NF1EY!-CM*"J8+G@LR"X(+,@L6"S8+(@J*"QHYV@NV"ZH+<@K>!0H*[@LR2
MAH+,@XJ#DX-.@O"#3H.*@V*#3H*U@KV"Z(%!C,*0;(_NE?&"\)&7D$V"MX+I
M@LR"S8]<E:J"R9*-B-."M8+$B;J"LX*B@4(`+2T@D4F1\"`M+0`Q,HZ>BM2,
M8(ZN`#(TCIZ*U(Q@CJX`,C0@CIZ*U``\D4^"S(-Y@5N#5P""L8+,@W6#C8-B
M@TZ"R8+-@V:!6X->@WB!6X-8@JJ52Y=V@L6"MX%"`))VEKV328+(@T>#B8%;
M@JJ4K9"V@K6"W(*U@KT`4$=0C/:*2HRN@JJ#@8-B@UJ!6X-7@LR(PXV&B;N"
MR95+EW:"Q8*W@4(`4$=0C/:*2HRN@JJ/D):\@K."ZH*]@X&#8H-:@5N#5X+,
MC)^/V(+)E4N7=H+%@K>!0@!01U",]HI*C*Z!05!'4)3IEJ>,KH*H@N:"T8-P
M@UB#=(.,@5N#68*JB,.-AHF[@X&#8H-:@5N#5X+,E9R-AH+)E4N7=H+%@K>!
M0@!01U",]HI*C*Z!05!'4)3IEJ>,KH*H@N:"T8-P@UB#=(.,@5N#68*J@X&#
M8H-:@5N#5X+,CY"6O(+)E4N7=H+%@K>!0@!3+TU)346,]HI*C*Z!05,O34E-
M193IEJ>,KH*H@N:"T8-P@UB#=(.,@5N#68*JB,.-AHF[@X&#8H-:@5N#5X+,
ME9R-AH+)E4N7=H+%@K>!0@!3+TU)346,]HI*C*Z!05,O34E-193IEJ>,KH*H
M@N:"T8-P@UB#=(.,@5N#68*J@X&#8H-:@5N#5X+,CY"6O(+)E4N7=H+%@K>!
M0@!3+TU)346,]HI*C*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%@K>!
M0@!!32]030""L8+,@T>#9H-"@UZ!6X+)@L*"HH+$`%9&4X-F@T*#C(-.@V>#
MBH+,C>R0K(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"`%9&4X-T@T"#0X.+
M@LR-[)"L@LV#08-.@UJ#6(N1E-N"LX+J@MR"M8*]@4(`@T&#2H-%@Y.#9X_N
ME?$`@T&#2H-%@Y.#9X+,@W"#6(./@5N#:`"#08-*@T6#DX-G@LV3@(R+@K."
MZH+$@J*"W(*W@4(`@T&#2H-%@Y.#9P"2QXG!`(-4@W6#3X.+@5N#=H+PDL>)
MP0"#5(-U@T&#3H-:@UB,H(+PDL>)P0""L8*Q@LF2QXG!.@"05H*U@J*#3X.+
M@5N#=H+PDL>)P0"05H*U@J*"\(-!@TZ#6H-8C*""\)+'B<$`@U2#=8-/@XN!
M6X-V@O`@(B5S(B""R9+'B<$`@U2#=8-!@TZ#6H-8C*""\"`B)7,B((+)DL>)
MP0"05HM+@X:!6X-5@O"2QXG!@48`E_&"\)+'B<$`D%:+2X.!@Y.#;X+PDL>)
MP8%&`(-Y@T&"\)+'B<$`)7,@@X&#:H.%@5N"\"!-;WII;&QA((+,@U2#0X-H
M@V^!6X+)DL>)P8*W@ND`@T&#:(.,@UB2H(+)DL>)P3H`CH2"S(+,@T&#:(.,
M@UB2H(+)DL>)P0"#AH%;@U6"\)+'B<$`@U:#6(-E@X""R2`B)7,B((+PDL>)
MP8*U@MR"M8*]@JJ!08-4@T.#DX-!@V*#=H+,C^Z5\8*JDL>)P8+%@JN"W(*Y
M@O&"Q8*U@KV!1B5S`(-6@UB#98.`@LD@(B5S(B""\)+'B<&"M8+<@K6"O8+,
M@L6!08.-@T^#0X.3@L6"JX+<@K>!0@"#AH%;@U6"S)+'B<&/B)>=@LV6LXSX
M@LF"R(+!@L2"HH+<@K>!0@"/6H^*`(-!@VB#C(-8DJ``BL>7G2`M()&\@LR#
MAH%;@U6"S(-!@TZ#6H-8C*``BL>7G0!!9',`@T&#=(-+@VJ#6(->@Y,`@T&#
MBX-O@VJ#00"#08.+@U>#1H.*@T$`E<J6O`"(RI)UD;6"IH%&`)%3E90`D5.4
M1H_8@X:!6X-5`)%3@L2"S(-/@XN!6X-V`)%3@L2"S(-!@TZ#6H-8C*``E:&0
ME(+,@T&#:(.,@UB"\(N6B<(`E-2-AI5T@JN#BH-8@V>"\)#=DNB"Q8*K@NF"
MYH*D@LF"M8+<@K>"J8%(`(KY@LF1MHW=@K6"W(*W`)'CD=:"S"!)35-0((.-
M@T^#0X.3`)'CD=:"S"!)35-0((-P@UB#CX%;@V@`D>.1UH+,($E-4U`@@X:!
M6X-5EKP`D>.1UH+,@X&!6X.+@T&#:(.,@U@`D>.1UH+,@V6#DX-V@XR!6X-G
M`)'CD=:#98-,@UB#9X%&`(-!@X&#BH-*E\R#5(."@T$`E7.0LX+(DFR"JHYW
MDNB"LX+J@L2"HH+<@K<`EUR*^H*U@LB"HH-'@XF!6X*JE*V0MH*U@MR"M8*]
M`(-!@Y.#:(.)`(-!@Y.#4X.)BZ2888V1`(-!@Y.#3X-"@XD`D[V6O(-V@XV#
M3(-6@5L`DYJ"I@"3[(O)@6F1Y9>D@6H`@T&#DX-E@T*#3X-!@46#;X%;@W6!
M6X-?`(-!@W:#BH-0@5N#5H.'@Y,`@T&#=H.*@U"!6X-6@X>#DXCJEY<`@T&#
M=H.*@U"!6X-6@X>#DXYGEW")P@")NHC*@LR+I)=,@LF32Y=P`(^SE$8`@JB"
MJ(+F@KN"S(-4@T.#60""4XR.`(-!@5N#2H-#@W6#=(-`@T.#BX-4@T.#60"#
M08%;@TJ#0X-UEKP`)7,@@LR#5(-#@Y.#08-B@W:7=HN!@O"6>Y.6@LF-[8^<
M@K6"Q(*B@J*"Q8*W@JF!2`"6>Y.6@LD@(B5S(B""QH-4@W6#3X.+@5N#=I%3
M@L2"\(WMCYR"M8+$@J*"HH+%@K>"J3\`@T&#BX-;@Y.#8(.3BZ2888V1`(-!
M@XN#@8-J@T&+I)AAC9$`@T&#BX-O`(-!@UJ#DX-6@X>#DY.'`(-!@U>#08%>
MD;Z5O9=MDFZ(Y@"5VX[GC>R+QH+,CL"-<Y%/@LF*;91&@O"+@8+?@NF"YH*D
M@LF"M8+<@K>"J8%(`)&VC=V"M8+(@J*#3X.+@5N#=H+PC>V/G(*U@N:"I(+&
M@K6"W(*U@KV!0@"1MHW=@K6"R(*B@T&#3H-:@UB,H(+PC>V/G(*U@N:"I(+&
M@K6"W(*U@KV!0@"1MHW=@K6"R(*B@T&#3H-:@UB,H(+PE=*/5X*U@N:"I(+&
M@K6"W(*U@KV!0@"1MHW=@K6"R(*BBZ273(+PE=*/5X*U@N:"I(+&@K6"W(*U
M@KV!0@"1KI"K`()7C(X`@TF!6X-8@V>#B8.*@T$`@TF!6X-8@V>#BH-!BZ28
M88V1`$%U=&A?8WER<W%L.B"52Y=V@LA)34%0BF>2HXM`E%R"JHRI@L*"J8+H
M@MR"N8+Q@4(`075T:%]C>7)U<SH@@V^#8H-.@T>#DX-H@LV52Y=V@LB47)?-
M@O"73(*U@L2"HH+<@KF"\8%"`$%U=&A?8WER=7,Z()=VBX&"MX+I:6UA<(IG
MDJ."JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]F='`Z($944(IGDJ.+0)1<@JJ"
MW8+"@JF"Z(+<@KF"\2X@4$A0@O`@+2UE;F%B;&4M9G1P((-)@W:#5H.'@Y."
M\(+"@J^"Q(-2@Y.#<(-#@XN"M8+(@JB"M8+$@JV"OH*S@J*!0@!!=71H7VEM
M87`Z($E-05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!!=71H7VMR8C4Z
M(&MR8C6*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!!=71H7VQD87`Z($%C
M=&EV92!$:7)E8W1O<GD@@L6"S(.&@5N#59+'B<&"S8-4@WR!6X-G@K."ZH+$
M@J*"W(*Y@O$`075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y((+%@LR#AH%;
M@U6-[8^<@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q`$%U=&A?;&1A<#H@3$1!
M4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?;&1A<#H@@X:!6X-5
M("5S((+PDL>)P8+%@JN"W(*Y@O&!0H-4@5N#;X+,B9Z3FCH@`$%U=&A?;&1A
M<#H@@X:!6X-5("5S((+PC>V/G(+%@JN"W(*Y@O$`075T:%]L9&%P.B"#AH%;
M@U4@)7,@@O"-6)!6@L6"JX+<@KF"\0!!=71H7VQD87`Z($%C=&EV92!$:7)E
M8W1O<GD@@L6"S(.&@5N#58U8D%:"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O$`
M075T:%]M8V%L.B!-0T%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T
M:%]S;6)A=71H.B!S;6)A=71HBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`
M24U!4(-4@5N#;X+%@LR41H_8@LF.N)1S@K6"W(*U@KV!0@"41H_8@LF.N)1S
M@K6"W(*U@KT`E$:/V(+)CKB4<X*U@MR"M8*]@4(E<P!2041)55.#5(%;@V^"
MR8+F@NB41H_8@JJ+D93;@K."ZH+<@K6"O8%"`$944(-4@5N#;X+,E$:/V(+)
MCKB4<X*U@MR"M8*]@4(`4TU"@U2!6X-O@LR41H_8@LF.N)1S@K6"W(*U@KV!
M0@".9Y=PB<*47(+(@W2#0H%;@XN#:(%&`(-!@UN#BX-O@T.#5X.#@Y.+I)AA
MC9$`E'>,:0"4=XQID$8`2V5R;V)E<F]S((-P@UB#CX%;@VB"JI:SC/B"Q8*W
M@4(`2V5R;V)E<F]S((.&@5N#59:\@JJ6LXSX@L6"MX%"`(-O@VZ#?0"#;X%;
M@XR!6X.3`(-O@Y.#3X.)@V:#5H.%D&R6KXNDF&&-D0"#;X.+@V^#:(-8`(KN
MEGN#3X.)@W2#0H-.@UB"S(-F@T*#C(-.@V>#BH%;("(E<R(@@JJ"H(+H@MR"
MN8+Q@4(`BNZ/@)#\`(-X@XF#BX%;@U:+I)AAC9$`@WB#BX--@5L`@WB#BH%;
M@UD`@WB#:8.3BZ2888V1`(-O@WZ#A8%;@U^!:8^4DX>!:@"#=8%;@UZ#DXFD
MC9$`DF&0MI/Z`(-U@XV#8H-.("(E<R(@@LR#08-V@XJ#4(%;@U:#AX.3("(E
M<R(@@JJ"H(+H@MR"N8+Q@4(`@W6#C8-B@TZ0W9+H`(-U@XV#8H-.@UZ#0X-V
M`)&^CIH`@WN#BH-R@T&+I)AAC9$`@W6#8H-.@WV!6X-.`(F/`(F/@LR1OH*S
M@48`B8\`@WN#6(-J@T&!18-W@XN#8X-&@U.#<H-I`(-[@V.#CX-IBZ2888V1
M`(-U@5N#>).'`(-U@XF#5X.+`(EPE\R#0X.3@VB/E).'`(-U@XN#;(-#@46#
M7X.+@U2#B8%;@X``@W6#BX-+@XJ#00")TX_PCY&"JP"#=8.+@TR#:8-T@T"#
M7`"#=8.+@Y.#5XNDF&&-D0!#35,`0U)#`$-23""4>I5Z@WR#0X.3@V<`7T6#
M6H.+D:Z0JRXN+@"#3(.#@V*#5H.%@LR/B8KZB;N"JHJNE[F"M8+<@KF"\8+%
M@K6"O8%"`)=<DNB57`"#2H.3@WN#5X-!`(-*@X&#BX%;@Y.+I)AAC9$`@W"#
M6(./@5N#:(+-CJF3KH+%@LV#BH-:@V*#9X+%@JN"W(*Y@O&!0HK'EYV.TH+)
MF$&7C8*U@L2)NH*S@J*!0@"#=(-`@T.#BR`B)7,B((+)CY&"KX+<@KF"\8%"
M`(I/E92"S(-:@V*#5H.'@Y.#;H.3@VB#B8%;@LV*QY>=@L6"JX+<@KF"\8%"
M`$E-05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O3H@)7,`@W2#0(-#
M@XL@(B5S(B""JHI*@J^"W(*Y@O&!0@"#2H-I@U\`@TR#@X.3@UJ#BP"/X8I1
ME?&-D(+P@TR#@X.3@UJ#BX*W@ND`@W2#0(-#@XL@(B5S(B""\(WMCYR"Q8*K
M@MR"N8+Q@4(`C>R+QH-F@T*#C(-.@V>#BH*JC*F5=(*I@NB"W(*Y@O&!0@`G
M=&%R9V5T1FEL92<@@W"#B8.!@5N#7H+(@K6"Q8+-D;&-<X+%@JN"W(*Y@O&!
M0@"#9H-"@XR#3H-G@XJ!6R`B)7,B((+PC>V/G(+%@JN"W(*Y@O&!0@"-[8^<
M@L6"JX+<@KF"\8%"CG&1MX*J("5D()&VC=V"M8+<@K>!0@"5P(+7D=:"IH+,
MD<Z/VX+,D)2"JI7;D;:"LX+J@L2"HH+ID)2"QHV'@NV"R(*B@LR"Q97`@M>1
MUH*F@JJ"Q8*K@MR"N8+Q@4(`CG>2Z(*S@NJ"O934C8:"R8.!@V*#6H%;@U>"
M\)1ZD9>"Q8*K@MR"N8+Q@L6"M8*]@4(`@TJ!6X-\@WB#BX-FBZ2888V1`)5<
MD>@`@TR#@X.*@T$`E:J7WH+&@XF#>(.+`(-0@T.#?8.3CY23AP",9Y'1DV28
M8@"#6H.+D:Z0JP"#6H.+EH21D(%&`(-:@XN1KI"K`(-:@XN77922@48`C&>1
MT9-DF&(`DH:)FP"2AHF;@T&#=(.*@TJ+I)AAC9$`C]B6OH^1@LR/VHW7`(_8
MEKZ/D8+,CXJ73([2`(_8EKZ/D8-\@XJ#5H%;`(-@@X.#:(NDF&&-D0"5SXU8
M`(-P@UB#CX%;@VB"\)7/C5@`DV2.<8.!@T.#BX+)CF>7<(*W@NF6O)%/@L:#
M08-H@XR#6(+PE<^-6(*U@MR"MX%"`(R[C=V"S)#=DNB"Q8+-@W"#6(./@5N#
M:(+,E<^-6(+P@U2#?(%;@V>"M8+$@J*"W(*Y@O&!0HK'EYV.TH+)F$&7C8*U
M@L2)NH*S@J*!0@!?2X.*@Y.#3H+P@V"#1H-B@TXN+BX`@V"#BHNDF&&-D0"2
MAHG8D&R6KXNDF&&-D0"#08-V@XJ#4(%;@U:#AX.3D4F1\(%&`(-P@UB#CX%;
M@VB"\)%)D?``@X:!6X-5EKR"\)%)D?``D_J5=)5<CJ:,8(ZN@48`@TZ#BH-8
M@WV#6).'`(-.@XF#6)+HBV`@)7,@@JJ,J95T@JF"Z(+<@KF"\8%"`$U3+4]F
M9FEC98+,@UZ#3X+PCN:"Z(^<@JT`C)^-]8_!BXX`@X:!6X-5@LR1WHN.@48E
M<P"#AH%;@U6/P8N.`(.&@5N#58-F@5N#7H_!BXX`@TZ#BH-B@TZ"MX+I@L:.
MGX+6`(-%@T*#DX-H@T6"\)7"@K:"Z0"#4H-2@UB/E).'`(-4@T.#:(-O@5N"
M\(_T@MX`@U*#C8.3@W*#08NDF&&-D0"01@"01I%)D?``D$:129'P`)?Q@48`
ME_&#7H-#@V>#BP"#4H-^@V*#3H-8`(-2@WV#DX-H`(-2@WV#DX-H@U:#1H.+
M`(-2@X&#DX-G`(NDDLJ6O`"#4H."@XV808V'`(GOCM``D-V2Z(+,C;>5J@!0
M1$&!08-8@WV!6X-G@W2#2(.3@4%/=71L;V]K@L:"S).OBOJ"\)#=DNB"M8+<
M@K>!0@"0W9+H@LV/W):ABOJ,P)#8@NJ"Q8*W@4(`)7,@@O"0W9+H@K>"Z0"#
M<(-8@X^!6X-H@O"*;91&`(-2@Y.#4XNDF&&-D0"#4H.3@U.6KX[EBZ2888V1
M`)#:D;&.N)1S@4(`D-J1L8ZXE'.!1@",]H]/C*Z#5(%;@V^"UH+,D-J1L8*J
MBY&4VX*S@NJ"W(*U@KV!0@",]HI*C*Z#5(%;@V^"UH+,D-J1L8*JBY&4VX*S
M@NJ"W(*U@KV!0I>=EU*!1B5S("@E<RD`1E10@U2!6X-O@M:"S)#:D;&"R8ZX
ME'."M8+<@K6"O8%"`)A!EXV0Y@"809>-D.:"S8-!@VB#C(-8DJ""R9+'B<&"
MLX+J@MR"M8*]@4(`B+./:X-T@T"#0X.+@LR#4H.3@V6#DX-C@UZ#0X-V@48`
M(B5S(B""S)/@EV4`D;&"K0"#3H-B@TZ/E).'`(-2@W.!6P"#4H-S@5N.N)1S
M@48E<P"129'PE,V(S8+P@U*#<X%;`(-2@UB#7H.*@TJ+I)AAC9$`@U*!6X-G
M@U>#>X./@5N#BXNDF&&-D0"#@8-B@UJ!6X-7@LP@4$=0((C#C8:)NX*J@L6"
MJX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!01U`@CY"6O(*J@L6"JX+<
M@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!3+TU)344@B,.-AHF[@JJ"Q8*K
M@MR"N8+Q@L6"M8*]@4(`@X&#8H-:@5N#5X+,(%,O34E-12"/D):\@JJ"Q8*K
M@MR"N8+Q@L6"M8*]@4(`F$&7C9#F@O"2QXG!@L6"JX+<@KF"\8+%@K6"O8%"
M)7,`3$1!4""#5(%;@V^"R8-O@T.#DX-H@L6"JX+<@KF"\8+%@K6"O8%"`(YC
MC8*"JHIME$:"Q8*K@MR"N8+Q@L6"M8*]@4(E<P!,1$%0((-4@5N#;X+)D-J1
ML8+%@JN"W(*Y@O&"Q8*U@KV!0@!&5%`@@L6#5(%;@V\@(B5S(B""R9#:D;&"
MQ8*K@MR"N8+Q@L6"M8*].B`E<P"1EY!-D.:#BH-8@V>"JHWLD*R"Q8*K@MR"
MN8+Q@L6"M8*]@4(E<P!01U`@@V:!6X->@LR5G(V&B;N"JH+%@JN"W(*Y@O&"
MQ8*U@KTZ`%,O34E-12"#9H%;@UZ"S)6<C8:)NX*J@L6"JX+<@KF"\8+%@K6"
MO8%"`)A!EXV0YH*JC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0YH.*
M@UB#9X*JC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)#=DNB-6)!6EW"#6(-.
M@XJ#=H-G("(E<R(@@O"-[8^<@L6"JX+<@KF"\8+%@K6"O8%"`([SD$V.TH+,
MDV2.<8.!@5N#BX-!@VB#C(-8@JJ*;9+H@L6"JX+<@KF"\8+%@K6"O8%"`(-!
M@VB#C(-8DJ""JHJND5."R8+-CN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0@"1EY!-
MD.:#BH-8@V>"JHJND5."R8+-CN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0@"1EY!-
MD.:#BH-8@V>"JHJND5."R8+-CN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0@"#6(-G
M@XF#98-7@5L@(B5S(B""\(.-@5N#:(+%@JN"W(*Y@O&"Q8*U@KV!0@!-:V1I
M<B`B)7,B((+)CKB4<X*U@MR"M8*]@4(`C/:*2HRN@O",KH-4@5N#;X*I@N>.
MYI.^@L6"JX+<@KF"\8+%@K6"O8%"`"(E<R(@@O"/D8*KC9Z"W9=P@LF#28%;
M@W:#DX+%@JN"W(*Y@O&"Q8*U@KV!0@`E<R""\(-)@5N#=H.3@L6"JX+<@KF"
M\8+%@K6"O8%"`)7;CN>-[(O&@X*#5X.%@5N#BR`E<R""\(I*@J^"W(*Y@O&"
MQ8*U@KV!0@"#9H-"@XR#3H-G@XJ!6R`B)7,B((*JBDJ"KX+<@KF"\8+%@K6"
MO8%"`$Q$05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8%"`"5S((*JD\>"W8]O
M@KF"W(*Y@O&!0@"7=HN!@K."ZH*]@X:!6X-5@LR#<(-8@X^!6X-H@O"#BH-:
M@V*#9X+%@JN"W(*Y@O&"Q8*U@KV!0H*B@JV"PH*I@J""Z8*B@LV14X+$@LR/
M[I7Q@LV*U(CA@L&"Q(*B@MR"MX%"C<23>(Z.@K6"Q(+=@NF"J8K'EYV.TH+)
MF$&7C8*U@L2)NH*S@J*!0@!!0TP@@O".YI.^@L6"JX+<@KF"\8+%@K6"O0"#
M08-H@XR#6)*@@O".YI.^@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#
M6(-G@O".YI.^@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G@O".
MYI.^@L6"JX+<@KF"\8+%@K6"O8%")7,`@U2!6X-O@LR+0)1<B.J7EX+PCN:3
MOH+%@JN"W(*Y@O&"Q8*U@KT`D-V2Z(+PC+."R9;?@KF"W(*Y@O&"Q8*U@KV!
M0@`B)7,B((-F@T*#C(-.@V>#BH%;@JJ-[8^<@L6"JX+<@KF"\8%"`"5S()#=
MDNB"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(`D-V2Z(+,@V^#8H-.@T&#8H-V
M@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%"`)#=DNB"S(-O@V*#3H-!@V*#=H+P
ME=N1MH+%@JN"W(*Y@O&"Q8*U@KV!1B5S`)#=DNB-6)!6EW"#6(-.@XJ#=H-G
M@O`@(B5S(B""R97;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(`D-V2Z(+,@V^#8H-.
M@T&#8H-V@W2#0(-#@XL@)7,@@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%"`)#=
MDNB#=(-`@T.#BR`E<R""R97;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(E<R""R9;?
M@L&"Q)7;D;:#28-V@U:#AX.3@O".P(US@K>"Z8*I@4&.Z(+%@K&"S(GFELJ"
MS(-2@5N#:(+P("5S((+)@U*#<X%;@K6"Q(FZ@K."HH%"`$Q$05`@@U2!6X-O
M@JJ,GXWU@L6"JX+<@KF"\8%"`"(E<R(@@O"-[8^<*'5N;&EN:RF"Q8*K@MR"
MN8+Q@L6"M8*]@4(`F$&7C9#F@O"-6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,`
MD9>039#F@XJ#6(-G@O"-6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,`(B5S(B""
MS)#=DNB"JH^1@JN-GH+?@MR"N8+Q@48E<P!-;WII;&QA((+,@U2#0X-H@V^!
M6X*JC*F5=(*I@NB"W(*Y@O&!0H-4@T.#:(-O@5N"\(I*@J*"Q(FZ@K."HH%"
M`(V1`(WLD*P`D%:+2XWLD*P`@U2#=8-T@TB#BX-?@O"-[)"L`(WLD*R.TH+,
M@T&#3H-:@UB,H`"#3H.,@U>#8H-G@TJ!6X-HE-2-A@"#3H.-@T&#8(-!BZ28
M88V1`(-,@X6!6X-OBZ2888V1`(R[C=V"S(-:@V*#5H.'@Y,`C+N-W8+,CIZ*
MU`",NXW=@LP@55),((+-`(R[C=V"S(.&@5N#58%;`"5S((+6@LR#C8-/@TF#
MDXZ>@LF.P(US@K>"Z8->@UB#3H+PD-V2Z(*U@MR"MX%"`)#8@NB.YH+H`)%)
MD?"4S8C-@O"0V(+HCN:"Z`"#3(-V@XV#6(NDF&&-D0"#8(-&@U*+I)AAC9$`
MD_H`EHB3^@!$871A5')E92")>Y>7`(-F@5N#7H-X@5N#6(Y1C\8`D_J5=`"#
M9H%;@UZ.\Y!-`)/ZE72129'P`%],E_&"S(WMCYP`,3*,C@"/7)!ID)0`DFF)
MNH*P@O"0\X*M`(-F@W2#2(.+@V<`@V:#=(-(@XN#9Y!&`(-F@W2#2(.+@V<@
M240`@V:#=(-(@XN#9R!S:&5L;`"-[8^<`(-:@XN-[8^<`(-/@XN!6X-V@O"-
M[8^<`(.-@T^"S(WMCYP`@T&#3H-:@UB,H(+PC>V/G`"#6H.+C>V/G`"7\8+,
MC>V/G`"1XY'6@V6#DX-V@XR!6X-G@LR-[8^<`(.!@V*#6H%;@U>"\(WMCYP`
M(B5S(B""S(-!@TZ#6H-8C*""\(WMCYP`(B5S(B""S(-!@TZ#6H-8C*""QH*[
M@LR#5(-U@T&#3H-:@UB,H(+PD5."Q(WMCYR"M8+<@K>"J8%(`(US@LR-[8^<
M`)%)D?""M8*]242"\(WMCYP`@U2#=8-T@TB#BX-?@O"-[8^<`(R[C=V(RI)U
M@LR7\8+PC>V/G`",NXW=B,J2=8+,C7."\(WMCYP`D-V2Z(U8D%:7<(-8@TZ#
MBH-V@V<@(B5S(B""\(WMCYR"M8+<@K6"O8%"`)1ZD9>.GHK4`(-F@Y.#?8%;
M@TX`C^&*49/@EV6"S)#@EKX`D."6O@"/VHW7@6E(;W)D98+,@XV#3X-T@T"#
M0X.+@N".48_&@6J!1@"/VHW7@LV*QY>=CM*"S(*]@M^"R8M,F%Z"LX+J@MR"
MM8*]@4(`BDJ4K0"-MH*I@N>)18+6`(E%@JF"YXVV@M8`,C2.GHK4E5R.I@"5
M7(ZF@TF#=H-6@X>#DP"#5X-U@V"+I)AAC9$`C>V/G(*U@LB"H@!M86EN=&5N
M86YC92YP:'`@@LF2O)#:@T&#3H-:@UB"M8+(@J*"Q8*M@KZ"LX*B`(W%CXF"
MS)?Q@JJ#=(-"@5N#BX-HEKR"\(K<@O&"Q8*B@MR"MX*I/R""NX*D@LB"YX-@
M@T:#8H-.@K6"Q(*M@KZ"LX*B@48`@VB#?H-J@TH`@VB#?H-J@TJ+I)AAC9$`
M@T&#2H-%@Y.#9X*JE4N7=H+(@N>#5(-#@Y.#08-B@W:!0@"#7X-%@Y.#C8%;
M@V@`)7,@@LR#7X-%@Y.#C8%;@V@`D+:0K(*S@NJ"O9#=DNB"\"!02%`@@UB#
M3H.*@W:#9X+P@L:"M8+$@U^#18.3@XV!6X-H@K>"Z8%"`)-DCG&#@8%;@XL`
M@T>#3H-!@VB#BXNDF&&-D0"5TH]7`(-U@XV#8H-.@LR5TH]7`(-/@XN!6X-V
M@LR5TH]7`(-!@TZ#6H-8C*""S)72CU<`@T&#3H-:@UB,H(+,E=*/5P`E<R""
MS(-!@TZ#6H-8C*""S)72CU<`@TF#=H-6@X>#DX+,E=*/5X%&`"(E<R(@@LR#
M08-.@UJ#6(R@@LR5TH]7`"5S((+,@T&#3H-:@UB,H(+,E=*/5P"#1X-7@W:#
M9X%%@T&#B8-UBZ2888V1`(-'@XN#5(.+@V^#:(.+BZ2888V1`)-DCG&#@8%;
M@XL`18.!@5N#BX-!@VB#C(-8`$6#@8%;@XN#08-H@XR#6(*JB.J2=H*U@LB"
MKX+J@LZ"HH*O@MR"N8+Q@4(`18.!@5N#BX-!@VB#C(-8BFV41@"+\X.!@V*#
M6H%;@U>"Q8*W@4(`B;V"X(RI@L*"J8+H@MR"N8+Q@4(`B_."S(R?C?6,Z@"#
M38.#@XF#BH%;@JF"YXGFD9R"\)%]D_R"Q8*K@NF"YH*D@LF"M8+<@K>"J8%(
M`(E%@TZ#BH-B@TZ"Q8.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2`"#1X-F@T*#
M7H%;B>:6RH+PD>6"JX*M`(*@@LB"O8+,@W"#6(./@5N#:(+P@XJ#6H-B@V>"
MMX+ICIZ"S)=PD%."S(*]@M^"S(Z_EN*"\)/\E\V!0I?A@J:"SH%!@76#>8-B
M@V>"S):\D4^"S8%(@7:!1@")YI&<@LQ54DR"\)/\E\T`D-23N8--@VJ#08ND
MF&&-D0"#1X.*@V>#BH-!`(-'@XF!6P"#=8.-@V*#3HWLD*R#1X.)@5LZ("5S
M+@"3KXKZ@XV#3X+,C>V/G(-'@XF!6SH@)7,N`)/@EV6.YI.^@T>#B8%;.B`E
M<RX`@W"#6(./@5N#:(U8D%:#1X.)@5LZ("5S+@"#@8%;@XN#08-H@XR#6(+,
M@T>#B8%;@L6"MX%"`"(E<R(@@LR/D8*KC9Z"W8-'@XF!6X+%@K>!0@"#1X-8
M@V>#:H-!BZ2888V1`(-'@V"#28-S@T$`@XB!6X.-@V*#<``Q-96JEH@`,I6J
MEH@`,S"5JI:(`#65JI:(`(.-@T^#0X.3EH@`,S"5JI:(`#&5JI:(`(YWDNB2
M;(+,E^$`CL"-<P"35XI*`(-4@T.#:(-O@5N"\)-7BDH`)RDG((+PDU>*2@"7
M3(SXBOJ,P`".=Y"4`)%/C&F01@"0W9+H@O`@1E10((+%@T&#8H-V@XV!6X-H
M@K>"Z0"#=H.,@W2#0(.,@Y.#6)#=DNB"\([FD[Z"Q8*K@MR"N8+Q@4(`3$1!
M4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*]@4(`4TU"((-4@5N#;X+)
MD-J1L8+%@JN"W(*Y@O&"Q8*U@KV!0@`B)7,B((*I@N>"S(-2@W.!6X+)CKB4
M<X*U@MR"M8*]@4(`(B5S(B""UH+,@U*#<X%;@LF.N)1S@K6"W(*U@KV!0@"0
M5HM+@LP@4T%33""0VI&Q@LF.N)1S@K6"W(*U@KV!0@`B)7,B((+6@LR(VI.N
M@LF.N)1S@K6"W(*U@KV!0@".YI.^@LF.N)1S@K6"W(*U@KV!1B5S`(-T@TB!
M6X-.@XF#DX-HCY23AX%I@WV#BX-R@VF#6(^4DX>!:@"#=(-&@XV!6X^4DX<`
MDG:6O9-)@T>#B8%;@48`1D%8`$9!6`""48R.`(-T@T*#5X%;CY23AXNDF&&-
MD0"#=(-`@T.#BP"#=(-`@T.#BY"4.B`E<R"#=(-`@T.#BP"#=(-`@T.#BY"4
M.B`E<R"#=(-`@T.#BP"#=(-`@T.#BX-]@VR!6X-7@X,`@W2#0(-#@XN6O`"#
M=(-`@T.#BY%)D?``@W2#0(-#@XN#08-B@W:#C8%;@V@`@W2#0(-#@XN#08-B
M@W:#C8%;@VB"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0@"#=(-"@XN#7@"#
M=(-"@Y.#B8.3@VB+I)AAC9$`C^.,MX+,C(X`@W2#2(.+@U^!6R`E<R""JH*@
M@NB"W(*Y@O$`E;:.FI!&`(GFD9R"\(-4@WR!6X-G@K6"R(*B@W6#B8-%@U67
M<`"#<(-8@X^!6X-H@O"668+J@L2"M8+<@J*"W(*U@KV"J8%(`(-T@TB!6X.`
M`(-T@TB!6X.)@X``B^``F&<`@W2#B8.3@UB+I)AAC9$`@W2#B8.3@UB!:99[
MC9&!:@"#=(.)@Y.#6)?,@TV#08-I`(-T@XF#DX-8E\R#?(.*@VR#5H-!`(-T
M@XF#DX-8E\R+R9/LCY23AP"/VH*U@J*0X):^`):>C(X`CH&6O`"#2X-[@Y.+
MI)AAC9$`B>:1G(+PCN:"Z(]O@K>#38.#@XF#BH%;`(--@X.#B8.*@5N!1@"#
M2X.3@W*#08NDF&&-D0`E<R"-7)"LC^Z5\8+PD+:0K(*W@ND`D+:0K(*S@NJ"
MO8-2@5N#:`"#3X.+@U>#08NDF&&-D0"#:(-#@V.8099-BZ2888V1`(-+@5N#
M:8NDF&&-D0"#5X-U@XF#BX->@XL`D*D`BZ22RH-)@W:#5H.'@Y,`1V]O9VQE
M((-]@V*#=@!';V]G;&4@C)^-]0"#38.*@U:#@XNDF&&-D0"#3X.*@5N#DX.)
M@Y.#:`"#3X.,@VF#7P"#3X.+@5N#=HK'EYT`@T^#BX%;@W:6O(+-B_.4DH+%
M@LV"R(*B@K&"Q@!'<F]U<%]L9&%P.B"#3X.+@5N#=B`E<R""\)+'B<&"Q8*K
M@MR"N8+Q@4*#5(%;@V^"S(F>DYHZ(`!'<F]U<%]L9&%P.B"#3X.+@5N#=B`E
M<R""\(WMCYR"Q8*K@MR"N8+Q`$=R;W5P7VQD87`Z((-/@XN!6X-V("5S((+P
MC5B05H+%@JN"W(*Y@O$`@T^#BX%;@W8`@T^#08-H@XN!6X-VDX<`@T^#08.`
MDX<`@T^#08-E@WV#B8NDF&&-D0"#2X%;@Y.#5X%;DX<`@U&#6(-G@T&#3H-:
M@UB,H`"#48-8@V>#=8-B@TX`@TV#:H-!BZ2888V1`(--@VJ#08-R@U2#18ND
MF&&-D0"#2X-#@T&#:8NDDZ^+I)AAC9$`2%144""41H_8@JJ"W8+"@JF"Z(+<
M@KF"\8%"`(-N@T.#8(NDF&&-D0"#;H-B@U:#A8-!@XN#4X.*@UF#@`"#=X-B
M@U\`@W>#8H-?`(-N@5N#:(%%@WV#3H-H@VF#BX-HCY23AP"-@H*S`(-W@XN#
M=@"4O(N%`(-Z@5N#@`"#C8%;@WV60(FDDJ&!:8-O@V"#2H.3CG.-D8%J`(-Z
M@5N#@`".J9'N@LR/6H^*`(-Z@5N#@(-F@T*#C(-.@V>#BH%;`(ZID>Z"S)-D
MF&*4U(V&`(-Z@Y.#5X.%@XF#6(NDF&&-D0"-@8U@`$AO<F1E`$AO<F1E+TMO
M;&%B.B"5<Y"S@L@@6$U,((-F@5N#7B`E<R""JH.!@V*#6H%;@U<@)7,@@L6,
MGX]O@K."ZH+<@K6"O0!(;W)D92]+;VQA8CH@@TF#=8-7@T:#3H-G("5S((+)
MD<Z)GH*W@NF#@8-B@UJ!6X-7@LV"H(+H@MR"N8+Q`$AO<F1E+TMO;&%B.B"#
M28-U@U>#1H-.@V>,7B`E<R""S8.!@V*#6H%;@U<@)7,@@LF"S8*@@NB"W(*Y
M@O$`2&]R9&4O2V]L86(Z("5S((+-C>V/G(*S@NJ"W(*U@KT@(B5S(@!(;W)D
M92]+;VQA8CH@4$A0((IGDJ,@)V1O;7AM;"<@@JJ52Y=V@L6"MP!(;W)D92]+
M;VQA8CH@@TF#=8-7@T:#3H-G("5S((+,(%A-3""#8X.*@5N"JHWLD*R"Q8*K
M@MR"N8+Q`$AO<F1E+TMO;&%B.B`E<R""JHWMCYR"Q8*K@MR"N8+Q("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B`E<R""S"!-24U%($E$((*JCN:3OH+%@JN"W(*Y
M@O$`2&]R9&4O2V]L86(Z("5S((+&DZ^*^H+%@JN"W(*Y@O$@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z().OBOJ"Q8*K@MR"N8+Q@48E<P!(;W)D92]+;VQA8CH@
M(B5S(B""S95SEKZ"R(NDETR"Q8*W`)"%E;V0_`""HH*M@L*"S)?Q@O",BXV'
M@K6"W(*W@JF!2`"#=(-"@5N#BX-H*(US*8+,D)2"S8*B@JV"PH+%@K>"J8%(
M`(*B@JV"PH+,C7."\(R+C8>"M8+<@K>"J8%(`(-N@Y.#2X.*@5N+I)AAC9$`
M24U!4""#@8%;@XN#>X-B@TZ#6(+,C>R0K(+)CKB4<X*U@MR"M8*].B`E<P!)
M34%0((.!@5N#BX-[@V*#3H-8@LR-[8^<@LF.N)1S@K6"W(*U@KTZ("5S`$E-
M05`@@X&!6X.+@WN#8H-.@UB#3H-(@5N#7H+,C>R0K(+)CKB4<X*U@MR"M8*]
M.B`E<P!)4""#08-H@XR#6`!)4""#08-H@XR#6(*J@J""Z(+<@KF"\8%"`$E0
M@T&#:(.,@UB"JHN6B<*"LX+J@KU#2412@W6#C8-B@TZ3X(+)@J""Z(+<@KF"
M\8%"`$E0E96-O8CAE+V"Q8*W@4(`@T&#0X-8@XF#DX-HBZ2888V1`(-!@T.#
M4H.3@LR"W0`E<R""S(-!@T.#4H.3`(-!@T.#4H.3@L:#98-,@UB#9P!)1(+,
MEKR13P""X(*U@N"0LX*U@JV57(ZF@K."ZH+(@J*"R(+G@4$E<R""M8+$D%:"
MM8*B@T6#0X.3@VB!6X+PBDJ"HH+$B;J"LX*B@4(`@N""M8+@($EN=&5R;F5T
M($5X<&QO<F5R((+PCF>"P8+$@J*"Q(%!@T&#0X-2@Y."JI5<CJ:"LX+J@LB"
MHH+(@N>!08*Q@K&"\)%)D?""M8+$B;J"LX*B@4(`B>:1G(-V@XR#<H.%@5L`
MB>:1G"!54DP`B>:1G"!54DPZ`(GFD9P`@T.#DX-\@5N#9X%!@UB#98-B@W8@
M)60`@T.#DX-\@5N#9X*S@NJ"O8-T@T*!6X.+@VB!1B`E<P"#0X.3@WR!6X-G
M@K."ZH*]@W2#0H%;@XN#:(%&`(K4B.&"P8*]@T&#3H-6@X>#DX-2@5N#:(*J
MEUZ"IH+G@NJ"Q(*B@MR"MX%"`(.&@5N#59:\@JF#<(-8@X^!6X-H@JJ0LX*U
M@JV"H(+H@MR"N8+Q@4(`@X:!6X-5EKR"J9'CD=:#08-H@XR#6(*JD+."M8*M
M@J""Z(+<@KF"\8%"C<23>(Z.@K6"Q(+=@NF"J8%!BL>7G8[2@LF809>-@K6"
MQ(FZ@K."HH%"`))IB;J"L(+PD%N"K0"#0X.3@V@`C,*5RH.&@5N#50"#0X.3
M@VB#;(-6@T&+I)AAC9$`C^Z5\0"#0X.3@W2#2(.!@5N#5H.'@Y,`7T^,XX+K
M@LF7\8+PD7V3_`")YI&<@O"1?9/\`)5<@O"1?9/\`(.*@Y.#3H+PD7V3_`!?
M0Y%/@LF7\8+PD7V3_`",NXW=B,J2=8+,C.."ZX+)E_&"\)%]D_P`C+N-W8C*
MDG6"S)%/@LF7\8+PD7V3_`",NXW=B,J2=8+,C.."ZX+)C7."\)%]D_P`C+N-
MW8C*DG6"S)%/@LF-<X+PD7V3_`",NXW=B,J2=8+,C.."ZX+)DFF7CH+PD7V3
M_`",NXW=B,J2=8+,D4^"R9)IEXZ"\)%]D_P`D>.1UH-E@Y.#=H.,@5N#9X+,
MD7V3_`"05H*U@J*#<(-8@X^!6X-H@O".\X*OCN:"Z8.!@5N#BX-!@VB#C(-8
M@O"3_)?-@48`C.."ZX+)@UJ#BX+PD7V3_`"13X+)@UJ#BX+PD7V3_`",XX+K
M@LF7\8+PD7V3_`"13X+)@UJ#BX+PD7V3_`"#@8-B@UJ!6X-7@O"1?9/\`(SC
M@NN"R9)IEXZ"\)%]D_P`D4^"R9)IEXZ"\)%]D_P`C.."ZX+)C7."\)%]D_P`
MD4^"R8US@O"1?9/\`)=PD%."S(*]@M^"S(Z_EN*"S).:@J:"\)/\E\V!1@")
MYI&<@LR1?9/\@5Z5SXU8`(.*@Y.#3H+,D7V3_(%>E<^-6`"1EY!-D.:"R9&7
M@NF"O8+?@LR.8XV"@JJ5<Y&K@K6"Q(*B@MR"MX%"`(YCC8*"JI5SD:N"Q8*W
M@4(`E7.0LX+((%II<""#9H%;@UZ"Q8*W@4(`E7.0LX+(@T&#=H.*@U"!6X-6
M@X>#DX+%@K>!0@"6LXSX@LB#9H%;@UZ"JI+QCV^"LX+J@MR"M8*]+@"1EX+H
MD.:"S(-!@VB#C(-8@JJ5<Y"S@L6"MX%"`)5SD+."R(.)@T.#6H.3@UB#3(-#
M@L6"MX%"`)5SD+."R(_JCXJ"JHYWDNB"LX+J@MR"M8*]@4(`C^.(RH+,@T&#
M3H-:@UB,H(*JE7.0LX+%@K>!0@"5<Y"S@LB#<(%;@V>#:8%;242"Q8*W@4(`
ME7.0LX+(D+N5:8-2@5N#:(+%@K>!0@"5<Y"S@LB#=H.-@V>#4H.+@L6"MX%"
M`)5SD+."R([SD$V.TH+%@K>!1B(E<R(`E7.0LX+(BZ273(-)@W6#5X-&@TZ#
M9P"5<Y"S@LB4K9!-C+.#08-H@XR#6(+%@K>!0@"5<Y"S@LAU;FEC;V1E@V:!
M6X->@L6"MX%"`)%)D?""\)2]DUT`@T.#B8.3@46#0X-8@XF#@(NDF&&-D0"#
M0X.)@TZ+I)AAC9$`@T&#0X.+@XF#DX-H`(-]@Y.3AP"#0X-8@XF#1X.+`)2M
MC7..T@".SI',`(-#@UZ#BH-!BZ2888V1`(-7@X.#?8-#@TH`@E",C@"3^I9[
M`(-7@X.!6X-7@5N3AP"#B(.+@U^#DP""5HR.`()5C(X`D;6"IH+I`)*&B9N1
MM8*F`)>\DEN1M8*F`(VVD;6"I@")19&U@J8`@TJ#58-T@UB#7H.3BZ2888V1
M`(-)@XJ#5X-I@XN"\)7;D;:!2`"#4(-J@T&+I)AAC9$`2V5R8F5R;W,@@U2!
M6X-O@JJ41H_8BY&4VX*U@MR"M8*]@4(`C*Z-[)"LD_H`C*Z.=Y;D`(RNDK<`
MC*Z.[9?>`)-DCG&,KH*J@K>"Q8+)C/:/3XRN@U2!6X-O@LF1MHW=@K6"W(*W
M@4(`@TR#BH-O@UB+I)AAC9$`DJF13I:OCN6.Y8M@D&R6KXNDF&&-D0"1Y8K8
MEJ^-D0"#3H-%@T:!6X-G`(-,@XN#38-8BZ2888V1`%]9@XR#0X-!@T6#9P",
MOHSJ`(.)@TF#6)!LEJ^6KX[EBZ2888V1`(FZC+>"S(R.`)%/B?&"S(.-@T^#
M0X.3.B`E<P"13XGQ@LR#C8-/@T.#DSH@)3(D<R""J8+G("4Q)',`D4^)\8+,
M@XV#3X-#@Y,Z((+(@K4`@XF#9X-R@T&+I)AAC9$`E'J2=0"#C(-O@VV#DXND
MF&&-D0"-M@"#C(-<@V>)I(V1`(.*@WB#BH-!BZ2888V1`)'E@XJ#<H-!@46#
M08.)@W6.T(GOCN6+8)!LEJ^#5X.#@WV!6X-Q@XJ!6X.$`(.*@W&#98.3@U:#
MA8->@T.#DXSVC9$`@XJ#DX-.`(.!@5N#BXWLD*R7<(+)@X&!6X.+@T&#:(.,
M@UB"R8.*@Y.#3H*W@ND`@V:!6X->@WB!6X-8B.J7EP"#=X.+@W:-@);:@O"5
M7(ZF@K>"Z0"57(+,B.J7EP"#6H-B@U:#AX.3@LR(ZI>7C>R0K(+)CKB4<X%&
M)7,`@X:!6X-5@LR(ZI>7C>R0K(+)CKB4<X%&)7,`@X:!6X-5@LR#BH-8@V>"
MS9:SC/B"R8+(@L&"Q(*B@MR"MX%"`(.*@V>#08-J@T&+I)AAC9$`@XV!6X-H
MDH8N+BX`C+N2;HZ>BM2!1@"2;HCF@L:.GHK4`(_JCXH`@XV#3X-#@Y,`@XV#
M3X-!@T6#9P"#C8-/@T.#DP"#C8-/@T.#DR"#7H-8@TX`@X:!6X-5EKR"J8-P
M@UB#CX%;@VB"JI"S@K6"K8+(@J*"O8+?@LF#C8-/@T.#DX+)CKB4<X*U@MR"
MM8*]@4(`@XV#3X-#@Y."R8ZXE'."M8+<@K6"O8%"`(--@XJ#5H.#E;:.FH%I
MCZR5MHZ:@6H`@XF#98.3E;:.FH%ICZR5MHZ:@6H`@XV!6X-]D)2.FH%ICZR5
MMHZ:@6H`@XN#3H-:@Y.#=8.+@TZ1Y8SVC9$`C(X`DUF5=(*S@NJ"O2!-4RU4
M3D5&((+-@V:!6X->@O"*W(+Q@L6"HH+<@KF"\8%"`(-]@TJ#20"#?8-0@VB#
M:H-!BXR#AH%;@U.#6(.)@W*#08NDF&&-D0"#?8-?@TN#6(-*@XN+I)AAC9$`
MDV2.<8.!@5N#BP"#?8.)@T6#0XNDF&&-D0"#?8.,@5N#5H-!`(."@XN#9H-"
M@W6+I)AAC9$`DV2.<8.!@5N#BP"#?8.+@UZ+I)AAC9$`D$:5=(*O@K."ZH*]
M@XF#>(.+@O"1SHF>@K."N8+$E:J7WH+PBL>7G8*U@MR"MX%"`()2C(X`@WV!
M6X-6@X.#BX^4DX>+I)AAC9$`@WV#BX-E@T*#:H-.DX<`@W2#0H%;@XN#:(+P
MB.J2=H*S@KF"Q(*B@MR"MP"#@H%;@XJ#7H-J@T&!18-#@UB#B8.`BZ2888V1
M`(."@5N#BH-6@X.#6(NDF&&-D0""5(R.`(-]@T.#B(-B@V>3AP"#@8.3@V\`
M@X&#:H.%@5N#@H%;@V@`@UJ#BXR+C8<`EGN5M@"#@8-B@UJ!6X-7@LV,GX_8
M@L6"JX+<@K6"O8*J@4&/D):\CM*"S)!GC+."S8R?C]B"Q8*K@MR"N8+Q@L6"
MM8*]@4(`@X&#7(-B@V@`@X&#7(-B@V@@(B5S(B""S9+HBV""LX+J@L2"W(*Y
M@O$`@X&#3(-6@U*-AX]/C9$`@WZ#3H.-@VR#5H-!F$&630!-:6UE(%1Y<&4`
M4$5!4B"#<(-B@U"!6X-7@LP@2%144%]297%U97-T((*JC*F3EH*]@NB"W(*Y
M@O&!0@"6HI#=DNB"Q8*W@4*"L8+,@T&#=H.*@U"!6X-6@X>#DX+PCF>7<(*W
M@NF"O8+?@LF"S9#=DNB#=(-`@T.#BX+PC>R0K(*W@NF52Y=V@JJ"H(+H@MR"
MMX%"`(.!@V*#6H%;@U<@240@@JJ,J9.6@KV"Z(+<@KF"\8%"`%!%05(@@W"#
M8H-0@5N#5X+,($UA:6P@@JJ,J9.6@KV"Z(+<@KF"\8%"`(-:@V*#5H.'@Y,@
M240@@JJ,J9.6@KV"Z(+<@KF"\8%"`(R.`(QGD=&#@8%;@XL`CT.0LY/Z`(."
M@XN#:(-OBZ2888V1`(."@VF#4HSVC9$`@X*#DX-3@XL`EHB,C@"#@H.3@V>#
M6H.)@V>3AP",CI?N`(."@XV#8H-2B:2-D0")NH+6`(VV@M8`B46"U@"/XX+6
M`(FZ@M8`C^."U@"#@H-5@Y.#<H%;@TZ+I)AAC9$`@T&#2H-%@Y.#9P"#08-*
M@T6#DX-GC^Z5\0"#?H.#@Y.#?8%;F$&630"3KXC3@K6"W(*Y@O$`EKR13P"#
M:8-^@W*#08NDF&&-D0"#:8-%@XN+I)AAC9$`@VR#<(%;@XN)I(V1`(-)@XF#
MDX-?B:2-D0"#28.)@Y.#7Y?,@T&#DX-E@T*#BX^4DX<`@VR#8H-G@X^!6X-.
M`(+(@K4`@W2#B8.3@UB7S(-J@X6!6X-*@XR#:(-J@T$`D%:+2Y6JE]X`D%:,
MC@"05H*U@J*#AH%;@U66O"B40XC3*0"#:H.%@5N#5X%;@XF#DX-H`)!6@K6"
MHH-P@UB#CX%;@V@`D%:"M8*B@W"#6(./@5N#:(+-("5X((+)BOJ,P)#8@NJ"
MR8+(@NB"W(*W@4(`D%:"M8*B@W"#6(./@5N#:(*JB.J2=H*U@MR"N8+Q@4(`
M@VJ#A8%;@U@`@VJ#A8%;@UB#3X.+@5N#=@".GP".GX+,@TF#=H-6@X>#DP".
MGX+,@WF!6X-7/@"#:H-*@XF#3X-!BZ2888V1`(-J@U>#1H%;@XN+I)AAC9$`
M@VF#0X-7@T:#BH-!F$&638NDF&&-D0"#:H-%@T>3AP"-MY6J@O"57(ZF@K>"
MZ8*]@M^"S)#=DNB"JH*@@NB"W(*Y@O&!0@"5SXU8@LB"M8%"`(*Q@LR#08-.
M@UJ#6(R@@LF"S8-4@W6#08-.@UJ#6(R@@LV2QXG!@L6"JX+<@KF"\8%"`"5S
M((+,D-V2Z(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`$944"!61E,@@LR-
M7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`4U%,(%9&4R""S(U<D*R/
M[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!344P@@TJ#98-3@XJ"S(U<D*R/
M[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@".8XV"@JJ"H(+H@MR"N8+Q@4(`
MD9>039#F@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"#=(-`@T.#BX*J@T&#8H-V
M@XV!6X-H@K."ZH+$@J*"W(*Y@O$`@T&#0X-2@Y."JH*@@NB"W(*Y@O&!0@"/
MZH^*@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"#@8-B@UJ!6X-7@JJ.=Y+H@K."
MZH+$@J*"W(*Y@O&!0@"6O)%/@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"4U(V&
M@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!(5%10()1&C]B"S(-P@UB#CX%;@VB"
MJH*@@NB"W(*Y@O&!0@!)34%0()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y
M@O&!0@!+97)B97)O<R"41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`
M@XV#3X-#@Y,@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`%!!4U-7
M1""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`4TU"()1&C]B"S(U<
MD*R/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!/<&5N4U-,((-V@XV#3X.)
M@X""S(-P@UB"JHYWDNB"LX+J@L2"HH+<@KF"\8%"3W!E;E-33"""S2!02T-3
M(#$R((+,@V:!6X->@O"(M8*D@LR"R95+EW:"Q8*W@4(`E=N7KX+,@U2#0X.3
M@T&#8H-V@LB"M8%"`(-.@TB!6X->@JJ0W9+H@K."ZH+$@J*"W(*Y@O&!0@"#
M6H-P@XR!6X->@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"*69.6@W2#0(-#@XN"
MR(*U`(.&@5N#59:\@JF#<(-8@X^!6X-H@JJ1EX+G@NJ"W(*Y@O&"Q8*U@KV!
M0@"6LXSX@LQ834R#9H%;@UZ"JI74@NB"W(*U@KT`DFR"R(*U`(-)@XJ#5X-I
M@XN"S)#=DNB#=(-`@T.#BX+)@V^!6X-7@X>#DX*J@J""Z(+<@KF"\8%"D-V2
MZ(+PC<20MI"L@K6"W(*W@4(`D-V2Z(-T@T"#0X.+@LF#;X%;@U>#AX.3@JJ"
MH(+H@MR"N8+Q@4*0W9+H@W2#0(-#@XN"\(WL@NB2O(*U@L2)NH*S@J*!0@""
MR(*U`(-M@5N#=(-(@5N#3I.'`)9KE+R+A0"6:X-]@XJ#08-ICY23AP"#;8.+
M@T6#1H%;B:2-D0""L8+J@N:"Z)%/`(*Q@NJ"YH+HC.,`@V:#0H.,@TZ#9X.*
M@L6"S8*@@NB"W(*Y@O$`CL"1E8*S@NJ"Q(*B@MR"N8+Q@4(`@U2#?(%;@V>"
MLX+J@L2"HH+<@KF"\8%"`(.!@X(`,3&,C@"0E`"5MHZ:D)0`E_&0E`"-<Y"4
M`)&7D$V0YH.*@UB#9X+PC5B05H*]@M^"S)34C8:"JHYWDNB"LX+J@MR"N8+Q
M@L6"M8*]@4(`3TL`@TF#=8-7@T:#3H-G`(-)@W6#5X-&@TZ#9XWLD*R.T@`Q
M,(R.`(-)@W2#0H-8`(S#@J*#<(-8@X^!6X-H`(S#@J*#<(-8@X^!6X-H@JJ0
MLX*U@JV"H(+H@MR"N8+Q`(-)@WV!6X.3`(NDETR#=(-(@XN#7X+-($E-05`@
M@U2!6X-O@KZ"KX*J@U2#?(%;@V>"Q8*K@MR"MX%"`)-DCG&#@8%;@XN#08-H
M@XR#6(+-,8+"@KZ"KXYWDNB"Q8*K@MR"MX%"`(^*ETR.TH*I@U:#6(-E@X"*
MQY>=CM*"OH*O@JJ+I)=,@LR/BI=,C*""QH-!@TZ#6H-8C*""\)7/C5B"Q8*K
M@MR"MP"05HM+@T6#0X.3@VB!6X+)E5R.I@!/<&5N4U-,((-'@XF!6X%&4R]-
M24U%((^0EKR"LX+J@KV#<(%;@V>"J8+G@V:!6X->@O".YH+HCV^"N8+<@KF"
M\8+%@K6"O8%"`(-)@W:#5H.'@Y,`)7,@@TF#=H-6@X>#DP"4U(V&E72)TX_P
MCY&"JP"19Y!$`)64CY``D*Z7G0",LX+,@T&#=H.*@U"!6X-6@X>#DX-E@Y.#
M=H.,@5N#9P"1O(+,@T.#DX-T@TB#@8%;@U:#AX.3`(^*ETR.TH+,@T&#3H-:
M@UB,H`!004T@E$:/V(+-CF>7<(+%@JN"W(*Y@O&!0@!01U`@DV2.<8^0EKP`
M4$=0((C#C8:5M@!01U`@C/:*2HRN`%!'4""/D):\C<\OB,.-AHF[@V:!6X->
M`%!(4(-2@5N#:`!02%"#5H-&@XL`4$]325@@BF>2HX*JC*F3EH*]@NB"W(*Y
M@O$`EH21D`"#<(-,@UB#7H.3@46#0X-8@XF#@(NDF&&-D0"#<(.)@TF+I)AA
MC9$`@W"#C(-8@V"#:8ZICJ&+Y@"#<(-I@WV+I)AAC9$`@W"#=H-!@VJ#A8%;
M@TV#:H-!D\:7IXV1`(-P@XF#3X-!@T.+I)AAC9$`@W"#6(./@5N#:`"#<(-8
M@X^!6X-H@LV0LX_M@LF5SXU8@K."ZH+<@K6"O8%"`(-P@UB#CX%;@VB"JI"S
M@K6"K8*@@NB"W(*Y@O$`4D%$2553()1&C]B"S(-P@UB#CX%;@VB"JI5+EW:"
MQ8*W@4(`@W"#6(./@5N#:(+,BFV41@"#<(-8@X^!6X-H.@"#<(-8@X^!6X-H
M.B``@W"#6(./@5N#:(*JB.J2=H*U@MR"N8+Q@4(`DUR"Z)5T@J\`@TZ#BH-B
M@W:#>X%;@VB"J8+GDUR"Z)5T@J\`@W"#6`"5VY>ODH:"S(-4@T.#DX-!@V*#
M=H%&`(-P@5N#6H.3@V<`E=N.YY&`C>R"\([`C7."MX+I`(.-@T^#0X.3CIZ"
MR97;CN>1@(WL@O".P(US@K6"W(*W@JF!2`"#08-.@UJ#6(R@`(-!@TZ#6H-8
MC*`@(B5S(B""S8WMCYR"LX+J@MR"N8+Q@L6"M8*]@4(`@T&#3H-:@UB"S8N1
ME-N"LX+J@MR"M8*]`(-!@TZ#6H-8C*``@T&#3H-:@UB,H(+,BL>7G0",PI!L
MC^Z5\0"#>8.+@5N+I)AAC9$`@W2#0H.*@W.#DXNDF&&-D0"39)AB`(-S@V>#
M4(-!@Y.3AP"#<X-.@UJ#BP",CH+&E$Z"\)/\E\V"M8+$@JV"OH*S@J*!0@"0
M5H*U@J*5JI?>@LR6O)%/@O"3_)?-@K6"Q(FZ@K."HCH`D+."M8*BD_J5=(+P
MD_R7S8*U@L2"K8*^@K."HBX@C(Z"S)/ZD)2"\(-@@T:#8H-.@K6"Q(*M@KZ"
MLX*B@4(`C^&*49/@EV6"\)=VEO&"M8+$@K*+3)/\@JV"OH*S@J*!0@"#AH%;
M@U66O(+&@W"#6(./@5N#:(+PD_R7S8*U@L2"K8*^@K."HH%"`(Z?@LR5MH^1
M@O"3QX+Q@L6"K8*^@K."HBX@@K&"S(-6@UB#98.`@O".9Y=P@K>"Z8*]@M^"
MS(M+DNB.EHV`@LF3KXC3@K>"Z95+EW:"JH*@@NB"W(*W@4(`@WR!6X.)@Y.#
M:(NDF&&-D0"3BI5;D)0`@WR#BX-G@TN#BXNDF&&-D0!0<F5F<U]L9&%P.B"5
M2Y=V@LA,1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`4')E9G-?;&1A
M<#H@E4N7=H+(<V5S<VEO;HIGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`(-V
M@XR#<H.%@5L`D%:"M8*B@T6#0X.3@VB!6X+)B>:1G(+PE5R.I@"13X+,@TF#
M=H-6@X>#DP"(\XW\`)3IEJ>,K@"/X8I1`(_ABE&3X)=E@LR0X):^`(SVBDJ,
MK@",]H]/C*Z#08.+@U.#BH-9@X``C/:*2HRNC^Z5\0",]H]/C*XOE.F6IXRN
M@JJ0MI"L@L6"JX+<@KF"\8+%@K6"O8%"`(-V@T>#BX-G@XJ#4@"#@8-B@UJ!
M6X-7@O"#<(%;@U<`@TJ#7H%;@XL`@TZ#1X.*@5L`@TJ#7H%;@XL`4E-!C/:/
M3XRN*"5D@W*#8H-G*0"4Y`"3QX+>`)9[DY:"R2`E<R""\(WMCYR"M8+<@K>"
MJ3\@@K&"S)&`C>R"S8RS@LF6WX*Y@MR"N8+Q@4(`EGN3EH+)@X:!6X-5("5S
M((+,@V:!6X->@O"-[8^<@K6"W(*W@JF!2"""L8+,D8"-[(+-CN:"Z(_!@KF"
MW(*Y@O&!0@"-Q8SC@LR1@(WL@O""XH+HDKR"MP"3KI-)@X&#:H.%@5N"S(W$
ME5R.IHK4BG4Z`(-\@5N#7H.+@LR-Q)5<CJ8`@XJ#C8%;@V@`@XJ#@H%;@V>#
M5(%;@W*#6`"#BH."@5N#9U523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(`"-[8^<`(-U@XV#8H-.@O"-[8^<`(^1CJZ"\(WMCYP`@WF#08+P
MC>V/G`"5VY&V@K6"O8-8@TZ#BH-V@V>"\(WLB\:#9H-"@XR#3H-G@XJ"J8+G
MC>V/G(*W@NF!0@"-[8^<@48`@K&"S(-M@5N#:(+P@VB#3(.%@X&#DX-G@JF"
MYXWMCYP`@X:!6X-5@O"-[8^<`(.&@5N#58+PC>V/G#H@)7,`EW:+@8+)E=23
MFH+%@JN"W(*Y@O$Z(`"7=HN!@K."ZH*]("(E<R(@@LT@)7,@@LR0W9+H@LF.
M=Y+H@K."ZH+$@J*"W(*Y@O&!0@"7=HN!@K."ZH*]("(E<R(@@LT@5D93()#=
MDNB"R8YWDNB"LX+J@L2"HH+<@KF"\8%"`)=VBX&"LX+J@KT@(B5S(B""S9#=
MDNB"R8YWDNB"LX+J@L2"HH+<@KF"\8%"`(.*@UJ#8H-G`(-P@UB#CX%;@VB"
M\(.*@UJ#8H-G`(*@@LB"O8+,@W"#6(./@5N#:(+P@XJ#6H-B@V<`C(N)R@"#
M28-V@U:#AX.3@LF6WX+I`(-P@UB#CX%;@VB"\(W$D_R7S0",LX+,C5R0K(+)
MEM^"MP"#98-,@UB#9X-'@V:#0H->@5N"S(-)@W:#5H.'@Y,`B44`EO"*A`"#
MBX%;@WV#:H-!`#$X,)-XB?&370"-MH+)B?&370")18+)B?&370"-<Y&ND*L`
MC7.1KI"K`(US@48`C'*0_`"14X+$@LR-<X+&E_&"S(K4@LF,<I#\@O"(^(*M
M`(US@LR*U(+)C'*0_(+PB/B"K0"7\8+,BM2"R8QRD/R"\(CX@JT`CL"-<P"#
MC8-6@T&8099-`(.+@X^#DX-?`%,O34E-12"(PXV&CY"6O`!3+TU)344@B,.-
MAI6V`%-!4TP@E$:/V(+-CF>7<(+%@JN"W(*Y@O&!0@!344P@@U:#1H.+`%-3
M2`"0K(SW`)-Y`(-:@Y.#9X-W@XR#:9.'`(-:@Y.#9X-,@V*#8X&5@VR!6X.4
M@T*#6`"#6H.3@V>#BX-6@T$`@U2#DX-S@T>!6X.+@46#?H-.@XV#DY.'`(-:
M@Y.#9X-S@Y.#6H.3@V>"J(+F@M&#3X.,@VF#9H-"@5N#DX^4DX<`@U2#@H-!
MD\:7IXV1`(-4@Y.#?8.*@VV+I)AAC9$`@U2#DX-G@X&!18-V@XJ#DX-6@WF6
MKX[EBZ2888V1`(-4@T6#5X-!@XF#<H-!B:2-D0"5VY&V`"(E<R(@@O"5VY&V
M`"5S((+PE=N1M@"#28-V@U:#AX.3@O"5VY&V`)"VD*R"LX+J@KV0W9+H@O`@
M4$A0((-8@TZ#BH-V@V>"QH*U@L2#5(%;@V^"S(WLB\:#9H-"@XR#3H-G@XJ"
MR97;D;:"MX+I@4(`)7,@D-V2Z(+PE=N1MH*U@MR"M8*]@4(`D-V2Z(U8D%:7
M<(-8@TZ#BH-V@V<@(B5S(B""\)7;D;:"M8+<@K6"O8%"`(R?C?4`C)^-]8-'
M@Y.#5X.3`(-T@T"#0X.+@O"129'P`)/ZE72"\(YWDNB"M8+$@JV"OH*S@J*!
M1@"2QXG!@K>"Z8-/@XN!6X-V@O"129'P@K6"Q(*M@KZ"LX*B`)!6@K6"HH^*
MCIV.TH+PD4F1\(*U@L2"K8*^@K."H@"#5(%;@V^"\)%)D?""M8+$@JV"OH*S
M@J(`DL>)P8*W@NF#AH%;@U6"\)%)D?""M8+$@JV"OH*S@J(`D5."Q)%)D?``
ME4N7=H+(E;:.FH+PB;J"S(-[@V*#3H-8@JF"YY%)@O&"Q8-2@W.!6X*W@NF"
MQH%!@V6#3(-8@V>#1X.*@T&"UH-Y@5N#6(-G@L6"JX+<@K>!0@"3^I5T@LR+
MYI#8@NB5MHZ:@O".=Y+H@K6"Q(*M@KZ"LX*B@48`D_J5=(+,C&".KH+PCG>2
MZ(*U@L2"K8*^@K."HH%&`)7/C5B"M8*]@J))1(+PD4F1\#H`CIZ-CX+,B^:0
MV(+HE;:.FH+PCG>2Z(*U@L2"K8*^@K."HH%&`(Z>C8^"S(Q@CJZ"\(YWDNB"
MM8+$@JV"OH*S@J*!1@"(ZI)V@K>"Z8)1@L*"S(-T@T*!6X.+@VB"\)%)@O&"
MQ8*M@KZ"LX*B@4(`D$:2LH+PD4F1\(*U@L2"K8*^@K."HBX`C+Z,ZH+PD4F1
M\(*U@L2"K8*^@K."HCH`C^&*48.,@WR!6X-G@O"1EY!-@K>"Z0!335,@D9>0
M30"#6H-L@TN#BXNDF&&-D0""6(R.`(-:@XN#<H-!@46#@H.3@V6#;(-/@XT`
MDLJ4U`"#6H-B@U:#AX.3BL>7G0"#6H-B@U:#AX.3`)99@NJ"Q(*U@MR"P8*]
M@W"#6(./@5N#:(+P@XJ#6H-B@V>"Q8*K@NF"YH*D@LF"M8+<@K>!0@"#?(%;
M@UZ#BX+%@T&#3H-:@UB"MX+I@XJ#@H%;@V>#5(%;@V^"\)#=DNB"M8+<@K>!
M0@",OHSJ@4&.GHK4D=&!09/ZE72"\)#=DNB"M8+<@K>!0@"*2HYNCIZ"S(-!
M@W:#BH-0@5N#5H.'@Y.!09!&DK*!08-Y@5N#5XW$E5R.IH%!@KN"S)&\@LR5
M7(ZF@TF#=H-6@X>#DX+PD4F1\(*U@L2"K8*^@K."HBX`D-V2Z`"0W9+HC5B0
M5H-8@TZ#BH-V@V<`@UJ!6X-6@T:#BXNDF&&-D0"*R))0@LB7=I;Q@48`@6F#
M@8-J@X6!6X+(@L>"Q8%J@U:#AX%;@V>#2H-B@V>#3(%;@JJ.9X*F@NF"YH*D
M@LF"M8+<@K>"J8%(`)5<CJ8`C+N-W8+,D-V2Z(+&D%:"M8*MD+:0K(*S@NJ"
MO9#=DNB"QH+,C;>5JH+PE5R.IH*W@NF!0@"#C8-/@T.#DXZ>@LF13XGQ@LR#
MC8-/@T.#DXZ>BM2"\)5<CJ:"M8+<@K>"J8%(`)5<D8"-[(.!@VJ#A8%;@O"5
M7(ZF@K6"W(*W@JF!2`")YI;*C;:"R2`E<R"#@8-J@X6!6X+PE5R.IH*U@MR"
MMX*I@4@`E5R"S(-:@XN1KI"K@U^#0X-!@XV#3X+PE5R.I@"57)&ND*N#7X-#
M@T&#C8-/@O"57(ZF`)5<@LR7\9&ND*N#7X-#@T&#C8-/@O"57(ZF`)5<@LR-
M<Y&ND*N#7X-#@T&#C8-/@O"57(ZF`(]KCZP`@MR"N)?7@NB"S(-U@XV#8H-.
M@O"/:X^L@MR"O8+-B-J3KH*S@KF"Q(*M@KZ"LX*B@4(`@U:#1X.)@XR#28-L
MBZ2888V1`(-4@T.#DX-!@V*#=@"39(YQCY"6O`"39(YQCY"6O(-!@XN#4X.*
M@UF#@`"#5H.3@TN#?(%;@XN+I)AAC9$`@U2#0X-9`)7;CN>"\(-8@TR#8H-V
M@K>"Z0"#6(.-@V^#3(-!BZ2888V1`(-8@XV#>(-J@T&+I)AAC9$`@UR#C8."
M@Y./E).'`(-<@WV#BH-!EJ^.Y8NDF&&-D0"5P(+1CX>"S)%)D?``D9>038RS
M@T&#:(.,@U@`D^R#08-T@XJ#2HNDF&&-D0"3[(-7@X>!6X-7@T&3AX%%D^R#
M5(.3@VB#0X-B@V"/E).'`)/LE+R+A0"7UX+,@UJ#BX+&@LR77922`(-:@XN"
MQHNKBD6"QH+,EUV4D@"77922`)==E)*"QI:$D9``@UB#>8-#@Y,`D\&.ZI6V
MCIJ"S)/\E\T`@UJ#BY6JBH0`E_&5JHJ$`(USE:J*A`"#6(.*@XF#DX-*EJ^.
MY8[0B>^.Y8M@BZ2888V1`(]"@MR"O8+-C*<`C_.1U`"/6H^*E-22;@".YH_!
M@K60_`"#6(->@T.#BR!;0U-370"3^@"#5(-U@V:#0H.,@TZ#9X.*("(E<R(@
M@JJ"H(+H@MR"N8+Q@4(`CL"-<P")NI5T@JL`D*R,]P`B)7,B((+-@U:#6(-E
M@X""R9+'B<&"LX+J@MR"M8*]@4(`(B5S(B""JH-6@UB#98.`@JF"YXWMCYR"
MLX+J@MR"M8*]@4(`(B5S(B""JHWMCYR"LX+J@MR"M8*]@4(`(B5S(B""JH-6
M@UB#98.`@JF"YXWMCYR"LX+J@MR"M8*]@4(`D-V2Z(+-D+./[8+)EM^"LX+J
M@MR"M8*]@4*#BH.-@5N#:(*U@L2*;91&@L6"JX+<@K>!0@"0W9+H@LR#;X-B
M@TZ#08-B@W:"S9"SC^V"R97;D;:"LX+J@MR"M8*]@4(`D-V2Z(-T@T"#0X.+
M@LR#;X-B@TZ#08-B@W8@)7,@@LV0LX_M@LF5VY&V@K."ZH+<@K6"O8%"`"(E
M<R(@@LV0LX_M@LF-6)!6@K."ZH+<@K6"O0`E<R""S9"SC^V"R8^1@JN-GH+<
M@NJ"W(*U@KT`@UB!6X-?@Y.+I)AAC9$`BE27=@"3^H+,CV\`D_J"S)/\@N@`
MD_J"S(]O+Y/Z@LR3_(+H`)/Z@LR/;X%&`)/ZEG8`D_J6=H%&`(_CE72"JP"#
M5(-\@5N#9P"#6(.*@VF#@(NDF&&-D0"0J0"#6(.4@T"!6X.+@V^#BX%!@X2#
MDX-]@T.#1X.3CY23AP"#6(./@U>#B8.3@VB)I(V1`(-8@T6#1H%;@V:#DXFD
MC9$`@UB#0X-8F$&630"#5H.*@T&!18-!@XF#=8NDF&&-D0!44U:#=(-`@T.#
MBP"57)&ND*L`E5R1KI"K`)'DF'``D>28<(%IDH:-D8+,B.J5E(%J`(->@U>#
M3(-8@UZ#DXNDF&&-D0"#7H.3@U6#:H-!F$&638NDF&&-D0"#7H-8@TX`DV28
M8I34C88`@V6#DX-V@XR!6X-G("(E<R(@@JJ"H(+H@MR"N8+Q@4(`@V6#DX-V
M@XR!6X-G@LR*QY>=`(-E@TR#6(-G@LR"W0"5MHZ:E'J2=0"5MHZ:@LR/XP"6
MV`"#7H-#B:2-D0!&5%`@BF>2HX*J@J""Z(+<@KF"\8%"`)>:E_"#5H-8@V6#
M@(+-EK.,^(+)@LB"P8+$@J*"W(*W@4(`36%I;G1E;F%N8V4@@TZ#B8-8@LR3
MQXV>@MV"JI"SC^V"R8US@J:"W(*Y@O&"Q8*U@KT`@TF#=H-6@X>#DX-%@T*#
MDX-H@T6"\)7"@K:"W(*U@KV!0H])E[F"M8+<@K>!0@"#08-.@UJ#6(R@@O"7
M3(SX@LF"MX+I@LF"S8K'EYV.TH*J@KN"S(-O@V*#3H-'@Y.#:(+PD-V2Z(*W
M@NF"L8+&@JJ52Y=V@L6"MX%"`)A!EXV0YDE$E-2-AH*JCG>2Z(*S@NJ"R(*I
M@L&"O8*I@4&+\X*^@L&"O8*I@4&"H(+I@J*"S8-F@5N#7H-X@5N#6)*&@LF,
MJ95T@JF"Z(+<@KF"\8+%@K6"O8%"`)A!EXV0YH+-@J""R(*]@LR#08-H@XR#
M6)*@@LF2QXG!@K."ZH+<@K6"O8%"`)-DCG&/D):\@K."ZH*]@X&#8H-:@5N#
M5X+PC)^/V(*W@NF"R8+-@4%01U`@CY"6O(*JE4N7=H+%@K>!0@"1EY!-D.9)
M1)34C8:"JHYWDNB"LX+J@LB"J8+!@KV"J8%!B_."OH+!@KV"J8%!@J""Z8*B
M@LV#9H%;@UZ#>(%;@UB2AH+)C*F5=(*I@NB"W(*Y@O&"Q8*U@KV!0@"1EY!-
MD.9)1)34C8:"JHYWDNB"LX+J@MR"N8+Q@L6"M8*]@4(`B,.-AHF[@LF"S8C`
MD5."R(-%@T:#=9#:D;&"JI5+EW:"Q8*W@4(`@W2#0(-#@XL@)7,@@LF"S2`E
M<R""S)#=DNB"JI5+D'N"Q8*W@4(`@W2#0(-#@XL@)7,@@LF"S2`E<R""S)#=
MDNB"JI5+D'N"Q8*W@4(`@W2#0(-#@XN"S8ZIE:J.J9!G@LF#4H-S@5N"Q8*K
M@MR"N8+Q@4(`@W2#0(-#@XN"JH-F@5N#7H+PBMR"\8+%@J*"W(*Y@O&!0@"(
MR(FZ@LV"L8+,@X&#8H-:@5N#5X%I4D9#.#(R@6J"S(-W@V*#7X+%@K>!0@"2
MC8C3@4D@@W2#BX-8@TZ#BH%;@Y.#@H%;@VB"S2!);G1E<FYE="!%>'!L;W)E
M<B""Q8+-EN*1Z(*JE*V0MH*W@NF"L8+&@JJ"H(+H@MR"MX%I@W6#B8-%@U6"
MS(-O@T^"Q8*W@6J!0HGFELJ"R8-3@WZ"JI5<CJ:"LX+J@KV"Z(%!5VEN9&]W
M<R""JH-.@XF#8H-6@X6"M8*]@NB"MX+I@JF"X(*U@NJ"W(*Y@O&!0@J#=(.+
M@UB#3H.*@5N#DX."@5N#:(+)@K>"Z8+(@N<@3TL@@O")GX*U@L2)NH*S@J*!
M0@!)1"`B)7,B((+-C>V/G(*S@NJ"W(*U@KV!0@!';G501R"#;X-#@VF#BH+,
M@W"#6(*J($-R>7!T7W!G<""#3H.)@UB"R9#=DNB"LX+J@L2"HH+IE4N7=H*J
M@J""Z(+<@K>!0@""L8+,@W2#0H%;@XN#:(+-D)2.FH+%@LB"KX+J@LZ"R(+H
M@MR"N8+Q@4(`2&]R9&5?0W)Y<'1?<VUI;66#3H.)@UB"R8+-;W!E;G-S;(."
M@U>#A8%;@XN"JI5+EW:"Q8*W@4(`@W:#C(-T@T"#C(.3@U@B)7,B@LV#9H%;
M@UZ"JH-4@T.#69"GC,""\(EZ@J:"O8*]@M^5VY&V@L6"JX+<@KF"\8+%@K6"
MO2X`@K&"S(-F@5N#7HQ>*"5S*8+PE5R.IH*W@NF"O8+?@LR#=H.-@T^#B8.`
M@JJ"L8+,@U:#6(-E@X""R8+=@L*"J8+H@MR"N8+Q@4(`B/B7<)6$@LV"4)6V
MCIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"`(OFD-B"Z)6$@LV"4)6VCIJ"Q8+(
M@J^"ZH+.@LB"Z(+<@KF"\8%"`(-4@5N#;R`B)7,B((+-C>V/G(*S@NJ"W(*U
M@KV!0@"#5(%;@V\@(B5S(B""S97;D;:"LX+J@MR"M8*]@4(`CG>2Z(*U@KV7
M\8%I)62!:H*J@J""Z(+<@KF"\8%"`(CJCIZ#=(-`@T.#BR`B)7,B((*J@J""
MZ(+<@KF"\8%"`(-!@V*#=H.-@5N#:(-F@5N#7H*JDKR13X+,@UB#98-B@W:"
MQ8_!CKB"M8+<@K6"O8%"`(-!@V*#=H.-@5N#:(-F@5N#7H+PE=N1MH+%@JN"
MW(*Y@O&"Q8*U@KV!0@"#98%;@WV#9H-"@XR#3H-G@XJ!6R`B)7,B((*J@J""
MZ(+<@KF"\8%"`(YWDNB"Q8*K@NF#28-V@U:#AX.3@LV"H(+H@MR"N8+Q@4(`
M@T.#DX.)@T.#DY5<CJ:"Q8*K@NF5E)6J@LV"H(+H@MR"N8+Q@4(`E;:.FI"4
M@JJ"L8+,@W2#0H%;@XN#:(+)D;V)WX*L@MR"MRX@)7,@@LR5MHZ:@JJ3_)?-
M@K."ZH+$@J*"W(*W+B`E<R"(R(FZ@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0@`B
M)7,B((+P@U:#6(-E@X""UI+'B<&2AH+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E
M<P"#AH%;@U4@(B5S(B""S(-F@5N#7H+P@U:#6(-E@X""J8+GC\&+CI*&@LF6
MXI'H@JJ4K9"V@K6"W(*U@KTZ`"(E<R(@@O"#5H-8@V6#@(*I@N>-[8^<DH:"
MR9;BD>B"JI2MD+:"M8+<@K6"O3H`(B5S(B""\(U8D%:2AH+)EN*1Z(*JE*V0
MMH*U@MR"M8*].B`E<P"#=(-`@T.#BX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0
MMH*U@MR"M8*].B`E<R""S8-!@V*#=H.-@5N#:(*S@NJ"Q(*B@MR"N8+Q@4(`
M@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,@
M@LV#=(-`@T.#BX+,@U2#0X-9D*>,P))L*"5D@V^#0X-G*8+PB7J"IH+$@J*"
MW(*W@4(`@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<@K6"
MO3H@)7,@@LV(ZI64@LR"W8-!@V*#=H.-@5N#:(*S@NJ"W(*U@KV!0@""L8+,
M@W"!6X-G@O"57(ZFDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]`)A!EXV0YH-F
M@5N#7H+,@T.#DX-\@5N#9Y*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"`&E#
M86QE;F1A<B""S(-#@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KTN
M`)#=DNB#=(-(@5N#@)*&@LF#1X.)@5N"JH*@@NB"W(*U@KV!0H*]@M2"\8%!
ME4N0>XV`EMJ"JHOSE)*"OH+!@KV"S(+%@K6"Y8*D@4(`CG>2Z(*S@NJ"O8-!
M@VB#C(-8DJ""S)&`C>R2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC@L6-
MQ)-XCL"-<X*U@L2"K8*^@K."HH%"`)A!EXV0YH+,C]J-UX+PC5B05I*&@LF#
M1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."Q8W$DWB.P(US@K6"Q(*M@KZ"LX*B
M@4(`D9>039#F@XJ#6(-G@LR-6)!6DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]
M@4*,XX+%C<23>([`C7."M8+$@JV"OH*S@J*!0@""L8+,($E-05`@@U2!6X-O
M@LV+I)=,@W2#2(.+@U^"\(-4@WR!6X-G@K6"Q(*B@MR"N8+Q@4(`@K&"ZH+-
METR,^(+((')A<B"#08%;@TJ#0X-U@L6"S8+(@J*"YH*D@L6"MX%"`(*Q@NJ"
MS9=,C/B"R"!Z:7`@@W2#0(-#@XN"Q8+-@LB"HH+F@J2"Q8*W@4(`@K&"ZH+-
METR,^(+(@TJ!6X-HE-2-AH+%@LV"R(*B@N:"I(+%@K>!0@""L8+,@W2#0H%;
M@XN#:(+-E4N0>X+%@K>!0@""L8+,@W2#0H%;@XN#:(+-D*Z0E(+%@LB"K8+$
M@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S9"4CIJ"QH-2@XV#DX+%
M@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S3B0:9"4@L6"
MR(*M@L2"S8*B@J^"W(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-@U*#DX-]@MR"
MO8+-B_.4DH+%B^:0V(+G@NJ"O9"ND)2"S(.*@UB#9X+%@LB"K8+$@LV"HH*O
M@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<
M@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LTQ-I!I4D="E5R+3(+,D$:#4H%;@VB"
MR(*M@L2"S8*B@J^"W(*Y@O&!0I?A.B<C,3(S-&%F)RX`@K&"S(-T@TB!6X.`
M@LV*^8+)CXB7G8*S@NJ"Q(*B@MR"MX%"`(*Q@LR#@8-B@UJ!6X-7@LV"H(+(
M@KV"JHYGEW""MX+I@LR"QHC9@LB"Z96VCIJ#6H-B@V>!:25S@6J"Q8^1@JF"
MZH+$@J*"W(*W@4(`@K&"S)34C8:"S8W%CZR"Q8+@,8+%@LB"K8+$@LV"HH*O
M@MR"N8+Q@4(`@K&"S(-4@5N#;X+%@LUZ:7""QF=Z:7"#=(-`@T.#BX+PDU>*
M2H+%@JN"W(*Y@O&!0@""L8+,@U:#6(-E@X""S8CJCIZ328+)EK.,^(+)@LB"
MP8+$@J*"W(*W@4(`@K&"S))L@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!
M0@""L8+,@T6#0H.3@VB#18+-@TF#=H-6@X>#DX-%@T*#DX-H@T6"J8+GC,2/
M;X*S@NJ"Z95+EW:"JH*@@NB"W(*W@4(`CIZ*U`"#7H-#@X"#5H%;@V<`CIZ*
MU(^1CJX`DXR#98-"@X*!6X.+EJ^.Y8NDF&&-D0"#7H-#@V>#BP"5H9"4@LR-
M@);:@O"129'P@K>"Z8+)@LV!05!#@L6"S4-O;G1R;VR#3(-#@4%-86."R(+G
M0V]M;6%N9(-,@T."\(F?@K6"R(*J@N>#3H.*@V*#3H*U@MR"MX%"`$A434R#
M7(%;@UB57(ZFD-B1U@"#9X%;@U.+I)AAC9$`@V>#4(.)@T6/E).'`(-G@Y.#
M2XFDC9$`@K&"S)"4E:J*U(+)B;V3>(+@@XV#3X-#@Y."JHZ.C7."LX+J@MR"
MM8*]@4(`@V>#BH-J@U^!6X-H@46#9X-O@U.+I)AAC9$`B<X`@V"#A8-J@U>#
M08NDF&&-D0"#9X.+@U*+I)AAC9$`@V>#BX-.@X&#:H-8@UZ#DP"#7H%;@TZ#
M6(%%@TJ#0X-2@UB/E).'`(-C@V^#BP"129'P@48`55),`(-%@TN#DX-?BZ28
M88V1`(-%@TZ#B8-#@VD`5D93((-F@T*#C(-.@V>#BH+)@T&#3H-:@UB"Q8*K
M@MR"N8+Q@4(`5D93((-T@T"#0X.+("(E<R(@@LR#08-.@UJ#6(R@@LV5SXU8
M@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BR`E<R\E<R""S(-!@TZ#6H-8C*""
MS97/C5B"Q8*K@MR"N8+Q@4(`)7,@@LF5SXU8@L6"JX+<@KF"\8%"`(-T@T"#
M0X.+("(E<R(@@LR#5(-#@UF"JH-@@T:#8H-.@JN"W(*Y@O&!0@"#=(-`@T.#
MBR`B)7,O)7,B((+,@U2#0X-9@JJ#8(-&@V*#3H+%@JN"W(*Y@O&!0@!344P@
M@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8%"`%-33"""Q9#:D;&"Q8*K@MR"N8+Q
M@4(`5D93((-T@T"#0X.+@O"#4H-S@5N"Q8*K@MR"N8+Q@4(`5D93((-F@T*#
MC(-.@V>#BB`B)7,B((+PC>R0K(+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#
M9X.*@O"-[)"L@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+PC>R0K(+%@JN"
MW(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*("(E<R(@@O"-[)"L@L6"JX+<@KF"
M\8%"`(OS@LP@5D93((-T@T"#0X.+@O"-[)"L@L6"JX+<@KF"\8%"`(-F@5N#
M7H+PB+./:X+%@JN"W(*Y@O&!0@`B)7,B@O"-[8^<@L6"JX+<@KF"\2X@@V:#
M0H.,@TZ#9X.*@JJ+\X+%@LV"H(+H@MR"N8+Q@4(`(B5S(H+PC>V/G(+%@JN"
MW(*Y@O$Z("5S+@`E<X+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.@V>#BH*J
MB_."Q8+-@J""Z(+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XJ"\(W$BT&328+)
MC>V/G(+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*@O"-[8^<@L6"JX+<
M@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XJ"\(WMCYR"Q8*K@MR"N8+Q@48E<P!6
M1E,@@W2#0(-#@XL@(B5S(B""\(WMCYR"Q8*K@MR"N8+Q@4(`5D93((-T@T"#
M0X.+@O"-[8^<@L6"JX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XH@(B5S(B""
M\(WMCYR"Q8*K@MR"N8+Q@4(`5D93((+PC<2+09-)@LF-[8^<@L6"JX+<@KF"
M\8%&)7,`C+N-W8+,@V:#0H.,@TZ#9X.*@5N"JI/!DNB"Q8*K@MR"N8+Q@4(`
MC]B6OH^1@LR/VHW7@JJ.YH+HCV^"N8+<@KF"\0`E<R""S)+HBV""JH.-@5N#
M:(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"JHC:DZZ"Q8*K@MR"N8+Q@4(`
M5D93((-T@T"#0X.+("(E<R(@@JJ*2H*O@MR"N8+Q@4(`5D93((-T@T"#0X.+
M@O"/D8*KC9Z"W9=P@LF*2H*O@MR"N8+Q@4(`5D93((-T@T"#0X.+@JJ*2H*O
M@MR"N8+Q@4(`B+./:X^1C,F#=(-`@T.#BX+PBDJ"KX+<@KF"\8%"`%9&4R"#
M=(-`@T.#BX*JD\>"WX+<@KF"\8%I9FEL97-I>F4H*2"#1X.)@5N!:H%"`%9&
M4R"#=(-`@T.#BX*JD\>"WX+<@KF"\8%I9V5T1FEL95-I>F4H*2"#1X.)@5N!
M:H%"`%9&4R"#=(-`@T.#BX*JD\>"WX+<@KF"\8%"`'9F<W)O;W0@@V:#0H.,
M@TZ#9X.*@O"3QX+?@MR"N8+Q@4(`EKR13R`E<R""\"`E<R""R97/C5B"Q8*K
M@MR"N8+Q@4:#=(-(@XN#7X%;@LV*^8+)D;:-W8*U@MR"MP!61E,@@V:#0H.,
M@TZ#9X.*@5N"S):\D4^"\)7/C5B"Q8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.
M@V>#BH%;@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%&)7,`5D93((-T@T"#0X.+
M("(E<R(@@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BR`E
M<R\E<R""S):\D4^"\)7/C5B"Q8*K@MR"N8+Q@4(`5D93((-T@T"#0X.+@LR6
MO)%/@O"5SXU8@L6"JX+<@KF"\8%"`(*Q@LP@5V]R9""5MH^1@O"6?);S@L6"
MJX+<@KF"\8%"`%9&4R"#=(-`@T.#BR`B)7,B((+)CY&"KX+<@KF"\8%"`%9&
M4R"#=(-`@T.#BX+)CY&"KX+<@KF"\8%I8V]P>2@ICKB4<X%J@4(`5D93((-T
M@T"#0X.+@LF/D8*O@MR"N8+Q@4(`5D93((-T@T"#0X.+@LF/D8*O@MR"N8+Q
M@4)Q=6]T82""\)*TB=^"M8*]@N:"I(+%@K>!0@")NI#\`)7/C5B"\([F@NB/
MP8*W`(W%C.."S)&`C>R"\(RS@LF6WX*W`)#:D;&.GH+,@U2!6X-O@5N"J8+G
M@LR77(KZ@K6"R(*BB9Z3FH%&`(-4@5N#;X%;@JF"YX+,EUR*^H*U@LB"HHF>
MDYJ!1@"6HI"NEYT`@T&#B8-UCO&2MXV1F$&630")<(V1`)7$C9$`E<27S)&^
ME;V7;8^4DX<`E7.6O@"#AH%;@U66O(*I@W"#6(./@5N#:(*JE7.6OH+%@K>!
M0@"6LY:\`(-:@TR#A8.*@V6#0H%;C^."S)>=EU*"J8+GD\&,H(+,EK."HH-8
M@TZ#BH-V@V>"S2!#=70O0V]P>2]087-T92""Q8*K@MR"N8+Q@4)/2R""\(-.
M@XJ#8H-.@K>"Z8+&@4&"QX*D@N*"P8+$@TZ#BH-B@W:#>X%;@VB"R8-!@TZ#
M6H-8@K>"Z8*I@L:"HH*D(&UO>FEL;&$N;W)G((+,BUJ/<)6VCY&"\(RI@NF"
ML8+&@JJ"Q8*K@MR"MX%"`(-4@WR!6X-G@K6"Q(*B@LB"HHIGDJ..<8+%@K<`
MC5B05@`E<R""\(U8D%:"MX+I@4(`@X:!6X-5@O"-6)!6@K>"Z0`B)7,B((+P
MC5B05H*U@MR"M8*]@4(`C5B05H-8@TZ#BH-V@V>"\(WMCYR"M8+<@K6"O8%"
M`(-!@V*#=H.-@5N#:`"14X+$@LR#08-V@XJ#4(%;@U:#AX.3@LR0W9+H@W2#
M0(-#@XN"\(-4@5N#;X+)@T&#8H-V@XV!6X-H@K6"W(*U@KV!0@"#B8-E@Y.5
MMHZ:@6F1Y96VCIJ!:@"#C8%;@WV0E(Z:@6F1Y96VCIJ!:@"#18.+@T^#08-#
MDXR5^XNDF&&-D0",NXW=@LR2;(+PCF>7<(%&)7,`4U-,((+PCF>7<`!)35-0
M((-4@5N#;X+,@X:!6X-5EKR!7H-P@UB#CX%;@VB"JHC9@LB"Z8_JC8>"R8YG
MEW""M8+<@K>!0@"#AH%;@U4`@X:!6X-5("5S((+-("5S((+%E$:/V(*S@NJ"
MQ(*B@MR"N8+Q@4(`@X:!6X-5BL>7G0"#AH%;@U6#28-V@U:#AX.3`(.&@5N#
M59-OF%X`@X:!6X-5@LR3;YA>@LV"L8+,@U2#0X-G@L6"S8O6CGZ"LX+J@L2"
MHH+<@K>!0@"#AH%;@U6!6X-!@TJ#18.3@V>"JH*@@NB"W(*Y@O&!0H%"`(.&
M@5N#59:\`(.&@5N#59:\("(E<R(@@LV*^8+)@J""Z(+<@K>!0@"#AH%;@U66
MO#H`@X:!6X-5EKPZ(`"#5H-8@V6#@)*&@LR#AH%;@U6!1@"#18-9@WB#3(-8
M@UZ#DXNDF&&-D0"+>(G)`)=,C/B0JP"#;X-K@T&#8XNDF&&-D0"#>(-L@UF#
M1X.)@46#>X.*@V^#BXNDF&&-D0",GX_8CKB4<R`M((*Q@LR#@8-B@UJ!6X-7
M@LV)_.*"@K."ZH+$@J*"Z8+F@J2"Q8*W@4(`E,4`@V^!6X-7@X>#DXK'EYT`
MCV.(RI)U`(-X@V>#:8.`CM")[X[EBV"+I)AAC9$`)7,@@O",J8+I`(I/E92"
MS"!W96(@@WF!6X-7@O"57(ZF`(EPE\R#;X%;@U>#DX^4DX<`E<27S(-O@5N#
M5X.3CY23AP"#18-(@XJ#6(%%@W2#9X-$@5N#:8^4DX<`C'B-D`"0A0"6B(]4
M`(+F@J2"L8*[`"5S((+)@N:"I(*Q@KL`)7,@@K."\8%!@N:"I(*Q@KL`D+R#
M5(-N@XD`)7.#C8-/@T.#DXSC@L>"S(-!@W:#BH-0@5N#5H.'@Y."\)5<CJ:"
MM8+<@K>"J8%(`(OFD-B"Z)6VCIJ"S8F]@L6"MX*I@4@`B/B7<)6VCIJ"S8F]
M@L6"MX*I@4@`@V6#3(-8@V>#1X-F@T*#7H%;@LR#=H.)@T^#0X.3@O"129'P
M@K6"W(*W@4(`E9T`C;:"R9)U@JTE<X.!@VJ#A8%;@LR5G8%ICI^)\8+,@XV#
M3X-#@Y."J8+GETR,^(%J.@"57(+,E9T`E9V"S))0B,H`E9V!1@"7?H*U@J*"
MX(+,B.J7EP"+SI:QD.:"S(]:CXH`B\Z6L9#F@LR39)ABE-2-A@`E9""-<Y;:
M@L6*U(CA@L&"O8V`EMJ0E(%"D+."M8*M@LT@)62!08YWDNB"LX+J@KV"S(+-
M("5D@4(`BM2(X8+!@KV-@);:D)2!0I"S@K6"K8+-("5D@4&.=Y+H@K."ZH*]
M@LR"S2`E9(%"`%9&4X-T@T"#0X.+@LR3QX+=CV^"M9*&@LF5<Y"S@LB#28-T
M@UJ#8H-G("5D((*JCG>2Z(*S@NJ"W(*U@KV!0@!8-3`Y=C,@BNZ6>Y"GC,``
M6#4P.78S((RNCF>7<)9``%@U,#EV,R".Y9',CM*"S)7*EKP`6#4P.78S(([E
MD<R.TH+,C*Z.KY7*CG$`6#4P.78S((IGDJ.+0)1<`)1.`)1.`):(E$X`@T.#
M1X.!@Y.+I)AAC9$`@LV"H@"3KXC3@K6"W(*W`(VA@LV#98-,@UB#9X."@5N#
M:(+%@K>!0EL\/EV#>X->@Y."Q5=94TE764>#@H%;@VB"R9;?@NB"W(*W@4(`
M)60@B,B/XX+,@W6#C8-B@TZ"\(WLD*R"MX+I@K&"QH+-BY:)PH*S@NJ"Q(*B
M@MR"N8+Q@4(`@J""R(*]@LV41H_8@K."ZH+$@J*"W(*Y@O&!0@"6O)%/@LR2
MAH+)("=<)R""QH*B@J25MHZ:@LV.9X*F@MR"N8+Q@4(`ETR,^(+(DV2.<8.!
M@5N#BX-!@VB#C(-8@L6"S8*@@NB"W(*Y@O&!0@"#0X.3@WR!6X-G@K."ZH*]
M@W2#0(-#@XN"S(-T@T*!6X.+@VB"\"5SD^""S)'.B9Z"MX+I@W2#0H%;@XN#
M:(+)@WV#8H-V@K6"Q(+<@KF"\2X`@XV#3X-!@T6#9X*U@MR"M8*]+@"0LX*U
M@J*39)ABE-2-AH+PD_R7S8*W@NF"YH*D@LF2C8C3@K6"Q(FZ@K."HH%"D)2.
MFH*^@J^"JHYGEW""Q8*K@MR"MX*J@4&-D8W;DV288H+(@N>0YI.J@LF!>X+P
ME72"KX+<@K>!0@"0LX*U@J*2;(+PD_R7S8*U@L2)NH*S@J*!0@"#5(-#@Y.#
M08-B@W:"\)>8EW""MX+I@KV"WX+)@LT@1&%T851R964@@V^#8H-.@T>#DX-H
M@O"0W9+H@K>"Z95+EW:"JH*@@NB"W(*W@4(`5D93((-O@V*#3H-'@Y.#:(+P
MD-V2Z(*W@NF52Y=V@JJ"H(+H@MR"MX%"`(_ABE&"S)/@EV6"\(M,CW&"M8+$
M@JF"YX%!C^&*48.,@WR!6X-G@O"1EY!-@K6"Q(*M@KZ"LX*B@4(`@K&"L8+)
M@XJ#DX-.@K>"Z5523(+PD_R7S8*U@L2)NH*S@J(`C>V/G(*W@NF#5(%;@V^"
M\(YWDNB"M8+$@JV"OH*S@J*!0@"/P8N.@K>"Z8.&@5N#59:\@O".=Y+H@K6"
MQ(*M@KZ"LX*B@4(`C>V/G(*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."
MHH%"`)+'B<&"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0@"-6)!6
M@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`CL"-<X*W@NF#08-.
M@U:#AX.3@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`D%:"M8*BE:J7WI:\@O"3_)?-
M@K6"Q(FZ@K."HH%"`"5S((-:@V*#5H.'@Y."S)=,C/B*^HS`@JJ0V(+J@L2"
MHH+<@K>!0H.-@T^#0X.3@K62O(*U@L2"K8*^@K."HH%"`)-DCG&#@8%;@XN#
M08-H@XR#6`""H(+(@KV"S"!&<F]M.B"#08-H@XR#6`""H(+(@KV"S(-#@Y.#
M=(-(@X&!6X-6@X>#DP"#6H-B@U:#AX.3("5S((+,BM2"R8*@@LB"O8+,@T&#
M:(.,@UB"JI7/C5B"LX+J@MR"M8*]@4*#6H-,@X6#BH-E@T*!6Y7;C.R"S(*]
M@M^"R8.-@T^#0X.3@K62O(*W@M>"JX+%@K>!0@""H(+(@KV"S):\D4\`@K&"
MS)1&C]B#;X-B@TZ#1X.3@VB"Q8+-@4&#AH%;@U6"S)+'B<&"JH-4@WR!6X-G
M@K."ZH+$@J*"W(*Y@O&!0H+@@K4@2&]R9&4@@L6#AH%;@U6#08-*@T6#DX-G
M@O"*QY>=@K6"O8*B@LR"R(+G@4&1O(+,E$:/V(-O@V*#3H-'@Y.#:(+PCF>"
MI(+7@JN"Q8*W@4(`@K&"S)1&C]B#;X-B@TZ#1X.3@VB"Q8+-@4&#AH%;@U6"
MS(.*@UB#9X*J@U2#?(%;@V>"LX+J@L2"HH+(@J*"J8%!@J""Z8*B@LV)O8+G
M@JF"S)>=EU*"Q8*Q@LR+0)1<@JJ6LXSX@LF"R(+!@L2"HH+<@K>!0@"#6H-B
M@U:#AX.3("5S((+,BM2"R8*@@LB"O8+,@W6#B8-%@U6"JI7/C5B"LX+J@KV"
MYH*D@LB"S(+%@4&#6H-,@X6#BH-E@T*!6Y7;C.R"S(*]@M^"R8.-@T^#0X.3
M@K62O(*W@M>"JX+%@K>!0@""J(YG@J*"S(-U@XF#18-5@LV"L8+,BT"47(+P
M@U2#?(%;@V>"M8+$@J*"W(*Y@O&!0@""J(YG@J*"S(-U@XF#18-5@LV"L8+,
MB/.-_(-)@W:#5H.'@Y."\(-4@WR!6X-G@K6"Q(*B@MR"N8+Q@4)#;VYT<F]L
M+T-O;6UA;F0@*R!0((+%B/.-_(*U@L2)NH*S@J*!0@"#7H-#@X"#78%;@Y.!
M1@""H(+(@KV"S(-F@W2#2(.+@V=)1(+-E<^-6(*S@NJ"W(*U@KV!0@""H(+(
M@KV"S(-F@W2#2(.+@V=)1#H`@J""R(*]@LR.@9:\`(.-@T^#0X.3@LV*^HS`
MD-B"ZH+%@K>!0@"05H*U@J(@)7,@EW""S(-P@UB#CX%;@VB!1B5S`(*@@LB"
MO8+,@TF#=H-6@X>#DX+-C+N-W8+,@UJ#8H-6@X>#DY*&@LF5SXU8@K."ZH+<
M@K6"O8%"`(-)@W:#5H.'@Y."\(U8D%:"M8+<@K6"O0"#<(-8@X^!6X-H@LV#
MBH-:@V*#9X*S@NJ"W(*U@KV!0@"#<(-8@X^!6X-H@LV#BH-:@V*#9X*S@NJ"
MW(*U@KV"S(+%@4&05H*U@J*#<(-8@X^!6X-H@L6#C8-/@T.#DX*U@L2"W8+$
MB;J"LX*B@4(`@W"#6(./@5N#:(*JBOJ,P)#8@NJ"Q8*W@4(`@XJ#@H%;@V>#
M5(%;@V\Z`(.&@5N#4X-8@XF#<H-!`(-5@T.!6X.+BZ2888V1@6F#4H.3@U.6
MKX[EBZ2888V1@6H`@U6#DX-R@T&+I)AAC9$`@U>#DX-O@W6#1XNDF&&-D0"!
M;8_ABE&5\8V0@6X`6XUS.B5S+R5S70!?08K'EYT`7T2-<X+PC>V/G`!?1X-/
M@XN!6X-V`%](@W>#BX-V`%])B>:1G(-V@XV#<(-E@T(N+BX`7TR#C8-/@T.#
MDP!?3(.-@T^#08-%@V<`7TV#BH.3@TZ5SXU8`%]/@TF#=H-6@X>#DP!?4(-!
M@TZ#6H-8C*``7U*#BH.3@TZ-[8^<`%]3@UJ#8H-G@T&#8H-V`%]4E5R1KI"K
M`%]5@X:!6X-5`(-!@VB#C(-8DJ``E7.6OH+(@T&#:(.,@U@`EUR2Z)5<`(]O
ME\V#=(-`@T.#BX*JC>R0K(+%@JN"W(*Y@O$`D_R7S8-T@T"#0X.+@JJ*2H*O
M@MR"N8+Q`(*Q@K&"\(-.@XJ#8H-.`(-2@WV#DX-HC7..9Y=P@LR#1X.)@5L`
MD-V2Z(-'@XF!6P"/9)=V@LB#5H-8@V6#@(-T@T"#0X.+@LR,AY>.`(-F@5N#
M7HQ@CJZ#1X.)@5L`E=*/5P"-@);:@JJ"H(+H@MR"N8+Q`(-T@T"#0X.+`(-Z
M@UB#9Y:\@JJ5<Y:^`)/\CV^7S8-'@XF!6P"#7(-T@V>#18-&@T&3X)64@LR#
M1X.)@5L`EKR13P".P)&5@K."ZH+$@J*"W(*Y@O$`@MR"OH[`D96"LX+J@L2"
MHH+<@KF"\0"#@8."DJ``@W"!6X-:@Y.#9P"#08-.@UJ#6(+-BY&4VX*S@NJ"
MW(*U@KT`@W.#3H-:@XL`@XJ#@H%;@V>"Q8+,@W:#C8-G@U*#BX-'@XF!6P"#
M5(%;@W*#6)5SE%P`C;>5JH+PE5R.I@"#5H-8@V6#@(-'@XF!6P"#7H-8@TZ#
MBH-8@V<`B.J.GI-)@LB#1X.)@5L`BFV41H+,@KV"WX-P@UB#CX%;@V@RDWB3
M_)?-@K6"Q(FZ@K."H@"6LY:\`'9#87)D````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]J85]*4"]H
M96QP+GAM;```````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#,S,C``,3`U,34T,S$P-C(`,#(P,S`P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\
M(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+VIA7TI0+VAE;'`N>&UL+'8@,2XR
M(#(P,#0O,#4O,C<@,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\
M96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O
M<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@
M<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N
M=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H
M;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U
M<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A
M<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE
M8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E
M"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@
M8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M
M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R
M('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O
M9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,
M87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W
M:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*
M("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W
M(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET
M;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E
M8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#
M;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q
M=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA
M8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@
M<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C
M:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN
M=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L
M:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T
M:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME
M9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E
M(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@
M8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*/"]H96QP/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:7-?25,O````````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#8R`#`Q-C8U-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]I<U])4R],0U]-15-304=%4R\`````````````````````````````
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C(`,#(P-#0S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+VES7TE3+TQ#7TU%4U-!1T53+VAO<F1E
M+FUO```````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S<U,0`Q,#4Q-30S,3`V
M,@`P,C(Q,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````!W````'````-0#``"C````C`<````````8"@``#```
M`!D*```#````)@H``!\````J"@``!0```$H*```&````4`H```0```!7"@``
M%@```%P*```&````<PH```8```!Z"@``&0```($*```4````FPH```0```"P
M"@``!@```+4*```H````O`H```0```#E"@``"````.H*```0````\PH```8`
M```$"P``#P````L+```(````&PL```L````D"P``!````#`+```-````-0L`
M``4```!#"P``$````$D+```0````6@L```\```!K"P``#P```'L+```,````
MBPL```@```"8"P``!P```*$+```$````J0L```0```"N"P``$````+,+```'
M````Q`L```0```#,"P``!````-$+```(````U@L```T```#?"P``#@```.T+
M```6````_`L``!$````3#```!@```"4,```&````+`P```<````S#```!```
M`#L,```'````0`P```D```!(#```!@```%(,```'````60P```L```!A#```
M!````&T,```&````<@P```@```!Y#```"````((,```$````BPP```4```"0
M#```!@```)8,```0````G0P```H```"N#````P```+D,```D````O0P```<`
M``#B#```!@```.H,```?````\0P```8````1#0``#0```!@-```"````)@T`
M``H````I#0``!@```#0-```&````.PT```D```!"#0``!P```$P-```$````
M5`T```4```!9#0``!````%\-```"````9`T```0```!G#0``"````&P-```"
M````=0T```<```!X#0``!P```(`-```(````B`T``!0```"1#0``*0```*8-
M```%````T`T```8```#6#0``'P```-T-```)````_0T```0````'#@``!P``
M``P.```'````%`X```0````<#@``(P```"$.```O````10X``"$```!U#@``
M'````)<.```"````M`X```<```"W#@``#````+\.```(````S`X```<```#5
M#@``!P```-T.```-````Y0X```,```#S#@``,````/<.```3````*`\``!``
M```\#P``4P```$T/```7````H0\``!8```"Y#P``#P```-`/```?````X`\`
M``4`````$```"`````80```(````#Q````0````8$```!@```!T0``!;`0``
M)!````L```"`$0``"@```(P1```6````EQ$```4```"N$0``!0```+01```$
M````NA$``!8```"_$0``"0```-81```&````X!$``!L```#G$0``$0````,2
M```%````%1(```<````;$@``.````",2```$````7!(```@```!A$@``%```
M`&H2```$````?Q(``!````"$$@``%@```)42```9````K!(```8```#&$@``
M!P```,T2```%````U1(``!````#;$@``$````.P2```5````_1(``!$````3
M$P``#P```"43```'````-1,```0````]$P```P```$(3```%````1A,```H`
M``!,$P``!@```%<3```$````7A,```0```!C$P``"````&@3```/````<1,`
M`!$```"!$P``&````),3```5````K!,```@```#"$P``"P```,L3```'````
MUQ,```<```#?$P``!P```.<3```'````[Q,```@```#W$P``!@`````4```5
M````!Q0```D````=%```!@```"<4```(````+A0```X````W%```!````$84
M```$````2Q0```<```!0%```#0```%@4```)````9A0```,```!P%```)@``
M`'04```&````FQ0```8```"B%```"@```*D4```&````M!0```@```"[%```
M`@```,04```+````QQ0```8```#3%```!@```-H4```,````X10```H```#N
M%```!````/D4```&````_A0```4````%%0```P````L5```%````#Q4```@`
M```5%0``!@```!X5```'````)14```T````M%0``"````#L5```6````1!4`
M`"$```!;%0``"@```'T5```%````B!4``!H```".%0``"0```*D5```%````
MLQ4```0```"Y%0``"0```+X5```%````R!4``!X```#.%0``,0```.T5```C
M````'Q8``"````!#%@```P```&06```&````:!8``!$```!O%@``"P```($6
M```'````C18```<```"5%@``$````)T6```"````KA8``"\```"Q%@``&P``
M`.$6```+````_18``%4````)%P``%````%\7```6````=!<``!````"+%P``
M)@```)P7```%````PQ<```8```#)%P``"0```-`7```%````VA<```@```#@
M%P```0````8`````````5P```&$````H`````````&0``````````````#T`
M```I`````````$T```!*````;@`````````O````$````#8````.````9P``
M``H````N````/P````(`````````$0```%$```!<````-````"(````^````
M2P```&H```!"````,````!X````(````10`````````W``````````````!V
M``````````L```!T````#`````````!(````,0````````!L`````````$X`
M`````````P```&````!H`````````!@```!M````1`````````!#````````
M`&8```!9``````````4`````````%0```%``````````90```"$`````````
M0````",````3`````````'4````Y````7@```%,```!5````-0````````!!
M`````````!D```!8````<P```$D````6````````````````````:P``````
M```Z````'0```"0`````````````````````````*P```"T```!6````````
M`!(```!2````#0```!L````<`````````"P`````````3`````````!W````
M*@```%L```!&````8@```&D````@````)0```$\````$````,P```#P```!'
M````<`````````!?````6@````\````'```````````````:````;P```"<`
M````````70```#@````4````,@```&,`````````)@```'(````)````'P``
M`!<````[`````````'$```!4``````````!!9&1R97-S($)O;VL`06QL`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07!R:6P`075G=7-T`$)O
M=&@`0G5I;&1I;F<@;&]C86QE("5S+BXN(`!#86YC96P`0VAA;F=E`$-L96%N
M:6YG('5P(&QO8V%L92`E<RXN+B``0V]M<&]S92!-97-S86=E("@E<RD`0V]P
M>0!#<F5A=&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+@!$871E`$1E8V5M8F5R`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1I
M<W!L87D@3W!T:6]N<P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!%9&ET`$5M86EL
M($%D9')E<W,`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O
M;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$9E8G)U87)Y`$9I;'1E<G,`1G)O;0!(96QP`$ED96YT:71Y)W,@;F%M
M93H`2F%N=6%R>0!*=6QY`$IU;F4`3&%N9W5A9V4`3&%S="!5<&1A=&5D.@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,87EO=70`3&5B86YO;@!,969T`$QI8F5R:6$`
M3&ET:'5A;FEA`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$UA:6P`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%R8V@`36%R9VEN`$UA<G-H
M86QL($ES;&%N9',`36%U<FET86YI80!-87D`365R9VEN9R!T<F%N<VQA=&EO
M;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`365X:6-O`$UI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8`36ER<F]R`$UI<V-E;&QA;F5O=7,`36\`
M36]D:69Y(%523`!-;V1U;&4`36]N86-O`$UO=F4@1&]W;@!-;W9E(%5P`$YA
M;64`3F5V97(`3F5X=`!.;P!.;VYE`$YO=F5M8F5R`$]+`$]C=&]B97(`3W!T
M:6]N<P!087-S=V]R9`!097)S;VYA;"!);F9O<FUA=&EO;@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!297-E=`!396%R8V@`
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!397!T96UB97(`4VEZ
M90!3=6)J96-T`%-U8V-E<W,`5&5X=`!4:&4@:61E;G1I='D@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R=`!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4;P!5;FYA;65D
M`%5S97(@3W!T:6]N<P!5<V5R;F%M90!6:65W("5S`%=A<FYI;F<`5V5L8V]M
M92!T;R`E<P!997,`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/<'1I;VX@*R!0('1O('!R:6YT
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%](96QP`%],;V<@;W5T`%]/<'1I;VYS`&1O;F4`9F%I;&5D`%!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+C4*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#(M,#$M,3`@,3DZ,#`K,#$P,`I03RU2979I<VEO;BU$871E.B`R,#`U
M+3$Q+3$Y(#(P.C,S*S`P,#`*3&%S="U4<F%N<VQA=&]R.B!":F]R;B!$879I
M9'-S;VX@/&)J;W-S:4!S;F5R<&$N:7,^"DQA;F=U86=E+51E86TZ($EC96QA
M;F1I8R`\<W5P<&]R=$!S;F5R<&$N:7,^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`$YE=&9A;F=A8O-K`-9L
M;"!S:V5Y=&D`TW3F:W0@9VEL9&D@=&EL9W)E:6YT+@!A<'+M;`#A9_IS=`!"
MYO!I`$)Y9V=I(&[Z(&QO8V%L92`E<R`N+BX`2.9T=&$@=FGP`$)R97ET80!(
M<F5I;G-A('1I;"#M(&QO8V%L92`E<R`N+BX`4V5M:F$@<VME>71I("@E<RD`
M069R:70`0OIA('1I;`!3=&EL;&$@8?!G97+P:7(@<V5M(&5R=2!F<F%M:W;F
M;61A<B#^96=A<B#^^B!T96YG:7-T("5S+@!$86=S`&1E<V5M8F5R`%-JX6QF
M9V5F:?`@:V5N;FEM87)K`$5Y\&$`VG1L:71S<W1I;&QI;F=A<@!3YFMJ82!Y
M9FER(.$@=FEN;G5S=/;P`%/F:VIA("5S('EF:7(@X2!V:6YN=7-T]O``0G)E
M>71A`$YE=&9A;F<`5FEL;&$`P2!K;W)T97)S(&9R97-T:0#!(#,P('-E:RX@
M9G)E<W1I`,$@9FEM;2!M[6[Z=&YA(&9R97-T:0#!(&CA;&9T[6UA(&9R97-T
M:0#!(&WM;OIT=2!F<F5S=&D`9F5B<OIA<@!3[75R`$9RX0!(:N%L<`!+96YN
M:6YA9FXZ`&IA;OIA<@!J^FSM`&KZ;NT`5'5N9W5MX6P`<^WP87-T('5P<&;F
M<G0Z`%/M\&%S="!T96YG<W0Z("5S`%/M\&%S="!T96YG<W0Z("5S(&9RX2`E
M<P!3[?!A<W0@=&5N9W-T.B!!;&1R96D`3&5T=&QA;F0`1G)A;7-E=&YI;F<`
M3.UB86YO;@!6:6YS=')I`$SM8F5R[6$`3&ET:.%E;@!496YG:F%S=`#:='-K
M<N$`5F5R:V5F;FD@=FGP('1E;F=I;F=U`%9E9G#S<W1U<@!-86QA=NT`36%L
M8>US[6$`1W+F;FCV9O!A97EJ87(`36%L[0!M87)S`%-PX7-S[6$`36%R<VAA
M;&QE>6IA<@!-X7+M=&%N[6$`;6'M`%-A;65I;F$@_OWP:6YG87(@9GER:7(@
M)7,@96EN:6YG=6YA+BXN`%-K97ET:0!-97CM:_,`3>UK<O-N97/M80!3<&5G
M;&$`W6UI<VQE9W0`3>$`0G)E>71A('-L\_``16EN:6YG`$WS;F%K\P!&;'ET
M:F$@;FGP=7(`1FQY=&IA('5P<`!.869N`$%L9')E:0!.YG-T80!.96D`16YG
M:6X`;O-V96UB97(`S2!L86=I`&]K=/-B97(`5F%L<W1I;&QI;F=A<@!,>6MI
M;&]R\`!5<'!L_7-I;F=A<B!U;2!N;W1A;F1A`%-LX?!U(&EN;B!N;W1A;F1A
M;F%F;B!O9R!L>6ML:6]R\`!%;F1U<G-E=&IA`$QE:71A`%9E;&1U('-JX6QF
M9V5F:?`@='5N9W5MX6PZ`'-E<'1E;6)E<@!3=.9R\`!%9FYI`$9R86UK=N9M
M=`!497AT:0!+96YN:6YU("(E<R(@:&5F=7(@=F5R:?`@97ET="X`5FEL;&$@
M:V]M('5P<"!V:?`@8FER=&EN9W4@_F5S<V$@:&QU=&$@<VME>71I<VEN<P!4
M86QA;B!V97+P=7(@8?`@=F5R82!A\"!LX6=M87)K:2`Q+@#>971T82!G:6QD
M:2!V97+P=7(@8?`@=F5R82!T86QA+@!4:6P`TVYE9FYT`%9A;&MO<W1I<B!N
M;W1A;F1A`$YO=&%N9&%N869N`%/];F$@)7,`0?!V]G)U;@!696QK;VUI;BAN
M*2#M("5S`$KA`$QO=&%N("5S(&5R(')U;FYI;B#Z="#A('3M;6$N(%1E;F=D
M=2#^:6<@869T=7(N`$9U;&QT(&YE=&9A;F<@_FET="`H1G+A.BD@.@!5<'!L
M_7-I;F=A<@!6969S:V_P87)I(/YI;FX@<W1Y\'5R(&5K:VD@_F5S<V$@<')E
M;G1A\&=E<O`N($YO=&'P=2!#5%),+T]P=&EO;B!O9R!0('1I;"!A\"!P<F5N
M=&$N`$[Z=F5R86YD:2!T[6UA8F5L=&DZ`%-JX6QF9V5F:?`@:V5N;FD@_FET
M=#H`1G5L;'0@;F%F;B#^:71T.@!3=&EL;&EN9V%R(/[M;F%R(&AA9F$@=F5R
M:?`@=7!P9N9R\&%R+@!(:N%L<`#:='-K<N$`5F%L:V]S=&ER`&QO:VGP`&ML
M:6MK8?!I````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O:71?250O````````````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R`#`Q
M-C8V,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]I=%])5"],0U]-
M15-304=%4R\`````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C(`,#(P-#0U`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+VET7TE4+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#,R-3$R-P`Q,#4Q-30S,3`V,@`P,C(Q,3(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````WA($E0````"'
M!0``'````%0L``!A!P``C%@````````0=@``#@```!%V```/````('8```T`
M```P=@``"````#YV```+````1W8```P```!3=@``!````&!V```8````978`
M`!L```!^=@``+0```)IV```=````R'8``"0```#F=@``*0````MW```9````
M-7<``"8```!/=P``#````'9W```D````@W<```\```"H=P``"P```+AW```.
M````Q'<```4```#3=P``*````-EW```(`````G@```H````+>```%0```!9X
M```2````+'@```L````_>```A0```$MX```.````T7@```H```#@>```#0``
M`.MX```.````^7@``!$````(>0``#0```!IY```,````*'D```T````U>0``
M!@```$-Y``"4````2GD```H```#?>0``#P```.IY```8````^GD```P````3
M>@``#@```"!Z```.````+WH```@````^>@``"0```$=Z```N````47H``!H`
M``"`>@``,@```)MZ```X````SGH``%0````'>P``40```%Q[``!:````KGL`
M`%<````)?```-````&%\```)````EGP```T```"@?```!P```*Y\```*````
MMGP```\```#!?```!0```-%\```&````UWP``!$```#>?```"````/!\```E
M````^7P``"`````??0``$P```$!]```0````5'T```\```!E?0``"@```'5]
M```#````@'T```\```"$?0``%````)1]```)````J7T```T```"S?0``$@``
M`,%]```9````U'T``!X```#N?0``#P````U^```*````'7X```\````H?@``
M"````#A^```D````07X``!0```!F?@``%@```'M^```(````DGX``$X```";
M?@``+0```.I^```9````&'\```<````R?P``#````#I_```L````1W\```X`
M``!T?P``!0```(-_```*````B7\```,```"4?P``%P```)A_```*````L'\`
M``\```"[?P``#@```,M_```8````VG\``",```#S?P``#@```!>````4````
M)H```!<````[@```%P```%.````7````:X```!,```"#@```#P```)>````?
M````IX```!T```#'@```!@```.6````+````[(```!````#X@```%0````F!
M```5````'X$```<````U@0``$````#V!```%````3H$``!$```!4@0``#```
M`&:!```[````<X$``#@```"O@0``.0```.B!```2````(H(``"<````U@@``
M+````%V"```J````BH(``"4```"U@@``"@```-N"```&````YH(``"\```#M
M@@``-P```!V#```N````58,``%4```"$@P``+0```-J#```M````"(0``#T`
M```VA```/P```'2$```M````M(0``$````#BA```(P```".%```C````1X4`
M`$````!KA0``+0```*R%```S````VH4``"4````.A@``%0```#2&```9````
M2H8``"D```!DA@``)````(Z&```H````LX8``!$```#<A@``"@```.Z&```0
M````^88``!8````*AP``%@```"&'```G````.(<```@```!@AP``*0```&F'
M```.````DX<```H```"BAP``!````*V'```)````LH<```8```"\AP``$0``
M`,.'```'````U8<``!8```#=AP``!````/2'```&````^8<```8`````B```
M#0````>(```#````%8@```,````9B```%P```!V(```3````-8@``!T```!)
MB```"````&>(```$````<(@```@```!UB```.P```'Z(```T````NH@``$$`
M``#OB```&@```#&)```K````3(D``"````!XB0``%0```)F)```&````KXD`
M`!4```"VB0``&````,R)```B````Y8D``"X````(B@``'0```#>*```A````
M58H``%0```!WB@``*0```,R*```'````]HH``!4```#^B@``#@```!2+```*
M````(XL```\````NBP``#0```#Z+```/````3(L```T```!<BP``"0```&J+
M```&````=(L``!T```![BP``$P```)F+```1````K8L``!0```"_BP``!@``
M`-2+```4````VXL``%0```#PBP``9````$6,```$````JHP```X```"OC```
M!0```+Z,```%````Q(P``!,```#*C```$0```-Z,```1````\(P``!P````"
MC0``*@```!^-```A````2HT```4```!LC0``"P```'*-```2````?HT```H`
M``"1C0``#P```)R-```-````K(T``!$```"ZC0``#````,R-```&````V8T`
M``P```#@C0``!@```.V-```0````](T``!$````%C@``!0```!>.```,````
M'8X``!`````JC@``!0```#N.```-````08X```8```!/C@``!P```%:.```-
M````7HX```<```!LC@``"P```'2.```'````@(X```D```"(C@``"0```)*.
M```*````G(X``!D```"GC@``/0```,&.```=````_XX```P````=CP``$```
M`"J/```2````.X\``!,```!.CP``*P```&*/```[````CH\``"````#*CP``
M"````.N/```V````](\``"$````KD```$````$V0```(````7I````0```!G
MD```#P```&R0```.````?)```!\```"+D```'````*N0```A````R)```!X`
M``#JD```&0````F1```>````(Y$``!L```!"D0``(0```%Z1```N````@)$`
M`"8```"OD0``'````-:1```>````\Y$``!P````2D@``)@```"^2```K````
M5I(``#,```""D@``)@```+:2```K````W9(``#@````)DP``'0```$*3```5
M````8),``"\```!VDP``(````*:3```2````QY,``"D```#:DP``'@````24
M```@````(Y0``!(```!$E```H@```%>4```6````^I0``",````1E0``*```
M`#65```I````7I4``"@```"(E0``'P```+&5```5````T94``"````#GE0``
M)0````B6```H````+I8``"T```!7E@``,````(66``"2````MI8``"$```!)
MEP``'````&N7```F````B)<``"H```"OEP``00```-J7``!$````')@```P`
M``!AF```!P```&Z8```'````=I@```8```!^F```#0```(68```0````DY@`
M`!(```"DF```$P```+>8```2````RY@``!````#>F```$````.^8```,````
M`)D```X````-F0``#0```!R9```/````*ID``!,````ZF0``#0```$Z9```H
M````7)D```,```"%F0``#0```(F9```&````EYD```4```">F0``!````*29
M```-````J9D```X```"WF0```P```,:9```.````RID```@```#9F0``#P``
M`.*9```/````\ID```T````"F@``$````!":```-````(9H```L````OF@``
M!@```#N:```+````0IH```P```!.F@``"@```%N:```1````9IH``!D```!X
MF@``"P```)*:```-````GIH``"(```"LF@``#P```,^:```;````WYH``#0`
M``#[F@``"@```#";```8````.YL``!(```!4FP``&0```&>;```6````@9L`
M`"(```"8FP``#0```+N;```'````R9L``!0```#1FP``"P```.:;```B````
M\IL``"\````5G```"P```$6<```)````49P``!D```!;G```"P```'6<```7
M````@9P``!<```"9G```%@```+&<```/````R)P``!D```#8G```#@```/*<
M```8`````9T```T````:G0``)@```"B=``!#````3YT``!\```"3G0``"```
M`+.=```+````O)T``"\```#(G0``!0```/B=```$````_IT```H````#G@``
M"@````Z>```/````&9X``!`````IG@``%P```#J>```1````4IX``!D```!D
MG@``%P```'Z>```%````EIX```H```"<G@``#0```*>>```;````M9X``!<`
M``#1G@``#@```.F>```-````^)X``!(````&GP``.````!F?```@````4I\`
M``@```!SGP``#@```'R?``![````BY\``!@````'H```&````""@```%````
M.:```!@````_H```'@```%B@```;````=Z```!D```"3H```&P```*V@```9
M````R:```!,```#CH```$````/>@```/````"*$``!`````8H0``#P```"FA
M```+````.:$```\```!%H0``#````%6A```/````8J$```<```!RH0``!@``
M`'JA```.````@:$```P```"0H0``*````)VA```/````QJ$```@```#6H0``
M"````-^A```3````Z*$``!X```#\H0``(0```!NB```@````/:(``!D```!>
MH@``%P```'BB```E````D*(``!<```"VH@``%@```,ZB```$````Y:(```P`
M``#JH@``"````/>B```*`````*,```P````+HP``$P```!BC```4````+*,`
M``P```!!HP``"0```$ZC```.````6*,```L```!GHP``&P```'.C```'````
MCZ,```<```"7HP``"@```)^C```-````JJ,```D```"XHP```P```,*C```8
M````QJ,```H```#?HP``!````.JC```F````[Z,```X````6I```%0```"6D
M```(````.Z0```(```!$I```!@```$>D```$````3J0```D```!3I```$```
M`%VD```)````;J0```D```!XI```&@```(*D```(````G:0``!D```"FI```
M#@```,"D```'````SZ0```D```#7I```"@```.&D```.````[*0```(```#[
MI```"P```/ZD```)````"J4```8````4I0``%````!NE```=````,*4``$(`
M``!.I0``)0```)&E```E````MZ4```8```#=I0``$0```.2E```)````]J4`
M``8`````I@``!P````>F```&````#Z8```0````6I@``$0```!NF```&````
M+:8```H````TI@``(@```#^F```$````8J8```4```!GI@``'0```&VF```$
M````BZ8```P```"0I@``#@```)VF```*````K*8```\```"WI@``$@```,>F
M```+````VJ8``"8```#FI@``*0````VG```D````-Z<``"8```!<IP``"```
M`(.G```*````C*<```<```"7IP``(````)^G```@````P*<``"8```#AIP``
M"@````BH```9````$Z@``"D````MJ```$@```%>H```'````:J@```H```!R
MJ```#````'VH```/````BJ@``!````":J```0````*NH``!P````[*@``&8`
M``!=J0``#@```,2I```)````TZD```H```#=J0``$@```.BI```3````^ZD`
M``P````/J@``!@```!RJ```/````(ZH``!(````SJ@``$````$:J```1````
M5ZH``!P```!IJ@``(P```(:J``!J````JJH```\````5JP``$````"6K```+
M````-JL``"````!"JP``%````&.K```,````>*L```P```"%JP``#P```)*K
M```5````HJL``"D```"XJP``*@```.*K```F````#:P``"<````TK```*0``
M`%RL```J````AJP``!D```"QK```0@```,NL```1````#JT``!(````@K0``
M$P```#.M```4````1ZT```\```!<K0``%@```&RM```7````@ZT``!````";
MK0``$0```*RM```T````OJT``!,```#SK0``$@````>N```U````&JX``!0`
M``!0K@``!P```&6N```,````;:X``"````!ZK@``$````)NN```4````K*X`
M`!$```#!K@``%P```-.N```<````ZZX``!,````(KP``%````!RO```:````
M,:\``!$```!,KP``&@```%ZO```>````>:\``!H```"8KP``$P```+.O```5
M````QZ\``!$```#=KP``%P```.^O```4````![```!<````<L```"0```#2P
M```0````/K````8```!/L```!0```%:P```'````7+````4```!DL```!```
M`&JP```$````;[````<```!TL```#@```'RP```,````B[````P```"8L```
M#0```*6P```.````L[```"@```#"L```#````.NP```/````^+````H````(
ML0``"````!.Q```)````'+$``"L````FL0``!````%*Q```'````5[$```@`
M``!?L0``"0```&BQ```4````<K$```P```"'L0``#0```)2Q```.````HK$`
M`!8```"QL0``$0```,BQ```#````VK$```8```#>L0``&0```.6Q```'````
M_[$```0````'L@``"P````RR```+````&+(```4````DL@``"@```"JR```$
M````-;(```\````ZL@``.@```$JR```%````A;(``!X```"+L@``#@```*JR
M```0````N;(```L```#*L@``#````-:R```)````X[(```<```#ML@``"@``
M`/6R```.`````+,``!`````/LP``&P```""S```8````/+,``!H```!5LP``
M"@```'"S```*````>[,```P```"&LP``#P```).S```(````H[,```8```"L
MLP``!P```+.S```%````N[,```L```#!LP``1P```,VS```-````%;0```D`
M```CM```!````"VT```#````,K0``!,````VM```$P```$JT```3````7K0`
M``H```!RM```)0```'VT```%````H[0```0```"IM```"@```*ZT```-````
MN;0``&@```#'M```!0```#"U```&````-K4``!L````]M0``+P```%FU```/
M````B;4``!,```"9M0``&P```*VU```8````R;4``!<```#BM0``'P```/JU
M```.````&K8```,````IM@``"````"VV```'````-K8```L````^M@``!P``
M`$JV``!1````4K8``!````"DM@``#````+6V```&````PK8``!H```#)M@``
M)0```.2V```&````"K<```8````1MP``!@```!BW```8````'[<``!<````X
MMP``*````%"W```&````>;<```T```"`MP``(@```(ZW``!7````L;<``!,`
M```)N```(P```!VX```3````0;@```(```!5N```"````%BX```-````8;@`
M``H```!ON```!P```'JX```.````@K@```<```"1N```"P```)FX```R````
MI;@```D```#8N```"0```.*X```*````[+@```<```#WN```"0```/^X```'
M````";D``!(````1N0``"@```"2Y```6````+[D```D```!&N0``$````%"Y
M```2````8;D```0```!TN0``!P```'FY```%````@;D```P```"'N0``"```
M`)2Y```7````G;D```P```"UN0``'P```,*Y```:````XKD``!,```#]N0``
M!````!&Z```*````%KH```0````AN@``#0```":Z```,````-+H```4```!!
MN@``!0```$>Z```X````3;H``"P```"&N@``*0```+.Z```R````W;H```H`
M```0NP``+````!N[```N````2+L``#,```!WNP``,P```*N[```X````W[L`
M``\````8O```&````"B\```0````0;P```\```!2O```$P```&*\```5````
M=KP``!0```",O```$@```*&\```4````M+P``"T```#)O```+0```/>\```Q
M````);T``"X```!7O0``+P```(:]```L````MKT``&(```#CO0``#0```$:^
M```(````5+X``!<```!=O@``"````'6^```,````?KX``"L```"+O@``(0``
M`+>^```:````V;X```D```#TO@``10```/Z^``!!````1+\```0```"&OP``
M$P```(N_```3````G[\```8```"SOP``"0```+J_```*````Q+\```\```#/
MOP``$````-^_```'````\+\```X```#XOP``!0````?````;````#<````@`
M```IP```!@```#+````4````.<```!$```!.P```#@```&#````X````;\``
M``8```"HP```#@```*_````%````OL````<```#$P```!@```,S````H````
MT\````P```#\P```'`````G!```I````)L$``!\```!0P0``7````'#!```4
M````S<$``#X```#BP0``'P```"'"```0````0<(```<```!2P@``#@```%K"
M```,````:<(```P```!VP@``$P```(/"```*````E\(``!T```"BP@``&0``
M`,#"```%````VL(``!$```#@P@``$0```/+"```D````!,,``!(````IPP``
M#@```#S#```9````2\,```@```!EPP``"0```&[#```:````>,,```<```"3
MPP``#0```)O#```>````J<,``!(```#(PP``+````-O#```:````",0``!4`
M```CQ```!0```#G$```4````/\0```0```!4Q```!@```%G$```'````8,0`
M`!X```!HQ```*````(?$```*````L,0``!P```"[Q```$0```-C$```+````
MZL0``!H```#VQ```%````!'%```%````)L4```8````LQ0``&P```#/%```T
M````3\4``#0```"$Q0``(````+G%```I````VL4``"`````$Q@``00```"7&
M```:````9\8``"@```""Q@``*0```*O&``!0````U<8``"(````FQP``!@``
M`$G'```(````4,<```4```!9QP``"````%_'```9````:,<``!D```""QP``
M*@```)S'```C````Q\<``"X```#KQP``-````!K(```(````3\@``!<```!8
MR```"@```'#(```'````>\@``"$```"#R```$````*7(```.````ML@```L`
M``#%R```!P```-'(```3````V<@```@```#MR```"@```/;(```4`````<D`
M``\````6R0``,@```";)```.````6<D```4```!HR0``#P```&[)```$````
M?LD```4```"#R0``!````(G)```-````CLD``#(```"<R0``10```,_)```7
M````%<H```<````MR@``'@```#7*```4````5,H```8```!IR@``!P```'#*
M```.````>,H``"H```"'R@``!@```++*```,````N<H```T```#&R@``$0``
M`-3*```+````YLH``#8```#RR@``"@```"G+```B````-,L```L```!7RP``
M#P```&/+```R````<\L``"4```"FRP``,````,S+```Q````_<L``"T````O
MS```#@```%W,```%````;,P```X```!RS```$P```(',```2````E<P```<`
M``"HS```$0```+#,```3````PLP```<```#6S```%````-[,```8````\\P`
M``<````,S0``!0```!3-```,````&LT```P````GS0``$@```#3-```$````
M1\T```H```!,S0``"P```%?-```,````8\T```X```!PS0``#@```'_-```%
M````CLT```4```"4S0``+@```)K-```F````R<T``",```#PS0```P```!3.
M```>````&,X``!@````WS@``)0```%#.```-````=LX``!\```"$S@``$@``
M`*3.```2````M\X```0```#*S@``"0```,_.```'````V<X```P```#AS@``
M4@```.[.```7````0<\``"0```!9SP``!P```'[/```&````AL\```X```"-
MSP``#````)S/```-````J<\``!4```"WSP``$@```,W/```/````X,\``!0`
M``#PSP``"@````70```;````$-```!`````LT```"P```#W0``!I````2=``
M`!H```"ST```%P```,[0```G````YM```!H````.T0``%P```"G1```;````
M0=$``!D```!=T0``'P```'?1```3````E]$```@```"KT0``"````+31```)
M````O=$```T```#'T0``(P```-71```-````^=$``!,````'T@``"````!O2
M```#````)-(``$8````HT@``/P```&_2```W````K](``%<```#GT@``!0``
M`#_3```?````1=,``"\```!ETP``#0```)73```M````H],```0```#1TP``
M3P```-;3```E````)M0``!P```!,U```"P```&G4```?````==0``!T```"5
MU```"P```+/4```'````O]0```D```#'U```$P```-'4```$````Y=0``!``
M``#JU```!````/O4```4`````-4```X````5U0``#````"35```3````,=4`
M`!P```!%U0``*````&+5```&````B]4```<```"2U0``$P```)K5```%````
MKM4``!<```"TU0``"@```,S5```,````U]4```D```#DU0``"@```.[5```1
M````^=4```X````+U@``#@```!K6```=````*=8```L```!'U@```@```%/6
M```<````5M8```<```!SU@``!@```'O6``!D````@M8``"8```#GU@``.```
M``[7```:````1]<``"H```!BUP``.P```(W7```H````R=<``#0```#RUP``
M&0```"?8```5````0=@```<```!7V```!P```%_8```'````9]@```8```!O
MV```"P```';8```<````@M@``!````"?V```"0```+#8```0````NM@```<`
M``#+V```!0```-/8```0````V=@``!0```#JV```"P```/_8```-````"]D`
M`!@````9V0``%P```#+9```$````2MD```D```!/V0``"@```%G9```"````
M9-D``",```!GV0``'P```(O9```X````J]D``"8```#DV0``,0````O:```G
M````/=H``!0```!EV@``.````'K:```H````L]H``#@```#<V@``*````!7;
M```L````/ML``!L```!KVP``/@```(?;```C````QML``"4```#JVP``00``
M`!#<``!;````4MP``$D```"NW```(0```/C<```?````&MT``"L````ZW0``
M)@```&;=```G````C=T``#H```"UW0``,P```/#=```E````)-X``"````!*
MW@``'P```&O>```P````B]X``&D```"\W@``,0```";?``!!````6-\``#,`
M``":WP``)0```,[?```]````]-\``&4````RX```30```)C@```O````YN``
M`"X````6X0``,````$7A``!4````=N$``%H```#+X0``2````";B``!*````
M;^(``#(```"ZX@``+P```.WB```L````'>,``"T```!*XP``)0```'CC```R
M````GN,``#X```#1XP``(@```!#D``!2````,^0``"4```"&Y```"P```*SD
M``!%````N.0``"$```#^Y```,````"#E```E````4>4``!P```!WY0``,0``
M`)3E```'````QN4```<```#.Y0``!````-;E```+````V^4```X```#GY0``
M!0```/;E```"````_.4``%D```#_Y0``!0```%GF```(````7^8``#````!H
MY@```P```)GF```,````G>8```T```"JY@```@```+CF```&````N^8``!(`
M``#"Y@``'P```-7F```U````]>8``"X````KYP``+P```%KG```7````BN<`
M`"(```"BYP``)0```,7G```@````Z^<``!L````,Z```&````"CH```D````
M0>@``!\```!FZ```&@```(;H```A````H>@``"````##Z```&@```.3H```R
M````_^@``!H````RZ0``+P```$WI```K````?>D``!\```"IZ0``(P```,GI
M```?````[>D``!H````-Z@``(0```"CJ```E````2NH``"8```!PZ@``)0``
M`)?J```D````O>H``!@```#BZ@``'0```/OJ```D````&>L``!@````^ZP``
M(@```%?K```L````>NL``"\```"GZP``%0```-?K```E````[>L``#P````3
M[```'P```%#L```C````<.P``!\```"4[```(````+3L```:````U>P``!@`
M``#P[```)@````GM```I````,.T``!X```!:[0``*0```'GM```>````H^T`
M`#$```#"[0``"0```/3M```,````_NT``!<````+[@``+P```"/N```D````
M4^X```<```!X[@``'0```(#N```:````GNX```<```"Y[@``%0```,'N```&
M````U^X```D```#>[@``"P```.CN```-````].X``!<````"[P``!@```!KO
M```S````(>\``!,```!5[P``$P```&GO```/````?>\```<```"-[P``,@``
M`)7O```$````R.\``"$```#-[P``$P```._O```,`````_```!$````0\```
M,@```"+P```6````5?````@```!L\```'0```'7P```)````D_````H```"=
M\```%````*CP```=````O?````@```#;\```'P```.3P```(````!/$``!H`
M```-\0``)P```"CQ```&````4/$``!4```!7\0``"````&WQ```_````=O$`
M``<```"V\0``#P```+[Q```.````SO$``!````#=\0``"0```.[Q```)````
M^/$```<````"\@``&0````KR```*````)/(```H````O\@``#````#KR```$
M````1_(``"H```!,\@``!P```'?R```"````?_(``!````""\@``&````)/R
M```&````K/(```<```"S\@``#0```+OR```+````R?(``"\```#5\@``(```
M``7S```Q````)O,```4```!8\P``$@```%[S```_````<?,``!(```"Q\P``
M"@```,3S```&````S_,```0```#6\P``$P```-OS```%````[_,```8```#U
M\P``!@```/SS```$`````_0```P````(]```"@```!7T```Y````(/0``"X`
M``!:]```*0```(GT```&````L_0```,```"Z]```#````+[T``!%````R_0`
M`#(````1]0``&@```$3U```T````7_4``"@```"4]0``4P```+WU```9````
M$?8``'(````K]@``(````)[V```U````O_8``"$```#U]@``10```!?W```P
M````7?<``"@```".]P``*0```+?W```F````X?<``"4````(^```*````"[X
M```H````5_@``"(```"`^```*P```*/X```P````S_@``!(`````^0``$P``
M`!/Y```0````)_D``'D````X^0``"0```++Y``"A````O/D``',```!>^@``
M?````-+Z```K````3_L``%0```![^P``%P```-#[```G````Z/L``!8````0
M_```#P```"?\```7````-_P``!\```!/_```0````&_\```?````L/P``!P`
M``#0_```40```.W\```:````/_T``!0```!:_0``$@```&_]```0````@OT`
M`!,```"3_0``'0```*?]```/````Q?T```\```#5_0``"P```.7]```'````
M\?T```4```#Y_0``%````/_]```'````%/X```@````<_@``#P```"7^```(
M````-?X```P````^_@``#P```$O^```&````6_X``!0```!B_@``!@```'?^
M```,````?OX``!$```"+_@``"````)W^```$````IOX``!D```"K_@``$0``
M`,7^```*````U_X``!@```#B_@``$P```/O^```1````#_\``!8````A_P``
M!````#C_```/````/?\``!D```!-_P``$0```&?_```)````>?\``!(```"#
M_P``%P```);_```&````KO\``"<```"U_P``!````-W_```/````XO\``!,`
M``#R_P``!P````8``0`'````#@`!`!$````6``$`&````"@``0`3````00`!
M`!````!5``$`!@```&8``0`,````;0`!``D```!Z``$`$0```(0``0`B````
ME@`!``<```"Y``$`!P```,$``0`+````R0`!``(```#5``$`"P```-@``0"(
M`0``Y``!`!,```!M`@$`%P```($"`0`/````F0(!``<```"I`@$`"0```+$"
M`0`'````NP(!``0```##`@$`&0```,@"`0`=````X@(!`"T``````P$`(0``
M`"X#`0`K````4`,!`"T```!\`P$`'````*H#`0`K````QP,!``H```#S`P$`
M*@```/X#`0`3````*00!``P````]!`$`$0```$H$`0`%````7`0!`"@```!B
M!`$`#P```(L$`0`(````FP0!`!4```"D!`$`$0```+H$`0`*````S`0!`(P`
M``#7!`$`#@```&0%`0`)````<P4!``\```!]!0$`#0```(T%`0`-````FP4!
M`!````"I!0$`"@```+H%`0`4````Q04!``8```#:!0$`D0```.$%`0`,````
M<P8!`!$```"`!@$`%@```)(&`0`/````J08!``X```"Y!@$`#@```,@&`0`&
M````UP8!``L```#>!@$`-0```.H&`0`<````(`<!`#T````]!P$`2````'L'
M`0!I````Q`<!`&<````N"`$`<````)8(`0!M````!PD!`$````!U"0$`!P``
M`+8)`0`2````O@D!``H```#1"0$`#0```-P)`0`+````Z@D!``4```#V"0$`
M!@```/P)`0`6`````PH!``L````:"@$`*````"8*`0`@````3PH!`!0```!P
M"@$`$````(4*`0`2````E@H!``H```"I"@$`"````+0*`0`6````O0H!`!@`
M``#4"@$`#0```.T*`0`5````^PH!`!<````1"P$`(````"D+`0`B````2@L!
M`!D```!M"P$`$````(<+`0`5````F`L!`!(```"N"P$`+````,$+`0`6````
M[@L!`!X````%#`$`#P```"0,`0!2````-`P!`"P```"'#`$`)````+0,`0`)
M````V0P!``<```#C#`$`-````.L,`0`/````(`T!``<````P#0$`#0```#@-
M`0`%````1@T!`!P```!,#0$`#@```&D-`0`0````>`T!`!8```")#0$`'```
M`*`-`0`V````O0T!``H```#T#0$`%@```/\-`0`9````%@X!`!<````P#@$`
M&P```$@.`0`4````9`X!`!(```!Y#@$`*@```(P.`0`3````MPX!``@```#+
M#@$`#````-0.`0`2````X0X!`!@```#T#@$`&@````T/`0`'````*`\!`!D`
M```P#P$`!@```$H/`0`;````40\!``T```!M#P$`.P```'L/`0`X````MP\!
M`$<```#P#P$`%````#@0`0`R````31`!`#0```"`$`$`-0```+40`0`Z````
MZQ`!``D````F$0$`!@```#`1`0`S````-Q$!`#0```!K$0$`,@```*`1`0!7
M````TQ$!`#(````K$@$`,0```%X2`0!%````D!(!`$L```#6$@$`,0```"(3
M`0!/````5!,!`"T```"D$P$`+0```-(3`0!.`````!0!`#$```!/%`$`-P``
M`($4`0`J````N10!`!8```#D%`$`&@```/L4`0`K````%A4!`"4```!"%0$`
M)0```&@5`0`2````CA4!``8```"A%0$`#0```*@5`0`=````MA4!`!L```#4
M%0$`*P```/`5`0`*````'!8!`"\````G%@$`$P```%<6`0`+````:Q8!``D`
M``!W%@$`"@```($6`0`%````C!8!`!,```"2%@$`!0```*86`0`4````K!8!
M``@```#!%@$`!0```,H6`0`'````T!8!``X```#8%@$``P```.<6`0`#````
MZQ8!`!<```#O%@$`$P````<7`0`I````&Q<!``H```!%%P$`!0```%`7`0`(
M````5A<!`$@```!?%P$`3P```*@7`0!/````^!<!`"$```!(&`$`)0```&H8
M`0`I````D!@!`"````"Z&`$`"````-L8`0`;````Y!@!`",`````&0$`+0``
M`"09`0`V````4AD!`"D```")&0$`*0```+,9`0!2````W1D!`#H````P&@$`
M"````&L:`0`5````=!H!``P```"*&@$`"0```)<:`0`/````H1H!`!(```"Q
M&@$`#P```,0:`0`-````U!H!``D```#B&@$`!@```.P:`0`;````\QH!`!@`
M```/&P$`'````"@;`0`9````11L!``8```!?&P$`%@```&8;`0!>````?1L!
M`&D```#<&P$`!P```$8<`0`.````3AP!``0```!='`$`!````&(<`0`6````
M9QP!`!,```!^'`$`%0```)(<`0`A````J!P!`#@```#*'`$`,P````,=`0`&
M````-QT!``\````^'0$`%````$X=`0`.````8QT!`!L```!R'0$`#P```(X=
M`0`4````GAT!``\```"S'0$`!````,,=`0`+````R!T!``@```#4'0$`#@``
M`-T=`0`.````[!T!``8```#['0$`#`````(>`0`0````#QX!``@````@'@$`
M#@```"D>`0`'````.!X!``<```!`'@$`$````$@>`0`(````61X!``L```!B
M'@$`!P```&X>`0`)````=AX!``H```"`'@$`"@```(L>`0`?````EAX!`$<`
M``"V'@$`'````/X>`0`,````&Q\!`!0````H'P$`%0```#T?`0`6````4Q\!
M`"P```!J'P$`/````)<?`0`B````U!\!``@```#W'P$`/0`````@`0`F````
M/B`!`!$```!E(`$`"````'<@`0`%````@"`!`!$```"&(`$`#P```)@@`0`F
M````J"`!`"8```#/(`$`*@```/8@`0`I````(2$!`"4```!+(0$`)@```'$A
M`0`F````F"$!`"8```"_(0$`-````.8A`0`Q````&R(!`"X```!-(@$`,```
M`'PB`0`E````K2(!`#,```#3(@$`1P````<C`0`\````3R,!`#,```",(P$`
M00```,`C`0!-`````B0!`"<```!0)`$`)0```'@D`0`S````GB0!`"L```#2
M)`$`%@```/XD`0`P````%24!`"4```!&)0$`)@```&PE`0`7````DR4!`+$`
M``"K)0$`&@```%TF`0`E````>"8!`#0```">)@$`-````-,F`0`P````""<!
M`"@````Y)P$`*0```&(G`0`L````C"<!`#,```"Y)P$`-@```.TG`0!+````
M)"@!`$8```!P*`$`F0```+<H`0`M````42D!`"8```!_*0$`-````*8I`0`S
M````VRD!`$4````/*@$`3````%4J`0`-````HBH!``<```"P*@$`!0```+@J
M`0`$````OBH!``P```##*@$`#@```-`J`0`5````WRH!`!0```#U*@$`%P``
M``HK`0`/````(BL!`!$````R*P$`#0```$0K`0`0````4BL!``X```!C*P$`
M#0```'(K`0`5````@"L!``X```"6*P$`-@```*4K`0`&````W"L!`!,```#C
M*P$`!0```/<K`0`,````_2L!``0````*+`$`#0````\L`0`1````'2P!``8`
M```O+`$`$````#8L`0`(````1RP!``\```!0+`$`&````&`L`0`/````>2P!
M`!,```")+`$`$````)TL`0`+````KBP!``<```"Z+`$`#0```,(L`0`.````
MT"P!``L```#?+`$`$````.LL`0`>````_"P!``T````;+0$`#P```"DM`0`I
M````.2T!`!(```!C+0$`&P```'8M`0`R````DBT!``P```#%+0$`'@```-(M
M`0`9````\2T!`!L````++@$`&````"<N`0`^````0"X!``T```!_+@$`"0``
M`(TN`0`4````ERX!``L```"L+@$`*@```+@N`0!#````XRX!``@````G+P$`
M$````#`O`0`C````02\!`!(```!E+P$`'@```'@O`0`>````ER\!`"<```"V
M+P$`&@```-XO`0`A````^2\!`!H````;,`$`&````#8P`0`-````3S`!`"D`
M``!=,`$`20```(<P`0`=````T3`!``<```#O,`$`"@```/<P`0`]`````C$!
M``8```!`,0$`"````$<Q`0`1````4#$!`!$```!B,0$`$P```'0Q`0`3````
MB#$!`!H```"<,0$`&@```+<Q`0`=````TC$!`!P```#P,0$`!@````TR`0`+
M````%#(!``\````@,@$`)0```#`R`0`2````5C(!`!````!I,@$`$````'HR
M`0`9````BS(!`$P```"E,@$`0@```/(R`0`)````-3,!`!,````_,P$`B```
M`%,S`0`A````W#,!`"4```#^,P$`!@```"0T`0`<````*S0!`"L```!(-`$`
M*0```'0T`0`A````GC0!`"(```#`-`$`'@```.,T`0`6`````C4!``X````9
M-0$`#0```"@U`0`/````-C4!``T```!&-0$`#P```%0U`0`-````9#4!``L`
M``!R-0$`$0```'XU`0`&````D#4!``<```"7-0$`#P```)\U`0`,````KS4!
M`"P```"\-0$`$````.DU`0`)````^C4!``D````$-@$`)`````XV`0`P````
M,S8!`"0```!D-@$`(P```(DV`0`A````K38!`"````#/-@$`,P```/`V`0`A
M````)#<!`!\```!&-P$`!@```&8W`0`.````;3<!``@```!\-P$`"````(4W
M`0`)````CC<!`!<```"8-P$`&````+`W`0`-````R3<!``D```#7-P$`#@``
M`.$W`0`+````\#<!`!\```#\-P$`!@```!PX`0`)````(S@!``L````M.`$`
M#````#DX`0`.````1C@!``8```!5.`$`&0```%PX`0`2````=C@!``0```")
M.`$`*@```(XX`0`0````N3@!`!P```#*.`$`!P```.<X`0`"````[S@!``<`
M``#R.`$``@```/HX`0`&````_3@!`!0````$.0$`"0```!DY`0`-````(SD!
M`"D````Q.0$`"0```%LY`0`8````93D!``\```!^.0$`"````(XY`0`*````
MESD!``D```"B.0$`#P```*PY`0`#````O#D!``P```#`.0$`#@```,TY`0`&
M````W#D!`!8```#C.0$`*@```/HY`0!2````)3H!`"X```!X.@$`+P```*<Z
M`0`&````USH!`!4```#>.@$`$@```/0Z`0`,````!SL!``P````4.P$`!P``
M`"$[`0`%````*3L!`!4````O.P$`"````$4[`0`(````3CL!`!L```!7.P$`
M!````',[`0`&````>#L!`"````!_.P$`!0```*`[`0`1````ICL!`!$```"X
M.P$`$````,H[`0`2````VSL!`!<```#N.P$`#`````8\`0`Y````$SP!`!H`
M``!-/`$`(````&@\`0`8````B3P!``<```"B/`$`"0```*H\`0`(````M#P!
M`"@```"]/`$`+````.8\`0`T````$ST!``P```!(/0$`'0```%4]`0`\````
M<ST!`!@```"P/0$`!P```,D]`0`*````T3T!``P```#</0$`#P```.D]`0`2
M````^3T!`$L````,/@$`C@```%@^`0!T````YSX!`"(```!</P$`#````'\_
M`0`-````C#\!`!<```":/P$`&````+(_`0`4````RS\!``@```#@/P$`$0``
M`.D_`0`3````^S\!`!`````/0`$`%````"!``0`=````-4`!`"8```!30`$`
M>P```'I``0`5````]D`!`!(````,00$`#````!]!`0`A````+$$!`!<```!.
M00$`$@```&9!`0`1````>4$!`!(```"+00$`&````)Y!`0`P````MT$!`#0`
M``#H00$`+0```!U"`0`Q````2T(!`"P```!]0@$`+@```*I"`0`B````V4(!
M`$@```#\0@$`&````$5#`0`9````7D,!`!H```!X0P$`&P```)-#`0`1````
MKT,!`!L```#!0P$`'````-U#`0`7````^D,!`!@````21`$`.@```"M$`0`=
M````9D0!`!H```"$1`$`/@```)]$`0`6````WD0!``8```#U1`$`#````/Q$
M`0`B````"44!`!,````L10$`&````$!%`0`3````644!`"@```!M10$`*@``
M`)9%`0`@````P44!`"4```#B10$`'0````A&`0`4````)D8!`!T````[1@$`
M(````%E&`0`A````>D8!`!H```"<1@$`&P```+=&`0`6````TT8!`!T```#J
M1@$`'`````A'`0`>````)4<!``H```!$1P$`%````$]'`0`)````9$<!``8`
M``!N1P$`!P```'5'`0`(````?4<!``8```"&1P$`!@```(U'`0`*````E$<!
M`!0```"?1P$`$````+1'`0`5````Q4<!`!,```#;1P$`%@```.]'`0`Q````
M!D@!`!`````X2`$`'@```$E(`0`6````:$@!`!$```!_2`$`$````)%(`0`P
M````HD@!``@```#32`$`#0```-Q(`0`*````ZD@!``P```#U2`$`+P````))
M`0`-````,DD!`!4```!`20$`%@```%9)`0`=````;4D!`!<```"+20$`!0``
M`*-)`0`,````J4D!`"4```"V20$`!@```-Q)`0`(````XTD!`!@```#L20$`
M$@````5*`0`'````&$H!``\````@2@$`#````#!*`0`8````/4H!`$\```!6
M2@$`#````*9*`0`H````LTH!`!,```#<2@$`'@```/!*`0`.````#TL!`!0`
M```>2P$`$0```#-+`0`:````14L!`!@```!@2P$`%0```'E+`0`?````CTL!
M`"4```"O2P$`(P```-5+`0`E````^4L!``L````?3`$`#@```"M,`0`,````
M.DP!``P```!'3`$`!0```%1,`0`%````6DP!``0```!@3`$`!0```&5,`0`5
M````:TP!`%,```"!3`$`$````-5,`0`+````YDP!``4```#R3`$`!0```/A,
M`0`8````_DP!`!@````730$`%P```#!-`0`+````2$T!`"T```!430$`!@``
M`()-`0`%````B4T!`!@```"/30$`%0```*A-`0!E````ODT!``4````D3@$`
M!P```"I.`0`I````,DX!`#@```!<3@$`%````)5.`0`9````JDX!`"@```#$
M3@$`'0```.U.`0`<````"T\!`!\````H3P$`$0```$A/`0`&````6D\!``@`
M``!A3P$`!@```&I/`0`/````<4\!``D```"!3P$`:0```(M/`0`2````]4\!
M``X````(4`$`!@```!=0`0`>````'E`!`"@````]4`$`!P```&90`0`'````
M;E`!``4```!V4`$`'````'Q0`0`;````F5`!`#4```"U4`$`"````.M0`0`%
M````]%`!`"H```#Z4`$`5````"51`0`:````>E$!`"P```"540$`&P```,)1
M`0`"````WE$!``@```#A40$`$P```.I1`0`,````_E$!``8````+4@$`"P``
M`!)2`0`+````'E(!``L````J4@$`2P```#92`0`,````@E(!`!$```"/4@$`
M#P```*%2`0`,````L5(!``P```"^4@$`#````,M2`0`2````V%(!``L```#K
M4@$`'````/=2`0`+````%%,!`!P````@4P$`%@```#U3`0`$````5%,!``0`
M``!94P$``P```%Y3`0`/````8E,!``H```!R4P$`'0```'U3`0`.````FU,!
M`!\```"J4P$`(@```,I3`0`7````[5,!``<````%5`$`$0````U4`0`(````
M'U0!``\````H5`$`$````#A4`0`)````250!``4```!35`$`6````%E4`0`X
M````LE0!`"T```#K5`$`10```!E5`0`1````7U4!`#0```!Q50$`2````*95
M`0!-````[U4!`$T````]5@$`4@```(M6`0`=````WE8!`"0```#\5@$`'```
M`"%7`0`@````/E<!`",```!?5P$`(@```(-7`0`A````IE<!`"````#(5P$`
M(@```.E7`0`Z````#%@!`#H```!'6`$`/@```()8`0`[````P5@!`#P```#]
M6`$`.0```#I9`0"5````=%D!`!\````*6@$`#@```"I:`0`F````.5H!``P`
M``!@6@$`$P```&U:`0`X````@5H!`#````"Z6@$`*@```.M:`0`-````%EL!
M`%L````D6P$`50```(!;`0`'````UEL!`!<```#>6P$`%P```/9;`0`(````
M#EP!``@````77`$`"0```"!<`0`1````*EP!`!`````\7`$`#0```$U<`0`/
M````6UP!``<```!K7`$`)@```'-<`0`(````FEP!``8```"C7`$`$P```*I<
M`0`1````OEP!``\```#07`$`50```.!<`0`'````-ET!`!4````^70$`!@``
M`%1=`0`'````6UT!``<```!C70$`-````&M=`0`0````H%T!`",```"Q70$`
M-````-5=`0`D````"EX!`'\````O7@$`&@```*]>`0!3````REX!`"X````>
M7P$`$0```$U?`0`'````7U\!``X```!G7P$`#P```'9?`0`.````AE\!`!,`
M``"57P$`!@```*E?`0`C````L%\!`!D```#47P$`!0```.Y?`0`2````]%\!
M`!D````'8`$`)P```"%@`0`8````26`!`!,```!B8`$`(````'9@`0`*````
MEV`!``D```"B8`$`&0```*Q@`0`+````QF`!`!4```#28`$`'P```.A@`0`5
M````"&$!`#4````>80$`%0```%1A`0`A````:F$!``<```",80$`%P```)1A
M`0`(````K&$!``<```"U80$`"P```+UA`0`D````R6$!`#0```#N80$`"```
M`"-B`0`=````+&(!``\```!*8@$`"````%IB`0`1````8V(!`!8```!U8@$`
M"````(QB`0`*````E6(!`"0```"@8@$`/@```,5B`0`_````!&,!`"<```!$
M8P$`-````&QC`0`L````H6,!`$T```#.8P$`(P```!QD`0`N````0&0!`#4`
M``!O9`$`70```*5D`0`R`````V4!``<````V90$`"````#YE`0`)````1V4!
M``H```!190$`(0```%QE`0`@````?F4!`#$```"?90$`)0```-%E`0`R````
M]V4!`#\````J9@$`"0```&IF`0`?````=&8!``L```"49@$`"0```*!F`0`M
M````JF8!`!$```#89@$`$````.IF`0`.````^V8!``@````*9P$`&````!-G
M`0`(````+&<!``\````U9P$`'P```$5G`0`B````96<!`$0```"(9P$`$@``
M`,UG`0`'````X&<!``\```#H9P$`!P```/AG`0`(`````&@!``4````):`$`
M$@````]H`0`_````(F@!`&,```!B:`$`'0```,9H`0`(````Y&@!`"@```#M
M:`$`(````!9I`0`(````-VD!``P```!`:0$`#0```$UI`0`J````6VD!``<`
M``"&:0$`$0```(YI`0`2````H&D!`!@```"S:0$`$0```,QI`0!`````WFD!
M``H````?:@$`(0```"IJ`0`0````3&H!`!0```!=:@$`0````')J`0`L````
MLVH!`#P```#@:@$`/0```!UK`0`V````6VL!``\```"2:P$`!@```*)K`0`2
M````J6L!`!8```"\:P$`&P```--K`0`)````[VL!`!0```#Y:P$`&@````YL
M`0`(````*6P!`!D````R;`$`'P```$QL`0`+````;&P!``8```!X;`$`%@``
M`']L`0`0````EFP!`!@```"G;`$`!@```,!L`0`,````QVP!`!````#4;`$`
M#@```.5L`0`4````]&P!`!0````);0$`!@```!YM`0`&````)6T!`#4````L
M;0$`*0```&)M`0`G````C&T!``@```"T;0$`%````+UM`0`8````TFT!`"@`
M``#K;0$`#0```!1N`0`J````(FX!`!@```!-;@$`%````&9N`0`%````>VX!
M``H```"!;@$`"````(QN`0`0````E6X!`&4```"F;@$`&@````QO`0`_````
M)V\!``<```!G;P$`!P```&]O`0`1````=V\!`!````");P$`$@```)IO`0`A
M````K6\!`!\```#/;P$`$P```.]O`0`A`````W`!``\````E<`$`*````#5P
M`0`4````7G`!`!$```!S<`$`=@```(5P`0`@````_'`!`"`````=<0$`*0``
M`#YQ`0`=````:'$!`!X```"&<0$`)@```*5Q`0`?````S'$!`!X```#L<0$`
M'`````MR`0`)````*'(!``D````R<@$`"0```#QR`0`/````1G(!`#0```!6
M<@$`&@```(MR`0`8````IG(!``@```"_<@$`!P```,AR`0!;````T'(!`$``
M```L<P$`/0```&US`0""````JW,!``P````N=`$`-@```#MT`0`P````<G0!
M``X```"C=`$`/P```+)T`0`&````\G0!`%,```#Y=`$`+@```$UU`0`O````
M?'4!`!8```"L=0$`,@```,-U`0`D````]G4!`!4````;=@$`#````#%V`0`%
M````/G8!`!(```!$=@$`"@```%=V`0`C````8G8!``0```"&=@$`(0```(MV
M`0`2````K78!``H```#`=@$`%````,MV`0`:````X'8!`"\```#[=@$`#0``
M`"MW`0`*````.7<!`!@```!$=P$`!@```%UW`0`>````9'<!``\```"#=P$`
M$0```)-W`0`/````I7<!`!````"U=P$`$0```,9W`0`9````V'<!``D```#R
M=P$`'P```/QW`0`+````''@!``(````H>`$`(````"MX`0`'````3'@!``H`
M``!4>`$`?P```%]X`0`N````WW@!`%@````.>0$`'````&=Y`0`F````A'D!
M`$D```"K>0$`,````/5Y`0`\````)GH!`!P```!C>@$`%P```(!Z`0`(````
MF'H!``@```"A>@$`"@```*IZ`0`&````M7H!``@```"\>@$`*0```,5Z`0`7
M````[WH!`!H````'>P$`%P```")[`0`*````.GL!``@```!%>P$`$@```$Y[
M`0`>````87L!``L```"`>P$`#0```(Q[`0`:````FGL!`!$```"U>P$`!0``
M`,=[`0`*````S7L!`!(```#8>P$``@```.M[`0`C````[GL!`"H````2?`$`
M-P```#U\`0`L````=7P!`#D```"B?`$`+@```-Q\`0`;````"WT!`#L````G
M?0$`,@```&-]`0`]````EGT!`#(```#4?0$`-0````=^`0`B````/7X!`$<`
M``!@?@$`(P```*A^`0`Q````S'X!`$````#^?@$`<@```#]_`0!E````LG\!
M`"$````8@`$`'P```#J``0`R````6H`!`"0```"-@`$`(P```+*``0`Y````
MUH`!`#P````0@0$`*````$V!`0`O````=H$!`"````"F@0$`.0```,>!`0!W
M`````8(!`#L```!Y@@$`5````+6"`0`V````"H,!`#0```!!@P$`3@```':#
M`0!T````Q8,!`%P````ZA`$`1P```)>$`0!`````WX0!`$`````@A0$`8@``
M`&&%`0!G````Q(4!`&`````LA@$`8P```(V&`0`\````\88!`#@````NAP$`
M-````&>'`0`S````G(<!`"@```#0AP$`-````/F'`0!-````+H@!`"H```!\
MB`$`5P```*>(`0`C````_X@!``P````CB0$`30```#")`0`@````?HD!`#X`
M``"?B0$`)P```-Z)`0`D````!HH!`$(````KB@$`!0```&Z*`0`)````=(H!
M``,```!^B@$`$````(**`0`2````DXH!``8```"FB@$``0```*V*`0!D````
MKXH!``0````4BP$`!@```!F+`0`T````((L!``0```!5BP$`"@```%J+`0`,
M````98L!``(```!RBP$`!P```'6+`0`6````?8L!`"@```"4BP$`6````+V+
M`0`U````%HP!`#8```!,C`$`&@```(.,`0`M````GHP!`#````#,C`$`)@``
M`/V,`0`@````)(T!`"````!%C0$`*0```&:-`0`D````D(T!`!\```"UC0$`
M*````-6-`0`E````_HT!`"D````DC@$`-0```$Z.`0`?````A(X!`#(```"D
MC@$`.0```->.`0`G````$8\!`"L````YCP$`)P```&6/`0`B````C8\!`"L`
M``"PCP$`,````-R/`0`M````#9`!`"X````[D`$`*@```&J0`0`A````E9`!
M`"0```"WD`$`,````-R0`0`?````#9$!`"<````MD0$`.````%61`0`W````
MCI$!`!T```#&D0$`*0```.21`0!+````#I(!`"@```!:D@$`+````(.2`0`H
M````L)(!`"D```#9D@$`(P````.3`0`?````)Y,!`"H```!'DP$`.P```'*3
M`0`F````KI,!`#$```#5DP$`,@````>4`0!%````.I0!``P```"`E`$`$0``
M`(V4`0`=````GY0!`#4```"]E`$`(````/.4`0`+````%)4!`"(````@E0$`
M(0```$.5`0`*````994!`!D```!PE0$`"````(J5`0`+````DY4!``\```"?
ME0$`#@```*^5`0`@````OI4!``8```#?E0$`1````.:5`0`:````*Y8!`!<`
M``!&E@$`$P```%Z6`0`'````<I8!`$8```!ZE@$`!@```,&6`0`D````R)8!
M``\```#ME@$`#@```/V6`0`4````#)<!`$(````AEP$`%P```&27`0`+````
M?)<!`"````"(EP$`#````*F7`0`-````MI<!`!,```#$EP$`'````-B7`0`'
M````]9<!`"0```#]EP$`"````"*8`0`8````*Y@!`#(```!$F`$`!@```'>8
M`0`<````?I@!``D```";F`$`0@```*68`0`(````Z)@!`!4```#QF`$`%@``
M``>9`0`5````'ID!``H````TF0$`"@```#^9`0`-````2ID!`"$```!8F0$`
M$@```'J9`0`*````C9D!``P```"8F0$`"@```*69`0`R````L)D!``H```#C
MF0$``@```.Z9`0`8````\9D!`",````*F@$`#P```"Z:`0`)````/IH!``X`
M``!(F@$`#0```%>:`0`X````99H!`"4```">F@$`,````,2:`0`)````]9H!
M`!8```#_F@$`3````!:;`0`7````8YL!`!(```![FP$`"@```(Z;`0`%````
MF9L!`!H```"?FP$`!@```+J;`0`'````P9L!``@```#)FP$`!@```-*;`0`4
M````V9L!`!,```#NFP$`/0````*<`0`N````0)P!`#T```!OG`$`"P```*V<
M`0`"````N9P!`!(```"\G`$`20```,^<`0`P````&9T!`!<```!*G0$`-@``
M`&*=`0`K````F9T!`%<```#%G0$`%@```!V>`0!X````-)X!`!\```"MG@$`
M/@```,V>`0`@````#)\!`$`````MGP$`.````&Z?`0`H````IY\!`"<```#0
MGP$`*````/B?`0`I````(:`!`"D```!+H`$`)P```'6@`0`O````G:`!`"P`
M``#-H`$`0````/J@`0`6````.Z$!`!\```!2H0$`$P```'*A`0"%````AJ$!
M``L````,H@$`J````!BB`0!Z````P:(!`(4````\HP$`+````,*C`0!=````
M[Z,!`!,```!-I`$`+@```&&D`0`;````D*0!`!4```"LI`$`%P```,*D`0`B
M````VJ0!`$8```#]I`$`)0```$2E`0`@````:J4!`%P```"+I0$`&@```.BE
M`0`5`````Z8!`!H````9I@$`%0```#2F`0`9````2J8!`",```!DI@$`$```
M`(BF`0`0````F:8!``X```"JI@$`!P```+FF`0`&````P:8!`!L```#(I@$`
M!@```.2F`0`%````ZZ8!`!D```#QI@$`"`````NG`0`)````%*<!`!@````>
MIP$`#0```#>G`0`;````1:<!``8```!AIP$`!P```&BG`0`5````<*<!``H`
M``"&IP$`!0```)&G`0`A````EZ<!`!@```"YIP$`"0```-*G`0`F````W*<!
M`!@````#J`$`'0```!RH`0`;````.J@!``@```!6J`$`$0```%^H`0`4````
M<:@!`!4```"&J`$`"0```)RH`0`6````IJ@!`!L```"]J`$`!@```-FH`0`X
M````X*@!``0````9J0$`$````!ZI`0`7````+ZD!``L```!'J0$`"````%.I
M`0`/````7*D!`!P```!LJ0$`&````(FI`0`4````HJD!``@```"WJ0$`$0``
M`,"I`0`/````TJD!`!$```#BJ0$`*P```/2I`0`)````(*H!``H````JJ@$`
M$@```#6J`0`"````2*H!``L```!+J@$``0````````!_````]P(``!8"``#(
M`P```````%D!```/`P````````4!````````704````````#!0``-`$`````
M````````4`$```````#5`P``,0(``(4"``"+`@``]00```````!O`P``3```
M``D!``"#`@``A@0``%P```"1`0```````&$$````````.@```"X#``#S`0``
MO0$```````!6!```3P(``,P#``"I````D@$`````````````%@```/<#````
M````9`4``$<%``#R!````````````````````0,``#\$``"N!```00$`````
M```/!```P@$``"<#``#$`@``(P(``,<"``!"`@```````"L#```;!0``K@,`
M`(8%```]`0``8`,``'@%``"Z`@``?`,`````````````<`(``````````0``
M=00````````B`0``_@(``#L!````````[`$``"0$`````````````%,%``#Q
M!```%P`````````<`P``6P,``)4"``".`0``$0(``+`"````````#@$``"X"
M``!D`0``]P0``/H#```3`P``<`4``/0$```Q````D`$``",#````````/00`
M`,(```",`P``%P(```$!``"@````7@4```````!U`0``K`$`````````````
MA00``$$%`````````P0``'0$``"P`0``2@(``%(````,!```E@```/4#````
M``````````````#T`0``^00```````#@`@``9`,``$P#``!(`P``^`(``(``
M``!\!0``&@,`````````````/@4``),"``!;!```=04``,D```#P!```!@$`
M```````%`P``8P4```````````````````````":!```%`4`````````````
MXP```.H#``#Z````#`4```````!O!```+@4``,`````9`P``(@4``#`!``"8
M`@`````````````6`0```````+0#``!8`0``W0$```````":`P```````%<!
M````````3@(```````"2````_P0```````````````````````#C`0``````
M`.D```"$!0``K`0``$,%````````C@0``*4!```_`0``'P```,<#``!1!0``
M`````-($```W!```#0$``#4#``",`0```````!4"```,`````````*0```!R
M!0``G@,``)8"```*`P```````'``````````PP(```````#]`0``/@```"X$
M``#*`P``1P(``)L``````````````#(#````````JP$``%$!````````````
M```````;`@``:`````````"H`@``C0,``',#``"+`0``````````````````
M_`,``.@!``#<`0``````````````````6P$``%,#````````F0(``(\```!V
M`0``\`,``)@#````````#@`````````4`@``VP0``!D"``#N````O`(``)<$
M```_`P```````'`#``!Z````8`$``)\!`````````````*$!``!J!```]`,`
M`%L%``!W`@``(@,`````````````P@0``/$`````````8`(``-@#````````
MR0$``(`"````````>P$``!@!````````,`0``````````````````!@"``#:
M`````````+$"``#3`P``G`(``.$$```J`@``1@0```````#H`````````-@"
M```)!0``SP(``!$%``"[`0```````#<%``"V!```D`(`````````````````
M`"<````L`@``>P4```````#-`P``VP````````"2`@```@,``*T#``#(````
M:P````````!V````80,``&D%`````````04``*H```"V`@``000```````#F
M!```3@,``!(#``"8`````````&H#``#M`@``CP$``$,```"J`@``'`4``(@#
M````````(04````````^`P```````*,!``"/`P``70,`````````````'@(`
M`*\$``"=!```A`0``*P"``"Q`````````'<$``!K`P``A@````````"S`P``
M-0$```````!J````;`,``.T$``!+`@``X@```+\```"_!````````)L!``!^
M!0``=@4``-T```"=`P``1@,``$T"````````T0,``!T```"1`@``\0(`````
M`````````````#H#`````````````!@%`````````````*("``"W!```3`4`
M`/@!```-`@``>P```$,$``!:`0```````.4"````````G`,``$D"``!(!0``
MT0```"("````````XP0``(<#``")`@``V0,``!L$```G`0``Y`$``/@```!/
M````4````!D$``#8!````````.X"``!+!0```````#T#````````10``````
M````````S00``&(%``"E`P``L@(``#8%``#F`P``C00````````V`P``````
M`.P"````````Q@```"@!``#8````C@(`````````````_`(````````?`@``
M`````!H!``#_````204``&X#```&`@``9P$``+(!``#O`P```````/\#````
M`````````"8$```[!0```````"<%``"D`P``V`$````"``#X`P``+P(``!T%
M``#U````(P4``*H#``!Y`````````#`"``!)`P``*`4```D#``#/`0``9P(`
M`&8"`````````0(``%D$``!U````J`$``"$!``#Q`0``#@0``,0#``!N!```
M304``%<#``#0`P``\0,``&8#``!.````TP(````````3`@```````,8$``!U
M`P``G0(``!X```">`@``U@0`````````````:0(``.@$``!+!```(`(```0!
M````````_0(``"4$``"@`@```````"H`````````:@(``%@%``#J`0``````
M``````!'````@04``"4!``"I`@```````!0#```(!````````'H!``"Q`0``
M$@0``-X!```*````-@(``%(!`````````````$`"``"!````*`0``!T!``!#
M`P``J@0``%8"``"S`@````4```````!*`P``/`,``(`#``#S````C@```$L!
M````````,@`````````X`@``(P`````````N````+`$``'T$``!H`0``=0(`
M`+H$```L````(P$```````"O`@``>````%4#````````6`(`````````````
M4P(``&$%````````MP$``)<"``#^`P``?`(``-P#```,`0``XP,``)\`````
M````;0(``(<!``"V`0``&@0```````!M`0``4@(``.0$`````````````*@`
M``#%`@``B0```/D#```*`0```@```)<````Z!```Z@0``/P```"(!```````
M`#8$``!?`0``:0$``.<````'!```"0```/(!``#Z!```U00``#0"``#%!```
M*0(``.T#``!$`@``9P4``,P$``"T`@```````%@$``"S````30,``-X```!-
M`0``7P(```````!_`0``S`````````"*`0``$`4```````!X!```<P$``.4`
M``"5`P``6`,``)$````W`P``"0(``"T$``"I`0``_0```+$#````````100`
M``0%``!3````*@0``'\%````````Y00``-("```=`@```````'(#````````
MU@,``'(!``#9`@```````$P"``""`@``(`,``,4```#G`@```````(T```!@
M!0``!@```'0"`````````P$``)T!``"C`@``*P4``&0````R!```^P```)X`
M`````````````-`"``!G!````````)D!``!S!0``8@```%T!``"]`P``````
M`%($``!_`@``M````-P"``#L`P``/@(``(4````M````P0$`````````````
M`````,L```"M````EP,````````````````````````7`P``:P(``(8"````
M````%0,``$(```#4`@```````#H"````````6P```-0#``#V`0``!````!$`
M``"0`P``G````"P#`````````````#@$````````.00``%\````Y!0``````
M`.D#```H`P``^P0```````!4`````````)@!``"V````KP$``'L$``!P!```
M50(``$D```"I`P``&0```#L"``!0`P``*`(``%P#``!H`P``-`0``(@"``#*
M!```T0$``"T!``"``0````,`````````````?P0``*4$````````0@,`````
M``#G`P``,`````````#]`P```````#D```#4!````````+8#````````\`$`
M`$0%``"9!```$`,``%H#``!G`P``]`(``)D```!F````>`,``!\#``"[`@``
M_P$```4%````````Y`,``*4"``"F`@``"P$```````#V````/`4``.@"````
M````&`0``-<$````````2@```),$```*!0``!@0```````"O`P``?0```,T`
M````````[0```&$!```$`@```````+T$`````````````)@$```Y`0``;0,`
M`)<!``!-!````@(``&X```"6`P```````#$#``!N`@```````*<$```>`P``
M)@(``-`!```M!0```````%8!``"@`0```````%4```#U`@``BP0``#P```!E
M`P``2`0``%4%``"Y`@``U@$``#@````\!```>0(``%4$``!9`@``/`(`````
M``"G`@``_P(```````"4````900``#8!``##`P````````````!'`P``T@,`
M`.\"``!@`````````,<!````````>0$```````")!```K@$`````````````
M`````%\$``!8````,P(``$\#````````'P$```````!W!0``N`(``,,```"R
M!```7@$```````"#!````````*$$``#B!`````````4$``!I!````````#T`
M```<`@``L```````````````,P$``"D!``#+`P``R@$``+@$``!C`P``@P4`
M```````>!```VP(``(H````E````YP0``/L!````````#P(``(4%```R!0``
M6P(``$8"```M`@``Z0(``!P$````````@0,``!0$``!O````V00```````!"
M!0``0`0``&P%``"B`P``F@(``!8$````````\@(``!,%```,`@``"````*0"
M```U!```1P0``%H````_!0``O0`````````"`0``700``-H$``!1````!P(`
M`,4#`````````````%\#``!Y!```2`(``"L````I````)@4````````P!0``
M@`0``(H#``"Y`0``5P0``"\!``"K````.P0``(<"``#,`@``P00``&D````6
M!0``0````/`"``"2!```BP,``)`$````````RP$``.0"``"U`P``<@0```4"
M``#\!````@0``,@$```!!```LP$``,<```"(`````````%0%``!&!0``K@``
M`&T$``#.`0```````.,"``"^`0``10,````````V````LP0```````!1`P``
M#0,````````O!```*``````````=`P```````&@%``#!`P````````H$```-
M!0`````````````2!0``P`0```(%```<`0``E`$``",$``##`0```````#@!
M````````10$``#,#````````N`$``,L$``"U````I@0``.D$``!C`0``D0,`
M`%H%``"#````>P,````````0````P`(````````J`P``1@```-,!``!G````
M<@(``````````````````'T#``"Z`P```````.("````````A````,D"``"5
M`0```````+\!````````B@(``$8!``!@!```L@,```````"!`@``A`$`````
M``"K!```R0,``!X%````````3P$``%`%```#`P```````!$#``!Z`@``````
M`#X$```U`@``%````!H"``!T`````````&@$``#@`P```````(\$```G!```
MSP````````!!````AP0```````"^`@``3@$``(H$``#K`P``Y0,````````(
M`@```````*$#``"=````.0,``!`"````````&````.X$``!)!```8P(``-\#
M``!L`0``50$``#$%``"]`@``C`````````!Z`P```````%0$```7`0``M0(`
M``L%`````````````$X%``!7``````````4`````````&04``-L!````````
MJP(``)P!``#@`0``<`$`````````````2@$``!(!```[`P``=`$```````"L
M`````````%0"```2`````````'X#``!B`0``.0(``+<"``!>`P```````-X$
M````````Z@(``-4!``"_`@``Q`$``"4#``#4`0```````+D#```#````_00`
M`*L#``#V`P````````````#M`0``)`$```````!"`0``UP$```````#N`0``
M6@(``)X!````````N@````````#^!```6@0``-L#```3````J`,``!H````,
M`P``[P$``````````````````-`$``#?`````````)\"```+`P``0`$`````
M``"^`P``HP``````````````(@```%8%```D!0``?0(```````!!`P``````
M`#<"```'`P```````*,$``#&`P```````*X"``!L!```)04```````"L`P``
M4P$``%(%``!\!````````.8``````````````'X$``#.!```2P```%$"``"'
M!0``A@$```T```!4`0``D@,``'8$````````I`0``((!```'`0``````````
M```A`@``4@,```H"``!*!````````'L"`````````````#T"``#<!```U```
M`&@"``!F`0```````````````````````$@````Q!````````*$```#7`@``
M`````%D```"/`@``B0$``'P!``"[````4`0``+P!````````%0```'(`````
M````^P,``#T%``!O`0```````#4%``#7````H@```$,!``#O!```7`4``,T!
M``#'!`````````8%``#W`0``W@,``"\%```(`P``%`$```````""!```V@,`
M`,\#``!*!0``N````$4"``#.`````````$<!````````"00``$D!``#F`0``
M70(`````````````>@4``$X$```?!```&P$``!T$``!$`P```````-,$```&
M`P``WP0`````````````Q````)````"'````30```/P!``#V!```0@0`````
M``""`P``N@$``,L"``#``0``:P4```````#S`@``<04``(@!``!^`@``````
M`.4!````````;P(``-H!``!E!0```````.$#````````M00``,8"``!L````
M%P0``%X"````````)@$```0$````````,P4``%D%``!X`@``:P0``"4"``#K
M`````````,$```#J````8@,``!4!````````00(```````#L````C`0``,@"
M```F`````````/X!``"B!```E`0``-,````O`P``80(``!<%```<````$@(`
M`'D#``!M!0``9@0``&\%````````,0$```````!A``````````````!^`0``
M;@$````````3!```DP```$0`````````,`,``.\```#Y`````````/H"``"[
M!```)P(``"$```"Q!```\@````````"4`@```````/H!``#P````;0```$P$
M``#K!```#@,``'D%``#.`P``I0```+0!``"5!```,@$````````O````I`$`
M``````!Q`P``(`0``(L````@`````````$@!``"6!````````-(`````````
MUP,``+D$``"9`P```````)H````B!```KP```$\$``#Y`@``E0`````````$
M`P```````!L`````````M0$``,`#```Z`0``X@$`````````````X```````
M``!J`0```````-D!``#2`0``8P```/<```!S`@```````#0%````````J@$`
M``````#F`@``=@,```````````````````T$``!=`````````!`!``!Q`@``
M`````*T"```````````````````X`P``S`$``$L#``!%!0``5P(```````"P
M!```H@$``+L#``":`0``ZP(``.$!``````````````````#Y`0``X0(`````
M`````````````%`"````````OP,``/X```#.`@``````````````````+0,`
M`',$````````*P(```````"?!```````````````````-````%D#````````
M)````'<!```9`0``"`4``(T!```X!0``!P````````"^!```*@$``/,$``"I
M!```!P4``*@$`````````````$\%``#R`P``^P(````````L!```"P(``&D#
M``````````````````!W````<00``&4!``#=`P``%04```````#<````A0,`
M`'T!````````O`,````````5!```&`,``/0```#1`@``I@$``&4"``!^````
MU@(``$0!``#%`0``X`0``$,"``"Y````@@4```\%````````H0(``%<%``";
M`@```````&0"``!B`@``5@````````#V`@``V0```-H"``"$`@``)`(``),!
M````````]0$````````@`0``)`,```````"G`0```````%0#``#B`P``GP,`
M``\!``##!```DP,```````"`!0``T````%8#``#L!````````'P````S````
MU0(``((````#`@``H`,``&L!````````K00``,$"``!$!```S0(``*,#````
M!```C@,``,8!``!``P``O````#<```#?`0``P@(``#H%``!Q`0``+`4``)L#
M``!Q````*@4``"8#`````````````"L!`````````````.<!``#(`0``C`(`
M``````#$!````````"$$``"#`0``P@,```@!``#I`0``7@```.0`````````
M>@0```````"<!````````.$```#X!`````````````"!`0```````',```!C
M!```@P,```X%`````````````!L#``"^`````````+P$````````*0,``%P"
M````````-0````````#S`P``-P$``$`%````````7`$`````````````W00`
M``````!3!```/@$``&P"```R`@``W0(`````````````U@```-$$``!D!```
M[@,``#,$``!N!0``*P0``'T%````````A`,``&4```!W`P``7`0``!X!``"W
M`P``R00```````!_`P``A@,```X"````````7P4``"X!``"F````L@```#P!
M``#5````8@0``)X$```T`P``WP(``$P!``"P`P``/P(``#L`````````$0$`
M````````````"P0``)$$``"T!```>`$``*<#```?!0``$P$```````")`P``
M`````!`$``!J!0``R@```%X$```+````A0$``'8"```@!0``R@(``*T!``"F
M`P``=`4``````````````````*<`````````E@$``!$$``"4`P``C0(``($$
M``!F!0``=`,````````_````ZP$```````"@!```````````````````N`,`
M````````````%@,``,\$```A`P```````!H%``#>`@``*00``.@#``";!```
M400``+<````I!0``#P``````````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E
M<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.
M;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S
M(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@
M)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`
M)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A
M<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@
M;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N
M($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO
M=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!2
M86EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`
M05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.
M97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P
M('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A
M(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E
M<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D
M(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI
M<W1R871I;VX`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T
M960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@
M<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E
M9"X`06YS=V5R`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E
M`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)C:&EV92!&:6QE(%-I>F4`07)C
M:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`
M075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R
M=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0FER
M=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N
M9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;VMM87)K<P!"
M;W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE
M<GIE9V]V:6YA`$)O=&@`0F]T=&]M`$)R87II;`!"=6QL971E9"!,:7-T`$--
M4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE
M<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#
M86QM`$-A;6)O9&EA`$-A;B!N;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N
M9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N`$-A;B!N;W0@;6]V92!F:6QE
M*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92X`0V%N(&YO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@
M861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S
M(BX`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E
M(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`
M0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L
M;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL
M<&AO;F4`0V5N=&5R`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E
M<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAO;W-E($%P<&QI
M8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@475E<GD`0VQE87(@;W5T('5S
M97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA
M=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U
M9',@16%R;'D`0VQO=61Y`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L
M<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL
M`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET
M:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O
M;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;FYE8W1I;VX@9F%I;&5D
M+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B
M)7,B`$-O;G1I;G5E`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T
M:6]N`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E
M9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O
M<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@
M)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E
M<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I
M=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T
M:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@
M;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R
M:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O
M=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N
M97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS
M`$-R961I="!C87)D(&YU;6)E<@!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@
M4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@
M57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R
M<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!$86EL>0!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F
M875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F
M:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U<`!$96QE
M=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S
M<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM
M90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE
M;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O
M:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO
M;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<FUA=`!$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&\@;F]T(&1E;&5T90!$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')U9W,`161I=`!%9&ET($)L;V-K`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9WEP=`!%;&5M96YT+BXN`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M<'1Y(&UE
M<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y
M96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@
M=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE
M='1E<G,@8F5L;W<Z`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y
M(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E
M8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P
M;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C
M;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S
M(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&
M86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%T86P@17)R;W(Z`$9E8G)U
M87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9I;&4@0V]U;G0Z("5S(&9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M
M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@
M475A<G1E<@!&:7@@<F%T:6\`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R9V]T('EO=7(@<&%S<W=O
M<F0_`$9O<G=A<F1S`$9R`$9R86YC90!&<F]M`$9R;VT@=&AE(`!&=6QL($1E
M<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VT`1V%L;&5R>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;@!'96YE<F%T960@0V]D90!'97)M86YY`$=I8G)A;'1A<@!':79E;B!.86UE
M`$=L;V)A;"!/<'1I;VYS`$=O`$=O;V=L92!-87!S`$=R87ES8V%L90!'<F5E
M8V4`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N
M;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N
M86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$AE861E<@!(96%D97)S`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@
M961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#
M:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(
M;VUE(%!H;VYE`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`
M2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P
M;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU
M;6ED:71Y.B``2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA
M;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED
M96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N
M)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U
M(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I
M;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D
M:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G
M92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O
M;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E
M9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T
M(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R
M<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF;W)M871I
M;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?
M;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@
M5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU
M;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E
M9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E
M`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R
M="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O
M=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-
M;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E
M9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D
M97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN
M=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L
M:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!)
M;G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D
M+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED
M+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R
M;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE
M;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@
M861D<F5S<RX`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27-S=65R`$ET
M86QY`$IA;G5A<GD`2F%P86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#
M96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$ME97`@;W)I9VEN86P_`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@
M3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`3&%?>6]U=`!,86YG=6%G
M90!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R
M`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87<`3&%Y;W5T`$QE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE
M9G0@=F%L=65S`$QE=F5L`$QI9VAT(%)A:6X`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T
M(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G
M(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`
M3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R
M(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-4RU43D5&($%T=&%C:&UE;G0@
M8V]N=&%I;F5D(&YO(&1A=&$N`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME
M(&QI;E]K+BXN`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<F-H`$UA<F=I;@!-87)K('=I
M=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%T8VAI;F<@9FEE;&1S`$UA>"!A
M;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N
M9W1H`$UA>0!-961I8VEN90!-96UB97)S`$UE<F=E(&-E;&QS`$UE<W-A9V4`
M365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G
M<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@
M97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N
M;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S`$UE=')I8P!-97AI8V\`36ED9&QE`$UI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D
M(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S
M`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S
M<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V1E<F%T90!-;V1I9FEE9"!$871E
M`$UO9&EF>2!54DP`36]D=6QU<P!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO
M;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UU;'1I<&QE('-E;&5C=&EO
M;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L
M`$UY(%!O<G1A;"!,87EO=70`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F5T
M=V]R:P!.979E<@!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE
M("AO<'1I;VYA;"D`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X
M<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I
M;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA
M<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6=H=`!.;R!A=F%I;&%B;&4@8V]N
M9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A
M=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE
M;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.
M;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D
M:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L
M;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA
M;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE
M($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O
M<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)T
M:&5R;B!(96UI<W!H97)E`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.
M;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S
M=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3V)J96-T`$]B
M:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F:6-E`$]L9"!A;F0@;F5W
M('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VYL>2!)34%0('-E<G9E<G,@
M<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N
M<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R
M<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-
M12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A
M=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI
M<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN
M9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E
M<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$]325@@97AT
M96YS:6]N(&ES(&UI<W-I;F<`4&%D9&EN9P!087)T;'D@0VQO=61Y`%!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5O<&QE`%!E
M<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!0
M97)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D
M`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!H;W1O<P!0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@
M=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`
M4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R
M:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@
M26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+@!0=7)G92!M97-S86=E<P!1=65R>0!2861I;R!S96QE8W1I
M;VX`4F%I;@!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E
M9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@
M4&]R=&%L(%9I97<Z`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@
M4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E
M<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W
M;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY`%)U;@!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S`%-A;64@9G)A;64@*%]S96QF*0!3871E;&QI=&4@
M4')O=FED97(`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`
M4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@
M=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@(B5S(BX`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T
M($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E
M;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E
M<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM
M92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YS;W(Z(`!3
M97!T96UB97(`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E
M9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B``4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C
M97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N
M=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=7!L
M;V%D`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEZ
M90!3:VEP($UA:6YT96YA;F-E`%-N;W<`4V]R="!O<F1E<B!S96QE8W1I;VX`
M4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H97)N($AE;6ES<&AE
M<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N
M(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P
M86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-T87)T('EE
M87(`4W1A=&4@;W(@4')O=FEN8V4`4W1O<F%G92!F;W)M870`4W1R965T($%D
M9')E<W,`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-3
M4UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U
M8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S
M(&)E96X@87!P<F]V960N`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E
M<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M
M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D
M('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O
M;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S
M(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5M;6%R>0!3=7!P;W)T`%-U<FYA
M;64`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R
M=&EE<P!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@
M;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T
M92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X
M=`!497AT($]N;'D`5&5X="!A;&EG;@!4:`!4:&4@1E10(&5X=&5N<VEO;B!I
M<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L
M960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI
M=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W
M86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T
M(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES
M="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X
M="!O;B!T:&4@<V-R965N+@!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S
M:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T
M;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@
M=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E
M<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`
M5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!2
M1T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C
M=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H
M=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N
M`%1I=&QE`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O9&%Y`%1O;6]R<F]W`%1O;R!M86YY(&EN=F%L:60@;&]G
M:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5')A;G-L871I;VYS
M`%1R=64@;W(@9F%L<V4`5'4`5'5R:V5Y`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E
M<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N
M`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E
M=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P9&%T92!F;W(@
M)7,`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`
M56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@`%5N:VYO=VX`56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE
M9`!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A
M=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA
M;B!N=6UB97)S`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE
M+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@
M4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N
M`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S
M(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@
M:6X@=&AE('-Y<W1E;3H`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S
M96QE8W0@9G)O;0!687)I86)L90!697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO
M;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I97<@)7,`5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<VEB:6QI='D`5FES:6)I;&ET
M>3H@`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A
M=&$@<')O=FED960@8GD`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I
M;F0`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O
M<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`665A<FQY
M`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@
M=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C
M:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R
M;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N
M`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT
M<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H
M870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H
M;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@
M861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E
M<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W
M:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L
M('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K
M96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A
M<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD
M("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D
M969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X
M<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@
M=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M(:61E(%%U;W1E9"!497AT70!;
M4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES
M=')A=&EO;@!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P
M97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/
M<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]4
M86)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S
M<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L
M:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`9&%T82!F;W)M
M870@97)R;W(`9&ES<&QA>2!F;W)E8V%S="`H=&%F*0!E9&ET`&5N=')Y(&YO
M="!F;W5N9`!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&AO<W0@;F%M92!U
M;FMN;W=N`&EM;65D:6%T90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@
M<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T
M(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE
M9`!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<V5R=FEC92!U;F%V86EL86)L
M90!S:&]W(&1I9F9E<F5N8V5S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L
M:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'<Z`'=E
M871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@:&]R9&4@,RXQ+C$*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#0M,3,@,30Z,38K,#(P,`I03RU2979I<VEO
M;BU$871E.B`R,#`V+3`T+3$S(#$T.C$V*S`R,#`*3&%S="U4<F%N<VQA=&]R
M.B!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A;F]`=6YI8F]C8V]N:2YI
M=#X*3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U6
M97)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0
M;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`H
M)7,@9VEO<FYI('-C;W)S:2D`("A#:&EA=F4@9&D@86-C97-S;R`E<RD`("AI
M;B`E<R!G:6]R;FDI`"`H;V=G:2D`("AD;VUA;FDI`"`H:65R:2D`(&$@80`B
M)7,B(&YO;B#H('5N82!D:7)E8W1O<GDN`"(E<R(@;F]N(.@@=6YA('-C96QT
M82!V86QI9&$N`"(E<R(@;F]N(.@@8V]N9FEG=7)A=&\@;F5I(%)E9VES=')I
M(&1I($AO<F1E+@`B)7,B(&%L8F5R;R!R96YD97)E<B!N;VX@=')O=F%T;RX`
M(B5S(B#H('-T871O(&%G9VEU;G1O(&%I(&=R=7!P:2!D:2!S:7-T96UA+@`B
M)7,B(.@@<W1A=&\@86=G:75N=&\@86D@<&5R;65S<VD@9&D@<VES=&5M82X`
M(B5S(B!N;VX@Z"!S=&%T;R!C<F5A=&\Z("5S+@`E+C)F34(@=7-A=&D@9&D@
M)2XR9DU"(&1I<W!O;FEB:6QI("@E+C)F)24I`"5D("5S(&4@)7,`)60@9VEO
M<FYI(&%L;&\@<V-A9&5R92!D96QL82!T=6$@<&%S<W=O<F0N`"5D+6=I;VYO
M('!R979I<VEO;F4`)7,@+2!.;W1I>FEA`"5S($9I<FUA($1I9VET86QE`"5S
M($M"`"5S($]P97)A>FEO;FD@9&D@36%N=71E;GII;VYE("T@0V]N9F5R;6$`
M)7,@26UP;W-T87II;VYE`"5S($9I<FUA`"5S(%1E<FUI;FD@9&D@06-C;W)D
M;P`E<R!G:>`@97-I<W1E;G1E+@`E<R!A("5S("5S`"5S(.@@<')O;G1O('!E
M<B!E<V5G=6ER92!L92!O<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N92!S;W1T
M;R!S96QE>FEO;F%T92X@4V5L97II;VYA(&QA(&-A<V5L;&$@<&5R(&]G;FD@
M;W!E<F%Z:6]N92AI*2!C:&4@=G5O:2!E<V5G=6ER92!O<F$N`"5S(.@@<FEC
M:&EE<W1O`"5S(&UI;G5T:0`E<R!N;VX@=')O=F%T;RX`)7,@82`E<R!D:2`E
M<P!2=6)R:6-A(&1I("5S`$-A;&5N9&%R:6\@9&D@)7,`3F]T92!D:2`E<P!,
M:7-T82!!='1I=FETX"!D:2`E<P`E<SH@)7,`)7,Z(%%U97-T;R!M97-S86=G
M:6\@<&]T<F5B8F4@;F]N(&%R<FEV92!D82!C:&D@9&EC:&EA<F$@9&D@97-S
M97)E+B!!='1E;GII;VYE(&%I(&QI;FL@<')E<V5N=&D@:6X@97-S;R!O(&9O
M<FYI<V-I(&]G;FD@:6YF;W)M87II;VYE(&%L(&UI='1E;G1E+@`L('-O9F9I
M86YD;R``+"!S;V9F:6%N9&\@)7,@)7,`+"!V87)I86)I;&4@9&$@)7,@82`E
M<P`M+2!S96QE>FEO;F$@+2T`1F]R;6%T;R`Q,B!O<F4`1F]R;6%T;R`R-"!O
M<F4`,C0@;W)E`#Q0<F5C961E;G1E`%5N(&1A=&%B87-E(&1I(&)A8VME;F0@
MZ"!R:6-H:65S=&\@<&5R('%U97-T;R!B;&]C8V\N`$4G(&%C8V%D=71O('5N
M(&5R<F]R92!F871A;&4`56YA(&-H:6%V92!P=6)B;&EC82!01U`@Z"!R:6-H
M:65S=&$@<&5R(&-I9G)A<F4@:6P@;65S<V%G9VEO+@!5;F$@8VAI879A('!U
M8F)L:6-A(%!'4"#H(')I8VAI97-T82!P97(@=F5R:69I8V%R92!I;"!M97-S
M86=G:6\@9FER;6%T;RX`56YA(&-H:6%V92!P=6)B;&EC82!01U`L('5N82!C
M:&EA=F4@<')I=F%T82!01U`L(&4@=6YA('!A<W-W;W)D('-O;F\@<FEC:&EE
M<W1E('!E<B!D96-I9G)A<F4@=6X@;65S<V%G9VEO`%5N82!C:&EA=F4@<'5B
M8FQI8V$@4$=0+"!U;F$@8VAI879E('!R:79A=&$@4$=0+"!E('5N82!P87-S
M=V]R9"!S;VYO(')I8VAI97-T92!P97(@9FER;6%R92!U;B!M97-S86=G:6\`
M56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344L('5N82!C:&EA=F4@<')I=F%T
M82!3+TU)344@92!U;F$@<&%S<W=O<F0@<V]N;R!R:6-H:65S=&4@<&5R(&1E
M8VEF<F%R92!U;F$@;65S<V%G9VEO+@!5;F$@8VAI879E('!U8F)L:6-A(%,O
M34E-12P@=6YA(&-H:6%V92!P<FEV871A(%,O34E-12!E('5N82!P87-S=V]R
M9"!S;VYO(')I8VAI97-T92!P97(@9FER;6%R92!U;B!M97-S86=G:6\N`%5N
M82!C:&EA=F4@<'5B8FQI8V$@4R]-24U%(.@@<FEC:&EE<W1A('!E<B!C:69R
M87)E('5N(&UE<W-A9V=I;RX`04T@3G5B:0!!32!0:6]G9VEA($QE9V=E<F$`
M04T@4&EO9V=I80!!32!!8W%U87IZ;VYI`$%-($YE=FEC871E`$%-+U!-`$%0
M22!)1`!2:6=U87)D;R!Q=65S=&\@961I=&]R`%)I9W5A<F1O+BXN`$%C8V5S
M<V\@;F5G871O(&-R96%N9&\@;&$@9&ER96-T;W)Y(%9&4RX`06-C97-S;R!N
M96=A=&\@8W)E86YD;R!61E,@9FEL92X`26YF;W)M87II;VYI($%C8V]U;G0`
M4&%S<V]W<F0@06-C;W5N=`!!8V-O=6YT(&-O;F=E;&%T;RX`06-C;W5N=&EN
M9P!!9V=I=6YG:0!!9V=I=6YG:2!'<G5P<&\@1FEG;&EO`$%G9VEU;F=I(%!E
M<FUE<W-I($9I9VQI;P!!9V=I=6YG:2!Q=6DZ`$%G9VEU;F=I($YU;W9O($=R
M=7!P;P!!9V=I=6YG:2!.=6]V;R!097)M97-S;P!!9V=I=6YG:2!U;B!G<G5P
M<&\@9FEG;&EO(&$@(B5S(@!!9V=I=6YG:2!U;B!P97)M97-S;R!F:6=L:6\@
M82`B)7,B`$%G9VEU;F=I('5N(&YU;W9O('5T96YT93H`06=G:75N9VD@8V]L
M;VYN80!!9V=I=6YG:2!N=6]V:2!M96UB<FD`06=G:75N9VD@;&$@8V]P<&EA
M`$%G9VEU;F=I(&EL("5S($UE;G4@8V]M92!U;F$@36]Z:6QL82!3:61E8F%R
M`$%G9VEU;F=I(&%L;&$@<G5B<FEC83H`06=I=6YG:2!A;&QA(')U8G)I8V$@
M<&5R<V]N86QE`$%G9VEU;F=I('5T96YT90!!9V=I=6YT:2`B)7,B(&%L('-I
M<W1E;6$L(&UA(&YO;B!S:2!P;W-S;VYO(&%G9VEU;F=E<F4@=6QT97)I;W)I
M(&EN9F]R;6%Z:6]N:3H@)7,N`$%G9VEU;G1O("(E<R(@86P@<VES=&5M82X@
M3W)A('!U;VD@86-C961E<F4N`$PG86=G:75N=&$@9&D@=71E;G1I(.@@9&ES
M86)I;&ET871A+@!);F1I<FEZ>F\`4G5B<FEC80!!;6UI;FES=')A=&]R92`M
M(&EM<&]S=&$@:2!P97)M97-S:2!P97(@86QT<FD@=71E;G1I`$%M;6EN:7-T
M<F%Z:6]N90!!;&QI;F5A`$%L;&EN96%M96YT;SH`5'5T=&D`5'5T=&D@9VQI
M('5T96YT:2!A=71E;G1I8V%T:0!4=71T:2!I(&=R=7!P:0!4=71T:2!I('!E
M<FUE<W-I`%1U='1I(&4@<75A='1R;R!I(&QA=&D`5'5T=&D@9VQI(&EN9&ER
M:7IZ:2!M=6QT:7!L:0!097)M971T97)E(&QE(&EM<&]S=&%Z:6]N:2!D:2!L
M:7-T92!O<F1I;F%T92!P97(@=&EP;S\`17-I<W1E(&=IX`!,;V=I;B!)35-0
M(&%L=&5R;F%T:79A`%!A<W-W;W)D($E-4U`@86QT97)N871I=F$`571E;G1E
M($E-4%,@86QT97)N871I=F\`26YD:7)I>GIO(&5M86EL(&%L=&5R;F%T:79O
M`$UA<V-H97)E(&%L=&5R;F%T:79E`%1E<W1O(&%L=&5R;F%T:79O.@!%)R!S
M=&%T;R!S<&5C:69I8V%T;R!U;B!V86QO<F4@;F]N('9A;&ED;RX`17)R;W)E
M('-C;VYO<V-I=71O+@!2:7-P;W-T80!!<'!L:6-A>FEO;F4`3&ES=&$@07!P
M;&EC87II;VYI`$PG87!P;&EC87II;VYE(.@@<')O;G1A+@!!<'!L:6-A(&%I
M(&9I9VQI(&-O;F1I=FES:0!!<'!R;W9A`$1I;65N<VEO;F4@07!P<F]S<VEM
M871I=F$`07!R:6QE`$1I;65N<VEO;F4@9FEL92!I;B!A<F-H:79I;P!.;VUE
M($%R8VAI=FEO`%-E:2!S:6-U<F\@9&D@=F]L97(@<FEM=6]V97)E(&QE(')I
M8VAI97-T92!F:7)M871E('!E<B`E<R`_`$%S96D@<VEC=7)O(&1I('9O;&5R
M(&5L:6UI;F%R92`B)7,B(&4@;V=N:2!S;W1T;RUG<G5P<&\_`%)I8VAI961E
M<F4@;&$@8V]N9F5R;6$@<')I;6$@9&D@97-E9W5I<F4@;&4@;W!E<F%Z:6]N
M:2!D:2!M86YU=&5N>FEO;F4_`$%S<V5G;F%M96YT;R!C;VQO;FYE`%-I(.@@
M8V5R8V%T;R!D:2!E;&EM:6YA<F4@=6X@9W)U<'!O(&YO;B!E<VES=&5N=&4N
M`%-I(.@@8V5R8V%T;R!D:2!E;&EM:6YA<F4@=6X@<&5R;65S<V\@;F]N(&5S
M:7-T96YT92X`4VD@Z"!C97)C871O(&1I('!U8F)L:6-A<F4@=6X@<&5R;65S
M<V\@;F]N(&5S:7-T96YT92X`4VD@Z"!C97)C871O(&1I('!U8F)L:6-A<F4@
M=6YA(&-O;F1I=FES:6]N92!N;VX@97-I<W1E;G1E+@!!='1R:6)U=&D`06=O
M<W1O`$%U=&A?8WER<W%L.B!E<W1E;G-I;VYE(&EM87`@<FEC:&EE<W1A(&YO
M;B!T<F]V871A+@!!=71H7V-Y<G5S.B!I;"!B86-K96YD(&YO;B!H82!L92!C
M87!A8VETX"!R:6-H:65S=&4N`$%U=&A?8WER=7,Z(&5S=&5N<VEO;F4@:6UA
M<"!R:6-H:65S=&$@;F]N('1R;W9A=&$N`$%U=&A?9G1P.B!%<W1E;G-I;VYE
M($944"!R:6-H:65S=&$@;F]N('1R;W9A=&$N($-O;7!I;&$@4$A0(&-O;B!L
M)V]P>FEO;F4@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z("!%<W1E;G-I;VYE
M($E-05`@<FEC:&EE<W1A(&YO;B!T<F]V871A+@!!=71H7VMR8C4Z($5S=&5N
M<VEO;F4@:W)B-2!R:6-H:65S=&$@;F]N('1R;W9A=&$N`$%U=&A?;&1A<#H@
M;"=A9V=I=6YT82!D:2!U=&5N=&D@;F]N(.@@<W5P<&]R=&%T82!P97(@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(&QA(&-A;F-E;&QA>FEO;F4@9&D@
M=71E;G1I(&YO;B#H('-U<'!O<G1A=&$@<&5R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!%<W1E;G-I;VYE($Q$05`@<FEC:&EE<W1A(&YO;B!T<F]V
M871A+@!!=71H7VQD87`Z($EM<&]S<VEB:6QE(&%G9VEU;F=E<F4@;"=U=&5N
M=&4@)7,N(%%U97-T82#H(&QA(')I<W!O<W1A(&1E;"!S97)V97(Z`$%U=&A?
M;&1A<#H@26UP;W-S:6)I;&4@8V%N8V5L;&%R92!L)W5T96YT92`E<P!!=71H
M7VQD87`Z($EM<&]S<VEB:6QE(&%G9VEO<FYA<F4@;"=U=&5N=&4@)7,`075T
M:%]L9&%P.B!L)V%G9VEO<FYA;65N=&\@9&5G;&D@=71E;G1I(&YO;B#H('-U
M<'!O<G1A=&\@<&5R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@97-T
M96YS:6]N92!-0T%,(')I8VAI97-T82!N;VX@=')O=F%T82X`075T:%]S;6)A
M=71H.B!E<W1E;G-I;VYE('-M8F%U=&@@<FEC:&EE<W1A(&YO;B!T<F]V871A
M+@!,)V%U=&5N=&EC87II;VYE(&%L('-E<G9E<B!)34%0(.@@9F%L;&ET82X`
M075T96YT:6-A>FEO;F4@9F%L;&ET80!!=71E;G1I8V%Z:6]N92!F86QL:71A
M+B`E<P!!=71E;G1I8V%Z:6]N92!R:69I=71A=&$@9&%L('-E<G9E<B!2041)
M55,N`$%U=&5N=&EC87II;VYE(&%L('-E<G9E<B!&5%`@9F%L;&ET82X`075T
M96YT:6-A>FEO;F4@86P@<V5R=F5R(%--0B!F86QL:71A+@!#86UP:2!D:7-P
M;VYI8FEL:3H`4V9O;F1O`$-O;&]R92!S9F]N9&\`4&%S<W=O<F0@:V5R8F5R
M;W,@;F]N('9A;&ED82X`571E;G1E(&ME<F)E<F]S(&YO;B!V86QI9&\N`$1I
M<F5C=&]R>2!G<F%F:6-A(&1I(&)A<V4@(B5S(B!N;VX@=')O=F%T82X`0V]M
M<&QE86YN;P!";&]C8V\@(B5S(B!D96QL)V%P<&QI8V%Z:6]N92`B)7,B(&YO
M;B!T<F]V871O+@!);7!O<W1A>FEO;FD@0FQO8V-O`%1I<&\@0FQO8V-O`$=R
M87-S971T;P!396=N86QI8G)I`$)O<F1O`%-P97-S;W)E(&1E;"!B;W)D;SH`
M0F]R9&D`0F]S;FEA(&4@2&5R>F5G;W9I;F$`16YT<F%M8F4`0F%S<V\`0G)A
M<VEL90!%;&5N8V\@<'5N=&%T;P!#35,`0U)#`%!U;G1I($1I<W1R:6)U>FEO
M;F4@0U),`%!R;W!R:65TX"!#7V5L;&4N+BX`3&$@8V%C:&4@:6YI>FEA;&4@
M;F]N(.@@<W1A=&$@8V]M<&QE=&%T82X`0V%L96YD87)I;P!#86QM;P!#86UB
M;V=I80!);7!O<W-I8FEL92!C;W!I87)E(&9I;&4H<RD@+2!L82!S;W)G96YT
M92!E(&QA(&1E<W1I;F%Z:6]N92!S;VYO('5G=6%L:2X`26UP;W-S:6)I;&4@
M<W!O<W1A<F4@:6P@9FEL92AS*2`M(&QA(&1E<W1I;F%Z:6]N92#H(&%L;"=I
M;G1E<FYO(&1E;&QA('-O<F=E;G1E+@!);7!O<W-I8FEL92!R96EM<&]S=&%R
M92!L82!P87-S=V]R9"!A=71O;6%T:6-A;65N=&4L(&-O;G1A='1A(&PG86UM
M:6YI<W1R871O<F4N`$EM<&]S<VEB:6QE('-C:79E<F4@;F5L(&9I;&4@(B5S
M(@!);7!O<W-I8FEL92!G97-T:7)E('-E<W-I;VYI(&5S=&5R;F4N`$EM<&]S
M<VEB:6QE(&-O;&QE9V%R<VD@86P@<V5R=F5R($E-05`Z("5S`$EM<&]S<VEB
M:6QE(&%P<FER92!I;"!F:6QE("(E<R(N`$-A;F-E;&QA`$-A;F-E;&QA(&EL
M(%)E<&]R="!P<F]B;&5M80!);7!O<W-I8FEL92!E;&EM:6YA<F4@:6P@9FEL
M92`B)7,B+@!);7!O<W-I8FEL92!T<F]V87)E('5N82!D:7)E8W1O<GD@=&5M
M<&]R86YE82X`26UP;W-S:6)I;&4@<')O8V5D97)E('-E;GIA(&EL('!A<F%M
M971R;R`G=&%R9V5T1FEL92<N`$EM<&]S<VEB:6QE(')I;75O=F5R92!L82!D
M:7)E8W1O<GD@("(E<R(N`$EM<&]S<VEB:6QE(')I;75O=F5R92P@97-I<W1O
M;F\@)60@9FEG;&DN`$EM<&]S<VEB:6QE(')I;W)D:6YA<F4L(&PG96QE;F-O
M(&9O<FYI=&\@;F]N(&-O<G)I<W!O;F1E(&-O;B!L)V5L96YC;R!M96UO<FEZ
M>F%T;RX`26UP;W-S:6)I;&4@:6YS=')A9&%R92!I;"!M97-S86=G:6\@86P@
M;G5M97)O('-P96-I9FEC871O+@!#87)R:65R80!#871E9V]R:64@92!%=&EC
M:&5T=&4`27-O;&4@0V%Y;6%N`$-E;&QU;&%R90!0<F]P<FEE=.`@0V5L;&4`
M4FEE;7!I;65N=&\@8V5L;&4Z`%!R;W!R:65TX"!C96QL90!3<&%Z:6\@8V5L
M;&4Z`$-E;&QU;&%R90!#96YT<F\`175R;W!A($-E=')A;&4@*$E33RTX.#4Y
M+3(I`$1E='1A9VQI(&1E;"!#97)T:69I8V%T;P!0<F]P<FEE=&%R:6\@9&5L
M($-E<G1I9FEC871O`%!O;&ET:6-H92!D96P@0V5R=&EF:6-A=&\`0V%M8FEA
M`$-A;6)I82!L82!T=6$@4&%S<W=O<F0`0V%M8FEA(&EL(&YO;64@92!L)VEN
M9&ER:7IZ;R!C:&4@;&4@<&5R<V]N92!V961O;F\@<75A;F1O(&QE9V=O;F\@
M92!R:7-P;VYD;VYO(&%L;&4@='5E(&5M86EL+@!);"!C86UB:6\@9&5L;&$@
M='5A('!A<W-W;W)D(&YO;B#H('-U<'!O<G1A=&\@8V]N(&QA(&-O;F9I9W5R
M87II;VYE(&-O<G)E;G1E+B`@0V]N=&%T=&$@;"=A;6UI;FES=')A=&]R92X`
M0V%R8F]N90!#:&5C7VL@3&EN:RXN+@!#:6QE`$-I;F$`4V-E9VQI(&PG87!P
M;&EC87II;VYE.@!38V5G;&D@=6YA('!A<W-W;W)D`%-C96=L:2!U;B!N;VUE
M('5T96YT90!38V5G;&D@8V]M92!V:7-U86QI>GIA<F4@;&$@9&%T83H`4V-E
M9VQI(&EL('1I<&\@9&D@<W1I;&4@9&5L;&$@;&ES=&$@*'!E<B!L:7-T92!O
M<F1I;F%T92D`3&$@9&5F:6YI>FEO;F4@9&D@8VQA<W-E(&1I("5S(&YO;B#H
M('-T871A('1R;W9A=&$N`$-H:6%R;P!!;FYU;&QA($1O;6%N9&$`16QI;6EN
M82!L)W5T96YT93H@)7,`16QI;6EN82!U=&5N=&4`16QI;6EN82!I;F9O<FUA
M>FEO;FD@=71E;G1E`$5L:6UI;F%R92!$;W!O(`!#;&EC:R!P97(@0V]N=&EN
M=6%R90!#:&EU9&D@1FEN97-T<F$`3G5B:0!.=6)I('!R97-T;P!.=79O;&]S
M;P!#:&EU9&D@4VED96)A<@!#:&EU9&D@:2!B;W)D:0!#;VQO<F4`36%P<&$@
M0V]L;W)I`%-E;&5Z:6]N92!C;VQO<FD`0V]L;VYN93H`5&ET;VQO(&-O;&]N
M;F4`0V]M:6-H90!#;VUA;F1O`$QI;F5A(&1I(&-O;6%N9&\`0V]M;65N=&\`
M3F]M92!#;VUU;F4`07II96YD80!#;VUP=71E<G,`0V]N9&EZ:6]N90!#;VYD
M:7II;VYI`$1I9F9E<F5N>F4@;F5L;&$@8V]N9FEG=7)A>FEO;F4`0V]N9FEG
M=7)A>FEO;F4@<&5R(&QA('-I;F-R;VYI>GIA>FEO;F4@8V]N(%!$07,L(%-M
M87)T<&AO;F5S(&4@3W5T;&]O:RX`3&$@8V]N9FEG=7)A>FEO;F4@Z"!V96-C
M:&EA+@!#;VYF:6=U<F$@)7,`0V]N9F5R;6$@;&$@4&%S<W=O<F0`0V]L;&5G
M86UE;G1O(&9A;&QI=&\N`$-O;&QE9V%M96YT;R!F86QL:71O.B``0V]N;F5S
M<VEO;F4@86P@:V5Y<V5R=F5R(&]U8F)L:6-O(')I9FEU=&%T82X`0V]N;F5S
M<VEO;F4@86P@:V5Y<V5R=F5R('!U8F)L:6-O(')I9FEU=&%T82X@36]T:79O
M.B`E<R`H)7,I`$-O;FYE<W-I;VYE(&%L('-E<G9E<B!&5%`@9F%L;&ET82X`
M0V]N=&%T=&D`22!C;VYT871T:2!S;VYO('-T871I(&%G9VEU;G1I(&-O;B!S
M=6-C97-S;R!A;&QA('1U82!R=6)R:6-A+@!4:7!O(&1I(&-O;G1E;G5T;R!D
M96P@9FEL92!C;VUP<F5S<V\Z(`!#;VYT96YU=&D@9&D@(B5S(@!#;VYT:6YU
M80!#;W!I80!#;W!I82!F86QL:71A.B`E<P!#;W!I82!S96QE>FEO;F4`3F]N
M('-I('!U\B!C:69R87)E(&EN(%!'4"!I;"!M97-S86=G:6\`3F]N('-I('!U
M\B!F:7)M87)E(&EN(%!'4"!I;"!M97-S86=G:6\`3F]N('-I('!U\B!C<FEF
M<F%R92!I;B!3+TU)344@:6P@;65S<V%G9VEO`$YO;B!S:2!P=?(@9FER;6%R
M92!I;B!3+TU)344@:6P@;65S<V%G9VEO`$YO;B!S:2!P=?(@86=G:75N9V5R
M92!I;"!C;VYT871T;RX@)7,`3F]N('-I('!U\B!I;G1E<G)O9V%R92!I;"!S
M97)V97(@3$1!4"X`3F]N('-I('!U\B!V97)I9FEC87)E(&PG97%U:6QI8G)I
M;RX@)7,`26UP;W-S:6)I;&4@8V]L;&5G87)S:2!A;"!S97)V97(@3$1!4"X`
M26UP;W-S:6)I;&4@8V]L;&5G87)S:2!A;"!S97)V97(@(B5S(B!U<V%N9&\@
M1E10.B`E<P!);7!O<W-I8FEL92!C<F5A<F4@=6YA(&QI<W1A(&1I(&1I<W1R
M:6)U>FEO;F4N("5S`$EM<&]S<VEB:6QE(&1E8VEF<F%R92!I;"!D871O(&EN
M(&9O<FUA=&\@4$=0.B``26UP;W-S:6)I;&4@9&5C:69R87)E(&EL(&1A=&\@
M:6X@9F]R;6%T;R!3+TU)344N`$EM<&]S<VEB:6QE(&5L:6UI;F%R92!I;"!C
M;VYT871T;RX@)7,`26UP;W-S:6)I;&4@96QI;6EN87)E(&QE(&QI<W1A(&1I
M(&1I<W1R:6)U>FEO;F4N("5S`$EM<&]S:6)I;&4@96QI;6EN87)E(&QO('-C
M<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E;&PG:6UP;W-T87II;VYE("(E<R(N
M`$EM<&]S<VEB:6QE(&1E=&5R;6EN87)E(&=L:2!I;F1I<FEZ>FD@96UA:6P@
M9&5I(&1E<W1I;F%T87)I+@!I26UP;W-S:6)I;&4@<V-A<FEC87)E(&EN(&UO
M9&\@8V]M<&QE=&\@;&$@<G5B<FEC82X`26UP;W-S:6)I;&4@<V-A<FEC87)E
M(&EN(&UO9&\@8V]M<&QE=&\@;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X`
M26UP;W-S:6)I;&4@<V-A<FEC87)E(&EN(&UO9&\@8V]M<&QE=&\@;&$@;&ES
M=&$@9&5L;&4@;&ES=&4@9&D@9&ES=')I8G5Z:6]N92X`26UP;W-S:6)I;&4@
M8V%R:6-A<F4@;&$@<W1R871E9VEA("(E<R(N`$EM<&]S<VEB:6QE(&-R96%R
M92!L82!D:7)E8W1O<GD@(B5S(BX`26UP;W-S:6)I;&4@;W1T96YE<F4@;&$@
M8VAI879E('!U8F)L:6-A(&1A;"!S97)V97(N`$EM<&]S<VEB:6QE(&%P<FER
M92`B)7,B('!E<B!L82!R:7-C<FET='5R82X`26UP;W-S:6)I;&4@87!R:7)E
M("5S+@!);7!O<W-I8FEL92!A<')I<F4@:6P@;6]D=6QO($UA:6YT96YA;F-E
M7U1A<VL@)7,`26UP;W-S:6)I;&4@87!R:7)E(&QA(&1I<F5C=&]R>2`B)7,B
M+@!);7!O<W-I8FEL92!C;VYT871T87)E(&EL('-E<G9E<B!,1$%0+@!);7!O
M<W-I8FEL92!L96=G97)E("5S+@!);7!O<W-I8FEL92!A>GIE<F%R92!L82!P
M87-S=V]R9"!P97(@;"=U=&5N=&4@<FEC:&EE<W1O+B!!;&-U;FD@;R!T=71T
M:2!I(&1E='1A9VQI(&YO;B!S;VYO(&-O<G)E='1I+B!2:7!R;W9A(&%N8V]R
M82!O(&-O;G1A='1A(&PG86UM:6YI<W1R871O<F4@<V4@;F5C97-S:71I(&1I
M('5L=&5R:6]R92!A:75T;RX`26UP;W-S:6)I;&4@<F5C=7!E<F%R92!!0TP`
M26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L82!R=6)R:6-A+B`E<P!);7!O<W-I
M8FEL92!R96-U<&5R87)E(&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N("5S
M`$EM<&]S<VEB:6QE(')E8W5P97)A<F4@;&4@;&ES=&4@9&D@9&ES=')I8G5Z
M:6]N92X@)7,`26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L92!P;W-S:6)I;&ET
MX"!D96P@<V5R=F5R`$EM<&]S<VEB:6QE(&EN=F5R=&ER92!L82!C;VYF:6=U
M<F%Z:6]N92X`26UP;W-S:6)I;&4@8V%N8V5L;&%R92!L82!D:7)E8W1O<GD@
M(B5S(BX`26UP;W-S:6)I;&4@<V%L=F%R92!L82!C;VYF:6=U<F%Z:6]N92!D
M:2`E<RX`26UP;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P:6$@9&5L;&$@8V]N
M9FEG=7)A>FEO;F4N`$EM<&]S<VEB:6QE('-A;'9A<F4@=6YA(&-O<&EA(&1E
M;&QA(&-O;F9I9W5R87II;VYE.B`E<P!);7!O<W-I8FEL92!S86QV87)E(&QO
M('-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM<&]S=&%Z:6]N:2!S
M=3H@(B5S(BX`26UP;W-S:6)I;&4@<V%L=F%R92!I;"!F:6QE(&1I('-A;'9A
M=&%G9VEO(&1E;&QA(&-O;F9I9W5R87II;VYE(&1I("5S+@!);7!O<W-I8FEL
M92!S86QV87)E(&EL(&9I;&4@9&D@8V]N9FEG=7)A>FEO;F4@9&D@)7,N(%!U
M;VD@=7-A<F4@;F$@9&5L;&4@;W!Z:6]N:2!P97(@<V%L=F%R92!I;"!C;V1I
M8V4@<W4@)7,@;R!C;W!I87)E(&UA;G5A;&UE;G1E(&EL(&-O9&EC92!S;W1T
M;R!S=2`E<RX`26UP;W-S:6)I;&4@9F%R92!U;F$@<G5C97)C82!N96P@<V5R
M=F5R($Q$05`N`$EM<&]S<VEB:6QE(&%G9VEO<FYA<F4@:6P@8V]N=&%T=&\N
M("5S`$EM<&]S<VEB:6QE(&%G9VEO<FYA<F4@;&$@;&ES=&$@9&D@9&ES=')I
M8G5Z:6]N92X@)7,`26UP;W-S:6)I;&4@<V-R:79E<F4@;&$@8V]N9FEG=7)A
M>FEO;F4@<&5R("(E<R(Z("5S`$EM<&]S<VEB:6QE('1R;W9A<F4@;&$@4VED
M96)A<B!D:2!-;WII;&QA+B!!<W-I8W5R871I(&-H92!S:6$@87!E<G1A+@!)
M;7!O<W-I8FEL92!D87)E(&%L;"=U=&5N=&4@(B5S(B!I('-E9W5E;G1I(&1I
M<FET=&D@<&5R(&QA(&-A<G1E;&QA("(E<R(Z("5S`%1E<W1O(&-O;G1A=&\`
M3F%Z:6]N90!#;W)S:0!#<F5A`$-R96$@=6X@;&EN:P!#<F5A('5N;R!N=6]V
M;P!#<F5A<F4@<V]T=&\@8V%R=&5L;&4`0W)E871O<F4@9&D@<&5R;65S<VD`
M3G5M97)O(&-A<G1A(&1I(&-R961I=&\`0V]R<F5N=&4@-"!&87-I`%-E<W-I
M;VYI(&-O<G)E;G1I`%1E;7!O($%T='5A;&4`3&$@55),(&%T='5A;&4@Z`!5
M=&5N=&D@071T=6%L:0!496UP;R!!='1U86QE`$-O;F1I>FEO;F4@8V]R<F5N
M=&4Z(`!3=&EL92!C;W)R96YT90!097)S;VYA;&EZ>F$@;&4@;W!E<F%Z:6]N
M:2!D82!E<V5G=6ER92!A;&PG879V:6\@9&D@)7,`5&%G;&EA`%1A9VQI82!L
M82!S96QE>FEO;F4`0VEP<F\`1VEO<FYA;&UE;G1E`$1A=&$`1&%T82!2:6-E
M=G5T80!396QE>FEO;F$@;&$@9&%T80!':6]R;F\`15]L:6UI;F$@0V]L;VYN
M80!$:6-E;6)R90!.=6UE<FD@9&5C:6UA;&D`1&EM:6YU:7-C:2!L82!R:65N
M=')A;GIA`$-O;&]R92!S=&%N9&%R9`!)9&5N=&ETX"!D:2!D969A=6QT`%-H
M96QL(&1I(&1E9F%U;'0`1&5F:6YI>FEO;FD`16QI;6EN80!%;&EM:6YA($-E
M;&QA`$5L:6UI;F$@1W)U<'!O`$5L:6UI;F$@3&]G`$5L:6UI;F$@4&5R;65S
M<V\`16QI;6EN87)E(&4@<W9U;W1A<F4@:2!M97-A9V=I`$5L:6UI;F$@8V5L
M;&$`16QI;6EN82!C;VQO;FYA`$5L:6UI;F$@;&$@;6%S8VAE<F$@86QT97)N
M871I=F$@97-I<W1E;G1E`$5L:6UI;F$@:2!M97-S86=G:0!%;&EM:6YA(&D@
M<&5R;65S<VD@<&5R("(E<R(`16QI;6EN82!I('!E<FUE<W-I('!E<B`B)7,B
M(&4@;V=N:2!S;W1T;RUP97)M97-S;S\`16QI;6EN82!R:6=A`$5L:6UI;F$@
M;"=I9&5N=&ETX"!S96QE>FEO;F%T80!%;&EM:6YA(&QE('-O='1O(&-A<G1E
M;&QE`$5L:6UI;F$@;&$@8V]L;VYN82!C;W)R96YT90!%;&EM:6YA(&QA(')I
M9V$@8V]R<F5N=&4`16QI;6EN82!L;R!S8W)I<'0@9&D@86=G:6]R;F%M96YT
M;R!D96QL92!I;7!O<W1A>FEO;FD@9&D@(B5S(BX`5&5M<&\@9"=I;G9I;P!$
M86YI;6%R8V$`1&5S8W)I=FD@:6P@<')O8FQE;6$`1&5S8W)I>FEO;F4`1&5T
M=&%G;&D@*&%N8VAE(&YE;"!F:6QE(&1I(&QO9R!D:2!(;W)D92DZ`$D@9&5T
M=&%G;&D@<V]N;R!S=&%T:2!S8W)I='1I(&YE;"!F:6QE(&1I(&QO9R!P97(@
M;"=A;6UI;FES=')A=&]R92X`4W9I;'5P<&\`4'5N=&\@9&D@<G5G:6%D80!0
M=6YT;R!D:2!R=6=I861A('!E<B!L)W5L=&EM82!O<F$Z(`!0=6YT;R!D:2!R
M=6=I861A.B``1&ER97II;VYE(&1A('-I;FES=')A(&$@9&5S=')A`$1I<F5Z
M:6]N92!D82!D97-T<F$@82!S:6YI<W1R80!6:7-U86QI>GIA(&EL('1E;7!O
M(&YE;"!F;W)M871O(#(T(&]R93\`3W!Z:6]N:2!D:2!V:7-U86QI>GIA>FEO
M;F4`5FES=6%L:7IZ82!P<F5V:7-I;VYE(&1E='1A9VQI871A`$9O<FUA=&\@
M9&D@=FES=6%L:7IZ87II;VYE`$YO=&EF:6-A(&1I(&1I<W!O<VEZ:6]N90!.
M;VX@96QI;6EN87)E`$YO;B!A8V-E9&5R92!D:7)E='1A;65N=&4@;6%I;G1E
M;F%N8V4N<&AP`$QA<')I;6$@<FEG82!C;VYT:65N92!I;"!C86UP;R!D96D@
M;F]M:3\@4V4@<VDL('-E;&5Z:6]N82!Q=65S=&$@8V%S96QL83H`3F]N(&AA
M:2!U;B=U=&5N>F$_(&ES8W)I=FET:2X`4V-A<FEC80!38V%R:6-A("5S`$QA
M(&-O;F9I9W5R87II;VYE(&=E;F5R871A(.@@<W1A=&$@<V-A<FEC871A(&-O
M;64@<V-R:7!T(%!(4"X`1')O9VAE`%!U8F)L:6-A`%9I<W5A;&EZ>F$@8FQO
M8V-O`%9I<W5A;&EZ>F$@1W)U<'!O`%9I<W5A;&EZ>F$@4&5R;65S<V\`5FES
M=6%L:7IZ82!097)M97-S:0!6:7-U86QI>GIA(%!E<FUE<W-I('!E<B`E<P!6
M:7-U86QI>GIA(&QE(&]P>FEO;FD@<&5R.@!6:7-U86QI>GIA(&D@<&5R;65S
M:2!P97(@(B5S(@!6:7-U86QI>GIA(&D@<&5R;65S<VD@<&5R("5S`$5G:71T
M;P!%;&5M96YT;RXN+@!);F1I<FEZ>F\@16UA:6P`3"=I;F1I<FEZ>F\@16UA
M:6P@9&5V92!C;W)R:7-P;VYD97)E+@!%;6%I;"!C;VX@8V]N9F5R;6$`365S
M<V%G9VEO('9U;W1O+@!2:7-U;'1A=&\@=G5O=&\N`%)I8V5R8V$@9&5I('1E
M<FUI;FD@=G5O=&$`06)I;&ET82!L)VEN<V5R:6UE;G1O(&1I(&EM;6%G:6YI
M(&YE;"!T97-T;R!D86QL82!'86QL97)I82!D96QL92!&;W1O9W)A9FEE/P!!
M8FEL:71A<F4@:6P@;65N=2!D:2!C;VYT97-T;R!C;&EC8V%N9&\@:6P@=&%S
M=&\@9&5S=')O(&1E;"!M;W5S93\`1FEN92!A;FYO`$EN9W)A9&ES8VD@;"=E
M9&ET;W(`26YS97)I<V-I('5N82!D;VUA;F1A('-I8W5R82!C:&4@=&D@=F5R
M<N`@8VAI97-T82!S92!A=G)A:2!N96-E<W-I=.`@9&D@87IZ97)A<F4@;&$@
M='5A('!A<W-W;W)D+"!E<R`G<75A;"?H(&EL(&YO;64@9&5L('1U;R!C=6-C
M:6]L;S\G.@!);G-E<FES8VD@;"=54DP@9&5L;"=I;6UA9VEN92!Q=6D`26YS
M97)I<V-I(&QE(&QE='1E<F4@<V]T=&\@<FEP;W)T871E.@!%<G)O<F4`17)R
M;W)E(&-R96%N9&\@:6P@8FQO8V-O.B`E<P!%<G)O<F4@96QI;6EN86YD;R!L
M)V%N8V]R82!D:2!S:6YC<F]N:6$Z("5S`$5R<F]R92!E;&EM:6YA;F1O(&EL
M(&QO9R!D:2!S:6YC<F]N:6$Z("5S`$5R<F]R92!O='1E;F5N9&\@:6P@8V]N
M=&5N=71O.B`E<P!%<G)O<F4@86=G:6]R;F%N9&\@;&$@<&%S<W=O<F0Z("5S
M`$5R<F]R92!C;VX@:6P@;65S<V%G9VEO(&5M86EL+@!%<G)O<F4@<V-R:79E
M;F1O("(E<R(N`$]G;FD@,34@;6EN=71I`$]G;FD@,B!M:6YU=&D`3V=N:2`S
M,"!S96-O;F1I`$]G;FD@-2!M:6YU=&D`060@;V=N:2!A8V-E<W-O`$]G;FD@
M;65Z>B=O<F$`3V=N:2!M:6YU=&\`5F%L;W)I(&0G97-E;7!I;SH`17-E9W5I
M`$5S<&%N9&D`17-P86YD:2!3:61E8F%R`%!R979I<W1O("<I)P!I4&%R;VQA
M('!R979I<W1A(&\@=&5R;6EN92!C:71A=&\@9&D@<FEC97)C80!$871A(&1I
M('-C861E;GIA`$5S<&]N96YT90!#;VQO<F4@1D<`06=G:6]R;F%M96YT;R!&
M5%`@9&5L;&4@:6UP;W-T87II;VYI`%1E;G1A=&EV;R!F86QL:71O(&YE;"!R
M96-U<&5R;R!D96QL92!P<F5F97)E;GIE+@!#;VQL96=A;65N=&\@86P@<V5R
M=F5R($Q$05`@9F%L;&ET;RX`0V]L;&5G86UE;G1O(&%L('-E<G9E<B!334(@
M9F%L;&ET;RX`3F]N(.@@<FEU<V-I=&\@82!C;W!I87)E(&1A("(E<R(N`$YO
M;B#H(')I=7-C:71O(&$@8V]P:6%R92!A("(E<R(N`$YO;B#H(')I=7-C:71O
M(&$@8W)E87)E('5N82!N=6]V82!C;VYN97-S:6]N92!305-,+@!.;VX@Z"!R
M:75S8VET;R!A('-P;W-T87)E(&$@(B5S(BX`3F]N(.@@<FEU<V-I=&\@82!R
M96-U<&5R87)E.B`E<P!':75S=&\`17)R;W)E($9A=&%L93H`1F5B8G)A:6\`
M4VEM:6QE(&$`4VEM:6QE(&$Z`$-O;G1E9V=I;R!F:6QE.B`E<R!F:6QE`$-O
M;G1E9V=I;R!F:6QE.B`E<R!F:6QE<P!'97-T:6]N92!&:6QE`$YO;64@1FEL
M90!396QE>FEO;F4@9FEL90!#87)I8V$@1FEL90!#87)I8V%M96YT;R!F:6QE
M(&YO;B!S=7!P;W)T871O`$9I;'1R:0!&:6YL86YD:6$`4')I;6\@365Z>F\`
M4')I;6\@475A<G1O`%)A<'!O<G1O(&9I<W-O`$YE8F)I80!,82!#87)T96QL
M82`E<R!N;VX@97-I<W1E`$-O;&]R92!D96QL82!F;VYT90!#:6)O`%!E<B!B
M<F]W<V5R(&-H92!N;VX@<W5P<&]R=&%N;R!L92!I;6UA9VEN:0!0<F5V:7-I
M;VYE("A4048I`$AA:2!D:6UE;G1I8V%T;R!L82!P87-S=V]R9#\`26YO;'1R
M:0!690!&<F%N8VEA`$1A`$1A(&EL(`!$97-C<FEZ:6]N92!#;VUP;&5T80!,
M;F$@4&EE;F$`3F]M92!#;VUP;&5T;P!'86QL97)I82!D86QL82!Q=6%L92!P
M<F5N9&5R92!L92!I;6UA9VEN:0!'86QL97)I83H`1V5N97)A("5S($-O;F9I
M9W5R87II;VYE`$-O9&EC92!'96YE<F%T;P!'97)M86YI80!':6)I;'1E<G)A
M`$YO;64@1&%T;P!/<'II;VYI($=L;V)A;&D`5F%I`$UA<'!E($=O;V=L90!3
M8V%L92!D:2!G<FEG:0!'<F5C:6$`06UM:6YI<W1R87II;VYE($=R=7!P:0!)
M(&YO;6D@9&5L(&=R=7!P;R!N;VX@9&5V;VYO(&5S<V5R<F4@=G5O=&D`1W)O
M=7!?;&1A<#H@26UP;W-S:6)I;&4@86=G:75N9V5R92!I;"!G<G5P<&\@)7,N
M(%%U97-T82#H(&QA(')I<W!O<W1A(&1E;"!S97)V97(Z(`!'<F]U<%]L9&%P
M.B!);7!O<W-I9&EL92!E;&EM:6YA<F4@:6P@9W)U<'!O("5S`$=R;W5P7VQD
M87`Z($EM<&]S<VEB:6QE(&%G9VEO<FYA<F4@:6P@9W)U<'!O("5S`$=R=7!P
M:0!097)M97-S:2!D96=L:2!O<W!I=&D`3&EB<F\@9&5G;&D@;W-P:71I`$EN
M=&5S=&%Z:6]N90!);G1E<W1A>FEO;FD`06QT97IZ80!!:75T;P!!:75T;R!U
M<V%N9&\@;"=E9&ET;W(`06EU=&%N=&4`16UI<V9E<F\`475E<W1O(.@@;"=I
M;FEZ:6\@9&5L(&9I;&4Z`$%L=&\`2&]?<F1E`%-A;G1A(%-E9&4@*$-I='1A
M)R!D96P@5F%T:6-A;F\I`$AO<F1E`$EN9&ER:7IZ;R!D:2!C87-A`$1I<F5C
M=&]R>2!D:2!C87-A`%1E;&5F;VYO(&1I(&-A<V$`4F5G;VQA(&]R:7IZ;VYT
M86QE`%)I96UP:6UE;G1O(&]R:7IZ;VYT86QE`$]R:7IZ;VYT86QE.@!#;VUE
M('-E:2!A<G)I=F%T;R!Q=6D_("A396D@<')E9V%T;R!D:2!F87)E('5N(')A
M<'!O<G1O(2D`475A;G1E(&-O;&]N;F4@=G5O:2!U;FER93\`475A;G1I(&-A
M;7!I("AC;VQO;FYE*2!C:2!S;VYO(#\`475A;G1E(')I9VAE('9U;VD@=6YI
M<F4_`%5M:61I=.``56UI9&ETX#H@`%5N9VAE<FEA`$-R96%Z:6]N92!D96QL
M82!C87-E;&QA($E-05`@9F%L;&ET83H@)7,`0V%N8V5L;&%Z:6]N92!D96QL
M82!C87-E;&QA($E-05`@9F%L;&ET83H@)7,`0W)E87II;VYE(&1E;&QA('%U
M;W1A(&1E;&QA(&-A<V5L;&$@24U!4"!F86QL:71A.B`E<P!);F1I<FEZ>F\@
M25``26YD:7)I>GIO($E0(&YO;B!D:7-P;VYI8FEL92X`3"=I;F1I<FEZ>F\@
M25`@;F]N(.@@86QL)VEN=&5R;F\@9&5L(&)L;V-C;R!#2412(&-O;G-E;G1I
M=&\N`$E?;G-E<FES8VD@;&$@4DEG82!P<FEM80!)<VQA;F1A`%-O;&\@26-O
M;F4`26-O;F4@<&5R("5S`$EC;VYE(&-O;B!T97-T;P!.;VUE(&1E;&PG261E
M;G1I=.``4V4@;F]N(.@@<W1A=&\@=FES=6%L:7IZ871O(&-O<G)E='1A;65N
M=&4L("5S(&%P<FER92!I;B!U;F$@;G5O=F$@9FEN97-T<F$N`%-E(&YO;B!V
M961I(&YE<W-U;F$@:6-O;F$@=7-A;F1O($EN=&5R;F5T($5X<&QO<F5R+"!P
M;W1R97-T:2!D;W9E<B!S96QE>FEO;F%R92!Q=65S=&$@8V%S96QL82!P97(@
M86YN=6QL87)E(&QA('1R87-P87)E;GIA(&1E;&QE(&EM;6%G:6YI(%!.1RX`
M4V4@=F5D:2!Q=65S=&\@;65S<V%G9VEO(&UA(&YO;B!L)VEM;6%G:6YE+"!L
M)VEM86=I;F4@8VAE('9U;VD@8V%R:6-A<F4@;F]N('!U\B!E<W-E<F4@=FES
M=6%L:7IZ871A(&1A;"!T=6\@8G)O=W-E<BX`4')E+59I<W5A;&EZ>F%Z:6]N
M92!D96QL)TEM;6%G:6YE.@!54DP@26UM86=I;F4`55),($EM;6%G:6YE.@!)
M;6UA9VEN92!D86QL82!G86QL97)I80!);6UA9VEN92!D86QL82!G86QL97)I
M83H`0V%R:6-A;65N=&\@26UM86=I;F4`26UM86=I;FD`26UP;W)T82P@4&%S
M<V\@)60`0V%M<&D@:6UP;W)T871I.B`E<P!#86UP:2!I;7!O<G1A=&DZ`$EN
M7W-E<FES8VD@<FEG82!D;W!O`$-O9&EC92!D:2!A>FEO;F4@97)R871O(&1A
M=&\N`$YO;64@=71E;G1E(&4O;R!P87-S=V]R9"!N;VX@8V]R<F5T=&\N`$YO
M;64@=71E;G1E(&\@:6YD:7)I>GIO(&%L=&5R;F%T:79O(&YO;B!V86QI9&\N
M(%)I<')O=F$@86YC;W)A(&\@8V]N=&%T=&$@;"=A;6UI;FES=')A=&]R92!S
M92!N96-E<W-I=&D@9&D@=6QT97)I;W)E(&%I=71O+@!!=6UE;G1A(&QA(')I
M96YT<F%N>F$`571E;G1I($EN9&EV:61U86QI`$EN9F]R;6%Z:6]N90!);F9O
M<FUA>FEO;F4@;F]N('!I^2!D:7-P;VYI8FEL92X`26YS97)I<V-I($-?;VQO
M;FYA($1O<&\`26YS97)I<V-I($EM;6%G:6YE`$EN<V5R:7-C:2!486)E;&QA
M`$EN<V5R:7-C:2!L:6YK('=E8@!);G-E<FES8VD@7T-O;&]N;F$@4')I;6$`
M26YS97)I<V-I('5N82!N=6]V82!C;VQO;FYA(&1O<&\@<75E;&QA(&-O<G)E
M;G1E`$EN<V5R:7-C:2!U;F$@;G5O=F$@8V]L;VYN82!P<FEM82!D:2!Q=65L
M;&$@8V]R<F5N=&4`26YS97)I<V-I('5N82!N=6]V82!R:6=A(&1O<&\@<75E
M;&QA(&-O<G)E;G1E`$EN<V5R:7-C:2!U;F$@;G5O=F$@<FEG82!P<FEM82!D
M:2!Q=65L;&$@8V]R<F5N=&4`26YS97)I<V-I('5N('!A<F%G<F%F;R!D;W!O
M(&EL(&YO9&\@8V]R<F5N=&4`26YS97)I<V-I('5N('!A<F%G<F%F;R!P<FEM
M82!D96P@;F]D;R!C;W)R96YT90!);G-E<FES8VD@=6YA(&UA<V-H97)A(&%L
M=&5R;F%T:79A`$EN<V5R:7-C:2!U;B!I;F1I<FEZ>F\@96UA:6P@86P@<75A
M;&4@<&]T<F%I(')I8V5V97)E(&QA(&YU;W9A('!A<W-W;W)D.@!);G-E<FES
M8VD@=6YA(&-E;&QA(&1O<&\`26YS97)I<V-I('5N82!C96QL82!P<FEM80!)
M;G-E<FES8VD@=6YA(&-O;&]N;F$@9&]P;P!);G-E<FES8VD@=6YA(&-O;&]N
M;F$@<')I;6$`26YS97)I<F4@;65S<V%G9VD`26YS97)I<V-I('5N('!A<F%G
M<F%F;R!D;W!O`$EN<V5R:7-C:2!U;B!P87)A9W)A9F\@<')I;6$`26YS97)I
M<V-I('5N82!R:6=A(&1O<&\`26YS97)I<V-I('5N82!R:6=A('!R:6UA`$EN
M<V5R:7-C:2!L82!R:7-P;W-T82!R:6-H:65S=&$@86QL82!D;VUA;F1A(&1I
M('-I8W5R97IZ83H`26YS97)I<V-I+TU/9&EF:6-A(&PG:6UM86=I;F4`26YS
M97)I<V-I+TU/9&EF:6-A(&EL(&QI;FL`0W)E9&ET:2!I;G-U9F9I8VEE;G1I
M('!E<B!S<&5D:7)E(&%L;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X`0W)E
M9&ET:2!I;G-U9F9I8VEE;G1I+@!);G1E<F\`3&ES=&$@:6YT97)A`%5$2"!N
M;VX@=F%L:61A("A5<V5R($1A=&$@2&5A9&5R*2X`1&%T82!:25`@;F]N('9A
M;&ED80!!<'!L:6-A>FEO;F4@;F]N('9A;&ED82X`0F%T8V@@240@;F]N('9A
M;&ED;P!I3"=I;F9O<FUA>FEO;F4@<V]T=&]M97-S82!N;VX@Z"!V86QI9&$N
M`$PG:6YD:7)I>GIO(&1I(&1D97-T:6YA>FEO;F4@;F]N(.@@=F%L:61O+@!)
M;"!F;W)M871O(&1E;"!F:6QE(&YO;B#H('9A;&ED;P!,82!C:&EA=F4@9&5L
M;&$@;&EC96YZ82!N;VX@Z"!V86QI9&$N`$EL(&QO9V\@9F]R;FET;R!N;VX@
MZ"!V86QI9&\N`&US9U]T>7!E(&YO;B!V86QI9&\N`&%P:5]I9"!N;VX@=F%L
M:61O(&\@;6%N8V%N=&4N`%!A<F%M971R;R!N;VX@=F%L:61O(&\@;6%N8V%N
M=&4N`%!E<FUE<W-O(&1E;"!G96YI=&]R92!N;VX@=F%L:61O+@!I9"!D96P@
M<&%R=&YE<B!N;VX@=F%L:61O+@!#;V1I8V4@<')O9&]T=&\@;F]N('9A;&ED
M;RX`4')O=&]C;VQL;R!N;VX@=F%L:61O+@!$97-T:6YA=&%R:6\@;F]N('9A
M;&ED;SH@(B5S(@!/9V=E='1O(&-O;F1I=FES;R!N;VX@=F%L:61O`$EN9&ER
M:7IZ;R!S;W)G96YT92!N;VX@=F%L:61O+@!);G9E;G1A<FEO`$EN=F5R=&D@
M;&$@<V5L97II;VYE`$5M:71T96YT90!)=&%L:6$`1V5N;F%I;P!':6%P<&]N
M90!,=6=L:6\`1VEU9VYO`$=I=7-T:69I8V$`1VEU<W1I9FEC82!A;"!C96YT
M<F\`1VEU<W1I9FEC82!T=71T;P!':75S=&EF:6-A(&$@<VEN:7-T<F$`1VEU
M<W1I9FEC82!A(&1E<W1R80!-86YT96YE<F4@;"=O<FEG:6YA;&4_`$EL('-E
M<G9E<B!+97)B97)O<R!H82!R:69I=71A=&\@;"=A=71E;G1I8V%Z:6]N92X`
M0W)E87II;VYE(&-H:6%V90!);7!R;VYT82!D:6=I=&%L92!D96QL82!C:&EA
M=F4`3'5N9VAE>GIA(&1E;&QA(&-H:6%V90!4:7!O(&1E;&QA(&-H:6%V90!5
M<V\@9&5L;&$@8VAI879E`$QA(&-H:6%V92#H(&=IX"!P<F5S96YT92!S=6P@
M:V5Y<V5R=F5R('!U8F)L:6-O+@!"86UI8FEN:0!$:5]S<&]S:7II;VYE`$QI
M;F=U86=G:6\`56QT:6UO(&UE>GIO`%5L=&EM82!P;W-S:6)I;&ETX"!P97(@
M:6P@8V%M8FEO(&1E;&QA('!A<W-W;W)D`%5L=&EM;R!Q=6%R=&\`56QT:6UO
M(&%G9VEO<FYA;65N=&\Z`%5L=&EM82!C;VYN97-S:6]N93H@)7,`56QT:6UA
M(&-O;FYN97-S:6]N93H@)7,@9&$@)7,`56QT:6UA(&-O;FYE<W-I;VYE.B!-
M86D`3&5G9V4`1&ES<&]S:7II;VYE`$QA<V-I86QO('9U;W1O('!E<B!A=F5R
M;&\@<V5N>F$@8F]R9&D`3&EB86YO`%-I;FES=')A`$EN=&5S=&%Z:6]N92!D
M:2!S:6YI<W1R80!686QO<FD@9&D@<VEN:7-T<F$`3&EV96QL;P!0:6]G9VEA
M(&QE9V=E<F$`0V]L;&5G86UE;G1O`$EL(&-O;&QE9V%M96YT;R!P=6YT82!A
M.@!#;VQL96=A(&PG:6YD:7)I>GIO(&5M86EL(&%L;&$@<&%G:6YA(&1I(&-O
M;7!O<VEZ:6]N92!Q=6%N9&\@=FEE;F4@=FES=6%L:7IZ871O`$-O;&QE9V%M
M96YT:0!%;&5N8V\@+2!L)W5T96YT92!P=?(@=F5D97)E(&QE(&-A<G1E;&QE
M`$5L96YC;R!D96D@9&%T86)A<V4`16QE;F-O(&1E:2!S;V=G971T:2!D96QL
M)V%I=71O`$5L96YC;R!486)E;&QE`$%R8VAI=FEO(&1E;&QA($QI<W1A`$%I
M=71O(&1E;&QA($QI<W1A`$ED96YT:69I8V%T:79O(&1E;&QA($QI<W1A`%!R
M;W!R:65T87)I;R!D96QL82!L:7-T80!)<V-R:7II;VYE(&%L;&$@3&ES=&$`
M06YN=6QL82!L)VES8W)I>FEO;F4@86QL82!,:7-T80!,)V5L96YC;R!D96QL
M92!S97-S:6]N92#H(&9A;&QI=&\Z("5S`$PG96QE;F-O(&1E9VQI('5T96YT
M:2#H(&9A;&QI=&\Z("5S`$PG96QE;F-O(&1E9VQI('5T96YT:2#H(&1I<V%B
M:6QI=&%T;RX`3&5T=&5R871U<F$`0V%R:6-A;65N=&\N+BX`3W)A(&QO8V%L
M93H@`$QI;F=U82!E($]R80!,=6]G;P!%;G1R80!%<V-I`$5N=')A`$]P97)A
M>FEO;FD@9&D@06-C97-S;P!,)V%C8V5S<V\@Z"!F86QL:71O('!E<F-HZ"!I
M;"!N;VUE('5T96YT92!O(&QA('!A<W-W;W)D(&EN<V5R:71I(&YO;B!S;VYO
M(&-O<G)E='1I+@!!8V-E<W-O(&9A;&QI=&\N`%1E<W1O(&QU;F=O`$%M;W)E
M`$)A<W-O`$QE='1E<F4@9W)E8VAE(&UI;G5S8V]L90!,971T97)E(&QA=&EN
M92!M:6YU<V-O;&4`3G5M97)I(')O;6%N:2!M:6YU<V-O;&D`3'5S<V5M8G5R
M9V\`35,M5$Y%1B!L)V%L;&5G871O(&YO;B!C;VYT:65N92!I;F9O<FUA>FEO
M;FDN`$UA9VEC;P!0;W-T80!);F1I<FEZ>F\@86UM:6YI<W1R871O<F4`0W)E
M82!C;VQL96=A;65N7W1O+BXN`$=E<W1I<V-I(&PG96QE;F-O(&1E;&QE(&-A
M=&5G;W)I92!E=&EC:&5T=&%N9&\@9VQI(&%R=&EC;VQI+"!E(&-O;B!I(&-O
M;&]R:2!A<W-O8VEA=&D@86QL92!C871E9V]R:64N`$UA<GIO`$UA<F=I;F4`
M0V]N=')A<W-E9VYA<F4@8V]N(&D@9FQA9W,@5FES=&\O3F]N5FES=&\`0V]N
M=')A<W-E9VYA<F4@8V]N(&%L=')I(&9L86=S("AE<SH@26UP;W)T86YT92]2
M:7-P;W-T;RD`0V%M<&D@8V]R<FES<&]N9&5N=&D`0W)E9&ET;R!M87-S:6UO
M('!E<FUE<W-O+@!%8V-E9'5T92!L82!P87)T:2!M87-S:6UE(&1E;"!M97-S
M86=G:6\N`%1E;7!O(&UA<W-I;6\@=6QT:6UE(#(T(&]R93H@`%1E;7!O(&UA
M<W-I;6\@=6QT:6UE(#8@;W)E.B``3G5M97)O(&UA<W-I;6\@9&5L(%!O<G1A
M($)L;V-K<P!,=6YG:&5Z>F$@;6%S<VEM80!-86=G:6\`365D:6-I;F$`365M
M8G)I`%5N:7-C:2!L92!C96QL90!-97-S86=G:6\`26P@;65S<V%G:6\@Z"!S
M=&%T;R!V97)I9FEC871O(&-O<G)E='1A;65N=&4L(&UA(&EL(&9I<FUA=&%R
M:6\@9&5L(&-E<G1I9FEC871O(&YO;B!P=?(@97-S97)E('9E<FEF:6-A=&\N
M`$UE<W-A9V=I;R!S8V%D=71O+@!4:7!O(&UE<W-A9V=I;P!-971O9&\`26P@
M;65T;V1O("`B)7,B(&YO;B#H(&1E9FEN:71O`$UE=&]D;R!N;VX@9&5F:6YI
M=&\N($UE=&]D;R!C:&EA;6%T83H@)7,`365T<FEC80!-97-S:6-O`$UE>GIO
M`%1E;7!O(&UI;FEM;R!U;'1I;64@,C0@;W)E.B``5&5M<&\@;6EN:6UO('5L
M=&EM92`V(&]R93H@`$EL('1E;7!O(&1I(&1U<F%T82!M:6YI;6\@9&5L;&$@
M<&%S=V]R9"!N;VX@Z"!S8V%D=71O`%-P96-C:&EO`%9A<FEO`$EL('!A8V-H
M971T;R!014%2($A45%!?4F5Q=65S="#H(&UA;F-A;G1E+@!#;VYF:6=U<F%Z
M:6]N92!M86YC86YT92X@1&5V:2!G96YE<F%R;F4@=6YA(&YU;W9A('-E('9U
M;VD@=7-A<F4@<75E<W1A(&%P<&QI8V%Z:6]N92X`240@9&5L(&UE<W-A9V=I
M;R!M86YC86YT92X`26P@<&%C8VAE='1O(%!%05(@36%I;"!R:6-H:65S=&\@
MZ"!M86YC86YT92X`240@9&5L;&$@<V5S<VEO;F4@;6%N8V%N=&4N`$QU`$UO
M9&5R871O`$1A=&$@9&5L;&$@;6]D:69I8V$`36]D:69I8V$@55),`$UO9'5L
M;P!-97-E(&4@86YN;P!-96YS:6QM96YT90!&87-I(&QU;F%R:0!3;VYO('-T
M871I('1R;W9A=&D@<&GY(&-A;7!I(&YE;&QA(&QI;F5A("5D(')I<W!E='1O
M(&$@<75E;&QI(&EP<F5V:7-T:2`E9"X`4W!O<W1A(%-O='1O`%-P;W-T82!A
M(%-I;FES=')A`%-P;W-T82!A($1E<W1R80!3<&]S=&$@4V]P<F$`4W!O<W1A
M('-O='1O`%-P;W-T82!S;W!R80!396QE>FEO;F4@;75L=&EP;&$`36EO($%C
M8V]U;G0`26YF;W)M87II;VYI(&1E;"!-:6\@06-C;W5N=`!-:6\@4&]R=&%L
M90!$:7-P;W-I>FEO;F4@9&5L($UI;R!0;W)T86QE`$Y/+"!N;VX@<V]N;R!D
M)V%C8V]R9&\`3F]M90!2971E`$UA:0!.=6]V82!#871E9V]R:6$`3'5N82!.
M=6]V80!.=6]V;R!.;VUE(%5T96YT92`H;W!Z:6]N86QE*0!.=6]V82!P87-S
M=V]R9`!,82!N=6]V82!P87-S=V]R9"!S8V%D<N`@:6X@)7@N`$QA(&YU;W9A
M('!A<W-W;W)D(&YO;B!C;W)R:7-P;VYD92X`3G5O=F$@9FEN:7-T<F$@*%]V
M=6]T82D`3F]T:7II90!'<G5P<&D@9&D@3F]T:7II90!0<F]S<VEM;P!0<F]S
M<VEM92`T($9A<VD`4')O<W-I;64@;W!Z:6]N:0!0<F]S<VEM;SX`3F]T=&4`
M3F]N('-O;F\@9&ES<&]N:6)I;&D@:6YF;W)M87II;VYI(')I9W5A<F1O(&QA
M(&-O;F9I9W5R87II;VYE('!E<B!M;W-T<F%R92!L92!D:69F97)E;GIE+@!.
M;VX@Z"!D:7-P;VYI8FEL92!U;F$@<W1R871E9VEA('!E<B!C<F5A<F4@:6UM
M86=I;FD@25-/+@!.;VX@97-I<W1E('5N(&)L;V-C;R!A;&QA('!O<VEZ:6]N
M92!R:6-H:65S=&$`3F]N(.@@<W1A=&\@9F]R;FET;R!I;"!N;VUE(&1E;"!C
M86QE;F1A<FEO('!E<B!L)V%U=&5N=&EC87II;VYE($U#04PN`$YE<W-U;F$@
M;6]D:69I8V$N`$YE<W-U;B!F:6=L:6\@<'7R(&5S<V5R92!A9V=I=6YT;R!A
M('%U97-T;R!P97)M97-S;RX`3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@86QC
M=6YA(&EN9F]R;6%Z:6]N92!S=6QL82!C;VYF:6=U<F%Z:6]N92!P97(@)7,N
M`$YO;B#H('-T871A('-P96-I9FEC871A(&%L8W5N82!I;F9O<FUA>FEO;F4@
M<W5L;&$@8V]N9FEG=7)A>FEO;F4@<&5R($944"!61E,N`$YO;B#H('-T871A
M('-P96-I9FEC871A(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG
M=7)A>FEO;F4@<&5R(%-13"!61E,N`$YO;B#H('-T871A('-P96-I9FEC871A
M(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG=7)A>FEO;F4@<&5R
M(%-13"U&:6QE(%9&4RX`3F]N(.@@<FEM87-T;R!N97-S=6X@8W)E9&ET;RX`
M3F]N(.@@<W1A=&$@9F]R;FET82!L82!D97-T:6YA>FEO;F4N`$EL(&9I;&4@
M;F]N(.@@<W1A=&\@8V%R:6-A=&\`3F]N('-O;F\@<W1A=&4@=')O=F%T92!L
M92!I8V]N92X`3F]N(.@@<W1A=&\@:6UP;W-T871O(&QA('!O<VEZ:6]N92X`
M3F]N(.@@<W1A=&\@:6YD:6-A=&\@;&$@<&]S:7II;VYE+@!.;VX@Z"!S=&%T
M;R!F;W)N:71O(&EL(&UE<W-A9V=I;RX`3F]N(.@@<W1A=&\@<W!E8VEF:6-A
M=&\@:6P@;F]M92X`3F]N(.@@<W1A=&\@<W!E8VEF:6-A=&\@:6P@;G5M97)O
M+@!.;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A<W-W;W)D('!E<B!L)V%U=&5N
M=&EC87II;VYE($A45%`N`$YO;B#H('-T871A(&9O<FYI=&$@;&$@<&%S<W=O
M<F0@<&5R(&PG875T96YT:6-A>FEO;F4@24U!4"X`3F]N(.@@<W1A=&$@9F]R
M;FET82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z:6]N92!+97)B97)O
M<RX`3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@;"=A=71E
M;G1I8V%Z:6]N92!,;V=I;BX`3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S
M=V]R9"!P97(@;"=A=71E;G1I8V%Z:6]N92!005-35T0N`$YO;B#H('-T871A
M(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@4TU"
M+@!.;VX@Z"!D:7-P;VYI8FEL92!A;&-U;F$@<&%T8V@@<&5R(&QA('9E<G-I
M;VYE(&)I;F%R:6$@9&D@3W!E;E-33"X@3&$@=F5R<VEO;F4@8FEN87)I82!D
M:2!/<&5N4U-,(.@@;F5C97-S87)I;R!C:&4@;W!E<FD@8V]N(&QE(&EN9F]R
M;6%Z:6]N:2!02T-3(#$R+@!.;VX@Z"!S=&%T82!I;7!O<W1A=&$@;&$@<75O
M=&$N`$YE<W-U;F$@<F5G;VQA`$YO;B#H('-T871O('-P96-I9FEC871O(&EL
M('-E<&%R871O<F4N`$YE<W-U;F$@;&%T;P!.97-S=6X@=&EP;R!D:2!F:6QE
M`$YO;B#H(&1I<W!O;FEB:6QE('5N82!D:7)E8W1O<GD@=&5M<&]R86YE82!P
M97(@;&$@8V%C:&4N`$YO;B#H('-T871A(&EN=FEA=&\@:6P@;F]M92!U=&5N
M=&4@92]O('!A<W-W;W)D+@!.;VX@<V]N;R!R:71O<FYA=&4@:6YF;W)M87II
M;VYI(%A-3"!V86QI9&4`3F5S<W5N('9A;&]R90!.;VX@Z"!S=&%T82!T<F]V
M871A(&QA('9E<G-I;VYE(&YE;&QA(&-O;F9I9W5R87II;VYE(&]R:6=I;F%L
M92X@4FEG96YE<F$@;&$@8V]N9FEG=7)A>FEO;F4N`$YO;B#H('-T871A('1R
M;W9A=&$@;&$@=F5R<VEO;F4@;F5L;&$@='5A(&-O;F9I9W5R87II;VYE+B!2
M:6=E;F5R82!L82!C;VYF:6=U<F%Z:6]N92X`3F5S<W5N;P!.97-S=6YO("]U
M<V\@:6UP;&EC:71O*0!%;6ES9F5R;R!3971T96YT<FEO;F%L90!.;W)V96=I
M80!.;VX@1&]P;P!.;VX@4')I;6$`3F]N('5N82!D:7)E8W1O<GD`3F]N(&EM
M<&QE;65N=&%T;P!.;VX@:6UP;W-T871O`$YO;B!S=7!P;W)T871O+@!!<'!U
M;G1I`$YU;&QA(&1A('9I<W5A;&EZ>F%R92P@=&]R;F$@:6YD:65T<F\N`$YO
M=F5M8G)E`$YU;65R;P!.=6UE<F\@9&D@8V%R871T97)I`$YU;65R;R!D:2!C
M;VQO;FYE`$YU;65R;R!D:2!R:6=H90!)(&YU;65R:2!N;VX@<V]N;R!S=&%T
M:2!S<&5C:69I8V%T:2!P97(@;"=A9V=I;W)N86UE;G1O(&YE;&QA(&QI<W1A
M(&1I(&1I<W1R:6)U>FEO;F4N`$]G9V5T=&\`0W)E871O<F4@9&5L;"=/9V=E
M='1O`$]T=&%L90!/='1O8G)E`%5F9FEC:6\`3&4@<&%S<W=O<F0@=F5C8VAI
M92!E(&YU;W9E(&1E=F]N;R!E<W-E<F4@9&EF9F5R96YT:0!696-C:&EA('!A
M<W-W;W)D`$QA('9E8V-H:6$@<&%S<W=O<F0@;F]N(.@@8V]R<F5T=&$N`%-O
M;&\@:2!S97)V97(@24U!4"!S=7!P;W)T86YO(&QE(&-A<G1E;&QE(&-O;F1I
M=FES92X`12<@<&5R;65S<V\@<V]L;R!U;B!I;F1I<FEZ>F\@96UA:6PN`%-O
M;&\@:6P@<')O<')I971A<FEO(&\@;"=A;6UI;FES=')A=&]R92!D:2!S:7-T
M96UA('!U\B!C86UB:6%R92!L82!P<F]P<FEE=.`@;R!I('!E<FUE<W-I(&1E
M;"!P<F]P<FEE=&%R:6\@<&5R('5N82!C;VYD:79I<VEO;F4`07!R92!I;B!U
M;F$@;G5O=F$@9FEN:7-T<F$`17)R;W)E($]P96Y34TPZ(&YO;B!S:2!P;W-S
M;VYO(&5S=')A<G)E(&QE(&EN9F]R;6%Z:6]N:2!D86QL82!P87)T92!F:7)M
M871A(%,O34E-12X`07!R92!Q=65S=&\@8V]L;&5G86UE;G1O(&EN('5N82!N
M=6]V82!F:6YE<W1R80!3:7-T96UA($]P97)A=&EV;P!/<'II;VYI`$]P>FEO
M;FD@<&5R("5S`$5L96YC;R!O<F1I;F%T;P!/<F=A;FEZ>F%Z:6]N90!5;FET
MX"!/<F=A;FEZ>F%T:79A`$%G96YD80!-87-C:&5R82!O<FEG:6YA;&4@9&5L
M;"=A<&QI8V%Z:6]N90!-87-C:&5R82!O<FEG:6YA;&4@:6X@)7,Z`$%L=')O
M`$%L=')E($EN9F]R;6%Z:6]N90!097)M97-S:2!D96P@<')O<')I971A<FEO
M`$PG875T96YT:6-A>FEO;F4@4$%-(&YO;B#H(&1I<W!O;FEB:6QE+@!);F9O
M<FUA>FEO;F4@0VEF<F%T82!01U``0VAI879E(%!U8F)L:6-A(%!'4`!);F9O
M<FUA>FEO;F4@1FER;6%T82]#:69R871A(%!'4`!#;V1I8V4@4$A0`%-H96QL
M(%!(4`!%<W1E;G-I;VYE(%!/4TE8(&UA;F-A;G1E`%)I96UP:6UE;G1O`%!A
M<GII86QM96YT92!.=79O;&]S;P!087-S=V]R9"!C86UB:6%T82!C;VX@<W5C
M8V5S<V\N`%!A<W-O=W)D(&YO;B!C;W)R971T80!%)R!R:6-H:65S=&$@;&$@
M<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@4D%$2553+@!087-S=V]R
M9"!C;VX@8V]N9F5R;6$`3&4@<&%S<W=O<F0@9&5V;VYO(&-O<G)I<W!O;F1E
M<F4N`$EN8V]L;&$`26YC;VQL82!D86QL82!C;&EP8F]A<F0`4&5R8V]R<V\`
M4&5R<V]N90!097)C96YT=6%L90!%<V5G=6D@;&4@3W!E<F%Z:6]N:2!D:2!-
M86YU=&5N>FEO;F4`17-E9W5I<F4@;&4@;W!E<F%Z:6]N:2!D:2!M86YT=71E
M;GII;VYE(&%L;"=A8V-E<W-O/P!097)M97-S;P!097)M97-S;R`B)7,B(&YO
M;B!C86YC96QL871O+@!097)M97-S;R!.96=A=&\`4&5R;65S<VD`1V5S=&EO
M;F4@4&5R;65S<VD`26YF;W)M87II;VYI(%!E<G-O;F%L:0!496QE9F]N;P!&
M;W1O9W)A9FEE`%-I('!R96=A(&1I(&-L:6-C87)E(&EN(&%L8W5N92!C96QL
M90!3:2!P<F5G82!D:2!C;VYF97)M87)E(&-H92!S:2!V=6]L92!R:6UU;W9E
M<F4@<75E<W1O(&5L96UE;G1O.@!3:2!P<F5G82!D:2!C;VYF97)M87)E(&-H
M92!S:2!V=6]L92!S8V]L;&5G87)E('%U97-T;R!E;&5M96YT;SH`4VD@<')E
M9V$@9&D@:6YS97)I<F4@=6X@;65S92!E('5N(&%N;F\N`%-I('!R96=A(&1I
M(&EN<V5R:7)E('5N(&YO;64@<&5R(&QA(&YU;W9A(&=A=&5G;W)I83H`4VD@
M<')E9V$@9&D@:6YS97)I<F4@=6X@:6YD:7)I>GIO($E0('9A;&ED;RX`4VD@
M<')E9V$@9&D@:6YS97)I<F4@=6YA(&1A=&$@=F%L:61A+"!C;VYT<F]L;&$@
M:6P@;G5M97)O(&1I(&=I;W)N:2!N96P@;65S92X`4VD@<')E9V$@9&D@:6YS
M97)I<F4@=6XG;W)A('9A;&ED82X`4VD@<')E9V$@9&D@9F]R;FER92!U;B!R
M:6%S<W5N=&\@9&5L('!R;V)L96UA+@!3:2!P<F5G82!D:2!F;W)N:7)E(&EL
M('!R;W!R:6\@;F]M92!U=&5N=&4@92!P87-S=V]R9`!3:2!P<F5G82!D:2!L
M96=G97)E(&EL('-E9W5E;G1E('1E<W1O+B!$159)(&5S<V5R92!D)V%C8V]R
M9&\@8V]N(&D@=&5R;6EN:2!D)W5S;R!D96P@<VES=&5M82X`4VD@<')E9V$@
M9&D@<V-R:79E<F4@:6QN;VUE(&1E;&QA(&YU;W9A(&-A=&5G;W)I83H`4&]L
M;VYI80!0;VQI=&EC80!38W)U=&EN:6\`4&]R=&]G86QL;P!0;W-I>FEO;F%M
M96YT;R!D:2!Q=65S=&$@:6UM86=I;F4`4&]S:7II;VYA;65N=&\@9&D@<75E
M<W1A('1A8F5L;&$`4&]S=&%R92!A('%U97-T82!C87)T96QL82`H;F]N(&%P
M<&QI8V%T;R!D82!)34%0*0!0<F5C:7!I=&%Z:6]N92!P97(@;"=U;'1I;6$@
M)7,@;W)A*&4I`%!R969S7VQD87`Z($5S=&5N<VEO;F4@3$1!4"!R:6-H:65S
M=&$@;F]N('1R;W9A=&$N`%!R969S7W-E<W-I;VXZ(&5S=&5N<VEO;F4@9&5L
M;&$@<V5S<VEO;F4@<FEC:&EE<W1A(&YO;B!T<F]V871A+@!0<F5S<VEO;F4`
M4')E<W-I;VYE(&%L(&QI=F5L;&\@9&5L(&UA<F4Z(`!0<F5S<VEO;F4Z(`!!
M;G1E<')I;6$`06YT97!R:6UA(&1E;&PG:6UM86=I;F4@:6X@=6YA(&YU;W9A
M(&9I;F5S=')A`$]P>FEO;FD@<')E8V1E;G1I`%-T86UP82!D;V-U;65N=&\`
M0VAI879E(%!R:79A=&$`4')O8FQE;6$`1&5S8W)I>FEO;F4@9&5L('!R;V)L
M96UA`%!R;V=E='1I`$-H:6%V92!0=6)B;&EC80!!;&=O<FET;6\@9&5L;&$@
M0VAI879E(%!U8F)L:6-A`$EN9F]R;6%Z:6]N:2!S=6QL82!#:&EA=F4@4'5B
M8FQI8V$`3&$@8V]P<&EA(&-H:6%V92!0=6)B;&EC82]0<FEV871A(&YO;B#H
M('-T871A(&=E;F5R871A(&-O;B!S=6-C97-S;RX`16QI;6EN82!I(&UE<W-A
M9V=I`$1O;6%N9&$`4V5L97II;VYE(')A9&EO`%!I;V=G:6$`4F%P<&]R=&\`
M3&5G9VD`3&5G9V5R92!I(&UE<W-A9V=I`$5L:6UI;F%R92!R96%L;65N=&4@
M)7,_($PG;W!E<F%Z:6]N92!N;VX@<'7R(&5S<V5R92!R96-U<&5R871A+@!%
M;&EM:6YA<F4@<F5A;&UE;G1E(&QE(&EN9F]R;6%Z:6]N:2!R96QA=&EV92!A
M;&PG=71E;G1E("5S/R!,)V]P97)A>FEO;F4@;F]N('!U\B!E<W-E<F4@<F5C
M=7!E<F%T82X`4FEE<V5G=64@;&$@='5A('5L=&EM82!A>FEO;F4`06=G:6]R
M;F$`06=G:6]R;F$@9VQI(&5L96UE;G1I(&1I;F%M:6-I(&1E;"!M96YU.@!!
M9V=I;W)N87)E(&QA('9I<W1A(&1E;"!P;W)T86QE.@!2:6-A<FEC80!/<W-E
M<G9A>FEO;FD`4V5R=F5R(')E;6]T:0!54DP@<F5M;W1A("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4FEM=6]V:0!2:6UU;W9I(&EL(&)L;V-C
M;P!2:6UU;W9I(&QA(&-O;&]N;F$`4FEM=6]V:2!L82!F;W)M871T87II;VYE
M`%)I;75O=FD@;&$@8V]P<&EA`%)I;75O=FD@;&\@<V-R:7!T('-A;'9A=&\@
M9&%L;&$@9&ER96-T;W)Y('1E;7!O<F%N96$@9&5L('-E<G9E<BX`4FEM=6]V
M:2!I;`!2:6UU;W9I('%U97-T;R!N;V1O(&1A;"!D;V-U;65N=&\`4FEM=6]V
M:2!L)W5T96YT90!2:6UU;W9I(&PG=71E;G1E.B`E<P!,82!R:6-H:65S=&$@
M;F]N('!U\B!E<W-E<F4@979A<V$N($-O9&EC92!D:2!E<G)O<F4@9&D@<FET
M;W)N;SH@`$EL('-E<G9I>FEO(')I8VAI97-T;R!O;B!P=?(@97-S97)E('1R
M;W9A=&\N`"(E<R(@<FEC:&EE<W1O(&YO;B#H('-P96-I9FEC871O(&YE;&QA
M(&-O;F9I9W5R87II;VYE(&1I("5S+@`B)7,B(')I8VAI97-T;R!N;VX@Z"!S
M<&5C:69I8V%T;R!N96QL82!C;VYF:6=U<F%Z:6]N92!D:2!61E,N`"(E<R(@
M<FEC:&EE<W1O(&YO;B#H('-P96-I9FEC871O(&YE;&QA(&-O;F9I9W5R87II
M;VYE+@!#86UP;R!2:6-H:65S=&\`07IZ97)A`$%Z>F5R82!L82!P87-S=V]R
M9`!!>GIE<F$@;&$@='5A('!A<W-W;W)D`%)I<')I<W1I;F$@;"=U;'1I;6$@
M9&]M86YD80!2:7-U;'1A=&D`4FET;W)N82!A;&QE($]P>FEO;FD`4FES8W)I
M=FD@;&$@;G5O=F$@<&%S<W=O<F0`4FEU;FEO;F4`26YV97)T:2!L82!#;VYF
M:6=U<F%Z:6]N90!/<'II;VYI('!E<B!I;"!2:6-H(%1E>'0@161I=&]R`$EN
M9&]V:6YE;&QI`$1E<W1R80!);G1E<W1A>FEO;FD@9&D@9&5S=')A`%9A;&]R
M:2!D:2!D97-T<F$`4')O<')I973@(&1E;&QA(%)I7V=A+BXN`%)E9V]L80!2
M;W5T82!D:2`Q.#``4F]U=&$@82!S:6YI<W1R80!2;W5T82!A($1E<W1R80!0
M<F]P<FEE=.`@9&5L;&$@4FEG80!0<F]P<FEE=.`@9&5L;&$@<FEG80!2:6=H
M93H`4F5G;VQE`$QE(')E9V]L92!A<'!A<FER86YN;R!T<F$@='5T=&4@;&4@
M<FEG:&4@92!L92!C;VQO;FYE`$QE(')E9V]L92!A<'!A<FER86YN;R!S;VQO
M('1R82!L92!C;VQO;FYE`$QE(')E9V]L92!A<'!A<FER86YN;R!S;VQO('1R
M82!L92!R:6=H90!%<V5G=6ER90!&:7)M82!C:69R871A(%,O34E-10!-97-S
M86=G:6\@8VEF<F%T;R!3+TU)344`3"=A=71E;G1I8V%Z:6]N92!305-,(&YO
M;B#H(&1I<W!O;FEB:6QE+@!-97-S86=G:6\@4TU3`$1I8VAI87)A>FEO;F4@
M4U%,('!E<B!I;"!V86QO<F4@9&D@;&]O:W-U<`!3=&5S<V$@<W1R=71T=7)A
M("A?875T;RD`<')O=FED97(@<V%T96QL:71A<F4`4V%L=F$`4V%L=F$@(B5S
M(@!386QV82`E<P!386QV82!L92!/<'II;VYI`$QA(&-O;F9I9W5R87II;VYE
M(&=E;F5R871A(.@@<W1A=&$@<V%L=F%T82!C;VUE('-C<FEP="!02%`@;F5L
M;&$@9&ER96-T;W)Y('1E;7!O<F%N96$@9&5L('1U;R!S97)V97(N`'-A;'9A
M=&4@)7,@8V]N9FEG=7)A>FEO;FDN`%-A;'9A=&\@;&\@<V-R:7!T(&1I(&%G
M9VEO<FYA;65N=&\@9&5L;&4@:6UP;W-T87II;VYI(&EN.B`B)7,B+@!38VEE
M;GIA`%)I8V5R8V$`36]T;W)I(&1I(%)I8V5R8V$`1FEL92!S96QE>FEO;F%T
M:0!396QE>FEO;F$@=6YA(&1A=&$`4V5L97II;VYA('5N(&=R=7!P;R!D82!A
M9V=I=6YG97)E`%-E;&5Z:6]N82!U;B!N=6]V;R!P<F]P<FEE=&%R:6\`4V5L
M97II;VYA('5N('-E<G9E<@!396QE>FEO;F$@=6X@=71E;G1E(&1A(&%G9VEU
M;F=E<F4`4V5L97II;VYA('1U='1O`%-E;&5Z:6]N82!T=71T:2!I(&-O;7!O
M;F5N=&D@9&5L;&$@9&%T82X`<V5L97II;VYA('5N(&]G9V5T=&\`3F5S<W5N
M82!S96QE>FEO;F4`4V5L97II;VYA(&D@8V%R871T97)I(&1I(&-U:2!H86D@
M8FES;V=N;R!D86QL92!C87-E;&QE('-O='1O(')I<&]R=&%T92X@4'5O:2!C
M;W!I87)L:2!E(&EN8V]L;&%R;&D@9&%L;"=A<F5A(&1I('1E<W1O+@!396QE
M>FEO;F$@:6P@=&5R;6EN92!D96QL82!D871A.@!396QE>FEO;F$@:6P@9F]R
M;6%T;R!D96QL82!D871A.@!396QE>FEO;F$@;"=I9&5N=&ETX"!C:&4@=G5O
M:2!M;V1I9FEC87)E.@!396QE>FEO;F$@:6P@;&EM:71E(&1E;&PG;W)A.@!3
M96QE>FEO;F$@:6P@9F]R;6%T;R!D96QL)V]R83H`4V5L97II;VYA(&1U92!C
M86UP:2!C:&4@8V]R<FES<&]N9&]N;RX`4V5L97II;VYA(&QO('-C:&5M82!D
M96D@8V]L;W)I+@!396QE>FEO;F$@;&$@;&EN9W5A('!R969E<FET83H`26YV
M:6$@:6P@4F5P;W)T(&1E;"!P<F]B;&5M80!);G9I82!335,`4V5N<V]R93H@
M`%-E='1E;6)R90!.=6UE<F\@9&D@4V5R:64`26YF;W)M87II;VYE(&1E;"!S
M97)V97(@<V)A9VQI871A(&\@;F]N(&1I<W!O;FEB:6QE+@!!;6UI;FES=')A
M=&]R92!D:2!S97-S:6]N90!,82!S97-S:6]N92!)1"#H('-C861U=&$`4V5S
M<VEO;FD`26UP;W-T80!);7!O<W1A(&QE(&]P>FEO;FD@<&5R('!E<FUE='1E
M<G1I(&1I(&%Z>F5R87)E(&QA('!A<W-W;W)D(&YE;"!C87-O(&1O=F5S<VD@
M9&EM96YT:6-A<G1E;&$N`$EM<&]S=&$@:6P@<V5R=F5R(')E;6]T;R!A;"!Q
M=6%L92!V=6]I(&%C8V5D97)E(&1A;"!T=6\@<&]R=&%L92X`26UP;W-T82!L
M82!L:6YG=6$@<')E9F5R:71A(&4@;&4@;W!Z:6]N:2!P97(@;"=O<F$@92!L
M82!D871A+@!);7!O<W1A(&QE(&%P<&QI8V%Z:6]N:2!D:2!A=G9I;RP@;&\@
M<V-H96UA(&1E:2!C;VQO<FDL(&EL('1E;7!O(&1I(&%G9VEO<FYA;65N=&\@
M9&5L;&$@<&%G:6YA(&4@86QT<F4@;W!Z:6]N:2!D:2!V:7-U86QI>GIA>FEO
M;F4N`$EM<&]S=&%Z:6]N90!38W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96QL
M92!I;7!O<W1A>FEO;FD@9&ES<&]N:6)I;&D`1&EV97)S92!P;W-I>FEO;FD@
M9&ES<&]N:6)I;&D@8V]N(&EL('!A<F%M971R;SH@`$)R979E(%-O;6UA<FEO
M`$QA(&-H:6%V92!D)V%C8V5S<V\@9&]V<N`@97-S97)E(&1E9FEN:71A('!E
M<B!P:?D@8V]L;&5G86UE;G1I/P!-;W-T<F$`36]S=')A(&QE(&1I9F9E<F5N
M>F4@=')A(&QA(&-O;F9I9W5R87II;VYE(&%T='5A;&UE;G1E('-A;'9A=&$@
M92!L82!N=6]V82!G96YE<F%T82X`36]S=')A(&PG;W)A(&1E;&PG=6QT:6UO
M(&%C8V5S<V\@<75A;F1O(&5N=')I/P!-;W-T<F$@;"=O<'II;VYE('!E<B!M
M86YT96YE<F4@<75E;&QA(&]R:6=I;F%L90!-;W-T<F$@:6P@<F%C8V]G;&ET
M;W)E`$UO<W1R87)E(&QA('1A8F5L;&$@9&5L;&4@;W!E<F%Z:6]N:2!D96P@
M;65N=2!B87(_`$UO<W1R82!I;"!M96YU(&1I("5S('-U;&QA('-I;FES=')A
M/P!-;W-T<F$@:6P@8V%R:6-A;65N=&\`0V]N=')A<W-E9VYA`$9I<FUA`$%L
M9V]R:71M;R!D:2!F:7)M80!$:6UE;G-I;VYE`%-A;'1A(&QE(&]P97)A>FEO
M;FD@9&D@;6%N=71E;GII;VYE`$YE=F4`3W)D:6YA(&PG;W)D:6YA;65N=&\@
M9&D@<V5L97II;VYE`$EN9&ER:7IZ;R!S;W)G96YT90!3=60@069R:6-A`&5M
M:7-F97)O($UE<FED:6]N86QE`%-P87II;R!T<F$@8V5L;&4@86ED86-E;G1I
M`%-P87II;R!T<F$@:6P@8V]N=&5N=71O(&4@:6P@8F]R9&\@:6X@=6YA(&-E
M;&QA`$1I<W1A;GII871O<F4`4W!A>FEA='5R80!3<&%Z:6%T=7)A(&4@<FEE
M;7!I;65N=&\`4W!A9VYA`$EN<V5R:6UE;G1O($-A<F%T=&5R:2!3<&5C:6%L
M:0!397!A<F$@;&$@8V5L;&$`4V5P87)A(&QA(&-O;&]N;F$`4V5P87)A(&QA
M(')I9VAA`$%N;F\@9&D@<&%R=&5N>F$`4W1A=&\@;R!0<F]V:6YC:6$`1F]R
M;6%T;R!D:2!M96UO<FEZ>F%Z:6]N90!);F1I<FEZ>F\`5&]G;&D@:6P@9&]M
M:6YI;R!D86QL)VEN9&ER:7IZ;P!3=&EL92!;0U-370!$;P!3;W1T;V1I<F5C
M=&]R>2`B)7,B(&YO;B!T<F]V871A+@!/9V=E='1O`%-O='1O;65T=&D`12<@
M<W1A=&$@:6YV:6%T82!L82!R:6-H:65S=&$@<&5R(&%G9VEU;F=E<F4@(B5S
M(B!A;"!S:7-T96UA+B!.;VX@<'5O:2!A8V-E9&5R92!F:6YT86YT;R`@8VAE
M(&QA(')I8VAI97-T82!N;VX@=FEE;F4@87!P<F]V871A+@`B)7,B(.@@<W1A
M=&\@86=G:75N=&\@8V]N('-U8V-E<W-O(&%L('-I<W1E;6$N`$QE(&EN9F]R
M;6%Z:6]N:2!R96QA=&EV92!A;&PG=71E;G1E("(E<R(@<V]N;R!S=&%T92!C
M86YC96QL871E(&-O;B!S=7-S97-S;R!D86P@<VES=&5M82X`(B5S(B!E;&EM
M:6YA=&$@8V]N('-U8V-E<W-O+@`B)7,B(')I;6]S<V\@8V]N('-U8V-E<W-O
M(&1A;"!S:7-T96UA+@!#;VYF:6=U<F%Z:6]N92!I;G9E<G1I=&$@8V]N('-U
M8V-E<W-O+B!2:6-A<FEC82!P97(@=F5D97)E(&D@8V%M8FEA;65N=&DN`$-O
M<&EA(&1E;&QA(&-O;F9I9W5R87II;VYE('-A;'9A=&$@8V]N('-U8V-E<W-O
M+@!#;W!I82!D96P@9FEL92!D:2!C;VYF:6=U<F%Z:6]N92!D:2`E<R!S86QV
M871A(&-O;B!S=6-C97-S;RX`06=G:6]R;F%T;R!C;VX@<W5C8V5S<V\@(B5S
M(@!38W)I='1O(&-O;B!S=6-C97-S;R`E<P!3;VUM87)I;P!3=7!P;W)T;P!3
M;W!R86YN;VUE`%-V97II80!3=FEZ>F5R80!%<G)O<F4@9&D@<VEN=&%S<VD@
M;F5I('1E<FUI;FD@9&D@<FEC97)C80!0<F]P<FEE=.`@9&5L;&$@5&%B96QL
M80!);7!O<W1A>FEO;F4@9&5L;&$@5&%B96QL80!0<F]P<FEE=.`@9&5L;&$@
M=&%B96QL80!/8FEE='1I=F\Z`$%T=&EV:73@`$YU;65R;R!D:2!T96QE9F]N
M;P!496UP97)A='5R82!P97(@;"=U;'1I;6$@;W)A.B``5&5M<&5R871U<F$`
M5&5M<&5R871U<F$Z(`!-87-C:&5R82`B)7,B(&YO;B!T<F]V871A+@!'97-T
M:6]N92!-87-C:&5R80!497-T;P!3;VQO(%1E<W1O`$%L;&EN96%M96YT;R!T
M97-T;P!':0!,)V5S=&5N<VEO;F4@1E10(&YO;B#H(&1I<W!O;FEB:6QE+@!,
M82!C<F]N:7-T;W)I82!D96P@<VES=&5M82#H(&1I<V%B:6QI=&%T82X`26P@
M;6]T;W)E(&1I(&EN=&5G<F%Z:6]N92!(;W)D92]+;VQA8B!N;VX@<W5P<&]R
M=&$@(B5S(@!);"!L;V<@9&D@24U34"!N;VX@<'7R(&5S<V5R92!I;FEZ:6%L
M:7IZ871O+@!,82!C;&%S<V4@36%I;G1E;F%N8V4Z.B!N;VX@Z"!S=&%T82!C
M87)I8V%T82!C;VX@<W5C8V5S<V\`3&$@9FEN:7-T<F$@9&5L;&4@3W!Z:6]N
M:2!S:2#H(&-H:75S82X@57-C:7)E+@!3;VQA;65N=&4@:6P@;&%T;R!I;F9E
M<FEO<F4`26P@8V]N=&%T=&\@Z"!S=&%T;R!A9V=I=6YT;R!C;VX@<W5C8V5S
M<V\@86QL82!T=6$@<G5B<FEC82X`3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@
M;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X`3&$@9G5N>FEO;F4@9&D@8VEF
M<F%T=7)A(')I8VAI961E('5N82!C;VYN97-S:6]N92!W96(@<VEC=7)A+@!)
M;"!F:6QE("5S(&1O=G)E8F)E(&-O;G1E;F5R92!U;F$@)7,@:6UP;W-T87II
M;VYE+@!);"!F:6QE("5S(&1O=G)E8F)E(&-O;G1E;F5R92!A;&-U;F4@)7,@
M:6UP;W-T87II;VYI+@!);"!F:6QE(&YO;B!C;VYT:65N92!I;F9O<FUA>FEO
M;FDN`$QE('-E9W5E;G1I('-O;F\@;&4@:6YT97-T87II;VYI('!E<B!Q=65S
M=&\@;65S<V%G9VEO+W)F8S@R,B!M97-S86=G:6\N`$PG:61E;G1I=.`@(B5S
M(B#H('-T871A(&-A;6-E;&QA=&$N`$EL(&YU;65R;R!D96D@8V%M<&D@9&5V
M92!E<W-E<F4@9&D@=&EP;R!N=6UE<FEC;RX`26P@;6]D=6QO(&]P96YS<VP@
MZ"!R:6-H:65S=&\@<&5R(&QA(&-L87-S92!(;W)D95]#<GEP=%]S;6EM93HZ
M+@!,82!P<F5F97)E;GIA("(E<R(@;F]N('!U\B!E<W-E<F4@<V%L=F%T82!P
M97)C:.@@;"=I;F9O<FUA>FEO;F4@8V]N=&5N=71A(&5C8V5D92!L82!M87-S
M:6UA(&1I;65N<VEO;F4@9&ES<&]N:6)I;&4`26P@<')O9W)A;6UA('5S871O
M('!E<B!V:7-U86QI>GIA<F4@<75E<W1O('1I<&\@9&D@:6YF;W)M87II;VYE
M("@E<RD@;F]N(.@@<W1A=&\@=')O=F%T;R!N96P@<VES=&5M82X`26P@<V5R
M=F5R("(E<R(@Z"!S=&%T;R!E;&EM:6YA=&\N`$EL('-E<G9E<B`B)7,B(.@@
M<W1A=&\@<V%L=F%T;RX`3&$@<FEC:&EE<W1A(&1I(&ES8W)I>FEO;F4@<&5R
M("5S(.@@<W1A=&$@<FEM;W-S82X`3&$@<FEG82!S<&5C:69I8V%T82`H)60I
M(&YO;B!E<VES=&4N`$EL(&9I;&4@=&5M<&]R86YE;R`B)7,B(&YO;B!E<VES
M=&4N`$EL('1E<W1O(&1I9VET871O(&YO;B!C;W)R:7-P;VYD92!A;"!T97-T
M;R!S=6QL;R!S8VAE<FUO+@!,)VEN9F]R;6%Z:6]N92!C87)I8V%T82#H('-T
M871A('!E<G-A('-I;B!D86QL)W5L=&EM;R!P87-S;RX`26P@9FEL92!C87)I
M8V%T;R!N;VX@<'7R(&5S<V5R92!S86QV871O+@!,82!D:7)E8W1O<GD@9&5I
M('1E;6D@(B5S(B!N;VX@Z"!S=&%T82!T<F]V871A+@!.;VX@8VD@<V]N;R!O
M<'II;VYI(&1I<W!O;FEB:6QI+@!.;VX@8VD@<V]N;R!P87)T:2!C:&4@<&]S
M<V]N;R!E<W-E<F4@=FES=6%L:7IZ871E(&EN;&EN92X`0VD@<V]N;R!T<F]P
M<&D@8V%R871T97)I(&EN('%U97-T;R!C86UP;RX@2&%I(&1I9VET871O("5S
M(&-A<F%T=&5R:3L@9&5V:2!D:6=I=&%R92!U;B!N=6UE<F\@9&D@8V%R871T
M97)I(&UI;F]R92!D:2`E<RX`0VD@<V]N;R!A;&-U;FD@<')O8FQE;6D@;F5L
M;"=A9V=I=6YG97)E("(E<R(@86P@<VES=&5M83H@)7,`0R?H('-T871O('5N
M('!R;V)L96UA(&YE;"!C86YC96QL87)E(&QE(&EN9F]R;6%Z:6]N:2!P97(@
M;"=U=&5N=&4@(B5S(B!D86P@<VES=&5M83H@`$,GZ"!S=&%T;R!U;B!P<F]B
M;&5M82!N96P@<FEM=6]V97)E("(E<R(@9&%L('-I<W1E;6$Z(`!#)^@@<W1A
M=&\@=6X@<')O8FQE;6$@;F5L;"=A9V=I;W)N86UE;G1O(&1I("(E<R(Z("5S
M`$,GZ"!S=&%T;R!U;B!P<F]B;&5M82!C;VX@:6P@8V%R:6-A;65N=&\@9&5L
M(&9I;&4Z($YE<W-U;B`E<R#H('-T871O(&-A<FEC871O+@!#)^@@<W1A=&\@
M=6X@<')O8FQE;6$@8V]N(&EL(&-A<FEC86UE;G1O(&1E;"!F:6QE.B!);"`E
M<R!E<F$@<&GY(&QU;F=O(&1E;&QA(&UA<W-I;6$@9&EM96YS:6]N92!P97)M
M97-S82`H)60@8GET97,I+@!#)^@@<W1A=&\@=6X@<')O8FQE;6$@8V]N(&EL
M(&-A<FEC86UE;G1O(&1E;"!F:6QE.B!);"`E<R#H('-T871O(&-A<FEC871O
M('-O;&\@<&%R>FEA;&UE;G1E+@!#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&QA
M('9I<W5A;&EZ>F%Z:6]N92!D:2!Q=65S=&$@<&%R=&4@9&5L(&UE<W-A9V=I
M;P!#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG:6UP;W)T87)E(&QE(&EN9F]R
M;6%Z:6]N:2!D96P@8V]N=&%T=&\N`$,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L
M;"=I;7!O<G1A<F4@;&4@:6YF;W)M87II;VYI(&1I(&E#86QE;F1A<BX`0R?H
M('-T871O('5N(&5R;W)E(&YE;&QA(&9O<FT@9&D@8V]N9FEG=7)A>FEO;F4N
M(%!R;V)A8FEL;65N=&4@:&%I(&1I;65N=&EC871O('5N(&-A;7!O(')I8VAI
M97-T;RX`0R?H('-T871O('5N(&5R<F]R92!N96QL)V5S96=U:7)E(&QA('-P
M96-I9FEC82!F=6YZ:6]N92!D96QL82!R=6)R:6-A+B!3:2!P<F5G82!D:2!R
M:7!R;W9A<F4@<&GY('1A<F1I+@!#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG
M86=G:6]R;F%M96YT;R!D96D@9&5T=&%G;&D@9&5L(&-O;G1A='1O+B!3:2!P
M<F5G82!D:2!P<F]V87)E('!I^2!T87)D:2X`0R?H('-T871O('5N(&5R<F]R
M92!N96QL)V%G9VEO<FYA;65N=&\@9&5L;&$@;&ES=&$@9&D@9&ES=')I8G5Z
M:6]N92X@4VD@<')E9V$@9&D@<')O=F%R92!P:?D@=&%R9&DN`%%U97-T;R!S
M97)V97(@24U!4"!N;VX@<W5P<&]R=&$@;&$@8V]N9&EV:7-I;VYE(&1I(&-A
M<G1E;&QE+@!1=65S=&\@<V5M8G)A(&YO;B!E<W-E<F4@=6X@87)C:&EV:6\@
M9&D@=&EP;R!R87(@=F%L:61O+@!1=65S=&\@<V5M8G)A(&YO;B!E<W-E<F4@
M=6X@9FEL92!D:2!T:7!O('II<"!V86QI9&\N`%%U97-T;R!N;VX@<V5M8G)A
M(&5S<V5R92!U;B!N=6UE<F\@9&D@8V%R=&$@=F%L:61O+@`@475E<W1O(&-A
M;7!O('!U\B!C;VYT96YE<F4@<V]L;R!I;G1E<FDN`"!1=65S=&\@8V%M<&\@
M<'7R(&-O;G1E;F5R92!S;VQO(&YU;65R:2!E(&1U92!P=6YT:2X`475E<W1O
M(&-A;7!O('!U\B!E<W-E<F4@<V]L;R!U;F$@;&ES=&$@9&D@:6YT97)I('-A
M<&%R871I(&1A('9I<F=O;&$@;R!S<&%Z:6\`475E<W1O(&-A;7!O(&1E=F4@
M97-S97)E('5N(&YU;65R;R!V86QI9&\N`%%U97-T;R!C86UP;R!D979E(&-O
M;G1E;F5R92!U;B!C;VQO<F\@:6X@9F]R;6%T;R!21T(@97-A9&5C:6UA;&4L
M(&%D(&5S96UP:6\@)R,Q,C,T868G+@!1=65S=&$@9F]R;2#H(&=I82!S=&%T
M82!P<F]C97-S871A+@!1=65S=&\@Z"`E<RX`475E<W1O(&UE<W-A9V=I;R#H
M('-T871O('-C<FET=&\@:6X@=6X@<V5T(&1I(&-A<F%T=&5R:2`H)7,I(&1I
M=F5R<V\@9&%L('1U;RX`475E<W1O(&YU;65R;R!D979E(&5S<V5R92!U;FEC
M;RX`475E<W1O('-E<G9E<B!N;VX@<'7R(&1E8V]M<')I;65R92!F:6QE(&EN
M(&9O<FUA=&\@>FEP(&4@9WII<"X`06P@;6]M96YT;R!Q=65S=&\@<VES=&5M
M82!N;VX@Z"!A='1I=F\N`%%U97-T;R!V86QO<F4@9&5V92!E<W-E<F4@=6X@
M;G5M97)O+@!1=65S=&$@9FEN97-T<F$@9&5V92!E<W-E<F4@8VAI86UA=&$@
M9&$@=6YA(&9I;F5S=')A(&1E;&QE($]P>FEO;FD`5'5O;F\`0FEG;&EE='1I
M`$]R80!&;W)M871O(&1E;&PG;W)A`%-E;&5Z:6]N92!D96QL)V]R80!4:71O
M;&\`00!097(@<V5L97II;VYE<F4@<&GY('9O8VDL('1I96YI('!R96UU=&\@
M:6P@=&%S=&\@0V]N=')O;"`H4$,I(&\@0V]M;6%N9"`H36%C*2!M96YT<FD@
M<W1A:2!C;&EC8V%N9&\N`$]G9VD`1&]M86YI`%1R;W!P92!A8V-E<W-I(&YO
M;B!V86QI9&D@9'5R96YT92!G;&D@=6QT:6UI(&UI;G5T:2X`06QT;P!4<F%D
M=7II;VYI`%9E<F\@;R!F86QS;P!-80!4=7)C:&EA`$1I9VET82!L82!T=6$@
M<V-E;'1A.B``26UP;W-S:6)I;&4@86-C961E<F4@86QL82!D:7)E8W1O<GD@
M5D93+@!);7!O<W-I8FEL92!A9V=I=6YG97)E(&%L=')E(&EN9F]R;6%Z:6]N
M:2!S=6=L:2!U=&5N=&D@;65N=')E(&1U<F%N=&4@;&$@<V]T=&]S8W)I>FEO
M;F4N`$EM<&]S<VEB:6QE(&-A;6)I87)E(&D@<&5R;65S<VD@<&5R(&EL(&9I
M;&4@5D93("(E<R(N`$EM<&]S<VEB:6QE(&-A;6)I87)E(&D@<&5R;65S<VD@
M<&5R(&EL(&9I;&4@5D93("5S+R5S+@!);7!O<W-I8FEL92!C86UB:6%R92!A
M("5S+@!);7!O<W-I8FEL92!V97)I9FEC87)E(&QA(&1I;65N<VEO;F4@9&D@
M(B5S(BX`26UP;W-S:6)I;&4@=F5R:69I8V%R92!L82!D:6UE;G-I;VYE(&1I
M("(E<R\E<R(N`$EM<&]S<VEB:6QE(&-O;FYE='1E<G-I(&%L('-E<G9E<B!3
M44PN`$EM<&]S<VEB:6QE(&-O;FYE='1E<G-I(&-O;B!34TPN`$EM<&]S<VEB
M:6QE(&-O<&EA<F4@:6P@9FEL92!61E,N`$EM<&]S<VEB:6QE(&-R96%R92!L
M82!D:7)E8W1O<GD@5D93("(E<R(N`$EM<&]S<VEB:6QE(&-R96%R92!L82!D
M:7)E8W1O<GD@5D93+@!);7!O<W-I8FEL92!C<F5A<F4@:6P@9FEL92!61E,N
M`$EM<&]S<VEB:6QE(&-R96%R92!L82!C87)T96QL82!61E,@(B5S(BX`26UP
M;W-S:6)I;&4@8W)E87)E(&EL(&9I;&4@5D93('9U;W1O+@!);7!O<W-I8FEL
M92!D96-O;7!R:6UE<F4@;&4@:6YF;W)M87II;VYI+@!);7!O<W-I8FEL92!E
M;&EM:6YA<F4@(B5S(BP@;&$@9&ER96-T;W)Y(&YO;B#H('9U;W1A+@!);7!O
M<W-I8FEL92!E;&EM:6YA<F4@(B5S(CH@)7,N`$EM<&]S<VEB:6QE(&5L:6UI
M;F%R92`E<RP@;&$@9&ER96-T;W)Y(&YO;B#H('9U;W1A`$EM<&]S<VEB:6QE
M(&5L:6UI;F%R92!L82!D:7)E8W1O<GD@5D93(&EN(&UO9&\@<FEC;W)S:79O
M+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@;&$@9&ER96-T;W)Y(%9&4RX`26UP
M;W-S:6)I;&4@96QI;6EN87)E(&QA(&1I<F5C=&]R>2!61E,Z("5S+@!)37!O
M<W-I8FEL92!E;&EM:6YA<F4@:6P@9FEL92!61E,@(B5S(BX`26UP;W-S:6)I
M;&4@96QI;6EN87)E(&EL(&9I;&4@5D93+@!);7!O<W-I8FEL92!E;&EM:6YA
M<F4@;&$@8V%R=&5L;&$@5D93("(E<R(N`$EM<&]S<VEB:6QE(&5L:6UI;F%R
M92!61E,@:6X@;6]D;R!R:6-O<G-I=F\Z("5S+@!);7!O<W-I8FEL92!D971E
M<FUI;F%R92!L82!D:7)E8W1O<GD@871T=6%L92X`26UP;W-S:6)I;&4@97-T
M87)R92!I(&1E='1A9VQI(&1E;"!C97)T:69I8V%T;P!);7!O<W-I8FEL92!C
M87)I8V%R92!L82!D969I;FEZ:6]N92!D:2`E<RX`26UP;W-S:6)I;&4@<W!O
M<W1A<F4@:6P@9FEL92!61E,N`$EM<&]S<VEB:6QE(&%P<FER92!I;"!F:6QE
M(%9&4R`B)7,B+@!);7!O<W-I8FEL92!A<')I<F4@:6P@9FEL92!61E,@<&5R
M(&QA('-C<FET='5R82X`26UP;W-S:6)I;&4@87!R:7)E(&EL(&9I;&4@5D93
M+@!);7!O<W-I8FEL92!A<')I92!L)V%R8VAI=FEO(&-O;7!R97-S;RX`26UP
M;W-I8FEL92!L96=G97)E(&EL(&9I;&4@5D93("AF:6QE<VEZ92!F:6QE*"D@
M9F%I;&5D*2X`26UP;W-S:6)I;&4@;&5G9V5R92!I;"!F:6QE(%9&4R`H9V5T
M1FEL95-I>F4H*2!F86EL960I+@!);7!O<W-I8FEL92!L96=G97)E(&EL(&9I
M;&4Z(`!);7!O<W-I8FEL92!L96=G97)E(&QA(&1I<F5C=&]R>2!V9G-R;V]T
M+@!);7!O<W-I8FEL92!R:6YO;6EN87)E("5S(&EN("5S.B!L82!C87)T96QL
M82!D:2!D97-T:6YA>FEO;F4@Z"!G:6$@<')E<V5N=&4`26UP;W-S:6)I;&4@
M<FEN;VUI;F%R92!L82!D:7)E8W1O<GD@5D93+@!);7!O<W-I8FEL92!R:6YO
M;6EN87)E(&QA(&1I<F5C=&]R>2!61E,Z("5S+@!);7!O<W-I8FEL92!R:6YO
M;6EN87)E(&EL(&9I;&4@5D93("(E<R(N`$EM<&]S<VEB:6QE(')I;F]M:6YA
M<F4@:6P@9FEL92!61E,@)7,O)7,N`$EM<&]S<VEB:6QE(')I;F]M:6YA<F4@
M:6P@9FEL92!61E,N`$EM<&]S<VEB:6QE(&5S96=U:7)E("=M:VES;V9S)RX`
M26UP;W-S:6)I;&4@=')A9'5R<F4@<75E<W1O(&1O8W5M96YT;R!7;W)D`$EM
M<&]S<VEB:6QE(&1A<F4@;"=A=G9I;R!A;&PG86=G:6]R;F%M96YT;R!F<F5E
M+V)U<WD@<&5R("5S`$EM<&]S<VEB:6QE('-C<FEV97)E(&EL(&9I;&4@5D93
M("(E<R(N`$EM<&]S<VEB:6QE('-C<FEV97)E(&EL(&9I;&4@5D93("AC;W!Y
M*"D@9F%I;&5D*2X`26UP;W-S:6)I;&4@<V-R:79E<F4@;&4@:6YF;W)M87II
M;VYI(&YE;"!F:6QE(%9&4RX`26UP;W-S:6)I;&4@<V-R:79E<F4@:6P@9FEL
M92!61E,L(&QA('%U;W1A(&-O;G-E;G1I=&$@=F5R<N`@96-C961U=&$N`%-O
M='1O;&EN96%T;P!!;FYU;&QA($UO9&EF:6-H90!.;VX@9F%R92!L82!T=6$@
M=6QT:6UA(&%Z:6]N90!2:7-P;W-T82!I;F%T=&5S82!D86P@<V5R=F5R(&1U
M<F%N=&4@;&$@8V]N;F5S<VEO;F4Z(`!2:7-P;W-T82!I;F%T=&5S82!D86P@
M<V5R=F5R(&$Z(`!38V]N;W-C:75T;P!.;VUE('5T96YT92!E('!A<W-W;W)D
M('-C;VYO<V-I=71I`$YO;B!C;VQL96=A<F4@;"=E;&5M96YT;R!C;W)R96YT
M90!396YZ82!N;VUE`$5S=&5N<VEO;F4@;F]N('-U<'!O<G1A=&$`06=G:6]R
M;F$`06=G:6]R;F$@)7,`06=G:6]R;F$@=71E;G1E`$%G9VEO<FYA("(E<R(N
M`%-C<FEP="!D:2!C87)I8V%M96YT92!E;&EM:6YA=&$N`$-A<FEC80!C87)I
M8V%T:2!T=71T:2!I(&9I;&4@9&D@:6UP;W-T87II;VYE(&1E;&QE(&%P<&QI
M8V%Z:6]N:2!S=6P@<V5R=F5R+@!C87)A='1E<FD@;&%T:6YI(&UA:75S8V]L
M:0!.=6UE<FD@<F]M86YI(&UA:75S8V]L:0!U<V$@:6P@8V]R<F5N=&4Z("5S
M`%5S82!34TP`57-A('-E(&EL(&YO;64@=71E;G1E+W!A<W-W;W)D(.@@9&EF
M9F5R96YT92!D82!Q=65L;&$@9&5L('-E<G9E<B!)35-0+@!5=&5N=&4`3'5T
M96YT92`E<R!N;VX@Z"!A=71O<FEZ>F%T;R!P97(@)7,N`$=E<W1I;VYE(%5T
M96YT:0!/<'II;VYI(%5T96YT:0!296=I<W1R87II;VYE(%5T96YT:0!,87)E
M9VES=')A>FEO;F4@9&5G;&D@=71E;G1I(.@@<W1A=&$@9&ES86)I;&ET871A
M('!E<B!Q=65S=&\@<VET;RX`3F]M92!U=&5N=&4@;F]N('1R;W9A=&\`3F]M
M92!5=&5N=&4`3F]M92!5=&5N=&4@(B5S(B#H(&=I82!P<F5S96YT92X`3F]M
M92!5=&5N=&4Z`$YO;64@571E;G1E.B``571E;G1I(&YE;"!S:7-T96UA.@!,
M82!D:7)E8W1O<GD@5D93(&YO;B!E<VES=&4N`$%S<V5N>F$`4&]S:7II;VYI
M('9A;&ED92!T<F]V871E(&EN8VQU9&]N;SH@`%9A;&ED:73@`%9A;&]R92!I
M;B!M:6YU=&D@9&$@;W)A+@!);"!V86QO<F4@Z"!M86=G:6]R92!D;&QA(&UA
M<W-I;6$@;'5N9VAE>GIA(&1I("5S+@!686QO<FD`5F%L;W)I(&1A:2!Q=6%L
M:2!S96QE>FEO;F%R90!687)I86)I;&4`5F5R:69I8V$@9F%L;&ET82`M('%U
M97-T;R!M97-S86=G:6\@<'7R(&5S<V5R92!S=&%T;R!A;'1E<F%T;R!C;VXN
M`%9E<G-I;VYE`%9E<G-I;VYE(&1I($-O;G1R;VQL;P!!;&QI;F5A;65N=&\@
M=F5R=&EC86QE`%)I96UP:6UE;G1O('9E<G1I8V%L90!697)T:6-A;&4Z`$UO
M;'1O($%L=&\`5FES=6%L:7IZ82`E<P!6:7-U86QI>GIA('5N82!P86=I;F$@
M=V5B(&5S=&5R;F$`5FES=6%L:7IZ82!C;VUE("5S`%9I<VEB:6QI=.``5FES
M:6)I;&ETX#H@`$%45$5.6DE/3D4`051414Y:24].12$A(2!224U53U9)($Q/
M(%-#4DE05"!-04Y504Q-14Y412!$02`E<RX`071T96YZ:6]N90!-90!";VQL
M971T:6YO(&UE=&5O<F]L;V=I8V\`0F]L;&5T=&EN;R!M971E;W)O;&]G:6-O
M(&9O<FYI=&\@9&$`4V5T=&EM86YA;&UE;G1E`$)E;G9E;G5T;P!"96YV96YU
M=&\@82`E<P!"96YV96YU=&\L("5S`%%U86QE(&%P<&QI8V%Z:6]N92!D;W9R
MX"!V:7-U86QI>GIA<F4@)7,@9&]P;R!L)V%C8V5S<V\_`%%U86PGZ"!I;"!C
M87)A='1E<F4@9&D@9&5L:6UI=&%Z:6]N93\`475A;&4@<&QU9VEN<R!A8FEL
M:71A<F4@<&5R(&EL(%)I8V@@5&5X="!E9&ET;W(N`$QA<F=H97IZ80!,87)G
M:&5Z>F$@:6X@=6YI=.`@0U-3`$QA<F=H97IZ82!D96P@;65N=2!D:2`E<R!S
M=6QL82!S:6YI<W1R82`H879RX"!E9F9E='1O(&-O;"!P<F]S<VEM;R!A8V-E
M<W-O*3H`3&%R9VAE>GIA(&1E;&QA('1A8F5L;&$`56YI=.`@9&D@;&%R9VAE
M>GIA`$QA<F=H97IZ83H`5F5N=&\`5F5L;V-I=.`@9&5L('9E;G1O(&EN(&YO
M9&D`5F5N=&\Z`%9E;G1O.B``4V%G9V5Z>F$`3&%V;W)O`$EN9&ER:7IZ;R!D
M96P@;&%V;W)O`%1E;&5F;VYO(&1E;"!L879O<F\`3G5M97)O(&1I(&-A;7!I
M(&5R<F%T;R!N96QL82!L:6YE82`E9"X@071T97-I("5D+"!T<F]V871I("5D
M+@!.=6UE<F\@9&D@8V%M<&D@97)R871O+B!!='1E<VD@)60L('1R;W9A=&D@
M)60N`$-O;7!E;G-A>FEO;F4@<V)A9VQI871A("5D(&1U<F%N=&4@;&$@;&5T
M='5R82!D:2!U;B!F:6QE(%9&4RX`06YN=6%L;65N=&4`4VD`4VDL('-O;F\@
M9"=A8V-O<F1O`%-E:2!I;B!F;W)M871O('1E<W1O+B!5<V$@:6P@8F]T=&]N
M92!;/#Y=('!E<B!T;W)N87)E(&%L(&9O<FUA=&\@5UE325=91RX`3F]N(&AA
M:2!I;"!P97)M97-S;R!D:2!C<F5A<F4@<&GY(&1I("5D(&)L;V-C:&DN`$YO
M;B!T:2!S96D@875T96YT:6-A=&\N`$YO;B!P=6]I(&%V97)E(&EL(&-A<F%T
M=&5R92`G7"<@;F5L('1U;R!N;VUE(&-O;7!L971O+@!.;VX@:&%I(&EN<V5R
M:71O('5N(&EN9&ER:7IZ;R!E;6%I;"!V86QI9&\N`$YO;B!H86D@87-S;V-I
M871O(&YE<W-U;B!D96D@8V%M<&D@9&%L(&9I;&4@:6UP;W)T871O(&-O;B!I
M(&-A;7!I(&-O<G)I<W!O;F1E;G1I(&EN("5S+@!396D@<W1A=&\@9&ES8V]N
M;F5S<V\N`$1E=FD@:6YS97)I<F4@=6X@;G5M97)O(&1I(&-E;&QU;&%R92!V
M86QI9&\L(&-O;G1E;F5N=&4@<V]L;R!N=6UE<FD@8V]N(&PG;W!Z:6]N92!D
M96P@)RLG('!E<B!I('!R969I<W-I(&EN=&5R;F%Z:6]N86QI+@!$979I(&EN
M<V5R:7)E('5N('9A;&]R92!V86QI9&\N`$1E=FD@8V]N9FEG=7)A<F4@=6X@
M8F%C:V5N9"!P97(@:6P@1&%T851R964@<&5R('5S87)E(%-I9VYU<',N`$1E
M=FD@8V]N9FEG=7)A<F4@=6X@8F%C:V5N9"!61E,N`$1E=FD@<')I;6$@9&5S
M8W)I=F5R92!I;"!P<F]B;&5M82!P<FEM82!D:2!M86YD87)L;R!C;VUE(')E
M<&]R="X`1&5V:2!I;G-E<FER92!L)U523"!A;&QA('%U86QE('!U;G1A('%U
M97-T;R!C;VQL96=A;65N=&\`1&5V:2!S96QE>FEO;F%R92!U;B!S97)V97(@
M9&$@96QI;6EN87)E+@!$979I('-P96-I9FEC87)E('5N('5T96YT92!D82!A
M>GIE<F%R92X`1&5V:2!S<&5C:69I8V%R92!U;B!U=&5N=&4@9&$@<FEM=6]V
M97)E+@!$979I('-P96-I9FEC87)E('5N('5T96YT92!D82!A9V=I=6YG97)E
M+@!$979I('-P96-I9FEC87)E('5N('5T96YT92!D82!A9V=I;W)N87)E+@!$
M979I('-P96-I9FEC87)E('5N)V%Z:6]N92!D82!E<V5G=6ER92X`1&5V:2!S
M<&5C:69I8V%R92!I;"!N;VUE(&1E;&QA(&YU;W9A(&-A=&5G;W)I82X`1&5V
M:2!I;G-E<FER92!U;B!N=6UE<F\@9&D@=&5L969O;F\@:71A;&EA;F\`3&$@
M='5A('-E<W-I;VYE("5S(.@@<V-A9'5T82X@4VD@<')E9V$@9&D@8V]L;&5G
M87)S:2!N=6]V86UE;G1E+@!);"!T=6\@:6YD:7)I>GIO($5M86EL`$EL(&-A
M;7!O($1A.B!D96P@='5O(&EN9&ER:7IZ;SH`3&4@='5E(&EN9F]R;6%Z:6]N
M:0!);"!T=6\@:6YD:7)I>GIO($EN=&5R;F5T(.@@8V%M8FEA=&\@9&%L;"=I
M;FEZ:6\@9&5L;&$@='5A('-E<W-I;VYE("5S+B!097(@<')O=&5G9V5R92!L
M82!T=6$@<VEC=7)E>GIA+"!D979I(')I8V]L96=A<G1I(&YU;W9A;65N=&4N
M`$EL('1U;R!.;VUE`$EL('1U;R!B86-K96YD(&1I(&%U=&5N=&EC87II;VYE
M(&YO;B!S=7!P;W)T82!L)V%G9VEU;G1A(&1I(&YU;W9I('5T96YT:2X@4V4@
M=G5O:2!U<V%R92!(;W)D92!P97(@9V5S=&ER92!G;&D@=71E;G1I+"!D979I
M('5S87)E('5N(&)A8VME;F0@9&D@875T96YT:6-A>FEO;F4@9&EF9F5R96YT
M90!);"!T=6\@8F%C:V5N9"!D:2!A=71E;G1I8V%Z:6]N92!N;VX@<W5P<&]R
M=&$@;"=E;&5N8V\@9&5G;&D@=71E;G1I+"!O(&QA(&9U;GII;VYE(.@@<W1A
M=&$@9&ES86)I;&ET871A('!E<B!A;'1R92!R86=I;VYI+@!396UB9G)A(&-H
M92!I;"!T=6\@8G)O=W-E<B!S:6$@8V%M8FEA=&$@9&%L;"=I;FEZ:6\@9&5L
M;&$@='5A('-E<W-I;VYE("5S+B!097(@<')O=&5G9V5R92!L82!T=6$@<VEC
M=7)E>GIA+"!D979I(&%C8V5D97)E(&YU;W9A;65N=&4N`$EL('1U;R!B<F]W
M<V5R(&YO;B!S=7!P;W)T82!Q=65S=&$@9G5N>FEO;F4N`$EL('1U;R!B<F]W
M<V5R(&YO;B!S=7!P;W)T82!Q=65S=&$@;W!Z:6]N92!D:2!S=&%M<&$N(%!R
M96UI($-O;G1R;VPO0V]M;6%N9"`K(%`@<&5R('-T86UP87)E+@!);"!T=6\@
M9G5S;R!O<F%R:6\Z`$QA('1U82!I9&5N=&ETX"!D:2!D969A=6QT(.@@<W1A
M=&$@;6]D:69I8V%T82X`3&$@='5A(&ED96YT:73@(&1I(&1E9F%U;'0Z`$EL
M('1U;R!N;VUE(&-O;7!L971O.@!,82!T=6$@;&]G:6X@Z"!S8V%D=71A+@!,
M82!T=6$@;G5O=F$@<&%S<W=O<F0@<&5R("5S(.@Z("5S`$QE('1U92!O<'II
M;VYI('-O;F\@<W1A=&4@86=G:6]R;F%T92!P97(@;&$@9'5R871A(&1I('%U
M97-T82!S97-S:6]N92X`3&4@='5E(&]P>FEO;FD@<V]N;R!S=&%T92!A9V=I
M;W)N871E+@!,82!T=6$@<&%S<W=O<F0@Z"!S=&%T82!A>GIE<F%T80!,82!T
M=6$@<&%S<W=O<F0@Z"!S=&%T82!A>GIE<F%T82P@8V]N=')O;&QA(&QA('1U
M82!E;6%I;"!E(&%C8V5D:2!C;VX@;&$@='5A(&YU;W9A('!A<W-W;W)D+@!,
M82!T=6$@<&%S<W=O<F0@Z"!S8V%D=71A+@!)('1U;VD@<V5R=F5R(')E;6]T
M:3H`6TYA<V-O;F1I(&EL('1E<W1O(&-I=&%T;UT`6U)E<&]R="!D96P@<')O
M8FQE;6%=`%M-;W-T<F$@:6P@=&5S=&\@8VET871O("T`6TUO<W1R82!I;"!T
M97-T;R!C:71A=&\@+2`E<R!L:6YE95T`6VQI;F5A("5S(&1I("5S70!?06UM
M:6YI<W1R87II;VYE`%]#86YC96QL82!2:6=A`%]'<G5P<&D`7T%I=71O`'!R
M;W!R:65TX"!D96QL)U]);6UA9VEN92XN+@!?16YT<F$`7T5S8VD`7TUO9&EF
M:6-A($-O;&QE9V%M96YT;RXN+@!?3W!Z:6]N:0!?4&5R;65S<VD`7T5L:6UI
M;F$@0V]L;&5G86UE;G1O+BXN`%]);7!O<W1A>FEO;F4`4')O<')I973@(&1E
M;&QA(%]486)E;&QA+BXN`%5T96YT:0!R=6)R:6-A`&EN9&ER:7IZ:2!S8V]N
M;W-C:75T:0!C86QE;F1A<FEO`&-A;&UO`&YO;B!P;W-S;R!C<F5A<F4@:6P@
M9FEL92!D:2!O=7!U=`!N;VX@<&]S<V\@87!R:7)E(&PG:6YP=70`<')E;6D@
M<75I`&5R<F]R92!N96QL)W5S;R!D96QL82!L:6YE82!D:2!C;VUA;F1O`&5R
M<F]R92!D:2!C;VYF:6=U<F%Z:6]N90!E<G)O<F4@;F5L(&9O<FUA=&\@9&5L
M;&$@9&%T80!V:7-U86QI>GIA('!R979I<VEO;F4@*'1A9BD`<'5B8FQI8V$`
M96YT<GD@;F]N('1R;W9A=&$`9&%L("5S("@E<RD@86P@)7,@)7,`;F]M92!H
M;W-T('-C;VYO<V-I=71O`&EM;65D:6%T;P!E<G)O<F4@9&D@:6YP=70O;W5T
M<'5T`&5R<F]R92!I;G1E<FYO(&1E;"!S;V9T=V%R90!L:6YE95T`97)R;W)E
M(&1I(&-O9&EC92`E9"!D:2!M:VES;V9S(&1U<F%N=&4@;&$@<V-R:71T;W)A
M($E33RX`;F]M90!N;VX@:6UP;&5M96YT871O`&YO;B!A;F-O<F$@:6UP;&5M
M96YT861O`&)L;V-C;R!N;W1E`'!E<F-E;G1O`'!E<FUE<W-O(&YE9V%T;P!E
M<G)O<F4@<F5M;W1O(&YE;"!P<F]T;V-O;&QO`'-E<G9I>FEO(&YO;B!D:7-P
M;VYI8FEL90!M;W-T<F$@;&4@9&EF9F5R96YZ90!C;W-T86YT90!E<G)O<F4@
M9&D@<VES=&5M80!E;&5N8V\@871T:79I=.``9W5A<W1O('1E;7!O<F%N96\`
M<V-R:79I(&QA('!A<W-W;W)D(&1U92!V;VQT92!P97(@8V]N9F5R;6%R90!U
M;FEF:6-A=&\`<V5N>F$@;F]M90!U=&5N=&4@<V5L97II;VYA=&\`=SH`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]I=%])5"]H96QP+GAM;```````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T,C<`,3`U,34T,S$P-C(`,#(P
M,S,V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SX*
M/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]I=%])5"]H96QP+GAM;"QV(#$N
M,BXQ,"XR(#(P,#4O,3`O,3@@,3$Z,S,Z-#,@:F%N($5X<"`D("TM/@H\:&5L
M<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)U<'1O9&%T92(@;60U
M/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(^"CQT:71L93Y0
M86=I;F$@9&D@:6YG<F5S<V\@9&5L('!O<G1A;&4\+W1I=&QE/@H@/'!A<F$^
M"B`@475E<W1A('!A9VEN82!D:2!I;F=R97-S;R!D96P@<&]R=&%L92!F;W)N
M:7-C92!U;B!B<F5V92!S;VUM87)I;R!D:2!T=71T92!L92!T=64*("!I;F9O
M<FUA>FEO;FD@:6UP;W)T86YT:2X@060@97-E;7!I;RP@=&D@<'7R(&UO<W1R
M87)E('%U86YT:2!N=6]V:2!M97-S86=G:2!C:0H@('-O;F\@;F5L;&$@='5A
M($E.0D]8+"!I('!R;W-S:6UI(&5V96YT:2!N96P@='5O(&-A;&5N9&%R:6\L
M(&QE(&%T=&EV:73@(&YE;&QA"B`@='5A(&QI<W1A+"!L92!U;'1I;64@;F]T
M:7II92!D82!S97)V:7II('-E;&5Z:6]N871I(&4@8V]S["!V:6$N($UO;'1I
M(&1I('%U97-T:0H@('-O;6UA<FD@8V]N=&5R<F%N;F\@9&5I(&-O;&QE9V%M
M96YT:2!A(&9U;GII;VYI(&-O;75N:2P@<75A;&D@860@97-E;7!I;R!L82!C
M;VUP;W-I>FEO;F4*("!D:2!U;F$@;G5O=F\@;65S<V%G9VEO+"!L82!C<F5A
M>FEO;F4@9&D@=6YO(&YU;W9O(&5V96YT;R!D82!I;G-E<FER92!N96P@8V%L
M96YD87)I;PH@(&\@;&$@8W)E87II;VYE(&1I('5N82!N=6]V82!A='1I=FET
MX"!D82!I;G-E<FER92!N96QL82!L:7-T82P@96-C+@H@/"]P87)A/@H@/'!A
M<F$^"B`@22!C;VYT96YU=&D@9&D@<75E<W1A('!A9VEN82!D96P@<&]R=&%L
M92!S;VYO('!E<G-O;F%L:7IZ86)I;&D@=')A;6ET92!I;"!B;W1T;VYE($9O
M<FUA=&\N"B`@060@97-E;7!I;RP@<'5O:2!S8V5G;&EE<F4@<75A;&D@:6YF
M;W)M87II;VYI(&EN<V5R:7)E(&YE;&QA('!A9VEN82!C;VUE(&%N8VAE(&EN
M"B`@<75A;&4@;W)D:6YE('9E<G)A;FYO(&UO<W1R871E+@H@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\=&ET
M;&4^3&$@8F%R<F$@9&D@;F%V:6=A>FEO;F4@9&5L;&4@87!P;&EC87II;VYI
M/"]T:71L93X*(#QP87)A/@H@(%-U;&QA('-I;FES=')A(&1E;&QA('!A9VEN
M82!W96(@Z"!P<F5S96YT92!L82!B87)R82!D:2!N879I9V%Z:6]N92!D96QL
M92!A<'!L:6-A>FEO;FDN"B`@0VQI8V-A('-U;&PG:6-O;F$@<')E<V5N=&4@
M;F5L;&$@8F%R<F$@9&D@;F%V:6=A>FEO;F4@<&5R('!A<W-A<F4@<F%P:61A
M;65N=&4@90H@('9E;&]C96UE;G1E('1R82!L92!V87)I92!A<'!L:6-A>FEO
M;FD@9&ES<&]N:6)I;&DN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L
M93Y0<F5F97)E;GIE.B!-86YU=&5N>FEO;F4Z($5S96=U:2!L82!M86YU=&5N
M>FEO;F4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!392!V=6]I(&5S96=U:7)E
M(&QE(&]P97)A>FEO;FD@9&D@;6%N=71E;GII;VYE(&%P<&5N82!E;G1R871O
M(&YE;"!P;W)T86QE+`H@("`@<V5L97II;VYE('%U97-T82!C87-E;&QA+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER
M;5]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4](F$R,3$V,F-D
M9F8S8C%D.&9A96%D8C<R.38R-#`P,S9E(CX*("`@(#QT:71L93Y0<F5F97)E
M;GIE.B!-86YU=&5N>FEO;F4Z($-O;F9E<FUA(&QA(&UA;G5T96YZ:6]N93PO
M=&ET;&4^"B`@("`\<&%R83X*("`@(%-E(&1E<VED97)I(&-H92!V96YG82!C
M:&EE<W1A(&QA(&-O;F9E<FUA('!R:6UA(&-H92!T=71T92!L92!O<&5R87II
M;VYI(&1I(&UA;G5T96YZ:6]N92`*("`@('9E;F=A;F\@97-E9W5I=&4L('-E
M;&5Z:6]N82!Q=65S=&$@8V%S96QL82X*("`@(%-E(&QA(&-A<V5L;&$@;F]N
M('9I96YE('-E;&5Z:6]N871A+"!T=71T92!L92!O<&5R87II;VYI(&1I(&UA
M;G5T96YZ:6]N92!C:&4@<V]N;PH@("`@<')O9W)A;6UA=&4@=F5R<F%N;F\@
M97-E9W5I=&4@875T;VUA=&EC86UE;G1E('-E;GIA(&QA('!O<W-I8FEL:73@
M(&1I(&-A;F-E;&QA<FQE"B`@("!Q=6%N9&\@<VD@96YT<F$@;F5L('!O<G1A
M;&4N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]B9U]"1R\`````````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C(`,#$V-C$P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+V)G7T)'+TQ#7TU%4U-!1T53+P``````````````````````````````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,C`S-S4`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O8F=?0D<O3$-?34534T%'15,O:&]R9&4N;6\`
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0R-C$Q`#$P-3$U-#,Q,#8R`#`R
M,C`S-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````/H````<````[`<``%$!``"\#P`````````5```.`````14`
M``@````0%0``#````!D5```+````)A4``"@````R%0``%0```%L5```.````
M<14```@```"`%0``,@```(D5```X````O!4``%0```#U%0``40```$H6```T
M````G!8```4```#1%@``#0```-<6```2````Y18```\```#X%@``&0````@7
M```'````(A<```P````J%P``#@```#<7```#````1A<```4```!*%P``"@``
M`%`7```/````6Q<``!\```!K%P``$0```(L7```,````G1<``#D```"J%P``
M)P```.07```L````#!@``"H````Y&```"@```&08```5````;Q@``"D```"%
M&```$0```*\8```6````P1@``!8```#8&```"````.\8```$````^!@```D`
M``#]&````P````<9```#````"QD```@````/&0``(````!@9```&````.1D`
M``H```!`&0``#````$L9```&````6!D```<```!?&0``$````&<9```K````
M>!D```0```"D&0``'@```*D9```;````R!D``!L```#D&0``,P`````:```O
M````-!H``"D```!D&@```P```(X:```"````DAH```4```"5&@``$````)L:
M```&````K!H``"\```"S&@``#P```.,:```$````\QH```4```#X&@``#0``
M`/X:```;````#!L```T````H&P``!0```#8;```0````/!L``!````!-&P``
M#P```%X;```+````;AL```\```!Z&P``#````(H;```/````EQL``!X```"G
M&P``(0```,8;```@````Z!L```,````)'```$P````T<```4````(1P```P`
M```V'```"0```$,<```;````31P```<```!I'```!@```'$<```)````>!P`
M`!0```""'```!@```)<<```1````GAP``!X```"P'```!````,\<```$````
MU!P```P```#9'```"@```.8<```%````\1P``"````#W'```(````!@=```F
M````.1T``"D```!@'0``"@```(H=```/````E1T``!(```"E'0``$````+@=
M```7````R1T```8```#A'0``#````.@=```,````]1T```T````"'@``*```
M`!`>```K````.1X```@```!E'@``$````&X>```:````?QX```8```":'@``
M!P```*$>```"````J1X``"4```"L'@``!````-(>```/````UQX```<```#G
M'@``"@```.\>```'````^AX```8````"'P``"0````D?```-````$Q\```<`
M```A'P``"@```"D?```$````-!\```<````Y'P``!0```$$?```7````1Q\`
M``(```!?'P``,P```&(?```S````EA\``#@```#*'P``+0````,@```Q````
M,2```"P```!C(```&@```)`@```)````JR````4```"U(````@```+L@```'
M````OB````P```#&(```$0```-,@```1````Y2````D```#W(```"`````$A
M```)````"B$```H````4(0``%0```!\A```%````-2$``"@````[(0``"P``
M`&0A```:````<"$```4```"+(0``(````)$A```R````LB$```4```#E(0``
M!````.LA```R````\"$``"H````C(@``!@```$XB```/````52(```0```!E
M(@``"0```&HB```#````="(``!4```!X(@``$@```(XB```/````H2(``!0`
M``"Q(@``&@```,8B```7````X2(``!<```#Y(@``&P```!$C```9````+2,`
M`!\```!'(P``5P```&<C```$````OR,```0```#$(P``%P```,DC```&````
MX2,```<```#H(P``!0```/`C```)````]B,``$H`````)```.````$LD``!(
M````A"0``$D```#-)```,````!<E``!I````2"4``#T```"R)0``90```/`E
M``!-````5B8``"X```"D)@``+P```-,F```L`````R<``!<````P)P``)0``
M`$@G```R````;B<``#X```"A)P``)0```.`G```A````!B@``#`````H*```
M'````%DH```-````=B@```4```"$*````P```(HH```@````CB@``"(```"O
M*```)0```-(H```F````^"@```D````?*0``!@```"DI```)````,"D``!,`
M```Z*0``"````$XI```)````5RD```H```!A*0``%````&PI```(````@2D`
M`#\```"**0``!P```,HI```&````TBD```T```#9*0``"P```.<I```O````
M\RD```P````C*@``"@```#`J```"````.RH```8````^*@```P```$4J```H
M````22H``"8```!R*@``)0```)DJ```H````ORH``!````#H*@``<P```/DJ
M```?````;2L``!0```"-*P``#P```*(K```$````LBL```<```"W*P``!0``
M`+\K``!2`0``Q2L```\````8+0``!P```"@M```(````,"T```X````Y+0``
M)0```$@M```<````;BT```P```"++0``!P```)@M```U````H"T``#4```#6
M+0``4@````PN``!/````7RX``#<```"O+@``!0```.<N```6````[2X``!8`
M```$+P``%@```!LO```F````,B\```4```!9+P``$````%\O```.````<"\`
M``<```!_+P``"0```(<O```,````D2\```P```">+P``(P```*LO```7````
MSR\```T```#G+P``-P```/4O```M````+3```"T```!;,```+P```(DP```(
M````N3```!@```#",```,@```-LP```/````#C$``!L````>,0``)0```#HQ
M```*````8#$```D```!K,0``!P```'4Q```#````?3$```,```"!,0``"```
M`(4Q```F````CC$```8```"U,0``#P```+PQ```0````S#$```<```#=,0``
M"````.4Q```3````[C$``"D````",@``!P```"PR```E````-#(``"4```!:
M,@``)P```(`R```E````J#(``#H```#.,@``-0````DS```&````/S,```(`
M``!&,P``"0```$DS```;````4S,```8```!O,P``+@```'8S```-````I3,`
M``@```"S,P``!0```+PS```+````PC,``"(```#.,P``$````/$S```&````
M`C0```\````)-```$````!DT```.````*C0```T````Y-```%````$<T```,
M````7#0``!,```!I-```*0```'TT```R````IS0``"0```#:-```!````/\T
M```5````!#4``!8````:-0``#````#$U```+````/C4``"8```!*-0``!@``
M`'$U```&````>#4```L```!_-0``%P```(LU```%````HS4```X```"I-0``
M(0```+@U```%````VC4```8```#@-0``#0```.<U```/````]34```4````%
M-@``+P````LV```O````.S8``#P```!K-@``)@```*@V```*````SS8```T`
M``#:-@``%````.@V```3````_38``!\````1-P``"0```#$W```2````.S<`
M`!$```!.-P``$@```&`W```J````<S<``"T```">-P``!````,PW```*````
MT3<``"$```#<-P``!````/XW```%`````S@```(````).```+0````PX```$
M````.C@``!`````_.```!P```%`X```.````6#@```4```!G.```!0```&TX
M```(````<S@``!$```!\.```!P```(XX```*````EC@```,```"A.```!0``
M`*4X```&````JS@``",```"R.````@```-8X```F````V3@``"8`````.0``
M*P```"<Y```K````4SD``"\```!_.0``-0```*\Y```9````Y3D```X```#_
M.0``!P````XZ```"````%CH```4````9.@``#P```!\Z```0````+SH``!0`
M``!`.@``"0```%4Z```&````7SH```<```!F.@``"````&XZ```2````=SH`
M``8```"*.@``,@```)$Z```%````Q#H``!D```#*.@``!P```.0Z```>````
M[#H``#<````+.P``"@```$,[```&````3CL``$(```!5.P``*0```)@[```(
M````PCL``!<```#+.P``!````.,[```)````Z#L```,```#R.P``&@```/8[
M```@````$3P```\````R/```'0```$(\```9````8#P``!H```!Z/```&```
M`)4\```>````KCP``",```#-/```)````/$\``!H````%CT```D```!_/0``
M!@```(D]```>````D#T```<```"O/0``!0```+<]```&````O3T```H```#$
M/0``1P```,\]```K````%SX``$D```!#/@``5P```(T^```O````Y3X``%\`
M```5/P``-0```'4_``!A````JS\``#\````-0```)P```$U````<````=4``
M`!L```"20```%P```*Y````J````QD```#$```#Q0```10```"-!```@````
M:4$``"0```"*00``-P```*]!```@````YT$``!4````(0@``"````!Y"```#
M````)T(``"0````K0@``*P```%!"```E````?$(``"@```"B0@``"@```,M"
M```'````UD(```H```#>0@``'P```.E"```#````"4,```0````-0P``!0``
M`!)#```8````&$,```@````Q0P``/0```#I#```(````>$,```@```"!0P``
M$````(I#```/````FT,``#0```"K0P``#````.!#```.````[4,```(```#\
M0P``!P```/]#```"````!T0``"$````*1```*P```"Q$```J````6$0``"T`
M``"#1```$0```+%$``!E````PT0``"L````I10``#P```%5%```0````944`
M``0```!V10``!P```'M%```%````@T4```$`````````MP```)H````\````
MY0```*<```!T````````````````````B@````````"6````4````'<`````
M````40```(X```!G````$@```',``````````````"@```"O````D````!T`
M```)````#P```'\``````````````#\```!N````&P```$L```!F````````
M`/8`````````*@```"T`````````6P````````!4````]0````````")````
M20```'T`````````J@```$4```"L````>P```/,`````````S@```&T````U
M````[P````````"N````YP```(8````S````DP```*T```!:`````````/(`
M``!@````0P```'8`````````3```````````````1P`````````@````.@``
M`#D```#:`````````#@````:````,@```(L```!-``````````````!C````
M;P```*L```#N````X````&$```````````````````!D`````````,P```!>
M````T````"X```!R````Z```````````````-@```-T```"C````VP```(P`
M`````````````-,```!7````%````,D```#4`````@```)D````$````$```
M`!X```#>````M0``````````````H@```$H```#/````(0```)4`````````
M6````"8````*````+P```"4````^````N0```($`````````&0```&@```#Z
M````:@```-4```"T`````````+$````7````Y@````````"2`````````%,`
M``!&````WP```*4`````````7`````````!9````G````,L`````````````
M`*D```#(````[````"(`````````90```+(```#M````?@```&P`````````
MX@```,0````3``````````````````````````````"V`````````((```#J
M````\0```.L```"1````<0```)T``````````````-P```"P````%0```*``
M``#2````%@```,T`````````O@```+@```#T````AP```)X```#%````````
M`$$`````````EP`````````Q````C0```'@```"_`````````.,`````````
M#@```%T```#1````0@`````````[````X0```'4``````````````$@```!2
M````3P```(\``````````````'`````(````#0```#0```!6````(P``````
M`````````````%4```#9````^0```/@```#8`````````)\````1````UP``
M`+P```#'````U@```*$````]````*P```*@````<````!0````,````+````
MQ@```+,`````````O0````````#!`````````,H`````````\````(`````8
M````F````+H`````````:P```````````````````'P```!Y````0```````
M``!Z````)````.0```"#````Z0````````"%````8@```#`````?````]P``
M````````````#````(@````I````NP```)L`````````1`````````##````
MA````#<```"D````P````"<`````````E````&D````&````!P```$X`````
M`````````"P```#"````I@```%\`````("@E<R!D87ES(&%G;RD`("AT;V1A
M>2D`("AY97-T97)D87DI`"5S("T@3F]T:6-E`"5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@5&5R;7,@;V8@06=R965M96YT
M`"5S(&ES(')E<75I<F5D`#(T(&AO=7)S`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32]030!!
M9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E
M<CH`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@
M0F]O:P!!9&UI;FES=')A=&EO;@!!9',`06QI87,`06QL($=R;W5P<P!!;&P@
M4&5R;6ES<VEO;G,`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T<FEB=71E
M<P!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BX`079A:6QA8FQE(&9I96QD<SH`0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)I<G1H
M9&%Y`$)O;&0`0F]O:VUA<FMS`$--4P!#4D,`0V%L96YD87(`0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N8V5L`$-E;&P@4&AO;F4`0V]L
M;W(@4&EC:V5R`$-O;6EC<P!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;W!Y
M`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#=70`1$0`1&%I;'D`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&ES<&QA>2!/<'1I;VYS`$5D:70`16UA:6P`16UA:6P@061D<F5S<P!%;6%I
M;"!A9&1R97-S97,@;75S="!M871C:"X`16UP='D@<F5S=6QT+@!%<G)O<@!%
M=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`
M17AA;7!L92!V86QU97,Z`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%X`$9I;&4@0V]U;G0Z("5S(&9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M
M90!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&;W)U;7,`
M1G5L;"!.86UE`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P<P!'=65S="!0
M97)M:7-S:6]N<P!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&5L
M<`!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$E-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$EM<&]R=&5D(&9I96QD
M.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$ET86QI8P!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG
M:'0`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+
M97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$QA
M;F=U86=E`$QI<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`3&]G(&EN`$QO9R!O=70`34T`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-86EL`$UA=&-H:6YG(&9I96QD<P!-96UB97)S
M`$UE;G4@;6]D93H`365S<V%G90!-971H;V0`36EM92!4>7!E`$UO9&EF:65D
M($1A=&4`36]N=&AL>0!->2!!8V-O=6YT`$YA;64`3F5T=V]R:P!.979E<@!.
M97<@57-E<FYA;64@*&]P=&EO;F%L*0!.;P!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL
M92!61E,N`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A
M;'5E<P!.;W1E<P!/2P!/<'1I;VYS`$]R9&5R960@3&ES=`!/=&AE<B!);F9O
M<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!02%`@4VAE;&P`4&%S<W=O<F0`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W1E`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&AO;F4`
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4F%T:6\`
M4F5A9`!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!U<V5R.B`E<P!2;VQE`%-13"!3:&5L
M;`!34T@`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE
M<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4VAO=P!3:7IE`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-U8FUI=`!3=6-C97-S`%1A<VMS`%1E>'0@3VYL>0!4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E
M<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@;&]C871I
M;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#
M<GEP=%]P9W`Z.B!C;&%S<RX`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4
M:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@
M9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1I;64@5')A8VMI;F<`5&ET;&4`55),`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92X`56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F1E<FQI;F4`57!D871E`%5P9&%T92`E<P!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%9A8V%T:6]N`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!787)N:6YG`%=E
M96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=O<FL@061D<F5S
M<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P
M9&%T92X`66]U<B!);F9O<FUA=&EO;@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!R96UO
M=&4@<V5R=F5R<SH`6VQI;F4@)7,@;V8@)7-=`&9I;&4`=6YN86UE9`!V0V%R
M9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G,*4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E
M.B`R,#`R+3$Q+3$Y(#(P.C0T+3`U,#`*3&%S="U4<F%N<VQA=&]R.B!-:7)O
M<VQA=B!096YD978@/&UI<F]`8WEB97)S:&%D92YU<SX*3&%N9W5A9V4M5&5A
M;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U,0I#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*"5S(.3MZ"#MX.?@Y"D`("CD
M[>7Q*0`@*.+WY?#@*0`E<R`M(,?@X>7KY>;JX``E<R#.X?'K\^;BX/GH(.[O
MY?#@]NCH("T@S^[RXOKPYN3E[>CE`"5S(-/QZ^[BZ/\@[^X@T>_N\.#G\^SE
M[>CE\NX`)7,@[>7NX?7NY.CL`#(T(/?@\>``Q^`@Y.`@ZO#H[_+H\.#RY2#O
MZ/'L[B#E(.WE[N'U[N3H["#O\^'KZ/?E[2!01U`@ZNO^]RX`Q^`@Y.`@[_#N
MXN7PZ/+E(._NY._H\>#M[B#OZ/'L[B#E(.WE[N'U[N3H["!01U`@ZNO^]RX`
MQ^`@Y.`@Y.7J\.CO\NCPX/+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH
M]^7M(.KK_O<L(.OH]^7M(.KK_O<@Z"#JZ_[W[N+@(/3PX.?@+@#'X"#DX"#O
M[N3OZ/CE\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@
MZ^CWY>T@ZNO^]R#H(.KK_O?NXN`@]/#@Y^`N`,?@(.3@(.KPZ._RZ/#@\N4@
M[^CQ[.X@Y2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4TU)344@ZNO^]RX`04TO4$T`
MQ.[AX.+_[>4@[>`@[>[BX"#C\//OX`#$[N'@XO_MY2#MX"#M[N+H(._PX.+@
M`,3NX>#BZ"#M[N(@[^[R\.7AZ/+EZSH`Q.[AX.+_[>7R[B#MX"#O[O+PY>'H
M\N7KZ"#E(.?@X?#@[>7M[BX`P.3PY?$`P.3PY?'E[2#AY>OEYNWHZ@#`Y.SH
M[>CQ\O#H\.#MY0#$[N'@XNKH`,_QY>+D[NWH[`#"\>CWZN@@X_#S[^@`PO'H
M]^KH(._PX.+@`,+ZXN7DY>W@\N`@\?+NZ>WN\?(@[>4@Y2#D[N_S\?+H[.`N
M`-#@Y^SE\"#MX"#@\/7HXNWH_R#TX.GK`,CLY2#MX"#@\/7HXN``Q.`@\>4@
MZ/'JX"#KZ"#O[O+B^O#FY.7MZ.4@[_#EY.@@[N'QZ_/FXN#YZ/+E(.[OY?#@
M]NCH/P##\.7XZN`@[_#H(.CG\O#HXN#MY2#MX"#MY?'Z^>7Q\N+SXN#YX"#C
M\//OX"X`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>4@[>7Q^OGE\?+B\^+@^>@@
M[_#@XN`N`,/PY?CJX"#O\.@@\.7DX.KRZ/#@[>4@[>`@[>7Q^OGE\?+B\^+@
M^>@@[_#@XN`N`,#R\.CA\_+H`,/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H_P#(
MY.7M\NCTZ.K@]NC_\N`@X>7XY2#N\O7B^O#KY>W@(.[R(%)!1$E54R#Q^O#B
M^O#@+@#-X.OH]^WH(._NZ^7RX#H`S>7BX.OHY.W@(&ME<F)E<F]S("#OX/#N
MZ^`N`,WEXN#KZ.3M[B!K97)B97)O<R#O[O+PY>'H\N7K\>KN(.CLY2X`T.[F
MY.7M(.3E[0#3Y.7AY>OE[>@`SO+LY?+JZ`!#35,`0U)#`,K@Z^7MY.#P`,/P
MY?CJX"#O\.@@\>+Z\.?BX.WE(/$@[.7IZR#Q^O#B^O`Z("5S`,[RZN#FZ`#,
M[N'HZ^7M(/+EZ^7T[NT`R.?AZ/#@[>4@[>`@]N+_\@#*[NSHZO'H`,KN[._@
M[>C_`,_N\N+Z\.3E\N4@[^#P[NO@\N``Q.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@
M\?KPXOKP(.'E^.4@[O+JX.?@[2X`RN[OZ/#@Z0##\.7XZN`@[_#H(%!'4"#J
M\.CO\NCPX.WE\NX@[>`@[^CQ[.XN`,/PY?CJX"#O\.@@4$=0(._NY._H\>+@
M[>7R[B#MX"#OZ/'L[BX`P_#E^.K@(._PZ"#DY>KPZ._RZ/#@[>7R[B#MX"!0
M1U`@Y.#M[>@N`,WEZN[PY>KRY>T@96UA:6P@X.3PY?$@[>`@[^[K\_?@\N7K
M_RX`P_#E^.K@(._PZ"#O[NOS]^#BX.WE\NX@[>`@[_/AZ^CW[>C_(.KK_O<@
M[O(@ZNO^]RWQ^O#B^O#@+@#-Y>+ZY^SNYNWN\?(@Y.`@\>4@[O+B[O#H(,[A
M\>OSYN+@^>A?Y^#DX/?H(.SNY//K("5S(`#HY_#EYN@`Q,0`Q>;EY.WEXNWN
M`,CDY>WRZ/?M[O'R(._N(._NY/#@Y^'H\.#MY0#(Y_+PZ.D`Q.7RX.GKZ/+E
M(.'_]>`@\.7CZ/'R\.CPX.WH(.?@(.#D[.CMZ/'R\.#R[O#@+@#$Z/'OZ^7I
M(,[O]NCH`-#EY.#J]NC_`,_H\>SN`,5M86EL(.#D\.7Q`$5M86EL(.#D\.7Q
MZ/+E(/+P_^'BX"#DX"#Q^N+OX.3@\BX`S_#@Y^7M(/#EY_/K\N#R+@##\.7X
MZN``PO'EZN@@,34@[.CM\_+H`,+QY>KH(#,P(/'EZO/MY.@`PO'EZN@@-2#L
MZ.WS\N@`PO'_ZNX@Z^[CXN#MY0#-X"#B\>7JZ"#O[NONXNCM(/?@\0#"\?_J
MX"#LZ.WS\N``S_#H[.7P[>@@\?+NZ>WN\?+H.@#-Y>+ZY^SNYNWN\?(@Y.`@
M\>4@Y^#PY>3_\B#O\.7TY?#E[?;HZ/+E+@#-Y>+ZY^SNYNWN\?(@Y.`@\>4@
M[O'Z^>7Q\N+H(.+P^N?JX"#Q($Q$05`@\?KPXOKP+@##\.7XZN`@[_#H(/'B
M^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z\"X`U.#J\0#!\.[I(/3@Z>ONXN4Z("5S
M(/3@Z>L`P?#NZ2#TX.GK[N+E.B`E<R#TX.GKX`#4X.GK(.SE[>#FY?``R.SE
M(.W@(/3@Z>L`R.?O\.#YX.WE\NX@[>`@].#IZ^[BY2#MY2#QY2#O[N3D^O#F
MX"X`U.CK\OKP`-3N\//LZ`#([.4@[>`@].#IZP#`Y.SH[>CQ\O#H\.#MY2#M
MX"#C\//OZ`##\//OZ`#/\.#BX"#GX"#C[O'RZ`!(5%10(.CDY>WRZ/3HZN#V
MZ/\@[>4@Y2#MX.SE\.7MX"X`S^[L[OD`S>#WX.ON`,3N[.#XY>T@X.3PY?$`
MQ.[LX/CE[2#RY>OE].[M`$AO<F1E`,/PY?CJX"#O\.@@\?KGY.#BX.WE(.W@
M($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`,/PY?CJX"#O\.@@Z.?R\.CBX.WE
M(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S`,/PY?CJX"#O[O#@Y.@@ZN+N
M\N`@[_#H(/'ZY^3@XN#MY2#MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<P!)
M4"#@Y/#E\>`@[>4@Y2#B(._NY^+NZ^7MZ/\@0TE$4B#AZ^[J+@#1X.SN(.CJ
M[NWH`,CJ[NWH(/$@\N7J\?(`R.SO[O#RZ/#@[>X@[^[KY3H@)7,`R.SO[O#R
MZ/#@[>@@[^[KY?+@.@#(Y^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N
M`,W@ZNON[>7MZ`#O^NOM[B#O[N3PX.+M_^+@[>4`Z__B[B#O[N3PX.+M_^+@
M[>4`Y/_Q[>X@[^[D\.#B[?_BX.WE`$ME<F)E<F]S(/'Z\.+Z\.`@[O+UXOKP
MZ^@@Z.3E[?+H].CJX/;H__+@+@#*Z_[WX"#BY??E(/'Z^>7Q\N+SXN`@XB#O
M\^'KZ/?MZ/\@ZNO^]_'Z\.+Z\"X`Q>?HZ@#/[NSN^2#RY>SH`-'OZ/'ZZN`@
M\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M+@#"]>[D`,CG]>[D`,S,`$U3+51.
M148@[_#HZO#E[^7MZ/_R(/3@Z>L@[>4@\?KD^O#FX/CE(.3@[>WH+@#/[OG@
M`-'ZXN_@Y.#YZ"#O[NOE\N``U^OE[>[BY0#"Z.0@[>`@[.7M_O+N.@#/Z/'L
M[@#,Y?+NY`!-:6UE(/+H[P#$X/+@(.W@(._P[NSE[?_MY0#,Y?'E]^WN`,SN
M__+@(,_N^>``R.SE`,SPY>;@`,WHZN[CX`#-[N+N(._N\O#EX>CRY>OQZNX@
MZ.SE("CN[_;H[NW@Z^WN*0#-Y0#-_^S@(.?@Y.#DY>W@(.KN[?3HX_/PX/;H
M_R#GX"!&5%`@5D93+@#-_^S@(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!3
M44P@5D93+@#-_^S@(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!344PM1FEL
M92!61E,N`,W_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($E-05`@Z.3E[?+H].CJ
MX/;H_RX`S?_LX"#GX.3@Y.7MX"#OX/#NZ^`@Y^`@2V5R8F5R;W,@Z.3E[?+H
M].CJX/;H_RX`S?_LX"#J[NWTZ./S\.#VZ.[M[>`@Z.WT[O#LX/;H_R#GX"!3
M34(@Z.3E[?+H].CJX/;H_RX`POKP[>#RZ/+E(.3@[>WH(.WE(/'@(%A-3`#-
M_^S@(/'R[NGM[O'RZ`#!Y>OEYNKH`,[*`,[O]NCH`,_NY/#EY.7M(/'OZ/'Z
MZ@#$\//CX"#H[?3N\.S@]NC_`,_PX.+@(.W@(._PZ/+EYN#RY>O_`%!'4"!3
M:&5L;`#/X/#NZ^``S^#P[NO@.@#/X/#NZ^`Z(`#-Y>KN\.7J\NW@(._@\.[K
MX"X`PNSZZNWH`,3@(/'E(.CGXOKP^.+@\B#KZ"#NX?'K\^;BX/GH\N4@[N_E
M\.#VZ.@@[_#H(,+U[N0_`,_PX.+@`,#D[.CMZ/'R\.CPX.WE(.W@(._PX.+@
M\N``TN7KY?3N[0#,[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CMX"X`RNO^
M]^[BX"#DXN[IZN`@[_/AZ^CWY>TO]^#Q\N7M(.KK_O<@[>4@X>7XY2#CY>WE
M\.CPX.W@+@#*[N7TZ/;HY>WR`-?E\N7MY0#(\>K@\N4@Y.`@Z.?R\.CE\N4@
M)7,@Z^@_(-+@Y^@@[N_E\.#VZ/\@[>4@[.[FY2#DX"#QY2#B^O#MY2#MX.?@
MY"X`P.3PY?$@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
MS_#E[.#U[>@`S_#E[.#U[>@@[^[R\.7AZ/+EZSH@)7,`T.[K_P!344P@4VAE
M;&P`4U-(`,CGX>7PY?+E(./P\^_@(.?@(.3NX>#B_^WE`,CGX>7PY?+E(.WN
MXB#O\.CRY>;@\N7K(.W@(./P\^_@`,CGX>7PY?+E(/'Z\.+Z\`#(Y^'E\.@@
M[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY0#(Y^'E\.7RY2#$X/+@(/#@Y^3EZ^CR
MY>LZ`,CGX>7PY?+E(/3N\.S@\B#GX"#$X/+@\N`Z`,CGX>7PY?+E(/3N\.S@
M\B#GX"#7X/'@.@#(Y^'E\.7RY2#DXN4@\?KB[^#DX/GH(._NZ^7RX#H`R.?A
MY?#E\N4@XN#XX/+@(/'UY>S@(.?@(/;BY?+NXN7RY2X`R.?AY?#E\N4@[_#E
MY._N]^CRX.WH__(@[O(@PN#Q(.7GZ.HZ`,?@Y.#I\N4@PN#XY?+N(.W@]^#K
M[>X@[_#HZ^[FY>WHY2P@\?7E[.`@Y^`@]N+E\N[BY2P@[N_PY?'M_^+@[>4@
M[>`@\?+PX.WH]N#RX"#H(.3P\^/H(.[O]NCH(.?@(.3H\>_KY?\N`,_NZN#G
MXN#MY0#0X.?LY?``POKBY>;DX.WE(.W@(/'OY?;HX.OMZ"#QZ.SB[NOH`,CG
M[_#@\N@`T_'OY?4`Q^#DX/?H`-'@[.X@\N7J\?(`S_#HZO#E[^7MZ/_R(%!'
M4"#O[N3OZ/$@Y2#MY>[A]>[DZ.P@Y^`@Y.`@\>4@[_#NXN7PZ"#O[N3OZ/'@
M[>[R[B#OZ/'L[BX`RO#H[_+H\.#MY?+N(.CGZ/'JXN`@ZO#H[_+H\.#MX"!W
M96(@XO#ZY^K@+@#,Y?'R[N_NZ^[FY>WHY?+N(.W@($=N=5!'(/3@Z>O@(/+P
M_^'BX"#DX"#A^N3E(.3@Y.7M;R#MX"!#<GEP=%]P9W`Z.B!C;&%S`,_P[N/P
MX.S@\N`L(.KN__+N(/'K\^;H(.?@(._NZN#GXN#MY2#MX"#R[N?H(/+H[R#D
MX.WMZ"`H)7,I(.WE(.'E^.4@[O+J\.CRX"#B(/'H\?+E[.#RX`#-_^S@(.3B
M[NGJZ"P@ZN[H\NX@Y.`@X?KDX/(@[^[JX.?@[>@@XB#KZ.WH__+@+@#([.`@
M\N+Z\.3E(.SM[N/N(/'H[.+NZ^@@XB#R[N+@(._NZ^4N(,+ZXN7KZ"#Q\N4@
M)7,@\>CLXN[KX#L@\O#_X>+@(.3@(.+ZXN7DY?+E(._N+>S@Z^KN(.[R("5S
M+@##\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@.B`E<R#MY2#AY?CE
M(.CG[_#@\N7M+@#([.#XY2#O\.[AZ^7L(._PZ"#HY^_PX/G@[>7R[B#MX"#T
MX.GKX"X@)7,@Y2#O[BWC[NO_["#N\B#LX.KQZ.S@Z^WN(.3N[_/Q\NCLZ/\@
M\.#G[.7P("@E9"#AX.GRX"DN`,/PY?CJX"#O\.@@Z.?O\.#YX.WE\NX@[>`@
M].#IZ^`N("5S(.'E^.4@\>#L[B#N\O?@\?+H(.CG[_#@\N7M+@##\.7XZN`@
M[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KRZ"X`TN[BX"#MY2#E(.+@
MZ^CDY>T@<F%R(.#P]>CB+@#2[N+@(.WE(.4@XN#KZ.3E[2!Z:7`@].#IZRX`
MTN[BX"#O[NOE(.4@[>7NX?7NY.CL[BX`TN[BX"#O[NOE(.SNYN4@Y.`@\?KD
M^O#FX"#QX.SN(/;EZ^@@]^CQZ^`N`-+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KP
MYN`@\>#L[B#WZ/'KX"#H(.3B[N7R[O?HY2X`TN[BX"#O[NOE(/+P_^'BX"#D
MX"#E(.?@[^7RX/\@Z.OH(.CM\N7PXN#K(/#@Y^3EZ^7M(/'OZ/'ZZB#O\.[L
MY>WKZ.+H`-+@Y^@@].[P[.`@XN7WY2#AY?CE(.[A\.#A[O+E[>`N`-+NXN`@
M]^CQZ^X@\O#_X>+@(.3@(.4@[^[MY2#EY.CMZ/;@+@#2[N?H(/'Z\.+Z\"#M
MY2#L[N;E(.3@(.3EZN[L[_#E\>CPX"!Z:7`@Z"!G>FEP(/3@Z>ONXN4N`-+@
MY^@@\?+NZ>WN\?(@\O#_X>+@(.3@(.4@]^CQZ^XN`,_P[O'KY>3_XN#MY2#M
MY2#B\.7LY0#$Z_KF[>[Q\@!54DP`S>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q
M(%-13"#Q^O#B^O`N`,/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7Q
MZ/#@[2#@\/7HXBX`P_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@
M[^K@+@##\.7XZN`@[_#H(._PY>+NY.`@[>`@\N[GZ"!7;W)D(.3NZO/LY>WR
M`,_NY/?E\/+@[>@`SN_PY?'MZ`#.[_#E\>WH("5S`,#D[.CMZ/'R\.CPX.WE
M(.W@(._N\O#EX>CRY>OH\N4`R.SE`,CLY3H`R.SE.B``S^[R\.7AZ/+EZ^@@
MXB#QZ/'RY>S@\N`Z`,+@ZN#M]NC_`,/PY?CJX"#O\.@@[_#NXN7PZN#RX"`M
M(/+NXN`@[^CQ[.X@[.[FY2#DX"#E(.'HZ^X@[^[D[_#@XN7M[BX`PNWH[.#M
MZ.4`T>7D[.CW[>X`Q.[A\.4@Q.[XZ^@@XB`E<P#$[N'PY2#D[OCKZ"P@)7,`
MR.?AY?#E\N4@[_#HZ^[FY>WHY?+N+"#J[N7R[B`E<R#DX"#O[NK@YN4@\>OE
MY"#B]>[D+@#!Z.?MY?$@X.3PY?$`P>CG[>7Q(/+EZ^7T[NT`P\,`P^[DZ/CM
M[@#$X`#-Y2#B^N+EY.[U\N4@XN#KZ.3E[2!E;6%I;"#@Y/#E\2X`TO#_X>+@
M(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@Z.?R\.CBX.WE+@#2\/_AXN`@
MY.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY2X`TO#_X>+@(.3@
M(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@[N_PY?'M_^+@[>4N`,CM].[P[.#V
MZ/\@Y^`@PN#Q`,+@^.C_\B#HY.7M\NCTZ.K@]NCN[>7M(.3PX.GBY?`@[>4@
M[^[DY/KPYN`@\>_H\?KJ(.W@(._N\O#EX>CRY>OH\N4L(.CKZ"#RX.?H(.+Z
MY^SNYNWN\?(@Y2#GX.'PX.WE[>`N`,+@^.CRY2#J[NWTZ./S\.#VZ.[M[>@@
M[N_VZ.@@X?_UX"#NX>WNXN7MZ"X`PN#XZ/+E(/'Z\.+Z\.@Z`%OKZ.WH_R`E
M<R#N\B`E<UT`].#IZP#AY><@Z.SE`'9#87)D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M8F=?0D<O:&5L<"YX;6P`````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S,S(P`#$P-3$U-#,Q,#8R`#`R,#(U-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/WAM;"!V97)S:6]N/2(Q
M+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]B9U]"1R]H96QP+GAM
M;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$V(&IA;B!%>'`@)"`M+3X*/&AE
M;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE
M/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A
M;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I
M;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT
M('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E
M(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N
M9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R
M;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O
M9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C
M=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@
M82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E
M=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N
M=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I
M82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C
M:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P
M86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W
M;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A
M=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"
M87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F
M('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B
M87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B
M87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE
M(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN
M=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L
M:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I
M<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B
M969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U
M;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E
M9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W
M:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VMO7TM2
M+P``````````````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,3`V,@`P,38V-34`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O:V]?2U(O3$-?34534T%'15,O````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R`#`R,#0T,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]K;U]+4B],0U]-15-304=%
M4R]H;W)D92YM;P``````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3$P-34`,3`U
M,34T,S$P-C(`,#(R,3`S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-X2!)4`````BP$``!P```!T#```'0(``,P8````````
M0"$```\```!!(0``"````%$A```+````6B$```P```!F(0``*````',A```2
M````G"$```@```"O(0``!0```+@A```1````OB$```,```#0(0``#P```-0A
M```(````Y"$```@```#M(0``&0```/8A```'````$"(```P````8(@``#@``
M`"4B```%````-"(```4````Z(@``"@```$`B```#````2R(```X```!/(@``
M#P```%XB```?````;B(```4```".(@``.0```)0B```&````SB(``!$```#5
M(@``"@```.<B```0````\B(```@````#(P``!`````PC```&````$2,``!$`
M```8(P``!P```"HC```$````,B,```8````W(P``#0```#XC```3````3",`
M``@```!@(P``!@```&DC```5````<",```<```"&(P``"@```(XC```/````
MF2,```T```"I(P``#P```+<C```-````QR,```D```#5(P``!@```-\C```&
M````YB,```X```#M(P``!0```/PC```J`````B0``!,````M)```#````$$D
M```0````3B0``!$```!?)```!0```'$D```%````=R0```8```!])```!P``
M`(0D```0````C"0```0```"=)```#@```*(D```I````L20```8```#;)```
M#0```.(D```.````\"0```T```#_)````P````TE```-````$24```(````?
M)0``!0```"(E```$````*"4```X````M)0``"````#PE```/````124```\`
M``!5)0``!P```&4E```0````;24```8```!^)0``"P```(4E```-````D24`
M``H```"?)0``&0```*HE```6````Q"4``!0```#;)0``"P```/`E```O````
M_"4```D````L)@``#P```#8F```F````1B8``$,```!M)@``"````+$F```+
M````NB8```0```#&)@``%P```,LF```1````XR8```H```#U)@```@`````G
M```%`````R<```D````))P``#0```!,G```.````(2<``!@````P)P``!0``
M`$DG```0````3R<``!````!@)P``#P```'$G```+````@2<```\```"-)P``
M#````)TG```/````JB<```X```"Z)P``"````,DG```>````TB<``"$```#Q
M)P```P```!,H```(````%R@```P````@*```!P```"TH```*````-2@```8`
M``!`*```!````$<H```'````3"@```(```!4*```!@```%<H```$````7B@`
M`!$```!C*```(@```'4H```,````F"@```H```"E*```!0```+`H```/````
MMB@``!(```#&*```"P```-DH```I````Y2@``"0````/*0``)@```#0I```2
M````6RD```H```!N*0``#P```'DI```0````B2D```X```":*0``"0```*DI
M```*````LRD``!(```"^*0``$````-$I```1````XBD```\```#T*0``%```
M``0J```,````&2H```P````F*@``#P```#,J```5````0RH``"D```!9*@``
M*@```(,J```F````KBH``"<```#5*@``*0```/TJ```J````)RL``!$```!2
M*P``$@```&0K```3````=RL``!0```"+*P``%@```*`K```7````MRL``!``
M``#/*P``$0```.`K```3````\BL``!(````&+```!@```!DL```'````("P`
M``4````H+```%@```"XL```$````12P```0```!*+```!P```$\L```.````
M5RP```P```!F+```#````',L```-````@"P``!(```".+```#P```*$L```(
M````L2P```X```"Z+```%@```,DL```1````X"P```8```#R+```!````/DL
M```0````_BP``!H````/+0``!@```"HM```'````,2T```L````Y+0``$P``
M`$4M```3````62T``!,```!M+0```@```($M```$````A"T```T```")+0``
M!0```)<M```&````G2T```\```"D+0```P```+0M```*````N"T```L```##
M+0``!P```,\M```&````URT```H```#>+0``!P```.DM```)````\2T```<`
M``#[+0``!`````,N```'````""X```4````0+@``$P```!8N```$````*BX`
M``(````O+@``,P```#(N```S````9BX``#@```":+@``!````-,N```%````
MV"X```@```#>+@``$0```.<N```.````^2X```<````(+P``'P```!`O```'
M````,"\```X````X+P``#````$<O```,````5"\```4```!A+P``$0```&<O
M```'````>2\```@```"!+P``%0```(HO```%````H"\``!0```"F+P``!```
M`+LO```'````P"\``!X```#(+P``%````.<O```%````_"\```8````",```
M*`````DP```I````,C````<```!<,```(0```&0P```.````AC```!,```"5
M,```%P```*DP```+````P3````4```#-,```$0```-,P```%````Y3```!(`
M``#K,```!````/XP```.`````S$```X````2,0``!0```"$Q```2````)S$`
M``0````Z,0``#````#\Q```&````3#$``&D```!3,0``&@```+TQ```7````
MV#$``!<```#P,0``&P````@R```?````)#(``!,```!$,@``"0```%@R```E
M````8C(``"````"(,@``)````*DR```@````SC(```0```#O,@``$````/0R
M```<````!3,``"@````B,P``!P```$LS```3````4S,``!<```!G,P``"@``
M`'\S```,````BC,```D```"7,P``#0```*$S```+````KS,```<```"[,P``
M!@```,,S```)````RC,```<```#4,P``!P```-PS```+````Y#,``!````#P
M,P``$`````$T```%````$C0```0````8-```"0```!TT```*````)S0``!\`
M```R-```&P```%(T```^````;C0``",```"M-```'P```-$T```]````\30`
M`"$````O-0``'````%$U```%````;C4``!````!T-0```@```(4U```2````
MB#4```,```";-0``$````)\U```#````L#4``"\```"T-0``(````.0U```D
M````!38``"4````J-@``(````%`V```F````<38```D```"8-@``#````*(V
M```7````KS8```X```#'-@``#0```-8V```:````Y#8```<```#_-@``"P``
M``<W```3````$S<``!,````G-P``#````#LW```(````2#<``!0```!1-P``
M#@```&8W```0````=3<```<```"&-P``!P```(XW```&````EC<```<```"=
M-P``#0```*4W```+````LS<``"````"_-P``'````.`W```%````_3<``!(`
M```#.```"@```!8X```&````(3@```P````H.```"@```#4X```"````0#@`
M``8```!#.````P```$HX``!%````3C@``!D```"4.```10```*XX```P````
M]#@``"8````E.0``)0```$PY```P````<CD``!(```"C.0``$P```+8Y```0
M````RCD```D```#;.0``<P```.4Y```K````63H``!<```"%.@``%@```)TZ
M```/````M#H``$````#$.@``'P````4[```2````)3L``!`````X.P``$P``
M`$D[```=````73L```\```![.P``#P```(L[```+````FSL```4```"G.P``
M%````*T[```(````PCL```\```#+.P``"````-L[```/````Y#L``!0```#T
M.P``!@````D\```$````$#P```<````5/```!@```!T\```'````)#P```4`
M```L/```4@$``#(\```,````A3T```<```"2/0``!P```)H]```'````HCT`
M`!<```"J/0``%0```,(]```'````V#T```D```#@/0``"P```.H]```$````
M]CT``!,```#[/0``#P````\^```+````'SX``!0````K/@``!````$`^```&
M````13X```0```!,/@``"@```%$^```$````7#X```4```!A/@``"0```&<^
M```(````<3X```<```!Z/@``%P```((^```#````FCX``!<```">/@```P``
M`+8^```,````NCX```0```#'/@``"0```,P^```$````UCX```0```#;/@``
M!````.`^```)````Y3X```0```#O/@``!````/0^```$````^3X```L```#^
M/@``#`````H_```$````%S\```0````</P``$@```"$_```$````-#\```8`
M```Y/P``!P```$`_```'````2#\```<```!0/P``!P```%@_```&````8#\`
M``8```!G/P``!````&X_```.````<S\```0```""/P``%0```(<_```4````
MG3\```<```"R/P``#0```+H_```+````R#\```0```#4/P```P```-D_```&
M````W3\```0```#D/P``"0```.D_```$````\S\```0```#X/P``*P```/T_
M```&````*4````L````P0```"@```#Q````+````1T````8```!30```!@``
M`%I````"````84````0```!D0```!````&E````)````;D````0```!X0```
M!````'U````(````@D````0```"+0```"P```)!````$````G$````<```"A
M0```!P```*E````'````L4````P```"Y0```#````,9````)````TT````4`
M``#=0```*@```.-````(````#D$```D````700``)P```"%!``!#````24$`
M``@```"-00``"P```)9!```$````HD$```P```"G00``#@```+1!```'````
MPT$```(```#+00``!@```,Y!```(````U4$```D```#>00``"P```.A!```-
M````]$$```0````"0@``"0````="```)````$4(```@````;0@``"P```"1"
M```)````,$(```0````Z0@```P```#]"```-````0T(```8```!10@``$P``
M`%A"```3````;$(```0```"`0@```P```(5"```+````B4(```0```"50@``
M"0```)I"```&````I$(```0```"K0@``!````+!"```$````M4(```0```"Z
M0@``!@```+]"```&````QD(``!X```#-0@``!P```.Q"```+````]$(```4`
M````0P``!@````9#```)````#4,```4````70P``$P```!U#```.````,4,`
M`!,```!`0P``#@```%1#```&````8T,```T```!J0P``#````'A#```.````
MA4,```@```"40P``"0```)U#```/````IT,```P```"W0P``$````,1#```(
M````U4,``!````#>0P``"0```.]#```'````^4,```P````!1```#@````Y$
M```7````'40``!<````U1```%P```$U$```7````940``!@```!]1```&```
M`)9$```,````KT0```P```"\1```#````,E$```,````UD0```X```#C1```
M#@```/)$```,`````44```P````.10``#@```!M%```.````*D4```@````Y
M10```P```$)%```$````1D4``!0```!+10```P```&!%```#````9$4```0`
M``!H10``"P```&U%```)````>44```D```"#10``"P```(U%```(````F44`
M``\```"B10``!````+)%```1````MT4``"````#)10``$P```.I%```(````
M_D4```0````'1@``"P````Q&```;````&$8```8````T1@``"````#M&```/
M````1$8```T```!41@``"P```&)&```0````;D8```(```!_1@``!````()&
M```0````AT8```,```"81@``"````)Q&```-````I48```,```"S1@``"0``
M`+=&```)````P48```8```#+1@``!@```-)&```(````V48```0```#B1@``
M"P```.=&```)````\T8```0```#]1@``"`````)'```(````"T<```T````4
M1P``!````")'```&````)T<``",````N1P``'````%)'```A````;T<```T`
M``"11P``!````)]'```$````I$<```<```"I1P``!P```+%'```$````N4<`
M`!$```"^1P``"````-!'```+````V4<```D```#E1P``!````.]'```$````
M]$<```D```#Y1P``!`````-(```$````"$@``!D````-2```!@```"=(```3
M````+D@```0```!"2```!@```$=(```3````3D@```D```!B2```"````&Q(
M```$````=4@``"$```!Z2```'@```)Q(```(````NT@``!````#$2```"0``
M`-5(```)````WT@``!````#I2```#P```/I(```)````"DD``!$````420``
M!@```"9)```,````+4D```0````Z20``!P```#])```'````1TD```,```!/
M20``$@```%-)```$````9DD```T```!K20``!````'E)```[````?DD``!,`
M``"Z20``#@```,Y)```.````W4D``!D```#L20``'P````9*```8````)DH`
M``,````_2@``#@```$-*```.````4DH```X```!A2@``$````'!*```$````
M@4H```T```"&2@``!@```)1*```:````FTH```0```"V2@``#0```+M*```.
M````R4H```<```#82@``!P```.!*```'````Z$H```@```#P2@``"P```/E*
M```$````!4L```0````*2P``"`````]+```$````&$L```0````=2P``!@``
M`")+```'````*4L```<````Q2P``!````#E+```&````/DL```0```!%2P``
M"0```$I+```8````5$L``!X```!M2P``+0```(Q+```>````NDL``!\```#9
M2P``/P```/E+```I````.4P``!@```!C3```!````'Q,```-````@4P```D`
M``"/3```#@```)E,```"````J$P``!$```"K3````P```+U,```M````P4P`
M`!X```#O3```&P````Y-```D````*DT``"@```!/30``(0```'A-```$````
MFDT``!$```"?30``$````+%-```$````PDT```0```#'30``%0```,Q-```)
M````XDT```D```#L30``#0```/9-```0````!$X```\````53@``"````"5.
M```0````+DX```D````_3@``"0```$E.```'````4TX```0```!;3@``!```
M`&!.```$````94X``!8```!J3@``#@```(%.```7````D$X``!<```"H3@``
M!````,!.```)````Q4X```D```#/3@``!0```-E.```*````WTX```T```#J
M3@```@```/A.```$````^TX```(`````3P``/0````-/```4````04\``#X`
M``!63P``*0```)5/```E````OT\``"4```#E3P``+`````M0```,````.%``
M``H```!%4```!````%!0```%````55```',```!;4```)P```,]0```,````
M]U````P````$40``"@```!%1```?````'%$``!8````\40``#0```%-1```/
M````85$```P```!Q40``$P```'Y1```.````DE$```8```"A40``"0```*A1
M```&````LE$```X```"Y40``"@```,A1```.````TU$```H```#B40``#0``
M`.U1```,````^U$```,````(4@``!`````Q2```&````$5(```0````84@``
M"0```!U2```%````)U(```$```#W````;P$```````!3`0```````%H```"L
M````%P$``"``````````/P````H```#+````C0```&<```#D````+`$``-T`
M````````:0```+$```!Z````I`````````#Y````A@```&(```!8`0``$P$`
M`#@````````````````````?`0``,P$``.8```#[````LP````````"\````
M`````*,```#>`````````#4````^`````````!(!``""`0``+P```%L!``!$
M`0``7P```'P!``".``````````````#<````````````````````?@$``%T`
M``````````````````````````````````"F````R````%H!``"I````2@``
M`/4`````````S``````````;````'0$``)X````6````"`$``+@```#7````
M`@````````"9````\@````,```#3````U````-(```!T`0``5P```.X`````
M`0``;0$``$<!``#*````````````````````$`$``.H```"+````[````'$`
M```E`0``SP`````````'````)@$````````(````*P```*L`````````````
M``````"*````3P$``)0```!X`0``&@`````````2````;0```#T!``!4````
M9@````````!/````-P$``%L````R`0``?0``````````````_`````````"J
M`````````%4!```7````A0```$````"+`0``^@````````"@````5@```!@!
M``"8````/````$L!``!V````1@```,0`````````/@$````````]````X@``
M`(````!J`0``90`````````A`0``90$```````""````7`$```````#O````
M`````(8!``!!````2@$``!0!``"_````B````&L`````````V0````````#.
M````9``````````&````Y0```.,```!,````0`$``+D````:`0```````%\!
M``#G`````P$```````!K`0``AP$```````!(`````````(,```!H`0``````
M`#L!```<`0``Z````+(```#6````1P``````````````S0```(`!``#_````
M.@```'X`````````(@````````!"`0``R0````````!1````60$``),`````
M````$0```,``````````=P$``'````#^````O0````````!(`0```````'P`
M````````:0$``%X!``")```````````````L````$P``````````````AP``
M`,(``````````````'T!```O`0``!`$```H!``!V`0``#@$``'\!````````
M]`````````!1`0````````````!&`0``4@``````````````VP```/,````.
M````=````.$`````````.@$``%`!``#%````E@````````!C````ZP```#,`
M```N````V@````0```!F`0````````````!A````(P````(!``"A````>0$`
M`(,!``"T````4@$``+8````,````>``````````8`````````+X````,`0``
M#0$``)(````\`0````````\!````````<P```$X````>`0``'`````````#0
M`````````)$````A`````````.D````D````=0```-$````6`0``````````
M``"5`````````"X!``!$````(P$``#`!```1`0``*0$``!0`````````,@``
M````````````4````+H````G````B0$```````"<````QP`````````V`0``
M`````#0!````````;``````````'`0``60```%X```"$`0```0$``(4!```9
M````;@$```````!G`0````````````"U`````````$T!````````>P```(@!
M``!,`0``8@$``'H!``!<````#0```$X!````````+0```%<!````````-```
M```````/````>0```!L!`````````````+`````5`0````````4````)````
M!0$``"L!``#X````!@$```````!D`0``.P```'<``````````````&$!````
M`````````!T```"[````;`$``!4```!)````*@$``($```!_`````````'$!
M``!O````H@```#\!`````````````$(`````````8P$``',!``"N````$```
M``````"M````-@`````````P````*`$```````!8````:@```)``````````
M`````,8`````````<`$````````H````50```/T`````````<@```"T!```E
M````"0$``"<!``"E`````````,$```#@``````````````#8````)@``````
M``"/````\`````````![`0``G0````````"O`````````+<```!U`0``````
M`!D!```Y`0``(`$``"0!````````.0`````````+```````````````B`0``
MIP```(0```":````8````!X````Q`0``C````&`!```J````0P$``$T```!)
M`0``4P```,,```!+````"P$`````````````0P```%8!``"H````-0$`````
M``"?````.`$```````!N````\0```%0!```I````:````-4`````````'P``
M`#$````W````EP```%T!``"!`0``<@$```````#V````00$``.T```";````
M10$```````#?````10```(H!````("A!8V-E<W-K97D@)7,I`"`H=&]D87DI
M`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(&%L<F5A9'D@97AI<W1S+@`R-"!H
M;W5R<P!!32]030!!8F]U="!T:&ES(&5D:71O<@!!9&0`061D(&$@;F5W('5S
M97(Z`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1R871I;VX`06QI87,`
M06QI9VX`06QI9VYM96YT.@!!;&P`06QL(&9O=7(@<VED97,`06QT97)N871E
M('1E>'0Z`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07!R:6P`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S.@!"86-K9W)O
M=6YD`$)A8VMG<F]U;F0@0V]L;W(`0FER=&AD87D`0F]L9`!";W)D97(`0F]R
M9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W1H`$)O='1O;0!"=6QL971E9"!,
M:7-T`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%N8V5L`$-A;F-E
M;"!0<F]B;&5M(%)E<&]R=`!#87!T:6]N`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5L;'!H;VYE`$-E;G1E<@!#:&%N9V4`0VAE8U]K($QI;FLN+BX`
M0VAI;F$`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I`$-L96%R($U33V9F:6-E('1A9W,`0VQO<V4@5VEN9&]W`$-O;&QA<'-E
M(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L<SH`0V]M:6-S
M`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#;W!Y`$-O<'D@<V5L96-T:6]N
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-R
M96%T90!#<F5A=&4@82!L:6YK`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@<W1Y
M;&4`0W5T`$-U="!S96QE8W1I;VX`1$0`1&%I;'D`1&%T90!$95]L971E($-O
M;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT
M`$1E9F%U;'0`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5L971E(&-E;&P`
M1&5L971E(&-O;'5M;@!$96QE=&4@<F]W`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$97-C<FEB92!T:&4@4')O
M8FQE;0!$97-C<FEP=&EO;@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA>2!/<'1I;VYS
M`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@)7,`161I=`!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M;W1I8V]N<P!%;7!T>2!R97-U;'0N`$5N;&%R
M9V4@161I=&]R`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<G)O<@!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S
M`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA
M;7!L92!V86QU97,Z`$5X<&%N9"!3:61E8F%R`$9'($-O;&]R`$9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%X`$9E8G)U87)Y`$9I;&4@36%N86=E<@!&:6QT97)S
M`$9O;G0@0V]L;W(`1G)A;65S`$9R;VT`1V5R;6%N>0!';P!(96EG:'0`2&5L
M<`!(96QP('5S:6YG(&5D:71O<@!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO<FEZ
M;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA
M;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$E?;G-E<G0@4F]W($)E9F]R90!)
M8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM<&]R=&5D(&9I
M96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN
M8W)E87-E($EN9&5N=`!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA
M9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M
M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&-E;&P@
M869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`
M26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T('!A<F%G<F%P:"!A9G1E<@!)
M;G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R
M="!R;W<@8F5F;W)E`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$ET86QI8P!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R
M,BU*4"D`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF
M>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MO<F5A+"!297!U
M8FQI8R!O9@!+;W)E86X@*$550RU+4BD`3&%N9W5A9V4`3&%S="!L;V=I;CH@
M)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,
M87EO=70`3&5F=`!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO=V5R(&=R
M965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N
M=6UB97)S`$U-`$UA:6P`36%K92!L:6Y?:RXN+@!-87)C:`!-87)G:6X`36%T
M8VAI;F<@9FEE;&1S`$UA>0!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A
M9V4`36ED9&QE`$UO9&EF>2!54DP`36]N=&AL>0!-;W9E($1O=VX`36]V92!5
M<`!.86UE`$YE='=O<FL`3F5V97(`3F5W('=I;F1O=R`H7V)L86YK*0!.97AT
M`$YO`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F]N90!.;W1E<P!.;W9E
M;6)E<@!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!/8W1O8F5R
M`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I
M;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`%!A9&1I;F<`4&%S<W=O<F0`4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5R
M8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R<V]N86P@
M26YF;W)M871I;VX`4&AO;F4`4&EX96QS`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I
M;B!A(&YE=R!W:6YD;W<`4')I;G0@9&]C=6UE;G0`4')O8FQE;2!$97-C<FEP
M=&EO;@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!296UO=F4@<&%I<@!297-E
M=`!2971U<FX@=&\@3W!T:6]N<P!2:6=H=`!2;U]W(%!R;W!E<G1I97,N+BX`
M4F]L90!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!386UE
M(&9R86UE("A?<V5L9BD`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E<'1E;6)E<@!3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`
M4W1R:6ME=&AR;W5G:`!3='EL92!;0U-370!3=6)J96-T`%-U8FUI=`!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6UM87)Y`%-U<&5R<V-R:7!T`%1A8FQE(%!R;W!E
M<G1I97,`5&%B;&4@<')O<&5R=&EE<P!487-K<P!497AT`%1E>'0@3VYL>0!4
M97AT(&%L:6=N`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+@!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O9V=L92!(
M5$U,(%-O=7)C90!4;W``5&]P(&9R86UE("A?=&]P*0!54DP`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD97)L
M:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;FET
M960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N;&EN:R!T:&4@8W5R<F5N="!E
M;&5M96YT`%5N;F%M960`56YS970@8V]L;W(`57!P97(@;&%T:6X@;&5T=&5R
M<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5
M<V5R<R!I;B!T:&4@<WES=&5M.@!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P
M861D:6YG`%9I97<@)7,`5V%R;FEN9P!7965K;'D`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VED=&@`5VED
M=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=O<FL@061D<F5S
M<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&UU<W0@9&5S
M8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O
M8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S
M.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT
M(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M(:61E(%%U;W1E
M9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`
M6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=
M`%]!9&UI;FES=')A=&EO;@!?1&5L971E(%)O=P!?2&5L<`!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`
M7U)E;6]V92!,:6YK+BXN`%]486)L92!0<F]P97)T:65S+BXN`&QI;F5S70!N
M86UE`'!E<F-E;G0`<&EX96QS`'5N;F%M960`=D-A<F0`4')O:F5C="U)9"U6
M97)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TQ,2TP.2`Q
M-CHR.2LP.3`P"DQA<W0M5')A;G-L871O<CH@2FEN:'EO:R!(96\@/&YO=F5M
M8G)E0&]U<FYA='5R92YO<F<^"DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U%54,M2U(*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`H`("BTW,/@Q;`@)7,I`"`HO\"TPRD`("BSN\#/*0`@*+[N
MP:8I`"5S(,"OP?:P_+BN(,#;OO<@+2#(KL#.`"(E<R*TPB#`S+G,(,#6O<"T
MS[39+@`R-""]P["C`+_`P/POO\#(Q`#`S""_H;7PQ<VTP@##W["A`+OUM\Z_
M[B"[Y[_KP-H@P]^PH3H`QN2^[BAP86ER*2##W["A`+OGO^O`VB##W["A`+OG
MO^O`VB##W["A(+OGO^N^R,?4`,'6O-(`P=:\TK?/`+#\N*X`OO.V\\#,ONZ]
MN@#!I+?$`,&DM\0Z`+CPM<X@O+'%PP"X\+7G(#2XZ0"TZ\.\(+';`,#?N/BU
MR""YKL#:L*$@P-:]P+3/M-DN`#2_^0#`K\'VL/RXKKW'Q^#`_"#(KL#.Q\^Q
MX@`XO_D`L*&TR<?1(,?*M>4Z`+GHL.8`N>BPYB"[]K'R`+O]P,\`L;VPU`"P
MYK#H`+#FL.@@M<ZRL@"PYK#H`+CPM<X`OL:WH0"QXLBC(+BNO;K&K@!?9;R_
M(+S3O+HN+BX`M-ZWP@##Z[S2`+_`M_D@NKBP[<?/L>(@P^N\T@#$N+S'`,C>
MM.O&^0"\OR"\T[RZ`+R_(,;DM?D`O+\@O-.\N@"\OR"PH[#=`,C>M.O&^0"P
MH;_NM:4`NJ^PY@!?:[BUQ:D@L,N[YRXN+@#!W[&Y`+SXO*T@N*Z]NL:N(,&^
MM_D@O+'%PP!-4[_`Q\>]NB#%U['7(,'VO^RQX@##HB"TW;'B`+_>PLJXM[3K
M(+3=L>(`Q]7#Q,'X(+#FL.@`N_:Q\@"_K3H`0V]M:6-S`,BXN^<`OL_(HR#(
MKL#.`+JYN^<`NKF[YP!-86EN=&5N86YC95]487-K(+CPM>(@)7,@N*8@OZT@
MO/8@OOB]P+3/M-DN`+BXM>FQX@"XM<6I(+BXM>FQX@#']L#G(%523,"Z`,?V
MP.<@O;K%N,#/`,#:N*.QX@#`VKBCL>(`1$0`P,^ZL`"SK\*E`%]LOZT@N^C!
MI@`Q,K_Y`+S]P-H`L[N^[KZRL>(`L>*ZNP"QXKJ[(+W$NK#`V@"[Z,&F`+R_
M(+OHP:8`OZT@N^C!I@#'X""[Z,&F`,?VP.<@OZT@P?:_\@#']L#G(,?@(,'V
MO_(`O\"W^2"\L[CM`+RSN.TZ`+R\NL[!I+JXL*$@L/RXKL#:N*8@P*?'V""Q
MXK?/M<>^[L&SO<"TS[39+@"U\+>ZQ>2XK@#(K;CI(+RSP:0`;6%I;G1E;F%N
M8V4N<&APOZ$@P??!HB#!HK'9Q\_!]B"XMKR\O^0N`,.YN?C"L"#'X,"Z(,?7
MN/$@P,RXI\"[(+"NL.T@P-:]P+3/L>X_(+'7M[BTV;CI+""_J;'BN*8@P[S%
MJ<?/O+R_Y#H`L[NWP;G>L>(`)7,@L[NWP;G>L>(`O/;!I``E<R"QQ\?1(+SV
MP:0`O+'%P[OGQ]<@O/;!I#H`O^2\TBXN+@!E;0#`S+C>P,\`P,RX\,:\Q-P`
ML.&P^B"^^,"]`,;MP?VQXB#(KK3K`+'7N+(@55),(,#4M\(`O\"W^0`Q-;K0
M(+BVM-D`,S##RB"XMK39`#6ZT""XMK39`+CPM><@M\ZQU\#.`#,PNM`@N+:T
MV0"XQ;K0`+^Y.@"_WL+*N+>TZR#(KL#E`,#\L.:[]@#(K[#FO+/!I"#`T+'B
M(+_`M_DN`$Q$05`@O*VY]B#!HKS3(+W'QM``QM&]N@`RO_D`QL3`SR"P_+BN
MP-H`Q\K%S0"QV\#:(+OVL?(`Q\&WN<#3`,"GQ*$`M;;`SP"PH;'B`+/TP,P`
MM;6_\KB[`+6UO_*XNP#&Q,#/P,<@O</`V\#,(+39P+VP^B"PL+W`M,^TV3H`
MP?T@P=:\T@#!_2#`_,BMN?C(HP!(;W)D90"\]L;RO+$`L*&WSB##I+_R`+"A
MM\XZ`,?5Q*&P[2"]S<"Z(+^MP,<@O/8`Q]>X\2B_K2G`QR"\]C\`Q]7$H;#M
M(+W-P+H@Q^#`QR"\]@!?;K[5OZ$@Q^`@P]^PH0"^QL#,Q-P`OL;`S,3<L/H@
MN:[`V@"]Q+JPP-H@P,RXISH`L=>XLB"YS+BNNKBQXCH`L=>XLB!54DP`L=>X
MLB!54DPZ`+"AP:Z_PB#'U[CQ.B`E<P"PH<&NO\(@Q]>X\3H`7W.TV<"]OZ$@
MQ^`@P]^PH0"UZ;^IOK*QX@!?;[39P+V_H2"_K2##W["A`+'7N+(@P]^PH0#'
MI2##W["A`,"E(+BUQ:D@P]^PH0!?8[[5OZ$@OZT@P]^PH0#']L#G(+^M(+7:
MOZ$@N_4@OZT@P]^PH0#']L#G(+^M(+[5OZ$@N_4@OZT@P]^PH0#']L#G(,?@
M(+7:OZ$@N_4@Q^`@P]^PH0#']L#G(,?@(+[5OZ$@N_4@Q^`@P]^PH0#']L#G
M(,'VP:$@M=J_H2"TW+;T(,/?L*$`Q_;`YR#!]L&A(+[5OZ$@M-RV]"##W["A
M`+7:OZ$@O+\@P]^PH0"^U;^A(+R_(,/?L*$`M=J_H2"_K2##W["A`+[5OZ$@
MOZT@P]^PH0"UVK^A(+3<MO0@P]^PH0"^U;^A(+3<MO0@P]^PH0"UVK^A(,?@
M(,/?L*$`OM6_H2#'X"##W["A`+'7N+(@P]^PH2^\]L&D`+BUQ:D@P]^PH2^\
M]L&D`+'BO^_`S+'B`#&_^0#`S[J[`,#/NKN^[B`H25-/+3(P,C(M2E`I`#>_
M^0`VO_D`P:2WQ`"PH;_NM:4@P:2WQ`"^Y\+*(,&DM\0`O]["RB#!I+?$`+_`
MN*7"RB#!I+?$`+3KQ]&YSK&Y`,?1L;F^[B`H155#+4M2*0"^\+[N`+BVP?:X
MMR"WSK'7P,XZ("5S`+BVP?:XMR"WSK'7P,XZ("5S+"#!HKS3(,"GQ*$Z("5S
M`+BVP?:XMR"WSK'7P,XZ(+[XP+T`M[G`S+[&O_0`O]["R@"UM;_ROLL@N/'"
M]P"[Y[_KQ](@O/8@OOBTPB"[Y[_KP-H@N/&WSRX`M\ZQU\#.`+?.L=>^QK_T
M`+?.L=?`SB"]P\#;P-N^]P"QU[BNO;H@O-*YKL#:`+;SQKX@O-*YKL#:`+?.
MN+8@O-*YKL#:(+S]P-H`34T`N-[`SP!?:[BUQ:D@N+BUZ;'B+BXN`#._^0"P
MH<#EP-JXK@#`S\2AQ\^TPB#'U[CQ`#6_^0"XWK2Z(+CPM>4`O+\@Q]7$H;'B
M`+C>O</!]@"PH;_NM:4`55),(+SVP:0`N,6_^0"^QK>AM\X@P,RUOP#`I[?.
M(,#,M;\`P,RXIP"SU\:NO_;%J0"[Y[_KOLC'U`"[]2##HBA?8FQA;FLI`+39
MP+T`OL:TS[_``$944"!61E.XIB#`I\?1(+RSP:3!I+JXL*$@OOB]P+3/M-DN
M`%-13"!61E,@O+/!I,&DNKBPH2"^^+W`M,^TV2X`4U%,+49I;&4@5D93(+RS
MP:3!I+JXL*$@OOB]P+3/M-DN`+RQQ</'S\'V(+[*P+T`POS!M@`Q,;_Y`+^M
MP,<@O/8`Q^#`QR"\]@`Q,+_Y`+OU(,.BOZ$@N+7%J2"_K;'B`+RQQ<.[Y\?7
M`"5S(+RQQ<.[Y\?7`+S]P-H@N/&WSP"TW,.\`+'BQ;@`L>+%N"#!I+JX`,;D
MM?D`OL_(HP"^S\BCL*$@P,_$H<?/P?8@OLJ]P+3/M-DN`+K9P,RQX@#%K+BS
MNKBUY;^AO*T@NMG`S+'B`+#FM\X`QMN\OL:N`,"OP?8@L/RXKB#`V[[W(+W'
MQ^``L+/`SB#!I+JX`,#\R*VY^,BC`,?(O+\`N:[!IK^A(+3KQ]$@O^2^X,"[
M(,#4M\+'V"#!UKR\O^0N`+OGO^O`VL#,N*>P^B"^S\BCN*8@P-2WPL?/O+R_
MY`"YS+BNNKBQX@"[]2##HK^A(+G,N*ZZN+'B`+FNO*T@P,Z\X@"YKL&F(+RS
MN.T`N+;!]KBW(+CMM\D@N=VZN0#&Y+[N*'!A:7(I(+OHP:8`P-2WPB##Z[S2
M`+_)O,?`N+?.(+6YOL:PH;'B`+_`N*7"R@!?=\?@(+S3O+HN+BX`OZK'T@#'
MX""\T[RZ`,?@(+S3O+H`Q^`Z`+"PP+H@Q\&WN<#3*%]S96QF*0#`^L#E`+RQ
MQ<.[Y\?7(,#ZP.4`L,N[]@"^QK>A(+OSP-J_H;RM(,?*O^3'T2"YKL#:N*8@
MO+'%P\?/L.T@NKF[Y\?/OZD@NMF_J;/6P+B\O+_D+@"SK\#:(+&XNM#'I;W#
M(+RQQ<,Z`+.OP-H@Q_R]Q""\L<7#`+W#L*,@Q_R]Q""\L<7#`+7.L+/`QR#`
MS\2AQ\^TPB#'U[CQ(+RQQ<,`P-K!UKOGO^O'S[3"(+[PONZXIB"\L<7#Q\^\
MO+_D+@"YKL&FN=^[_2"ZN+#MO*T@P/R\V\?/L>(`.;_Y`+R_(+S3O+K#HB"Z
MN+'B`,>E(+S3O+K#HB"ZN+'B`+^M(+S3O+K#HB"ZN+'B`+'7N+(@O-.\NL.B
M(+JXL>(`Q:FQX@#`K\'VL/RXKB"[_;>K`+R_L*.PW0"\OR"PYK#HO\T@L[N_
MZR"[Y\#,P,<@L*.PW0"PQ;BN`+#%N*Z_S2##I+_LL>(`QJ^\]B"YKL#:(,#4
MM\(`O+\@NM#'T@"_K2"ZT,?2`,?@(+K0Q](`L*&_[K6EP=D`O;K%N,#/6T-3
M4UT`P::X\0#!IL/B`+[&MZ'#M\#:`+RZL/@`O^2^X`#`K<.WP-H`QZ4@O-.\
MN@#'I2"\T[RZ`,#;OO<`N:[`VK^M`+FNP-H`N:[`VB#!I+?$`+OGO^O'V,'6
MO,6\K2"PJ+OGQ]6TS[39+@#&Q,#/OZ$@OL:YJ[>Q(,#:M^&PH2"^^+W`M,^T
MV2X`OL:WH;3"(,#,(&UE<W-A9V4O<F9C.#(R(,;MP?;`QR"XT[BTN+O`U+3/
MM-DN`+W$NK#`VB`B)7,B(+"A(+OHP::UQ[[ZO<"TS[39+@#`S+_KL*&TR<?1
M(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN`,;$P,\@O\.XKK'BOZ$@N:[!IK"A(,#6
MO<"TS[39+B`E<R#&Q,#/P,P@OO>WSK7EM<?!]B"^RK[2O<"TS[39+@#`S""\
M_<#:M,(@P]:\TL?1(#'`VKBN(,#,N_/`S+[NOM\@Q]6TS[39+@#`S""PJL"Z
M(+S]P-J_J;[?(,?5M,^TV2X`P::X\0#%N,#,QK(HQ?C&P2DZ`+G>M,(@N^>V
M]P!(5$U,(+S2O;H@NKBQX@#`IP"[\\"G(,?!M[G`TRA?=&]P*0!54DP`5D93
M(,;$P,\@)7,O)7/`QR#&V[G,O,?`NR"ZK[#FQ](@O/8@OOB]P+3/M-DN`%-1
M3""\K;GVOZ$@P:*\T\?2(+SV(+[XO<"TS[39+@`E<R#!I,#'N*8@P-#`NR"\
M]B"^^+W`M,^TV2X`=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/
MM-DN`%9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2X`
MP,P@O_:UY;FNO*VXIB"ZK[#FQ](@O/8@OOB]P+3/M-DN`+G8P=D`NJ^PYKOG
MQ]<@M<>UN;BNL>(`N+;!]KBW(+CMM\D@P^N\T@"_M;&Y`+G,L;D`Q_;`YR"_
MY+S2OZ$@N+7%J2#!IK#%`,#,N*<@OOC`O0"[]K'R(,&FL,4`MO/&OK[N(+3K
MN:[`V@"WSKBV(+3KN:[`VB"\_<#:`+OGO^O`VB"\L<7#N^?'UP"[Y[_KP-JX
M[0"]P[VZQ=O`QR"[Y[_KP-HZ`+SVP?<@P:2WQ`"\]L'W(,.DO_(`)7,@NKBQ
MX@"PYK#M`+C%P=8`R*^_M0#(K[^UQ]6TS[39(2`E<R#`U+3/M-DN`,BOO[7'
MU;3/M-DL("5S`+&XNM`@N:[`VK3"(+FKOOG`U+3/L>X_`,#.O^L@NL[(H[3"
M(+FKOOG`U+3/L>X_`+/*NO$`QZ7`QR"SRKKQ`+/*NO$@M-S`IP"SRKKQ.@#!
M]\#E(,'6O-(Z`,'WP.4@P/S(K;GXR*,`65D`N,6SX@"_N0!415A4N/"UY<#4
MM,^TV2X@6SP^72"Y]L:PP+L@M*FXH[CI(%=94TE764<@N/"UY;?.(+6YOL:P
MJ;3/M-DN`+?.L=>^QK_T(,?/O[2]P+3/M-DN`+FNP:8@NKBP[;RMN*8@NKBS
MN['BP/R_H2#`S+FNP::_H2"TZ\?1(+RSN.W`NR#`U+?"Q]B^WR#'U;3/M-DN
M`,#,(+BUQ:FPH2"PH;BNQ*&TPB!54DS`NR#`U+?"Q]B^WR#'U;3/M-DN`+OH
MP:;'TB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`P]^PH<?2(+OG
MO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+@`E<R"\O+S'P,P@N+BWX;7'
MOOJ]P+3/M-DN(+39O<,@M\ZQU\#.Q\^\O+_D+@#`S+C>P,\@P=:\TCH`N-[`
MSR#!UKS2.@#!I+JX`,#,N*<Z`+3GO<7`QR#`SL'UQ:RV\\#,OO#&KK"A(+OG
MO^O`VB"X\;?/NKBQXKBF(,'VO_C'S\'V(+[*O<"TS[39+B"VQ[3"(+39N*4@
MP,S`K[?.(+OGO^O`VB"X\;?/NKBQXKBF(+OGO^O'TB"\]B"^^+W`M,^TV2X`
MNNJV\[_LP/JPH2#`S""QXK3)P+L@P?:_^,?/P?8@OLJ]P+3/M-DN`,?VP.<@
MO<.PH[3K.@"QXKJ[(+W$NK#`VCH`P/S#O"#`S+BG.@#`S""\O+S'(+6_OL@@
MO\F\Q\#,(,#ZP.6UR[3/M-DN`+_)O,?`S"#`^L#EM<>^^KW`M,^TV2X`6\#.
MO^L@O/NQXK'B70!;O\"W^2"ZN+#MQ\^QXET`6\#.O^L@NKBQXB`M`%O`SK_K
M(+JXL>(@+2`E<R#!V5T`6[;SP,X@)7,@+R`E<UT`7T&P_+BN`%]$Q^`@P?:_
M\@"UM;_RN+L`7TFQU[BR(+S3O+HN+BX`7TRWSK'7OL:_]`!?;;BUQ:D@O/;!
MI"XN+@!?3[RQQ<.[Y\?7`%]RN+7%J2"[Z,&F+BX`7W3'I2"\T[RZ+BXN`,'9
M70#`S+BG`,;;O+[&K@#'R+R_`,#,N*<@OOC`O0!V0V%R9```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VMO7TM2
M+VAE;'`N>&UL````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S,R,``Q,#4Q-30S,3`V,@`P,C`S,C(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^
M"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O:V]?2U(O:&5L<"YX;6PL=B`Q
M+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-"!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@
M4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G
M92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T
M86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W
M(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y
M;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@
M=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E
M;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE
M<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T
M;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W
M(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@
M;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S
M(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE
M($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E
M('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A
M<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N
M97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T
M:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@
M=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@
M($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O
M('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I
M;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N
M8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T
M;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H
M96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA
M:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD
M(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E
M('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C
M:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@
M8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N
M;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H\+VAE;'`^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]L=%],5"\`````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C(`,#$V-C8V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+VQT7TQ4+TQ#7TU%4U-!1T53+P``````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,C`T-3,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;'1?3%0O3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S,R,C0R`#$P-3$U-#,Q
M,#8R`#`R,C$Q-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````'0&```<````O#,``)L(``!<9P```````,B)```.
M````R8D```\```#8B0``"````.B)```,````\8D```0```#^B0``#`````.*
M```/````$(H```L````@B@``#@```"R*```%````.XH``"@```!!B@``"@``
M`&J*```5````=8H``!(```"+B@``"P```)Z*```.````JHH```H```"YB@``
M#0```,2*```.````THH``!$```#AB@``#0```/.*```,`````8L```T````.
MBP``!@```!R+```/````(XL``!@````SBP``#````$R+```.````68L```X`
M``!HBP``"````'>+```N````@(L``!H```"OBP``,@```,J+```X````_8L`
M`%0````VC```40```(N,``!:````W8P``%<````XC0``-````)"-```*````
MQ8T```4```#0C0``!@```-:-```1````W8T```@```#OC0``"0```/B-```)
M`````HX``"4````,C@``(````#*.```0````4XX```\```!DC@``"@```'2.
M```#````?XX```\```"#C@``%````)..```)````J(X```T```"RC@``$@``
M`,".```/````TXX```H```#CC@``#P```.Z.```(````_HX``"0````'CP``
M%````"R/```6````08\```@```!8CP``&0```&&/```'````>X\```P```"#
MCP``+````)"/```.````O8\```,```#,CP``"P```-"/```'````W(\```<`
M``#DCP``!0```.R/```%````\H\```H```#XCP```P````.0```7````!Y``
M``H````?D```#P```"J0```.````.I```!@```!)D```(P```&*0```.````
MAI```!0```"5D```%P```*J0```7````PI```!<```#:D```$P```/*0```/
M````!I$```X````6D0``'P```"61```'````19$```8```!-D0``"````%21
M```/````79$```8```!MD0``"@```'21```3````?Y$```L```"3D0``%0``
M`)^1```5````M9$```<```#+D0``!0```-.1```5````V9$``!$```#OD0``
M#`````&2```[````#I(```D```!*D@``!P```%22```4````7)(```,```!Q
MD@``!0```'62```0````>Y(```D```",D@``$P```):2```Y````JI(``!(`
M``#DD@``)P```/>2```L````'Y,``"H```!,DP``)0```'>3```*````G9,`
M``8```"HDP``"0```*^3```'````N9,``"\```#!DP``-P```/&3```N````
M*90``%4```!8E```+0```*Z4```M````W)0``"T````*E0``0````#B5```C
M````>94``",```"=E0``+0```,&5```S````[Y4``!4````CE@``&0```#F6
M```I````4Y8``"0```!]E@``$0```**6```*````M)8```P```"_E@``"@``
M`,R6```0````UY8``!8```#HE@``%@```/^6```'````%I<```<````>EP``
M%````":7```*````.Y<```@```!&EP``"````$^7```'````6)<```<```!@
MEP``!@```&B7```%````;Y<```<```!UEP``!@```'V7```(````A)<```X`
M``"-EP``"@```)R7```$````IY<```<```"LEP``"0```+27```&````OI<`
M`!$```#%EP``!P```->7```6````WY<```0```#VEP``"````/N7```&````
M!)@```T````+F```!@```!F8```>````()@``!$````_F```"````%&8```-
M````6I@```P```!HF```!P```'68```#````?9@```,```"!F```%P```(68
M```3````G9@```@```"QF```!````+J8```(````OY@```@```#(F```00``
M`-&8```@````$YD```8````TF0``!@```#N9```5````0ID``!@```!8F0``
M(@```'&9```N````E)D``!T```##F0``(0```.&9``!4`````YH``"D```!8
MF@``"@```(*:```'````C9H``!4```"5F@``#@```*N:```*````NIH```\`
M``#%F@``#0```-6:```/````XYH```T```#SF@``"0````&;```4````"YL`
M``8````@FP``&````">;```=````0)L``!,```!>FP``%````'*;```$````
MAYL```8```",FP``5````).;```$````Z)L```X```#MFP``!0```/R;```%
M`````IP``!L````(G```&@```"2<```1````/YP``!$```!1G```'````&.<
M```J````@)P``!````"KG```(0```+R<```%````WIP``!,```#DG```$@``
M`/B<```*````"YT```\````6G0``$0```":=```3````.)T```P```!,G0``
M!@```%F=```&````8)T``!<```!GG0``$0```'^=```(````D9T```4```":
MG0``#````*"=```0````K9T```4```"^G0``#0```,2=```&````TIT```<`
M``#9G0``#0```.&=```'````[YT```L```#WG0``!P````.>```'````"YX`
M``D````3G@``"@```!V>```9````*)X```P```!"G@``$````$^>```%````
M8)X``"4```!FG@``$@```(R>```3````GYX``"L```"SG@``.P```-^>```@
M````&Y\``#8````\GP``"````'.?```,````?)\```8```")GP``!````)"?
M```.````E9\```H```"DGP``#0```*^?```>````O9\``!L```#<GP``(0``
M`/B?```>````&J```!D````YH```'@```%.@```;````<J```"8```".H```
M&P```+6@```>````T:```!P```#PH```)@````VA```S````-*$``"8```!H
MH0``*P```(^A```X````NZ$``"\```#TH0``$@```"2B```I````-Z(``!(`
M``!AH@``H@```'2B```6````%Z,``",````NHP``*````%*C```I````>Z,`
M`"@```"EHP``'P```,ZC```@````[J,``"4````/I```(0```#6D```<````
M5Z0``"8```!TI```00```)ND```,````W:0```<```#JI```!P```/*D```&
M````^J0```T````!I0``$`````^E```2````(*4``!,````SI0``$@```$>E
M```'````6J4```0```!BI0``#````&>E```.````=*4```\```"#I0``$P``
M`).E```-````IZ4``"@```"UI0```P```-ZE```-````XJ4```8```#PI0``
M$0```/>E```7````":8``!L````AI@``#@```#VF```"````3*8```4```!/
MI@``$````%6F```$````9J8```T```!KI@``#@```'FF```#````B*8```X`
M``",I@``"````)NF```/````I*8```\```"TI@``#0```,2F```0````TJ8`
M``L```#CI@``!@```.^F```,````]J8``!$````#IP``&0```!6G```+````
M+Z<```T````[IP``(@```$FG```*````;*<``!@```!WIP``&0```)"G```6
M````JJ<```T```#!IP``!P```,^G```4````UZ<```L```#LIP``(@```/BG
M```O````&Z@```L```!+J```"0```%>H```9````8:@```L```![J```%P``
M`(>H```7````GZ@```D```"WJ```%@```,&H```/````V*@``!8```#HJ```
M#@```/^H```8````#JD```@````GJ0``#0```#"I```F````/JD``$,```!E
MJ0``"````*FI```2````LJD```@```#%J0``"P```,ZI```O````VJD```X`
M```*J@``!0```!FJ```&````'ZH```,````FJ@``!P```"JJ```$````,JH`
M``H````WJ@``"@```$*J```/````3:H``!````!=J@``%P```&ZJ```1````
MAJH``!<```"8J@``"0```+"J```%````NJH```L```#`J@``"@```,RJ```"
M````UZH```4```#:J@``#0```."J```;````[JH``!<````*JP``"0```"*K
M```.````+*L```T````[JP``$@```$FK```X````7*L``"````"5JP``"```
M`+:K```.````OZL``'L```#.JP``&````$JL```1````8ZP```<```!UK```
M!0```'VL```9````@ZP```<```"=K```"````*6L```&````KJP```8```"U
MK```$````+RL```/````S:P``!````#=K```#P```.ZL```+````_JP```\`
M```*K0``#````!JM```/````)ZT```<````WK0``!@```#^M```,````1JT`
M`"@```!3K0``#P```'RM```(````C*T```@```"5K0``$P```)ZM```>````
MLJT``"$```#1K0``(````/.M```9````%*X``!<````NK@``)0```$:N```7
M````;*X```0```"$K@``&P```(FN```-````I:X```,```"SK@``"````+>N
M```*````P*X```P```#+K@``"P```-BN```$````Y*X``!,```#IK@``%```
M`/VN```,````$J\```D````?KP``#@```"FO```+````.*\``!L```!$KP``
M!P```&"O```'````:*\```H```!PKP``#0```'NO```)````B:\```0```"3
MKP``!0```)BO```#````GJ\``!@```"BKP``"@```+NO```$````QJ\``"8`
M``#+KP``#@```/*O``!\`````;```!4```!^L```!0```)2P```'````FK``
M``P```"BL```"````*^P```*````N+````8```##L```"````,JP```"````
MT[````8```#6L```!@```-VP```4````Y+````T```#YL```$`````>Q```;
M````&+$```0````TL0``"0```#FQ```0````0[$```D```!4L0``"0```%ZQ
M```%````:+$``!H```!NL0``"````(FQ```&````DK$``!D```"9L0``#@``
M`+.Q```'````PK$```<```#*L0``!0```-*Q```)````V+$```H```#BL0``
M`@```.VQ```&````\+$```T```#WL0``"0````6R```&````#[(``!(````6
ML@``"0```"FR```'````,[(``!0````[L@``'0```%"R```&````;K(```H`
M``!UL@``!````("R```)````A;(```@```"/L@``$0```)BR```)````JK(`
M``8```"TL@``#0```+NR```&````R;(```0```#0L@``.0```-6R```]````
M#[,``#H```!-LP``'@```(BS```%````I[,```X```"MLP``!````+RS```&
M````P;,``"$```#(LP``%0```.JS```&`````+0```0````'M```$0````RT
M```&````'K0```H````EM```(@```#"T```$````4[0```4```!8M```'0``
M`%ZT```$````?+0```P```"!M```"@```(ZT```(````F;0```D```"BM```
M!0```*RT```Z````LK0``#````#MM```-0```!ZU```I````5+4``$<```!^
MM0``.````,:U```I````_[4``#\````IM@``+@```&FV```M````F+8``!\`
M``#&M@``#P```.:V```2````]K8```L````)MP``)@```!6W```I````/+<`
M`"0```!FMP``)@```(NW```(````LK<```H```"[MP``"0```,:W```'````
MT+<``"````#8MP``(````/FW```F````&K@```H```!!N```&0```$RX```I
M````9K@``!8```"0N```$@```*>X```'````NK@```H```#"N```#P```,VX
M```0````W;@``$````#NN```9@```"^Y```.````EKD```D```"EN0``"@``
M`*^Y```2````NKD``!,```#-N0``#````.&Y```&````[KD```\```#UN0``
M$@````6Z```0````&+H``!$````IN@``'````#NZ```C````6+H``&H```!\
MN@``#P```.>Z```%````][H``!````#]N@``"0````Z[```$````&+L```L`
M```=NP``%````"F[```,````/KL```P```!+NP``#P```%B[```5````:+L`
M`"D```!^NP``*@```*B[```F````T[L``"<```#ZNP``*0```"*\```J````
M3+P``!D```!WO```0@```)&\```1````U+P``!(```#FO```$P```/F\```4
M````#;T```\````BO0``%@```#*]```7````2;T``!````!AO0``$0```'*]
M```T````A+T``!,```"YO0``$@```,V]```U````X+T``!0````6O@``!P``
M`"N^```,````,[X``"````!`O@``%````&&^```1````=KX``!<```"(O@``
M'````*"^```3````O;X``!$```#1O@``&@```..^```>````_KX``!H````=
MOP``$0```#B_```4````2K\``!<```!?OP``%0```'>_```)````C;\``!D`
M``"7OP``!````+&_```'````MK\```L```"^OP``$0```,J_```&````W+\`
M``8```#COP``!@```.J_```%````\;\```<```#WOP``!P```/^_```%````
M!\```!8````-P```!@```"3````&````*\````0````RP```!````#?````'
M````/,````X```!$P```#````%/````,````8,````T```!MP```"@```'O`
M```.````AL````4```"5P```*````)O````.````Q,````P```#3P```#P``
M`.#````*````\,````@```#[P```"0````3!```K````#L$```0````ZP0``
M"````#_!```F````2,$``!(```!OP0``#P```(+!```&````DL$```H```"9
MP0``!P```*3!```(````K,$``"````"UP0``"0```-;!```,````X,$```T`
M``#MP0``#@```/O!```6````"L(``!$````AP@``!@```#/"```#````.L(`
M``8````^P@``&0```$7"```'````7\(```0```!GP@``"P```&S"```+````
M>,(```<```"$P@``!P```(S"```6````E,(```T```"KP@``#0```+G"```*
M````Q\(``!````#2P@``#P```./"```1````\\(``!<````%PP``"@```!W#
M```1````*,,```@````ZPP``!````$/#```/````2,,``#H```!8PP``!0``
M`)/#```,````F<,``!X```"FPP``#@```,7#```0````U,,```L```#EPP``
M#````/'#```)````_L,```<````(Q```"@```!#$```)````&\0```X````E
MQ```$````#3$```:````1<0```H```!@Q```"0```&O$```*````=<0```P`
M``"`Q```#P```(W$```(````G<0```8```"FQ```!P```*W$```+````M<0`
M`$<```#!Q```#0````G%```)````%\4```0````AQ0```P```";%```3````
M*L4``!,````^Q0``$P```%+%```*````9L4```(```!QQ0``!````'3%```E
M````><4```,```"?Q0``!0```*/%```J````J<4```H```#4Q0``!0```-_%
M```$````Y<4```H```#JQ0``#0```/7%```&`````\8```@````*Q@``"```
M`!/&```$````',8```4````AQ@``:````"?&```)````D,8```P```":Q@``
M!0```*?&```&````K<8``!L```"TQ@``+P```-#&```0`````,<```H````1
MQP``#P```!S'```*````+,<```D````WQP``$P```$''```;````5<<``!@`
M``!QQP``%P```(K'```.````HL<```,```"QQP``!P```+7'```(````O<<`
M``<```#&QP``"@```,['```+````V<<```<```#EQP``40```.W'```0````
M/\@```P```!0R```#0```%W(```:````:\@``$H```"&R```!@```-'(```&
M````V,@```8```#?R```'P```.;(```&````!LD```D````-R0``&````!?)
M```7````,,D```8```!(R0``#0```$_)```B````7<D``%<```"`R0``$P``
M`-C)```C````[,D``!,````0R@```@```"3*```+````)\H```@````SR@``
M#0```#S*```*````2LH```<```!5R@``%````%W*```&````<LH```@```!Y
MR@``#@```(+*```'````D<H```H```"9R@``"P```*3*```'````L,H```P`
M``"XR@``#0```,7*```,````T\H```D```#@R@``"0```.K*```*````],H`
M``<```#_R@``"0````?+```'````$<L```H````9RP``&P```"3+```2````
M0,L```H```!3RP``"0```%[+```0````:,L```<```!YRP``$@```('+```$
M````E,L```<```"9RP``!0```*'+```%````I\L```L```"MRP``%````+G+
M```1````SLL``!H```#@RP``%@```/O+```4````$LP``!<````GS```&```
M`#_,```<````6,P``!D```!US```!P```(_,```%````E\P```T```"=S```
M#````*O,```(````N,P``!<```#!S```"P```-G,```3````Y<P```0```#Y
MS```"@```/[,```$````"<T```P````.S0``"0```!O-```%````)<T```<`
M```KS0``!0```#/-```$````.<T```(````^S0``.````$'-```L````>LT`
M`!(```"GS0``*0```+K-```R````Y,T```H````7S@``+````"+.```N````
M3\X``#,```!^S@``,P```++.```X````YLX```\````?SP``&````"_/```0
M````2,\``!,```!9SP``%````&W/```2````@L\``!0```"5SP``%0```*K/
M```M````P,\``"T```#NSP``,0```!S0```N````3M```"\```!]T```+```
M`*W0``!B````VM```!,````]T0``"````%'1```(````6M$``"L```!CT0``
M(0```(_1```:````L=$```D```#,T0``10```-;1``!!````'-(```0```!>
MT@``$P```&/2```4````=](```X```",T@``$P```)O2```8````K](```8`
M``#(T@``"0```,_2```*````V=(```\```#DT@``$````/32```'````!=,`
M``X````-TP``!0```!S3```;````(M,```@````^TP``!@```$?3```4````
M3M,``!$```!CTP``#@```'73```X````A-,```(```"]TP``!@```,#3```.
M````Q],```4```#6TP``!P```-S3```.````Y-,```8```#STP``!````/K3
M```I````_],``!<````IU```'P```$'4``!<````8=0``!0```"^U```'P``
M`-/4```0````\]0```<````$U0``#@````S5```,````&]4```P````HU0``
M$P```#75```*````2=4``!T```!4U0``&0```'+5```%````C-4``!$```"2
MU0``$0```*35```D````MM4``!4```#;U0``$@```/'5```.````!-8``!D`
M```3U@``"````"W6```)````-M8```T```!`U@``"@```$[6```+````6=8`
M``H```!EU@``!P```'#6```(````>-8```4```"!U@``'P```(?6```&````
MI]8``!````"NU@``"````+_6```-````R-8```@```#6U@``$@```-_6```L
M````\M8``!H````?UP``"0```#K7```*````1-<``!4```!/UP``!0```&77
M```4````:]<```0```"`UP``$````(77```&````EM<```<```"=UP``'@``
M`*77```H````Q-<```H```#MUP``&@```/C7```4````$]@```0````HV```
M!````"W8```+````,M@```4````^V```!@```$38```(````2]@```8```!4
MV```"@```%O8```;````9M@``#0```""V```-````+?8```@````[-@``"D`
M```-V0``(````#?9``!!````6-D``!H```":V0``*````+79```I````WMD`
M`"(````(V@``!@```"O:```(````,MH```4````[V@``"````$':```9````
M2MH``!D```!DV@``*@```'[:```C````J=H``"X```#-V@``-````/S:```(
M````,=L``!<````ZVP``"@```%+;```'````7=L``"$```!EVP``$````(?;
M```.````F-L```L```"GVP``!P```+/;```3````N]L```@```#/VP``"P``
M`-C;```*````Y-L``!0```#OVP``,@````3<```+````-]P```4```!#W```
M!0```$G<```7````3]P```\```!GW```!````'?<```*````?-P```D```"'
MW```"P```)'<```.````G=P```4```"LW```!````++<```-````M]P``#(`
M``#%W```10```/C<```7````/MT``!X```!6W0``%````'7=```%````BMT`
M`!0```"0W0``!P```*7=```.````K=T``"H```"\W0``!@```.?=```,````
M[MT```T```#[W0``$0````G>```+````&]X``#8````GW@``"@```%[>```B
M````:=X```L```",W@``#P```)C>```R````J-X```4```#;W@``#@```.'>
M```3````\-X```<````$WP``$0````S?```'````'M\``!0````FWP``&```
M`#O?```'````5-\```4```!<WP``#````&+?```,````;]\``!(```!\WP``
M!````(_?```'````E-\```H```"<WP``"P```*??```,````L]\```X```#`
MWP``#@```,_?```%````WM\```4```#DWP``+@```.K?```F````&>```",`
M``!`X````P```&3@```2````:.````8```![X```'@```(+@```8````H>``
M`"4```"ZX```#0```.#@```)````[N````,```#XX```!P```/S@```*````
M!.$```(````/X0``#````!+A```5````'^$```L````UX0``&0```$'A```@
M````6^$``!(```!\X0``!0```(_A```*````E>$``!4```"@X0``$@```+;A
M```,````R>$```0```#6X0``!P```-OA```,````X^$``%(```#PX0``%P``
M`$/B```'````6^(```8```!CX@``#@```&KB```,````>>(```T```"&X@``
M%0```)3B```2````JN(```\```"]X@``%````,WB```;````XN(``!````#^
MX@``:0````_C```:````>>,``!<```"4XP``)P```*SC```:````U.,``!<`
M``#OXP``&P````?D```9````(^0``!\````]Y```$P```%WD```(````<>0`
M``<```!ZY```"````(+D```)````B^0``!4```"5Y```#0```*OD```3````
MN>0```,```#-Y```1@```-'D```_````&.4``#<```!8Y0``5P```)#E```?
M````Z.4``"\````(Y@``"@```#CF```(````0^8```T```!,Y@``+0```%KF
M```$````B.8``$\```"-Y@``)0```-WF```<`````^<```L````@YP``'P``
M`"SG```=````3.<``"4```!JYP``(````)#G```D````L><``"````#6YP``
M"P```/?G```'`````^@```T````+Z```#````!GH```&````)N@``#D````M
MZ```#````&?H```'````=.@```D```!\Z```$P```(;H```)````FN@```0`
M``"DZ```$````*GH```(````NN@```@```##Z```"P```,SH```,````V.@`
M`!H```#EZ```#P````#I```'````$.D```T````8Z0``%````";I```.````
M.^D```P```!*Z0``&P```%?I```L````<^D``!,```"@Z0``'````+3I```H
M````T>D```8```#ZZ0``!P````'J```3````">H```4````=Z@``!````"/J
M```7````*.H```H```!`Z@``#````$OJ```)````6.H```8```!BZ@``"0``
M`&GJ```(````<^H```D```!\Z@``"@```(;J```1````D>H```8```"CZ@``
M#@```*KJ```.````N>H```T```#(Z@``"P```-;J```=````XNH```L`````
MZP```@````SK```'````#^L```8````7ZP``"0```![K```'````*.L``#L`
M```PZP``*````&SK```5````E>L```4```"KZP``!P```+'K```(````N>L`
M``<```#"ZP``!0```,KK```'````T.L```X```#8ZP``"0```.?K```&````
M\>L```@```#XZP``"P````'L```'````#>P```@````5[```!P```![L```6
M````)NP```D````][```!@```$?L```+````3NP``!P```!:[```%````'?L
M```'````C.P```@```"4[```"````)WL```%````INP``!````"L[```$```
M`+WL```&````SNP``!D```#5[```"@```._L```<````^NP```<````7[0``
M!0```!_M```0````)>T``!0````V[0``"P```$OM```-````5^T``!<```!E
M[0``!````'WM```)````@NT```H```",[0``!P```)?M```"````G^T```X`
M``"B[0``"````+'M```?````NNT``",```#:[0``.````/[M```Q````-^X`
M`"<```!I[@``9````)'N```4````]NX``%4````+[P``.````&'O``!*````
MFN\``%L```#E[P``*````$'P```X````:O```"@```"C\```+````,SP```G
M````^?```!L````A\0``/@```#WQ``"I`0``?/$``",````F\P``%P```$KS
M``!(````8O,``(4```"K\P``,````#'T``!!````8O0``%L```"D]```20``
M``#U```=````2O4``!@```!H]0``(0```('U```?````H_4``"L```##]0``
M(0```._U```=````$?8``!$````O]@``,P```$'V```E````=?8``"<```";
M]@``'P```,/V```P````X_8``&D````4]P``/0```'[W``!E````O/<``$T`
M```B^```+P```'#X```N````H/@``#````#/^```5`````#Y``!:````5?D`
M`$@```"P^0``2@```/GY```R````1/H``"\```!W^@``+````*?Z```M````
MU/H``'$````"^P``;P```'3[``"S````Y/L``!<```"8_```)0```+#\```R
M````UOP``"D````)_0``/@```#/]```B````<OT``%(```"5_0``)0```.C]
M```+````#OX``+$````:_@``10```,S^```A````$O\``#`````T_P``)0``
M`&7_```<````B_\``#$```"H_P``!P```-K_```'````XO\```0```#J_P``
M#0```.__```+````_?\```X````)``$`"P```!@``0`%````)``!`!`````J
M``$``@```#L``0!9````/@`!``4```"8``$`$@```)X``0`$````L0`!``<`
M``"V``$`"````+X``0`%````QP`!``,```#-``$`$````-$``0`,````X@`!
M`!,```#O``$`#0````,!`0`"````$0$!``<````4`0$`!@```!P!`0`4````
M(P$!``P````X`0$`&````$4!`0`&````7@$!`!(```!E`0$`#````'@!`0`#
M````A0$!`"H```")`0$`!````+0!`0`&````N0$!``<```#``0$`'P```,@!
M`0`U````Z`$!`"X````>`@$`+P```$T"`0`7````?0(!`"````"5`@$`&P``
M`+8"`0`8````T@(!`"0```#K`@$`'P```!`#`0`:````,`,!`"````!+`P$`
M&@```&P#`0`R````AP,!`"\```"Z`P$`*P```.H#`0`?````%@0!`",````V
M!`$`'P```%H$`0`:````>@0!`"4```"5!`$`)@```+L$`0`E````X@0!`"0`
M```(!0$`&````"T%`0`=````1@4!`"0```!D!0$`&````(D%`0`B````H@4!
M`"4```#%!0$`/````.L%`0`?````*`8!`",```!(!@$`'P```&P&`0`@````
MC`8!`!H```"M!@$`&````,@&`0`F````X08!`!X````(!P$`*0```"<'`0`>
M````40<!``D```!P!P$`#````'H'`0`7````AP<!`"\```"?!P$`)````,\'
M`0`'````]`<!``\```#\!P$`%`````P(`0`.````(0@!``T````P"`$`)```
M`#X(`0`%````8P@!``<```!I"`$`(@```'$(`0`E````E`@!`!T```"Z"`$`
M&@```-@(`0`'````\P@!`,<```#["`$`"P```,,)`0`5````SPD!``8```#E
M"0$`"0```.P)`0`+````]@D!`!<````""@$`!@```!H*`0`S````(0H!`!,`
M``!5"@$`$P```&D*`0`'````?0H!``\```"%"@$`!P```)4*`0`R````G0H!
M`"$```#0"@$`$P```/(*`0`,````!@L!`!$````3"P$`,@```"4+`0`(````
M6`L!``D```!A"P$`"@```&L+`0`4````=@L!``H```"+"P$`'0```)8+`0`(
M````M`L!`!\```"]"P$`"````-T+`0`:````Y@L!``8````!#`$`%0````@,
M`0`'````'@P!``@````F#`$`"0```"\,`0`_````.0P!``<```!Y#`$`#P``
M`($,`0`.````D0P!`!````"@#`$`"0```+$,`0`)````NPP!``@```#%#`$`
M$P```,X,`0`'````X@P!`!D```#J#`$`"@````0-`0`7````#PT!`!0````G
M#0$`"@```#P-`0`,````1PT!`!<```!4#0$`!````&P-`0`J````<0T!`!$`
M``"<#0$`!P```*X-`0`"````M@T!`!````"Y#0$`&````,H-`0`+````XPT!
M``,```#O#0$`"````/,-`0`&````_`T!``<````##@$`#0````L.`0`+````
M&0X!`!0````E#@$`%0```#H.`0`.````4`X!`"\```!?#@$`(````(\.`0`<
M````L`X!``P```#-#@$`,0```-H.`0`%````#`\!`!(````2#P$`/P```"4/
M`0`2````90\!``H```!X#P$`!@```(,/`0`$````B@\!`!,```"/#P$`!0``
M`*,/`0`&````J0\!``8```"P#P$`!````+</`0`,````O`\!``H```#)#P$`
M!0```-0/`0`8````V@\!`!D```#S#P$`'P````T0`0`=````+1`!`!$```!+
M$`$``@```%T0`0`$````8!`!``H```!E$`$`!@```'`0`0`%````=Q`!``,`
M``!]$`$`#````($0`0!%````CA`!`!H```#4$`$`-0```.\0`0`H````)1$!
M`%,```!.$0$`&0```*(1`0!R````O!$!`"`````O$@$`-0```%`2`0!%````
MAA(!`#````#,$@$`*````/T2`0`I````)A,!`"8```!0$P$`)0```'<3`0`H
M````G1,!`"@```#&$P$`(@```.\3`0`P````$A0!`!(```!#%`$`$P```%84
M`0`0````:A0!`'D```![%`$`"0```/44`0!S````_Q0!`'P```!S%0$`*P``
M`/`5`0`7````'!8!`!8````T%@$`#P```$L6`0`?````6Q8!`!\```![%@$`
M'````)L6`0!1````N!8!`!0````*%P$`"@```!\7`0`%````*A<!``8````P
M%P$`"````#<7`0`%````0!<!`!(```!&%P$`$````%D7`0`3````:A<!`!T`
M``!^%P$`#P```)P7`0`/````K!<!``0```"\%P$`"0```,$7`0`+````RQ<!
M``<```#7%P$`!0```-\7`0`4````Y1<!``<```#Z%P$`"`````(8`0`/````
M"Q@!``@````;&`$`#````"08`0`/````,1@!``8```!!&`$`%````$@8`0`&
M````71@!``P```!D&`$`"````'$8`0`$````>A@!``H```!_&`$`!P```(H8
M`0`$````DA@!`!D```"7&`$``@```+$8`0`)````M!@!``8```"^&`$`!@``
M`,48`0`G````S!@!``0```#T&`$`#P```/D8`0`3````"1D!``<````=&0$`
M!P```"49`0`&````+1D!``8````T&0$`$````#L9`0`2````3!D!``8```!?
M&0$`"0```&89`0`B````<!D!``<```"3&0$`!P```)L9`0`+````HQD!``4`
M``"O&0$``@```+49`0`+````N!D!`%<!``#$&0$`$@```!P;`0`.````+QL!
M``L````^&P$`"````$H;`0`!````4QL!``L```!5&P$`$0```&$;`0`,````
M<QL!``T```"`&P$`!0```(X;`0`I````E!L!``\```"^&P$`#````,X;`0`2
M````VQL!``@```#N&P$`$0```/<;`0`*````"1P!``P````4'`$`$P```"$<
M`0`1````-1P!``X```!''`$`$0```%8<`0`0````:!P!``8```!Y'`$`#@``
M`(`<`0`5````CQP!`!$```"E'`$`$P```+<<`0`3````RQP!``L```#?'`$`
M+````.L<`0`2````&!T!`#T````K'0$`20```&D=`0!E````LQT!`&8````9
M'@$`:````(`>`0!I````Z1X!`$````!3'P$`"@```)0?`0`%````GQ\!``8`
M``"E'P$`$@```*P?`0`'````OQ\!`!$```#''P$`$P```-D?`0`K````[1\!
M`"@````9(`$`"P```$(@`0`3````3B`!``@```!B(`$`!P```&L@`0`/````
M<R`!`!````"#(`$`$````)0@`0`3````I2`!`!4```"Y(`$`&@```,\@`0`0
M````ZB`!`!8```#[(`$`#````!(A`0`M````'R$!`!H```!-(0$`'P```&@A
M`0`1````B"$!`!P```":(0$`!P```+<A`0`'````OR$!`#D```#'(0$`"```
M``$B`0`(````"B(!``P````3(@$`"````"`B`0`'````*2(!``@````Q(@$`
M"````#HB`0`+````0R(!``4```!/(@$`&@```%4B`0`,````<"(!``P```!]
M(@$`%````(HB`0`4````GR(!`"$```"T(@$`#@```-8B`0`?````Y2(!`!T`
M```%(P$`(@```",C`0`>````1B,!`!4```!E(P$`%````'LC`0`.````D",!
M`!L```"?(P$`!@```+LC`0`&````PB,!``<```#)(P$`&0```-$C`0`)````
MZR,!``H```#U(P$`$@`````D`0`'````$R0!`!4````;)`$`%P```#$D`0`+
M````220!``@```!5)`$`%P```%XD`0`3````=B0!`!D```"*)`$`,P```*0D
M`0`)````V"0!``@```#B)`$`%0```.LD`0`%`````24!``4````')0$`'0``
M``TE`0`+````*R4!`"`````W)0$`+@```%@E`0`5````AR4!`"@```"=)0$`
M*@```,8E`0`K````\24!`"L````=)@$`"0```$DF`0`)````4R8!``H```!=
M)@$`"````&@F`0`O````<28!`"P```"A)@$`+@```,XF`0!0````_28!`"T`
M``!.)P$`+0```'PG`0`M````JB<!`#\```#8)P$`*0```!@H`0`K````0B@!
M`"T```!N*`$`,P```)PH`0`4````T"@!`!@```#E*`$`*@```/XH`0`G````
M*2D!``X```!1*0$`#0```&`I`0`1````;BD!``4```"`*0$`"P```(8I`0`A
M````DBD!`"8```"T*0$`!P```-LI`0`)````XRD!`!8```#M*0$`"@````0J
M`0`*````#RH!``X````:*@$`"P```"DJ`0`'````-2H!``<````]*@$`!P``
M`$4J`0`(````32H!``<```!6*@$`"P```%XJ`0`0````:BH!``L```![*@$`
M"@```(<J`0`(````DBH!``<```";*@$`!P```*,J`0`0````JRH!``<```"\
M*@$`%@```,0J`0`%````VRH!``@```#A*@$`"````.HJ`0`*````\RH!``D`
M``#^*@$`(`````@K`0`5````*2L!``D````_*P$`$0```$DK`0`.````6RL!
M``D```!J*P$``P```'0K`0`#````>"L!`!<```!\*P$`%````)0K`0`+````
MJ2L!``0```"U*P$`"````+HK`0`)````PRL!`$\```#-*P$`*@```!TL`0`&
M````2"P!``@```!/+`$`'````%@L`0`<````=2P!`"$```"2+`$`*````+0L
M`0`?````W2P!`"D```#]+`$`6````"<M`0`L````@"T!``H```"M+0$`"P``
M`+@M`0`+````Q"T!``T```#0+0$`$0```-XM`0`0````\"T!``X````!+@$`
M$````!`N`0`2````(2X!`!,````T+@$`$P```$@N`0`&````7"X!`!P```!C
M+@$`'@```(`N`0`3````GRX!`!(```"S+@$`!0```,8N`0`(````S"X!`&(`
M``#5+@$`"````#@O`0`6````02\!``0```!8+P$`!@```%TO`0`<````9"\!
M`!L```"!+P$`%@```)TO`0`;````M"\!`"$```#0+P$`)````/(O`0`+````
M%S`!``\````C,`$`!@```#,P`0`8````.C`!`!T```!3,`$`&P```'$P`0`;
M````C3`!``4```"I,`$`$P```*\P`0`.````PS`!``D```#2,`$`"0```-PP
M`0`6````YC`!`!L```#],`$`"0```!DQ`0`&````(S$!`!(````J,0$`%```
M`#TQ`0`+````4C$!`!4```!>,0$`"````'0Q`0`'````?3$!`!````"%,0$`
M"@```)8Q`0`.````H3$!``<```"P,0$`"0```+@Q`0`,````PC$!``<```#/
M,0$`%````-<Q`0`/````[#$!`!4```#\,0$`!@```!(R`0`<````&3(!`!4`
M```V,@$`%@```$PR`0`Q````8S(!`#X```"5,@$`)P```-0R`0`R````_#(!
M``4````O,P$`"@```#4S`0`.````0#,!``D```!/,P$`%0```%DS`0`*````
M;S,!`!8```!Z,P$`'@```)$S`0`?````L#,!`"$```#0,P$`(@```/(S`0`=
M````%30!`"@````S-`$`'P```%PT`0`I````?#0!`!\```"F-`$`(@```,8T
M`0`>````Z30!`"H````(-0$`*P```#,U`0`C````7S4!`"D```"#-0$`,```
M`*TU`0`O````WC4!`!8````.-@$`+@```"4V`0`5````5#8!`+<```!J-@$`
M$@```"(W`0`B````-3<!`"<```!8-P$`)P```(`W`0`E````J#<!`!P```#.
M-P$`(````.LW`0`O````##@!`"`````\.`$`(````%TX`0`L````?C@!`$<`
M``"K.`$`#P```/,X`0`(`````SD!``8````,.0$`!P```!,Y`0`/````&SD!
M`!0````K.0$`%````$`Y`0`0````53D!`!L```!F.0$`"````((Y`0`$````
MBSD!`!$```"0.0$`$0```*(Y`0`6````M#D!`!0```#+.0$`$@```.`Y`0`S
M````\SD!``@````G.@$`%````#`Z`0`&````13H!`!$```!,.@$`%P```%XZ
M`0`?````=CH!`!(```"6.@$``@```*DZ`0`'````K#H!`!<```"T.@$`!```
M`,PZ`0`%````T3H!`!(```#7.@$`!0```.HZ`0`2````\#H!``<````#.P$`
M%0````L[`0`5````(3L!`!(````W.P$`%````$H[`0`+````7SL!``@```!K
M.P$`#@```'0[`0`.````@SL!`!D```"2.P$`#0```*P[`0`1````NCL!`"H`
M``#,.P$`#P```/<[`0`:````!SP!`!0````B/`$`$P```#<\`0`1````2SP!
M``8```!=/`$`$P```&0\`0`)````>#P!`"X```""/`$`+0```+$\`0`(````
MWSP!``D```#H/`$`'0```/(\`0`+````$#T!`!H````</0$`&@```#<]`0`)
M````4CT!`!H```!</0$`%0```'<]`0`5````C3T!`!,```"C/0$`'````+<]
M`0`(````U#T!``@```#=/0$`*@```.8]`0`B````$3X!``@````T/@$`%```
M`#T^`0`*````4CX!``T```!=/@$`-````&L^`0`9````H#X!``<```"Z/@$`
M$0```,(^`0`#````U#X!``D```#8/@$`!@```.(^`0`7````Z3X!``\````!
M/P$`$````!$_`0`0````(C\!`!4````S/P$`$@```$D_`0`5````7#\!``<`
M``!R/P$`!P```'H_`0`*````@C\!``P```"-/P$``@```)H_`0`*````G3\!
M`!$```"H/P$`'P```+H_`0`A````VC\!``H```#\/P$`#@````=``0`3````
M%D`!`!L````J0`$`.P```$9``0`F````@D`!``X```"I0`$`$P```+A``0!R
M````S$`!`!D````_00$`$@```%E!`0`(````;$$!``8```!U00$`#@```'Q!
M`0`&````BT$!``@```"200$`!P```)M!`0`&````HT$!``X```"J00$`#0``
M`+E!`0`0````QT$!``T```#800$`&P```.9!`0`.`````D(!``H````10@$`
M"P```!Q"`0`'````*$(!``H````P0@$`#P```#M"`0`\````2T(!``X```"(
M0@$`"@```)="`0`-````HD(!`!P```"P0@$`'0```,U"`0`H````ZT(!`"<`
M```40P$`'0```#Q#`0`<````6D,!`"(```!W0P$`&0```)I#`0`'````M$,!
M`!H```"\0P$`#````-=#`0`&````Y$,!``<```#K0P$`"@```/-#`0`,````
M_D,!`!,````+1`$`!@```!]$`0`9````)D0!`!P```!`1`$`#P```%U$`0`1
M````;40!`!(```!_1`$`#P```))$`0`B````HD0!``<```#%1`$`!P```,U$
M`0`,````U40!`!(```#B1`$`%P```/5$`0`+````#44!``H````910$`!0``
M`"1%`0`9````*D4!``T```!$10$`!P```%)%`0`I````6D4!`!(```"$10$`
MAP```)=%`0`:````'T8!``8````Z1@$`!0```$%&`0`,````1T8!``8```!4
M1@$`"````%M&`0`*````9$8!``P```!O1@$`!0```'Q&`0`)````@D8!``H`
M``",1@$`%@```)=&`0`2````KD8!`!8```#!1@$`(````-A&`0`#````^48!
M``0```#]1@$`$`````)'`0`(````$T<!``T````<1P$`!P```"I'`0`U````
M,D<!``D```!H1P$`!P```')'`0`7````>D<!`!(```"21P$`!P```*5'`0`)
M````K4<!``0```"W1P$`"P```+Q'`0`&````R$<!``8```#/1P$`!P```-9'
M`0`.````WD<!``L```#M1P$`"````/E'`0`6`````D@!``L````92`$`!P``
M`"5(`0`6````+4@!`"$```!$2`$`!@```&9(`0`)````;4@!``4```!W2`$`
M"0```'U(`0`'````AT@!``T```"/2`$`#````)U(`0`'````JD@!``X```"R
M2`$`!@```,%(`0`$````R$@!`#,```#-2`$`-P````%)`0`V````.4D!`"``
M``!P20$`!@```)%)`0`/````F$D!``4```"H20$`"````*Y)`0`>````MTD!
M`!8```#620$`!P```.U)`0`'````]4D!`"````#]20$`#0```!Y*`0`)````
M+$H!`!L````V2@$`!@```%)*`0`)````64H!`"0```!C2@$`"````(A*`0`,
M````D4H!``X```">2@$`"````*U*`0`)````MDH!``@```#`2@$`,P```,E*
M`0`O````_4H!`#(````M2P$`)@```&!+`0!&````ATL!`#H```#.2P$`*@``
M``E,`0`R````-$P!`#(```!G3`$`,P```)I,`0`E````SDP!`!(```#T3`$`
M$P````=-`0`.````&TT!`"`````J30$`'P```$M-`0`?````:TT!`!T```"+
M30$`"0```*E-`0`+````LTT!``H```"_30$`"````,I-`0`G````TTT!`"@`
M``#[30$`,````"1.`0`*````54X!`!D```!@3@$`(P```'I.`0`.````GDX!
M`!<```"M3@$`"0```,5.`0`/````STX!`!4```#?3@$`$P```/5.`0`H````
M"4\!`&D````R3P$`%0```)Q/`0`0````LD\!`!$```##3P$`&0```-5/`0`:
M````[T\!`!4````*4`$`!P```"!0`0`5````*%`!`!(````^4`$`#@```%%0
M`0`8````8%`!`!H```!Y4`$`,0```)10`0"C````QE`!`!4```!J40$`!@``
M`(!1`0`7````AU$!``H```"?40$`"P```*I1`0`+````ME$!`!L```#"40$`
M$P```-Y1`0`/````\E$!``\````"4@$`&0```!)2`0`O````+%(!`"X```!<
M4@$`+````(M2`0`K````N%(!`",```#D4@$`(@````A3`0`;````*U,!`$$`
M``!'4P$`$@```(E3`0`6````G%,!`!D```"S4P$`&````,U3`0`/````YE,!
M`!<```#V4P$`&P````Y4`0`4````*E0!`!@````_5`$`+P```%A4`0`=````
MB%0!`!D```"F5`$`,0```,!4`0`2````\E0!``@````%50$`#P````Y5`0`D
M````'E4!`!0```!#50$`#P```%A5`0`;````:%4!`!0```"$50$`&@```)E5
M`0`5````M%4!`!T```#*50$`(P```.A5`0`>````#%8!`!<````K5@$`%```
M`$-6`0`=````6%8!`!P```!V5@$`"P```)-6`0`:````GU8!``8```"Z5@$`
M!@```,%6`0`)````R%8!`!,```#25@$`"````.96`0`)````[U8!``@```#Y
M5@$`!P````)7`0`'````"E<!``8````25P$`"````!E7`0`7````(E<!``<`
M```Z5P$`"0```$)7`0`%````3%<!``@```!25P$`!@```%M7`0`/````8E<!
M``X```!R5P$`$````(%7`0`1````DE<!``L```"D5P$`%````+!7`0`&````
MQ5<!`"P```#,5P$`$P```/E7`0`-````#5@!``\````;6`$`"P```"M8`0`+
M````-U@!`!(```!#6`$`)P```%98`0`&````?E@!``D```"%6`$`)P```(]8
M`0`2````MU@!`!4```#*6`$`"````.!8`0`)````Z5@!``L```#S6`$`!0``
M`/]8`0`E````!5D!``H````K60$`%````#99`0`+````2UD!`!P```!760$`
M*0```'19`0`8````GED!``<```"W60$`!0```+]9`0`*````Q5D!`#````#0
M60$`!P````%:`0`'````"5H!`!$````16@$`$P```"-:`0`'````-UH!``@`
M```_6@$`%@```$A:`0`.````7UH!``X```!N6@$`$````'U:`0`5````CEH!
M`!<```"D6@$`#P```+Q:`0`=````S%H!`!$```#J6@$`$@```/Q:`0`)````
M#UL!``<````96P$`"@```"%;`0`Y````+%L!``@```!F6P$`%````&];`0`O
M````A%L!`!L```"T6P$`%0```-!;`0`6````YEL!`!8```#]6P$`%0```!1<
M`0`0````*EP!`!@````[7`$`%0```%1<`0`>````:EP!`!P```")7`$`'0``
M`*9<`0`*````Q%P!``<```#/7`$`"0```-=<`0`1````X5P!`!````#S7`$`
M!0````1=`0`+````"ET!``H````670$`$P```"%=`0!4````-5T!`!4```"*
M70$`#0```*!=`0`%````KET!``@```"T70$`&@```+U=`0`:````V%T!`!H`
M``#S70$`#0````Y>`0`"````'%X!``0````?7@$`*````"1>`0`#````35X!
M``4```!17@$`"@```%=>`0`,````8EX!``8```!O7@$`!@```'9>`0`.````
M?5X!`!,```",7@$`!P```*!>`0`)````J%X!``@```"R7@$`!0```+M>`0`%
M````P5X!`%<```#'7@$`#P```!]?`0`2````+U\!``4```!"7P$`!P```$A?
M`0`C````4%\!`#$```!T7P$`#0```*9?`0`)````M%\!``\```"^7P$`"P``
M`,Y?`0`*````VE\!`!0```#E7P$`*P```/I?`0`:````)F`!`!D```!!8`$`
M$````%M@`0`&````;&`!``8```!S8`$`"````'I@`0`&````@V`!``X```"*
M8`$`#@```)E@`0`&````J&`!`$P```"O8`$`$@```/Q@`0`-````#V$!``L`
M```=80$`%@```"EA`0!$````0&$!``<```"%80$`!0```(UA`0`'````DV$!
M`"(```";80$`"````+YA`0`*````QV$!`!D```#280$`&@```.QA`0`)````
M!V(!``4````18@$`(P```!=B`0!)````.V(!`!````"%8@$`)P```)9B`0`0
M````OF(!``4```#/8@$`#@```-5B`0`)````Y&(!``\```#N8@$`"@```/YB
M`0`'````"6,!`!,````18P$`!P```"5C`0`)````+6,!`!$````W8P$`"@``
M`$EC`0`*````5&,!``T```!?8P$`!P```&UC`0`1````=6,!`!0```"'8P$`
M$@```)QC`0`/````KV,!`!````"_8P$`$0```-!C`0`1````XF,!`!````#T
M8P$`$@````5D`0`*````&&0!`"8````C9`$`$P```$ID`0`-````7F0!``T`
M``!L9`$`%P```'ID`0`)````DF0!``T```"<9`$`!@```*ID`0`(````L60!
M``8```"Z9`$`!P```,%D`0`+````R60!`!(```#59`$`%0```.AD`0`A````
M_F0!`!\````@90$`&````$!E`0`6````664!`!P```!P90$`'@```(UE`0`:
M````K&4!``<```#'90$`!P```,]E`0`2````UV4!`!````#J90$`#@```/ME
M`0`C````"F8!`!$````N9@$`%@```$!F`0`)````5V8!``\```!A9@$`"```
M`'%F`0`3````>F8!``D```".9@$`!P```)AF`0`(````H&8!``8```"I9@$`
M!0```+!F`0`"````MF8!`"4```"Y9@$`(@```-]F`0`7`````F<!`"`````:
M9P$`-````#MG`0`.````<&<!`",```!_9P$`*````*-G`0`M````S&<!`"T`
M``#Z9P$`,@```"AH`0`4````6V@!`!(```!P:`$`$@```(-H`0`4````EF@!
M`!(```"K:`$`$````+YH`0`2````SV@!`!P```#B:`$`+0```/]H`0`M````
M+6D!`#$```!;:0$`+@```(UI`0`O````O&D!`"P```#L:0$`8````!EJ`0`@
M````>FH!`!(```";:@$`$0```*YJ`0`D````P&H!`#$```#E:@$`&0```!=K
M`0`-````,6L!`$`````_:P$`0````(!K`0`*````P6L!``0```#,:P$`%0``
M`-%K`0`.````YVL!`!(```#V:P$`&`````EL`0`)````(FP!``@````L;`$`
M#````#5L`0`,````0FP!``T```!/;`$`"@```%UL`0`-````:&P!``<```!V
M;`$`(0```'YL`0`)````H&P!``<```"J;`$`$0```+)L`0`2````Q&P!`!``
M``#7;`$`,P```.AL`0`"````'&T!``@````?;0$`$@```"AM`0`+````.VT!
M``8```!';0$`$````$YM`0`&````7VT!``8```!F;0$`+P```&UM`0`8````
MG6T!`"@```"V;0$`5@```-]M`0`7````-FX!`",```!.;@$`$@```')N`0`*
M````A6X!``T```"0;@$`$P```)YN`0`,````LFX!``D```"_;@$`#````,EN
M`0`?````UFX!`!<```#V;@$`!`````YO`0`0````$V\!`!$````D;P$`)0``
M`#9O`0`8````7&\!`!D```!U;P$`$P```(]O`0`A````HV\!``D```#%;P$`
M!P```,]O`0`1````UV\!``D```#I;P$`"@```/-O`0`(````_F\!``T````'
M<`$`"@```!5P`0`%````('`!`!X````F<`$`!@```$5P`0`5````3'`!``H`
M``!B<`$`$0```&UP`0`+````?W`!`!<```"+<`$`+````*-P`0`;````T'`!
M``P```#L<`$`#0```/EP`0`;````!W$!``8````C<0$`*P```"IQ`0`&````
M5G$!`!T```!=<0$`!@```'MQ`0`)````@G$!`!\```",<0$`-0```*QQ`0`&
M````XG$!`!8```#I<0$`%`````!R`0`$````%7(!``<````:<@$`"0```")R
M`0`)````+'(!``H````V<@$`"0```$%R`0`)````2W(!``D```!5<@$`&P``
M`%]R`0`U````>W(!`#X```"Q<@$`&0```/!R`0`G````"G,!`!P````R<P$`
M/````$]S`0`8````C',!`!0```"E<P$`+@```+IS`0`F````Z7,!``<````0
M=`$`"0```!AT`0`*````(G0!``L````M=`$`%0```#ET`0`1````3W0!`"D`
M``!A=`$`(````(MT`0`N````K'0!`#,```#;=`$`!@````]U`0`5````%G4!
M``@````L=0$`"````#5U`0`D````/G4!`!0```!C=0$`%@```'AU`0`0````
MCW4!``@```"@=0$`$P```*EU`0`)````O74!`!````#'=0$`#P```-AU`0`8
M````Z'4!`"H````!=@$`#````"QV`0`'````.78!``<```!!=@$`'@```$EV
M`0`4````:'8!``8```!]=@$`"P```(1V`0`-````D'8!``8```">=@$`$0``
M`*5V`0`(````MW8!``@```#`=@$`$P```,EV`0`P````W78!`$,````.=P$`
M&P```%)W`0`D````;G<!`!H```"3=P$`!0```*YW`0`0````M'<!``@```#%
M=P$`$````,YW`0`L````WW<!``@````,>`$`#P```!5X`0`3````)7@!`!8`
M```Y>`$`#0```%!X`0`\````7G@!``D```";>`$`(@```*5X`0`2````R'@!
M`!8```#;>`$`+````/)X`0`(````'WD!`!,````H>0$`%0```#QY`0`*````
M4GD!`!,```!=>0$`"````'%Y`0`7````>GD!`!P```"2>0$`!@```*]Y`0`(
M````MGD!`!(```"_>0$`%````-)Y`0`6````YWD!``0```#^>0$`"`````-Z
M`0`+````#'H!``X````8>@$`#P```"=Z`0`2````-WH!`!(```!*>@$`"```
M`%UZ`0`)````9GH!`"@```!P>@$`'````)EZ`0`:````MGH!``<```#1>@$`
M$@```-EZ`0`&````['H!``X```#S>@$`&0````)[`0`F````''L!``L```!#
M>P$`!P```$][`0`#````5WL!``8```!;>P$`"````&)[`0`%````:WL!``\`
M``!Q>P$`%P```(%[`0`-````F7L!`!T```"G>P$`'0```,5[`0`:````XWL!
M``4```#^>P$`"P````1\`0`4````$'P!``D````E?`$`#0```"]\`0`)````
M/7P!``P```!'?`$`%````%1\`0!6````:7P!`!@```#`?`$`!P```-E\`0`'
M````X7P!``<```#I?`$`$@```/%\`0`0````!'T!`!$````5?0$`&P```"=]
M`0`3````0WT!`!4```!7?0$`)````&U]`0`3````DGT!`&(```"F?0$`&P``
M``E^`0`:````)7X!`"D```!`?@$`&P```&I^`0`:````AGX!`"0```"A?@$`
M&@```,9^`0`9````X7X!`!H```#[?@$`"@```!9_`0`)````(7\!``L````K
M?P$`"````#=_`0`6````0'\!``\```!7?P$`%0```&=_`0`(````?7\!`%``
M``"&?P$`00```-=_`0`H````&8`!`$\```!"@`$`&P```)*``0`K````KH`!
M``@```#:@`$`"@```..``0`1````[H`!`"D`````@0$`!@```"J!`0!-````
M,8$!`"4```!_@0$`(0```*6!`0`2````QX$!`"````#:@0$`&````/N!`0`<
M````%((!`!\````Q@@$`'@```%&"`0`C````<((!`!0```"4@@$`!@```*F"
M`0`+````L((!``T```"\@@$`"0```,J"`0`J````U((!``L```#_@@$`#```
M``N#`0`'````&(,!`!$````@@P$`"@```#*#`0`%````/8,!`!8```!#@P$`
M"0```%J#`0`)````9(,!``0```!N@P$`#@```'.#`0`8````@H,!``X```";
M@P$`!P```*J#`0`5````LH,!`!X```#(@P$`$````.>#`0`,````^(,!`!H`
M```%A`$`*````""$`0`1````280!`!$```!;A`$`)@```&V$`0`&````E(0!
M`!$```";A`$`!@```*V$`0`(````M(0!``8```"]A`$`'0```,2$`0`.````
MXH0!`!(```#QA`$`$`````2%`0`'````%84!``D````=A0$`"@```">%`0`,
M````,H4!``\````_A0$`%P```$^%`0`&````9X4!`!(```!NA0$`#@```(&%
M`0`)````D(4!``X```":A0$`&````*F%`0`-````PH4!``4```#0A0$`!```
M`-:%`0`&````VX4!``@```#BA0$`"````.N%`0!4````](4!`#0```!)A@$`
M&0```'Z&`0`'````F(8!``<```"@A@$`"@```*B&`0`*````LX8!``<```"^
MA@$`"@```,:&`0`5````T88!``P```#GA@$`"@```/2&`0`,````_X8!``@`
M```,AP$`#````!6'`0`)````(H<!``<````LAP$`&````#2'`0`+````38<!
M``<```!9AP$`"@```&&'`0`E````;(<!`!@```"2AP$`!P```*N'`0`(````
MLX<!``H```"\AP$`!P```,>'`0`3````SX<!`!,```#CAP$`"````/>'`0`<
M`````(@!``T````=B`$`'@```"N(`0`)````2H@!``8```!4B`$`$````%N(
M`0`5````;(@!``L```""B`$`#0```(Z(`0`7````G(@!``<```"TB`$`"P``
M`+R(`0`/````R(@!``X```#8B`$`!0```.>(`0`8````[8@!``D````&B0$`
M'````!")`0`1````+8D!`#,````_B0$`)@```'.)`0`C````FHD!`'L```"^
MB0$`%````#J*`0`_````3XH!`#0```"/B@$`10```,2*`0!#````"HL!`!\`
M``!.BP$`9````&Z+`0`F````TXL!`#,```#ZBP$`*@```"Z,`0`3````68P!
M`!@```!MC`$`?0$``(:,`0`7````!(X!`!(````<C@$`.````"^.`0"!````
M:(X!`#P```#JC@$`-P```">/`0!)````7X\!`$0```"ICP$`'@```.Z/`0`3
M````#9`!`!@````AD`$`&0```#J0`0`D````5)`!`!T```!YD`$`(P```)>0
M`0`4````NY`!`!L```#0D`$`(0```.R0`0`7````#I$!``\````FD0$`,```
M`#:1`0!;````9Y$!`"P```##D0$`4@```/"1`0`Y````0Y(!`",```!]D@$`
M)@```*&2`0`C````R)(!`$<```#LD@$`1P```#23`0`]````?),!`#P```"Z
MDP$`,````/>3`0`J````*)0!`"H```!3E`$`+0```'Z4`0!G````K)0!`&4`
M```4E0$`JP```'J5`0`6````)I8!`"T````]E@$`,0```&N6`0`P````G98!
M`$D```#.E@$`'@```!B7`0!.````-Y<!`!8```"&EP$`!P```)V7`0"Q````
MI9<!`$4```!7F`$`*````)V8`0`S````QI@!`!H```#ZF`$`'@```!69`0`N
M````-)D!``D```!CF0$`"````&V9`0`&````=ID!``X```!]F0$`#@```(R9
M`0`2````FYD!``H```"NF0$`"````+F9`0`,````PID!``,```#/F0$`;```
M`-.9`0`(````0)H!`!````!)F@$`!0```%J:`0`'````8)H!``4```!HF@$`
M!0```&Z:`0`'````=)H!`!D```!\F@$`"````)::`0`5````GYH!``P```"U
MF@$`!0```,*:`0`'````R)H!``<```#0F@$`%0```-B:`0`*````[IH!`!<`
M``#YF@$`!@```!&;`0`;````&)L!``\````TFP$``P```$2;`0`F````2)L!
M``0```!OFP$`!@```'2;`0`'````>YL!`"(```"#FP$`00```*:;`0`H````
MZ)L!`"H````1G`$`%@```#R<`0`G````4YP!`"````![G`$`'P```)R<`0`C
M````O)P!`!X```#@G`$`&P```/^<`0`B````&YT!`!X````^G0$`*P```%V=
M`0`I````B9T!`"L```"SG0$`'P```-^=`0`C````_YT!`"$````CG@$`'```
M`$6>`0`F````8IX!`"<```")G@$`(P```+&>`0`>````U9X!`!P```#TG@$`
M(@```!&?`0`E````-)\!`!T```!:GP$`)0```'B?`0`F````GI\!`#H```#%
MGP$`(0````"@`0`E````(J`!`",```!(H`$`)````&R@`0`>````D:`!`!P`
M``"PH`$`)````,V@`0`@````\J`!`"L````3H0$`(P```#^A`0`)````8Z$!
M`!,```!MH0$`&@```(&A`0`:````G*$!`!H```"WH0$`"@```-*A`0`0````
MW:$!`!D```#NH0$`$@````BB`0`3````&Z(!`"(````OH@$`"````%*B`0`)
M````6Z(!`"0```!EH@$`)P```(JB`0`O````LJ(!`"$```#BH@$`#`````2C
M`0#Z````$:,!`!$````,I`$`%0```!ZD`0`*````-*0!``T````_I`$`%```
M`$VD`0`?````8J0!``@```""I`$`,0```(ND`0`<````O:0!`!H```#:I`$`
M"0```/6D`0`5````_Z0!``L````5I0$`10```"&E`0`O````9Z4!`!D```"7
MI0$`%````+&E`0`6````QJ4!`"````#=I0$`$````/ZE`0`1````#Z8!`!(`
M```AI@$`&P```#2F`0`,````4*8!`!L```!=I@$`"0```'FF`0`;````@Z8!
M``H```"?I@$`'````*JF`0`(````QZ8!`",```#0I@$`!P```/2F`0`)````
M_*8!``D````&IP$`,0```!"G`0`'````0J<!`!````!*IP$`%````%NG`0`1
M````<*<!``L```""IP$`#0```(ZG`0`)````G*<!`!<```"FIP$`#0```+ZG
M`0`6````S*<!`!(```#CIP$`%P```/:G`0`5````#J@!``D````DJ`$`"P``
M`"ZH`0`9````.J@!``0```!4J`$`*@```%FH`0`/````A*@!``<```"4J`$`
M!0```)RH`0`,````HJ@!`!(```"OJ`$`"P```,*H`0`#````SJ@!``P```#2
MJ`$`"P```-^H`0`&````ZZ@!`!(```#RJ`$`"0````6I`0`3````#ZD!`!0`
M```CJ0$`#@```#BI`0`K````1ZD!`!<```!SJ0$`%@```(NI`0`,````HJD!
M`"0```"OJ0$`!@```-2I`0`1````VZD!`$8```#MJ0$`#P```#2J`0`,````
M1*H!``<```!1J@$`!````%FJ`0`4````7JH!``8```!SJ@$`!P```'JJ`0`(
M````@JH!``8```"+J@$`#0```)*J`0`/````H*H!``4```"PJ@$`'@```+:J
M`0`B````U:H!`!H```#XJ@$`'0```!.K`0`/````,:L!``(```!!JP$`!```
M`$2K`0`0````2:L!``8```!:JP$`!P```&&K`0`$````::L!`!````!NJP$`
M1P```'^K`0`1````QZL!`"D```#9JP$`)`````.L`0!$````**P!`!````!M
MK`$`90```'ZL`0`;````Y*P!`%@`````K0$`+@```%FM`0`6````B*T!`#``
M``"?K0$`,P```-"M`0`D````!*X!`",````IK@$`)P```$VN`0`3````=:X!
M`#````")K@$`,````+JN`0`7````ZZX!`!(````#KP$`%````!:O`0!/````
M*Z\!`!,```![KP$`;0```(^O`0!4````_:\!`"<```!2L`$`$@```'JP`0`:
M````C;`!`!0```"HL`$`(@```+VP`0`;````X+`!`!H```#\L`$`7````!>Q
M`0`6````=+$!``L```"+L0$`!@```)>Q`0`'````GK$!``@```"FL0$`"@``
M`*^Q`0`;````NK$!`!8```#6L0$`&@```.VQ`0`F````"+(!`!$````OL@$`
M"0```$&R`0`$````2[(!``X```!0L@$`$````%^R`0`'````<+(!``@```!X
ML@$`&P```(&R`0`,````G;(!``L```"JL@$`$0```+:R`0`+````R+(!``<`
M``#4L@$`%````-RR`0`.````\;(!`!<`````LP$`"P```!BS`0`.````)+,!
M``L````SLP$`!0```#^S`0`-````1;,!``8```!3LP$`!@```%JS`0`1````
M8;,!``(```!SLP$`"@```':S`0`(````@;,!``@```"*LP$`)@```).S`0`&
M````NK,!``P```#!LP$`$````,ZS`0`.````W[,!``D```#NLP$`"0```/BS
M`0`$`````K0!`!`````'M`$`$@```!BT`0`'````*[0!``T````SM`$`(P``
M`$&T`0`*````9;0!``4```!PM`$`%@```':T`0`%````C;0!``(```"3M`$`
M"P```):T`0`!````$`,``(<"```:`P``JP4````````?`@``3@$``#4$``"H
M!0``2@(`````````````YP,```````"0!```H`$``*H!````````Q0(`````
M``!%!0```````)\%````````:`0`````````````*0(``"@#``!'!@``]```
M`"\&```Q`@```P,`````````````]0```"\%``!5!@``90,```````!N`P``
M&@$```````!<`0```````+L````F`@``S`$```````!G!```<00``#P!``"[
M`0```````-D"``!9`@``(P,``)X"``"*!```80```````````````````#,#
M`````````````*D#``"_!``````````````^!```?@```#X!``#[````````
M```````K`P``X@4```````!@````80,``*8!``"K`@``X`0`````````````
M.@$``"@$``#2`@``WP4``!(#``!9!````````'(&````````LP0``!L#``"A
M!0````````````#V`0```````(P$````````300``$T%``"\`0``````````
M``"4!0``YP4`````````````"`(```````!'````6P0``#($````````````
M`"D`````````LP$````````!`0``'0,```````!:!@``HP```$D%``"0`@``
M```````````3!@``?P$```````#^`0``GP,``&X&``````````````````"I
M`0``C@````````"3````;P0``-\$```8!``````````````V`0``FP4`````
M``#,`@``@0,````````=`@``+@$``(($```S!0``8P8```````#/!0``YP$`
M````````````-P```%H```#Y!```IP(``&0#``"Y`@```````*8#````````
M`````)0!```_`0``B00``,<$``"R`P``O`(```````#A````&0````````!8
M``````````````".`0``,P$```````"\````/P0``*D"``"C`0``"@(``*T`
M```E!@```````"L$``"5````!`(```````!2`````````"T`````````0P8`
M`&0"``#<!```+08```````"W`P````````````!R!0``[@,``,(#````````
M``````````````````````````!]!````@$```P#```]`@``G0,``(T$````
M````E0$``/<"``#!````3@4````````F`P``?`,``.T```"%`0``_`(``/X"
M```2!0````````H!``"R``````````````"S!0``PP(``&(%```3`0``K@0`
M`$@"``!,!```S@```"H$````````"`8``"\````>````6P8``"8%``!W`P``
M`````.\#``"9!0``T@$``/H%``!&!0``T0$``!`"```X!@``4`(``*$#``#A
M!0``,@4``!0!```8!@``:08``#,$``".`P```@0``$\$``!:!```B`(``#8%
M``!&`P```@(``&8%``!9`P``408``$<!```+`@``4P(``"\$````````D@``
M`,\#``!!`0``]00`````````````_@```(0```!-!@``MP(``#L"````````
MSP$```8$````````U0,```4!``#;!````````-$%``#``0``=P4````````1
M````3@````````#-!```N@(```````!$!@``"0,````````H`@``>04``(H!
M``#_!```+00``!H$``!=!0``[P(``$0"````````K`$``&X"```O`P``O`,`
M``T&``#S!```_`$``*,%``"]`@``C0$``),$``!B`@``-0,``%8"``"8!```
M(@0``)$!``#X````5@```-(%``#M`P``Y0```.H````>`0``=@```'L#``!6
M`P```````#(```!Y````A0,``/@$``"P`@``\@4```````"=`0``9`````0!
M``"V`P``90```-$```!0!```608``#\````R`@``2P4`````````````````
M`-,$``"@!0````````8#``"H````=0,``/<%``!A!@``'`0``),"``!2!```
M$0(``(0#````````)0```/\#```````````````````A`P```````#T&``"]
M!0``-P,``````````````````","``")!0``"P8```````#>````FP```'0`
M````````I`(``#4"```^!@```````&L&```5!@``0P(``(\#``!7!@``G@0`
M````````````908``!\#````````K@(``!T!``#;`@``P`4``#X#``"[!0``
MD````/L#```>!@```````,H!``#,`````````#,`````````\P4``*X!````
M````W04``%8!`````````````-0````N!@``F@````````!;`P``N`$`````
M``"&`@``EP0`````````````'`4``%0````,!```Z````*\"````````D@0`
M`$,#``"I!0``M@(``#P$``"%!```>P````````#V`@``I0(``(0$```6`@``
M;`(``$(```#$`0``"@8`````````````E@$```````!=!```-`(``"`%````
M````$````%(#````````IP4``&T"``"T`@``Z04``'\#```[!```5@0``$D"
M````````8P```'$```!)````Q0$```````!<````FP$``'0"``!L````^0$`
M``````#``P``=P````````#R!```9@$``*X%``"J!0``G@,```````!X````
M`````#P"````````#@4```$#``!0`0``3@0``#H%```Z!```!0,``$X&````
M````H@``````````````4P0``(T#`````````````/(!````````_P4``(<!
M``"0`0``L04``(L#```@`````````,D!``"[!```M`0``,L%````````'P8`
M`)T%``!?`@```````&\"``!G`0```````-X"``",`````````-@"``!T`0``
MC`,``/("````````F@0``&<#``!$!```^`$``-@%`````````@,``(D```"E
M`0```````&L``````````````!$$```L`P``$`0``.$!```8!0```````*8"
M```W!0``?@4``+X#``````````0`````````````C@4``&`$``!%````JP$`
M`(L$``!\````UP,``+8`````````;`$``+<````0!0````````````"_`P``
M`````'0&``!-`@``[P0``(0!```L`0```````#0```#$`P``T0,````````Q
M`P``2`4``%,!````````[@0``&\%``#=`0```P$``"\"```L````1P(`````
M``#K`@``'P$``.`#``!*`P``<@(```````"J`@``K04``)X%````````"@0`
M`+\"```7!@``9@(``&8`````````%@```(@!``!3!0``)0,``+0```!"!```
M``````````#(`@``M00``#T```#E`P`````````````,!@``L`,``)(#``#6
M````2`0``!D"````````Y`,````````K`@``GP$``.0$```6!@```````&P#
M```,````NP(```````!B`P``````````````````+`0``"$```!2!@``B0,`
M```````*`P``;@$``(@`````````%P(``%$%```.`````````#4```"%`@``
M`````.0"``!L!0``>P0``&@```#Q`````````'@!``#Q`@```````%P%``"4
M!```G`4``$@```#<!0``VP```#T%````````\00```````#W!````````!@"
M``!8`P``6`4``)\```";!```"P0```````!*`````````"\!``"3`0``*@4`
M`````````````````+4%````````HP(``*$$````````C04```````!>!@``
M<@$``#P#``#:`P``Y@4``'0#``#[`@``@P4``.,$````````)0(``$L"````
M````````````````````10,```````#]!0``N`(``"L````Q`0``[04``)<"
M``"D!0```````,X$``"L!`````````X"``"*`@``*@,``-,"````````^04`
M````````````XP$``,0"````````2P,``!\$``#?````-@8``+T!``!3!@``
M`````````````````````!$&````````J`,```T!``",!0``DP,```````#@
M`0```````&`#``!>`0``Q`4``*\#```'!0``70,``%4$``":`P```````$0#
M````````.@8``&0&````````30$````````/`0``#P4``$<$``"Z!0``\P``
M`-$"``"Y````&`,``-<"``!Z`P``?`$``!D#``"4`P``KP$``%T!``!/````
M\@,``'@"``!B!@```````#(!``#G```````````````;!````````*$!````
M!@```````+,```"8`0``]@,``````````````````!D$``"#`@```````%\!
M```X`P``RP0``"0$````````)P4``/8```#Z````=@4``/(```"U`P``QP,`
M````````````!@8``,$"```5!```5`0``#$$``!C`P```````%P#``!?````
MZ0,``````````````````,L"``#5````,P(``$`!```X!0``N@```%X```!`
M`P``RP```.````#L!```T00``"@```#Q`P``AP,``%$"``"E!0``````````
M``!F!@``V`,``-4!```K`0``[`4``'P%``!-`P``$`$``"`&```Y`@``PP4`
M`!X#``!@`0``;04``(`#``!C`0``B0(```````"U`@``)P8``+T$````````
MEP4``%<$``````````````````"<`@``9@,``#0#```7````>`4````````1
M!0```````'(````B`P``R0(```````"T`P``B`4``'$!```-`P``1P4``%H#
M````````$@(``$8"```F`0``(@(``%`%``"G`````````*`#``!E`0``YP0`
M`.8!``"1`````````&H$``!9!0``%`,```X#``#L````IP$``#<"``!U`@``
M``````````!S`0````````````"6`@```````,4$``#*`P``@`(``&T#````
M````L`0```````!S!@``^@(``$D$``!-````X`(``%,```!;!0``T@,```@#
M```6`P```````)8$``#>!0``R0```*,$````````Z`(``+8!````````````
M`+P$``"U````@P```&<```!4!@````````````#D!0```````,T!``!5`P``
M_`4````````X!```6`(````````N`@``W@,``'X$`````````````"`$``#&
M`0``P`0``*P"``#6!```M@0``,8```"D`P``S04``/,!```A`0``QP4`````
M``!]`0```````"T%````````X@,``!0"``#L`0``=0```-8!```'!```R00`
M`%0!``!"`0```````%L!``"H`@``%``````````,!0`````````````N````
M`````#H"`````````````!P!```Z``````````````!5`@``=@(``*@!``"/
M!0``00,``&X$````````W00``"P&``"J`P``;P,```P"``!#!0``7@,``)(!
M``!)`P``)@8``#T#``"N````9P4``-0#`````````````/0%``#,!0``)`(`
M```````4!@``D0(```````"I````5P$``&$$``"M`@```````.L#````````
M``````````"?`@````````````"E`````````)\$``#:`0``!`0``#8#``#P
M!0``M0$``,($``#U!0``U@,``%8%``"M!```P0,``-@`````````#@$``'H$
M````````20$``-P"`````````````````````````````,8%``"1`P``4@$`
M`#\%````````8`(```````#B`0``7@0```````!L!```<`8``!$#```V`@``
M,````*P````6`0````(``+$```!J`P``X00````````R`P``(P$```````!P
M`P``TP4````````!!0```````",$````````````````````````$0$``&\!
M``"P````7`8``'4%```7`P```````-,!``#A`@``L0(``&D````#!@``O`4`
M`"$$````````>`0``-`!````````/`8``.(```"G`P``X@0```````"W`0``
MEP$```````"^!```*`8``$`$``#M!```$@```.4$`````````````.L$````
M````F@(`````````````"`0``-X!`````````````,,$````````ZP$``*X#
M``#C````<`(``$P&```=!@```````!8%``"1!```2@$``',$``"$`@``50``
M`.H!`````````````'($```W!@``F00``.H#```N!````P4``$<#``!?!```
M`````*P#``!^`@``>P$``+$$``!_````.04``,8$``!(`0``0@(````````I
M!@``-@0``(H```#M`0```````````````````````.@%````````Y@,``!`&
M``#E!0``@0```,H%`````P``<P,````````#`@``D`,``/\```!*!```````
M`"<```#[!```00```(8#``"/`0``)````(\````V````Q@(``&,"``!,`@``
M50$``'D!```X`@``JP```'L%````````_0(```````!.`P``DP4``&T```#W
M`P``;P```,X#``"!`@``F`(`````````````-P$```T```#/````A0`````%
M``"B!```7`0```````#)`P``[`(``)@````J`@``#P,`````````````7P8`
M`/X$```;!@``L0,``+@```"M`P``.00``#H#``#;!0``LP,```4&``#,!```
MOP```,T````'`@``40```/8%```[!0```````+L#``#O`````````.X"``!X
M`P`````````````9`0``"@4```````"'!```$P,``'\"`````````````*,#
M```T!0``504``#4%``"B!0```````&@"``!\!```_P$```8````.!@``904`
M`'(#``````````````````#K!0``&@(````````8`````````"T"``!H`P``
M6@$``',%````````5@8``.0````"!@````````````!+!@``P00```````!G
M!@``N00```````"8`P``G``````````G`0``100```<!``##`0``0`8```0`
M``"`````>0(``%<```!(`P```````(L"``""``````````````!B!```````
M`.<"``#(````]0$```4$``!1`P``U00```````")`0``!@4``)8#``"!!```
MKP0```````".!````````&T!``#'`0``"00``+X!```N!0````````D%```>
M`@``:P(``(@$``!=`@``M`4````````%`````````%@!```Y````````````
M``#3`P``U`$`````````````K0$``-D`````````*04``)0```!U!```,0``
M`-@!``!W!````````!L%``!J`@``P@````````!1!```UP$``$$&``"B`@``
M(`,``'<!``#J`@``\P,```````!9`0``V00``"0#``#T`P``BP```+X`````
M````"P,``,\$``#H!```)04``!L!``#(`P``2@8``#D#``"W!0``-`0``)8`
M```Y`0```````(L%``!Q`P```````"L&```3`@``CP(``$@&``!9````2P$`
M``````#3````(P4``*\`````````*0,``&$!``#X`@``208``!@!``!"!@``
MW0,```````!%`0```````)<#`````````````%$!`````````````#T!````
M````P0$``*0!``"&````9`$``$`%`````````````%0"``!0!@``J00``(H#
M`````````````-D%``"-`````````$P!```"!0``/`````````!@!@``PP,`
M`,X"````````F@$```````"K!```5P4``&(!````````_`,``+`!``#2````
MN@$``,@%``"_!0``708``.D`````````'00``&T$`````````````%0#````
M````#P8``)0"``"D!```:P4````````A!@``N@0```````!Z````^0(``&H%
M``#=`@``]0,```````!$````BP$``)4%``!M!@``@P0``+,"````````EP``
M`$$$````````G00``)4"``",`@``@@4``/H$`````````````%0%``#0`P``
M`````.@#```+!0```````(,#``#7````.P$```````"9`P``(@8`````````
M````]P$``.\%``!J`0``P@4``+\!``!J!@``804``!<$`````````````.8`
M``!O!@``!0(``'$%``!&`0``.`$```````#N!0``L@(`````````````````
M`'4!````````-P0```````"`!0``-`8```````!P`0``6`8``+@#````````
M3@(``#@````)`0``Q04`````````````MP0``'D#````````@`$``$P%```'
M`P``@04``',"``#!!0```````````````````````/T!``#F!````````&$"
M```N`P``3P(``+$!``#[!0```````)P#````````6`0``.T"``#:!0``=@0`
M`-`$``!!!0``:`8``,T#````````````````````````XP(``'$"```4!```
M;@4``*$"``!/!@``QP(``*8$````````?0(``-D#``!H`0```````-8%````
M````:`4``$P````5````D@(```$$``"F!0````$``#`"``#N`0``T`(``*$`
M``#'````'@0``%<"```H`0``^@$`````````````"`$``!(&````````F`4`
M`!H```"B`P``>@4``-P#```^!0``V0$``,L!```;`@``[`,``#`&````````
MXP4`````````````Q`0``"(!``#*!```WP(``'X!```K!0```````%T```#]
M````UP0``'T%``"^`@``#@0``#$&``!_!0``%0$``+@%``"&`0``!`,``,H`
M```+````D@4``(T"```?````^`,``/`"````````>00````````'````R@(`
M``````"&!0``AP4``.`%``!2!0``'````)L"``#6`@``N04``)D````[!@``
M7`(``'0$``!&````````````````````.08``'<"``"H!````````'`$``"J
M!``````````````@`@``'04``$8&````````]0(``#\#``"5!```````````
M`````````````+`%```U!@``?P0``.0!``#:````]`$``!H%``!Z`0``M`$`
M`-L#``#I`0```````(`$``#$````@@$````````_!@``"08``&L!``#5!0``
M`````*P%````````@@(```$&```/!````````!L`````````!04```L!````
M````I0,````````[`P``_00``.@!```P`P``0P0``-0"```<`P``WP,```H`
M``"K`P``\`$``&L#````````:0$``-H"``#4!````0(``!D&``#-`@``*0$`
M````````````(`$````````F!```9P(``/T#``#;`0``B@4``$\!``#.`0``
M`````.X```#:!`````````D"``!V`P``1@0```````"R!```3P,```8"``!F
M!```$@0``)X!````````5P,``+H#```]!```)P(````````B!0``_@4`````
M``#P`P``'0```'````!E!```Q@,```````!#`0``#04```0&````````CP0`
M`&(```!+!````````+(!``#I`@``]`(``$0%``!0````T@0````````-`@``
M"0```%L"```3````L@4```````!I`P``-`$``!P"``"9`@``!P8``&X`````
M````/@(``/D#```3!```)00``*`"``!,`P``&04```````#J!```````````
M``#Q!0```````.4!``#K`````@`````````7!0``>P(``.("```G`P``J@``
M`)4#``#(`0```````+X%``#W````3P4``!4%``!0`P``*@```+T#````````
MA@0``````````````````-````#?`0``)`8````````[`````````)T"```C
M````(0(```````!3`P``*@8``,("``"X!```%P$``(0%```B````=@$``/H#
M``"Y`P``:0(``)H%``!P!0``]@0``/`$````````Q0,````````E`0``0@4`
M`#`$```````````````````#`````````)L#``#``@``(04``#(&```F````
M?0,``&0$``````````````@%``"(`P``````````````````I@```/\"````
M````1`$``%X%``!Z`@``^`4``",&``#4!0``G`$``#,&````````8P0``$$"
M````````@P$``*<$````````#00``%H%`````````````!8$```Q!0``````
M```````4!0``RP,``$`"``!`````D04```@```"9`0``%0,``%\#``#P````
M`P0``-T```#Y````108``&,%``"D````S@4``(P!```I!```KP4``/P```"Y
M`0``SP(``!,%``#%``````````\```!T!0``M@4``-`%```G!```````````
M````````P````&0%```$!0``G0```,D%``!I!0``-0$``&H```#F`@``````
M``8!``#>!```XP,``/P$````````*@$``&4"```P!0``,`$``!X%``!2`@``
MZ00``'$&``#E`@``G`0``'T``````````````!P&``#T!```P@$``)X```!S
M````6P```%\%``#^`P```````-4"``#<````[P$```\"```\!0``V`0``#\"
M``".`@``'P4```````!\`@``6@(``"P"``#S`@```````.$#```D`0``````
M`,,````L!0``$@$``$H%``!>`@``0@,``((#```,`0````````````"@````
M`````,@$``#,`P``10(`````````````+0$``)`%``#J!0``2P``````````
M````+0,```````"]````E@4```````#<`0``?@,``(4%````````;`8``!4"
M```H!0``)`4``*(!``#Q`0```````*`$``#7!0``AP```#X```!@!0``:00`
M`*4$````````&@8``$,``````````````/L!``!K!```@0$`````````````
M`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@*'EE
M<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T`"5S
M("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S
M`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T
M;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S
M)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@)7,@
M)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(
M;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&1A=&%B87-E
M(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@
M97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%-H;W=E<G,`04TO
M4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT
M(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@
M0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D
M9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R
M.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE
M("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@
M8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN
M:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI
M87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D
M97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0
M($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0
M(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T
M96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG
M=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@:7,@<F5A
M9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL`$%R86)I
M8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA
M;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@
M*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@
M07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE
M;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T
M<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N
M9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A
M=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E
M<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I
M;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A
M<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!"
M:'5T86X`0FER=&AD87D`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD
M`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!"
M;W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!"
M;W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE
M=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E
M;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E
M<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E
M;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`
M0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#
M96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@
M069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S`$-H
M860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E
M;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA
M:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@
M4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U
M*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@
M:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC
M92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S
M97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10
M`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)
M<VQA;F1S`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R
M(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`
M0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A
M<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O
M9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y
M`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E
M(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#
M<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA
M`$-U8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A
M=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M
M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E
M;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H
M(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E
M(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$
M96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969I;FET:6]N<P!$96QE=&4`
M1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R
M9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!R;W<`1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`
M1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I
M;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E
M8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$
M:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO
M;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$
M;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%
M+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``
M161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S
M:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N
M<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N
M+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M
M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS
M`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R
M:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_
M`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E
M<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U871O
M<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!E
M8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P
M;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C
M;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S
M(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&
M86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S
M`$9A>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&
M:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R
M<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`
M1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@
M0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE
M`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W
M87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R
M96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T
M:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R
M86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y
M<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E
M;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E
M(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'
M=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U
M:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X
M-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N
M=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE
M`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R
M>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB
M;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E
M871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V
M86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O
M<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET
M>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);G-E
M<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN
M<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H
M92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E
M<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@
M=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E
M;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B
M969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`
M26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E
M<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T
M:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS
M97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N
M`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A
M($AE861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@
M240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I
M;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T
M>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`
M26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI
M9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N
M=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)
M<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET
M86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE
M=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H
M`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA
M;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@
M2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E
M<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA
M='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B
M86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&EB
M97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG
M:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@
M4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`
M3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T
M;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU
M>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN
M+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO
M=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T
M;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R
M965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N
M=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@
M8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-
M86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`
M36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O
M<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S
M(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``
M36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H
M:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C
M<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU
M;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO
M9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E
M`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I8P!-97AI
M8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM
M92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y
M`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`
M36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE
M=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C
M;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)
M($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R
M;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`
M3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N
M(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O
M<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`
M3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O
M=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`
M3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I
M;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@
M9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E
M9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL
M9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I
M;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N
M(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I
M960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE
M<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P
M<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO
M(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N
M90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO
M<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@
M82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P
M;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E
M;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O
M;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B
M:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F
M:6-E`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M
M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N
M<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T
M:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A
M;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y
M`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL
M`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`
M4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U
M<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y
M`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@
M=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I
M`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A
M:6X@4VAO=V5R`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S
M86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W
M<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`
M4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE
M(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T
M(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A
M=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2
M:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2
M;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG
M:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&
M961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`
M4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@
M2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M
M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD
M(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V
M90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-C:65N
M8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@
M82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N
M97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E
M;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R
M;P!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H
M96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO
M;G,N`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE
M;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO
M860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:')I;FL`
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3
M:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E
M;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=R!3:&]W97(`4VYO=R!D97!T
M:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`
M4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D
M97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG
M`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L
M;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A
M;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`
M4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H
M<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E
M;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`
M4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES
M92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP
M=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R
M;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN
M:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4
M:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG
M('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O
M;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V
M:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL
M("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T
M<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I
M;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A
M>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O
M;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A
M9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`
M5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@
M:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`
M56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B
M)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E
M;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E
M;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI
M;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N
M:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN
M9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI
M;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@
M=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5
M<&1A=&4@)7,`57!D871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`
M57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N
M(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI
M;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE
M('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X
M:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@
M`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!6
M86QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E
M;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L
M`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E
M<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)
M<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI
M='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`
M5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A
M;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!7
M96%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3
M:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E
M<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8+5)E9@!8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA
M<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R
M<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI
M9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D
M(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E
M<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE
M=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO
M9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI
M<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I
M97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86QM`&-L:6-K
M(&AE<F4`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`
M:#H`:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO
M="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I
M;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W1E861Y
M`'1A<VL@;&ES=`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M
M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R
M+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G,*4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$
M871E.B`R,#`T+3$Q+3(Y(#$R.C4R*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!6
M:6QI=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#X*3&%N9W5A9V4M5&5A;3H@
M3&ET:'5A;FEA;B`\=FEL:75S0&QN:RYL=#X*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$S
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H<')I9?`@)7,@
M9&EE;F%S*0`@*&UY9W1U:V%S("5S*0`@*/!I86YD:65N*0`@*'9A:V%R*0`@
M`"5D("5S(&ER("5S`"5D+61I96[X('!R;V=N;WKK`"5S("T@<&%S=&%B80`E
M<R!A;G1S<&%U9&%S`"5S($M"`"5S('!R;V9I;&%K=&EK;W,@=F5I:W-M86D@
M+2!P871V:7)T:6YI;6%S`"5S(')E9VES=')A8VEJ80`E<R!N=6]S=&%T;W,`
M)7,@:F%U(&5G>FES='5O:F$N`"5S("5S("5S`"5S('ER82!P<FEV86QO;6%S
M`"5S(&UI;G5TZW,`)7,@;F5R87-T87,N`&YU;R`E<R!I:VD@)7,@:?`@)7,`
M)7,@861R97/X(&MN>6=E;.L`)7,@:V%L96YD;W)I=7,`)7,@=?YR8?#X(&MN
M>6=E;.L`)7,@9&%R8O@@<^!R8?!A<P`E<SH@)7,`+"!G^W-I86D@)7,@)7,`
M+"!K:6YT82!N=6\@)7,@:6MI("5S`"TM('!A<VER:6YK:71E("TM`#$R('9A
M;&%N9/@@9F]R;6%T87,`,C0@=F%L86YD^"!F;W)M871A<P`R-"!V86QA;F1O
M<P#0:6%M(&)L;VMU:2!R96EK86QI;F=A('9I971A(&1U;VUE;O@@8F%ZZVIE
M+@#!=GEK;R!R:6UT82!K;&%I9&$`3F]RZV1A;6D@=?YK;V1U;W1I(&QA:?!K
MX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M
M:2!P871I:W)I;G1I('!A<VER8?!Y=.`@;&%I\&O@('!R:79A;&]T92!T=7+K
M=&D@=FEE\.!JX2!01U`@<F%K=.`N`$YO<NMD86UI(&%T:V]D=6]T:2!L86GP
M:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%!'4"!R
M86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO<NMD86UI('!A
M<VER8?!Y=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S
M;&%P=.!JX2!01U`@<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF
M+@!.;W+K9&%M:2!A=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@
M=FEE\.!JX2!I<B!S;&%P=.!JX2!3+TU)344@<F%K='5S+"!B96D@_FEN;W1I
M('-L87!TX&K@(&9R87KF+@!.;W+K9&%M:2!P87-I<F'P>71I(&QA:?!KX"!P
M<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A
M:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@=?YK
M;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4R]-24U%
M(')A:W3@+@!!32!R;V1Y;6%S`$%-+U!-`$%022!)1`!!<&EE(/#A(')E9&%K
M=&]R:?@`07!I92XN+@!6:7-I\&MA:2!A<&'H:6]J90!6:7-I\&MA:2!P97(@
M=FED=7+A`%-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!K871A
M;&]GX"X`4VES=&5M82!N971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&9A:6S@
M+@!3;&%P=&'^;V1I<P!3X'-K86ET82!U_O!A;&1Y=&$N`$%P<VMA:71A`%-U
M:W5R=&D`4W5K=7)T:2!P;V=R=7#A`%-U:W5R=&D@<&]T96ES97,`0FQO:V\@
MX71E<G!I;6%S.@!3=6MU<G1I(&YA=6K@(&=R=7#F`%-U:W5R=&D@;F%U:F%S
M('1E:7-E<P!.875J;R!V87)T;W1O:F\@<W5K^W)I;6%S.@!0<FEDZW1I('-T
M=6QP96SA`$YA=6KX(&YA<FGX('!R:63K:FEM87,`4W5K=7)T:2!P;W+@`%!R
M:63K=&D@)7,@;65N:74@<')I92!-;WII;&]S(.%R86YK:?@@:G5O<W1O<P#!
M=')A=6MT:2#A(&%D<F5S^"!K;GEG96SF.@#!=')A=6MT:2#A(&UA;F\@861R
M97/X(&MN>6=E;.8Z`%-U:W5R=&D@=F%R=&]T;VK@`%9A<G1O=&]J^"!K^W)I
M;6%S(&GP:G5N9W1A<RX`061R97-A<P!!9')E<V%I`$%D;6EN:7-T<G5O=&D@
M+2!G86QI(&YU<W1A='ET:2!T96ES97,@:VET:65M<R!V87)T;W1O:F%M<P!6
M86QD>6UA<P!"86YE<FEA:0!!9F=A;FES=&%N87,`06QB86YI:F$`06S^>7)A
M<P!0<F%V87)DZP!,>6=I=6]T:0!,>6=I879I;6%S.@!6:7-O<P!6:7-I('!R
M:7-I:G5N9^8@=F%R=&]T;VIA:0!6:7-O<R!G<G5PZW,`5FES;W,@=&5I<^MS
M`%9I<V]S(&ME='5R:6]S('!U<^MS`$QE:7-T:2!K96QE=.`@861R97/X`$QE
M:7-T:2!N875D;W1I('-U<OOP:75O=.`@<^!R8?#@/P!*874@96=Z:7-T=6]J
M80!!;'1E<FYA='EV=7,@24U34"!P<FES:6IU;F=I;6%S`$%L=&5R;F%T>79U
M<R!)35-0('-L87!T8?YO9&ES`$%L=&5R;F%T>79U<R!)35-0('9A<G1O=&]J
M;R!V87)D87,`06QT97)N871Y=G5S(&5L+B!P8?!T;R!A9')E<V%S`$%L=&5R
M;F%T>7;[<R#P86)L;VYA:0!!;'1E<FYA='EV=7,@=&5K<W1A<P!!;65R:6MO
M<R!386UO80#!=F5DZW1E(&YE;&5I<W1I;N`@<F5I:_!MYBX`06YD;W)A`$%N
M9V]L80!!;F=I;&%I`$%N;VYI;6EN:7,@<')O>'D@<V5R=F5R:7,`071S86MY
M;6%S`$%N=&%R:W1I9&$`06YT:6=U82!I<B!"87)B=61A`$UO9'5L:7,`36]D
M=6QI<R!V96EK:6$@9V5R86DN`%!R:71A:6MY=&D@:7(@<&_P86MI86US`%!A
M='9I<G1I;G1I`$)A;&%N9&ES`$%R86)I\&MA("A7:6YD;W=S+3$R-38I`$%R
M8VAY=F\@9F%I;&\@9'ED:7,`07)C:'EV;R!F86EL;R!P879A9&EN:6UA<P!!
M<B!T:6MR86D@;F]R:71E(&GP=')I;G1I("5S(')E9VES=')A8VEJ;W,@<')A
M\'EMX#\`07)G96YT:6YA`$%R;>MN:6IA`$%R;>MN:?!K82`H05)-4T-)22TX
M*0!-96YA<P!!<G5B80!+<FES=&%U<R#^96YG:6UO(.$@9&%N9_@@<V%L80!!
M8W-I:2!M96YA<P!!>FEJ82]286UI;VIO('9A;F1E;GEN;R!R96=I;VYA<P!!
M<B!P<F'P>71I('!A='9I<G1I;G1I('!R;V9I;&%K=&EK;W,@=F5I:W-M=7,_
M`%!R:7-K>7)I;6\@<W1U;'!E;&EA:0!"86YD;W1E(&GP=')I;G1I(&YE96=Z
M:7-T=6]J86[H:>`@9W)U<.8N`$)A;F1O=&4@:?!T<FEN=&D@;F5E9WII<W1U
M;VIA;NAI87,@=&5I<V5S+@!"86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O
M:F%NZ&EA<R!T96ES97,N`$)A;F1O=&4@<F5D86=U;W1I(&YE96=Z:7-T=6]J
M86YTX2!E;&5M96YTX"X`071R:6)U=&%I`%)U9W!J^W1I<P!!=7-T<F%L:6IA
M`$%U<W1R:6IA`$%U=&A?8WER<W%L.B!N97)A<W1A<R!R96EK86QI;F=A<R!)
M34%0(&UO9'5L:7,N`$%U=&A?8WER=7,Z(&-Y<G5S(&YE='5R:2!R96EK:6%M
M^"!G86QI;7EB:?@N`$%U=&A?8WER=7,Z(&YE<F%S=&%S(')E:6MA;&EN9V%S
M($E-05`@;6]D=6QI<RX`075T:%]F='`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S
M($944"!M;V1U;&ES+B!3=6MO;7!I;&EU;VMI=&4@4$A0('-U("TM96YA8FQE
M+69T<"X`075T:%]I;6%P.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO
M9'5L:7,N`$%U=&A?:W)B-3H@;F5R87-T87,@<F5I:V%L:6YG87,@:W)B-2!M
M;V1U;&ES+@!!=71H7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$05`@
M;6]D=6QI<RX`075T:%]L9&%P.B!S=6MU<G1I('9A<G1O=&]JX"`E<R!N97!A
M=GEK;RX@4V5R=F5R:6\@<')A;F7P:6UA<SH@`$%U=&A?;&1A<#H@:?!T<FEN
M=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO`$%U=&A?;&1A<#H@871N875J:6YT
M:2!V87)T;W1O:N`@)7,@;F5P879Y:V\`075T:%]M8V%L.B!N97)A<W1A<R!R
M96EK86QI;F=A<R!-0T%,(&UO9'5L:7,N`$%U=&A?<VUB875T:#H@;F5R87-T
M87,@<F5I:V%L:6YG87,@<VUB875T:"!M;V1U;&ES+@!0<FES:6IU;F=T:2!N
M97!A=GEK;P!0<FES:6IU;F=T:2!N97!A=GEK;RX@)7,`4D%$2553('-E<G9E
M<FES(&YE;&5I9/YI82!A=71E;G1I9FEK=6]T:7,N`%!R:7-I:G5N9W1I('!R
M:64@1E10('-E<G9E<FEO(&YE<&%V>6MO+@!'86QI;6D@;&%U:V%I.@!!>F5R
M8F%I9/YA;F%S`$)/1D@@871S:7!R8?!Y;6%I`$9O;F%S`$9O;F\@<W!A;'9A
M`$YE=&5I<VEN9V%S(&ME<F)E<F]S('-L87!T8?YO9&ES+@!.971E:7-I;F=A
M<R!K97)B97)O<R!V87)T;W1O:F\@=F%R9&%S+@!"86AA;6%I`$)A:')E:6YA
M<P!"86QT:?!K82`H25-/+3@X-3DM,3,I`$)A9VQA9&7P87,`0F%R8F%D;W-A
M<P!086=R+B!L:6YI:F]J90!"86QT87)U<VEJ80!"96QG:6IA`$)E;&EZ87,`
M0F5N:6YA<P!"97)M=61A:0!"=71A;F%S`$=I;71A9&EE;FES`$)L;VMO('!A
M<F%M971R86D`0FQO:V\@=&EP87,`4&%S=&]R:6YT:0!";VQI=FEJ80!!=/YY
M;6]S`$MR8?!T87,`2W)A\'1O('-T;W)U;6%S.@!+<F'P=&%I`$)O<VYI:F$@
M:7(@2&5R8V5G;W9I;F$`5FES;W,`0F]T<W9A;F$`07!AZ&EO:F4`0G5V970@
M<V%L80!"<F%Z:6QI:F$`0G)I=/@@26YD:6IO<R!V86YD96YY;F\@=&5R:71O
M:F$`0G)U;NMJ875S(&1A<G5S86QE;6%S`$)U;&=A<FEJ80!3=?YY;>MT87,@
M<^!R8?!A<P!"=7)K:6YA<R!&87-A<P!"=7)U;F1I:F$`5%93`$-20P!#4DP@
M<&%S:VER<W1Y;6\@<'5N:W1A:0!?0V5LZW,@;G5S=&%T>6UA:2XN+@!+86QE
M;F1O<FEU<P!286UU`$MA;6)O9/YA`$MA;65R^VYA<P!.979E:6MI82!A=71O
M;6%T:6YI<R!S;&%P=&'^;V3^:6\@<&%K96ET:6UA<RP@<W5S:7-I96MI=&4@
M<W4@861M:6YI<W1R871O<FEU;6DN`$YE9V%L:74@<')I<VEJ=6YG=&D@<')I
M92!)34%0('-E<G9E<FEO.B`E<P!+86YA9&$`073P875K=&D`073P875K=&D@
M<')O8FQE;6]S('!R86YE\&EMX`!.96=A;&EU(&GP=')I;G1I(&9A:6QO("(E
M<R(N`$YE9V%L:74@<F%S=&D@;&%I:VEN;VIO(&MA=&%L;V=O+@!.96=A;&EU
M(&%P9&]R;W1I("=T87)G971&:6QE)R!P87)A;65T<F\N`$YE9V%L:74@:?!T
M<FEN=&D@:V%T86QO9V\@(B5S(BX`3F5G86QI=2!I\'1R:6YT:2X@16=Z:7-T
M=6]J82`E9"!P;_!A:VEA:2X`3F5G86QI=2!P97)R^_!I=6]T:2X@P79E<W1A
M<R#A<F'P^"!S:V%IZ&EU<R!N97-U=&%M<&$@<W4@X7)A\/@@<VMA:>AI=6UI
M(&1U;VUE;O@@8F%ZZVIE+@!.96=A;&EU(&YU:W)E:7!T:2#^:6YU=.MS(.$@
M;G5R;V1Y=.`@;G5M97+A+@!+96EP=F5R9&ES`%!A=F%D:6YI;6%S`$MA=&5G
M;W)I:F]S`$MA:6UA;O@@<V%L;W,`36]B:6QU<R!T96QE9F]N87,`0V5LZW,@
M;G5S=&%T>6UA:0!487)P86D@8V5LZW-E.@!#96SK<R!N=7-T871Y;6%I`%1A
M<G!A:2!T87)P(&-E;&GX.@!-;V)I;'5S:7,@=&5L969O;F%S`$ME;'3X("A)
M4T\M.#@U.2TQ-"D`0V5N=')E`$-E;G1R:6[K<R!!9G)I:V]S(%)E<W!U8FQI
M:V$`0V5N=')I;NMS($5U<F]P;W,@*$E33RTX.#4Y+3(I`%-E<G1I9FEK871O
M(&1E=&%LZW,`4V5R=&EF:6MA=&\@=&5I<^MS`,AA9&%S`%!A:V5I<W1I`$K[
M<_@@=F%R9&\@:7(@861R97-O+"!K=7)I=6]S(&UA='ES(/YM;V[K<RP@<VMA
M:71A;G1Y<R!I<B!A='-A:VENZVIA;G1Y<R#A($K[<_@@;&%I\&MU<RP@:V5I
M=&EM87,N`%-I;6)O;&ES`%!A7W1I:W)I;G1I(&YU;W)O9.`N+BX`R&ELZP!+
M:6YI:F$`2VEN:65T:?!K82!P87!R87-T82`H1T(R,S$R*0!+:6YI971I\&MA
M('1R861I8VENZR`H0FEG-2D`4&%S:7)I;FMI=&4@<VQA<'1A_F]DX0!087-I
M<FEN:VET92!V87)T;W1O:F\@=F%R9.``4&%S:7)I;FMI=&4@:V%I<"!V86EZ
M9'5O=&D@9&%T87,Z`%!A<VER:6YK:71E('-U<OOP:75O=&\@<^!R8?!O('-T
M:6QI^`!+86SK9/@@<V%L80!+;&%SZW,@)7,@;NMR82X`1VEE9')A`$GP=')I
M;G1I($U3($]F9FEC92#^>6UE<P!687)T;W1O:F\@9'5O;65N^"!V86QY;6%S
M.B`E<P!)\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N:7,`2?!V86QY=&D@=F%R
M=&]T;VIO(&1U;VUE;FES`%3F<W1I`$-L:6-K871E;&P@<&5R($A45%``5?YD
M87)Y=&D@;&%N9^``1&5B97-U;W1A`$1E8F5S=6]T80!+;VMO<V\@*$MY;&EN
M9V\I('-A;&]S`%1U\.AI^"!C96QI^"!K<F'P=/@@<F]D>6UA<P!+;VQU;6)I
M:F$`4W!A;'9A`%!A<VER:6YK:71E('-P86QVX`!3<&%L=F]S('!A<VER:6YK
M:6UA<P!3='5L<&5L:6%I.@!3='5L<&5L:?@@<&%V861I;FEM86D`2V]M:6MS
M86D`2V]M86YD80!+;VUA;F1I;NL@96EL=73K`$MO;65N=&%R87,`5F%R9&%S
M+W!A=F%R9.L`2V]M;W)A:0!+;VUP86YI:F$`2V]M<&EU=&5R:6%I`%/@;'EG
M;W,`3G5S=&%T>6WX('!A:V5I=&EM86D`2V]N9FEG^W)U;W1I("5S`%-L87!T
M8?YO9&ES(&1A<B!K87)TX`!+;VYG87,`1&5M;VMR871I;NL@2V]N9V\@4F5S
M<'5B;&EK80!0<FES:6IU;F=T:2!N97!A=GEK;RX`4')I<VEJ=6YG=&D@;F5P
M879Y:V\Z(`!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R=F5R
M:6\@;F5P879Y:V\N`%!R:7-I:G5N9W1I('!R:64@=FEE\/AJ^"!R86MT^"!S
M97)V97)I;R!N97!A=GEK;RP@;F5S.B`E<R`H)7,I`%!R:7-I:G5N9W1I('!R
M:64@1E10('-E<G9E<FEO(&YE<&%V>6MO+@!+;VYK86MT86D@<^MK;6EN9V%I
M(.%T<F%U:W1I(.$@2OMS^"!A9')E<_@@:VYY9V5LY@!4YG-T:0!+=6MO('-A
M;&]S`$QA:6WK<R#^:6YU=.MS`$MO<&EJ=6]T:0!+;W!I:G5O=&D@<&%S:7)I
M;FMI;>``2V]S=&$@4FEK80!$<F%M8FQI;R!+875L;R!+<F%N=&%S`$YE<&%V
M>6MO('7^:V]D=6]T:2!01U`@;&%I\&MO+@!.97!A=GEK;R!P87-I<F'P>71I
M(%!'4"!L86GP:V\N`$YE<&%V>6MO('7^:V]D=6]T:2!3+TU)344@;&%I\&MO
M+@!.97!A=GEK;R!P87-I<F'P>71I(%,O34E-12!L86GP:V\N`$YE<&%V>6MO
M('!R:63K=&D@:V]N=&%K=&\N("5S`$YE<&%V>6MO(&%U=&5N=&EF:6MU;W1I
M<R#A($Q$05`@<V5R=F5RX2X`3F5P879Y:V\@<&%T:6MR:6YT:2!B86QA;G-O
M+B`E<P!.97!A=GEK;R!S=6MU<G1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E
M<P!.97!A=GEK;R!A=&MO9'5O=&D@4$=0(&1U;VUE;O@N`$YE<&%V>6MO(&%T
M:V]D=6]T:2!3+TU)344@9'5O;65N^"X`3F5P879Y:V\@:?!T<FEN=&D@:V]N
M=&%K=&\N("5S`$YE<&%V>6MO(&GP=')I;G1I(&1I<W1R:6)U8VEJ;W,@<^!R
M8?!O+B`E<P!.97!A=GEK;R!N=7-T871Y=&D@9V%VZVIO(&5L+B!P8?!T;R!A
M9')E<V\N`%!A=GEK;R!G875T:2!V:7-O<R!A9')E<_@@:VYY9V5LZW,N`$YE
M<&%V>6MO(&=A=71I('9I<V\@9&ES=')I8G5C:6IO<R!SX')A\&\N`$YE<&%V
M>6MO(&=A=71I('9I<V\@9&ES=')I8G5C:6IO<R!SX')A\/@@<^!R8?!O+@!.
M97!A=GEK;R!G875T:2!V:67P;VIO(')A:W1O(&GP(')A:W3X('-E<G9E<FEO
M+@!.97!A=GEK;R!A=&ED87)Y=&D@)7,N`$YE<&%V>6MO(&%T:61A<GET:2!-
M86EN=&5N86YC95]487-K(&UO9'5L:6\@)7,`3F5P879Y:V\@<VMA:71Y=&D@
M)7,N`$YE<&%V>6MO('!A:V5I<W1I('-L87!T8?YO9/YI;R#P:6%M('9A<G1O
M=&]J=6DN($MA:2!K=7)I(&%R8F$@=FES82!I;F9O<FUA8VEJ82!Y<F$@;F5T
M:6MS;&DN(%!A8F%N9'EK:71E(&1A<B!K87)TX"!A<F)A('-U<VES:65K:71E
M('-U('-A=F\@861M:6YI<W1R871O<FEU;6D@:F5I9W4@<F5I:V%L:6YG82!P
M86=A;&)A+@!.97!A=GEK;R!G875T:2!!0TP`3F5P879Y:V\@9V%U=&D@861R
M97/X(&MN>6=E;.MS+B`E<P!.97!A=GEK;R!G875T:2!D:7-T<FEB=6-I:F]S
M('/@<F'P;RX@)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C:6IO<R!SX')A
M\/@N("5S`$YE<&%V>6MO(&YU<W1A='ET:2!S97)V97)I;R!G86QI;7EB:?@`
M3F5P879Y:V\@871K96ES=&D@;G5S=&%T>6WX+@!.97!A=GEK;R!I\'-A=6=O
M=&D@)7,@;G5S=&%T>6WX+@!.97!A=GEK;R!P861A<GET:2!A='-A<F=I;NMS
M(&YU<W1A='EM^"!K;W!I:F]S+@!.97!A=GEK;R!P86EE\&MA($Q$05`@<V5R
M=F5R>6IE+@!.97!A=GEK;R!A=&YA=6II;G1I(&MO;G1A:W1O+B`E<P!.97!A
M=GEK;R!A=&YA=6II;G1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<P!.97!A
M=GEK;R!R87-T:2!-;WII;&]S(.%R86YK:?@@:G5O<W1O<RX@P7-I=&EK:6YK
M:71E+"!K860@:FD@871I9&%R>71A+@!2:6)O=&%S('1E:W-T87,`5F%L<W1Y
M8NL`2W5R<V%I`%-U:W5R=&D`4W5K=7)T:2!N=6]R;V3@`%-U:W5R=&D@;F%U
M:N`@87!R8?#@`%-U:W5R=&D@<&%K871A;&]G:75S`%-A=FEN:6YK;R!T96ES
MZW,`2W)E9&ET:6[K<R!K;W)T96SK<R!N=6UE<FES`$MR;V%T:6IA`$MU8F$`
M1&%B87)T:6YI<R!L86EK87,`T&EU;R!M971U(%523"!Y<F$`1&%B87)T:6[K
M<R!O<F\@<^!L>6=O<P!$86)A<G1I;NMS('/@;'EG;W,Z(`!$86)A<G1I;FES
M('-T:6QI=7,`5F5I:W-M^"P@871L:65K86WX('!R:7-I:G5N9W5S('!R:64@
M)7,L(&YU<W1A='EM87,N`%!E<FME;'1I`%!E<FME;'1I('!A<VER:6YK:6W@
M`$MI<')A<P!+:7)I;&EC82`H2T])."U2*0!+:7)I;&EC82`H5VEN9&]W<RTQ
M,C4Q*0!+:7)I;&EC82]5:W)A:6YI971I\&MA("A+3TDX+54I`,AE:VEJ;W,@
M4F5S<'5B;&EK80!$1`!+87-D:65N`$1U;VUE;O@@;65D_FEO(&YA<O!Y:VSK
M`$1A=&$`1V%U=&$`1&%T;W,@<&%S:7)I;FMI;6%S`$1I96YA`$GP=')I;G1I
M(%]S='5L<&5LX0!'<G5O9&ES`$1E\&EM=&%I;FEA:2!S:V%IZ&EA:0!3=6UA
M_FEN=&D@871I=')A=6MI;>``4W1A;F1A<G1I;NL@<W!A;'9A`%-T86YD87)T
M:6YI<R!A<')A\&%S`$%P:6)RZ_YI;6%I`$GP=')I;G1I`$GP=')I;G1I(&=R
M=7#F`$GP=')I;G1I('1E:7/F`%9I<VGP:V%I(&GP=')I;G1I(&QA:?!K=7,`
M2?!T<FEN=&D@8V5LY@!)\'1R:6YT:2!S='5L<&5LX0!)\'1R:6YT:2!E9WII
M<W1U;VIA;G3A(&%L=&5R;F%T>7;X(/!A8FQO;N``2?!T<FEN=&D@96EL=73F
M`$GP=')I;G1I('!A<VER:6YK=.`@87!R8?#@`$GP=')I;G1I(/#A('-T=6QP
M96SA`$GP=')I;G1I(/!IX"!E:6QU=.8`4')I<W1A='EM;R!L86EK87,`1&%N
M:6IA`%!R;V)L96UO<R!A<')A\'EM87,`07!R8?!Y;6%S`$1E=&%L:6%U("AT
M86EP('!A="#^:?MRZVMI=&4@2&]R9&4@;&]G(&9A:6QE*3H`061M:6YI<W1R
M871O<FEU:2!I\'-I^'-T87,@9&5T86QU<R!A<')A\'EM87,N`%9Y<W1Y;6%S
M`$1RZV=N=6UA<P!$<NMG;G5M87,@<&%S:W5T:6[F('9A;&%N9.`Z(`!$<NMG
M;G5M87,Z(`!+<GEP=&ES(&GP(&MA:7+K<R#A(&1E\&ENY@!+<GEP=&ES(&GP
M(&1E\&ENZW,@X2!K86ERY@!+871A;&]G87,`4F]D>71I(#(T+6GX('9A;"X@
M9F]R;6%TX#\`5F%I>F1A=FEM;R!N=7-T871Y;6%I`%)O9'ET:2!P<F]G<F]N
MYB`H5$%&*0!686EZ9&%V:6UO(&9O<FUA=&%S`$QA:?!K;R!P<FES=&%T>6UO
M('!R86YE\&EM86D`1/YI8G5T:7,`3F5T<FEN=&D`3F5S:6MR96EP:VET92!T
M:65S:6]G:6%I(.$@;6%I;G1E;F%N8V4N<&AP`$%R('!I<FUA<R#A<F'P87,@
M>7)A(&QA=6MO('9A<F1A:3\`1&]M:6YI:V$`1&]M:6YI:V]S(%)E<W!U8FQI
M:V$`071S:7-I^'-T:0!!='-I<VGX<W1I("5S`$%T<VES:?AS=&D@<W5G96YE
M<G5O='5S(&YU<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"X`2?!S:7-K;&5I
M9/YI86YT:7,@<^!R8?!A<P!686ES=&%I`$5L+B!P8?!T;R!A9')E<V%S`$52
M4@!%:W9A9&]R87,`2V5I<W1I`$ME:7-T:2!B;&]K;R!P87)A;65T<G5S`%)E
M9&%G=6]T:2!G<G5PY@!2961A9W5O=&D@=&5I<V5S`%)E9&%G=6]T:2!T96ES
M97,`)7,@=&5I<VGX(')E9&%G879I;6%S`$ME:7-T:2!N=7-T871Y;75S.@`E
M<R!T96ES:?@@<F5D86=A=FEM87,`56=D>6UA<P!%9VEP=&%S`%-A;'9A9&]R
M87,`16QE;65N=&%S+BXN`$5M`$5L+B!P8?!T87,`16PN('!A\'1O(&%D<F5S
M87,`16PN('!A\'1O(&%D<F5S86D@='5R:2!S=71A<'1I+@!%;"X@<&'P=&\@
M861R97-A<R!S=2!P871V:7)T:6YI;74`T'EP<V5NZVSK<P#>:6YU=.L@='7P
MZ&EA+@!297IU;'1A=&%S('1U\.AI87,N`$YE;G5R;V3K=&4@<&%I9?!K;W,@
M=&5R;6EN^`!,96ES=&D@=&5K<W1E(.%T97)P=&D@<&%V96EK<VSK;&EU<R!I
M\"!.=6]T<F%U:_@@9V%L97)I:F]S/P#!:G5N9W1I(&1E\&EN:6]J;R!P96SK
M<R!M>6=T=6MO(&UE;FEU/P!'86QI;FEA:2!M971A:0!)\'!LZW-T:2!R961A
M:W1O<FGX`,%R8?!Y:VET92!K;&%U<VEMX"P@:W5R:7,@:G5M<R!B=7,@=?YD
M=6]T87,@:F5I9W4@<&%M:7+P:71E('-A=F\@<VQA<'1A_F]DX2P@<'9Z+CH@
M)VMO:W,@>7)A($K[<_@@9WEV^VYO('9A<F1A<S\G.@#!=F5S:VET92!P879E
M:6MS;.ML:6\@55),`$5K=F%T;W)I;NL@1W9I;NMJ80!%<FET<NMJ80!+;&%I
M9&$`2VQA:61A(&QA:?!K92X`17-T:6IA`$5T:6]P:6IA`$5T;FENZW,`175R
M;W!A`$MA<R`Q-2!M:6YUZ&GX`$MA<R`R(&UI;G5T97,`2V%S(#,P('-E:W5N
M9/YI^`!+87,@-2!M:6YU=&5S`$MI96MV:65N;R!P<FES:6IU;F=I;6\@;65T
M=0!+87,@<'5S=F%L86YDX0!+87,@;6EN=73F`%!A=GEZ9/YI=6DZ`%9Y:V1Y
M=&D`2?!S:VQE:7-T:0!296EK86QI;F=A<R`G*2<`4F5I:V%L:6YG87,@_F]D
M:7,@87)B82!K86)U=.MS92#A<F'P>71A<R!P86EE\&MO<R!K<FET97)I:G5S
M`$=A;&EO:FEM;R!D871A`$5K<W!O;F5N=.L`5&5K<W1O('-P86QV80!.=7-T
M871Y;?@@<VEU;G1I;6%S('!E<B!&5%`N`$ML86ED82!N=7-K86ET86YT(&YU
M<W1A='EM=7,N`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@3$1!4"!S97)V
M97)I;RX`3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!334(@<V5R=F5R:6\N
M`$YE<&%V>6MO(&YU:V]P:6IU;W1I(&GP("(E<R(N`$YE<&%V>6MO(&YU:V]P
M:6IU;W1I(.$@(B5S(BX`3F5P879Y:V\@<W5K=7)T:2!N875J;R!305-,(')Y
M\&EO+@!.97!A=GEK;R!P97)K96QT:2#A("(E<R(N`-!V96QN=7,`1F]L:VQA
M;F3X('-A;&]S("A-86QV:6YA:2D`1F%R97+X('-A;&]S`$9A:W-A<P!687-A
M<FES`$%T<F]D;R!L>6<`071R;V1O(&QY9SH@`%1R=6UP86QA:6MI<R!L:65T
M=7,`1FED_FES`$9A:6SX('-K86GH:75S.B`E<R!F86EL87,`1F%I;/@@<VMA
M:>AI=7,Z("5S(&9A:6QA:2CX*0!&86EL^"!T=F%R:WEM87,`1F%I;&\@<&%V
M861I;FEM87,`1F%I;&\@<&%S:7)I;FMI;6%S`$9A:6QO('-I=6YT:6UA<P!.
M87+P>6MLZR!N97!A;&%I:V\@9F%I;/@@<VEU;G1I;6\N`$9I;'1R86D`4W5O
M;6EJ80!0:7)M;VII('!U<^L`4&ER;6%S:7,@:V5T=FER=&ES`$YU<W1A='ET
M87,@:V]E9FEC:65N=&%S`$%T=FER:_#H:6%S`$GP9.MS='EM87,`4OMK87,`
M2V%T86QO9V%S("5S(&YE96=Z:7-T=6]J80!496MS=&\@<W!A;'9A`$UA:7-T
M87,`3F%R\'EK;.MM<RP@:W5R:6]S(&YE<&%L86EK;R!P879E:6MS;.ML:?@`
M3W+X('!R;V=N;WKK("A4048I`$]R^"!P<F]G;F]ZZW,@87!I;71I<R`HX7-I
M9.MMZVMI=&4L(&MA9"#P:2!F=6YK8VEJ82!G<F'^:6YA(&ER(&1I96YO<R!I
M<B!N86MT:65S('!R;V=N;WKF.R!P97(@9&ED96QI<R!S:V%IZ&EU<R!G86QI
M('-U9&%R:WET:2!D:7IA:6[@*0!086UI<O!O=&4@<V%V;R!S;&%P=&'^;V3A
M/P!&;W)M;W,`1G)A>NL`1G)A>FGX('1I<&%S`$9R87KK<P!&<F%ZZW,@,@!$
M:7-K=7-I:F]S`%!E<G-I=6YT:6UA:0!096YK+@!+<F'P=&ENZW,`4')A;F/[
M>FEJ80!0<F%N8_MZ:6IA+"!-971R;W!O;&ES`%!R86YC^WII:F]S($=V:6%N
M80!0<F%N8_MZ:6IO<R!0;VQI;F5Z:6IA`%!R86YC^WII:F]S('!I971I;NMS
M('1E<FET;W)I:F]S`$YU;P!.=6\@`%!I;&YA<R!A<')A\'EM87,`4&EL;F%T
M:7,`4&EL;F%S('9A<F1A<P!'86)O;F%S`$=A;&5R:6IA(&GP(&MU<FEO<R!I
M\"!K=7)I;W,@8G5S(')O9&]M87,@<&%V96EK<VSK;&ES`$=A;&5R:6IA.@!'
M86UB:6IA`$=E;F5R=6]T:2`E<R!N=7-T871Y;75S`%-U9V5N97)U;W1A<R!K
M;V1A<P!'<G5Z:6IA`%9O:VEE=&EJ80!'86YA`$=I8G)A;'1A<F%S`%9A<F1A
M<P!2;V1Y=&D`1V%D96QI<P!';V]G;&4@<&%I9?!K80!.97-P86QV;W1A<P!'
M<F%I:VEJ80!'<F%I:VGP:V$@*$E33RTX.#4Y+3<I`$=R96YL86YD:6IA`$=R
M96YA9&$`1W)U<&GX(&%D;6EN:7-T<F%V:6UA<P!'<G5PZW,@=F%R9&%S('1U
M<FD@8OMT:2!N971U\.AI87,`1W)U<.MS`$=V861E;'5PZP!'=6%M80!'=F%T
M96UA;&$`1V5R;G-I<P!3=F7H:?@@=&5I<^MS`%-V9>AI^"!K;GEG80!'=FEN
MZVIA`$)I<W-A=2U'=FENZVIA`$=A:F%N80!(5$U,`$A434Q!<F5A(&YE9V%L
M:2!I\'1R:6YT:2!P87-K=71I;NMS(&-E;.MS(&5I;'5TZVIE+@!(5$U,07)E
M82!N96=A;&D@:?!R:6YT:2!P87-K=71I;FEO('-T=6QP96QI;R!L96YT96SK
M:F4N`$A434Q!<F5A(&YE9V%L:2!I\'1R:6YT:2!P87-K=71I;NMS(&5I;'5T
MZW,@;&5N=&5LZVIE+@!296EK86QI;F=A($A45%`@875T96YT:69I:V%C:6IA
M+@!(86ET:7,`2&%S:"U!;&=O<FET;6%S`$UI9VQA`$%N=')A\'3K`$AE<F1O
M('-A;&$@:7(@36%K9&]N86QD;R!S86QO<P!(96)R86KX("A)4T\M.#@U.2TX
M+4DI`$%U:_!T:7,`4&%G86QB80!2961A:W1O<FEA=7,@;F%U9&]J:6UO<VD@
M<&%G86QB80!086=A;&)I;FEN:V%S`$AE;6ES9F5R80#0=&%I(.AI82!Y<F$@
M9F%I;&\@<')A9/YI83H`4W9A<F)U`%]0;W)T86QA<P#0=F5N=&%S:7,@4V]S
M=&%S("A6871I:V%N;R!V86QS=&EJ82D`4&]R=&%L87,`3F%M^"!A9')E<V%S
M`$YA;?@@=&5L969O;F%S`$AO;F3[<F%S`$AO;FMO;F=A<P!0;W)T86QA<P!(
M;W)D92]+;VQA8CH@;F5T96ES:6YG:2`E<R!834P@9'5O;65N>7,@_FEN=73K
M:F4@)7,`2&]R9&4O2V]L86(Z(&]B:F5K=&\@)7,@;F5A=&ET:6YK82!J;VMI
M82#^:6YU=.L`2&]R9&4O2V]L86(Z(&]B:F5K=&\@=&EP87,@)7,@;F5R87-T
M87,@_FEN=73K:F4@)7,`2&]R9&4O2V]L86(Z("5S("(E<R(@<^MK;6EN86D@
M:?!T<FEN=&$`2&]R9&4O2V]L86(Z(&EN=&5G<F%C:6IO<R!V87)I:VQI=6MU
M:2!R96EK86QI;F=A<R`G9&]M>&UL)R!02%`@;6]D=6QI<P!(;W)D92]+;VQA
M8CH@;F5P879Y:V\@<W5K=7)T:2!N875J;R!834P@;65D_FEO(&]B:F5K='5I
M("5S`$AO<F1E+TMO;&%B.B!N97!A=GEK;R!I\'1R:6YT:2`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@9V%U=&D@34E-12!)1"!D86QI86D@
M)7,@=&EP;P!(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC:')O;FEZ=6]T
M:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC:')O
M;FEZ=6]T:2!E;&5M96YT^#H@)7,`2&]R9&4O2V]L86(Z(&YE_FEN;VUA<R!E
M;&5M96YT87,@(B5S(@!(;W)I>F]N=&%L:2!L:6YI:F$`2&]R:7IO;G1A;'5S
M('1A<G!A<P!(;W)I>F]N=&%L:6%I.@!+86EP(.AI82!P871E:V]T93\@*%!R
M86YE\&MI=&4A*0!+:65K('-T=6QP96QI^"!N;W)I=&4@<W5J=6YG=&D_`$MI
M96L@;&%U:_@@*'-T=6QP96QI^"D@=&5N('ER83\`2VEE:R!E:6QUZ&GX(&YO
M<FET92!S=6IU;F=T:3\`1'+K9VYU;6%S`$1RZV=N=6UA<SH@`$IU;6]R97-K
M;W,`5F5N9W)I:F$`3F5P879Y:V\@<W5K=7)T:2!)34%0('!A\'1O(&3K_G5T
MZW,Z("5S`$YE<&%V>6MO(&GP=')I;G1I($E-05`@<&'P=&\@9.O^=73K<SH@
M)7,`3F5P879Y:V\@;G5S=&%T>71I($E-05`@<&'P=&\@9.O^=73K<R!D>63^
M:6\Z("5S`$E0(&%D<F5S87,`3F5P879Y:V\@9V%U=&D@25`@861R97-O+@!)
M4"!A9')E<V%S(&YE=&5I<VEN9V%M92!#2412(&)L;VME+@!)4"!U_G)A:VEN
M=&%S+@!?P71E<G!T:2!E:6QU=.8@=FER\'5J90!)<VQA;F1I:F$`5&EK('!I
M:W1O9W)A;6]S`%!I:W1O9W)A;6]S('-U('1E:W-T=0!!<')A\&\@<&%V861I
M;FEM87,Z`$IE:2!N96=A;&ET92!P97)S:V%I='ET:2#P:6\@;&%I\&MO+"`E
M<RX`2F5I9W4@;6%T;W1E(/!IX"#^:6YU=.8@=FEE=&]J('!A=F5I:W-LZVQI
M;RP@:W5RX2!N;W)I=&4@X6ME;'1I+"!T86D@2OMS^"!N87+P>6MLZR!N96=A
M;&D@:F\@871V86EZ9'5O=&DN`%!A=F5I:W-LZVQI;R!P97+^:?MR80!0879E
M:6MS;.ML:6\@55),`%!A=F5I:W-LZVQI;R!54DPZ`%!A=F5I:W-LZVQI<R!I
M\"!G86QE<FEJ;W,`4&%V96EK<VSK;&ES(&GP(&=A;&5R:6IO<SH`4&%V96EK
M<VSK;&EO(.%KZVQI;6%S`%9A:7ID86D`P6OK;&EM87,L("5D(/YI;F=S;FES
M`$QA=6MA<R#A:V5L=&%S.B`E<P#!:V5L=&D@;&%U:V%I.@#!7W1E<G!T:2!E
M:6QU=.8@87!AZ&EO:F4`3F5T96ES:6YG87,@=F5I:W-M;R!K;V1A<RX`3F5T
M96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES
M+@!.96ET96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!A<F)A(&%L=&5R;F%T
M>79U<R!E;"X@<&'P=&\@861R97-A<RX@0F%N9'EK:71E(&1A<B!K87)TX"!A
M<F)A('-U<VES:65K:71E('-U('-A=F\@861M:6YI<W1R871O<FEU;6D@:F5I
M9W4@<F5I:V%L:6YG82!T;VQE<V[K('!A9V%L8F$N`%!A9&ED:6YT:2!A=&ET
M<F%U:VEMX`!);F1I:F$`26YD:79I9'5A;/MS('9A<G1O=&]J86D`26YD;VYE
M>FEJ80!);F9O<FUA8VEJ80!);F9O<FUA8VEJ80#!=')A=6MT:2!S='5L<&5L
MX2!?9&7P:6[K:F4`P71E<G!T:2!P879E:6MS;.MLX0#!=&5R<'1I(&QE;G1E
M;.8`P71E<G!T:2!N=6]R;V3@`,%T97)P=&D@<W1U;'!E;.$@7VMA:7+K:F4`
MP71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@9&7P:6[K
M:F4`P71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@:V%I
M<NMJ90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K<R!A<&'H
M:6]J90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K<R!V:7+P
M=6IE`,%T97)P=&D@<&%R86=R86;@(&5L96UE;G1O(&%P8>AI;VIE`,%T97)P
M=&D@<&%R86=R86?@(&5L96UE;G1O('9I<O!U:F4`P71E<G!T:2!A;'1E<FYA
M='EV^"#P86)L;V[@`,%R8?!Y:VET92!E;"X@<&'P=&\@861R97/@+"#A(&MU
M<N$@;F]R:71E(&=A=71I(&YA=6K@('-L87!T8?YO9.$Z`,%T97)P=&D@8V5L
MYB!P;R!T;P#!=&5R<'1I(&-E;.8@<')I9?`@=&%I`,%T97)P=&D@<W1U;'!E
M;.$@9&7P:6[K:F4`P71E<G!T:2!S='5L<&5LX2!K86ERZVIE`,%T97)P=&D@
M;&%I\&MU<P#!=&5R<'1I('!A<F%G<F%FX"!P;R!T;P#!=&5R<'1I('!A<F%G
M<F%FX"!P<FEE\"!T86D`P71E<G!T:2!E:6QU=.8@<&\@=&\`P71E<G!T:2!E
M:6QU=.8@<')I9?`@=&%I`,%R8?!Y:VET92!R96EK:6%MX"!A='-A:WEMX"#A
M(&ML875S:6W@('9I<O!U:F4Z`,%T97)P=&DO<F5D86=U;W1I('!A=F5I:W-L
MZVSA`,%T97)P=&DO4F5D86=U;W1I(&YU;W)O9.``1&ES=')I8G5C:6IO<R!S
MX')A\'5I(&YU<VGX<W1I(&YE=?YT96YK82!K<F5D:71O+@!.977^=&5N:V$@
M:W)E9&ET;RX`4VMA:>AI=7,`4VMA:>AI^"!SX')A\&%S`$YE=&5I<VEN9V%S
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!.971E:7-I;F=A<R!M;V1U;&ES
M+@!.971E:7-I;F=A<R!)1"X`P79E<W1I(&YE=&5I<VEN9VD@9'5O;65N>7,N
M`$YE=&5I<VEN9V%S(&%D<F5S87,N`$YE=&5I<VEN9V%S(&9A:6QO(&9O<FUA
M=&%S`$YE=&5I<VEN9V%S(&US9U]T>7!E+@!.971E:7-I;F=A<R!A<F)A(&[K
M<F$@87!I7VED+@!087)A;65T<F%I(&YE=&5I<VEN9VD@87)B82!J^"!NZW)A
M+@!.971E:7-I;F=O<R!P879E;&1I;6]S('1E:7/K<RX`3F5T96ES:6YG87,@
M<')O=&]K;VQA<RX`3F5T96ES:6YG87,@;V)J96MT87,`3F5T96ES:6YG87,@
M<VEU;G3K:F\@861R97-A<RX`3F5T96ES:6YG:2!U;FEK;V1O(&1U;VUE;GES
M+@!);G9E;G1O<FEU<P!)<VQA;6GP:V$@27)A;F\@4F5S<'5B;&EK80!)<F%K
M87,`06ER:6IA`$UE;F\@<V%L80!)>F]L:75O=&]S(%0M875D<F]S`$EZ<F%E
M;&ES`$GP9&%VZVIA<P!+=7)S>79A<P!)=&%L:6IA`$IA;6%I:V$`4V%U<VES
M`$IA<&]N:6IA`$IA<&]N:?!K82`H25-/+3(P,C(M2E`I`$3^97)S:7,`2F]R
M9&%N:6IA`$QI97!A`$)I<OYE;&ES`%!I;&YA:0!,>6=I=6]T:2!C96YT<F4`
M3'EG=6]T:2!P:6QN86D`3'EG:75O=&D@:V%I<NMJ90!,>6=I=6]T:2!D9?!I
M;NMJ90!+87IA:W-T86YA<P!)\'-A=6=O=&D@;W)I9VEN86S@/P!+96YI:F$`
M3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!+97)B97)O<R!S97)V97)I;RX`
M0G)A;F1U;VQI;R!N875J;VMA:0!286MT;R!K^W)I;6%S`%)A:W1O(&%T<W!A
M=61A<P!286MT;R!I;&=I<P!286MT;R!T:7!A<P!286MT;R!P86YA=61O:FEM
M87,`4F%K=&%S(&IA=2!Y<F$@=FEE\/AJ^"!R86MT^"!S97)V97)Y:F4N`%9A
M:6MA:0!+:7)I8F%T:7,`1&5M;VMR871I;NL@2V]RZVIO<R!,:6%U9&EE<R!2
M97-P=6)L:6MA`$MO<NMJ;W,@4F5S<'5B;&EK80!+;W+K:FEE=&GP:V$@*$55
M0RU+4BD`2W5V96ET87,`2VER9VEZ:6IA`%])\&3K<W1Y;6%S`$MA;&)A`$QA
M;W-O($1E;6]K<F%T:6[K($QI875D:65S(%)E<W!U8FQI:V$`06YT<F$@<'5S
MZP!087-K=71I;FES(&ME='9I<G1I<P!!=&YA=6II;G1A.@!087-K=71I;FES
M('!R:7-I:G5N9VEM87,Z("5S`%!A<VMU=&EN:7,@<')I<VEJ=6YG:6UA<SH@
M)7,@:?`@861R97-O("5S`%!R:7-I:G5N9^MT92!P:7)MX"!K87)TX`!,871V
M:6IA`%1E:7/K`$GP9.MS='EM87,`2F5I9W4@;F5N;W)I=&4@;F5N875D;W1I
M(&MR8?!T^"P@<&%L:6MI=&4@='7PZ&G@`$QI8F%N87,`2V%I<NMJ90!+86ER
M:6]J:2!A;G1R8?!TZP!+86ER:6]S:6]S(')E:6OP;>MS`$QE<V]T87,`3&EB
M97)I:F$`3&EB:6IO<R!!<F%B^"!%;7ER871A:0!,:6-H=&5N\'1E:6YA<P!3
M;75L:W5S(&QI971U<P!.961I9&5L:7,@;&EE='5S`$YE9&ED96QI<R!L:65T
M=7,@<GET90!.961I9&5L:7,@;&EE='5S('9A:V%R90!.961I9&5LZR!L:?MT
M:7,`3F5D:61E;&ES(&QI971U<R!S=2!P97)K^VYI:F$`3F5D:61E;&ES('-N
M:65G87,`3F5D:61E;.L@\&QA<&1R:6)A`$QI;65R:6MA<P!.=6]R;V1A`$YU
M;W)O9&$@X3H`4&%D87)Y=&D@96PN('!A\'1O(&%D<F5SX"!N=6]R;V1A(.$@
M;&%I\&MO(')A\'EM;R!P=7-L87#A`$YU;W)O9&]S`$QI;G5X(&QA:6WK<R#^
M:6YU=.MS`%)O9'ET:2`M('9A<G1O=&]J87,@9V%L:2!M871Y=&D@:V%T86QO
M9V\@='5R:6[A`%)O9'ET:2!D=6]M96[X(&)A>FGX('/@<F'PX`!2;V1Y=&D@
M<&%G86QB;W,@=&5M87,`4F]D>71I(&QE;G1E;&GX('/@<F'PX`!+;VYF97)E
M;F-I:F]S(&%R8VAY=F%S`$MO;F9E<F5N8VEJ;W,@<&%G86QB80!+;VYF97)E
M;F-I:F]S($E$`$MO;F9E<F5N8VEJ;W,@<V%V:6YI;FMA<P!28?!Y=&D@X2!K
M;VYF97)E;F-I:N``4')I<VEJ=6YG=&D@<')I92!K;VYF97)E;F-I:F]S`$%T
M<VEJ=6YG=&D@;G5O(&MO;F9E<F5N8VEJ;W,`5F%R=&]T;VKX('/@<F'P87,@
M=?YD<F%U<W1A<RX`3&ET97)A=/MR80!,:65T=79A`$MR875N82XN+@!6:65T
M:6YI<R!L86EK87,Z(`!,;VMA;.L@:7(@;&%I:V%S`%9I971A`%!R:7-I:G5N
M9W1I`$%T<VEJ=6YG=&D`4')I<VEJ=6YG:6UO(&1A<F)A:0!0<FES:6IU;F=T
M:2!N97!A=GEK;RX@3F5T96ES:6YG87,@2OMS^"!N=7)O9'ET87,@=F%R=&]T
M;VIO('9A<F1A<R!I<B]A<B!S;&%P=&'^;V1I<RX`4')I<VEJ=6YG=&D@;F5P
M879Y:V\N`$EL9V%S('1E:W-T87,`365I;.L`3F5S=F%R8G4`36'^;W-I;W,@
M9W)A:6MI\&MO<R!R86EDZW,`36'^;W-I;W,@;&]T>6YI\&MO<R!R86EDZW,`
M36'^:65J:2!R;VWK;FGP:VD@<VMA:>AI86D`3&EU:W-E;6)U<F=A<P!-30!-
M3U1$`%!R:6MA8FEN=&%M92!-4RU43D5&(&9A:6QE(&[K<F$@9'5O;>MN^"X`
M35-'`$UA:V%O`$UA:V5D;VYI:F$`36%D86=A<VMA<F%S`$UA9VEJ80!08?!T
M87,`4&'P=&\@=F%L9'EM87,`4W5K=7)T:2!?;G5O<F]DX"XN+@!-86QA=FES
M`$UA;&%I>FEJ80!-86QD>79A:0!-86QI<P!-86QT80!+871E9V]R:6KX('/@
M<F'P;RP@:W5R:6]M<R!P<FES:VER:6%M:2!O8FIE:W1A:2P@:7(@<W4@:F]M
M:7,@<W5S:6IU<VGX('-P86QV^"!K96ET:6UA<RX`36%P,C0@_F5MZVQA<&ES
M`$UA<%%U97-T(/YE;>ML87!I<P!+;W9A<P!087)A\'3K`%!A_GEMZW1I(&MA
M:7`@<VMA:71Y='5S+VYE<VMA:71Y='5S`%!A_GEMZW1I(&MI=&%I<R!A=')I
M8G5T86ES("AP=GHN('-V87)B=2]A='-A:WET82D`36%R\&%L;R!S86QO<P!-
M87)T:6YI:V$`4W5J=6YG=&D@;&%U:V%I`$UA=7)I=&%N:6IA`$UA=7)I8VEJ
M=7,`36%K<VEM86QU<R!K<F5D:71A<RX`36%K<VEM86QU<R#^:6YUZ&GX(&1A
M;&GX(&MI96MI<R!I\&5I:W9O=&%S+@!-86MS+B!T96UP+B!P87-K+B`R-"!V
M86PZ(`!-86MS+B!T96UP+B!P87-K+B`V('9A;#H@`$UA:W-I;6%L=7,@:6QG
M:7,`1V5G=?[K`$UO:F]TZP!-961I8VEN80!.87)I86D`365N:74@<F7^:6UA
M<SH`4W5J=6YG=&D@8V5L97,`WFEN=73K`$QA:?!K87,@<&%V:7)T:6YT87,L
M('1AZ&EA=2!N97!A='9I<G1I;G1A<R!P87-I<F'P:75S:6\@87-M96YS('-E
M<G1I9FEK871A<RX`WFEN=73K(&YE:?!S:?AS=&$N`-YI;G5TZW,@=&EP87,`
M3W)O('-A;'EG;W,`3W)O('/@;'EG^"!B;&]K;R!NZW)A+@!/<F\@<^!L>6?X
M(&)L;VMO(&[K<F$N($%D;6EN:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L
M=7,@87!R8?!Y;6%S+@!-971O9&%S`$UA=&%I`$UE:W-I:V$`36EK<F]N97II
M:F]S($9E9&5R86-I;NMS(%9A;'-T:6IO<P!6:61U<GEJ90!-24U%('1I<&%S
M`$UI;BX@=&5M<"X@<&%S:RX@,C0@=F%L.B``36EN+B!T96UP+B!P87-K+B`V
M(&AO=7)S.B``071S<&EN9'ES`$MI=&]S`$YE<F%S=&%S(%!%05(@2%144%]2
M97%U97-T('!A:V5T87,N`$YU<W1A='EM^"!NZW)A+B!*96EG=2!N;W)I=&4@
M;F%U9&]T:2#PX2!M;V1U;.$L('1U<FET92!JX2!S=6MO;F9I9_MR=6]T:2X`
M3NMR82#^:6YU=.MS($E$+@!.97)A<W1A<R!R96EK86QI;F=A<R!014%2($UA
M:6P@<&%K971A<RX`3NMR82!S97-I:F]S($E$+@!0:7)M+@!-;V)I;'5S('!A
M\'1A<P!6:61U=&EN:7,`4F5D86=A=FEM;R!D871A`$ME:7-T:2!54DP`36]D
M=6QI<P!-;VQD;W9O<R!297-P=6)L:6MA`$UO;F%K87,`36]N9V]L:6IA`$WK
M;F5S:6%I(&ER(&UE=&%I`$MA<R!MZVYE<^$`36]N<V5R871A<P!-ZVYU;&EO
M(&9A>NMS`$UA<F]K87,`1&%U9VEA=7-I82!G:65D<F$`1&%U9VEA=7-I82!A
M<'-I;F%U:^8`1&%U9VEA=7-I82!S875LZW1A`%!E<FME;'1I(/YE;6EA=0!0
M97)K96QT:2!K86ER:6%U`%!E<FME;'1I(&1E\&EN:6%U`%!E<FME;'1I(&%U
M:_#H:6%U`%!E<FOK;&EM87,@_F5M>6X`4&5R:^ML:6UA<R!A=6OP='EN`$UO
M>F%M8FEK87,`2V5L971O(&QY9VGX(&GP<VES:VQE:63^:6%N=&ES('/@<F'P
M87,`2V5L971A<R!P87-I<FEN:VEM^`!-86YO('/@<VMA:71A`$UA;F\@<&]R
M=&%L87,`36%N;R!P;W)T86QO(&GP9.MS='EM87,`36%I;FUA<F%S`$Y%+"!.
M15-55$E.2U4`5F%R9&%S`$YA;6EB:6IA`$YA=7)A<P!.97!A;&%S`$YY9&5R
M;&%N9&%I`$YY9&5R;&%N9/@@06YT:6QA:0!.971S8W!A<&4@8F%Z:6YI<R!5
M4DP`3F5T<V-P864@<V5R:69I:V%T;R!A=/!A=6MI;6\@55),`$YE='-C<&%E
M('-E<G1I9FEK871O('1E:7-I^"!54DP`3F5T<V-A<&4@871N875J:6YO;6\@
M55),`$YE='-C87!E(&%T\&%U:VEM;R!54DP`3F5T<V-A<&4@4U-,('-E<G9E
M<FEO('9A<F1A<P!.971S8V%P92!S97)T:69I:V%T;R!A<')A\'EM87,`3F5T
M<V-A<&4@<V5R=&EF:6MA=&\@=&EP87,`5&EN:VQA<P!.:65K861A`$YA=6IO
M:FD@2V%L961O;FEJ80!.875J82!K871E9V]R:6IA`$YA=6IA<R!MZVYU;&ES
M`$YA=6IA<R!V87)T;W1O:F\@=F%R9&%S("AN96+[=&EN87,I`$YA=6IO:FD@
M6F5L86YD:6IA`$YA=6IA;64@;&%N9V4@*%]B;&%N:RD`3F%U:FEE;F]S`$YA
M=6II96[X(&=R=7#K<P!396MA;G1I<P!396MA;G1Y<R!N=7-T871Y;6%I`$YI
M:V%R86=V80!.:6=E<FES`$YI9V5R:6IA`$YA:W1I<P!.:75JZP!.90!.977^
M=&5N:V$@9'5O;65N^"!S:VER='5M^"!P87)O9'EM=6DN`$YE;G5R;V1Y=&$@
M<W1R871E9VEJ82!)4T\@<F'P>6UU:2X`3NMR82!S=63K=&EN:6\@\&%B;&]N
M;RX`3G5R;V1Y=&]J92!P;WII8VEJ;VIE(&)L;VMO(&[K<F$`3F7A=F5DZW1E
M(&MA;&5N9&]R:6%U<R!V87)D;R!-0T%,(&%U=&5N=&EF:6MA8VEJ;VIE+@!3
M:VER='5M^"!NZW)A+@#0:6]S('1E:7/K<R!N96=A;&D@='5RZW1I('!O=&5I
M<VGX+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE("5S(&MO;F9I9_MR86-I:N`N
M`$[K<F$@:6YF;W)M86-I:F]S(&%P:64@1E10(%9&4R!K;VYF:6?[<F%C:6K@
M+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE(%-13"!61E,@:V]N9FEG^W)A8VEJ
MX"X`3NMR82!I;F9O<FUA8VEJ;W,@87!I92!344PM1FEL92!61E,@:V]N9FEG
M^W)A8VEJX"X`2W)E9&ET87,@:?!E:6MV;W1A<RX`3F7A=F5S=&%S(&=A=NMJ
M87,N`$9A:6QA<R!N96YU<VGX<W1A<P!.96YU<W1A='ET82!V:65T;W;K+@!.
M9>%R8?#K=&4@_FEN=73K<RX`3F7A<F'PZW1E('9A<F1O+@!.9>%R8?#K=&4@
M;G5M97)I;RX`3F5R;V1Y=&D@X?YE:63^:6%NZ&GX(&9R87II^`!.9>%V963K
M=&4@<VQA<'1A_F]D_FEO($A45%`@875T96YT:69I:V%C:6IA:2X`3F7A=F5D
MZW1E('-L87!T8?YO9/YI;R!)34%0(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E
M9.MT92!S;&%P=&'^;V3^:6\@2V5R8F5R;W,@875T96YT:69I:V%C:6IA:2X`
M3F7A=F5DZW1E('-L87!T8?YO9/YI;R!,;V=I;B!A=71E;G1I9FEK86-I:F%I
M+@!.9>%V963K=&4@<VQA<'1A_F]D_FEO(%!!4U-71"!A=71E;G1I9FEK86-I
M:F%I+@!.9>%V963K=&4@<VQA<'1A_F]D_FEO(%--0B!A=71E;G1I9FEK86-I
M:F%I+@!.9>%V97-T87,@:V5L:6%S(&EK:2!/<&5N4U-,('!A9W)I;F1I;FGX
M(&9A:6SX+B!/<&5N4U-,(')E:6MA;&EN9V$@9&%R8G5I('-U(%!+0U,@,3(@
M9'5O;65N:6UI<RX`3F5P871V:7)T:6YT^"!R96=I<W1R86-I:O@@;NMR82X`
M3F5N875D;W1I('-K:7)T=6OX`$[K('9I96YO:F4@<'5SZVIE`%-P87)T:6YI
M;75I(&[K<F$@;&%I:VEN;VIO(&MA=&%L;V=O+@!687)T;W1O:F\@=F%R9&%S
M(&ER+V%R8F$@<VQA<'1A_F]D:7,@;F5N=7-I^'-T87,N`%1E:7-I;F?X(%A-
M3"!D=6]M96[X(&[K<F$`3NMR82!R96EK\&UI^`!+;VYF:6?[<F%C:6YI86UE
M(&9A:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E;F5R=6]K:71E(&YU<W1A='EM
M=7,N`$MO;F9I9_MR86-I;FEA;64@9F%I;&4@;NMR82!V97)S:6IO<RX@4&5R
M9V5N97)U;VMI=&4@;G5S=&%T>6UU<RX`3F5N=7)O9'ET80!.ZW)A`-!I875R
MZW,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK;R!S86QO<P#0:6%U<FENZR!H96UI
M<V9E<F$`T&EA=7)I;NMS($UA<FEJ86[X('-A;&]S`$YO<G9E9VEJ80!.92!P
M;R!T;P!.92!P<FEE\"!T86D`3F4@:V%T86QO9V%S`$YE<F5A;&EZ=6]T82X`
M3F5N=7)O9'ET80!.97!A;&%I:V]M87,N`%7^<F'P86D`3NMR82!KX"!P97+^
M:?MRZW1I+"!E:6MI=&4@871G86PN`$QA<&MR:71I<P!.=6UE<FES`%-I;6)O
M;&GX('-K86GH:75S`%-T=6QP96QI^"!S:V%IZ&EU<P!%:6QUZ&GX('-K86GH
M:75S`$YEX79E<W1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O(&%T;F%U:FEN:6UO
M('-K86GH:6%I+@!/2P!/8FIE:W1A<P!/8FIE:W1O('-A=FEN:6YK87,`0?!T
M=6YT86EN:7,`4W!A;&ES`-YI875R=6UO(&9I;'1R87,`3V9I<V%S`$]M86YA
M<P!+871A;&]G^"!D86QI:FEMX'-I('!A;&%I:V\@=&EK($E-05`@<V5R=F5R
M:6%I+@!4:6L@X?YE:63^:6%NZ&EO<R!F<F%ZZW,`3&5I9/YI86UA<R!T:6L@
M=FEE;F%S(&5L+B!P8?!T;R!A9')E<V%S+@!%;&5M96YT;R!S879I;FEN:V\@
M=&5I<V5S(&=A;&D@:V5I<W1I('1I:R!J;R!S879I;FEN:V%S(&%R8F$@<VES
M=&5M;W,@861M:6YI<W1R871O<FEU<P!!=&ED87)Y=&D@;F%U:F%M92!L86YG
M90!!=&ED87)Y=&D@\&G@(&YU;W)O9.`@;F%U:F%M92!L86YG90!/<')A8VEN
MZW,@<VES=&5M;W,`3G5S=&%T>6UA:0`E<R!N=7-T871Y;6%I`%-U<OOP:75O
M=&%S('/@<F'P87,`3W)G86YI>F%C:6IA`%!A9&%L:6YY<P!3:7-T96UI;FEM
M87,`3W)I9VEN86QU<R!A<&QI:V%C:6IO<R#P86)L;VYA<P!/<FEG:6YA;/AS
M(/!A8FQO;F%I("5S.@!+:71A`$MI=&$@:6YF;W)M86-I:F$`4V%V:6YI;FEK
M;R!T96ESZW,`3NMR82!004T@875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO
M+@!01U`@<VMA:71M96YI;FES('!A<F'P87,`4$=0('7^:V]D=6]T82!I;F9O
M<FUA8VEJ80!01U`@=FEE\&%S:7,@<F%K=&%S`%!'4"!P87-I<F'P>71I+W7^
M:V]D=6]T:2!D=6]M96YY<P!02%`@:V]D87,`4$A0($-,20!032!L96YG=F%S
M(&QI971U<P!032!L:?MT:7,`4$T@5"UA=61R80!07TA0($-,20!487)P86D@
M8V5LZW-E`%!A:VES=&%N87,`4&%L874`5?YI;71O:FD@4&%L97-T:6YO<R!T
M97)I=&]R:6IA`%!A;F%M80!087!U82!.875J;VII($=V:6[K:F$`4&%R86=V
M86IU<P!$86QI;F%I(&1E8F5S=6]T80!3;&%P=&'^;V1I<P!3;&%P=&'^;V1I
M<R!N971E:7-I;F=A<P!2041)55,@875T96YT:69I:V%C:6IA:2!R96EK:6$@
M<VQA<'1A_F]D_FEO+@!3;&%P=&'^;V1I<R!S=2!P871V:7)T:6YI;74`4VQA
M<'1A_F]D:7,Z`%-L87!T8?YO9&ES.B``4VQA<'1A_F]D_FEA:2!T=7)I('-U
M=&%P=&DN`,%K96QT:0#!:V5L=&D@:?`@;&%I:VEN;W-I;W,@<V%U9WEK;&]S
M("AC;&EP8F]A<F0I`$ME;&EA<P!.97!A='9I<G1I;G1O<R!R96=I<W1R86-I
M:F]S.@#>;6]NZW,`4')O8V5N=&%I`$%T;&EK=&D@<')O9FEL86MT:6YI=7,@
M=F5I:W-M=7,`07(@871L:6MT:2!P<F]F:6QA:W1I;FEU<R!V96EK<VUU<R!P
M<FES:6IU;F=I;6\@;65T=3\`5&5I<^MS`%1E:7-I^"!A9&UI;FES=')A=FEM
M87,`07-M96YI;NL@:6YF;W)M86-I:F$`4&5R=0!'>7;[;F%I`$9I;&EP:6YA
M:0!496QE9F]N87,`3G5O=')A=6MO<P!0:71K<F%N87,`4&EK<V5L:6%I`$)A
M;F%L>6+K<P!)\'-I<FEN:VET92!K=7)IX"!N;W)S(&-E;.8`4&%T=FER=&EN
M:VET92P@87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#PX2!E;&5M96YTX#H`
M4&%T=FER=&EN:VET92P@87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P:6\@
M96QE;65N=&\@;G5O<F]DX"X`P79E<VMI=&4@;>MN97/A(&ER(&UE='5S+@#!
M=F5S:VET92!N875J;W,@:V%T96=O<FEJ;W,@<&%V861I;FEMX#H`P79E<VMI
M=&4@=&5I<VEN9^`@25`@861R97/@+@#!=F5S:VET92!T96ES:6YGX"!D873@
M+"!P871I:W)I;FMI=&4@9&EE;O@@<VMA:>AI^"!MZVYE<WEJ92X`P79E<VMI
M=&4@=&5I<VEN9^`@;&%I:^`N`$%P<F'P>6MI=&4@<')O8FQE;>`N`$YU<F]D
M>6MI=&4@<V%V;R!V87)T;W1O:F\@=F%R9.`@8F5I('-L87!T8?YO9.$`P79E
M<VMI=&4@;F%U:N`@:V%T96=O<FEJ;W,@<&%V861I;FEMX#H`3&5N:VEJ80!0
M;VQI=&EK86D`0F%L<V%V:6UA:0!0;W)T=6=A;&EJ80!0879E:6MS;.ML:6\@
M<&]Z:6-I:F$`3&5N=&5LZW,@<&]Z:6-I:F$`2?!S875G;W1I(/!I86UE(&MA
M=&%L;V=E("AN96=A;&EO:F$@24U!4"D`2W)I='5L:6%I('!A<VLN("5S('9A
M;&%N9.`H87,I.B``4')E9G-?;&1A<#H@;F5R87-T87,@<F5I:V%L:6YG87,@
M3$1!4"!M;V1U;&ES+@!0<F5F<U]S97-S:6]N.B!N97)A<W1A<R!R96EK86QI
M;F=A<R!S97-I:O@@;6]D=6QI<RX`4VSK9VES`%-LZV=I<R!J^W)O<R!L>6=Y
M:F4Z(`!3;.MG:7,Z(`!097+^:?MR80!097+^:?MRZW1I('!A=F5I:W-LZVSA
M(&YA=6IA;64@;&%N9V4`06YK<W1E<VYI(&YU<W1A='EM86D`071S<&%U<V1I
M;G1I(&1O:W5M96YTX`!3;&%P=&%S:7,@<F%K=&%S`%!R;V)L96UA`%!R;V)L
M96UO<R!A<')A\'EM87,`4')O:F5K=&%I`%!R8?!Y;6%S('1E:W-T=6D`5FEE
M\&%S:7,@<F%K=&%S`%9I9?!O:F\@<F%K=&\@86QG;W)I=&UA<P!6:67P;VIO
M+W-L87!T;VIO(')A:W3X('!O<F$@;F5S=6=E;F5R=6]T82X`4'5E<G1O(%)I
M:V%S`$MA=&%R87,`4V%K:6YY<P!24T$@=FEE\&%S:7,@<F%K=&%S("@E9"!B
M:71A:2D`)U)A9&EO)R!P87-I<FEN:VEM87,`3&EE='5S`$QI971U<R!R>71E
M`$QI971U<R!V86MA<F4`3&G[=&ES`$%T<VET:6MT:6[K(&9R87KK`%-A;G1Y
M:VES`%-K86ET>71I`%!E<G-K86ET>71I(&QA:?!K86D`5&EK<F%I(&GP=')I
M;G1I("5S/R!'<F'^:6YT:2!A=&=A;"!N96)E9V%LZW-I=&4N`%1I:W)A:2!I
M\'1R:6YT:2!V87)T;W1O:F\@)7,@9'5O;65N:7,_($=R8?YI;G1I(&%T9V%L
M(&YE8F5G86SK<VET92X`4&%K87)T;W1I(&%N:W-T97-NX2!V96EK<VW@`$%T
M;F%U:FEN=&D@:V%I<FEO:F\@;65N:74@96QE;65N='5S.@!!=&YA=6II;G1I
M('!O<G1A;&\@=F%I>F3@.@!296=E>`!3X')Y\&GX(&YA<O!Y:VSK`%!A<W1A
M8F]S`$YU=&]LYB!S97)V97)I86D`3G5T;VSF<R!54DP@*&AT='`Z+R]W=W<N
M<&%V>7ID>7,N8V]M+VAO<F1E*3H`2?!T<FEN=&D`4&'P86QI;G1I(&)L;VO@
M`%!A;F%I:VEN=&D@<W1U;'!E;.$`4&%N86EK:6YT:2!F;W)M871A=FEMX`!)
M\'1R:6YT:2!P;W+@`$GP=')I;G1I(&%T;F%U:FEN:6UO('-K<FEP=.`@:?`@
M<V5R=F5R:6\@;&%I:VEN;VIO(&MA=&%L;V=O+@!08?!A;&EN=&D`4&'P86QI
M;G1I(/#A(&5L96UE;G3@(&GP(&1O:W5M96YT;P!)\'1R:6YT:2!V87)T;W1O
M:N``5F%R=&]T;VIO('1R>6YI;6%S.B`E<P!.96=A;&EU(&%T<V%K>71I(.$@
M=?YK;&%U<^`N($ML86ED;W,@:V]D87,Z(`!)\"!N875J;P!086ME:7-T:2!S
M;&%P=&'^;V3A`%-L87!T8?YO9/YI;R!K96ET:6UA<P!297IU;'1A=&%I`$=R
MX?YT:2#A(&YU<W1A='EM=7,`4F5J^VYI:F$`071S=&%T>71I(&MO;F9I9_MR
M86-I:N``2%1-3"!R961A:W1O<FEA=7,@;G5S=&%T>6UA:0!-X7-LZW,`1&7P
M:6[K:F4`1&7P:6YI;VII(&%N=')A\'3K`$1E\&EN:6]S:6]S(')E:6OP;>MS
M`%]%:6QU=.MS(&YU<W1A='EM86DN+BX`4F]LZP!2=6UU;FEJ80!087-U:W1I
M(#$X,`!087-U:W1I(&MA:7+K;@!087-U:W1I(&1E\&ENZVX`16EL=73K<R!N
M=7-T871Y;6%I`$5I;'5TZW,@;G5S=&%T>6UA:0!%:6QU=.MS.@!3:VER='5K
M86D`4VMI<G1U:V%I('1A<G`@=FES^"!E:6QUZ&GX(&ER('-T=6QP96QI^`!3
M:VER='5K86D@=&EK('1A<G`@<W1U;'!E;&GX`%-K:7)T=6MA:2!T:6L@=&%R
M<"!E:6QUZ&GX`%9Y:V1Y=&D`4G5S:6IO<R!&961E<F%C:6IA`%)U86YD80!3
M+TU)344@<&%R8?!A<P!3+TU)344@=?YK;V1U;W1A<R!L86GP:V%S`$[K<F$@
M4T%33"!A=71E;G1I9FEK86-I:F]S(&UE8VAA;FEZ;6\N`%--4R#^:6YU=.MS
M`%-13"!#3$D`4U-(`%!!5EE+3P!37U%,($-,20#09?!T+@#0=F5N=&]J:2!(
M96QE;F$`4V%I;G0@2VET<V%S(&ER($YE=FES87,`4V%I;G0@3&EU8VEJ80#0
M=F5N=&%S:7,@4&5T<F%S(&ER($UI9V5L;VYA<P!386EN="!6:6YC96YT87,@
M:7(@1W)E;F%D:6YA:0!486UE('!AZ&EA;64@;&%N9V4@*%]S96QF*0!386UO
M80!386X@36%R:6YA<P!386\@5&]M92!I<B!0<FEN8VEPZP!086QY9&]V87,`
M4V%U9&\@07)A8FEJ80!)\'-A=6=O=&D`2?!S875G;W1I("5S`$GP<V%U9V]T
M:2!N=7-T871Y;75S`$GP<V%U9V]T:2!S=6=E;F5R=6]T=7,@;G5S=&%T>6UU
M<R!K86EP(%!(4"!S:W)I<'3@(&K[<_@@<V5R=F5R:6\@;&%I:VEN86IA;64@
M:V%T86QO9V4N`"5S(&YU<W1A='EM86D@:?!S875G;W1I+@!-;VMS;&%S`$EE
M\&MO=&D`4&%I9?!K80!087-I<FEN:VET92!F86EL=7,`4&%S:7)I;FMI=&4@
M9&%TX`!087-I<FEN:VET92!G<G5PY@!087-I<FEN:VET92!N875JX"!S879I
M;FEN:^``4&%S:7)I;FMI=&4@<V5R=F5RX0!087-I<FEN:VET92!V87)T;W1O
M:N``4&%S:7)I;FMI=&4@=FES=7,@9&%T;W,@:V]M<&]N96YT=7,N`%!A<VER
M:6YK:71E(&]B:F5K=.``2?`@_F5M:6%U(&5S86[H:?@@<^!R8?#X('!A<VER
M:6YK:71E(')E:6MI86UU<R!S:6UB;VQI=7,N(%;K;&EA=2!G86QI=&4@:G5O
M<R!N=6MO<&EJ=6]T:2#A(&QA:?!KX"X`4&%S:7)I;FMI=&4@9&%T;W,@<VMI
M<G1U:^`Z`%!A<VER:6YK:71E(&1A=&]S(&9O<FUA=.`Z`%!A<VER:6YK:71E
M(&%P<F'PX"!K=7+A(&YO<FET92!R961A9W5O=&DZ`%!A<VER:6YK:71E(&QA
M:6MO('-K:7)T=6O@.@!087-I<FEN:VET92!L86EK;R!F;W)M873@.@!087-I
M<FEN:VET92!D=2!A=&ET:6YK86[H:75S(&QA=6MU<RX`4&%S:7)I;FMI=&4@
M<W!A;';X(&1E<FENX2X`4&%S:7)I;FMI=&4@;F]R:6W@(&MA;&+@.@!3:?AS
M=&D@<')O8FQE;6]S('!R86YE\&EMX`!3:?AS=&D@4TU3`%-E;F5G86QA<P!3
M96YS;W)I=7,Z(`!2=6=SZVII<P!397)B:6IA(&ER($UO;G1E;F5G<F%S`%-E
M<FEJ;W,@;G5M97)I<P!397-I:F]S($E$('!A<VEB86EGZRX`4FEN:VEN>7,`
M3G5S=&%T>6UA:2!L96ED_FEA;G1Y<R!*=6US('!A<VEK96ES=&D@<VQA<'1A
M_F]DX2P@:F5I9W4@:N$@:V%D82!N;W)S('!A;6ER\&ET92X`3G5T;VQU<VGX
M('-E<G9E<FGX+"!K=7)I=6]S(&YO<FET92!M871Y=&D@:?`@<&]R=&%L;RP@
M;G5S=&%T>6UA:2X`2V%L8F]S+"!L86EK;R!Z;VYO<R!I<B!D871O<R!N=7-T
M871Y;6%I+@!0=7-L87!I;R!S<&%L=O@L(&%T<VEN875J:6YI;6\@9&'^;G5M
M;R!I<B!K:73X('9A:7ID879I;6\@<&%R86UE='+X(&YU<W1A='EM86DN`%)A
M<W1A<R!A=&YA=6II;FEM;R!S:W)I<'1A<P!3=2#P:75O('!A<F%M971R=2!G
M86QI;6]S(&ME;&EO<R!V:65T;W;K<SH@`%-E:?!E;&%I`%!A<F1U;W1U=NL`
M5')U;7!A<R!A<')A\'EM87,`07(@;F%U9&]T:2!K;&%V:6%T^W)O<R!M>6=T
M=6MU<R!V86QD>6UU:3\`4F]D>71I`%!A<F]D>71I('-K:7)T=6UU<R!T87)P
M(&GP<V%U9V]T;R!I<B!KX"!T:6L@<W5G96YE<G5O=&\@:V]N9FEG^W)A8VEN
M:6\@9F%I;&\N`%)O9'ET:2!P87-K=71I;FEO('!R:7-I:G5N9VEM;R!L86EK
MX#\`4F]D>71I(&=A;&EM>6+F('!A;&EK=&D@;W)I9VEN86S@`%)O9'ET:2!P
M87)I<VEN:VEMX`!2;V1Y=&D@;&5N=&5LZW,@;W!E<F%C:6KX(&UE;FEU/P!2
M;V1Y=&D@)7,@;65N:74@:V%I<NMJ93\`4F]D>71I(&-E;.MS(&YU<W1A='EM
M^"!L86YGX`!2;V1Y=&D@;&5N=&5LZW,@;G5S=&%T>6WX(&QA;F?@`%)O9'ET
M:2!E:6QU=.MS(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@<&%V96EK<VSK;&EO
M(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@9F%I;/@@X6OK;&EMX`!,:?MT:7,`
M3&G[=&ES(')Y=&4`3&G[=&ES('9A:V%R90!3=6UA_FEN=&D`4W5M8?YI;G1I
M(&%R8F$@<&%S='5M=&D@:V%I;7EN:6YI=7,@8FQO:W5S`%-I97)A($QE;V[K
M`%)E9VES=')A8VEJ80!087)A\&%S`%!A<F'P;R!A;&=O<FET;6%S`%-I;F=A
M</MR87,`1'ED:7,`4')A;&5I<W1I('!R;V9I;&%K=&EKX`!3;&]V86MI:F$`
M4VQO=NMN:6IA`%#[9V$`4VYI96=O(&=Y;&ES.B``4VYI96=O(&MI96MI<R!V
M86YD96YI=3H@`%-O;&]M;VYO('-A;&]S`%-O;6%L:6$`1&%I;F]S(&ER($5I
M;.MR8?#H:6%I`%+[\&EA=FEM;R!T=F%R:V]S('!A<VER:6YK:6UA<P!3:75N
M=.MJ;R!A9')E<V%S`%!I973X($%F<FEK80!0:65T^"!%=7)O<&]S("A)4T\M
M.#@U.2TS*0!0:65T^"!$_F]R9/YI:F]S(&ER(%!I973X(%-A;F1V:>AO('-A
M;&]S`%!I971I;NL@:&5M:7-F97)A`%1A<G!A<R!T87)P(&-E;&GX`%1A<G!A
M<R!T87)P(&-E;.MS('1U<FEN:6\@:7(@:W)A\'1I;NMS`%1A<G!A<P!487)P
M86D@=&%R<"!C96QI^`!487)P86D`27-P86YI:F$`4W!A;6%S`%-P96-I9FEN
M:?@@<VEM8F]L:?@@X71E<G!I;6%S`%!E<G-K96QT:2!C96SF`%!E<G-K96QT
M:2!S='5L<&5LX0!097)S:V5L=&D@96EL=73F`%-P;W)T87,`T')I($QA;FMA
M`%-T86YD87)T87,`4W1A<B!4<F5K)V%S`%!R861I;FEA:2!M971A:0!286IO
M;F%S(&%R8F$@<')O=FEN8VEJ80!"^W-E;F$`4V%U9V]J:6UO(&9O<FUA=&%S
M`$=A=';K<R!A9')E<V%S`%7^8G)A=6MT:0#>;V3^:?@@<^!R8?!A<P!.=6EM
M=&D@9&]M96[@(&YU;R!A9')E<V\`4W1I;&EU<R!;0U-370!396MM+@!496UA
M`,%V97-T:0!);F1E:W-A<P!3ZVMM:6YG80!+;VYF:6?[<F%C:6IA(&%T<W1A
M='ET82!SZVMM:6YG86DN(%!E<FMR875K:71E('!U<VQA<.$L(&MA9"!P86UA
M='ET=6WK=&4@<&%K96ET=6UU<RX`071S87)G:6[K(&MO;F9I9_MR86-I:F]S
M(&MO<&EJ82!SZVMM:6YG86D@:?!S875G;W1A+@`G)7,G('/K:VUI;F=A:2!U
M_G)A\'ET87,N`%-U9&%N87,`5'5R:6YY<P!3875LZW1E:VES`%-A=6SK;'EG
M:7,`4V%U;.MT80!3875LZW1E:VES`%-A=6SK=&5K:7,O4V%U;.ML>61I<P!3
M875LZW1E:VES.B``4V%U;.ML>6=I<P!3875LZVQY9VES.B``3&%I<'-N:7,`
M07!T87)N879I;6%S`%-U<FEN86UA<P!0879A<F3K`%-V86QB87)D87,@:7(@
M1/YA;FUA:6YA<P!3=F%Z:6QA;F1A<P#0=F5D:6IA`-!V96EC87)I:F$`4VEN
M=&%K<^MS(&ML86ED82!P86EE\&MO<R!K<FET97)I:G5J90!3:7)I:F]S($%R
M86+X(%)E<W!U8FQI:V$`5"UA=61R80!4+6%U9')O<P!44U8@9F%I;&%S`$QE
M;G1E;.L`3&5N=&5LZW,@;G5S=&%T>6UA:0!,96YT96SK<R!N=7-T871Y;6%I
M`%1A:79A;F%S`%1A:79A;F%S+"!+:6YI:F]S('!R;W9I;F-I:F$`5&%D_FEK
M:7-T86YA<P!*=6YG=&ENZR!486YZ86YI:F]S(%)E<W!U8FQI:V$`5&%I:VEN
M>7,Z`$1A<F)A:0!496QE9F]N;R!N=6UE<FES`%1E;7`N('!A<VLN('9A;&%N
M9.`Z(`!496UP97)A=/MR80!496UP97)A=/MR83H@`-!A8FQO;O@@861M:6YI
M<W1R879I;6%S`%1E:W-T87,`5&EK('1E:W-T87,`3'EG:75O=&D@=&5K<W3@
M`%1E:W-T;R!V:7+P=6IE`$ME='8N`%1A:6QA;F1I971I\&MA("A425,M-C(P
M*0!486EL86YD87,`0>AI^R!K860@;F%U9&]J873K<R!S:7-T96UA+@!.ZW)A
M($944"!M;V1U;&EO+@!(;W)D92]+;VQA8B!I;G1E9W)A8VEJ;W,@=F%R:6ML
M:75K87,@;F5P86QA:6MO("(E<R(`3F5P879Y:V\@=?YK<F%U=&D@36%I;G1E
M;F%N8V4Z.B!K;&%SZW,`3G5S=&%T>6WX(&QA;F=A<R!U_F1A<GET87,N($GP
M96EN=2X`2F5I9W4@;F]R:71E(&YA=61O=&D@;G5S=&%T>6UU<RP@<&%P<F'P
M>6MI=&4@:V%D(&%D;6EN:7-T<F%T;W)I=7,@<W5K;VYF:6?[<G5O=/@@<&%S
M=&]V:>`@9'5O;65N^"!B87KF(&YU<W1A='EM86US('-A=6=O=&DN`%1I:R!A
M<&%T:6[K:F4@<'5SZVIE`$YEX7)A\.MT92!C;VYT86MT;R!)1"!N=6UE<FEO
M(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+@!+;VYT86MT87,@
M<^MK;6EN9V%I(.%T<F%U:W1A<R#A($K[<_@@861R97/X(&MN>6=E;.8N`$YO
M<NMD86UI('!A=&EK<FEN=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@871S
M:VERX"!01U`@<&%R8?!O(&)L;VO@+@!.9>%R8?#K=&4@9&ES=')I8G5C:6IO
M<R!SX')A\&\@240@87)B82!J:7,@;F5R87-T87,@9'5O;65N^"!B87KK:F4N
M`$YEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;RX`4$=0('7^:V]D879I
M;6\@9V%L:6UY8NL@<F5I:V%L875J82!S875G875S('!R:7-I:G5N9VEM;RX@
M0F%N9'EK:71E(')A\'ET:2!H='1P<SHO+R!A9')E<V\@<')A9/YI;VIE+@!&
M86EL87,@)7,@<')I=F%L;R!T=7+K=&D@)7,@<&%R86UE='+@+@!&86EL87,@
M)7,@<')I=F%L;R!T=7+K=&D@:V%I(&MU<FEU;W,@)7,@<&%R86UE=')U<RX`
M1F%I;&%S(&YE9V%L:2!B^W1I(&YU:V]P:6IU;W1A<R!A;G0@<V%VYG,N`$9A
M:6QE(&[K<F$@9'5O;65N^"X`4D9#.#@R(&QA:?!K;R!A;G1R8?!TZW,N`$IE
M:6=U(&1I<F)A=&4@26YT97)N970@17AP;&]R97(@;F%R\'EK;&4L('!I;&YA
M96MR86YI<R!R961A:W1O<FEA=7,@<F7^:6UA<R!G86QI('-U:V5L=&D@<')O
M8FQE;?@L(&3K;"#P:6]S(&YA<O!Y:VSK<R!K;&%I9/@N($=A;&ET92!N96UA
M='ET:2!K86D@:W5R:?@@<F5D86MT;W)I875S(&5L96UE;G3X+B!*96EG=2!N
M875D;VIA=&4@5VEN9&]W<R`Y>"!/4R!G<F5IZ&EA=7-I86D@:OMS^"!K;VUP
M:75T97)I<R!P87!R8?#H:6%U<VEA:2!N=6QU\"!P87-K96QB9&%M87,@87!I
M92!P86=R:6YD:6[F(&ML86EDX"Y<;EQN2OMS(&)U=F]T92!P97)S<.MT87,N
M($IE:6=U('9I<W1I96L@;F]R:71E(&GP8F%N9'ET:2!P:6QN865K<F%NX2!R
M9?YI;>`@<W!A=7-K:71E($]++@!!<')A\&%S("(E<R(@:?!T<FEN=&%S+@!4
M:6L@:V%I<NMJ92!P=7/K:F4`0W)Y<'1?<'%P.CH@:VQA<V5I(')E:6MI82!N
M=7)O9'ET:2!K=7(@>7)A($=N=5!'(&9A:6QA:2X`3&%I\&MA<R!I\'-I^'-T
M87,@)7,@861R97-A='5I("5S('1E;6$@(B5S(B!B=79O('!A<F]D>71A<RX*
M5&'H:6%U('1A:2!N96=A<F%N='5O:F$@:V%D(&QA:?!K87,@8G5V;R!P97)S
M:V%I='ET87,@87)B82!S=7!R87-T87,N`%!A=F%D:6YI;6%S(&MU<N$@;F%U
M9&]S:71E(&YU;W)O9&]J92#A(&QA:?!K;R!R8?!Y;6\@<'5S;&%PX0!(;W)D
M95]#<GEP=%]S;6EM93HZ(&ML87-E:2!R96EK86QI;F=A<R!/<&5N4U-,(&UO
M9'5L:7,N`$YE9V%L:74@:?!S875G;W1I(&YU<W1A='EM;R`B)7,B+"!N97,@
M9'5O;65N^"!D>61I<R!V:7+P>6IA(&QE:7-T:6[@(')I8N``4')O9W)A;6$L
M('-K:7)T82!P97+^:?MRZW1I(/#A(&1U;VUE;O@@=&EPX"`H)7,I+"!N97)A
M<W1A('-I<W1E;6]J92X`5&EK(&MA:7+K:F4@:7(@9&7P:6[K:F4@<'5SZW-E
M`%1I:R!D9?!I;NMJ92!P=7/K:F4`4V5R=F5R:7,@(B5S(B!I\'1R:6YT87,N
M`%-E<G9E<FES("(E<R(@:?!S875G;W1A<RX`)7,@<F5G:7-T<F%C:6IO<R!P
M<F'P>6UA<R!I\'1R:6YT87,N`$YU<F]D>71A(&5I;'5TZR!N965G>FES='5O
M:F$N`%1I:R!V:7+P=71I;NMJ92!I<B!A<&%T:6[K:F4@<'5SZW-E`%1I:R!A
M<&%T:6[K:F4@<'5SZVIE`$YU<VGX<W1I(&1U;VUE;GES('!R87)A<W1I+@!.
M96=A;&EU(&GP<V%U9V]T:2!N=7-I^'-T;R!F86EL;RX`5V5A=&AE<BYC;VT@
M8FQO:V\@;NMR82X`3G5S=&%T>6WX(&[K<F$N`$1A;&GX+"!K=7)I87,@9V%L
M:6UA(')O9'ET:2!L86GP:V\@=&5K<W1E+"!NZW)A+@#0:6%M92!L875K92#A
M=F5S=&$@<&5R(&1A=6<@<VEM8F]L:?@N($K[<R#A=F5DZW1E("5S+"!O(&UA
M:W-I;6%L=7,@<VMA:>AI=7,@+2`E<R!S:6UB;VQI86DN`%!R;V)L96UO<R!S
M=2!F86EL^"!S:75N=&EM=3H@)7,@;F5N=7-I^'-T87,N`$YU<VGX<W1I(&9A
M:6QO(&YE<&%V>6MO+B!&86EL87,@)7,@>7)A(&1I9&5S;FES(&YE9W4@;&5I
M9/YI86UA<R!D>61I<R`H)60@8F%I=&%I*2X`3G5S:?AS=&D@9F%I;&\@;F5P
M879Y:V\N($9A:6QA<R`E<R!T:6L@9&%L:6YA:2!N=7-I^'-T87,N`$YE9V%L
M:74@<&%R;V1Y=&D@\&EO<R!L86GP:V\@9&%L:65S`$ML86ED82#A:V5L:6%N
M="!K;VYT86MT:6YI=7,@9'5O;65N:7,N`$ML86ED82#A:V5L:6%N="!I0V%L
M96YD87(@9'5O;65N:7,N`$ML86ED82!K;VYF:6?[<F%C:6IO<R!F;W)M;VIE
M+B!'<F5IZ&EA=7-I86D@;F5U_G!I;&3K=&4@<F5I:VEA;?@@;&%U:_@N`$ML
M86ED82!A=&QI96MA;G0@;G5R;V1Y=.`@861R97/X(&MN>6=E;.MS(&9U;FMC
M:6K@+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED82!A=&YA=6II;F%N="!K
M;VYT86MT:6YI=7,@9'5O;65N:7,N(%!A8F%N9'EK:71E(';K;&EA=2X`2VQA
M:61A(&%T;F%U:FEN86YT(&1I<W1R:6)U8VEJ;W,@<^!R8?#@+B!086)A;F1Y
M:VET92!VZVQI874N`-!I<R!)34%0('-E<G9E<FES(&YE<&%L86EK;R!K871A
M;&]G^"!D86QI:FEM;W-I+@!!=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S
M(%)!4B!A<F-H>79A<RX`071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!:
M25`@87)C:'EV87,N`$%T<F]D;RP@:V%D('1A:2!N971E:7-I;F=A<R!K;W)T
M96SK<R!N=6UE<FES+@#0:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN
M=71E<R!P97(@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P
M87-I;F%U9&]J86YT($A45%`@<')O=&]K;VQU`-!I('1V87)K>6MLZR!L96ED
M_FEA('-I^'-T:2#^:6YU=&5S('!E<B!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!P87-I;F%U9&]J86YT($A45%`@<')O=&]K;VQU`-!I('1V
M87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S(%--5%`@<')O=&]K;VQU
M('!E<B!6;V1A9F]N92!)=&%L:6IO<R!V87)T=7,L('1I:R!6;V1A9F]N92!N
M=6UE<FEA;7,N($II(')E:6MA;&%U:F$@96PN('!A\'1O(&%D<F5S;R!6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@#0:7,@;&%U:V%S('!R
M:79A;&]M87,N`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@<W9E:6MI96II
M('-K86GH:6%I+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-K86GH:6%I
M(&ER(&1V:71A\&MI86DN`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@8?!T
M=6YT86EN:6%I('-K86GH:6%I+@#0:6%M92!L875K92!T=7)I(&+[=&D@:V%B
M;&5L:6%I<R!A<F)A('1A<G!A:7,@871S:VER=&D@<W9E:6MI96II('-K86GH
M:6%I`-!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+@#0:6%M92!L875K
M92!G86QI(&+[=&D@=&EK('-P86QV;W,@:V]D87,@4D="($AE>"!F;W)M871E
M+"!P879Y>F3^:75I("<C,3(S-$%&)RX`T&D@9F]R;6$@:F%U(&%P9&]R;W1A
M+@!486D@)7,N`%1A:2!+;VQA8B!'<F]U<'=A<F4@;V)J96MT87,N($YO<NMD
M86UI('!E<OYI^W+K=&D@;V)J96MTX"!P<FEV86QO=&4@='5RZW1I(&5L+B!P
M8?!T;R!K;&EE;G3@+"!K=7)I<R!S=7!R86YTX"#PX2!F;W)M873@+B!4;VMI
M^"!E;"X@<&'P=&\@:VQI96YT^"!SX')A\.`@9V%L:71E(')A<W1I(&%P<VEL
M86YKYB`E<P#0:7,@;&%I\&MA<R!B=79O('!A<F'P>71A<R`E<R!K;V1U;W1E
M+B!*^W,@;F%U9&]J871E(&MI=&]K:>`@:V]D=6]TYBX`T&ES('-K86GH:75S
M('1U<FD@8OMT:2!D:61E<VYI<R!U_B!N=6SA+@#0:7,@<V5R=F5R:7,@;F5G
M86QI(&GP87)C:'EV=6]T:2!Z:7`@:7(@9WII<"!F86EL^"X`T&D@<VES=&5M
M82!D86)A<B!I\&IU;F=T82X`T&D@<F5I:_!MZR!T=7)I(&+[=&D@<VMA:>AI
M=7,N`-#A(&QA;F?@(')E:6MI82!A=&ED87)I;NMT:2!I\"!N=7-T871Y;?@@
M;&%N9V\`4&5R:_MN:6IA`$)I;&EE=&%I`$QA:6MA<P!,86EK;R!A<'-K86ET
M80!,86EK;R!F;W)M871A<P!,86EK;R!P87-I<FEN:VEM87,`5&EM;W)L97-T
MZP!087)E:6=O<P!0879A9&EN:6UA<SH`2V%M`$YO<NMD86UI('!A<VER:6YK
M=&D@:V5L973@(&5L96UE;G3X+"!L86EK>6MI=&4@0V]N=')O;"`H4$,I(&%R
M8F$@0V]M;6YA9"`H36%C*2!K;&%V:?#@+"!I<B!P87-I<FEN:VET92!P96QE
M+@#0:6%N9&EE;@!2;V1Y=&D@2%1-3"!K;V3@`%1O9V%S`%1O:V5L874`4GET
M;VH`5&]N9V$`5FER\'5J90!6:7+P=71I;FEA;64@;&%N9V4@*%]T;W`I`%9E
M<G1I;6%I`%1R:6YI9&%D87,@:7(@5&]B86=A<P!486EP(&%R8F$@;F4`06YT
M<BX`5'5N:7-A<P!4=7)K:6IA`%1U<FMI\&MA("A)4T\M.#@U.2TY*0!4=7)K
M;>MN:6IA`%1U<FMS;R!I<B!+86EK;W-O('-A;&]S`%1U=F%L=0#!=F5S:VET
M92!S879O('!A<VER:6YK:6W@.B``52Y6+B!I;F1E:W-A<SH@`%523`!3:W)I
M<'1O('!R:7-T871Y;6\@<W1A='5S;R!R87!O<G1O(%523`!54DPZ`%5G86YD
M80!5:W)A:6YA`$YE<&%V>6MO('!E<G-K86ET>71I(%9&4R!K871A;&]G;RX`
M3F5P879Y:V\@<')I9.MT:2!P87!I;&1O;6]S('9A<G1O=&]J;R!R96=I<W1R
M86-I:F]S(&EN9F]R;6%C:6IO<RX`3F5P879Y:V\@<&%K96ES=&D@5D93(&9A
M:6QO("(E<R(@=&5I<VGX+@!.97!A=GEK;R!P86ME:7-T:2!T96ES:?@@5D93
M(&9A:6QU:2`E<R\E<RX`3F5P879Y:V\@<&5R96ET:2#A("5S+@!.97!A=GEK
M;R!P<FES:6IU;F=T:2!P<FEE(%-13"!S97)V97)I;RX`3F5P879Y:V\@<')I
M<VEJ=6YG=&D@4U-,(')E_FEM=2X`3F5P879Y:V\@;G5K;W!I:G5O=&D@5D93
M(&9A:6QO+@!.97!A=GEK;R!S=6MU<G1I(%9&4R!K871A;&]G;R`B)7,B+@!.
M97!A=GEK;R!S=6MU<G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@<W5K=7)T
M:2!61E,@9F%I;&\N`$YE<&%V>6MO('-U:W5R=&D@='7PZ&EO(%9&4R!F86EL
M;RX`3F5P879Y:V\@:?!A<F-H>79U;W1I(&1U;VUE;O@N`$YE<&%V>6MO(&GP
M=')I;G1I("(E<R(L(&MA=&%L;V=A<R!N971U\.AI87,`3F5P879Y:V\@:?!T
M<FEN=&D@)7,L(&MA=&%L;V=A<R!N971U\.AI87,`3F5P879Y:V\@<F5K=7)S
M:?!K86D@:?!T<FEN=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!I\'1R:6YT
M:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO(&GP=')I;G1I(%9&4R!K871A;&]G
M;SH@)7,N`$YE<&%V>6MO(&GP=')I;G1I(%9&4R!F86EL;R`B)7,B+@!.97!A
M=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\N`$YE<&%V>6MO(')E:W5R<VGP:V%I
M(&GP=')I;G1I(%9&4SH@)7,N`$YE<&%V>6MO(&YU<W1A='ET:2!D86)A<G1I
M;FEO(&MA=&%L;V=O+@!.97!A=GEK;R!G875T:2!S97)T:69I:V%T;R!A<')A
M\'EM;P!.97!A=GEK;R!U_FMR875T:2`E<R!A<')A\'EM;RX`3F5P879Y:V\@
M<&5R:V5L=&D@5D93(&9A:6QO+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A
M:6QO("(E<R(N`$YE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\@<F'P>6UU
M:2X`3F5P879Y:V\@871I9&%R>71I(%9&4R!F86EL;RX`3F5P879Y:V\@871I
M9&%R>71I('-U<W!A=7-T;R!A<F-H>79O+@!.97!A=GEK;R!P97)S:V%I='ET
M:2!V9G-R;V]T(&MA=&%L;V=O+@!.97!A=GEK;R!P97)V861I;G1I("5S(.$@
M)7,Z('1O:W,@:V%T86QO9V%S(&IA=2!E9WII<W1U;VIA`$YE<&%V>6MO('!E
M<G9A9&EN=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!P97)V861I;G1I(%9&
M4R!K871A;&]G;SH@)7,N`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO
M("(E<R(N`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO("5S+R5S+@!.
M97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;RX`3F5P879Y:V\@<&%L96ES
M=&D@)VUK:7-O9G,G+@!.97!A=GEK;R!I\'9E<G-T:2#P:6\@5V]R9"!D;VMU
M;65N=&\`3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y
M:V\@X7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH*2!K;&%I9&$I+@!.97!A=GEK
M;R#A<F'P>71I(%9&4R!F86EL;R!D=6]M96[X+@!086)R875K=&D`073P875K
M=&D@<&%K96ET:6UU<P!!=/!A=6MT:2!A;FMS=&5S;N$@=F5I:W-MX`!.971I
M:^MT82!S97)V97)I;R!K;&%I9&$Z(`!.971I:^MT82!S97)V97)I;R!K;&%I
M9&$Z(`!.96YU<F]D>71A`%5N:6MO9&%S("A55$8M."D`2G5N9W1I;FEA:2!!
M<F%B^"!%;7ER871A:0!*=6YG=&ENZR!+87)A;'ES=.L`2G5N9W1I;NMS(%9A
M;'-T:6IO<P!*=6YG=&EN:?@@5F%L<W1Y:O@@071O:V5S;NMS('-A;&]S`%9I
M96YE=&%I`$YE_FEN;VUA<P!.9?YI;F]M87,@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2X`3F7^:6YO;6%S(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN`$YE_FEN;VUA<R!V87)T;W1O:F\@=F%R9&%S(&ER+V%R8F$@<VQA<'1A
M_F]D:7,N`%!A;F%I:VEN=&D@;G5O<F]DX"#P:6%M(&5L96UE;G1U:0!.9>%V
M87)D:6YT87,`4V%U9W5M;R!S=6UE=&EM86ES(&YE<')I=FEL96=I:G5O=&D@
M<VMR:7!T86D@;F5G86QI(&%T;&EK=&D@4&5R:^ML:6UO+TMO<&EJ879I;6\O
MP6OK;&EM;R!P<F]G<F%M:?!K86DN($YO<NMD86UI('!E<OYI^W+K=&D@=&5C
M:&YI;F5S(&1E=&%L97,@;6]Z:6QL82YO<F<@=&EN:VQA<'EJ92P@:7(@<W7^
M:6YO=&D@:V%I<"!S:W)I<'1A;7,@;&5I<W1I('!R:65I=&D@<')I92!L86EK
M:6YO<VEO<R!S875G>6ML;W,L('!A<W!A=7-K:71E($]++@!.96YA=61O=&D@
M<W!A;'9O<P!0;.MT:6YY<R!N97!A;&%I:V]M87,`071N875J:6YT:0!!=&YA
M=6II;G1I("5S`$%T;F%U:FEN=&D@=F%R=&]T;VK@`$%T;F%U:FEN:6UO('-K
M<FEP=&%S(&GP=')I;G1A<RX`3G5S:?AS=&D`5FES:2!M;V1U;&GX(&%T;F%U
M:FEN:6UO(&9A:6QA:2#A:V5L=&D@X2!S97)V97+A+@!$:63^:6]S:6]S(&QO
M=&EN:?!K;W,@<F%I9.MS`$1I9&EE:FD@<F]MZVYI\&MI('-K86GH:6%I`%5R
M=6=V86IU<P!.875D;W1I(&1A8F%R=&ENYCH@)7,`3F%U9&]T:2!34TP`3F%U
M9&]T:2!J96EG=2!V87)T;W1O:F\@=F%R9&%S+W-L87!T8?YO9&ES($E-4U`@
M<V5R=F5R:75I('ER82!K:71O:W,N`%9A<G1O=&]J87,@)7,@;F5A=71O<FEZ
M=6]T87,@<')IZVII;75I('!R:64@)7,N`%9A<G1O=&]J^"!A9&UI;FES=')A
M=FEM87,`5F%R=&]T;VIO(&YU<W1A='EM86D`5F%R=&]T;VKX(')E9VES=')A
M8VEJ80!687)T;W1O:O@@<F5G:7-T<F%C:6IA(&GP:G5N9W1A+@!687)T;W1O
M:F\@=F%R9&%S`%9A<G1O=&]J;R!V87)D87,Z`%9A<G1O=&]J;R!V87)D87,Z
M(`!687)T;W1O:F%I(/!I;VIE('-I<W1E;6]J93H`57IB96MI<W1A;F%S`%9&
M4R!K871A;&]G87,@;F5E9WII<W1U;VIA+@!!=&]S=&]G;W,`4F%S=&]S('1E
M:7-I;F=O<R!V:65T;W;K<SH@`$=A;&EO:FEM87,`4F5I:_!MZR!M:6YU=.MM
M:7,@;G5O(&1A8F%R+@!296EK\&WK<P!296EK\&WK<R!I\"!K=7)I^"!G86QI
M;6$@<&%S:7)I;FMT:0!686YU871U`$MI;G1A;G1I<P!696YE<W5E;&$`4&%T
M=FER=&EN:6UA<R!N96)A:6=T87,@+2#P:7,@;&%I\&MA<R!S=6=A9&EN=&%S
M+@!697)S:6IA`%9E<G-I:O@@:V]N=')O;.L`3'EG:75O=&D@=F5R=&EK86QI
M86D`5F5R=&EK86QU<R!T87)P87,`5F5R=&EK86QU<SH`3&%B86D@9&ED96QI
M<P!6:65T;F%M87,`5FEE=&YA;6EE=&GP:V$@*%9)4T-)22D`4&5R_FG[<NMT
M:2`E<P!2;V1Y=&D@:?!O<FENX2!P=7-L87#A`%!E<OYI^W+K=&D@:V%I<"`E
M<P!"<FET^"!6:7)D_FEN:6IO<R!S86QO<P!*058@5FER9/YI;FEJ;W,@<V%L
M;W,`36%T;VUU;6%S`$UA=&]M=6UA<SH@`%9O9&%F;VYE($ET86QI:F$@<&5R
M(%--5%``5T%23@!$RTU%4TE/(2$A(%!!5%E3($G05%))3DM)5$4@4TM225!4
MP"!)T"`E<RX`5F%L:7,@:7(@1G5T=6YA`$3K;65S:6\`5')EZ"X`3W+X('!R
M;V=N;WKK`$]R^"!P<F]G;F]ZZR!P86=A;`!796%T:&5R+F-O;0!75U<`5U=7
M('!U<VQA<&ES`$MA<R!S879A:73F`%-V96EK:0!3=F5I:VD@871V>6OF(.$@
M)7,`3&%B87,L("5S`%9A:V%R^"`H25-/+3@X-3DM,2D`5F%K87+X("A)4T\M
M.#@U.2TQ-2D`5F%K87+X(%-A8VAA<F$`2V]KX2!M;V1U;.$@)7,@='5R:2!R
M;V1Y=&D@<&\@<')I<VEJ=6YG:6UO/P!+;VMS('-K:7)T=6MO('-I;6)O;&ES
M/P!+;VMS(&MA8G7H:?@@<VEM8F]L:7,_`$MU<FEO<R!F87KK<P!(5$U,(')E
M9&%K=&]R:6%U<R!M;V1U;&GX(.%J=6YG:6UA<RX`4&QO=&ES`%!L;W1I<R!#
M4U,@;6%T86ES`"5S(&MA:7)I;VIO(&UE;FEU('!L;W1I<R`H<&%K96ET:6UA
M:2!B=7,@;6%T>71I('!O(&MI=&\@<')I<VEJ=6YG:6UO*3H`3&5N=&5LZW,@
M<&QO=&ES`%!L;^AI;R!M871A<P!0;&]T:7,Z`%=I:VD`5NMJ;R!G<F5I=&ES
M(&UA>F=A:7,`5NMJ87,Z`%;K:F%S.B``2?!M:6YT:7,`1&%R8F%S`$1A<F)O
M(&%D<F5S87,`1&%R8F\@=&5L969O;F%S`%@M4F5F`%@U,#EV,R!P86=R:6YD
M:6YI86D@;G5S=&%T>6UA:0!8-3`Y=C,@:?!P;.MS=&\@<F%K=&\@<&%N875D
M;VII;6%S`%@U,#EV,R!A;'1E<FYA='EV=7,@=F%R9&%S`%@U,#EV,R!R86MT
M;R!I9&5N=&EF:6MA=&]R:75S`%@U,#EV,R!M;V1U;&EA:0!960!965E9`%EA
M:&]O(2#^96WK;&%P:7,`2V%S;65T`$IE;65N87,`5&%I<`!486EP+"!A\"!S
M=71I;FMU`$K[<R!E<V%T92!414M35$E.24%-12!21=Y)344N($YO<NMD86UI
M(&=RX?YT:2#A(%=94TE764<@<W!A=7-K:71E(%L\/ETN`$K[<R!N97!R:7-I
M:G5N9^8N`%-A=F\@=F%R9&4@;F5G86QI=&4@;F%U9&]T:2!S:6UB;VQI;R`G
M7"<N`,%V963K=&4@;F5T96ES:6YGX"!E;"X@<&'P=&\@861R97/@+@!.97!R
M:6IU;F?K=&4@:F]K:?@@;&%U:_@@:?`@X6ME;&EA;6\@9F%I;&\@<')I92`E
M<R!A=&ET:6YK86WX(&QA=6OX+@!*^W,@871S:6IU;F?K=&4N`%1U<FET92#A
M=F5S=&D@=&5I<VEN9^`@=&5L969O;F\@;G5M97+A("AT:6L@<VMA:>AI=7,@
M:7(@)RLG+"!J96EG=2!N;W)I=&4@;G5R;V1Y=&D@=&%R<'1A=71I;N$@:V]D
MX"DN`,%V963K=&4@;F5T96ES:6YGX"!R96EK\&WF+@!.;W+K9&%M:2!N875G
M;W1I<R!R96=I<W1R86-I:F]S('-I<W1E;6$L('1U<FET92!S=6MO;F9I9_MR
M=6]T:2!D=6]M96[X(&UE9/YI;R!P;W-I<W1E;>8N`%!R:67P('-I^'-D86UI
M('!R86YE\&EMX"P@87!R8?!Y:VET92!P<F]B;&5MX"X`P7)A\'EK:71E(&YU
M;W)O9&]S(%523`!4=7)I=&4@<&%S:7)I;FMT:2!S97)V97+A+"!K=7+A(&YO
M<FET92!I\'1R:6YT:2X`3G5R;V1Y:VET92!V87)T;W1O:F\@=F%R9.`L(&MU
M<FEO(&1U;VUE;FES('1R:6YA=&4N`$YU<F]D>6MI=&4@=F%R=&]T;VIO('9A
M<F3@('1R>6YI;75I+@!.=7)O9'EK:71E(&MU<FEA;6\@=F%R=&]T;VIO('9A
M<F3@+@!.=7)O9'EK:71E(&%T;F%U:FEN86UO('9A<G1O=&]J;R!V87)DX"X`
M3G5R;V1Y:VET92!V96EK<VW@+@!*^W,@='5R:71E(.%V97-T:2!N875J;W,@
M:V%T96=O<FEJ;W,@<&%V861I;FEMX"X`)7,@<V5S:6IA(&)A:6?K<VDN(%!R
M8?!O;64@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@96PN('!A\'1O(&%D
M<F5S87,Z`$5L+B!P8?!T;R!A9')E<V%S.@!);F9O<FUA8VEJ82!A<&EE($IU
M<P!.=6\@)7,@<V5S:6IO<R!P<F%D_FEO<R!J^W/X($E0(&%D<F5S87,@<&%S
M:6ME:73K+B!4=7)I=&4@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@=F%R
M9&%S+W!A=F%R9.L`2OMS^"!A=71E;G1I9FEK879I;6\@<VES=&5M82!N97!A
M;&%I:V\@=F%R=&]T;VKX('/@<F'P;RP@87)B82#P:2!F=6YK8VEJ82!U_F1R
M875S=&$@9.ML('1A;2!T:6MR^"!P<FEE_F%SZ&GX+@!.=6\@)7,@<V5S:6IO
M<R!P<F%D_FEO<R!J^W/X(&YA<O!Y:VSK<R!T:7!A<R!P87-I:V5I=.LN(%1U
M<FET92!P<FES:6IU;F=T:2!I\"!N875J;RX`2OMS^"!N87+P>6MLZR!N97!A
M;&%I:V\@\&EO<R!G86QI;7EBZW,N`$K[<_@@;&%I:V\@:G5O<W1A.@!*^W/X
M('-T86YD87)T:6YI<R!A<')A\&%S.@!*^W/X('9A<F1A<R]P879A<F3K.@!*
M^W/X(&YA=6IA<R`E<R!S;&%P=&'^;V1I<R!Y<F$Z("5S`$K[<_@@;G5S=&%T
M>6UA:2!A=&YA=6II;G1I+@!*^W/X('-L87!T8?YO9&ES('!A:V5I<W1A<P!*
M^W/X('-L87!T8?YO9&ES('!A:V5I<W1A<RX@4&%S:71I:W)I;FMI=&4@<V%V
M;R!P8?!TX"!I<B!P<FES:6IU;FMI=&4@<W4@;F%U:G4@<VQA<'1A_F]D_FEU
M+@!*^W/X(&YU=&]LYB!S97)V97)I86DZ`$IU9V]S;&%V:6IA`%IA:7)A<P!:
M86UB:6IA`%II;6)A8G;K`$5N97)G:6YG;W,`6U!A<VSK<'1I(&-I='5O:F%M
MX"!T96MS=.!=`%M0<F]B;&5M;W,@<')A;F7P:6UA<UT`6U)O9'ET:2!C:71U
M;VIA;>`@=&5K<W3@("T`6U)O9'ET:2!C:71U;VIA;>`@=&5K<W3@("T@)7,@
M96EL=71E<UT`6V5I;'5TZR`E<R!I\"`E<UT`7U9A;&1Y;6%S`%]#3$D`7T1U
M;VUE;O@@;65D:7,`7TGP=')I;G1I(&5I;'5TY@!'7W)U<.MS`%!A7V=A;&)A
M`%]0879E:6MS;.ML:6\@;G5S=&%T>6UA:2XN+@!0<FES:5]J=6YG=&D`071S
M:5]J=6YG=&D`7TME:7-T:2!N=6]R;V3@+BX`7TYU<W1A='EM86D`7U1E:7/K
M<P!?2?!T<FEN=&D@;G5O<F]DX"XN+@!?2V]N9FEG^W)A8VEJ80!?3&5N=&5L
MZW,@;G5S=&%T>6UA:2XN+@!67V%R=&]T;VIA:0!A9')E<_@@:VYY9V5LZP!+
M86QE;F1O<FEU<P!R86UU<P!S<&%U<VMI=&4@Z&EA`&MR96YT80!F86EL87,`
M;G5O("5S("@E<RD@)7,@)7,`83H`='5O:F%U('!A=`!P87!R87-T:0!E:6QU
M=&5S70!M:VES;V9S(&ML86ED;W,@:V]D87,@)60@8F5D87)A;G0@25-/+@!V
M87)D87,`;F5R96%L:7IU;W1A`&1A<B!N97)E86QI>G5O=&$`=?YR8?#X(&MN
M>6=E;.L`<')O8V5N=&%I`'!I:W-E;&EA:0!K>6QA`')O9'ET:2!S:VER='5M
M=7,`<VUS,F5M86EL('!E<B!(5%10`'-T86)I;&D`9&%R8O@@<^!R8?!A<P!S
M;&%P=&'^;V3A('1U<FET92#A<F'P>71I(&1U(&MA<G1U<P!U;FEF:6MU;W1I
M`&1A;&ES`'9A<G1O=&]J;R!P87-I<FEN:VEM87,`=D-A<F0`<#H`=V5A=&AE
M<BYC;VT`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]L=%],5"]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`U
M,34T,S$P-C(`,#(P,S,S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D
M93H@:&]R9&4O;&]C86QE+VQT7TQ4+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O
M,C<@,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60]
M(G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E
M/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@
M82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R
M;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N
M97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@
M=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO
M=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S
M('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R
M:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U
M;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A
M9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T
M8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O
M<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T
M=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M
M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S
M(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE
M/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R
M83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES
M('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T
M:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N
M9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI
M8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F
M97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*
M("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O
M>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO
M=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O
M;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R
M=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL
M(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O
M(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;6M?34LO````````````````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q
M,#8R`#`Q-C8T-@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]M:U]-
M2R],0U]-15-304=%4R\`````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-C(`,#(P-#,S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+VUK7TU++TQ#7TU%4U-!1T53+VAO<F1E+FUO````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C8Q,``Q,#4Q-30S,3`V,@`P,C(P-C8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````!8````'````-P"``!_````G`4```````"8!P``*````)D'```(````
MP@<```4```#+!P``#P```-$'```(````X0<```@```#J!P``&0```/,'```'
M````#0@```X````5"```!0```"0(```1````*@@```@````\"```%0```$4(
M```*````6P@```P```!F"```!P```',(```0````>P@``"D```","````@``
M`+8(```%````N0@``!````"_"```!@```-`(```4````UP@``"8```#L"```
M!0```!,)```-````&0D```4````G"0``"P```"T)```/````.0D``"$```!)
M"0```P```&L)```$````;PD```P```!T"0``"@```($)```%````C`D``!(`
M``"2"0``$````*4)```0````M@D``!H```#'"0``!@```.()```'````Z0D`
M``(```#Q"0``!````/0)```/````^0D```<````)"@``!P```!$*```$````
M&0H```4````>"@``"````"0*```5````+0H``!X```!#"@``!0```&(*```H
M````:`H``"D```"1"@``$P```+L*```+````SPH```4```#;"@``$0```.$*
M```$````\PH```P```#X"@``&@````4+```7````(`L``!<````X"P``&P``
M`%`+```3````;`L``!````"`"P``%P```)$+```'````J0L```4```"Q"P``
M`P```+<+```@````NPL``"8```#<"P``#`````,,```(````$`P``!0````9
M#```!P```"X,```&````-@P```L````]#```#````$D,```*````5@P```(`
M``!A#```!@```&0,``!%````:PP``"8```"Q#```)0```-@,``!S````_@P`
M`!````!R#0``<0$``(,-```B````]0X```<````8#P``!0```"`/```4````
M)@\```H````[#P``#P```$8/```G````5@\```8```!^#P``#@```(4/```%
M````E`\``!````":#P``"````*L/```5````M`\```<```#*#P``%0```-(/
M```%````Z`\```\```#N#P``.P```/X/```"````.A````8````]$```%```
M`$00```'````61```!$```!A$```*@```',0```'````GA```!````"F$```
M!@```+<0```1````OA````<```#0$```)0```-@0```$````_A````4````#
M$0``#P````D1```/````&1$```4````I$0``%````"\1```3````1!$``!8`
M``!8$0``)@```&\1```(````EA$```4```"?$0```@```*41```%````J!$`
M`!8```"N$0``!@```,41```'````S!$```,```#4$0``"0```-@1```'````
MXA$``!T```#J$0``'`````@2```'````)1(``"`````M$@``,````$X2```1
M````?Q(```P```"1$@``!0```)X2```1````I!(```4```"V$@``#0```+P2
M```<````RA(``!D```#G$@``&0````$3```>````&Q,``!L````Z$P``$P``
M`%83```=````:A,```<```"($P``!@```)`3```#````EQ,``"H```";$P``
M*P```,83```3````\A,```X````&%```%@```!44```(````+!0```<````U
M%```#@```#T4```0````3!0``!$```!=%````@```&\4```'````<A0``#``
M``!Z%```*P```*L4```I````UQ0``&X````!%0``%P```'`5```!````+```
M`"H`````````5@````L`````````&```````````````1````"@`````````
M%```````````````-0````4```!*`````@````,````[````2````!(`````
M````40```#X````S````(0```#(```!,````&@`````````O````(```````
M````````5P```!8````K````$P````````!&````'P````8````Y````````
M````````````"@```$(````G```````````````D````#P````P```!-````
M1P```#8`````````.@```"D```!+````!P```",```````````````````!3
M````0````!X````T````'``````````=`````````"(````1````````````
M```_```````````````7````0P```%0```!/````)0```!4````P````3@``
M```````.````/````!````!8``````````````!%``````````T`````````
M&P````D````(`````````%`````9`````````"8````$````,0```#@````]
M````50```%(````M``````````````!)````00```#<`````````+@``````
M`````````"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VX`,C0@:&]U<G,`04TO4$T`061D(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D
M9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&UI
M;FES=')A=&EO;@!!;&EA<P!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#
M86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`
M0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I
M='D`1&5L971E`$1E<V-R:6)E('1H92!0<F]B;&5M`$1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`
M17)R;W(`179E<GD@3&]G:6X`17AA;7!L92!V86QU97,Z`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`2&5L<`!(;VUE($%D9')E<W,`
M2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S
M`$UE<W-A9V4`36]N=&AL>0!.86UE`$YO=&5S`%!A<W-W;W)D`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER`%)E<V5T`%)E='5R;B!T
M;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396YD
M(%!R;V)L96T@4F5P;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W5C8V5S<P!4:71L90!54DP`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S97)N86UE`%5S97)S(&EN('1H
M92!S>7-T96TZ`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64L("5S`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%M0<F]B;&5M(%)E<&]R=%T`4')O:F5C="U)
M9"U697)S:6]N.B!M:U]-2PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q
M-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#8M,C8@,34Z,3@K
M,#(P,`I,87-T+51R86YS;&%T;W(Z(%-T;VIA;B!097-O=B`\<W-P0&5U<F5K
M82YC;VTN;6L^"DQA;F=U86=E+51E86TZ($UA8V5D;VYI86X@/&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM-0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N97)A=&]R.B!+0F%B96P@,2XP+C$*
M`"5S(+[?U>#0YMC8(-?0(-[4X-;CTM#ZU2`M(+_>XM+@U-``,C0@Y]#AT`!!
M32]030"TWM30U-@@W=[2(-K>X-CAW=C:.@"TWM30U-@@W]#@`+3>U-#4V"#:
MWN#8X=W8V@"TWM30TM#ZU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=
MWBX`L-3@U>'0`+#4W-C=V.'BX-#FV/C0`$%L:6%S`+3>X>+0W]W8(-_>V]CZ
MT#H`P-[4U=W4U=T`ON+:T-;8(+_@WM';U=P@P-7?WN#B`+S>T=C;U=T`M]#B
MTM[@V"#3WB#?X-[7WN#5YM[B`,38X-S0`+_>XM+@U-@@V][7V-W:T`"\WM3C
MV][B(-W0(-?0U-#GT.+0(-?0(-[4X-;CTM#ZU2`E<R#=U2#<WM;5(-30(-'8
MU-4@WN+2WN#5W0!$1`"TW=72W=X`P>+0W=30X-35W2#8U-7=XMCBU>(`N-?1
MX-CHV`"^W]CA(-W0(-_@WM';U=S>X@"]U2#?X-CAXM#?X]+0^"#4V.#5VN+=
MWB#4WB!M86EN=&5N86YC92YP:'``U2W?WNCBT`"_X-#7U=T@X-77X]OBT.(N
M`+/@U>C:T`#!U=K>U2#?X-CXT-+CTM#ZU0"_X-C<U>`Z`+W5X^'?U>C=T"#:
MWMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBX`Q-#:X0"_WMS>Z`"TWMS0Z-W0
M(-#4X-7AT#H`M-[<T.C5W2#BU=O5Y-[=`$AO<F1E`+C<W][@XMC@T-W>(-_>
MV]4Z("5S`+C<W][@XMC@T-W8(-_>V]CZT#H`N-?;V.'BT/@@XM7<V"#7T"#?
MWMS>Z`"[V.'BT/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>+@"[
MWM/8X-#ZU0"XU]O5UP!-30"_WNCBT`"ZWN#5X=_>W=38X-#GVM@@W][;V/K0
M`+_>X-#:T`"\U>'5Y]W>`+C<U0"WT-'5V]7HVM@`N][7V-W:T`"[WM?8W=K8
MXM4@W-[@T"#4T"#1V-30XB#8X>+8+@"XU]+@Z-@@WM_5X-#FV-@@U]`@WM3@
MUN/2T/K5`,+5V]7DWMT`LM4@W-[;V-S5(-W0TM74U>+5(-/>(-_@WM';U=S>
MXBX`LM4@W-[;V-S5(-W0TM74U>+5(-+0Z-4@VM[@V.'=V.?:WB#8W-4@V"#;
MWM?8W=K0`+[?V.$@W=`@W^#>T=O5W-[B`+[4X>+@T-W8(-_0X`!297-E=`"]
MT-?0U"#:WMT@WM_FV-CBU0##V][3T`"WT.?CTM#X(-[?YMC8`+C7T=7@V"#A
MU=_0X-#BWN`@U]`@U-#BX]S>XCH`N-?1U>#8(.3>X-S0XB#7T"#4T.+CW-[B
M.@"XU]'5X-@@Y-[@W-#B(-?0(-+@U=S5XMXZ`+C7T=7@V"#4TM4@WM33WM+0
MX-#GVM@@W][;V/K0+@"_X-#BV"#8U]+5Z.+0^"#7T"#?X-[1V]7<WN(`O^#5
MX=K>VMW8(-[4X-;CTM#ZU0"RW=7AX]+0^M4@W=`@X=_5YMCXT-O=V"#7W=#F
MV`##X=_5Z-W>`+W0X=O>T@!54DP`O=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0
MW"#AWB!344P@X=7@TM7@WN(N`+W5(-S>UM72(-30(-/>(-_@U=+5U-#<(-[2
MWO@@5V]R9"#4WMKCW-7=XBX`ON+:T-;8(-/8(-_@WMS5W=CBU0"ZWN#8X=W8
MY]K>(-C<U0"ZWN#8X=W8YM@@TMX@X=CAXM7<WN(Z`++=V-S0W=C5`+W5U-7;
MW=X`M-[1X-74WOC4U2P@)7,`L-3@U>'0(-W0(.#0T=[BT`#"U=O5Y-[=(-W0
M(.#0T=[BT`"SLP"SWM38Z-W>`+[?V.C5XM4@T]X@W^#>T=O5W-[B(-_@U=0@
MU-`@V.'?X-#BU>+5(-C7TM7HXM#X+@"]T-+5U-7BU2#:WM4@VM[@V.'=V.?:
MWB#8W-4@U-`@X=4@WN+AXN#0W=@N`+W0TM74U>+5(-K>U2#:WN#8X=W8Y]K>
M(-C<U2#4T"#AU2#4WM30U-4N`++0Z-C>XB#0TN+>X-C7T.;8WMW5W2#?X-[B
MWMK>VR#=U2#?WM3@UN/2T"#;V.'BT/K5(-K>X-CAW=CFV"P@V-O8(.+0T"#<
MWM;=WN'B(-4@WMW5TM[7W-[6U=W0(-[4(-3@X]/8(-_@V.?8W=@N`%NXU]+5
MZ.+0^"#7T"#?X-[1V]7<WN)=````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VQV7TQ6+P``
M````````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,3`V,@`P,38V-S(`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O;'9?3%8O3$-?34534T%'15,O````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R`#`R,#0U-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]L=E],5B],0U]-15-304=%4R]H
M;W)D92YM;P``````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,U-S$`,3`U,34T
M,S$P-C(`,#(R,3(Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````9````!P````\`P``B0```%P&````````@`@`
M`"@```"!"```"````*H(```%````LP@```@```"Y"```!P```,((```%````
MR@@``!\```#0"```$0```/`(```(`````@D```@````+"0``%0```!0)```*
M````*@D```P````U"0``!P```$()```I````2@D```(```!T"0``!0```'<)
M```0````?0D``!0```"."0``+P```*,)```/````TPD``"8```#C"0``!0``
M``H*```-````$`H```4````>"@``$````"0*```0````-0H```\```!&"@``
M"P```%8*```/````8@H```P```!R"@``#P```'\*```>````CPH``"$```"N
M"@```P```-`*```$````U`H```P```#9"@``"@```.8*```%````\0H``!(`
M``#W"@``$`````H+```(````&PL``!`````D"P``!@```#4+```'````/`L`
M``(```!$"P``!````$<+```/````3`L```<```!<"P``!P```&0+```$````
M;`L```4```!Q"P``!0```'<+```'````?0L``!$```"%"P``"````)<+```>
M````H`L```4```"_"P``*````,4+```I````[@L``!,````8#```"P```"P,
M```1````.`P```0```!*#```#````$\,```:````7`P``!<```!W#```%P``
M`(\,```;````IPP``!\```###```$P```.,,```0````]PP``!<````(#0``
M!P```"`-```%````*`T``"$````N#0``'````%`-```%````;0T```,```!S
M#0``(````'<-```F````F`T```P```"_#0``#````,P-```(````V0T```<`
M``#B#0``!@```.H-```-````\0T```L```#_#0``#`````L.```*````&`X`
M``(````C#@``!@```"8.``!%````+0X``#````!S#@``$````*0.```?````
MM0X``!````#5#@``#P```.8.```%````]@X``%<!``#\#@``*@```%00```*
M````?Q````4```"*$```#@```)`0```&````GQ````P```"F$```&0```+,0
M```0````S1````\```#>$```"0```.X0```;````^!```!$````4$0``#```
M`"81```(````,Q$``"L````\$0```@```&@1```(````:Q$``!(```!T$0``
M$P```(<1```O````FQ$``!(```#+$0``(@```-X1```'`````1(``!`````)
M$@``!0```!H2```1````(!(``!(````R$@``$````$42```8````5A(```\`
M``!O$@``#````'\2```.````C!(``!X```";$@``)````+H2```%````WQ(`
M``D```#E$@``#````.\2```.````_!(```4````+$P``%````!$3```0````
M)A,```8````W$P``&@```#X3```+````61,```4```!E$P```@```&L3```%
M````;A,``!````!T$P``!````(43```,````BA,```4```"7$P``!0```)T3
M```(````HQ,```<```"L$P``$````+03```&````Q1,``!\```#,$P``"```
M`.P3```C````]1,``"T````9%```$@```$<4```,````6A0``!<```!G%```
M!````'\4```0````A!0``!X```"5%```&P```+04```:````T!0``",```#K
M%```$P````\5```<````(Q4``!(```!`%0``%````%,5```'````:!4```@`
M``!P%0``'P```'D5```?````F14```H```"Y%0```P```,05```G````R!4`
M`"L```#P%0``#P```!P6```1````+!8```\````^%@``"P```$X6```,````
M6A8``!````!G%@``$````'@6```,````B18```X```"6%@```@```*46```*
M````J!8``"\```"S%@``/````.,6```0````(!<``!L````Q%P``%````$T7
M```0````8A<```4```!S%P```0```"0`````````3@```!T```!/````%P``
M`$4````'````(@````````!-````(0````````!+````8@````H````1````
M``````P````R````4P```#$`````````)0```$8```!=`````````%(```!"
M````50````````!'````+````"\```!6````40```#4````0````"````#X`
M``!!````7P```"L````/````.0```$H````C````&````#,```!`````*```
M`&`````+``````````````!4```````````````]````"0`````````N````
M2````%P````Z``````````X`````````60`````````V`````````!L````_
M````'````!H````-````.P`````````$````!0`````````2`````````!,`
M````````5P```"T`````````)@``````````````%0````8`````````6P``
M`#<````9`````````%X`````````.````#0`````````20```!\```!:````
M1``````````>``````````````!C`````````%@````I`````````#``````
M`````````#P```!D````4``````````6````(``````````#````80```$,`
M```J````)P```$P````"`````````!0`````)7,@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`R-"!H;W5R<P!!32]030!!9&0@<&%I
M<@!!9&1R97-S`$%L:6%S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`079A:6QA8FQE(&9I96QD<SH`0FER=&AD87D`0V%L96YD87(`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A
M;GD`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`
M1$0`1&%I;'D`1&5F875L="!)9&5N=&ET>0!$97-C<FEB92!T:&4@4')O8FQE
M;0!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$:7-P;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S
M`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA
M;7!L92!V86QU97,Z`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M
M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,
M;V<@:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-97-S86=E
M`$UO;G1H;'D`3F%M90!.979E<@!.;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R
M;6%T:6]N`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T=7)N('1O($]P
M=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!D871E(&1E;&EM
M:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE
M(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3
M:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E
M<W,`5&%S:W,`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`55),`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($]P=&EO;G,`
M57-E<FYA;64`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E
M9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;
M;&EN92`E<R!O9B`E<UT`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D
M92`R+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3(X(#$T.C`P*S`R,#`*3&%S="U4
M<F%N<VQA=&]R.B!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^
M"DQA;F=U86=E+51E86TZ($QA='9I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]0U`Q,C4W"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M
M8FET"@`E<R!5>G1U<N?P86YA<R!O<&5RXF-I:F%S("T@87!S=&EP<FENXFIU
M;7,`,C0@<W1U;F1A<P!!32]030!0:65V:65N;W0@<.)R:0!!9')E<V4`06EZ
M<W3B:G;B<F1S`$YO<N)D[G1A(&YE9&5R[F=A(';G<G3N8F$`4&EE96IA;6EE
M(&QA=6MI.@!$>FEM\&%N87,@9&EE;F$`2V%L96YDXG)S`$%T8V5L="!P<F]B
M;.=M87,@<&EE=&5I:W5M=0!-;V)I;&%I<R!TXFQR=6YI<P!!:7IVYW)T(&QO
M9W4`57KRYVUU;7,`3F5I>F1E=N)S(&%T=N=R="!-86EN=&5N86YC95]487-K
M(&UO9'5L:2`E<P!$1`!):V1I96YA<P!087)A<W3B(&ED96YT:73B=&4`07!R
M86MS=&EE="!P<F]B;.=M=0!3[FOB:V$@:6YF;W)MXF-I:F$@:7(@;F]S^W3N
M=&$@861M:6YI<W1R871O<F%M+@!%:W+B;F$@:65S=&%T[FIU;6D`3F%V('1I
M9?!A<R!P:65E:F%S(&UA:6YT96YA;F-E+G!H<`!%+7!A<W1S`%1U:_!S(')E
M>G5L=.)T<RX`2^_[9&$`2V%T<F%S(#$U(&UI;OMT97,`2V%T<F%S(#,P('-E
M:W5N9&5S`$MA=')A<R`U(&UI;OMT97,`2V%T<N(@<&EE<VSG9_!A;N)S(')E
M:7KG`$MA=')U('!U<W-T=6YD=0!+871R=2!M:6[[=&D`4&%R875G=N=R=.YB
M87,`3F5I>F1E=N)S('-A\F5M="!I97-T873N:G5M=7,N`$YE:7ID97;B<R!P
M:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+@!&86MS<P!086SN9'KN8F$`3>)J
M87,@861R97-E`$WB:F%S('1E;&5F;VYS`$AO<F1E`$EE;.)DYW1A:7,@;&%U
M:W,Z("5S`$EE;.)DYW1I92!L875K:3H`5F%L;V1A`%!A<N)D[G0@<&%L[F1Z
M[F)A<R!T96UA='5S`%!I97-LYV=T:65S`$EZ:65T`$U-`%!A<W1S`%-A<VMA
M;F_P:64@;&%U:VD`6FGR80!+871R=2!MYVYE<VD`5N)R9',`3F5K860`4&EE
M>NYM97,`3W!C:6IA<P!#:71A(&EN9F]R;>)C:6IA`%!A<F]L90!)>G!I;&3N
M="!U>G1U<N?P86YA<R!O<&5RXF-I:F%S`%3B;')U;FES`$S[9'IU(&YO<N)D
M:65T('!R;V)LYVUA<R!A;F]TXF-I:G4N`$S[9'IU(&YO<N)D:65T('-A=G4@
M;&EE=&]TXFIA(';B<F1U('5N('!A<F]L:0!0<F]B;.=M87,@87!R86MS=',`
M27ID>N=S="!PXG)I`$%T9W)I97IT:65S('!I92!O<&-I:N)M`$QO;6$`4V%G
M;&%BXG0@;W!C:6IA<P!)>G;G;&EE=&EE<R!D871U;6$@871D86SN=.)J=3H`
M27IVYVQI971I97,@9&%T=6UA(&9O<FWB='4Z`$EZ=N=L:65T:65S(&QA:6MA
M(&9O<FWB='4Z`$EZ=N=L:65T:65S(&1I=G5S('-A9&5R[F=U<R!L875K=7,N
M`$EZ=N=L:65T:65S('9A;&]D=3H`3F]S^W3N="!P<F]B;.=M87,@<&EE=&5I
M:W5M=0!)>FQA:7-T('5Z='5RY_!A;G4`SG!A\&\@<VEM8F]L=2!I979A9&4`
M5F5I:W-M90!5>F1E=G5M:0#0:6T@<VMA:71L:6T@:7(@:N)B^W0@=FES;6%Z
M(#$N`-!A:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2X`5FER<W)A:W-T
M<P!54DP`3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN
M`$YA=B!I97-PYVIA;7,@:6YT97)P<F5TYW0@\&\@5V]R9"!D;VMU;65N='4`
M071C96QT(&EZ;6%I\F%S`$QI971O=.)J82!O<&-I:F%S`$QI971O=.)J82!V
MXG)D<P!"<NYD:6[B:G5M<P!+871R=2!N963G[W4`3&%I<&YI(&S[9'IA;2`E
M<P!,86EP;FD@;/MD>FTL("5S`$1A<F)A(&%D<F5S90!$87)B82!TXFQR=6YI
M<P!'1P!+871R=2!G861U`$%P<F%K<W1I970@<')O8FSG;74@<&ER;7,@<&EE
M=&5I:W5M82!S^W3N\&%N87,N`$K[<W4@)7,@<V5S:6IA(&ER(&)E:6=U<VEE
M<RX@3/MD>G4@<&EE<VSG9'II971I97,@871KXG)T;W1I+@!*^W-U(&EN9F]R
M;>)C:6IA`$K[<W4@;W!C:6IA<R!I<B!S86=L86+B=&%S+@!;4')O8FSG;6%S
M('II\F]J=6US70!;<FEN9&$@)7,@;F\@)7-=`'9#87)D````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+VYB7TY/+P``````````````````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V
M,@`P,38V-#,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;F)?3D\O
M3$-?34534T%'15,O````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#8R`#`R,#0S,``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]N8E].3R],0U]-15-304=%4R]H;W)D92YM;P``````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`Q-C$P-#,`,3`U,34T,S$P-C(`,#(R,#<P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-X2!)4`
M````40,``!P```"D&@``?P0``"PU````````*$<``$@````I1P``#@```')'
M```/````@4<```T```"11P``"````)]'```+````J$<```P```"T1P``!```
M`,%'```,````QD<``!$```#31P``)0```.5'```/````"T@```L````;2```
M$0```"=(```.````.4@```4```!(2```*````$Y(```(````=T@```H```"`
M2```%0```(M(```2````H4@```L```"T2```%````,!(```F````U4@``"<`
M``#\2```)@```"1)```3````2TD```X```!?20``"@```&Y)```-````>4D`
M`"<```"'20``(````*])```.````T$D``!<```#?20``(@```/=)```U````
M&DH``!$```!02@``#0```&)*```,````<$H```T```!]2@``!@```(M*```;
M````DDH``"T```"N2@``)````-Q*```I`````4L``!D````K2P``&````$5+
M```,````7DL```X```!K2P``#@```'I+```(````B4L``"X```"22P``&@``
M`,%+```R````W$L``#@````/3```5````$A,``!1````G4P``%H```#O3```
M5P```$I-```T````HDT```4```#730``$0```-U-```(````[TT```D```#X
M30``"0````).```.````#$X```@````;3@``)0```"1.```@````2DX``!``
M``!K3@``#P```'Q.```*````C$X```<```"73@```P```)].```/````HTX`
M`!0```"S3@``"0```,A.```-````TDX``!(```#@3@``&0```/-.```>````
M#4\```\````L3P``"@```#Q/```/````1T\```@```!73P``)````&!/```7
M````A4\``!0```"=3P``%@```+)/```(````R4\``$X```#23P``+0```"%0
M```?````3U```!D```!O4```!P```(E0```,````D5```"P```">4```#@``
M`,M0```#````VE````4```#>4```!0```.10```*````ZE````,```#U4```
M%P```/E0```*````$5$```\````<40``#@```"Q1```8````.U$``",```!4
M40``#@```'A1```4````AU$``!<```"<40``%P```+11```7````S%$``!,`
M``#D40``#P```/A1```?````"%(```\````H4@``!@```#A2```+````/U(`
M`!````!+4@``%0```%Q2```5````<E(```<```"(4@``$````)!2```1````
MH5(```P```"S4@``.P```,!2```X````_%(```,````U4P``"0```#E3```Y
M````0U,``!(```!]4P``.0```)!3```G````RE,``"P```#R4P``*@```!]4
M```E````2E0```D```!P5```"@```'I4```'````A50``"\```"-5```-P``
M`+U4```N````]50``%4````D50``+0```'I5```M````J%4``"T```#650``
M0`````16```C````158``",```!I5@``+0```(U6```S````NU8``!4```#O
M5@``&0````57```I````'U<``"0```!)5P``$0```&Y7```1````@%<```P`
M``"25P``"@```)]7```0````JE<``!8```"[5P``%@```-)7```$````Z5<`
M`"<```#N5P``"````!98```'````'U@```@````G6```*0```#!8```.````
M6E@```H```!I6```!````'18```)````>5@```8```"#6```$0```(I8```'
M````G%@```0```"D6```!@```*E8```-````L%@```,```"^6````P```,)8
M```7````QE@``!,```#>6```"````/)8```$````^U@``$$`````60``(```
M`$)9```&````8UD```8```!J60``%0```'%9```8````AUD``"(```"@60``
M+@```,-9```=````\ED``"$````06@``5````#):```I````AUH```<```"Q
M6@``%0```+E:```*````SUH```\```#:6@``#0```.I:```/````^%H```T`
M```(6P``"0```!9;```&````(%L``!,````G6P``%````#M;```,````4%L`
M``8```!=6P``5````&1;```$````N5L```X```"^6P``1````,U;```1````
M$EP``!$````D7```$0```#9<```<````2%P``"H```!E7```(0```)!<```%
M````LEP``!,```"X7```$@```,Q<```*````WUP```\```#J7```$0```/I<
M```3````#%T```P````@70``!@```"U=```&````-%T``!`````[70``$0``
M`$Q=```%````7ET```P```!D70``$````'%=```-````@ET```8```"070``
M!P```)==```-````GUT``!````"M70``"0```+Y=```'````R%T```L```#0
M70``"P```-Q=```'````Z%T```D```#P70``%````/I=```)````#UX```H`
M```97@``&0```"1>```=````/EX```P```!<7@``$````&E>```2````>EX`
M`!,```"-7@``*P```*%>```[````S5X``"`````)7P``-@```"I?```0````
M85\```@```!R7P``!@```'M?```$````@E\```X```"'7P``$````)9?```>
M````IU\``!L```#&7P``(0```.)?```>````!&```!D````C8```'@```#U@
M```;````7&```"X```!X8```%P```*=@```F````OV```#````#F8```&P``
M`!=A```>````,V$``!P```!280``)@```&]A```K````EF$``#,```#"80``
M)@```/9A```K````'6(``#@```!)8@``'0```()B```5````H&(``"\```"V
M8@``$@```.9B```@````^6(``"D````:8P``'@```$1C```2````8V,``*(`
M``!V8P``%@```!ED```C````,&0``"@```!49```*0```'UD```H````IV0`
M`!\```#09```%0```/!D```@````!F4``"4````G90``*````$UE```M````
M=F4``#````"D90``D@```-5E```A````:&8``!8```"*9@``'````*%F```F
M````OF8``"H```#E9@``00```!!G``!$````4F<```P```"79P``!P```*1G
M```'````K&<```8```"T9P``#0```+MG```0````R6<``!(```#:9P``$P``
M`.UG```2`````6@```T````4:```#````")H```/````+V@``!,````_:```
M#0```%-H```H````86@```,```"*:```#0```(YH```&````G&@```(```"C
M:```!0```*9H```$````K&@``!````"Q:```!````,)H```-````QV@```X`
M``#5:````P```.1H```.````Z&@```@```#W:```#P````!I```(````$&D`
M``\````9:0``!P```"EI```-````,6D``!`````_:0``$P```%!I```3````
M9&D```L```!X:0``$0```(1I```)````EFD```8```"@:0``#````*=I```1
M````M&D``!D```#&:0``"P```.!I```-````[&D``"(```#Z:0``&P```!UJ
M```T````.6H```H```!N:@``&````'EJ```9````DFH``!8```"L:@``+P``
M`,-J```B````\VH```T````6:P``!P```"1K```,````+&L``"8````Y:P``
M%````&!K```+````=6L``"(```"!:P``+P```*1K```+````U&L```D```#@
M:P``&0```.IK```+````!&P``!<````0;```%P```"AL```)````0&P``!8`
M``!*;```#P```&%L```6````<6P```X```"(;```&````)=L```-````L&P`
M`"8```"^;```0P```.5L```(````*6T``"\````R;0``#@```&)M```%````
M<6T```8```!W;0```P```'YM```$````@FT```H```"';0``"@```))M```/
M````G6T``!````"M;0``%P```+YM```1````UFT``!<```#H;0``&0````!N
M```)````&FX```H````D;@```@```"]N```%````,FX```T````X;@``&P``
M`$9N```7````8FX```D```!Z;@``#@```(1N```-````DVX``!(```"A;@``
M.````+1N```@````[6X```,````.;P``"````!)O```.````&V\``'L````J
M;P``&````*9O```%````OV\``!@```#%;P``&0```-YO```3````^&\```<`
M```,<```!@```!1P```0````&W````\````L<```$````#QP```/````37``
M``L```!=<```#P```&EP```,````>7````\```"&<```!P```)9P```*````
MGG````8```"I<```#@```+!P```,````OW```"@```#,<```#P```/5P```(
M````!7$```@````.<0``$P```!=Q```>````*W$``"$```!*<0``(````&QQ
M```9````C7$``!<```"G<0``)0```+]Q```7````Y7$```0```#]<0``#```
M``)R```#````#W(```@````3<@``"@```!QR```,````)W(```L````T<@``
M$````$!R```,````47(``!,```!><@``%````')R```,````AW(```D```"4
M<@``#@```)YR```+````K7(``!L```"Y<@``!P```-5R```*````W7(```T`
M``#H<@``"0```/9R```$`````',```4````%<P```P````MS```8````#W,`
M``H````H<P``!````#-S```F````.',```X```!?<P``?````&YS```5````
MZW,```4````!=```!P````=T```,````#W0```@````<=```"@```"5T```&
M````,'0```@````W=```%@```$!T```2````5W0```(```!J=```!@```&UT
M```5````='0```\```"*=```$0```)IT```:````K'0```0```#'=```"0``
M`,QT```0````UG0```D```#G=```"0```/%T```:````^W0```@````6=0``
M&0```!]U```.````.74```X```!(=0``"@```%=U```"````8G4```T```!E
M=0``"0```'-U```&````?74```D```"$=0``%````(YU```=````HW4``!$`
M``#!=0``!@```--U```1````VG4``!$```#L=0``"0```/YU```"````"'8`
M``0````+=@``.0```!!V```]````2G8``#H```"(=@``'@```,-V```.````
MXG8```0```#Q=@``!@```/9V```&````_78```0````$=P``$0````EW```&
M````&W<```H````B=P``(@```"UW```$````4'<``"4```!5=P``!0```'MW
M```$````@7<```P```"&=P``"@```)-W```%````GG<``#H```"D=P``,```
M`-]W```U````$'@``"D```!&>```+@```'!X``!'````GW@``#@```#G>```
M*0```"!Y```_````2GD``"X```"*>0``+0```+EY```?````YWD```\````'
M>@``$@```!=Z```+````*GH``"8````V>@``*0```%UZ```D````AWH``"8`
M``"L>@``"````--Z```*````W'H```D```#G>@``(````/%Z```@````$GL`
M`"8````S>P``"@```%I[```9````97L``"D```!_>P``%@```*E[```2````
MP'L```H```#3>P``#````-Y[```/````ZWL``!````#[>P``0`````Q\``!P
M````37P``&8```"^?```#@```"5]```)````-'T```H````^?0``$@```$E]
M```3````7'T```P```!P?0``!@```'U]```/````A'T``!(```"4?0``$```
M`*=]```*````N'T``!$```##?0``'````-5]```C````\GT``&H````6?@``
M#P```(%^```0````D7X```0```"B?@``"P```*=^```4````LWX```P```#(
M?@``#````-5^```/````XGX``!4```#R?@``*0````A_```J````,G\``"8`
M``!=?P``)P```(1_```I````K'\``"H```#6?P``&0````&```!"````&X``
M`!$```!>@```$@```'"````3````@X```!0```"7@```#P```*R````6````
MO(```!<```#3@```$````.N````1````_(```#0````.@0``$P```$.!```2
M````5X$``#4```!J@0``%````*"!```'````M8$``"L```"]@0``(````.F!
M```4````"H(``!$````?@@``%P```#&"```<````28(``!,```!F@@``$0``
M`'J"```:````C((``!X```"G@@``&@```,:"```1````X8(``!<```#S@@``
M%`````N#```7````((,``!4````X@P``"0```$Z#```1````6(,```8```!J
M@P``!@```'&#```'````>(,```0```"`@P``!````(6#```'````BH,```X`
M``"2@P``#@```*&#```H````L(,```X```#9@P``#````.B#```/````]8,`
M``H````%A```"````!"$```)````&80``"L````CA```!````$^$```'````
M5(0```@```!<A```"0```&6$```,````;X0```T```!\A```#@```(J$```6
M````F80``!$```"PA````P```,*$```&````QH0``!D```#-A```!````.>$
M```+````[(0```L```#XA```#0````2%```*````$H4``!`````=A0``#P``
M`"Z%```1````/H4``!<```!0A0``"@```&B%```1````<X4```@```"%A0``
M!````(Z%```/````DX4``#H```"CA0``!0```-Z%```,````Y(4``!X```#Q
MA0``#@```!"&```0````'X8```L````PA@``#````#R&```)````288```<`
M``!3A@``"@```%N&```)````9H8```X```!PA@``$````'^&```:````D(8`
M``H```"KA@``%````+:&```*````RX8```P```#6A@``#P```..&```(````
M\X8```8```#\A@``!P````.'```+````"X<``$<````7AP``#0```%^'```)
M````;8<```0```!WAP```P```'R'```3````@(<``!,```"4AP```@```*B'
M```$````JX<```\```"PAP``%````,"'```3````U8<``!````#IAP``#0``
M`/J'```.````"(@``!8````7B```"@```"Z(```'````.8@```<```!!B```
M"0```$F(```'````4X@```0```!;B```#````&"(```%````;8@```0```!S
MB```!````'B(```)````?8@```(```"'B```#P```(J(```$````FH@```4`
M``"?B```!@```*6(```"````K(@```8```"OB```%````+:(```'````RX@`
M``H```#3B```$0```-Z(```(````\(@``!X```#YB```*````!B)```4````
M08D```4```!6B0``*````%R)```I````A8D``%<```"OB0``+`````>*```'
M````-(H```T````\B@``$P```$J*```C````7HH```L```""B@``"P```(Z*
M```@````FHH``"<```"[B@``*P```..*```4````#XL```4````DBP``$0``
M`"J+```$````/(L```0```!!BP``#````$:+```&````4XL```T```!:BP``
M&@```&B+```7````@XL``!<```";BP``&P```+.+```?````SXL``!<```#O
MBP``$P````>,```9````&XP```0````UC```$````#J,```7````2XP```4`
M``!CC```!@```&F,```'````<(P```8```!XC```!P```'^,```'````AXP`
M``4```"/C```&@```)6,```4````L(P```D```#%C```'````,^,```I````
M[(P``#@````6C0``+P```$^-```K````?XT``"H```"KC0``/@```-:-```=
M````%8X``",````SC@``(0```%>.```<````>8X```4```"6C@```@```)R.
M```#````GXX``"````"CC@``)@```,2.```,````ZXX``!\```#XC@``!P``
M`!B/```8````((\```8````YCP``#````$"/```(````38\```D```!6CP``
M!P```&"/```*````:(\```D```!SCP``!P```'V/```&````A8\```T```",
MCP``"P```)J/```,````IH\```H```"SCP```@```+Z/```&````P8\```,`
M``#(CP``10```,R/```P````$I```!````!#D```"0```%20``!3````7I``
M`!\```"RD```$````-*0```/````XY````4```#SD```"````/F0```(````
M`I$```0````+D0``!0```!"1``!H`0``%I$``$\```!_D@``$0```,^2```0
M````X9(``!$```#RD@``"`````23```+````#9,```@````9DP``!0```"*3
M```+````*),``!$````TDP``*0```$:3```0````<),```T```"!DP``$0``
M`(^3```.````H9,```4```"PDP``*````+:3```/````WY,```\```#ODP``
M#P```/^3```3````#Y0```L````CE```%0```"^4``!$````190``"0```"*
ME```+@```*^4```6````WI0```T```#UE```"P````.5```/````#Y4``#,`
M```?E0``(0```%.5```-````=94``!D```"#E0``)P```)V5```Z````Q94`
M`!(`````E@``#P```!.6```1````(Y8``!,````UE@``!@```$F6```<````
M4)8``"P```!ME@``'P```)J6```E````NI8``!H```#@E@``&@```/N6```*
M````%I<``!`````AEP``$````#*7```(````0Y<``#````!,EP``&@```'V7
M```\````F)<``$0```#5EP``8````!J8``!=````>Y@``&<```#9F```9```
M`$&9``!`````IID```4```#GF0``$0```.V9```%````_YD``!`````%F@``
M#0```!::```4````))H```<````YF@``+@```$&:```J````<)H```T```";
MF@``#0```*F:```5````MYH```H```#-F@``"````-B:```4````X9H``!D`
M``#VF@``#0```!";```2````'IL``!4````QFP``(````$>;```@````:)L`
M`!,```")FP``$````)V;```6````KIL```P```#%FP``)@```-*;```7````
M^9L``!<````1G```&@```"F<```/````1)P``$X```!4G```*@```*.<```>
M````SIP``#,```#MG```!P```"&=```+````*9T``#`````UG0``#@```&:=
M```(````=9T```4```!^G0``!P```(2=```*````C)T```0```"7G0``&0``
M`)R=```,````MIT``!````##G0``#P```-2=```6````Y)T``#$```#[G0``
M$P```"V>```5````09X``!@```!7G@``&P```'">```9````C)X``!$```"F
MG@``$0```+B>```=````RIX```P```#HG@``!````/6>```'````^IX```P`
M```"GP``%`````^?```U````))\```@```!:GP``%````&.?```7````>)\`
M``D```"0GP``0P```)J?```[````WI\```4````:H```"P```""@```^````
M+*```!````!KH```00```'R@```P````OJ```#,```#OH```-0```".A```X
M````6:$```D```"2H0``"````)RA```)````I:$``#L```"OH0``.@```.NA
M```Z````)J(``%8```!AH@``.0```+BB```Y````\J(``#D````LHP``.```
M`&:C```H````GZ,``"D```#(HP``.0```/*C```_````+*0``!0```!LI```
M&````(&D```F````FJ0``"8```#!I```$P```.BD```.````_*0```P````+
MI0``"````!BE```.````(:4``!8````PI0``&0```$>E```%````8:4``"T`
M``!GI0``"@```)6E```&````H*4```<```"GI0``+@```*^E```3````WJ4`
M``H```#RI0```P```/VE```)`````:8```4````+I@``#@```!&F```&````
M(*8```4````GI@``!````"VF```*````,J8```,````]I@```P```$&F```8
M````1:8``!@```!>I@``"````'>F```&````@*8``$(```"'I@``)````,JF
M```&````[Z8```8```#VI@``%0```/VF```;````$Z<``!\````OIP``+P``
M`$^G```?````?Z<``"0```"?IP``=0```,2G```W````.J@```8```!RJ```
M%P```'FH```,````D:@``!0```">J```'````+.H```4````T*@``!(```#E
MJ```#````/BH```&````!:D``!<````,J0``'@```"2I```)````0ZD```4`
M``!-J0``30```%.I```$````H:D```X```"FJ0``)@```+6I```0````W*D`
M`!,```#MJ0``#@````&J```@````$*H``"X````QJ@``*````&"J```%````
MB:H``!,```"/J@``$````*.J```,````M*H``!````#!J@``%0```-*J```3
M````Z*H```H```#\J@``!0````>K```%````#:L``!4````3JP``$0```"FK
M```%````.ZL```L```!!JP``"0```$VK```.````5ZL```L```!FJP``"```
M`'*K```-````>ZL``!(```")JP``"P```)RK```)````J*L```H```"RJP``
M"P```+VK```%````R:L```8```#/JP``$@```-:K```,````Z:L```8```#V
MJP``'````/VK```B````&JP```T````]K```#P```$NL```5````6ZP``!8`
M``!QK```,P```(BL``!"````O*P``"4```#_K```)````"6M```.````2JT`
M``@```!9K0``!@```&*M```&````::T``!,```!PK0``$@```(2M```?````
MEZT``!X```"WK0``*0```-:M```H`````*X``"`````IK@``(@```$JN```J
M````;:X``#D```"8K@``'````-*N```F````[ZX``#$````6KP``(@```$BO
M```E````:Z\``"````"1KP``*P```+*O```Q````WJ\``"H````0L```)@``
M`#NP```G````8K```#@```"*L```(P```,.P```C````Y[```#@````+L0``
M$P```$2Q```B````6+$``"D```![L0``'P```*6Q```2````Q;$``+$```#8
ML0``%P```(JR```B````HK(``"H```#%L@``*@```/"R```]````&[,``"8`
M``!9LP``(0```("S```B````HK,``"D```#%LP``+````.^S```X````'+0`
M`"\```!5M```H````(6T```G````)K4``!<```!.M0``(````&:U```L````
MA[4``"P```"TM0``-P```.&U```_````&;8```H```!9M@``!````&2V```&
M````:;8```<```!PM@``#P```'BV```-````B+8``!,```"6M@``%````*JV
M```1````O[8```X```#1M@``#0```."V```-````[K8``!0```#\M@``#@``
M`!&W```R````(+<```@```!3MP``%0```%RW```&````<K<```(```!YMP``
M!@```'RW```$````@[<``!$```"(MP``!````)JW```,````G[<```D```"L
MMP```P```+:W```-````NK<```@```#(MP``"P```-&W```'````W;<```\`
M``#EMP``"````/6W```.````_K<``!$````-N```%````!^X```4````-+@`
M``P```!)N```$````%:X```(````9[@```4```!PN```#````':X```/````
M@[@``!@```"3N```"P```*RX```-````N+@``"$```#&N```&P```.BX```V
M````!+D```D````[N0``%0```$6Y```7````6[D``!,```!SN0``,P```(>Y
M```F````N[D```P```#BN0``!P```.^Y```1````][D``"\````)N@``$0``
M`#FZ```+````2[H``"(```!7N@``+@```'JZ```)````J;H```D```"SN@``
M'P```+VZ```+````W;H``!T```#IN@``'0````>[```'````);L``!0````M
MNP``#````$*[```3````3[L```X```!CNP``$@```'*[```*````A;L``"``
M``"0NP``.@```+&[```(````[+L``"\```#UNP``#@```"6\```)````-+P`
M``8````^O````P```$6\```'````2;P```X```!1O```#@```&"\```3````
M;[P``!(```"#O```&@```):\```1````L;P``!H```##O```&@```-Z\```)
M````^;P```H````#O0```@````Z]```&````$;T```T````8O0``&````":]
M```6````/[T```@```!6O0``#````%^]```.````;+T``!$```![O0``0```
M`(V]```9````SKT```4```#HO0``"````.Z]```4````][T``)`````,O@``
M(0```)V^```$````O[X``!P```#$O@``&@```.&^```;````_+X```8````8
MOP``!@```!^_```0````)K\```\````WOP``$````$>_```/````6+\```\`
M``!HOP``#0```'B_```,````AK\``!````"3OP``!````*2_```'````J;\`
M``4```"QOP``#0```+>_```-````Q;\``"X```#3OP``"@````+````)````
M#<````X````7P```&P```";````A````0L```"(```!DP```(0```(?````>
M````J<```!X```#(P```*@```.?````=````$L$```@````PP0``#````#G!
M```#````1L$```<```!*P0``"0```%+!```+````7,$```@```!HP0``"P``
M`''!```+````?<$``!8```")P0``%@```*#!```,````M\$```<```#$P0``
M!P```,S!```.````U,$``"$```#CP0``!@````7"```/````#,(``!`````<
MP@``#````"W"```#````.L(```0````^P@``!````$/"```9````2,(```D`
M``!BP@```P```&S"```F````<,(```\```"7P@``C@```*?"```0````-L,`
M``@```!'PP``#0```%##```2````7L,```X```!QPP``$````(##```'````
MD<,```P```"9PP``%````*;#```0````N\,```(```#,PP``!@```,_#```9
M````UL,``!(```#PPP``&0````/$```A````'<0```,````_Q```!````$/$
M```0````2,0```@```!9Q```"@```&+$```C````;<0```@```"1Q```&```
M`)K$```-````L\0```T```#!Q```"0```,_$```"````V<0```T```#<Q```
M!P```.K$```&````\L0```@```#YQ```%0````+%```>````&,4``!$````W
MQ0``!P```$G%```5````4<4``!4```!GQ0``"0```'W%```"````A\4```0`
M``"*Q0``,P```(_%```W````P\4``#0```#[Q0``'P```##&```.````4,8`
M``,```!?Q@``!````&/&```%````:,8```4```!NQ@``&````'3&```'````
MC<8```@```"5Q@``'````)[&```#````N\8``#````"_Q@``!0```/#&```$
M````]L8```T```#[Q@``#@````G'```%````&,<``#0````>QP``,0```%/'
M```Y````A<<``!P```"_QP``(@```-S'```^````_\<``#T````^R```*@``
M`'S(```Z````I\@``#````#BR```.````!/)```E````3,D``!````!RR0``
M$@```(/)```+````ELD``"H```"BR0``*P```,W)```D````^<D``"@````>
MR@``"0```$?*```+````4<H```H```!=R@``)P```&C*```F````D,H``#``
M``"WR@``"@```.C*```=````\\H``"P````1RP``%0```#[+```4````5,L`
M``H```!IRP``#0```'3+```0````@LL``!(```"3RP``-P```*;+``"0````
MWLL``'4```!OS```&0```.7,```,````_\P```T````,S0``$0```!K-```2
M````+,T``!,````_S0``!@```%/-```4````6LT``!,```!OS0``$````(/-
M```,````E,T``!,```"AS0``&````+7-```D````SLT``($```#SS0``"@``
M`'7.```4````@,X```0```"5S@``"P```)K.```7````ILX```X```"^S@``
M#P```,W.```0````W<X``!4```#NS@``*@````3/```H````+\\``"8```!8
MSP``)````'_/```M````I,\``"L```#2SP``%P```/[/``!"````%M```!0`
M``!9T```%````&[0```6````@]```!0```":T```$@```*_0```9````PM``
M`!<```#<T```$@```/30```0````!]$``#T````8T0``%P```%;1```6````
M;M$``#L```"%T0``$0```,'1```'````T]$``"T```#;T0``(`````G2```0
M````*M(``!`````[T@``$P```$S2```9````8-(``!$```!ZT@``%````(S2
M```?````H=(``",```#!T@``%0```.72```2````^](``!8````.TP``$P``
M`"73```4````.=,``!4```!.TP``!P```&33```7````;-,```<```"$TP``
M!@```(S3```&````D],```0```":TP``!````)_3```&````I-,```D```"K
MTP``$````+73```J````QM,``!(```#QTP``$`````34```2````%=0```T`
M```HU```"P```#;4```*````0M0``#P```!-U```!````(K4```)````C]0`
M``4```"9U```#0```)_4```-````K=0``!(```"[U```%````,[4```;````
MX]0``!<```#_U````P```!?5```(````&]4``"L````DU0``!P```%#5```,
M````6-4```\```!EU0``#0```'75```)````@]4``!,```"-U0``%0```*'5
M```/````M]4``!0```#'U0``#````-S5```.````Z=4```@```#XU0``!```
M``'6```/````!M8``#0````6U@``!@```$O6```,````4M8``!T```!?U@``
M#@```'W6```-````C-8```T```":U@``"P```*C6```*````M-8```@```"_
MU@``#0```,C6```*````UM8``!````#AU@``&@```/+6```K````#=<```H`
M```YUP``%0```$37```)````6M<```H```!DUP``#````&_7```(````?-<`
M``@```"%UP``!P```([7```3````EM<``$8```"JUP``#0```/'7```*````
M_]<```H````*V````P```!78```4````&=@``!8````NV````@```$78```'
M````2-@``!````!0V```#0```&'8```/````;]@```\```!_V```"````(_8
M```/````F-@``!T```"HV```"@```,;8```'````T=@```D```#9V```"0``
M`./8```)````[=@```0```#WV```$````/S8```%````#=D```<````3V0``
M!0```!O9```*````(=D```,````LV0``#0```##9```%````/MD```<```!$
MV0``!````$S9```"````4=D```8```!4V0``$````%O9```$````;-D```P`
M``!QV0``$0```'[9```'````D-D``!T```"8V0``+0```+;9```5````Y-D`
M``<```#ZV0``*`````+:```H````*]H``%@```!4V@``,0```*W:```/````
MW]H```P```#OV@``$@```/S:```?````#]L```D````OVP``"P```#G;```>
M````1=L``#````!DVP``-````)7;```5````RML```D```#@VP``$````.K;
M```%````^]L```D````!W```"@````O<```#````%MP```P````:W```%```
M`"?<```/````/-P``!````!,W```&0```%W<```2````=]P``!8```"*W```
M$P```*'<```@````M=P```D```#6W```%0```.#<```5````]MP```4````,
MW0``!@```!+=```$````&=T```0````>W0``!P```"/=```*````*]T```@`
M```VW0``&P```#_=```/````6]T```D```!KW0``%P```'7=```X````C=T`
M`"\```#&W0``/@```/;=```W````-=X``#4```!MW@``3@```*/>```H````
M\MX``"T````;WP``'0```$G?```6````9]\```8```!^WP```P```(7?```#
M````B=\``!\```"-WP``*````*W?```/````UM\``"````#FWP``"0````?@
M```<````$>````@````NX```"@```#?@```*````0N````L```!-X```!@``
M`%G@```,````8.````X```!MX```"````'S@```(````A>```!````".X```
M#0```)_@```,````K>````P```"ZX````@```,?@```%````RN````(```#0
MX```/````-/@```V````$.$```\```!'X0``"@```%?A``!B````8N$``!T`
M``#%X0``$````./A```0````].$```4````%X@``!P````OB```$````$^(`
M``0````8X@``!0```!WB```!````R@(``,T```"H````6P(``$\!````````
M$`,```````#6````FP```,X```!.`P``1`(``$0!````````````````````
M`````````#$#```?````5````-T!```V````S`$``+4"``"%`0```````*,!
M````````SP$``"$#````````A`$```````#K`@````````````#S`@``40(`
M``@"````````.@,``"<!`````````````(("```/`@``C`$``!8"``"V````
MC0$``)("```]`0```````/8```#T`@```````$8!``!H````:0(``.X````7
M`0``I````+H````#````B`$``$X!``#8`0``!`$`````````````#@(``.@"
M````````````````````````10$``/<`````````O@$``%8````[`P``````
M`($"```4`P```````"4"````````:P(``$,#````````G`$```T````"`@``
M4````/\````'`P``0`,``!@!````````TP```!(````)````70(`````````
M````20(``)D```!3````9@(``/<!````````MP```%@!```:`0``%@,``',!
M``````````````````#$````"P$``"X!``"&````K````%0!``#?````````
M``````````````````X!``"F````$`(```````#1`0``````````````````
M"````#$"``#+````90```*P!`````````````"@!``"5`0``,P,``.0````F
M`P``_@````````#R````'0$``&4!`````````````.4"``"Q`@```````(,`
M``#4`@``````````````````K@```%D````O`0```````"4#```!`0``J`(`
M`!,!``!D`0``O0```'X````S`````````+$`````````DP$``/4"```2`P``
MY0```.P"```#`0``L`$``#8"``";`0``G0$````````-`P``S0(````````Z
M`@```````!,#``!#`@```````/\!``"+````&P(``!$`````````-0(``!``
M````````5@(``````````````````$L!````````&P```````````@``<```
M`!H````,`0``B@$``-P````,`@``50(``-,!````````%P``````````````
MX`$``$@````"`0``+````&8`````````$0,``%(`````````"P,``$$#``#\
M`0````````\!``"@`@``?`(``,<!```^````0@,````````Z`0``K0$``$T"
M``#"`0```````"$```#7````````````````````L@$``!T`````````K`(`
M`/X"```P`0```````%P"`````````````$8"````````R@$``"T!``"0````
M2P(``,,!````````T`$```4"``#\`@``10(``&````!M``````````T"````
M````%`$``,4`````````M````'(!``"[`0``6@$``)0!```3````40$`````
M````````-````$H````I`@``+0,``/\"``!O`@``.@```$$"``!X`@``````
M`!L!``"R`@`````````````*`P``^@(```````!X````:@```#$!``#T````
M`````.<"``!.````20$``%4````?`0``B````(X````N````2`$``%\```!A
M`@```````$(`````````IP````````#:`0``00```/$!``"I`0``F````*\`
M```U`0``'P(``'`!``"'`0``BP$``+\"`````````````%(!````````60$`
M`!P"`````````````/T```#&`````0(``&@"`````0``IP(``/`!``![````
M``````````#Y`@``7@```#<!````````8`$``-H``````````````#T"````
M````>@(```````"4`@``&0,``*$"```S`0``Z@$``%4!``"1`0``2@(``&(`
M```I`0```````+4`````````A@(``````````````````/L!``!``````P(`
M`)`!`````````````*,`````````IP$``)8"``#V`0``9`(```H````-`0``
MV0$``.<!``#C`@``F0$``#@!``""`0``H0```,X"````````20```$4`````
M`````````$H!``")````WP$``(``````````&`````````#P````^`(``!D"
M````````=@(``)P`````````"`$``*H"``````````````(`````````````
M``````#M`0``O@````````!O`0``=0(``,0"``!Q`@``D`(``'0!``!1`P``
MA```````````````G@$``)P"```C`@``B@``````````````DP```-@```!B
M`@``.`,``,P```!7````ZP$``(4"``#(`0``K0(``%@```#]`0``&@,``!P#
M```N`@``?0$``#P!``#I`0``!@,```````":````XP$``$P"``!-`P``````
M`*L!`````````````````````````````"T"``#B````!@(``"`!````````
M`````'0"````````#````*8"````````N````,,"``"P````@P$```````!*
M`P``SP```,8!``!$````&`,``-<"``#K`````````+D```!L````<P```/@`
M``"+`@``J@```&P"``#$`0``F0(``+D!``"2``````````````!G````C@(`
M``D"``!L`0``.`(```````#J`@```0,``#(!```"`P``10,```<"````````
M'@,```````"^`@``1P$``-4!```W`P``*````%L```````````````````!3
M`@``P0```)4````\`@``_@$``*4!``"N`@```````/<"``"1````U0(``"0!
M````````@`$``.D`````````5P(``"4```!=`0``_````*X!````````!`(`
M`#P```"V`@``(````$\#``"_`0``&0```"("``!P`@``B0(````````@`@``
M70`````````Y`0``RP(``*`!```:`@`````````````J`````````%D"``#9
M`@``Y@```&<!````````O`$``#L!``"X`@``+`(``*L```!\`0``>`$`````
M````````O0$```````#E`0``S`(``$`!```5````G0(```````!B`0``R0$`
M````````````GP$``"0#``"J`0```````/4!``#0`@``VP```/H`````````
M$`$```````")`0``H@$``-,"``"/`0``KP(`````````````CP````````!C
M`0```````&$```"@````/P$``#\#``#O`0```````",#```>`@``````````
M``"P`@``3@(``!,"``!\`````````%8!``"W`@```````%L!```;`P``"@(`
M`(P```"Q`0```````"L!````````C@$``$(!```)`P```````#P#```O`@``
M*@,```4````5`P``I`$``)4"```1`0``O`(``($!``"[`````````-L"```8
M`@```````(0"``!"`@``1P(``&@!``!&`P````````````!4`@``\P```'<"
M```$`P``P0$``$T```````````````````#>`@``C0```%P```#M````*P``
M``````#B`0``)@(``.P```#P`@```````(H"``"6`0``*0```($`````````
MU```````````````G@`````#``!,````@`(````````/````KP$``'X!```P
M````R@```!("```K`P``<@(``)$"``#V`@```````!4"``#C`````````&4"
M``#<`0``.P(``,\"````````H0$``#4#``"'````^P(```````!V`0``(P$`
M``````!W````<@``````````````*`(``&L!``#1`@``'@$````````(`P``
M>0`````````O`````````+4!``"8`@``N`$``*("```A`@``*@$``/T"````
M````40```*@!``#>`0```````(@"```=`@```````(4```#[````/0``````
M``#J`````````-8!``````````````4#``#I`@``AP(``$T!```N`P``;@(`
M`'\````<````UP$``)<!``#O`@``P`(``,X!``!``@``````````````````
MV@(``"$!``#Y`````````)<````W`@``)P(``%<!``"I`@``U@(``"0"``"]
M`@``R````&T"```Y`P``*P(``&H"````````,@```+,!``!<`0``P@(``%\!
M```1`@``G@(``#T#``"V`0``YP```&`"``!I``````````````":`0``Z```
M````````````^0$``*D```"C`@````````X#``#Q`@```````,T!``#O````
M``````````!(`P``X0(``"<#```L`P```````'\"``"T`@```````)\"``!J
M`0````````````!:`@``0P$``%@"``!>`0``X`(```````!N`````````!8!
M````````[@(``,`!``#?`@``)@```-X````P`@``@@````````#;`0``````
M`-`````)`0````````````";`@``"P```#`#```'````Q@(``!(!```O`P``
M)`````````"/`@``[@$``#X"``#D`@````````L"``#(`@``I0```!<#``!&
M````,@,``*4"`````````````#$```!Q````.0(``"(```!]````V0```'D"
M````````%0$``$$!`````````````,D``````````````$P#``#R`0``[`$`
M`"(#```?`P``-`(```8!```7`@``MP$``+0!``````````````,#``#@````
M`````,,```"M````P@``````````````*`,```````"[`@``8P````0```#2
M`0``Y`$``#0#``!?`@```````"`#``#1````````````````````/P(`````
M```<`0``)0$``*0"```^`P``]`$``#X!``"#`@``JP(```P#``!V````7@(`
M`"8!``"_````Y@$``'H````V`P``;P```)8```#F`@``8P(``$<```#=`@``
M`````'D!``#R`@``X@(``'\!``!K````N0(````````T`0``T@(````````.
M````QP`````````'`0``QP(```````````````````````!M`0``N@$``),"
M``!N`0``20,``-0!``!'`P``-P``````````````,@(``)T````>````C`(`
M`'4!```_````-@$```\#``#Z`0``L@```!D!```=`P```````)0```#%`@``
M>@$```8````B`0``T@```,4!````````\P$``#4```!U`````````!0```#A
M````.0````````#M`@``*0,``#,"``!G`@```````'X"``#!`@``:0$`````
M```4`@``X0$``"T```!:````4`(``$\```````````````4!```[````2P``
M``````!/`@```````'$!``#)`@``)P```+H"`````````````+P````X````
M3`$```````![`0``9`````````!F`0```````-T````C````H@```$@"``!0
M`0``2P,``"H"``!W`0``P````(8!``#8`@``%@````````!A`0``I@$`````
M``!T````F`$`````````````"@$``(T"````````?0(``$0#``#Q````````
M``````![`@``+`$``-4```"S````4`,``)(!````````````````````````
M``````````#U````4P$``$,```"7`@``^`$``+,"``!2`@```````)H"````
M`````````-P"``!S`@``Z`$```````#+`0``GP`````@)B,Q-3$[("5S(&ES
M(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"!A="``)60@)7,@86YD("5S`"5D(&)Y=&5S('=R:71T96XN`"5D(&]F
M("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($9I;F=E<G!R
M:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE
M;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&AA<R!C86YC
M96QL960@)7,N`"5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E
M<W0N`"5S(&AA<R!R97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E
M<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!I<R!N
M;W0@=W)I=&%B;&4N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T
M(&9O=6YD+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RX`)7,@=&\@)7,@
M;V8@)7,`)7,@=VES:&5S('1O(&%D9"!T;R`E<RX`)7,@=VES:&5S('1O(&UA
M:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@
M;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E<R=S($%D9')E<W,@0F]O
M:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S
M.B`E<P`G)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC92X`)R5S)R!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"<E<R<@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@
M)7,N`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@
M2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32]030!!8F]U="!T
M:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5P
M="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`
M06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!
M8W1I;VYS`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I
M;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N
M`$%D9"!A(&-H:6QD(&=R;W5P('1O("<E<R<`061D(&$@8VAI;&0@<&5R;6ES
M<VEO;B!T;R`G)7,G`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N
M97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII
M;&QA(%-I9&5B87(`061D('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@)R5S)R!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!N97<@
M9FEL97,@=&\@<F5P;W-I=&]R>3H`061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`06QI
M87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D
M97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0
M($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0
M(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T
M96UP;&%T97,`06QT97)N871E('1E>'0Z`$%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"X`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!<'!L:6-A=&EO
M;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L
M>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%R
M8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("<E<R<@86YD(&%N>2!S
M=6(M9W)O=7!S/P!!<G0`07-C:6D@07)T`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM
M96YT(&-O;'5M;G,`071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P
M;'D@=&\@82!R97%U97-T('EO=2!S96YT`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+@!!='1E;F1E97,`071T<FEB=71E<P!!=7-T<FEA`$%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07=A:71I;F<@4F5S<&]N
M<V4`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"
M860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`
M0F%R90!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"X`
M0F%S96QI;F4`0F5L9VEU;0!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI
M8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4
M>7!E`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!"
M;W)D97)S`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0TU3`$-20P!#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N
M9&%R`$-A;&T`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE
M;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<'1I;VX`
M0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T
M:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN
M9SH`0V5L;'!H;VYE`$-E;G1E<@!#97)T:69I8V%T92!$971A:6QS`$-E<G1I
M9FEC871E(%!O;&EC:65S`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H87(`0VAE8U]K($QI
M;FLN+BX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAO;W-E(&$@<&%S<W=O
M<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO;CH`0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RD`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T
M('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O
M($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L
M;W5D<P!#;&]U9'D`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R
M<P!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQU;6X@
M=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;6%N9"!O
M<'1I;VYS.@!#;VUM86YD<SH`0V]M;65N=`!#;VUM:71T:6YG.@!#;VUM;VX@
M3F%M90!#;VUP86YY`$-O;7!L971E9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#
M;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M`$-O;F9I9W5R871I;VX@;F5E9',@=7!D871I;F<N`$-O;F9I9W5R92`E<P!#
M;VYF:7)M(%!A<W-W;W)D`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N
M(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G1S(&]F("<E<R<`0V]N=&EN
M=64`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]P>6EN9R`E<R!T;R`E
M<P!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-O
M<'D@)7,@=&\@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L
M;V-A;&4@)7,Z`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N`$-O
M=6QD(&YO="!M:V1I<B`G)7,G+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U
M;&0@;F]T(&]P96X@)R5S)R!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y("<E<R<N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G
M)7,G+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@)R5S)RX`0V]U;&0@;F]T('5P
M9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M)R5S)SH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U
M<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M)R5S)SH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L
M9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#
M=7)R96YT(%!H87-E`$-U<G)E;G0@5&EM90!#=7)R96YT(%=E871H97(`0W5R
M<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`
M0WEP<G5S`$1$`$1A:6QY`$1A=&$`1&%T851R964@0G)O=W-E<@!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE9`!$96-R96%S92!)
M;F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI<W-I;VYS`$1E9FEN
M:71I;VYS`$1E;&5G871E('!O<VET:6]N`$1E;&5G871E9`!$96QE=&4`1&5L
M971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@
M;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI
M<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@)R5S)P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C
M=7)R96YT(')O=P!$96QE=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E
M<R<N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$96YY(')E<75E<W0`1&5N>2!R
M97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES
M<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F
M;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VX`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL
M;V%D`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`161I=`!%
M9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R
M;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS
M(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161I="!P97)M:7-S:6]N
M<R!F;W(@)R5S)P!%9'5C871I;VX`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I
M;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP
M='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO
M;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD`$5N9"!Y96%R`$5N
M;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17)R;W(`17)R;W(@<V5N9&EN
M9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@
M=W)I=&EN9R`G)7,G+@!%<G)O<CH@`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S
M`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN
M=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E
M`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X96-U=&EN9SH`17AP86YD`$5X
M<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N
M=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:7(`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R
M>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO
M=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6QE($-O=6YT.B`E<R!F:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N`$9I;'1E<G,`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R
M871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`
M1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@
M=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A
M;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN
M(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O
M<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US
M`$9O<G=A<F1S`$9O=6YD(&%P<&QI8V%T:6]N<SH@)7,`1F]U;F0@9&ER96-T
M;W)I97,Z`$9R`$9R86UE<P!&<F5E+T)U<WD@26YF;W)M871I;VX`1G)E92]"
M=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T`$9R964O0G5S>2!297%U97-T
M(%)E<W!O;G-E`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L
M;"!-;V]N`$9U;&P@3F%M90!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'
M86QL97)Y.@!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#
M;V1E`$=E=&]P="!%<G)O<CH@`$=I=F5N($YA;64`1V\`1V]O9VQE(%-E87)C
M:`!'<F%Y<V-A;&4`1W)E96-E`$=R965N;&%N9`!'<F]U<"!!9&UI;FES=')A
M=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<"!P97)M
M:7-S:6]N<P!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W0@<&5R;6ES
M<VEO;G,`1W5E<W1B;V]K`$A(`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5I9VAT`$AE
M;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I
M<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AI<W1O<GD@96YT
M<GD@;F%M97,@;75S="!B92!N;VXM96UP='D`2&]?;64`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!0:&]N90!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E
M<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S
M(@!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B
M)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO
M;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W
M(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y
M.B``2'5M;W)I<W1S`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D
M<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E
M<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W
M:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R
M979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R
M>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP
M;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L
M9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I
M=FED=6%L(%5S97)S`$EN9F\`26YF;W)M871I;VX`26YS97)T($-?;VQU;6X@
M069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI
M;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F
M;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL
M(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S
M<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!)
M;G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R
M="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A
M9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O
M<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y
M('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@
M3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN
M=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="X`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E
M9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@
M9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED
M(')E8VEP:65N=#H@)R5S)P!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED
M('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT
M;W)Y`$ES;VQA=&5D(%0M4W1O<FUS`$ES<W5E<@!)=&%L:6,`2F%N=6%R>0!*
M=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!+965P(&]R:6=I;F%L
M/P!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME
M<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y
M($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$QA7WEO=70`3&%N9W5A
M9V4`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@
M;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@
M3F5V97(`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE
M9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&EG:'0@1')I>GIL90!,:6=H
M="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT
M(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N
M;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT
M<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M
M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@
M2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L
M<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E
M`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M3&ET97)A='5R90!,;V%D:6YG(&QI8G)A<FEE<RXN+@!,;V%D:6YG+BXN`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO
M9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`
M3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@
M;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$U-`$UA:6P`36%T8VAI;F<@
M9FEE;&1S`$UE971I;F<@0V%N8V5L;&%T:6]N`$UE971I;F<@26YF;W)M871I
M;VX`365E=&EN9R!0<F]P;W-A;`!-965T:6YG(%)E<&QY`$UE971I;F<@57!D
M871E`$UE971I;F<@57!D871E(%)E<75E<W0`365N=2!M;V1E.@!-97-S86=E
M`$UO;G1H;'D`36]V92!D;W=N`$UO=F4@=7``3F%M90!.965D<R!!8W1I;VX`
M3F5V97(`3F5W<P!.97AT`$YE>'0@4&%G90!.;P!.;VX@4&%R=&EC:7!A;G0`
M3F]N90!.;W1E<P!.;W1I8V4`3TL`3V9F:6-E`$]P=&EO;F%L(%!A<G1I8VEP
M86YT`$]P=&EO;G,`3W)G86YI>FEN9P!/=&AE<B!);F9O<FUA=&EO;@!087-S
M=V]R9`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)S;VYA;"!);F9O
M<FUA=&EO;@!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO
M;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E
M;&]W+@!0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E
M;&]W+@!0<F5V:65W`%!R979I;W5S(%!A9V4`4')O8FQE;2!$97-C<FEP=&EO
M;@!296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!296UO=F4@
M<&%I<@!297!L>2!396YT+@!297!L>2!W:71H($YO="!3=7!P;W)T960@365S
M<V%G90!297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`
M4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!2
M97%U:7)E9"!087)T:6-I<&%N=`!297-E=`!2971U<FX@=&\@3W!T:6]N<P!2
M;VQE`%-A=F4`4V%V92!/<'1I;VYS`%-E87)C:`!396QE8W0@82!D871E`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;F0@3&%T97-T($EN9F]R;6%T:6]N`%-E;F0@4')O8FQE;2!297!O<G0`4VEG
M;B!U<"!I9B!N;W0@<F5G:7-T97)E9`!3:7IE`%-K:7`@36%I;G1E;F%N8V4`
M4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W1A<G0`4W1A='5S`%-U8FIE8W0`
M4W5B;6ET`%-U8V-E<W,`4W5M;6%R>0!487-K<P!496YT871I=F5L>2!!8V-E
M<'0@<F5Q=65S=`!496YT871I=F5L>2!!8V-E<'1E9`!497AT($]N;'D`5&AE
M(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9`!4:&4@=&%S:R!H87,@8F5E;B!A
M9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I
M;VXZ("5S+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C
M=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:71L90!4;P!54DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD
M;R!#:&%N9V5S`%5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YN
M86UE9`!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!L;V%D`%5S97(@3W!T
M:6]N<P!5<V5R;F%M90!5<V5R;F%M93H`5FEE=R`E<P!6:65W(&5V96YT`%9I
M97<@=&%S:P!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO
M=7(@3F%M90!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/<'1I;VX@*R!0('1O('!R:6YT
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E
M<&]R=%T`6VQI;F4@)7,@;V8@)7-=`%](96QP`%],;V<@;W5T`%]/<'1I;VYS
M`&YA;64`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`N-`I2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TP-2TQ."`Q,CHT,RLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#4M,3@@,30Z,S<K,#(P,`I,87-T+51R86YS;&%T
M;W(Z($=E:7(@3RX@2&]G8F5R9R`\:&]R9&5`<VMY9&EV97(N;F\^"DQA;F=U
M86=E+51E86TZ($YO<G=E9VEA;B`H0F]K;6%L*2`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:70*`"`F(S$U,3L@)7,@97(@:VQA<B!F;W(@Y2!U=&;X<F4@
M=F5D;&EK96AO;&1S;W!E<F%S:F]N96YE('-O;2!E<B!V86QG="!N961E;F9O
M<BX`("@E<R!D86=E<B!S:61E;BD`("AH=7)T:6=T87-T("5S*0`@*&EN;F5N
M("5S(&1A9V5R*0`@*&D@9&%G*0`@*&D@;6]R9V5N*0`@*&D@9^5R*0`@9&5N
M(``E9"`E<R!O9R`E<P`E9"!B>71E<R!S:W)E=F5T+@`E9"!A=B`E9"!O<'!F
M^')I;F=E<B!M87)K970@<V]M(&]P<&1A=&5R=``E9"UD86=E<G,@=F%R<V5L
M`"5S("T@5&EL(&EN9F\`)7,@861M:6YI<W1R87-J;VX`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@=F5D;&EK96AO;&1S;W!E<F%S:F]N97(@+2!"96MR969T
M96QS90`E<R!I;G-T:6QL:6YG97(`)7,@<F5G:7-T<F5R:6YG`"5S(&%V=&%L
M979I;&OE<@`E<R!F:6YN97,@86QL97)E9&4N`"5S('#E("5S("5S`"5S(&AA
M<B!K86YS96QL97)T("5S+@`E<R!H87(@8F5S=F%R="!E;B!F;W)E<W#X<G-E
M;"!O;2!I;F9O<FUA<VIO;B!A;F?E96YD92!L961I9R]O<'!T871T+@`E<R!H
M87(@<W9A<G0@<.4@:6YV:71A<VIO;F5N('1I;"`E<RX`)7,@:&%R('-E;F1T
M(&1E9R!I;F9O<FUA<VIO;B!O;2!L961I9R]O<'!T871T+@`E<R!E<B!S:W)I
M=F5B97-K>71T970N`"5S(&5R('#E:W)E=F0`)7,@;6EN=71T97(`)7,@:6MK
M92!F=6YN970N`"5S(&9O<F5S</AR(&EN9F]R;6%S:F]N(&]M(&[E<B!D=2!E
M<B!L961I9R]O<'1T871T+@`E<R!F;W)E<W#X<B!D:6X@9&5L=&%G96QS92!P
MY2`E<RX`)7,@+2`E<R!A=B`E<P`E<R#X;G-K97(@Y2!L96=G92!T:6P@)7,N
M`"5S(/AN<VME<B#E(&=J^')E(&1E9R!O<'!M97)K<V]M('#E("5S+@`E<R#X
M;G-K97(@Y2!M;W1T82!D96X@<VES="!O<'!D871E<G1E(&EN9F]R;6%S:F]N
M96X@;VT@)7,N`$%D9')E<W-E8F]K(&9O<B`E<P!+86QE;F1E<B!F;W(@)7,`
M3F]T871B;&]K:R!F;W(@)7,`3W!P9V%V96QI<W1E(&9O<B`E<P`E<SH@)7,`
M)R5S)R!E<B!I:VME(&5T(&=Y;&1I9R!V86QG+@`G)7,G(&5R(&EK:V4@8V]N
M9FEG=7)E<G0@:2!(;W)D92!296=I<W1E<F5T+@`E<R!B;&4@;&%G="!T:6P@
M9W)U<'!E<WES=&5M970N`"<E<R<@8FQE(&QA9W0@=&EL(')E='1I9VAE='-S
M>7-T96UE="X`)7,@8FQE(&EK:V4@;W!P<F5T=&5T.B`E<RX`+"!V87)I86)E
M;"!M96QL;VT@)7,@;V<@)7,`+2T@=F5L9R`M+0`Q,B!4:6UE<G,@9F]R;6%T
M`#(T(%1I;65R<R!F;W)M870`,C0@=&EM97(`16X@9&%T86)A<V5K;V)L:6YG
M(&5R('#E:W)E=F0@9F]R(&1E;FYE(&)L;VMK96XN`$5N(&9A=&%L(&9E:6P@
M:&%R(&]P<'-TY71T`$5N(&]F9F5N=&QI9R!01U`M;OAK:V5L(&5R('#E:W)E
M=F0@9F]R(.4@:W)Y<'1E<F4@;65L9&EN9V5N+@!%;B!O9F9E;G1L:6<@4$=0
M+6[X:VME;"!E<B!PY6MR979D(&9O<B#E('9E<FEF:7-E<F4@<VEG;F5R="!M
M96QD:6YG+@!%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"P@<')I=F%T(%!'4"UN
M^&MK96P@;V<@<&%S<W!H<F%S92!E<B!PY6MR979D(&9O<B#E(&1E:W)Y<'1E
M<F4@96X@;65L9&EN9RX`16X@;V9F96YT;&EG(%!'4"UN^&MK96PL('!R:79A
M="!01U`M;OAK:V5L(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"!F;W(@Y2!S
M:6=N97)E(&5N(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!3+TU)344M;OAK:V5L
M+"!P<FEV870@4R]-24U%+6[X:VME;"P@;V<@<&%S<W!H<F%S92!E<B!PY6MR
M979D(&9O<B#E(&1E:W)Y<'1E<F4@96X@;65L9&EN9RX`16X@;V9F96YT;&EG
M(%,O34E-12UN^&MK96PL('!R:79A="!3+TU)344M;OAK:V5L+"!O9R!P87-S
M<&AR87-E(&5R('#E:W)E=F0@9F]R(.4@<VEG;F5R92!E;B!M96QD:6YG+@!%
M;B!O9F9E;G1L:6<@4R]-24U%+6[X:VME;"!E<B!PY6MR979D(&9O<B#E(&MR
M>7!T97)E(&5N(&UE;&1I;F<N`$%-+U!-`$]M(&1E;FYE(&5D:71O<F5N`$]M
M+BXN`$%B<V]L=71T(&YE9&5R<W0`06)S;VQU='0@;6ED=`!';V1K:F5N;B!F
M;W)E<W#X<G-E;`!';V1T871T`%1I;&=A;F<@;F5K=&5T('9E9"!O<'!R971T
M96QS92!A=B!61E,@:V%T86QO9RX`5&EL9V%N9R!N96MT970@=F5D(&]P<')E
M='1E;'-E(&%V(%9&4R!F:6PN`$MO;G1O(%!A<W-O<F0`2V]N=&\@9G+X<V5T
M+@!";VMH;VQD:6YG+T%C8V]U;G1I;F<`2&%N9&QI;F=E<@!,96=G('1I;`!,
M96=G('1I;"!U;F1E<F=R=7!P90!,96=G('1I;"!U;F1E<G)E='1I9VAE=&5R
M`$QE9V<@=&EL(&AE<CH`3&5G9R!T:6P@;GD@9W)U<'!E`$QE9V<@=&EL(&YY
M(')E='1I9VAE=`!,96=G('1I;"!E;B!U;F1E<F=R=7!P92!T:6P@)R5S)P!,
M96=G('1I;"!U;F1E<G)E='1I9VAE="!T:6P@)R5S)P!,96=G('1I;"!N>2!B
M<G5K97(Z`$QE9V<@=&EL(&MO;&]N;F4`3&5G9R!T:6P@;GEE(&UE9&QE;6UE
M<@!,96=G('1I;"!P87(`3&5G9R!T:6P@)7,@;65N>65N('-O;2!-;WII;&QA
M(%-I9&5B87(`3&5G9R!T:6P@:2!M:6X@:V%L96YD97(`3&5G9R!T:6P@:2!A
M9&1R97-S96)O:SH`3&5G9R!T:6P@:2!M:6X@861D<F5S<V5B;VL`3&5G9R!T
M:6P@8G)U:V5R`$QA('1I;"`G)7,G(&D@<WES=&5M970L(&UE;B!K=6YN92!I
M:VME(&QE9V=E('1I;"!E:W-T<F$@<F5G:7-T<F5R:6YG<VEN9F\Z("5S+@!,
M82`G)7,G('1I;"!S>7-T96UE="X@1'4@:V%N(&QO9V=E(&EN;B!NY2X`3&$@
M=&EL(&YY92!F:6QE<B!I(')E<&]S:71O<GDZ`$UU;&EG:&5T(&9O<B#E(&QE
M9V=E('1I;"!N>64@8G)U:V5R92!E<B!D96%K=&EV97)T+@!!9')E<W-E`$%D
M<F5S<V4@0F]K`$%D;6EN:7-T<F5R("T@<V5T="!R971T:6=H971E<B!F;W(@
M86YD<F4@8G)U:V5R90!!9&UI;FES=')A<VIO;@!296ML86UE<@!!;&EA<P!*
M=7-T97)E`$IU<W1E<FEN9SH`06QL90!!;&QE(&%U=&5N=&ES97)T92!B<G5K
M97)E`$%L;&4@1W)U<'!E<@!!;&QE(')E9&1I9VAE=&5R`$%L;&4@9FER92!S
M:61E<@!4:6QL871T(&9L97)E(&%D<F5S<V5R`%1I;&QA='0@96YD<FEN9R!A
M=B!F;W)M871E="!PY2!N=6UM97)E<G1E(&QI<W1E<C\`16MS:7-T97)E<B!A
M;&QE<F5D90!!;'1E<FYA=&EV($E-4U`@3&]G:6X`06QT97)N871I=G0@24U3
M4"!P87-S;W)D`$%L=&5R;F%T:79T($E-4U`@8G)U:V5R;F%V;@!!;'1E<FYA
M=&EV(&4M<&]S="!A9')E<W-E`$%L=&5R;F%T:79E(&UA;&5R`$%L=&5R;F%T
M:78@=&5K<W0Z`$5N('5L;W9L:6<@=F5R9&D@=F%R(&]P<&=I='0N`$%N;VYY
M;2!0<F]X>0!3=F%R`%!R;V=R86T`4')O9W)A;6QI<W1E`%!R;V=R86UM970@
M97(@:VQA<G0N`$]P<&1A=&5R(&]G<^4@<F5K=7)S:79T(&YE9&]V97(@9F]R
M('5N9&5R;6%P<&5R+V9I;&5R`$=O9&MJ96YN`$]M=')E;G1L:6<@<W3X<G)E
M;'-E`$9I;'-T^')R96QS92!PY2!A<FMI=F5T`$%R:VEV;F%V;@!%<B!D=2!3
M24M+15(@<.4@870@9'4@=FEL(&9J97)N92!R96=I<W1R97)I;F=S9F]R97-P
M^')S96QE;B!F;W(@)7,_`$5R(&1U('-I:VME<B!PY2!A="!D=2!V:6P@<VQE
M='1E("<E<R<@;V<@9&5N<R!U;F1E<F=R=7!P97(_`$MU;G-T`$%S8VEI(&MU
M;G-T`$)E(&]M(&)E:W)E9G1E;'-E(&;X<B!G:F5N;F]M9OAR:6YG(&%V('9E
M9&QI:V5H;VQD<V]P97)A<VIO;F5R`$MO;&]N;F5A;G9I<VYI;F<`5F5D;&%G
M="!I('-V87)E="!E<B!E;B!I0V%L96YD87(@9FEL(&9O<B!E;B!F;W)E<W#X
M<G-E;"!D=2!S96YD=&4`1F]R<_AK=&4@Y2!S;&5T=&4@96X@9W)U<'!E('-O
M;2!I:VME(&5K<VES=&5R97(N`$9O<G/X:W1E(.4@<VQE='1E(&5N(')E='1I
M9VAE="!S;VT@:6MK92!E:W-I<W1E<F5R+@!&;W)S^&MT92#E(')E9&EG97)E
M(&5N(')E='1I9VAE="!S;VT@:6MK92!E:W-I<W1E<F5R+@!&;W)S^&MT92#E
M(')E9&EG97)E(&5N(&1E;'0@<F5S<W5R<R!S;VT@:6MK92!E:W-I<W1E<F5R
M+@!$96QT86=E<F4`071T<FEB=70`V'-T97)R:6ME`$%U=&A?8WER<W%L.B!+
M86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN
M`$%U=&A?8WER=7,Z($)A8VME;F0@:6YN96AA<B!I:VME(&[X9'9E;F1I9R!F
M=6YK<VIO;F%L:71E="X`075T:%]C>7)U<SH@2V%N(&EK:V4@9FEN;F4@9&5N
M(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L<V5N+@!!=71H7V9T<#H@2V%N(&EK
M:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@1E10('5T=FED96QS96XN($MO;7!I
M;&5R(%!(4"!M960@+2UE;F%B;&4M9G1P+@!!=71H7VEM87`Z($MA;B!I:VME
M(&9I;FYE(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E;BX`075T:%]K
M<F(U.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!K<F(U('5T=FED
M96QS96XN`$%U=&A?;&1A<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I
M9V4@3$1!4"!U='9I9&5L<V5N+@!!=71H7VQD87`Z($MU;FYE(&EK:V4@;&5G
M9V4@=&EL(&)R=6ME<B`E<RX@4V5R=F5R96X@<V$Z(`!!=71H7VQD87`Z($MU
M;FYE(&EK:V4@9FIE<FYE(&)R=6ME<F5N("5S`$%U=&A?;&1A<#H@2W5N;F4@
M:6MK92!O<'!D871E<F4@8G)U:V5R("5S`$%U=&A?;6-A;#H@2V%N(&EK:V4@
M9FEN;F4@9&5N(&[X9'9E;F1I9V4@34-!3"!U='9I9&5L<V5N+@!!=71H7W-M
M8F%U=&@Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E('-M8F%U=&@@
M=71V:61E;'-E;BX`075T96YT:7-E<FEN9R!F96EL970`075T96YT:7-E<FEN
M9R!F96EL970N("5S`$%U=&5N=&ES97)I;F<@;F5K=&5T(&%V(%)!1$E54R!T
M:F5N97(N`$%U=&5N=&ES97)I;F<@;6]T($944"!T:F5N97)E;B!F96EL970N
M`%1I;&=J96YG96QI9V4@9F5L=#H`5F5N=&5R('#E('-V87(`0D]&2"!%>&-U
M<V5S`$)A:V=R=6YN`$)A:V=R=6YN<V9A<F=E`$9E:6P@:V5R8F5R;W,@<&%S
M<V]R9"X`1F5I;"!K97)B97)O<R!B<G5K97)N879N+@!";&%N:P!"87-E:V%T
M86QO9R!F;W(@9W)A9FEK:R`G)7,G(&)L92!I:VME(&9U;FYE="X`1W)U;FYL
M:6YJ90!"96QI9V$`0G5R<V1A9P!";&]K:R`B)7,B(&%V('!R;V=R86UM970@
M(B5S(B!B;&4@:6MK92!F=6YN970N`$)L;VMK(&EN;G-T:6QL:6YG97(`0FQO
M:VL@='EP90!&970`0F]K;65R:V5R`%)A;6UE`%)A;6UE='EK:V5L<V4Z`%)A
M;6UE<@!"96=G90!"=6YN`%!U;FMT;&ES=&4`0TU3`$-20P!#4DP@1&ES=')I
M8G5S:F]N<W!U;FMT97(`16=E;G-K87!E<B!F;W(@8U]E;&QE+BXN`$MA;&5N
M9&5R`%-T:6QL90!+86X@:6MK92!N=6QL<W1I;&QE('!A<W-O<F0@875T;VUA
M=&ES:RP@:V]N=&%K="!D:6X@861M:6YI<W1R871O<BX`2V%N(&EK:V4@:V]B
M;&4@=&EL($E-05`@=&IE;F5R96XZ("5S`$MA;F%D80!!=F)R>70`079B<GET
M('!R;V)L96UR87!P;W)T`$MA;B!I:VME('-L971T92!F:6QE;B`B)7,B+@!+
M86X@:6MK92!F:6YN92!E;B!T96UP+6MA=&%L;V<N`$MA;B!I:VME(&9O<G1S
M971T92!U=&5N("=T87)G971&:6QE)R!P87)A;65T97(N`$MA;B!I:VME('-L
M971T92!K871A;&]G96X@(B5S(BX`2V%N(&EK:V4@<VQE='1E+"`E9"!B87)N
M(&5K<VES=&5R97(N`$MA;B!I:VME(&5N9')E(')E:VME9OAL9V5N+"!A;G1A
M;&QE="!O<'!F^')I;F=E<B!V86QG="!F;W(@;VUS;W)T97)I;F<@<W1E;6UE
M<B!I:VME(&UE9"!A;G1A;&QE="!L86=R961E(&]P<&;X<FEN9V5R+@!+86X@
M:6MK92!S96YD92!M96QD:6YG96X@=&EL(&1E="!S<&5S:69I<V5R=&4@;G5M
M;65R970N`%5T9')A9P!+871E9V]R:65R(&]G(&5T:6ME='1E<@!-;V)I;'1E
M;&5F;VX`16=E;G-K87!E<B!F;W(@8V5L;&4`3'5F="!R=6YD="!I;FYH;VQD
M(&%V(&-E;&QE.@!%9V5N<VMA<&5R(&9O<B!C96QL90!,=69T(')U;F1T(&-E
M;&QE;CH`36]B:6QT96QE9F]N`%-E;G1E<@!$971A;&IE<B!F;W(@<V5R=&EF
M:6MA=`!2971T;FEN9W-L:6YJ97(@9F]R('-E<G1I9FEK870`3W)D<W1Y<F5R
M`$5N9')E`$5N9')E(&YA=FX@;V<@861R97-S92!S;VT@;6]T=&%K97)E('-E
M<B!NY7(@9&4@;&5S97(@;V<@<W9A<F5R('#E('!O<W1E;B!D:6XN`%1E9VX`
M4VIE:U]K(&QI;FLN+BX`5F5L9R!D92!O<&5R87-J;VYE;F4@9'4@=FEL('5T
M9OAR92!NY2X`5F5L9R!E='0@<&%S<V]R9`!696QG(&5T="!B<G5K97)N879N
M`%9E;&<@:&%N9&QI;F<Z`%9E;&<@:'9O<F1A;B!D=2!V:6P@=FES92!D871O
M97(Z`%9E;&<@<W1I;"!PY2!L:7-T971Y<&4@*&9O<B!N=6UM97)E<G1E(&QI
M<W1E<BD`2VQA<W-E9&5F:6YI<VIO;B!F;W(@)7,@8FQE(&EK:V4@9G5N;F5T
M+@!+;&%R=`!&:F5R;B!-4T]F9FEC92!T86=S`$9J97)N(&)R=6ME<CH@)7,`
M1FIE<FX@8G)U:V5R`$9J97)N(&)R=6ME<F1A=&$`2VQI:VL@9F]R(.4@9F]R
M='-E='1E`$-L:6-K871E;&P@=FEA($A45%``3'5K:R!V:6YD=0!3:WEE<@!3
M:WEE=`!3;.4@<V%M;65N('-I9&5L:6YJ96X`4V%M;65N<VSE='0@<F%M;64`
M1F%R9V4`1F%R9V5V96QG97(`1F%R9V5V86QG`$MO;&]N;F4M=&ET;&5R`%1E
M9VYE<V5R:65R`$MO;6UA;F1O`$MO;6UA;F1O=FEN9'4`5F%L9R!F;W(@:V]M
M;6%N9&\Z`$MO;6UA;F1O97(Z`$MO;6UE;G1A<@!3:F5K:R!I;FXZ`%9A;FQI
M9R!N879N`$9I<FUA`$9E<F1I9P!3:W)I=B!M96QD:6YG("@E<RD`1&%T86UA
M<VMI;F5R`%9I;&OE<@!&;W)S:VIE;&QE<B!I(&EN;G-T:6QL:6YG96YE`$EN
M;G-T:6QL:6YG97(@8F5H^'9E<B!O<'!D871E<FEN9RX`2V]N9FEG=7)E<B`E
M<P!"96MR969T('!A<W-O<F0`5&EL:V]B;&EN9R!M:7-L>6MT97,N`%1I;&MO
M8FQI;F<@;6ES;'EK=&5S.B``2V]B;&EN9V5N('1I;"!D96X@;V9F96YT;&EG
M92!N^&MK96QT:F5N97)E;B!F96EL970N`$MO8FQI;F=E;B!T:6P@9&5N(&]F
M9F5N=&QI9V4@;OAK:V5L=&IE;F5R96X@9F5I;&5T+B#%<G-A:SH@)7,@*"5S
M*0!+;V)L:6YG96X@=&EL($944"!T:F5N97)E;B!M:7-L>6MT97,N`$MO;G1A
M:W1E;F4@8FQE(&QA9W0@=&EL(&%D<F5S<V5B;VME;@!);FYH;VQD(&D@)R5S
M)P!&;W)T<V5T=`!#;V]K:64`2V]P:65R`$MO<&EE<B!V86QG="!O;7+E9&4`
M2V]P:65R97(@)7,@=&EL("5S`$MU;FYE(&EK:V4@4$=0+6MR>7!T97)E(&UE
M;&1I;F<`2W5N;F4@:6MK92!01U`M<VEG;F5R92!M96QD:6YG`$MU;FYE(&EK
M:V4@:W)Y<'1E<F4@;65L9&EN9V5N(&UE9"!3+TU)344N`$MU;FYE(&EK:V4@
M<VEG;F5R92!M96QD:6YG96X@;65D(%,O34E-12X`2W5N;F4@:6MK92!L96=G
M92!T:6P@:V]N=&%K=#H@)7,`5&EL:V]B;&EN9R!T:6P@3$1!4"US97)V97(@
M9F5I;&5T+@!+=6YN92!I:VME('-J96MK92!T:6QG:F5N9V5L:6<@:W)E9&ET
M="X@)7,`2VQA<G1E(&EK:V4@Y2!K;V)L92!T:6P@=&IE;F5R96X@)R5S)R!V
M960@8G)U:R!A=B!&5%`Z("5S`$MU;FYE(&EK:V4@:V]P:65R92`E<R!T:6P@
M)7,`2W5N;F4@:6MK92!L86=E(&1I<W1R:6)U<VIO;G-L:7-T92X@)7,`2W5N
M;F4@:6MK92!O<'!R971T92!L;V-A;&4@:V%T86QO9R!F;W(@;&]C86QE("5S
M.@!+=6YN92!I:VME(&1E:W)Y<'1E<F4@4$=0(&UE;&1I;F<N`$MU;FYE(&EK
M:V4@9&5K<GEP=&5R92!3+TU)344@;65L9&EN9RX`2VQA<G1E(&EK:V4@Y2!S
M;&5T=&4@:V]N=&%K="X@)7,`2VQA<G1E(&EK:V4@Y2!S;&5T=&4@9&ES=')I
M8G5S:F]N<VQI<W1E+B`E<P!+=6YN92!I:VME('-L971T92!S971U<"!O<'!G
M<F%D97)I;F=S<V-R:7!T("<E<R<N`$MU;FYE(&EK:V4@9FEN;F4@;6]T=&%K
M97)S(&4M<&]S="!A9')E<W-E+@!+=6YN92!I:VME(&AE;G1E('5T(&AE;&4@
M861R97-S96)O:V5N+@!+=6YN92!I:VME('5T(&AE;&4@9&ES=')I8G5S:F]N
M<VQI<W1E;BX`2W5N;F4@:6MK92!H96YT92!U="!H96QE(&QI<W1E;B!M960@
M9&ES=')I8G5S:F]N<VQI<W1E<BX`2W5N;F4@:6MK92!L87-T92!I;FX@<W1R
M871E9VD@)R5S)RX`2W5N;F4@:6MK92!O<'!R971T92!K871A;&]G96X@)R5S
M)RX`2W5N;F4@:6MK92!H96YT92!U="!O9F9E;G1L:6<@;OAK:V5L(&9R82!N
M^&MK96QT:F5N97)E;BX`2W5N;F4@:6MK92#E<&YE("5S+@!+=6YN92!I:VME
M(.5P;F4@)R5S)R!F;W(@<VMR:79I;F<N`$MA;B!I:VME(.5P;F4@36%I;G1E
M;F%N8V5?5&%S:RUM;V1U;&5N("5S`$MU;FYE(&EK:V4@Y7!N92!K871A;&]G
M96X@)R5S)RX`2W5N;F4@:6MK92!L97-E("5S`$MU;FYE(&EK:V4@;G5L;'-T
M:6QL92!P87-S;W)D970@9F]R(&1E;B!F;W)E<W!U<G1E(&)R=6ME<F5N+B!.
M;V5N(&5L;&5R(&%L;&4@9&5T86QJ96YE(&5R('5R:6MT:6=E+B!&;W)S^&L@
M:6=J96X@96QL97(@:V]N=&%K="!A9&UI;FES=')A=&]R96X@:'9I<R!D=2!T
M<F5N9V5R('ET=&5R;&EG97)E(&AJ96QP+@!+=6YN92!I:VME(&AE;G1E('5T
M($%#3`!+=6YN92!I:VME(&AE;G1E('5T(&%D<F5S<V5B;VLN("5S`$MU;FYE
M(&EK:V4@:&5N=&4@=70@9&ES=')I8G5S:F]N<VQI<W1E+B`E<P!+=6YN92!I
M:VME(&AE;G1E('5T(&1I<W1R:6)U<VIO;G-L:7-T92X@)7,`2W5N;F4@:6MK
M92!H96YT92!U="!I;F9O<FUA<VIO;B!O;2!T:F5N97)E;G,@9G5N:W-J;VYA
M;&ET971E<@!+=6YN92!I:VME(')E=F5R=&5R92!K;VYF:6=U<F%S:F]N96YE
M+@!+=6YN92!I:VME(&9J97)N92!K871A;&]G96X@)R5S)RX`2W5N;F4@:6MK
M92!L86=R92`E<R!K;VYF:6=U<F%S:F]N+@!+=6YN92!I:VME(&QA9W)E(&5N
M(&)A8VMU<"!K;VYF:6=U<F%S:F]N+@!+=6YN92!I:VME(&QA9W)E(&5N(&)A
M8VMU<"!C;VYF:6=U<F%S:F]N.B`E<P!+=6YN92!I:VME(&QA9W)E('-E='5P
M(&]P<&=R861E<FEN9W,M<V-R:7!T970@=&EL.B`G)7,G+@!+=6YN92!I:VME
M(&QA9W)E(&)A8VMU<"!K;VYF:6=U<F%S:F]N<V9I;&5N("5S+@!+=6YN92!I
M:VME(&QA9W)E(&MO;F9I9W5R87-J;VYS9FEL96X@)7,N($1U(&MA;B!E;G1E
M;B!B96YY='1E(&1E9R!A=B!E;B!A=B!M=6QI9VAE=&5N92!F;W(@Y2!L86=R
M92!D871A('1I;&)A:V4@=&EL("5S(&5L;&5R(&MO<&EE<F4@:V]D96X@=6YD
M97(@;6%N=65L="!T:6P@)7,N`$MU;FYE(&EK:V4@=71F^')E('/X:R!PY2!,
M1$%0('1J96YE<F5N+@!+=6YN92!I:VME(&9J97)N92`G)7,G+@!+=6YN92!I
M:VME(&]P<&1A=&5R92!K;VYT86MT+B`E<P!+=6YN92!I:VME(&]P<&1A=&5R
M92!D:7-T<FEB=7-J;VYS;&ES=&5N+B`E<P!+=6YN92!I:VME('-K<FEV92!K
M;VYF:6=U<F%S:F]N(&9O<B`G)7,G.B`E<P!+=6YN92!I:VME(&9I;FYE($UO
M>FEL;&$@4VED96)A<BX@4VIE:VL@870@9&5N(&5R(.5P96XN`$)R=6ME<F5N
M("<E<R<@8FQE(&=I='0@9OAL9V5N9&4@<F5T=&EG:&5T97(@=&EL(&UA<'!E
M;B`G)7,G.B`E<P!486QT('1E:W-T`$QA;F0`2W5R<V5R`$]P<')E='0`3W!P
M<F5T="!E;B!L:6YK`$]P<')E='0@96X@;GD`3W!P<F5T="!U;F1E<FUA<'!E
M<@!2971T:6=H971E<B!F;W(@96EE<@!+<F5D:71T:V]R=&YU;6UE<@!':F5L
M9&5N9&4@9F%S90!':F5L9&5N9&4@=&ED`$=J96QD96YD92!VYG(`1VIE;&1E
M;F1E('5T<VEK=&5R.B``1VIE;&1E;F1E('-T:6P`5&EL<&%S<R!O<'!G879E
M<B!S;VT@:VKX<F5S('9E9"!I;FYL;V=G:6YG('1I;"`E<RX`2VQI<'`@=70`
M2VQI<'`@=70@=F%L9W0@;VURY61E`$MY<')O<P!$1`!$86=L:6<`1&%T80!$
M871A5')E('5T9F]R<VME<@!$871O`$1A=&\@36]T=&%T=`!$871O('9A;&<`
M1&%G`%-L971T(&MO;&]N;F4`1&5S96UB97(`1&5S:6UA;'1A;&P`079S;.5T
M=`!2961U<V5R(&EN;G)Y:VL`4W1A;F1A<F0`4W1A;F1A<F0@9F%R9V4`4W1A
M;F1A<F1I9&5N=&ET970`4W1A;F1A<F0@<F5T=&EG:&5T97(`4W1A;F1A<F0@
M<F5T=&EG:&5T97(`1&5F:6YI<VIO;F5R`$1E;&5G97(@<&]S:7-J;VX`1&5L
M96=E<G0`4VQE='0`4VQE='0@9W)U<'!E`%-L971T(')E='1I9VAE=`!3;&5T
M="!O9R!F:F5R;B!M96QD:6YG97(`4VQE='0@8V5L;&4`4VQE='0@:V]L;VYN
M90!3;&5T="!E:W-I<W1E<F5N9&4@86QT97)N871I=B!M86P`1FIE<FX@<F5T
M=&EG:&5T96YE('1I;"`G)7,G`$9J97)N(')E='1I9VAE=&5N92!T:6P@)R5S
M)R!O9R!A;&QE('5N9&5R+7)E='1I9VAE=&5R/P!3;&5T="!R860`4VQE='0@
M=F%L9W0@:61E;G1I=&5T`%-L971T(&=J96QD96YD92!K;VQO;FYE`%-L971T
M(&=J96QD96YD92!R860`4VQE='1E(&1E;FYE(')E='1I9VAE=&5N(&]G(&%L
M;&4@=6YD97(M<F5T=&EG:&5T97(_`%-L971T('-E='5P(&]P<&=R861E<FEN
M9W,M<V-R:7!T("<E<R<N`$QE=F5R:6YG<W1I9`!$86YM87)K`$%V<VSE(&9O
M<F5S</AR<V5L`$%V<VSE(&9O<F5S</AR<V5L(&9O<B!L961I9R]O<'!T871T
M+6EN9F]R;6%S:F]N`$)E<VMR:78@<')O8FQE;65T`$)E<VMR:79E;'-E`$1E
M=&%L:F5R("AO9W/E(&D@2&]R9&4G<R!L;V=G9FEL*3H`1&5T86QJ97(@:&%R
M(&)L:71T(&QO9V=E="!F;W(@861M:6YI<W1R871O<F5N+@!5='9I:VQI;F<`
M1&]G9W!U;FMT`$1O9V=P=6YK="!F;W(@9&5N('-I<W1E('1I;65N.B``1&]G
M9W!U;FMT.B``4F5T;FEN9R!F<F$@=F5N<W1R92!M;W0@:/AY<F4`4F5T;FEN
M9R!F<F$@:/AY<F4@;6]T('9E;G-T<F4`2V%T86QO9P!6:7,@,C0M=&EM97)S
M('1I9&5R/P!6:7-N:6YG<W9A;&<`5FES(&9O<G9A<G-E;"`H5$%&*0!6:7-N
M:6YG<V9O<FUA=`!-96QD:6YG(&]M(&]R9&YI;F<`26MK92!S;&5T=`!):VME
M(.5P;F4@;6%I;F5N86YC92YP:'`@9&ER96MT90!+<GES<R!A=B!H97(@:'9I
M<R!D96X@9OAR<W1E(')A9&5N(&EN;F5H;VQD97(@9F5L="UN879N970Z`$QA
M<W0@;F5D`$QA<W0@;F5D(&=E;F5R97)T(&MO;F9I9W5R87-J;VX@<V]M(%!(
M4"!S8W)I<'0N`$YE9'1R96MK<VQI<W1E`$UE9&ES:6YE<@!%+7!O<W0`15)2
M`%)E9&EG97(`4F5D:6=E<F4@8FQO:VL`4F5D:6=E<B!'<G5P<&4`4F5D:6=E
M<B!R971T:6=H971E<@!2961I9V5R(')E='1I9VAT97(`4F5D:6=E<B!R971T
M:6=H971E<B!F;W(@)7,`4F5D:6=E<B!V86QG(&9O<CH`4F5D:6=E<B!R971T
M:6=H971E<B!F;W(@)7,`4F5D:6=E<B!R971T:6=H971E<B!F;W(@)7,`3W!P
M;.9R:6YG`$5L96UE;G0N+BX`16T`12UP;W-T`$4M<&]S=&%D<F5S<V4`12UP
M;W-T861R97-S92!MY2!S=&5M;64N`$4M<&]S="!M960@8F5K<F5F=&5L<V4`
M1OAL96QS97(`5&]M(&UE;&1I;F<N`%1O;70@<F5S=6QT870N`%3X;2!S^&ME
M:W)I=&5R:65R`$%K=&EV97(@;75L:6=H970@9F]R(.4@<V5T=&4@:6YN(&)I
M;&1E<B!F<F$@9V%L;&5R:65R(&D@=&5K<W1E;C\`06MT:79E<F4@:/AY<F5K
M;&EK:R!M96YY/P!3;'5T=`#%<G-S;'5T=`!':OAR(&5D:71O<F5N('-T^')R
M90!3:W)I=B!I;FX@971T('-I:VME<FAE='-S</AR<VWE;"!S;VT@9'4@=FEL
M(&)L:2!S<'5R="!O;2!H=FES(&1U(/AN<VME<B#E(&YU;&QS=&EL;&4@<&%S
M<V]R9&5T(&1I='0L(&8N96MS+B`G:'9A(&5R(&YA=FYE="!PY2!K:N9L961Y
M<F5T(&1I='0_)SH`4VMR:78@:6YN(&%D<F5S<V5N('1I;"!B:6QD970@:&5R
M`$9E:6P`1F5I;"!V960@<V5N9&EN9R!A=B!S=F%R.B`E<P!&96EL(&UE9"!E
M+7!O<W0@;65L9&EN9V5N+@!&96EL('9E9"!S:W)I=FEN9R!T:6P@)R5S)RX`
M1F5I;#H@`$5U<F]P80!(=F5R="`Q-2X@;6EN=71T`$AV97)T(#(N(&UI;G5T
M=`!(=F5R="`S,"X@<V5K=6YD`$AV97)T(#4N(&UI;G5T=`!(=F5R(&EN;FQO
M9V=I;F<`2'9E<B!H86QV=&EM90!(=F5R="!M:6YU='0`16MS96UP96QV97)D
M:65R.@!+:OAR`$MJ^')E<CH`571V:60`571V:60@4VED96)A<@!&;W)V96YT
M970@)RDG`$9O<G9E;G1E="!B;&%N:W0@;W)D(&5L;&5R('%U;W1E="!S^&ME
M:W)I=&5R:64`571L^'!S9&%T;P!%:W-P;VYE;G0`1F]R9W)U;FYS9F%R9V4`
M3W!P;&%S=&EN9R!A=B!S971U<"!V:6$@1E10`%5T:&5N=&EN9R!A=B!I;G-T
M:6QL:6YG97(@9F5I;&5T+@!4:6QK;V)L:6YG('1I;"!,1$%0+71J96YE<B!F
M96EL970N`%1I;&MO8FQI;F<@=&EL(%--0BUT:F5N97(@9F5I;&5T+@!&96EL
M970@=F5D(&MO<&EE<FEN9R!F<F$@(B5S(BX`1F5I;&5T('9E9"!K;W!I97)I
M;F<@=&EL("(E<R(N`$9E:6QE="!V960@;W!P<F5T=&5L<V4@878@;GD@4T%3
M3"!K;V)L:6YG+@!&96EL970@=F5D(&9L>71T:6YG('1I;"`B)7,B+@!096YT
M(';F<@!&871A;"!&96EL.B``1F%X`$9E8G)U87(`1OAL97,@<V]M`$;X;&5S
M('-O;3H@`$;E(&)Y9V5R`$;E('-N^&)Y9V5R`$9E;'1M871R:7-E`$%N=&%L
M;"!F:6QE<CH@)7,@9FEL97(`06YT86QL(&9I;&5R.B`E<R!F:6QE<@!&:6QB
M96AA;F1L97(`1FEL;F%V;@!&:6QV86QG`$QA<W0@;W!P(&9I;&5R`$]P<&QA
M<W1I;F<@878@9FEL97(@<W3X='1E<R!I:VME+@!&:6QT97(`1OAR<W1E(&AA
M;'9MY6YE`$;X<G-T92!K=F%R=&WE;F4`1F%S="!F;W)H;VQD`%-N=0!&;'ET
M`%3E:V4`36%P<&5N("5S(&5K<VES=&5R97(@:6MK90!&;VYT9F%R9V4`36%T
M`$9O<B!N971T;&5S97)E('-O;2!I:VME('-T^'1T97(@8FEL9&5R`$9O<G9A
M<G-E;"`H5$%&*0!!;G1A;&P@9&%G97)S(&9O<G9A<G-E;"`H=N9R(&]B<R!P
MY2!A="!D970@<F5T=7)N97)T92!F;W)V87)S;&5T(&EN;F5H;VQD97(@8N5D
M92!D86<@;V<@;F%T=#L@96X@<W1O<B!V97)D:2!H97(@:V%N(')E<W5L=&5R
M92!I(&5N('-T;W(@8FQO:VLI`$=L96UT('!A<W-O<F1E=#\`4VMJ96UA97(`
M4VMJ96)N92]L>6MK90!4>7!E('-K:F5B;F4O;'EK:V4`4VMJ96)N97(O;'EK
M:V4`4VMJ96)N97(O;'EK:V4@,@!&;W)U;65R`%9I9&5R97-E;F1T90!&86YT
M('!R;V=R86UM96YE.B`E<P!&86YT(&MA=&%L;V=E;F4Z`$9R`%)A;6UE<@!,
M961I9R]O<'!T871T+6EN9F]R;6%S:F]N`$QE9&EG+V]P<'1A='0@<W9A<@!,
M961I9R]O<'!T871T(&9O<F5S</AR<V5L`%-V87(@<.4@;&5D:6<O;W!P=&%T
M="!F;W)E<W#X<G-E;`!&<F$`1G)A(`!&=6QL(&)E<VMR:79E;'-E`$9U;&QM
MY6YE`$9U;&QT(&YA=FX`1V%L;&5R:2!D=2#X;G-K97(@Y2!H96YT92!B:6QD
M92!F<F$`1V%L;&5R:3H`1V5N97)E<B`E<R!K;VYF:6=U<F%S:F]N`$=E;F5R
M97)T(&MO9&4`1V5T;W!T($9E:6PZ(`!':71T($YA=FX`1V\`4_AK('#E($=O
M;V=L90!'<N5T;VYE`$AE;&QA<P!'<OAN;&%N9`!'<G5P<&4@861M:6YI<W1R
M87-J;VX`1W)U<'!E;F%V;B!K86X@:6MK92!VYG)E('1O;6UE`$=R=7!P97)E
M='1I9VAE=&5R`$=R=7!P97(`4F5T=&EG:&5T97(@9F]R(&=J97-T`%)E='1I
M9VAE=&5R(&9O<B!G:F5S=`!':F5S=&5B;VL`2$@`2%1-3`!(5$U,07)E82!N
M96MT97(@Y2!S;&5T=&4@9&5N('-I<W1E(&-E;&QE;B!I(&5N(')A9"X`2%1-
M3$%R96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S:7-T92!K;VQO;FYE;B!I('1A
M8F5L;&5N+@!(5$U,07)E82!N96MT97(@Y2!S;&5T=&4@9&5N('-I<W1E(')A
M9&5N(&D@=&%B96QL96XN`$A45%`@875T96YT:7-E<FEN9R!I:VME(&9U;FYE
M="X`2&%S:"UA;&=O<FET;64`1&ES`$AO9&4`2/AY9&4`2&IE;'``2&IE;'`@
M=&EL(&)R=6L@878@961I=&]R`$AJ96QP97(`2&%L=FMU;&4`2&5R(&5R(&)E
M9WEN;F5L<V5N('#E(&9I;&5N.@!(^'D`2&ES=&]R:65O<'!F^')I;F=E<B!P
MY2!H82!N879N('-O;2!I:VME(&5R('1O;6UE`$AJ95]M`$AJ96T`2&IE;6UE
M861R97-S90!496QE9F]N(&AJ96UM90!(;W)D90!(;W)D92]+;VQA8CH@56=Y
M;&1I9R`E<R!834P@9&%T82!F=6YN970@:2!M96QD:6YG("5S`$AO<F1E+TMO
M;&%B.B!);F=E;B!M96QD:6YG('!A<W-E<B!M960@;V)J96MT970@)7,`2&]R
M9&4O2V]L86(Z($EN=&5T(&]B:F5K="!A=B!T>7!E;B`E<R!F=6YN970@:2!M
M96QD:6YG("5S`$AO<F1E+TMO;&%B.B!&:F5R;F5T("5S("(E<R(`2&]R9&4O
M2V]L86(Z(%-Y;FMR;VYI<V5R=&4@)7,@(B5S(@!(;W)D92]+;VQA8CH@26YT
M96=R87-J;VYS;6]T;W)E;B!K<F5V97(@4$A0("=D;VUX;6PG('5T=FED96QS
M90!(;W)D92]+;VQA8CH@2W5N;F4@:6MK92!O<'!R971T92!N>71T(%A-3"!T
M<F4@9F]R(&]B:F5K=&5T("5S`$AO<F1E+TMO;&%B.B!+=6YN92!I:VME(&9J
M97)N92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@2W5N;F4@:6MK92!H96YT
M92!-24U%($E$(&9O<B!D96QE;B!A=B!T>7!E("5S`$AO<F1E+TMO;&%B.B!+
M=6YN92!I:VME('-Y;FMR;VYI<V5R92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@2W5N;F4@:6MK92!S>6YK<F]N:7-E<F4@9&5L=&4@<F5S<W5R<V5R.B`E
M<P!(;W)D92]+;VQA8CH@56MJ96YT(&1E;'0@<F5S<W5R<R`B)7,B`$AO<FES
M;VYT86P@;&EN:F4`2&]R:7-O;G1A;"!P861D:6YG`$AO<FES;VYT86PZ`$AV
M;W)D86X@:V]M(&1U(&AI=#\@*%9E;FYL:6=S="!R87!P;W)T97(A*0!(=F]R
M(&UA;F=E(&MO;&]N;F5R(/AN<VME<B!D=2#E('-LY2!S86UM96X_`$AV;W(@
M;6%N9V4@9F5L=&5R("AK;VQO;FYE<BD@97(@9&5T/P!(=F]R(&UA;F=E(')A
M9&5R(/AN<VME<B!D=2#E('-LY2!S86UM96X_`$9U:W1I9VAE=`!&=6MT:6=H
M970Z(`!(=6UO<FES=&5R`$]P<')E='1E;'-E(&%V($E-05`@<&]S=&)O:W,@
M9F5I;&5T.B`E<P!3;&5T=&EN9R!A=B!)34%0('!O<W1B;VMS96X@9F5I;&5T
M.B`E<P!/<'!R971T96QS92!A=B!K=F]T92!PY2!)34%0('!O<W1B;VMS(&9E
M:6QE=#H@)7,`25`@061R97-S90!)4"!!9')E<W-E(&EK:V4@=&EL9VIE;F=E
M;&EG+@!)4"!!9')E<W-E(&EK:V4@:6YN96YF;W(@=&EL871T92!#2412(&)L
M;VMK+@!"<G5D9"!PY2!)4"!L;V-K9&]W;BX`4U]E='0@:6YN(&YY(')A9"!F
M^'(`2W5N(&EK;VYE<@!):V]N97(@9F]R("5S`$EK;VYE<B!M960@=&5K<W0`
M261E;G1I=&5T96YS(&YA=FXZ`$AV:7,@9&5N(&EK:V4@=FES97,@<FEK=&EG
M+"`E<R!F;W(@Y2#E<&YE(&D@;GET="!V:6YD=2X`2'9I<R!D=2!I:VME('-E
M<B!N;V5N(&EK;VYE<B!NY7(@9'4@8F5N>71T97(@26YT97)N970@17AP;&]R
M97(L(&MA;B!D970@:&5N9&4@9'4@=')E;F=E<B#E(&MR>7-S92!A=B!D96YN
M92!B;VMS96X@9F]R(.4@<VMR=2!A=B!T<F%N<W!A<F5N="!03D<N`$AV:7,@
M9'4@<V5R(&1E;FYE(&UE;&1I;F=E;B!M96X@:6YT970@8FEL9&4L(&MA;B!D
M970@:&5N9&4@870@8FEL9&5T(&1U('9I;"!L87-T92!O<'`@:6MK92!K86X@
M=FES97,@:2!D:6X@;F5T=&QE<V5R+@!&;W)HY6YD<W9I<VYI;F<@878@8FEL
M9&4Z`$)I;&1E861R97-S90!":6QD96%D<F5S<V4Z`$)I;&1E(&9R82!G86QL
M97)I`$)I;&1E(&9R82!G86QL97)I.@!/<'!L87-T:6YG(&%V(&)I;&1E`$)I
M;&1E<@!);7!O<G1E<FEN9RP@<W1E9R`E9`!);7!O<G1E<G1E(&9E;'0Z("5S
M`$EM<&]R=&5R=&4@9F5L=#H`56YD97(@87)B96ED`%]3971T(&EN;B!R860@
M971T97(`1F5I;"!H86YD;&EN9W-K;V1E(&=I='0N`%5G>6QD:6<@8G)U:V5R
M;F%V;B!O9R]E;&QE<B!P87-S;W)D+@!&96EL(&)R=6ME<FYA=FX@96QL97(@
M86QT97)N871I=B!A9')E<W-E+B!696YN;&EG<W0@9F]R<_AK(&EG:F5N(&5L
M;&5R(&MO;G1A:W0@<WES=&5M861M:6YI<W1R871O<F5N(&1I;B!F;W(@>71T
M97)L:6=E<F5R92!H:F5L<"X`V&L@:6YN<GEK:P!);F1I=FED=65L;&4@8G)U
M:V5R90!);F9O`$EN9F]R;6%S:F]N`%-E='0@:6YN(&M?;VQO;FYE(&5T=&5R
M`%-E='0@:6YN(&)I;&1E`%-E='0@:6YN('1A8F5L;`!3971T(&EN;B!W96)L
M:6YK`%-E='0@:6YN(%]K;VQO;FYE(&;X<@!3971T(&EN;B!E;B!N>2!K;VQO
M;FYE(&5T=&5R(&1E;B!G:F5L9&5N9&4`4V5T="!I;FX@96X@;GD@:V]L;VYN
M92!F^'(@9&5N(&=J96QD96YD90!3971T(&EN;B!E;B!N>2!R860@971T97(@
M9&5N(&=J96QD96YD90!3971T(&EN;B!E;B!N>2!R860@9OAR(&1E;B!G:F5L
M9&5N9&4`4V5T="!I;FX@;&EN:F5S:VEF="!E='1E<B!D96X@9VIE;&1E;F1E
M(&YO9&5N`%-E='0@:6YN(&QI;FIE<VMI9G0@9OAR(&1E;B!G:F5L9&5N9&4@
M;F]D96X`4V5T="!I;FX@86QT97)N871I=B!M86P`4V5T="!I;FX@96X@92UP
M;W-T(&%D<F5S<V4@9'4@^&YS:V5R(.4@;6]T=&$@9&5T(&YY92!P87-S;W)D
M970@<.4Z`%-E='0@:6YN(&-E;&QE(&5T=&5R`%-E='0@:6YN(&-E;&QE(&5T
M=&5R`%-E='0@:6YN(&MO;&]N;F4@971T97(`4V5T="!I;FX@:V]L;VYN92!F
M^'(`4V5T="!I;FX@;65L9&EN9V5R`%-E='0@:6YN(&QI;FIE<VMI9G0@971T
M97(`4V5T="!I;FX@;&EN:F5S:VEF="!F^'(`4V5T="!I;FX@<F%D(&5T=&5R
M`%-E='0@:6YN(')A9"!F^'(`4V5T="!I;FX@9&5T('#E:W)E=F1E('-V87)E
M="!T:6P@9OAL9V5N9&4@<VEK:V5R:&5T<W-P^')S;>5L.@!3971T(&EN;B]R
M961I9V5R92!B:6QD90!3971T(&EN;B]R961I9V5R92!L:6YK`$EK:V4@;F]K
M(&MR961I='0@9F]R(.4@:W5N;F4@<V5N9&4@=&EL(&1I<W1R:6)U<VIO;G-L
M:7-T96XN`$EK:V4@;F]K(&MR961I='0N`$EN=&5G97(`56=Y;&1I9R!H86YD
M;&EN9R!V86QG="!F;W(@9&5N;F4@:V]M<&]N96YT96XN`%5G>6QD:6<@541(
M+B`H57-E<B!$871A($AE861E<BDN`%5G>6QD:6<@<')O9W)A;2X`56=Y;&1I
M9R!B871C:"!)1`!59WEL9&EG(&1A=&$@<V5N9'0N`%5G>6QD:6<@;6]T=&%K
M97(@861R97-S92X`56=Y;&1I9R!F:6QF;W)M870`56=Y;&1I9R!M96QD:6YG
M<W1Y<&4`56=Y;&1I9R!E;&QE<B!M86YG;&5N9&4@87!I7VED+@!59WEL9&EG
M(&5L;&5R(&UA;F=L96YD92!P87)A;65T97)E+@!59WEL9&EG92!R971T:6=H
M971E<BX`56=Y;&1I9R!P<F]T;VMO;&PN`%5G>6QD:6<@;6]T=&%K97(Z("<E
M<R<`56=Y;&1I9R!D96QT(&]B:F5K=`!59WEL9&EG(&MI;&1E861R97-S90!5
M9WEL9&EG('5N:6-O9&4@9&%T82X`26YN:&]L9`!)<V]L97)T92!T;W)D96XM
M<W1O<FUE<@!5=&=I=F5R`$MU<G-I=@!*86YU87(`2G5L:0!*=6YI`$IU<W1E
M<@!-:61T<W1I;&P`0F5H;VQD92!O<F=I;F%L/P!+97)B97)O<R!T:F5N97)E
M;B!A=G9I<W1E(&%U=&5N=&ES97)I;F=E;BX`2V5R;F5L($YY8F5G>6YN97)E
M`$[X:VME;&=E;F5R97)I;F<`3OAK:V5L(&9I;F=E<G!R:6YT`$[X:VME;"!L
M96YG9&4`3OAK:V5L('1Y<&4`3OAK:V5L8G)U:P!.^&MK96P@96MS:7-T97)E
M<B!A;&QE<F5D92!PY2!D96X@;V9F96YT;&EG92!N^&MK96QT:F5N97)E;BX`
M0F%R;@!5=%]S965N9&4`4W!RY6L`4VES=&4@:&%L=&EM90!3:7-T92!K=F%R
M=&5R`%-I<W1E(&]P<&1A=&5R:6YG.@!3:7-T92!I;FYL;V=G:6YG.B`E<P!3
M:7-T92!I;FYL;V=G:6YG.B`E<R!F<F$@)7,`4VES=&4@:6YN;&]G9VEN9SH@
M06QD<FD`3&]V`%5T<V5E;F1E`-AN<VME<R!I;F=E;B!R86UM97(@;&%R(&1U
M(&9E;'1E="!VYG)E('1O;70`5F5N<W1R90!696YS=')E(&AO9&4`5F5N<W1R
M92!V97)D:65R`$QE='0@9'5S:W)E9VX`3&5T="!R96=N`$QE='0@9F]R;6ED
M9&%G<W)E9VX`3&5T="!E='1E<FUI9&1A9W-R96=N`$QE='1E(')E9VYB>6=E
M<@!,971T(')E9VX@;65D('1O<F1E;@!,971T('-N^&9A;&P`3&5T=&4@<V[X
M8GEG97(`3&EM97)I8VL`3&EN:P!,:6YK('!E:V5R('1I;#H`3&EN:R!E+7!O
M<W0@861R97-S96X@=&EL("=S:W)I=B!N>2<M<VED92!V960@=FES;FEN9P!,
M:6YK97(`3&EN=7@@0V]O:VEE`$QI<W0@+2!B<G5K97)E;B!K86X@<V4@;6%P
M<&5N`$QI<W0@9&%T86)A<V5R`$5M;F5R(&D@2&IE;'``3&ES="!T86)E;&QE
M<@!,:7-T92UA<FMI=@!,:7-T96AJ96QP`$QI<W1E+4ED`$5I97(@878@;&ES
M=&4`3&ES=&4M<&]S=`!!8F)O;F5R('#E(&QI<W1E`%-T;W!P(&%B8F]N;F5M
M96YT('#E(&QI<W1E`$UU;&EG:&5T(&9O<B#E(&QI<W1E(&)R=6ME<F4@97(@
M9&5A:W1I=F5R="X`3&ET=&5R871U<@!,87-T97(@8FEB;&EO=&5K97(N+BX`
M3&%S=&5R+BXN`$QO:V%L('1I9#H`4W!RY6L@;V<@=&ED`$QO:V%S:F]N`$QO
M9V<@:6YN`$QO9V<@=70`26YN;&]G9VEN9W-O<'!G879E<@!,;V=I;B!F96EL
M970@9F]R9&D@8G)U:V5R;F%V;F5T(&5L;&5R('!A<W-O<F1E="!D=2!S:W)E
M=B!I;FX@=F%R(&9E:6PN`$QO9VEN(&9E:6QE="X`3&%N9R!T96MS=`!+:N9R
M;&EG:&5T`$QA=@!3;>4@9W)E<VME(&)O:W-T879E<@!3;>4@;&%T:6YS:V4@
M8F]K<W1A=F5R`$U-`$EN;F)O:W,`4V%M<W9A<F5N9&4@9F5L=`!-^'1E879L
M>7-N:6YG`$WX=&5I;F9O<FUA<VIO;@!-^'1E:6YN:V%L;&5L<V4`3?AT97-V
M87(`3?AT96]P<&1A=&5R:6YG`$9O<F5S^')S96P@;VT@;?AT96]P<&1A=&5R
M:6YG`$UE;GEM;V1U<SH`365L9&EN9P!-Y6YE9'1L:6<`9FQY='0@;F5D`&9L
M>71T(&]P<`!.879N`%1R96YG97(@:&%N9&QI;F<`06QD<FD`3GEH971E<@!.
M97-T90!.97-T92!S:61E`$YE:0!):VME(&1E;'1A9V5R`$EN9V5N`$YO=&%T
M97(`3V)S(0!/2P!+;VYT;W(`5F%L9V9R:2!D96QT86=E<@!686QG`$]R9V%N
M:7-E<FEN9P!!;FYE;B!I;F9O<FUA<VIO;@!087-S;W)D`%5T9OAR('9E9&QI
M:V5H;VQD<V]P97)A<VIO;F5R`%5T9OAR('9E9&QI:V5H;VQD<V]P97)A<VIO
M;F5R('9E9"!I;FYL;V=G:6YG/P!097)S;VYL:6<@:6YF;W)M87-J;VX`5&5L
M969O;@!696YN;&EG<W0@9VD@970@<V%M;65N9')A9R!A=B!P<F]B;&5M970N
M`%9E;FYL:7-T('-K<FEV(&EN;B!B<G5K97)N879N(&]G('!A<W-O<F0`5F5N
M;FQI9W-T('-E(&]V97(@9&5N(&;X;&=E;F1E(&EN9F]R;6%S:F]N96XL('9E
M;&<@<^4@96X@:&%N9&QI;F<@9G)A(&UE;GEE;B!N961E;G5N9&5R+@!696YN
M;&EG<W0@=F5L9R!E;B!H86YD;&EN9R!F<F$@;65N>65N(&YE9&5N=6YD97(N
M`$9O<FCE;F1S=FES;FEN9P!&;W)R:6=E('-I9&4`4')O8FQE;6)E<VMR:79E
M;'-E`$AU<VL@;&5D:6<O;W!P=&%T="UI;F9O<FUA<VIO;BX`1FIE<FX@<&%R
M`%-V87(@<V5N9'0N`%-V87(@870@;65L9&EN9V5N(&EK:V4@<W3X='1E<P!3
M=F%R(&UE9"!L961I9R]O<'!T871T(&9O<B!D92!N97-T92!T;R!MY6YE9&5N
M92X`4W9A<B!M960@9&5N(&9O<F5S<'5R=&4@;&5D:6<O;W!P=&%T="UI;F9O
M<FUA<VIO;F5N+@!/8FQI9V%T;W)I<VL@9&5L=&%G97(`3G5L;'-T:6QL`%1I
M;&)A:V4@=&EL(%9A;&<`4F]L;&4`3&%G<F4@<V]M`$QA9W)E(%9A;&<`4_AK
M`%9E;&<@96X@9&%T;P!696QG(&1A=&]S:VEL;&5T96=N.@!696QG(&1A=&]F
M;W)M870`5F5L9R!T:61S9F]R;6%T.@!696QG('1O('-A;7-V87)E;F1E(&9E
M;'0N`%9E;&<@^&YS:V5T('-P<N5K.@!396YD('-I<W1E(&EN9F]R;6%S:F]N
M`%-E;F0@<')O8FQE;7)A<'!O<G0`4F5G:7-T<F5R(&1E9R!O;2!I:VME(')E
M9VES=')E<G0`4W3X<G)E;'-E`$AO<'`@;W9E<B!V961L:6ME:&]L9`!3<&5S
M:6%L=&5G;FEN;G1A<W1I;F<`4W1A<G0`4W1A='5S`$5M;F4`4V5N9`!3=6MS
M97-S`%-A;6UE;F1R86<`3W!P9V%V97(`1V]D=&$@9F]R97-P^')S96P@9F]R
M96SX<&EG`$=O9'1A(&9O<F5L^'!I9P!+=6X@=&5K<W0`2V%L96YD97)D871A
M(&5R('5G>6QD:6<`2&%N9&QI;F=E;B!H87(@8FQI='0@;&%G="!T:6P@9&EN
M(&QI<W1E(&]V97(@:&%N9&QI;F=E<BX`0G)U:V5R96YS(&QE9&EG+V]P<'1A
M='0@:6YF;W)M87-J;VX@8FQE(&QA9W)E="X`1&5T(&]P<'-T;V0@96X@9F5I
M;"!U;F1E<B!F;W)S^&L@<.4@Y2!V:7-E(&1E;FYE(&UE;&1I;F=S9&5L96X`
M1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!I;7!O<G1E<FEN9R!A=B!H96YD
M96QS96XZ("5S+@!$970@;W!P<W1O9"!E;B!F96EL('9E9"!I;7!O<G1E<FEN
M9R!A=B!H96YD96QS96XZ("5S+@!$970@;W!P<W1O9"!E;B!F96EL('9E9"!I
M;7!O<G1E<FEN9R!A=B!B<G5K97)E;G,@;&5D:6<O;W!P=&%T="UI;F9O<FUA
M<VIO;CH@)7,`1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!S=&]T
M=&5T+@!$96X@9F]R97-P=7)T92!O<'!G879E;B!E<B!I:VME(&EM<&QE;65N
M=&5R="X`1&5T=&4@=&%L;&5T(&WE(';F<F4@;6EN<W0@,2X`1&5T=&4@;>4@
M=N9R92!E="!T86QL+@!4:71T96P`5&EL`%523`!+86X@:6MK92!K;V)L92!T
M:6P@4U%,<V5R=F5R96XN`$MA;B!I:VME(&]V97)S971T92!D971T92!7;W)D
M+61O:W5M96YT970`06YG<F4@96YD<FEN9V5R`%5HY6YD=&5R="!K;VUP;VYE
M;G0@878@='EP96XZ("5S`%5T96X@;F%V;@!/<'!D871E<B!S=&%T=7,@<.4@
M879S96YD97)E`$QA<W0@;W!P`$QA9W)E(%9A;&<`0G)U:V5R;F%V;@!"<G5K
M97)N879N.@!6:7,@)7,`5FES(&AE;F1E;'-E`%9I<R!H86YD;&EN9V5R`$%D
M=F%R<V5L`%5K96YT;&EG`%9E;&MO;6UE;B!T:6P@)7,`5F5L:V]M;65N+"`E
M<P!&:7)M86%D<F5S<V4`1FER;6%T96QE9F]N`.7E`.5R;&EG`$IA`$1U(&WE
M(&)E<VMR:79E('!R;V)L96UE="!F^'(@9'4@:V%N('-E;F1E(&5N('!R;V)L
M96UR87!P;W)T+@!$:6X@)7,@=&EL:V]B:6YG(&AA<B!GY71T('5T+B!696YN
M;&EG<W0@;&]G(&EN;B!I9VIE;BX`1&EN(&EN9F]R;6%S:F]N`$9U;&QT(&YA
M=FX`3F5T=&QE<V5R96X@9&EN('-T^'1T97(@:6MK92!D96YN92!U='-K:69T
M<V]P97)A<VIO;F5N+B!4<GEK:R!+;VYT<F]L;"]/<'-J;VX@*R!0(&9O<B#E
M('-K<FEV92!U="X`1&EN92!V86QG(&AA<B!B;&ET="!O<'!D871E<G0`6U!R
M;V)L96UR87!P;W)T70!;;&EN:F4@)7,@878@)7-=`$AJ96QP`$QO9V<@=70`
M5F%L9P!N879N`'9#87)D````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYB7TY/+VAE;'`N>&UL
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q
M,#4Q-30S,3`V,@`P,C`S,3``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO
M<F1E.B!H;W)D92]L;V-A;&4O;F)?3D\O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P
M-2\R-R`R,#HR,CHQ-"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A
M9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E
M<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF
M;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY
M(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8
M+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@
M>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE
M=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM
M87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@
M9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S
M<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@
M971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@
M<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B
M=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET
M96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@
M87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET
M;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP
M87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@
M:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N
M('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@
M86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P
M;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@
M8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E
M(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I
M;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@
M=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N;%].3"\`````````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-C(`,#$V-C4R`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYL
M7TY,+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,C`T,S<`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O;FQ?3DPO3$-?34534T%'15,O:&]R9&4N;6\`````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#$U,#`W`#$P-3$U-#,Q,#8R`#`R,C$P
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````(D'```<````9#P``!,*``"L>````````/B@```.````^:````\`
M```(H0``#0```!BA```(````)J$```L````OH0``#````#NA```$````2*$`
M`!@```!-H0``&P```&:A```M````@J$``!T```"PH0``)````,ZA```I````
M\Z$``!D````=H@``)@```#>B```,````7J(``"0```!KH@``#P```)"B```+
M````H*(```X```"LH@``!0```+NB```H````P:(```@```#JH@``"@```/.B
M```5````_J(``!(````4HP``"P```">C``"%````,Z,```X```"YHP``"@``
M`,BC```-````TZ,```X```#AHP``$0```/"C```-`````J0```P````0I```
M#0```!VD```&````*Z0``)0````RI```"@```,>D```/````TJ0``!@```#B
MI```#````/ND```.````"*4```X````7I0``"````":E```)````+Z4``"X`
M```YI0``&@```&BE```R````@Z4``#@```"VI0``5````.^E``!1````1*8`
M`%H```"6I@``5P```/&F```T````2:<```D```!^IP``#0```(BG```'````
MEJ<```H```">IP``#P```*FG```%````N:<```8```"_IP``$0```,:G```(
M````V*<```D```#AIP``"0```.NG```E````]:<``"`````;J```$P```#RH
M```0````4*@```\```!AJ```"@```'&H```#````?*@```\```"`J```%```
M`)"H```)````I:@```T```"OJ```$@```+VH```9````T*@``!X```#JJ```
M#P````FI```*````&:D```\````DJ0``"````#2I```D````/:D``!0```!B
MJ0``%@```'>I```(````CJD``$X```"7J0``+0```.:I```9````%*H```<`
M```NJ@``#````#:J```L````0ZH```X```!PJ@```P```'^J```+````@ZH`
M``<```"/J@``!P```)>J```%````GZH```4```"EJ@``"@```*NJ```#````
MMJH``!<```"ZJ@``"@```-*J```/````W:H```X```#MJ@``&````/RJ```C
M````%:L```X````YJP``%````$BK```7````7:L``!<```!UJP``%P```(VK
M```3````I:L```\```"YJP``#@```,FK```?````V*L``!T```#XJP``!P``
M`!:L```&````'JP```@````EK```#P```"ZL```&````/JP```H```!%K```
M$P```%"L```+````9*P``!````!PK```%0```(&L```5````EZP```<```"M
MK```$````+6L```%````QJP``!4```#,K```$0```.*L```,````]*P``#L`
M```!K0``.````#VM```)````=JT```<```"`K0``%````(BM```#````G:T`
M``4```"AK0``$````*>M```)````N*T``!,```#"K0``.0```-:M```2````
M$*X``"<````CK@``+````$NN```J````>*X``"4```"CK@``"@```,FN```&
M````U*X```D```#;K@``!P```.6N```O````[:X``#<````=KP``+@```%6O
M``!5````A*\``"T```#:KP``+0````BP```]````-K```#\```!TL```+0``
M`+2P``!`````XK```",````CL0``(P```$>Q``!`````:[$``"T```"LL0``
M,P```-JQ```E````#K(``!4````TL@``&0```$JR```I````9+(``"0```".
ML@``*````+.R```1````W+(```H```#NL@``#````/FR```*````!K,``!``
M```1LP``%@```"*S```6````.;,```<```!0LP``!P```%BS```4````8+,`
M``H```!ULP``"````("S```G````B;,```@```"QLP``!P```+JS```'````
MPK,```8```#*LP``!0```-&S```'````U[,```8```#?LP``"````.:S```I
M````[[,```X````9M```"@```"BT```$````,[0```<````XM```"0```$"T
M```&````2K0``!$```!1M```!P```&.T```6````:[0```0```""M```"```
M`(>T```&````D+0```T```"7M```!@```*6T```>````K+0``!$```#+M```
M"````-VT```-````YK0```P```#TM```!P````&U```#````";4```,````-
MM0``%P```!&U```3````*;4``!T````]M0``"````%NU```$````9+4```@`
M``!IM0``"````'*U``!!````>[4``!H```"]M0``*P```-BU```@````!+8`
M`!4````EM@``!@```#NV```&````0K8``!4```!)M@``&````%^V```B````
M>+8``"X```";M@``'0```,JV```A````Z+8``%0````*MP``*0```%^W```*
M````B;<```<```"4MP``!P```)RW```5````I+<```X```"ZMP``"@```,FW
M```/````U+<```T```#DMP``#P```/*W```-`````K@```D````0N```%```
M`!JX```&````+[@``!@````VN```'0```$^X```3````;;@``!$```"!N```
M%````).X```$````J+@```8```"MN```%````+2X``!4````R;@``&0````>
MN0``!````(.Y```.````B+D```4```"7N0``!0```)VY```;````H[D``!H`
M``"_N0``$P```-JY```1````[KD``!$`````N@``'````!*Z```J````+[H`
M`!````!:N@``(0```&NZ```%````C;H``!,```"3N@``"P```*>Z```2````
ML[H```H```#&N@``#P```-&Z```-````X;H``!$```#ON@``$P````&[```,
M````%;L```8````BNP``#````"F[```&````-KL``!<````]NP``$````%6[
M```1````9KL```@```!XNP``!0```(&[```,````A[L``!````"4NP``!0``
M`*6[```-````J[L```8```"YNP``!P```,"[```-````R+L```<```#6NP``
M"P```-Z[```'````ZKL```<```#RNP``"0```/J[```)````!+P```H````.
MO```&0```!F\```]````,[P``!T```!QO```#````(^\```0````G+P```4`
M``"MO```)0```+.\```2````V;P``!,```#LO```*P````"]```[````++T`
M`"````!HO0``"````(F]```V````DKT``"$```#)O0``$````.N]```(````
M_+T```P````%O@``!@```!*^```$````&;X```\````>O@``#@```"Z^```'
M````/;X```H```!%O@``#0```%"^```?````7KX``!P```!^O@``(0```)N^
M```>````O;X``!D```#<O@``'@```/:^```;````%;\``"$````QOP``+@``
M`%._```F````@K\``!P```"IOP``'@```,:_```<````Y;\``"8````"P```
M*P```"G````S````5<```"8```")P```*P```+#````X````W,```!T````5
MP0``%0```#/!```O````2<$``"````!YP0``$@```)K!```I````K<$``!X`
M``#7P0``(````/;!```2````%\(``*(````JP@``%@```,W"```C````Y,(`
M`"@````(PP``*0```#'#```H````6\,``!\```"$PP``%0```*3#```@````
MNL,``"4```#;PP``*`````'$```M````*L0``#````!8Q```D@```(G$```A
M````',4``!8````^Q0``'````%7%```F````<L4``"H```"9Q0``00```,3%
M``!$````!L8```P```!+Q@``!P```%C&```'````8,8```8```!HQ@``#0``
M`&_&```0````?<8``!(```".Q@``$P```*'&```2````M<8```<```#(Q@``
M!````-#&```0````U<8``!````#FQ@``#````/?&```.````!,<```T````3
MQP``#P```"''```3````,<<```T```!%QP``*````%/'```#````?,<```T`
M``"`QP``!@```(['```1````E<<``!<```"GQP``&P```+_'```.````V\<`
M``(```#JQP``20```.W'```%````-\@``!`````]R```#P```$[(```$````
M7L@```T```!CR```#@```''(```#````@,@```X```"$R```"````)/(```/
M````G,@```\```"LR```!P```+S(```-````Q,@``!````#2R```#0```./(
M```+````\<@```8```#]R```"P````3)```,````$,D```H````=R0``$0``
M`"C)```9````.LD```L```!4R0``#0```&#)```B````;LD```\```"1R0``
M&P```*')```T````O<D```H```#RR0``&````/W)```2````%LH``!D````I
MR@``%@```$/*```B````6LH```T```!]R@``!P```(O*```4````D\H```L`
M``"HR@``(@```+3*```O````U\H```L````'RP``"0```!/+```9````'<L`
M``L````WRP``%P```$/+```7````6\L```D```!SRP``%@```'W+```/````
ME,L``!D```"DRP``%@```+[+```.````U<L``!@```#DRP``"````/W+```-
M````!LP``"8````4S```0P```#O,```(````?\P``!(```"(S```'P```)O,
M```(````N\P```L```#$S```+P```-#,```.`````,T```4````/S0``!@``
M`!7-``!%````',T```,```!BS0``!P```&;-```$````;LT```H```!SS0``
M"@```'[-```/````B<T``!````"9S0``%P```*K-```1````PLT``!D```#4
MS0``%P```.[-```)````!LX```4````0S@``"P```!;.```*````(LX```(`
M```MS@``!0```##.```-````-LX``!L```!$S@``%P```&#.```4````>,X`
M``D```"-S@``#@```)?.```-````ILX``!(```"TS@``.````,?.```@````
M`,\```@````ASP``#@```"K/``![````.<\``!@```"USP``&````,[/```1
M````Y\\```<```#YSP``!0````'0```8````!]```!X````@T```&P```#_0
M```9````6]```!L```!UT```&0```)'0```3````J]````<```"_T```"```
M`,?0```&````T-````8```#7T```$````-[0```/````[]```!````#_T```
M#P```!#1```+````(-$```\````LT0``#````#S1```/````2=$```<```!9
MT0``!@```&'1```.````:-$```P```!WT0``*````(31```/````K=$```@`
M``"]T0``"````,;1```3````S]$``!X```#CT0``(0````+2```@````)-(`
M`!D```!%T@``%P```%_2```E````=](``!<```"=T@``%@```+72```$````
MS-(``!L```#1T@``#0```.W2```,````^](```,````(TP``!0````S3```(
M````$M,```H````;TP``#````";3```+````,],``!`````_TP``#````%#3
M```.````7=,```L```!LTP``!````'C3```$````?=,``!,```""TP``%```
M`);3```,````J],```D```"XTP``#@```,+3```+````T=,``!L```#=TP``
M!P```/G3```'`````=0```H````)U```#0```!34```)````(M0```0````L
MU```!0```#'4```#````-]0``!@````[U```"@```%34```$````7]0``"8`
M``!DU```#@```(O4``!\````FM0``!4````7U0``!0```"W5```'````,]4`
M``P````[U0``"````$C5```*````4=4```8```!<U0``"````&/5```"````
M;-4```8```!OU0``!@```';5```4````?=4```T```"2U0``$````*#5```;
M````L=4```0```#-U0``"0```-+5```0````W-4```D```#MU0``"0```/?5
M```%`````=8``!H````'U@``"````"+6```&````*]8``!D````RU@``#@``
M`$S6```'````6]8```<```!CU@``!0```&O6```)````<=8```H```![U@``
M#@```(;6```"````E=8```8```"8U@``"P```)_6```-````J]8```D```"Y
MU@``!@```,/6```2````RM8```D```#=U@``!P```.?6```4````[]8``!T`
M```$UP``0@```"+7```E````9=<``"4```"+UP``!@```+'7```*````N-<`
M``0```##UP``"0```,C7```(````TM<``!$```#;UP``"0```.W7```&````
M]]<```T```#^UP``!@````S8```$````$]@``#D````8V```/0```%+8```Z
M````D-@``!X```#+V```!0```.K8```.````\-@```0```#_V```!@````39
M```'````"]D``"$````3V0``#0```#79```5````0]D```8```!9V0``!```
M`&#9```1````9=D```8```!WV0``"@```'[9```B````B=D```0```"LV0``
M!0```+'9```=````M]D```0```#5V0``#````-K9```.````Y]D```H```#V
MV0``"`````':```)````"MH```4````4V@``.@```!K:```P````5=H``#4`
M``"&V@``*0```+S:``!'````YMH``#@````NVP``*0```&?;```_````D=L`
M`"X```#1VP``+0````#<```?````+MP```\```!.W```$@```%[<```+````
M<=P``"8```!]W```*0```*3<```D````SMP``"8```#SW```"````!K=```*
M````(]T```D````NW0``!P```#C=```@````0-T``"````!AW0``)@```(+=
M```*````J=T``!D```"TW0``*0```,[=```6````^-T``!(````/W@``!P``
M`"+>```*````*MX```P````UW@``#P```$+>```0````4MX``$````!CW@``
M<````*3>``!F````%=\```X```!\WP``"0```(O?```*````E=\``!(```"@
MWP``$P```+/?```,````Q]\```8```#4WP``#P```-O?```2````Z]\``!``
M``#^WP``$0````_@```<````(>```",````^X```:@```&+@```/````S>``
M``4```#=X```$````./@```)````].````0```#^X```"P````/A```@````
M#^$``!0````PX0``#````$7A```,````4N$```\```!?X0``%0```&_A```I
M````A>$``"H```"OX0``)@```-KA```G`````>(``"D````IX@``*@```%/B
M```9````?N(``$(```"8X@``$0```-OB```2````[>(``!,`````XP``%```
M`!3C```/````*>,``!8````YXP``%P```%#C```0````:.,``!$```!YXP``
M-````(OC```3````P.,``!(```#4XP``-0```.?C```4````'>0```<````R
MY```#````#KD```@````1^0``!````!HY```%````'GD```1````CN0``!<`
M``"@Y```'````+CD```3````U>0``!0```#IY```&@```/[D```1````&>4`
M`!H````KY0``'@```$;E```:````9>4``!,```"`Y0``%0```)3E```1````
MJN4``!<```"\Y0``%````-3E```7````Z>4``!4````!Y@``"0```!?F```0
M````(>8``!D````RY@``!````$SF```'````4>8```L```!9Y@``$0```&7F
M```&````=^8```8```!^Y@``!@```(7F```%````C.8```<```"2Y@``!P``
M`)KF```%````HN8``!8```"HY@``!@```+_F```&````QN8```0```#-Y@``
M!````-+F```'````U^8```X```#?Y@``#````.[F```,````^^8```T````(
MYP``"@```!;G```.````(><```4````PYP``*````#;G```.````7^<```P`
M``!NYP``#P```'OG```*````B^<```@```"6YP``"0```)_G```K````J><`
M``0```#5YP``"````-KG```F````X^<``!(````*Z```#P```!WH```&````
M+>@```H````TZ```!P```#_H```(````1^@``"````!0Z```"0```''H```4
M````>^@```P```"0Z```#0```)WH```.````J^@``!8```"ZZ```$0```-'H
M```&````X^@```,```#JZ```!@```.[H```9````]>@```<````/Z0``!```
M`!?I```+````'.D```L````HZ0``!P```#3I```%````/.D```<```!"Z0``
M%@```$KI```-````8>D```T```!OZ0``"@```'WI```0````B.D```\```"9
MZ0``$0```*GI```7````N^D```H```#3Z0``$0```-[I```(````\.D```0`
M``#YZ0``#P```/[I```Z````#NH```4```!)Z@``#````$_J```>````7.H`
M``X```![Z@``$````(KJ```+````F^H```P```"GZ@``"0```+3J```'````
MONH```H```#&Z@``"0```-'J```.````V^H``!````#JZ@``&P```/OJ```8
M````%^L``!H````PZP``"@```$OK```)````5NL```H```!@ZP``#````&OK
M```/````>.L```@```"(ZP``!@```)'K```<````F.L```<```"UZP``!0``
M`+WK```+````P^L``$<```#/ZP``#0```!?L```)````)>P```0````O[```
M`P```#3L```3````..P``!,```!,[```$P```&#L```*````=.P```(```!_
M[```!````(+L```E````A^P```,```"M[```!0```+'L```J````M^P```H`
M``#B[```!0```.WL```$````\^P```H```#X[```#0````/M```&````$>T`
M``@````8[0``"````"'M```$````*NT```4````O[0``:````#7M```)````
MGNT```P```"H[0``$````+7M```%````QNT```8```#,[0``&P```-/M```O
M````[^T``!`````?[@``"@```##N```/````.^X```H```!+[@``"0```%;N
M```3````8.X``!L```!T[@``&````)#N```7````J>X``!\```#![@``#@``
M`.'N```#````\.X```<```#T[@``"````/SN```'````!>\```H````-[P``
M"P```!CO```'````).\``%$````L[P``$````'[O```,````C^\```T```"<
M[P``&@```*KO``!*````Q>\``!D````0\```!@```"KP```:````,?```"4`
M``!,\```!@```'+P```&````>?```!\```"`\```!@```*#P```)````I_``
M`!@```"Q\```%P```,KP```H````XO````8````+\0``#0```!+Q```B````
M(/$``%<```!#\0``$P```)OQ```C````K_$``!,```#3\0```@```.?Q```+
M````ZO$```@```#V\0``#0```/_Q```*````#?(```<````8\@``%````"#R
M```&````-?(```@````\\@``#@```$7R```'````5/(```H```!<\@``"P``
M`&?R```R````<_(```<```"F\@``#````*[R```-````N_(``!<```#)\@``
M#````.'R```)````[O(```D```#X\@``"@````+S```'````#?,```D````5
M\P``!P```!_S```*````)_,``!L````R\P``#P```$[S```2````7O,```H`
M``!Q\P``%@```'SS```)````D_,``!````"=\P``!P```*[S```2````MO,`
M``0```#)\P``!P```,[S```%````UO,```4```#<\P``"P```.+S```4````
M[O,``!$````#]```&@```!7T```6````,/0``!0```!']```%P```%ST```8
M````=/0``!P```"-]```&0```*KT```'````Q/0```4```#,]```#0```-+T
M```,````X/0```@```#M]```%P```/;T```+````#O4```P````:]0``'P``
M`"?U```:````1_4``!,```!B]0``!````';U```*````>_4```0```"&]0``
M#0```(OU```,````F?4```4```"F]0``"0```*SU```%````MO4```<```"\
M]0``!0```,3U```$````RO4```(```#/]0``.````-+U```L````"_8``!(`
M```X]@``*0```$OV```R````=?8```H```"H]@``+````+/V```N````X/8`
M`#,````/]P``,P```$/W```X````=_<```\```"P]P``&````,#W```0````
MV?<```\```#J]P``$P```/KW```5````#O@``!0````D^```$@```#GX```4
M````3/@``!4```!A^```+0```'?X```M````I?@``#$```#3^```+@````7Y
M```O````-/D``"P```!D^0``8@```)'Y```3````]/D```T````(^@``"```
M`!;Z```7````'_H```@````W^@``#````$#Z```K````3?H``"$```!Y^@``
M&@```)OZ```)````MOH``$4```#`^@``00````;[```$````2/L``!,```!-
M^P``%````&'[```.````=OL``!,```"%^P``&````)G[```&````LOL```D`
M``"Y^P``"@```,/[```/````SOL``!````#>^P``!P```._[```.````]_L`
M``4````&_```&P````S\```(````*/P```8````Q_```%````#C\```1````
M3?P```X```!?_```.````&[\```"````I_P```8```"J_```#@```+'\```%
M````P/P```<```#&_```#@```,[\```&````W?P``"@```#D_```#`````W]
M```<````&OT```0````W_0``*0```#S]```7````9OT``!\```!^_0``7```
M`)[]```4````^_T``#X````0_@``'P```$_^```0````;_X```<```"`_@``
M#@```(C^```,````E_X```P```"D_@``$P```+'^```*````Q?X``!T```#0
M_@``&0```.[^```%````"/\``!$````._P``$0```"#_```D````,O\``!(`
M``!7_P``%0```&K_```2````@/\```X```"3_P``&0```*+_```(````O/\`
M``D```#%_P``#0```,__```'````W?\```H```#E_P``!P```/#_```/````
M^/\```8````(``$`"P````\``0`:````&P`!``H````V``$`!P```$$``0`(
M````20`!``4```!2``$`'P```%@``0`&````>``!`!````!_``$`"````)``
M`0`-````F0`!``@```"G``$`'@```+```0`2````SP`!`"P```#B``$`&@``
M``\!`0`)````*@$!``H````T`0$`%0```#\!`0`%````50$!`!0```!;`0$`
M!````'`!`0`0````=0$!``8```"&`0$`!P```(T!`0`>````E0$!`"@```"T
M`0$`"@```-T!`0`<````Z`$!`!$````%`@$`"P```!<"`0`:````(P(!`!0`
M```^`@$`!````%,"`0`$````6`(!``L```!=`@$`!0```&D"`0`&````;P(!
M``@```!V`@$`!@```'\"`0`*````A@(!`!L```"1`@$`-````*T"`0`T````
MX@(!`"`````7`P$`*0```#@#`0`@````8@,!`$$```"#`P$`&@```,4#`0`H
M````X`,!`"D````)!`$`4````#,$`0`B````A`0!``8```"G!`$`"````*X$
M`0`%````MP0!``@```"]!`$`&0```,8$`0`9````X`0!`"H```#Z!`$`(P``
M`"4%`0`9````204!`"X```!C!0$`-````)(%`0`(````QP4!`!<```#0!0$`
M"@```.@%`0`'````\P4!`"$```#[!0$`$````!T&`0`.````+@8!``L````]
M!@$`!P```$D&`0`3````408!``@```!E!@$`"P```&X&`0`*````>@8!`!0`
M``"%!@$`#P```)H&`0`R````J@8!``L```#=!@$`#@```.D&`0`%````^`8!
M``4```#^!@$`!0````0'`0`7````"@<!``\````B!P$`!````#('`0`*````
M-P<!``D```!"!P$`"P```$P'`0`-````6`<!``P```!F!P$`#@```','`0`%
M````@@<!``0```"(!P$`#0```(T'`0`R````FP<!`$4```#.!P$`%P```!0(
M`0`'````+`@!`!X````T"`$`%````%,(`0`%````:`@!`!0```!N"`$`!@``
M`(,(`0`'````B@@!``X```"2"`$`*@```*$(`0`&````S`@!``P```#3"`$`
M#0```.`(`0`1````[@@!``L`````"0$`-@````P)`0`*````0PD!`"(```!.
M"0$`"P```'$)`0`/````?0D!`#(```"-"0$`)0```,`)`0`P````Y@D!`#$`
M```7"@$`+0```$D*`0`.````=PH!``4```"&"@$`#@```(P*`0`3````FPH!
M`!(```"O"@$`!P```,(*`0`1````R@H!`!,```#<"@$`!P```/`*`0`4````
M^`H!`!@````-"P$`!P```"8+`0`%````+@L!``P````T"P$`#````$$+`0`2
M````3@L!``0```!A"P$`!P```&8+`0`*````;@L!``L```!Y"P$`#````(4+
M`0`.````D@L!``X```"A"P$`!0```+`+`0`%````M@L!`"X```"\"P$`)@``
M`.L+`0`C````$@P!``,````V#`$`$@```#H,`0`&````30P!`!X```!4#`$`
M&````',,`0`E````C`P!``T```"R#`$`"0```,`,`0`?````R@P!``,```#J
M#`$`!P```.X,`0`*````]@P!``(````!#0$`#`````0-`0`5````$0T!``L`
M```G#0$`&0```#,-`0`@````30T!`!(```!N#0$`!0```($-`0`*````APT!
M`!4```"2#0$`$@```*@-`0`,````NPT!``0```#(#0$`"0```,T-`0`'````
MUPT!``P```#?#0$`4@```.P-`0`7````/PX!`"0```!7#@$`$@```'P.`0`'
M````CPX!``8```"7#@$`#@```)X.`0`,````K0X!``T```"Z#@$`%0```,@.
M`0`2````W@X!``\```#Q#@$`%`````$/`0`*````%@\!`!L````A#P$`$```
M`#T/`0`+````3@\!`&D```!:#P$`&@```,0/`0`7````WP\!`"<```#W#P$`
M&@```!\0`0`7````.A`!`!L```!2$`$`&0```&X0`0`?````B!`!`!,```"H
M$`$`"````+P0`0`'````Q1`!``@```#-$`$`"0```-80`0`5````X!`!``T`
M``#V$`$`(P````01`0`-````*!$!`!,````V$0$`"````$H1`0`#````4Q$!
M`$8```!7$0$`/P```)X1`0`W````WA$!`%<````6$@$`!0```&X2`0`?````
M=!(!`"\```"4$@$`"@```,02`0`(````SQ(!``T```#8$@$`+0```.82`0`$
M````%!,!`$\````9$P$`)0```&D3`0`<````CQ,!``L```"L$P$`'P```+@3
M`0`=````V!,!`"4```#V$P$`(````!P4`0`D````/10!`"````!B%`$`"P``
M`(,4`0`'````CQ0!``T```"7%`$`#````*44`0`7````LA0!``8```#*%`$`
M.0```-$4`0`,````"Q4!``<````8%0$`"0```"`5`0`3````*A4!``D````^
M%0$`!````$@5`0`0````314!``@```!>%0$`"````&<5`0`$````<!4!``L`
M``!U%0$`#````($5`0`2````CA4!`!$```"A%0$`#````+,5`0`:````P!4!
M``\```#;%0$`!P```.L5`0`-````\Q4!`!0````!%@$`#@```!86`0`,````
M)18!`!L````R%@$`+````$X6`0`3````>Q8!`!P```"/%@$`*````*P6`0`&
M````U18!``<```#<%@$`$P```.06`0`%````^!8!``0```#^%@$`%P````,7
M`0`*````&Q<!``P````F%P$`"0```#,7`0`&````/1<!``D```!$%P$`"```
M`$X7`0`)````5Q<!``H```!A%P$`$0```&P7`0`&````?A<!``X```"%%P$`
M#@```)07`0`-````HQ<!``L```"Q%P$`'0```+T7`0`+````VQ<!``(```#G
M%P$`'````.H7`0`'````!Q@!``8````/&`$`9````!88`0`)````>Q@!``<`
M``"%&`$`)@```(T8`0`X````M!@!`!H```#M&`$`*@````@9`0`[````,QD!
M`"@```!O&0$`-````)@9`0`9````S1D!`!4```#G&0$`!0```/T9`0`'````
M`QH!``@````+&@$`!P```!0:`0`%````'!H!``<````B&@$`#@```"H:`0`)
M````.1H!``8```!#&@$`"````$H:`0`+````4QH!``<```!?&@$`"````&<:
M`0`'````<!H!`!8```!X&@$`"0```(\:`0`&````F1H!``L```"@&@$`$```
M`*P:`0`&````O1H!`!P```#$&@$`%````.$:`0`'````]AH!`!$```#^&@$`
M"````!`;`0`.````&1L!``@````H&P$`$````#$;`0`)````0AL!`!````!,
M&P$`!@```%T;`0`9````9!L!``H```!^&P$`'````(D;`0`'````IAL!``4`
M``"N&P$`$````+0;`0`4````Q1L!``L```#:&P$`#0```.8;`0`H````]!L!
M`!@````='`$`%P```#8<`0`$````3AP!``D```!3'`$`"@```%T<`0`'````
M:!P!``(```!P'`$`#@```',<`0`(````@AP!`",```"+'`$`'P```*\<`0`X
M````SQP!`"8````('0$`,0```"\=`0`G````81T!`&0```")'0$`%````.X=
M`0!5`````QX!`#@```!9'@$`2@```)(>`0!;````W1X!`"@````Y'P$`.```
M`&(?`0`H````FQ\!`"P```#$'P$`)@```/$?`0`;````&"`!`#X````T(`$`
MJ0$``',@`0`C````'2(!`!<```!!(@$`2````%DB`0"%````HB(!`#`````H
M(P$`)0```%DC`0!!````?R,!`%L```#!(P$`20```!TD`0`Q````9R0!`!T`
M``"9)`$`&````+<D`0`K````T"0!`"$```#\)`$`'P```!XE`0`K````/B4!
M`"8```!J)0$`)P```)$E`0`Z````N24!`!T```#T)0$`$0```!(F`0`S````
M)"8!`"4```!8)@$`)P```'XF`0`@````IB8!`!\```#')@$`,````.<F`0!I
M````&"<!`#$```"")P$`00```+0G`0`S````]B<!`"4````J*`$`/0```%`H
M`0!E````CB@!`$T```#T*`$`+P```$(I`0`N````<BD!`#````"A*0$`5```
M`-(I`0!:````)RH!`$@```""*@$`2@```,LJ`0`R````%BL!`"\```!)*P$`
M+````'DK`0`M````IBL!`'$```#4*P$`9@```$8L`0!O````K2P!`+,````=
M+0$`%P```-$M`0`E````Z2T!`#(````/+@$`*0```$(N`0`^````;"X!`"(`
M``"K+@$`4@```,XN`0`E````(2\!``L```!'+P$`L0```%,O`0!%````!3`!
M`"$```!+,`$`,````&TP`0`E````GC`!`!P```#$,`$`,0```.$P`0`'````
M$S$!``<````;,0$`!````",Q`0`-````*#$!``L````V,0$`#@```$(Q`0`+
M````43$!``4```!=,0$`$````&,Q`0`"````=#$!`%D```!W,0$`!0```-$Q
M`0`2````US$!``0```#J,0$`!P```.\Q`0`(````]S$!``4`````,@$`,```
M``8R`0`#````-S(!`!`````[,@$`#````$PR`0`3````63(!``T```!M,@$`
M`@```'LR`0`'````?C(!``8```"&,@$`%````(TR`0`,````HC(!`!@```"O
M,@$`!@```,@R`0`2````SS(!``P```#B,@$``P```.\R`0`J````\S(!``0`
M```>,P$`!@```",S`0`'````*C,!`!\````R,P$`-0```%(S`0`N````B#,!
M`"\```"W,P$`%P```.<S`0`B````_S,!`"4````B-`$`(````$@T`0`;````
M:30!`!@```"%-`$`)````)XT`0`?````PS0!`!H```#C-`$`(0```/XT`0`@
M````(#4!`!H```!!-0$`,@```%PU`0`:````CS4!`"\```"J-0$`*P```-HU
M`0`?````!C8!`",````F-@$`'P```$HV`0`:````:C8!`"$```"%-@$`)0``
M`*<V`0`F````S38!`"4```#T-@$`)````!HW`0`8````/S<!`!T```!8-P$`
M)````'8W`0`8````FS<!`"(```"T-P$`+````-<W`0`O````!#@!`!4````T
M.`$`)0```$HX`0`\````<#@!`!\```"M.`$`(P```,TX`0`?````\3@!`"``
M```1.0$`&@```#(Y`0`8````33D!`"8```!F.0$`'@```(TY`0`I````K#D!
M`!X```#6.0$`,0```/4Y`0`)````)SH!``P````Q.@$`%P```#XZ`0`O````
M5CH!`"0```"&.@$`!P```*LZ`0`/````LSH!`!0```##.@$`#@```-@Z`0`-
M````YSH!`"0```#U.@$`!0```!H[`0`'````(#L!`"(````H.P$`)0```$L[
M`0`:````<3L!`!T```",.P$`&@```*H[`0`'````Q3L!`,<```#-.P$`"P``
M`)4\`0`5````H3P!``8```"W/`$`"0```+X\`0`+````R#P!``T```#4/`$`
M%P```.(\`0`&````^CP!`#,````!/0$`$P```#4]`0`3````23T!``<```!=
M/0$`#P```&4]`0`'````=3T!`#(```!]/0$`!````+`]`0`A````M3T!`!,`
M``#7/0$`#````.L]`0`1````^#T!`#(````*/@$`%@```#T^`0`(````5#X!
M`!T```!=/@$`"0```'L^`0`*````A3X!`!0```"0/@$`"@```*4^`0`=````
ML#X!``@```#./@$`'P```-<^`0`(````]SX!`!H`````/P$`)P```!L_`0`&
M````0S\!`!4```!*/P$`!P```&`_`0`(````:#\!``D```!Q/P$`/P```'L_
M`0`'````NS\!``\```##/P$`#@```-,_`0`0````XC\!``D```#S/P$`"0``
M`/T_`0`(````!T`!`!,````00`$`!P```"1``0`9````+$`!``H```!&0`$`
M%P```%%``0`4````:4`!``H```!^0`$`#````(E``0`7````ED`!``0```"N
M0`$`*@```+-``0`,````WD`!`!$```#K0`$`!P```/U``0`"````!4$!`!``
M```(00$`&````!E!`0`+````,D$!``,````^00$`"````$)!`0`&````2T$!
M``<```!200$`#0```%I!`0`+````:$$!`!0```!T00$`%0```(E!`0`.````
MGT$!`"\```"N00$`(````-Y!`0`<````_T$!`!4````<0@$`#````#)"`0`Q
M````/T(!``4```!Q0@$`$@```'="`0`_````BD(!`!(```#*0@$`"@```-U"
M`0`&````Z$(!``0```#O0@$`!````/1"`0`*````^4(!`!,````$0P$`!0``
M`!A#`0`&````'D,!``8````E0P$`"````"Q#`0`$````-4,!``P````Z0P$`
M"@```$=#`0`Y````4D,!`"X```",0P$`*0```+M#`0`%````Y4,!`!@```#K
M0P$`&0````1$`0`?````'D0!`!T````^1`$`$0```%Q$`0`"````;D0!``0`
M``!Q1`$`"@```'9$`0`&````@40!``4```"(1`$``P```(Y$`0`,````DD0!
M`$4```"?1`$`,@```.5$`0`:````&$4!`#0````S10$`*````&A%`0!3````
MD44!`!D```#E10$`<@```/]%`0`@````<D8!`#4```"31@$`(0```,E&`0!%
M````ZT8!`#`````Q1P$`*````&)'`0`I````BT<!`"8```"U1P$`)0```-Q'
M`0`H`````D@!`"@````K2`$`(@```%1(`0`K````=T@!`#````"C2`$`$@``
M`-1(`0`3````YT@!`!````#[2`$`>0````Q)`0`)````ADD!`*$```"020$`
M<P```#)*`0!\````IDH!`"L````C2P$`5````$]+`0`7````I$L!`"<```"\
M2P$`%@```.1+`0`/````^TL!`!<````+3`$`'P```"-,`0!`````0TP!`!\`
M``"$3`$`'````*1,`0!1````P4P!`!H````330$`%````"Y-`0`*````0TT!
M``4```!.30$`!@```%1-`0`(````6TT!``4```!D30$`$@```&I-`0`0````
M?4T!`!,```".30$`'0```*)-`0`/````P$T!``\```#030$`!````.!-`0`)
M````Y4T!``L```#O30$`!P```/M-`0`%`````TX!`!0````)3@$`!P```!Y.
M`0`(````)DX!``\````O3@$`"````#].`0`,````2$X!``\```!53@$`!@``
M`&5.`0`4````;$X!``8```"!3@$`#````(A.`0`1````E4X!``@```"G3@$`
M!````+!.`0`9````M4X!`!$```#/3@$`"@```.%.`0`8````[$X!`!,````%
M3P$`'````!E/`0`1````-D\!``0```!(3P$`#P```$U/`0`'````74\!``0`
M``!E3P$`&0```&I/`0`'````A$\!``(```",3P$``@```(]/`0`1````DD\!
M``D```"D3P$`!@```*Y/`0`2````M4\!`!<```#(3P$`!@```.!/`0`G````
MYT\!``(````/4`$`!````!)0`0`/````%U`!`!,````G4`$`!P```#M0`0`'
M````0U`!`!$```!+4`$`!@```%U0`0`8````9%`!``8```!]4`$`$P```(10
M`0`0````F%`!`!(```"I4`$``@```+Q0`0`&````OU`!``P```#&4`$`"0``
M`--0`0`1````W5`!`"(```#O4`$`!P```!)1`0`'````&E$!``L````B40$`
M!0```"Y1`0`"````-%$!``L````W40$`90$``$-1`0`3````J5(!``\```"]
M4@$`$@```,U2`0`*````X%(!``D```#K4@$`"P```/52`0`$`````5,!`!<`
M```&4P$`&P```!Y3`0`R````.E,!`"(```!M4P$`)P```)!3`0`G````N%,!
M`!P```#@4P$`+@```/U3`0`+````+%0!`",````X5`$`$P```%Q4`0`.````
M<%0!``\```!_5`$`!0```(]4`0`H````E50!``P```"^5`$`#@```,M4`0`9
M````VE0!``X```#T5`$`"P````-5`0"/````#U4!``T```"?50$`"@```*U5
M`0`1````N%4!`!````#*50$`#@```-M5`0`+````ZE4!`!````#V50$`#P``
M``=6`0`&````%U8!`+(````>5@$`#0```-%6`0`2````WU8!`!@```#R5@$`
M$`````M7`0`/````'%<!``\````L5P$`!P```#Q7`0`'````1%<!`"X```!,
M5P$`*````'M7`0`^````I%<!`$T```#C5P$`:````#%8`0!K````FE@!`&X`
M```&60$`<0```'59`0!`````YUD!`!@````H6@$`&P```$%:`0`4````75H!
M`!0```!R6@$`&@```(=:`0`%````HEH!``8```"H6@$`$````*]:`0`'````
MP%H!``D```#(6@$`"0```-):`0`R````W%H!`#`````/6P$`$0```$!;`0`1
M````4EL!`!$```!D6P$`#@```'9;`0`)````A5L!`!4```"/6P$`%0```*5;
M`0`/````NUL!`!8```#+6P$`%0```.);`0`C````^%L!`",````<7`$`&P``
M`$!<`0`/````7%P!`!8```!L7`$`#@```(-<`0`M````DEP!`!<```#`7`$`
M&P```-A<`0`3````]%P!`%L````(70$`-0```&1=`0`J````FET!``4```#%
M70$`"0```,M=`0`Q````U5T!``8````'7@$`#`````Y>`0`*````&UX!``<`
M```F7@$`"````"Y>`0`%````-UX!``D````]7@$`"P```$=>`0`$````4UX!
M`"````!87@$`#````'E>`0`,````AEX!`!````"37@$`&@```*1>`0`L````
MOUX!``H```#L7@$`'````/=>`0`;````%%\!`"`````P7P$`%P```%%?`0`6
M````:5\!`!,```"`7P$`$````)1?`0`?````I5\!`"L```#%7P$`!P```/%?
M`0`&````^5\!``@`````8`$`#@````E@`0`(````&&`!``H````A8`$`$@``
M`"Q@`0`*````/V`!`!$```!*8`$`%0```%Q@`0`8````<F`!``H```"+8`$`
M$0```)9@`0`%````J&`!`!<```"N8`$`%@```,9@`0`+````W6`!`$(```#I
M8`$`/````"QA`0`*````:6$!``<```!T80$`$P```'QA`0`%````D&$!``4`
M``"680$`$````)QA`0`+````K6$!`!4```"Y80$`10```,]A`0`1````%6(!
M`#(````G8@$`,0```%IB`0`N````C&(!`"\```"[8@$`"@```.MB`0`(````
M]F(!``D```#_8@$`"@````EC`0`R````%&,!`#@```!'8P$`,0```(!C`0!7
M````LF,!`#`````*9`$`,````#MD`0!0````;&0!`%(```"]9`$`,````!!E
M`0!&````064!`#0```"(90$`,P```+UE`0!1````\64!`#````!#9@$`-@``
M`'1F`0`E````JV8!`!4```#19@$`&0```.=F`0`N`````6<!`"0````P9P$`
M)P```%5G`0`3````?6<!``P```"19P$`#````)YG`0`+````JV<!`!````"W
M9P$`&````,AG`0`=````X6<!``<```#_9P$`!P````=H`0`6````#V@!``H`
M```F:`$`"````#%H`0`O````.F@!``D```!J:`$`"P```'1H`0`&````@&@!
M``8```"':`$`!0```(YH`0`'````E&@!``8```"<:`$`"@```*-H`0`L````
MKF@!`!````#;:`$`"````.QH`0`#````]6@!``<```#Y:`$`"0````%I`0`$
M````"VD!``H````0:0$`!@```!MI`0`5````(FD!``8````X:0$`"````#]I
M`0`)````2&D!``T```!2:0$`"````&!I`0`A````:6D!`!$```"+:0$`"0``
M`)UI`0`1````IVD!``P```"Y:0$`!P```,9I`0`#````SFD!``,```#2:0$`
M%0```-9I`0`4````[&D!`"4````!:@$`!@```"=J`0`$````+FH!``@````S
M:@$`"````#QJ`0!2````16H!`"0```"8:@$`)P```+UJ`0`F````Y6H!`!T`
M```,:P$`!@```"IK`0`(````,6L!`!@````Z:P$`(@```%-K`0`E````=FL!
M`#````"<:P$`)````,UK`0`J````\FL!`'H````=;`$`-0```)AL`0`*````
MSFP!``D```#9;`$`!@```.-L`0`5````ZFP!``\`````;0$`#0```!!M`0`0
M````'FT!`!$````O;0$`$````$%M`0`.````4FT!``T```!A;0$`%@```&]M
M`0`&````AFT!`!T```"-;0$`'@```*MM`0`2````RFT!`!,```#=;0$`$0``
M`/%M`0`&`````VX!``@````*;@$`%````!-N`0!A````*&X!`'@```"*;@$`
M"`````-O`0`3````#&\!``4````@;P$`!0```"9O`0`>````+&\!`!L```!+
M;P$`$````&=O`0`3````>&\!`!<```",;P$`$P```*1O`0`L````N&\!`!``
M``#E;P$`)````/9O`0`&````&W`!`!0````B<`$`"0```#=P`0`1````07`!
M``T```!3<`$`$@```&%P`0`0````='`!`!8```"%<`$`$P```)QP`0`,````
ML'`!``8```"]<`$`$````,1P`0`'````U7`!`!@```#=<`$`$0```/9P`0`1
M````"'$!``@````:<0$`!0```"-Q`0`-````*7$!``T````W<0$`"0```$5Q
M`0`+````3W$!``8```!;<0$`"````&)Q`0`-````:W$!``D```!Y<0$`#0``
M`(-Q`0`'````D7$!``<```"9<0$`"0```*%Q`0`(````JW$!``D```"T<0$`
M&P```+YQ`0!'````VG$!`!H````B<@$`#P```#UR`0`3````37(!``4```!A
M<@$`*````&=R`0`3````D'(!`!0```"D<@$`.````+ER`0!'````\G(!`"(`
M```Z<P$`"````%US`0`U````9G,!`"@```"<<P$`#P```,5S`0`(````U7,!
M``T```#><P$`!@```.QS`0`(````\W,!`!0```#\<P$`$````!%T`0`)````
M(G0!``H````L=`$`"0```#=T`0`>````070!`",```!@=`$`(````(1T`0`E
M````I70!`!P```#+=`$`+0```.AT`0`?````%G4!`",````V=0$`+@```%IU
M`0`C````B74!`!T```"M=0$`'P```,MU`0`>````ZW4!`"D````*=@$`+P``
M`#1V`0`R````9'8!`"0```"7=@$`*P```+QV`0`W````Z'8!`!X````@=P$`
M'@```#]W`0`]````7G<!`"0```"<=P$`$P```,%W`0`H````U7<!`!\```#^
M=P$`(0```!YX`0`2````0'@!`,0```!3>`$`%````!AY`0`>````+7D!`"4`
M``!,>0$`)P```')Y`0`C````FGD!`"(```"^>0$`)````.%Y`0`A````!GH!
M`"0````H>@$`)P```$UZ`0`P````=7H!`#(```"F>@$`I@```-EZ`0`C````
M@'L!`!H```"D>P$`'````+][`0`G````W'L!`#`````$?`$`1P```#5\`0!$
M````?7P!``T```#"?`$`!````-!\`0`)````U7P!``4```#??`$`#0```.5\
M`0`/````\WP!``X````#?0$`#P```!)]`0`0````(GT!``<````S?0$`!```
M`#M]`0`/````0'T!``\```!0?0$`#````&!]`0`.````;7T!`!(```!\?0$`
M"P```(]]`0`2````FWT!``T```"N?0$`+@```+Q]`0`'````ZWT!`!````#S
M?0$`!@````1^`0`3````"WX!`!D````??@$`&P```#E^`0`5````57X!``(`
M``!K?@$`20```&Y^`0`)````N'X!`!````#"?@$`$P```--^`0`%````YWX!
M``\```#M?@$`#@```/U^`0`#````#'\!`!`````0?P$`"````"%_`0`1````
M*G\!`!4````\?P$`"0```%)_`0`/````7'\!`!0```!L?P$`#P```(%_`0`*
M````D7\!``L```"<?P$`#0```*A_`0`1````MG\!``T```#(?P$`$0```-9_
M`0`:````Z'\!``T````#@`$`#P```!&``0`I````(8`!`!,```!+@`$`'```
M`%^``0`V````?(`!``T```"S@`$`)````,&``0`3````YH`!`!H```#Z@`$`
M&````!6!`0`E````+H$!``L```!4@0$`"@```&"!`0`6````:X$!``P```""
M@0$`)````(^!`0`M````M($!``P```#B@0$`"````.^!`0`A````^($!``H`
M```:@@$`&0```"6"`0`:````/X(!``D```!:@@$`%0```&2"`0`.````>H(!
M`"8```")@@$`'0```+""`0`/````SH(!`!D```#>@@$`"````/B"`0`0````
M`8,!`"8````2@P$`/0```#F#`0`(````=X,!`!8```"`@P$`&P```)>#`0`*
M````LX,!``T```"^@P$`,@```,R#`0`/````_X,!``4````/A`$`!@```!6$
M`0!3````'(0!``,```!PA`$`!P```'2$`0`(````?(0!``T```"%A`$`#@``
M`).$`0`.````HH0!`!````"QA`$`&0```,*$`0`5````W(0!`!D```#RA`$`
M%P````R%`0`)````)(4!``8````NA0$`"P```#6%`0`*````084!``(```!,
MA0$`!@```$^%`0`+````5H4!`",```!BA0$`%@```(:%`0`7````G84!``D`
M``"UA0$`#0```+^%`0`/````S84!``\```#=A0$`/@```.V%`0`F````+(8!
M``@```!3A@$`#P```%R&`0"+````;(8!`!X```#XA@$`'0```!>'`0`2````
M-8<!``<```!(AP$`!````%"'`0`;````58<!`"<```!QAP$`)0```)F'`0`?
M````OX<!`"4```#?AP$`%P````6(`0`<````'8@!``<````ZB`$`"````$*(
M`0`'````2X@!``8```!3B`$`#P```%J(`0`.````:H@!`!````!YB`$`#@``
M`(J(`0`/````F8@!``P```"IB`$`"P```+:(`0`1````PH@!``D```#4B`$`
M"@```-Z(`0`2````Z8@!``X```#\B`$`+@````N)`0`+````.HD!``@```!&
MB0$`#@```$^)`0`4````7HD!`"8```!SB0$`*0```)J)`0`H````Q(D!`!T`
M``#MB0$`'@````N*`0`L````*HH!`"$```!7B@$`&0```'F*`0`$````DXH!
M`!P```"8B@$`#P```+6*`0`,````Q8H!``,```#2B@$`!0```-:*`0`(````
MW(H!``D```#EB@$`"P```.^*`0`,````^XH!`!$````(BP$`"@```!J+`0`.
M````)8L!``L````TBP$`!````$"+`0`'````18L!`!P```!-BP$`'@```&J+
M`0`-````B8L!``P```"7BP$`#@```*2+`0`-````LXL!`"<```#!BP$`!P``
M`.F+`0`'````\8L!``P```#YBP$`#P````:,`0`5````%HP!``<````LC`$`
M!P```#2,`0`$````/(P!`!,```!!C`$`"0```%6,`0`'````7XP!`#````!G
MC`$`%P```)B,`0""````L(P!`!<````SC0$`"P```$N-`0`'````5XT!``L`
M``!?C0$`"````&N-`0`*````=(T!``8```!_C0$`"@```(:-`0`"````D8T!
M``8```"4C0$`"0```)N-`0`9````I8T!``P```"_C0$`#P```,R-`0`<````
MW(T!``,```#YC0$`!P```/V-`0`6````!8X!``H````<C@$`#@```">.`0`%
M````-HX!`#,````\C@$`!@```'".`0`&````=XX!`!@```!^C@$`$0```)>.
M`0`'````J8X!``D```"QC@$`!0```+N.`0`)````P8X!``@```#+C@$`#@``
M`-2.`0`"````XXX!``8```#FC@$`#@```.V.`0`-````_(X!``L````*CP$`
M"P```!:/`0`3````(H\!``D````VCP$`!P```$"/`0`,````2(\!`!\```!5
MCP$`0P```'6/`0`Q````N8\!`#````#KCP$`!P```!R0`0`*````))`!``0`
M```OD`$`"0```#20`0`(````/I`!``P```!'D`$`"@```%20`0`&````7Y`!
M``T```!FD`$`!@```'20`0`$````>Y`!`$````"`D`$`1````,&0`0!"````
M!I$!`"$```!)D0$`!0```&N1`0`/````<9$!``4```"!D0$``P```(>1`0`&
M````BY$!`"$```"2D0$`$````+21`0`8````Q9$!``8```#>D0$`!````.61
M`0`;````ZI$!``8````&D@$`"`````V2`0`B````%I(!``0````YD@$`!0``
M`#Z2`0`7````1)(!``0```!<D@$`#0```&&2`0`-````;Y(!``\```!]D@$`
M"````(V2`0`)````EI(!``4```"@D@$`/0```*:2`0`V````Y)(!`#L````;
MDP$`*@```%>3`0`X````@I,!`#H```"[DP$`+0```/:3`0!2````))0!`#``
M``!WE`$`.0```*B4`0`I````XI0!`!`````,E0$`&````!V5`0`,````-I4!
M`"0```!#E0$`)````&B5`0`B````C94!`"$```"PE0$`"P```-*5`0`-````
MWI4!``H```#LE0$`"0```/>5`0`B`````98!`"@````DE@$`*````$V6`0`(
M````=I8!`!H```!_E@$`,P```)J6`0`8````SI8!`!(```#GE@$`!P```/J6
M`0`3`````I<!`!0````6EP$`%@```"N7`0`0````0I<!`%$```!3EP$`D0``
M`*67`0"$````-Y@!`!<```"\F`$`#@```-28`0`/````XY@!`!0```#SF`$`
M%0````B9`0`1````'ID!``P````PF0$`$P```#V9`0`5````49D!`!4```!G
MF0$`#P```'V9`0`B````C9D!`"D```"PF0$`C0```-J9`0`4````:)H!``4`
M``!]F@$`%@```(.:`0`)````FIH!``0```"DF@$`"@```*F:`0`C````M)H!
M`!$```#8F@$`$P```.J:`0`.````_IH!`!`````-FP$`%````!Z;`0`G````
M,YL!`"D```!;FP$`)0```(6;`0`E````JYL!`#````#1FP$`,`````*<`0`=
M````,YP!`$4```!1G`$`#P```)><`0`1````IYP!`!$```"YG`$`$P```,N<
M`0`2````WYP!`!4```#RG`$`%P````B=`0`/````()T!`!$````PG0$`.0``
M`$*=`0`=````?)T!`!<```":G0$`.@```+*=`0`3````[9T!``<````!G@$`
M#0````F>`0`B````%YX!`!(````ZG@$`%0```$V>`0`2````8YX!`!D```!V
MG@$`&0```)">`0`4````JIX!`!H```"_G@$`'````-J>`0`2````]YX!`!X`
M```*GP$`)````"F?`0`6````3I\!`!0```!EGP$`&````'J?`0`2````DY\!
M`!D```"FGP$`%P```,"?`0`3````V)\!`!<```#LGP$`"@````2@`0`0````
M#Z`!`"`````@H`$`!````$&@`0`'````1J`!``H```!.H`$`&````%F@`0`&
M````<J`!``@```!YH`$`!P```(*@`0`&````BJ`!``<```"1H`$`!P```)F@
M`0`%````H:`!`!0```"GH`$`!@```+R@`0`(````PZ`!``0```#,H`$`!```
M`-&@`0`)````UJ`!`!4```#@H`$`$@```/:@`0`/````":$!`!`````9H0$`
M"@```"JA`0`3````-:$!``4```!)H0$`)P```$^A`0`.````=Z$!``T```"&
MH0$`$P```)2A`0`-````J*$!``L```"VH0$`#@```,*A`0`S````T:$!``@`
M```%H@$`"`````ZB`0`G````%Z(!`!0````_H@$`$0```%2B`0`'````9J(!
M``D```!NH@$`!P```'BB`0`$````@*(!`"````"%H@$`#0```*:B`0`;````
MM*(!`!````#0H@$`$@```.&B`0`6````]*(!`!T````+HP$`&0```"FC`0`'
M````0Z,!``<```!+HP$`!@```%.C`0`8````6J,!``<```!SHP$`!0```'NC
M`0`*````@:,!``X```",HP$`!P```)NC`0`&````HZ,!``<```"JHP$`'0``
M`+*C`0`-````T*,!``P```#>HP$`#````.NC`0`2````^*,!``P````+I`$`
M#P```!BD`0`7````**0!``T```!`I`$`$````$ZD`0`(````7Z0!``0```!H
MI`$`$````&VD`0!!````?J0!``4```#`I`$`#````,:D`0`A````TZ0!``T`
M``#UI`$`&0````.E`0`*````':4!``T````HI0$`"@```#:E`0`(````0:4!
M``X```!*I0$`"@```%FE`0`1````9*4!`!(```!VI0$`*````(FE`0`L````
MLJ4!`"\```#?I0$`"@````^F`0`(````&J8!``@````CI@$`#````"RF`0`6
M````.:8!``<```!0I@$`"0```%BF`0`>````8J8!``@```"!I@$`"0```(JF
M`0`,````E*8!`$X```"AI@$`$P```/"F`0`+````!*<!``8````0IP$`!```
M`!>G`0`6````'*<!`!<````SIP$`&````$NG`0`)````9*<!``(```!NIP$`
M!````'&G`0`B````=J<!``,```"9IP$`!0```)VG`0`S````HZ<!``H```#7
MIP$`!0```.*G`0`&````Z*<!``T```#OIP$`#0```/VG`0`&````"Z@!``@`
M```2J`$`"0```!NH`0`$````):@!``4````JJ`$`8@```#"H`0`+````DZ@!
M``T```"?J`$`%P```*VH`0`%````Q:@!``4```#+J`$`)@```-&H`0`W````
M^*@!`!$````PJ0$`"@```$*I`0`5````3:D!``H```!CJ0$`"0```&ZI`0`<
M````>*D!`"<```"5J0$`+0```+VI`0`L````ZZD!`!T````8J@$`#@```#:J
M`0`#````1:H!``<```!)J@$`"P```%&J`0`%````7:H!``H```!CJ@$`$@``
M`&ZJ`0`'````@:H!`&D```")J@$`$0```/.J`0`+````!:L!``H````1JP$`
M'P```!RK`0!-````/*L!`!H```"*JP$`!P```*6K`0`A````K:L!`#4```#/
MJP$`"`````6L`0`&````#JP!`!\````5K`$`!@```#6L`0`)````/*P!`"T`
M``!&K`$`+````'2L`0`O````H:P!``8```#1K`$`"@```-BL`0`E````XZP!
M`&$````)K0$`%@```&NM`0`H````@JT!`!4```"KK0$``@```,&M`0`.````
MQ*T!``D```#3K0$`#P```-VM`0`*````[:T!``<```#XK0$`%P````"N`0`&
M````&*X!``@````?K@$`#0```"BN`0`+````-JX!``H```!"K@$`"0```$VN
M`0`W````5ZX!``<```"/K@$`%@```)>N`0`4````KJX!`"````##K@$`$P``
M`.2N`0`,````^*X!``H````%KP$`"P```!"O`0`*````'*\!``P````GKP$`
M"@```#2O`0`*````/Z\!`!T```!*KP$`$0```&BO`0`4````>J\!``P```"/
MKP$`%````)RO`0`,````L:\!`!(```"^KP$`!0```-&O`0`E````UZ\!``0`
M``#]KP$`!P````*P`0`%````"K`!``4````0L`$`"0```!:P`0`3````(+`!
M`!(````TL`$`&@```$>P`0`6````8K`!`!@```!YL`$`%P```)*P`0`7````
MJK`!`!X```#"L`$`&````.&P`0`'````^K`!``4````"L0$`#P````BQ`0`0
M````&+$!``L````IL0$`(0```#6Q`0`-````5[$!`!````!EL0$`)````':Q
M`0`G````F[$!`!4```##L0$`!@```-FQ`0`-````X+$!``@```#NL0$`$```
M`/>Q`0`/````"+(!``D````8L@$`"0```"*R`0`%````++(!``<````RL@$`
M!0```#JR`0`$````0+(!``,```!%L@$`/P```$FR`0`Y````B;(!`!,```##
ML@$`+````->R`0`R````!+,!`!$````WLP$`.@```$FS`0`N````A+,!`#,`
M``"SLP$`,P```.>S`0`[````&[0!`!(```!7M`$`&@```&JT`0`5````A;0!
M`!L```";M`$`'0```+>T`0`7````U;0!`!8```#MM`$`%`````2U`0`5````
M&;4!`!D````OM0$`,@```$FU`0`R````?+4!`#4```"OM0$`,P```.6U`0`T
M````&;8!`#$```!.M@$`:P```("V`0`=````[+8!`!4````*MP$`#@```""W
M`0`?````+[<!``L```!/MP$`%@```%NW`0`P````<K<!`"\```"CMP$`(P``
M`-.W`0`,````][<!`$D````$N`$`0@```$ZX`0`$````D;@!`!````"6N`$`
M'````*>X`0`.````Q+@!`!,```#3N`$`"````.>X`0`)````\+@!``<```#Z
MN`$`"0````*Y`0`.````#+D!`!4````;N0$`#@```#&Y`0`1````0+D!``@`
M``!2N0$`'````%NY`0`(````>+D!``4```"!N0$`$````(>Y`0`/````F+D!
M``P```"HN0$`/P```+6Y`0`"````];D!``8```#XN0$`#@```/^Y`0`&````
M#KH!``<````5N@$`$````!VZ`0`'````+KH!`#@````VN@$`#P```&^Z`0`=
M````?[H!``0```"=N@$`,0```**Z`0`;````U+H!`"(```#PN@$`6````!.[
M`0`8````;+L!`$@```"%NP$`(P```,Z[`0`0````\KL!``8````#O`$`#@``
M``J\`0`/````&;P!``P````IO`$`$P```#:\`0`+````2KP!`!T```!6O`$`
M&@```'2\`0`&````C[P!`!$```"6O`$`#P```*B\`0`F````N+P!`!(```#?
MO`$`&0```/*\`0`3````#+T!`!0````@O0$`(````#6]`0`(````5KT!``D`
M``!?O0$`&0```&F]`0`2````@[T!`!(```"6O0$`$P```*F]`0`8````O;T!
M`!````#6O0$`&0```.>]`0`8`````;X!``H````:O@$`#````"6^`0`(````
M,KX!``4````[O@$`'0```$&^`0`&````7[X!`!(```!FO@$`"````'F^`0`4
M````@KX!``H```"7O@$`(````**^`0`2````P[X!`#````#6O@$`&@````>_
M`0`+````(K\!``P````NOP$`(0```#N_`0`'````7;\!`!8```!EOP$``P``
M`'R_`0`8````@+\!``8```"9OP$`!P```*"_`0`A````J+\!`#$```#*OP$`
M!0```/R_`0`;`````L`!``\````>P`$`!P```"[``0`-````-L`!`!<```!$
MP`$`!````%S``0`*````8<`!``P```!LP`$`"````'G``0`&````@L`!``@`
M``")P`$`!@```)+``0`*````F<`!`!<```"DP`$`-````+S``0`T````\<`!
M`"(````FP0$`,P```$G!`0`@````?<$!`$<```">P0$`'0```.;!`0`N````
M!,(!`"P````SP@$`9@```&#"`0`E````Q\(!``4```#MP@$`"````//"`0`)
M````_,(!``@````&PP$`(0````_#`0`<````,<,!`#````!.PP$`(P```'_#
M`0`2````H\,!`#$```"VPP$`-@```.C#`0`)````'\0!`!@````IQ`$`"P``
M`$+$`0`*````3L0!`"L```!9Q`$`#0```(7$`0`2````D\0!``T```"FQ`$`
M"````+3$`0`4````O<0!``D```#2Q`$`#````-S$`0`0````Z<0!`!L```#Z
MQ`$`&@```!;%`0`L````,<4!``L```!>Q0$`#0```&K%`0`&````>,4!``4`
M``!_Q0$`!0```(7%`0`=````B\4!`!0```"IQ0$`!0```+[%`0`+````Q,4!
M``H```#0Q0$`"````-O%`0`/````Y,4!`!$```#TQ0$`#@````;&`0`*````
M%<8!``4````@Q@$`#@```";&`0!%````-<8!`&(```![Q@$`'````-[&`0`)
M````^\8!`",````%QP$`&0```"G'`0`%````0\<!`!0```!)QP$`"````%['
M`0`+````9\<!`!(```!SQP$`+@```(;'`0`+````M<<!`!````#!QP$`$0``
M`-+'`0`2````Y,<!`!````#WQP$`20````C(`0`,````4L@!`"0```!?R`$`
M%0```(3(`0`7````FL@!`#T```"RR`$`+@```/#(`0`P````'\D!`#$```!0
MR0$`+0```(+)`0`,````L,D!``H```"]R0$`$````,C)`0`3````V<D!`!L`
M``#MR0$`"@````G*`0`1````%,H!`!P````FR@$`!P```$/*`0`8````2\H!
M`!<```!DR@$`"````'S*`0`&````A<H!``L```",R@$`#P```)C*`0`4````
MJ,H!``,```"]R@$`"````,'*`0`+````RLH!`!(```#6R@$`$P```.G*`0`1
M````_<H!`!$````/RP$`!@```"'+`0`)````*,L!`#<````RRP$`,````&K+
M`0`M````F\L!``<```#)RP$`$P```-'+`0`&````Y<L!`",```#LRP$`&```
M`!#,`0`G````*<P!``T```!1S`$`"0```%_,`0`G````:<P!``,```"1S`$`
M!@```)7,`0`*````G,P!``(```"GS`$`"0```*K,`0`1````M,P!``@```#&
MS`$`%0```,_,`0`;````Y<P!`!0````!S0$`!0```!;-`0`*````',T!`!0`
M```GS0$`$0```#S-`0`,````3LT!``<```!;S0$`#````&/-`0`*````<,T!
M``X```![S0$`70```(K-`0`:````Z,T!`"L````#S@$`%@```"_.`0`*````
M1LX!``8```!1S@$`#````%C.`0`.````9<X!`!,```!TS@$`)````(C.`0`=
M````K<X!`!0```#+S@$`*````.#.`0`0````"<\!`"`````:SP$`%````#O/
M`0`0````4,\!`'0```!ASP$`(P```-;/`0`;````^L\!`"P````6T`$`(@``
M`$/0`0`;````9M`!`"4```""T`$`&0```*C0`0`;````PM`!`!D```#>T`$`
M"P```/C0`0`'````!-$!``@````,T0$`"0```!71`0`4````']$!``L````T
MT0$`)````$#1`0`/````9=$!`!,```!UT0$`!P```(G1`0`)````D=$!`%X`
M``";T0$`1P```/K1`0`X````0M(!`%L```![T@$`"0```-?2`0`A````X=(!
M`#(````#TP$`"@```#;3`0`(````0=,!`!(```!*TP$`/P```%W3`0`)````
MG=,!`&@```"GTP$`,````!#4`0`G````0=0!`!````!IU`$`(@```'K4`0`D
M````G=0!`"X```#"U`$`*P```/'4`0`N````'=4!`#$```!,U0$`$````'[5
M`0`%````C]4!``L```"5U0$`"@```*'5`0`5````K-4!``H```#"U0$`+```
M`,W5`0`,````^M4!``D````'U@$`#````!'6`0`7````'M8!``D````VU@$`
M!P```$#6`0`3````2-8!``D```!<U@$`"````&;6`0`&````;]8!``L```!V
MU@$`"P```(+6`0`1````CM8!`!````"@U@$`#@```+'6`0`;````P-8!`!``
M``#<U@$`!P```.W6`0`5````]=8!`!@````+UP$`"0```"37`0`+````+M<!
M`!H````ZUP$`*0```%77`0`2````?]<!`"4```"2UP$`)P```+C7`0`/````
MX-<!``H```#PUP$`&@```/O7`0`&````%M@!``0````=V`$`&````"+8`0`.
M````.]@!`!````!*V`$`#@```%O8`0`%````:M@!``D```!PV`$`"0```'K8
M`0`)````A-@!``D```".V`$`$@```)C8`0`&````J]@!``T```"RV`$`!0``
M`,#8`0`)````QM@!``L```#0V`$`&@```-S8`0`+````]]@!``(````#V0$`
M(`````;9`0`)````)]D!``H````QV0$`;0```#S9`0`)````JMD!``8```"T
MV0$`*P```+O9`0`^````Y]D!`!L````FV@$`*P```$+:`0!$````;MH!`"H`
M``"SV@$`-````-[:`0`:````$]L!`!@````NVP$`!@```$?;`0`,````3ML!
M``H```!;VP$`#0```&;;`0`&````=-L!``H```![VP$`&````(;;`0`,````
MG]L!``T```"LVP$`#P```+K;`0`+````RML!``T```#6VP$`"````.3;`0`*
M````[=L!`!@```#XVP$`"0```!'<`0`&````&]P!``L````BW`$`$P```"[<
M`0`&````0MP!`!@```!)W`$`'````&+<`0`*````?]P!`!@```"*W`$`#```
M`*/<`0`2````L-P!``L```##W`$`$@```,_<`0`(````XMP!`!(```#KW`$`
M!@```/[<`0`;````!=T!``P````AW0$`(0```"[=`0`%````4-T!``4```!6
MW0$`#@```%S=`0`C````:]T!``L```"/W0$`#0```)O=`0`L````J=T!`!P`
M``#6W0$`#@```//=`0`%`````MX!``P````(W@$`#P```!7>`0`.````)=X!
M``(````TW@$`#P```#?>`0`(````1]X!`"0```!0W@$`*0```'7>`0`O````
MG]X!`"T```#/W@$`*````/W>`0`H````)M\!`%T```!/WP$`$P```*W?`0!9
M````P=\!`#0````;X`$`7@```%#@`0!;````K^`!`"8````+X0$`/0```#+A
M`0`S````<.$!`#<```"DX0$`-0```-SA`0`>````$N(!`#L````QX@$`Y`$`
M`&WB`0`A````4N0!`!0```!TY`$`5````(GD`0""````WN0!`$(```!AY0$`
M*0```*3E`0`_````SN4!`'(````.Y@$`4@```('F`0`R````U.8!`"`````'
MYP$`%0```"CG`0`R````/N<!`!T```!QYP$`'0```(_G`0`M````K><!`",`
M``#;YP$`*````/_G`0!!````*.@!`!T```!JZ`$`$P```(CH`0`Z````G.@!
M`"@```#7Z`$`*0````#I`0`B````*ND!`!@```!-Z0$`0````&;I`0!I````
MI^D!`#L````1Z@$`3@```$WJ`0`[````G.H!`"L```#8Z@$`.@````3K`0!C
M````/^L!`$P```"CZP$`,@```/#K`0`M````(^P!`#$```!1[`$`5````(/L
M`0!;````V.P!`$T````T[0$`40```(+M`0`T````U.T!`"X````)[@$`+@``
M`#CN`0`N````9^X!`(@```"6[@$`?0```!_O`0"&````G>\!`-`````D\`$`
M$P```/7P`0`F````"?$!`#D````P\0$`+````&KQ`0!(````E_$!`"L```#@
M\0$`3`````SR`0`@````6?(!``H```!Z\@$`P0```(7R`0!'````1_,!`"8`
M``"/\P$`-0```+;S`0`G````[/,!`"0````4]`$`/@```#GT`0`&````>/0!
M``<```!_]`$`!````(?T`0`,````C/0!``L```"9]`$`#````*7T`0`+````
MLO0!``4```"^]`$`$````,3T`0`#````U?0!`&<```#9]`$`!P```$'U`0`5
M````2?4!``0```!?]0$`!P```&3U`0`&````;/4!``4```!S]0$`/@```'GU
M`0`)````N/4!`!4```#"]0$`"P```-CU`0`2````Y/4!``T```#W]0$``@``
M``7V`0`'````"/8!``<````0]@$`$@```!CV`0`,````*_8!`!@````X]@$`
M!@```%'V`0`.````6/8!``P```!G]@$``P```'3V`0`K````>/8!``0```"D
M]@$`!P```*GV`0`(````L?8!`"L```"Z]@$`1P```.;V`0`Z````+O<!`#L`
M``!I]P$`(@```*7W`0`V````R/<!`#D```#_]P$`+0```#GX`0`C````9_@!
M`"8```"+^`$`*@```++X`0`E````W?@!`",````#^0$`)````"?Y`0`L````
M3/D!`"$```!Y^0$`/````)OY`0`F````V/D!`#H```#_^0$`-0```#KZ`0`K
M````</H!`"X```"<^@$`+@```,OZ`0`I````^OH!`"H````D^P$`+@```$_[
M`0`K````?OL!`#````"J^P$`+@```-O[`0`I````"OP!`"D````T_`$`,P``
M`%[\`0`D````DOP!`"X```"W_`$`.````.;\`0`[````'_T!`"````!;_0$`
M*@```'S]`0!#````I_T!`"D```#K_0$`+````!7^`0`L````0OX!`"T```!O
M_@$`)P```)W^`0`=````Q?X!`"L```#C_@$`+`````__`0`W````//\!`"P`
M``!T_P$`00```*'_`0`,````X_\!`!,```#P_P$`(`````0``@`Q````)0`"
M`"0```!7``(`"0```'P``@`/````A@`"`!P```"6``(`%````+,``@`0````
MR``"`#$```#9``(`"`````L!`@`(````%`$"`",````=`0(`)@```$$!`@`<
M````:`$"`"<```"%`0(`'P```*T!`@`)````S0$"`.$```#7`0(`$@```+D"
M`@`:````S`("``D```#G`@(`#````/$"`@`4````_@("`!`````3`P(`&@``
M`"0#`@`&````/P,"`#<```!&`P(`%0```'X#`@`7````E`,"``<```"L`P(`
M$P```+0#`@`+````R`,"`#P```#4`P(`"0```!$$`@`K````&P0"`!````!'
M!`(`$````%@$`@`5````:00"`#0```!_!`(`(````+0$`@`.````U00"`!\`
M``#D!`(`#P````0%`@`0````%`4"`!H````E!0(`"P```$`%`@`;````3`4"
M``L```!H!0(`)````'0%`@`*````F04"`!L```"D!0(`*P```,`%`@`'````
M[`4"`"<```#T!0(`!P```!P&`@`)````)`8"``D````N!@(`.P```#@&`@`&
M````=`8"``X```![!@(`$P```(H&`@`6````G@8"``H```"U!@(`"````,`&
M`@`'````R08"`!,```#1!@(`"P```.4&`@`<````\08"``\````.!P(`&```
M`!X'`@`6````-P<"``4```!.!P(`!P```%0'`@`7````7`<"``0```!T!P(`
M,P```'D'`@`,````K0<"`!````"Z!P(`#````,L'`@`"````V`<"`!$```#;
M!P(`(@```.T'`@`+````$`@"``,````<"`(`!P```"`(`@`)````*`@"``8`
M```R"`(`#0```#D(`@`*````1P@"`!0```!2"`(`%0```&<(`@`1````?0@"
M`#8```"/"`(`'@```,8(`@`:````Y0@"`!<`````"0(`"P```!@)`@`S````
M)`D"``<```!8"0(`%P```&`)`@!+````>`D"`!0```#$"0(`#P```-D)`@`(
M````Z0D"``0```#R"0(`!````/<)`@`*````_`D"`!8````'"@(`!0```!X*
M`@`&````)`H"``@````K"@(`"0```#0*`@`$````/@H"``D```!#"@(`#@``
M`$T*`@`]````7`H"`#$```":"@(`+@```,P*`@`%````^PH"`!<````!"P(`
M(````!D+`@`A````.@L"`"4```!<"P(`$````((+`@`"````DPL"``0```"6
M"P(`"@```)L+`@`)````I@L"``4```"P"P(``@```+8+`@`?````N0L"`$X`
M``#9"P(`.0```"@,`@`>````8@P"`#,```"!#`(`*@```+4,`@!@````X`P"
M`!````!!#0(`?````%(-`@`G````SPT"`%,```#W#0(`*````$L.`@!2````
M=`X"`#@```#'#@(`,P`````/`@`T````-`\"`#D```!I#P(`.````*,/`@`_
M````W`\"`#\````<$`(`+0```%P0`@`P````BA`"`#,```"[$`(`#@```.\0
M`@`.````_A`"``T````-$0(`@P```!L1`@`(````GQ$"`+$```"H$0(`C0``
M`%H2`@"(````Z!("`"X```!Q$P(`6@```*`3`@`4````^Q,"`"4````0%`(`
M&````#84`@`2````3Q0"`!H```!B%`(`(P```'T4`@`W````H10"`!H```#9
M%`(`&````/04`@!6````#14"`!H```!D%0(`%@```'\5`@`+````EA4"``4`
M``"B%0(`!@```*@5`@`(````KQ4"``4```"X%0(`&P```+X5`@`1````VA4"
M`!X```#L%0(`'P````L6`@`1````*Q8"``<````]%@(`!````$46`@`)````
M2A8"``X```!4%@(`"````&,6`@`%````;!8"`!P```!R%@(`"@```(\6`@`)
M````FA8"``\```"D%@(`!P```+06`@`(````O!8"`!(```#%%@(`"@```-@6
M`@`6````XQ8"``L```#Z%@(`"0````87`@`6````$!<"``@````G%P(`!```
M`#`7`@`<````-1<"`!4```!2%P(`"0```&@7`@`:````<A<"`!````"-%P(`
M(0```)X7`@`/````P!<"``@```#0%P(`%````-D7`@`&````[A<"``<```#U
M%P(`%P```/T7`@`(````%1@"``(````>&`(``@```"$8`@`1````)!@"``L`
M```V&`(`!@```$(8`@`1````21@"`!0```!;&`(`!P```'`8`@`M````>!@"
M``(```"F&`(`!````*D8`@`3````KA@"`!<```#"&`(`"P```-H8`@`'````
MYA@"``\```#N&`(`!@```/X8`@`7````!1D"``@````=&0(`&````"89`@`0
M````/QD"`!(```!0&0(``@```&,9`@`'````9AD"``L```!N&0(`"@```'H9
M`@`5````A1D"`#(```";&0(`!P```,X9`@`)````UAD"`!$```#@&0(`!0``
M`/(9`@`"````^!D"``L```#[&0(``0```-,$```<!```,04``%\#````````
MG`$``&T"``"@!````````)0#``#'`0``^P8``'P``````````````(8"```I
M!P``"P$```````"!!P``P0```'<%```5!```\`4``"P```#;`P``P08``",'
M```(`@```00``+P%```"!P``,0,```````"F`@``[P4``&0"``"R`@``#P0`
M`($#````````````````````````U@0``%$%``"%!`````````````#V`0``
M<`(`````````````?P(``"X$````````(P$``*0%````````8@<``.,%``"/
M!@``)0$``'`&``#U!```;@(``'`!```S!P``P@$``-$"```O!```;P,``$X'
M``!:````H@$``#,!``")!P```````'L!``#K````E@8``,`%``!<!P``2@4`
M`,P&````````E`0``&("``#R````*0(``&8"````````VP0``(0&``#=!0``
M``````````"E````````````````````F`,```````!`````Y`8```````#-
M`0```````)T$``!(`@``OP4```````#]`@``B`<````````,!0```````$\$
M``#+!0``[`(``"8%```7`````````#0```!8````O`$`````````````M0(`
M`%H$``!E`P``:@,``%\!``""!P``````````````````^@$``&0#``!O````
MU@$```````!]!@````````@'``"0`````````$T#``";`@```````!P#``!=
M!@``]`$``-\````H`P``W`$``-`!``"V`P``1P,````````;!P``$0<``"4#
M``#Q````L`4``-($`````````````*L#``"D`````````,H%``!A`P``>0,`
M`)4$```*!````````(H&``#``0```````.$$``!X!P``V0,``.<!````````
M_@4``$H'``"I`0``6`0``.0!````````3P```+X!```````````````````O
M`P``;`<```````"R`````````)@%``!G!```I`8``.(!``!&!@```````"H`
M``#[`0``:`$``%0'``#:`P``*`8``*,$``!4!@``5@0``*\&````````G0(`
M`%L```"2!@``BP,``*D`````````K`4``-,```"@`P``>@$``&<"``#"`P``
M*`<``'L#```K`````````#8``````````````#$"``"#````Y`0```````#V
M!```>00``$0'````````]P``````````````DP(``+H%````````%P4``*H#
M```K`@``>@<```````!T!```.P(`````````````D`(``(X!``"*!```W```
M`'P'``!7!0``F@,```,"```[!P``7@,```8!````````100````````M!P``
MGP,``*4!`````````````&<%``!Q`0````````````!"!@``VP```#T'``!*
M``````````("````````*0$```````!6`P```````)P$````````S`$``&$$
M```6`P```````"<$``!A```````````````E!```=P```.X#``!F!@``````
M`)P&``#_!0``>P`````````8!@``L00```,````#!P``W`4``+<&``#)`P``
M?`(``!8'``#L``````````````!C`0```````.X"``":````D@```)X#````
M````FP$``"L%``!Q`@``\P,``$8#``"^`@``N@$``-T$``#6!@``M`,``.,$
M``#*!```J@0````````8!P``%P(``+\$```8`0``L0(`````````````X@,`
M`(\"````````?@$``/T%``!I`0``%@8``/@!```J`P``2P,``'(#``!'!```
ME@$``$<```#(`0``<0,``$X&```Z````8`8``%,```#5!@``=@(````````N
M!0``)@(``',&``#M````"@8```0```#D`@``?@,``(,%``")`0``DP0``/X"
M``!D!P``Y@4``!<!````````GP$```T'``![`@``?@````4$```)!P``+08`
M`#0&````````4@(``+\`````````=P,``/\#````````"P```#,%````````
M`````&8'```G!@``W0````````#T`@``/P<```````#8`P``V@0`````````
M````:`````T"``!R!@```````-,&``#%!@``<0```*````#\!@``0@(`````
M``";!```N0,``,`````$!```#@8``$P!``"4`@``N04``*`!``#!`0``````
M``4`````````3`<``-8"``!C`````````,0```````````````````#R!```
M`````$`%``!O!P```````,T&````````%P,``($&`````````````%(%````
M`````````/,$``!W!```HP8``&\$```(````7@```$@'``"Z`P``=@4``-X`
M``"$`P``)`0``#L%``#W!@``G`,``'<"````````:@$``#X"``"^!@``[04`
M`+X$````````;P8```````")````I0(````````S!@```````!P'````````
M50$``"($```X`0```````&T$````````AP(``'D%``"`!0``U@`````````A
M`@``3P8``#<$```S`@````````````"7`P``_P0````'```'`P``:08`````
M``#Q`0``Q@```/`#``"/````6P<`````````````YP8``(4#````````````
M`-T"```N`P``5P$``/0&````````Y0$``/X```!-````S00``!`%````````
M-@$``)`#``!]`0``EP```%D$``!_!```<P```*<%``!8`@``@@(```````!!
M!@``=@$``/X!````````YP0````````D`````````/@$``!K!```Q@0``%D!
M```A!```!@```)\"``!>`@`````````````#!@``E`4```````#A!@``C@,`
M`#X````K`0``%`(``-<#``"1!@``0`<```````!L`P```````(X$``"C````
M`````,4#``!1````O0(``"P$```@!```Z00````````L!@``]@(``"X&``!8
M!0``````````````````J0(``"0#`````````````+,!````````?0```"<#
M````````<@<```````"1!````````,X!``#P!@``"`$`````````````````
M```!``!,!0``.`8```````#(!0``$0$``%\$``#Z`P``G````+`#``#$`0``
M`````'4$``!Q!```UP(``,D%``!\`0``C`$``````````````````/P%```U
M!````````#X'``"E!@``T`,``*@&``#M`0``I@````````#O`@``````````
M````````K00``.L!``#Y!```WP,``"@$````````9@0``)\````/!@``N00`
M`.H#````````R00``%L"``",!````````,0"``"^!0``0@4``'0'``#5!0``
MDP8```````!C!P`````````````;!````````/0#``!4````V0````````!(
M````E@````````!6`@``-P```!\&```\`@``<P(```````#S`@````````@$
M``"W`@``I00``'<'````````V@8``!4`````````V00```````#\````````
M`!\%``"+!0``]P$``/8%``!\`P``V`8``+0%``"5!0```P4`````````````
M``````````"#!```OP(``,X"```,!P``F0,``/\"````````]`0``#\"``!3
M`0```````,4$```R`0```````,L"``",``````````````!+`0``````````
M``"Z!@``"0$``-X!```F!```I`,``,P%``!S`0``,P0``!`&``"+!```8@``
M```````O````H`8``#@"``!9`@``?P<``$<'``"-!0``&0````````"M````
M[P,``-$&``!\!0``,@```+T%``#*`@```````/8&``"V!@``6P4``$0!````
M`````````!T"```>!P``VP8````````.!0```````&`!```Y`@``0P(``+L!
M``"``P```````"H!``!&````T`(``!,&````````?P```$(#```U!P``+0$`
M`#$$``#A`0```````-$%``"T`@``Z`$``%0#``#X`P``?00```````"B`P``
MU`(``&(#``#J!0````````````!?````'P(``#(#``#\`@```````',$````
M````@`8``#<%```Z!0``&`0```````!V````HP,```````"7!0``8@4``!("
M``!L`0``(@$```````".`````````&H%````````Q04``!H!``#@`0``````
M`),#``"8`````````(4%```8`````````"P%``"&!````````!P```"9!@``
M:`8``/L"``"%`0```````$P#``!H!P``>@0``!`$``!E````5`4``,0&``!T
M`@``X```````````````MP,``'4#`````````````````````````````%P!
M````````.`<``'X"``!L``````````````"(`@```````,X&```+`@``#P4`
M`&T!```M`@``WP4``.<"``!/`P``#0$``&````!G`````````+\&``#9`@``
MN08``````````````````.H```"R!```*``````````O!P```````/,```"J
M!0``_0$``-4$```:````````````````````8@0```````#(!@``7P8``$X`
M````````$P(`````````````2@0``!4&```C````/P```((%``"H!```N`(`
M`)$%``#D````0@0```````"X!0``004``!\!``"X`0```````)L%````````
MM0````$'```K!P````````````"P!````````&D'``![!0``9@``````````
M`````````,X$```'`0``5P8`````````````WP8``&`'```[`0``.P0``'4"
M``#K!@``.00``!\'``#]!@``<08```P!````````1P8``)T&``"\!```908`
M``D%``!%!P``````````````````<P,``(L```!Y!P``T@,```$"``"C`0``
M+`,```````"S!````````"0'```!`P``ZP(``'````!M!@``V````!$&``!%
M`P``70<``/(%``#H!@``T00``#\#````````^@4``&4'``"?!@``T@(`````
M``!K`0``T0```(D&```P````R`(``*$$``#L`0``X@```&H"``"F`0``7`(`
M```````X`P```````%L&```K!```8`,``.`%````````SP```)8%``#7!@``
M10(`````````````E0$`````````````!@8``$8%``#^!@```````$D#``!L
M!0``4P<``-,!``"``0````````````````````````````#]!```;`0```8$
M```^`P``'P0``-\$````````7`,``'X$```1`@``*P8``,L$```;`P``````
M`'X&``!U````!0,``)$!````````K``````````$`@``>0$``"D$```T!P``
M`````'H```!T``````````````!B`0``5`$```T````_`0``W@,``+0&```W
M!P`````````````F````````````````````B`4``(\$````````1@0````&
M````````LP```%`!``"0!@``L@$``!8"``!0`@``AP,``&X'``#U`@``M@``
M`/(&``#Q`P``40$``.($``#O!````````,\&````````+P(````````+!P``
M4`````````!4`@```````$L&``"!`@```````!L&````````\P8``(L&``"[
M````7`8```````#Y`0``A````$4&````````=0$`````````````1`(``$@!
M```5`P```````"0!``!9`P``]0```)H%``!3!0``W`8``#D!```9!P``````
M`(@!``!<!0``5P0``$$'``":`@``/0,``!$#``"N!0``20$```````"?!```
M`````#X!``!J````?@4``*<#``"G!@``(`````````"N````2P```!(```"F
M!````0$``'@&````````U0$``+H```#D`P``M@$`````````````:`0`````
M````````O@```+D```!R!````````!$```!?!0``Y@0``"`#``"K`0``Y@``
M`"("``">!@``O0$``/(!```Y!@``@@8```````"!````$@0``+L"```]!```
M?P$``!L```"S`@```````+T#``!U!0``90(``(4`````````S0(``,,&``!_
M!0```````%<"``"?!0``\`$``*T#````````B@4``'(!``"Q````@00`````
M``#O!@```````!`'``!O`@```````.T#````````$`(``!0!```M`P``1`0`
M``````#5`P``WP(```````![!@``204```````#:!0``AP0```````"Q!@``
M]P(``*\$```%`@```````"$```#[!0``=P$``#P#```)!@``\P4``/`"``!Q
M!0``N`,```````#4`P``Z`(``%@&````````>P0``$$#````````*@(``)P%
M``#&!0``V04``&$%`````````````/\&``!Z!0``1P(``#P```"\````````
M```````/`P`````````````/!P``-@8``!0$`````````````&$"```'!P``
M,P,```````!``0``/04```````":!@````````````"'`0``R0```.D#``#C
M!@``O0```(L!``"]!````````#8#```U`@``'04```````"&!@``K@0```<"
M``#K!```OP,``````````````````$D$``!0!@``M00``',%``#$`P``````
M`&L#``#:`0``L`$```````"3!0```````,D&``"B!0````````D#``!]`P``
M$P````T$``#%`0``"P0```````!!`@``50```.(%````````K`,```,#```9
M!```!08`````````````Z@0``.L%```*`P``J`4``+<$```6````5`0``#<!
M``!5!0``I`(``/D"````````@`(``",%``#[`P``0P$``&H$````````````
M`#\%```3`0```````/(#``#'!```O08```````!(`P```````,T#``!=!0``
M?`0``#P&``#Y````'@4``$8!````````JP```%8!``#H!```C0````````#.
M`P``-P8`````````````RP```(<```#=`P````````````#,!````````%$'
M````````&04```````#G`P``,0```,P#``")!0``$`$```X```!J!P``IP``
M`,\$``!A!P``%P8``-H````A`0``H@(``)@"``!>!```+00``"('``!E`0``
M>`(``!,'```=!```V`4``)P"``!=`````````.`$``!F!0``/@8``.8"````
M````L@4````````$`P``'@0```````````````````0%````````DP$``(4&
M``!T`P``KP,``/D&````````D@0``(4"```=!@```````-P#````````6P$`
M`%H'```4`P``\0(``#('``!T!0``J`,``%T!```J!@``````````````````
MK@8``.`#``!.`P``_`0``#D'``!X!````````"\%``!G!@``U````*`"``#Y
M`P```````"@%``"%!P``[`4``'("````````*0`````````&`@````````H'
M``#E!````````%$&`````````````"8'```!!@```````$8"````````````
M``````#7`0``S0```#<#```$`0```````"H'``!Q!P``8@8```````"!!0``
M;@$``*\"``#$!```+@(``%4$``````````````````"$!0``$P0``)$"``!6
M!@``T@```*X#``!(!@``-@<``'L'````````T`0``!L%````````N@0`````
M````````@@$`````````````(P(``%H!````````&@<``#$'```@`@``J`(`
M`"4'````````.@0``(D"``!K````\08``#D%```\`0``$04```````#D!0``
MB@```!P!``"K!```B0,```8%````````(@4``%T"````````Z@$```````#Z
M!````````-\!``!'!0```````!(&``"(````Z0(``#0$``#E`P``JP4``,T%
M``#'`P```````#\$``````````````````#J`@``H0,``/X#```8!0``,P``
M`/4%``!V!P```````&X&````````RP,``&\!```>`P``604```````"&````
M@P$```````"T````CP,``(0$```P!```MP$``)D"``"@!0``M@(``.4"````
M````,@0``*$````L`@``R`,```L#````````C`4````````:!@``K`0`````
M`````````````&L%````````V`$````````.!```!P8````````E````X0,`
M`)X``````````````'(%```>!@```````!4!```^!0``'0```,P"``">!0``
MB`8``(X"```A!0``E@(````````_!@``0`8``*$!``"A!0``)P(`````````
M````+0```$D'``"5`@``4@0`````````````-`(``/<%``!T`0``70,``#4!
M````````3@0``%8%``"B!```"0```,,%``"#`P```````%@!``!I`@``[`,`
M`!D"````````P@(``%D'``!#`P``/`0``)`!``#F`0``XP,``%$$````````
M`````*P"```.`@``'`(``$X!``!(!```"@````````!,!@``_`$``"X```"-
M`0```````"P'``#M`@``Z0$``,\!``!L`@````````````#:`@``PP(``"<`
M``"S`P``D@4```````!N````$`````````"-!```&P$``'`$``!U!P````,`
M`-X%``!2!P``L@,```8'``"-`P```````(T"``!G`0``@@,``+\!``!V!@``
M;@0``*H```!.`@``9`4```````",`P``+@<``(($````````O`,``#X$```8
M`@```````#<"``"2`P``@@`````$```````````````````/`@``%0(``,(`
M``"[`P```````-`&```P!0``[@```,$%````````2`4``!('``!8!P```@0`
M`%X!`````````````-D!``!)!@``\00``&P&```X!0``.@<``)H!``#A````
MO`(``+X#```6!`````````````"9!0``Z04``/4#````````0@<``!D#``#L
M!```E0,```(#```(!@``C08```````!K!@``7P<``"X!```E!@```````&0&
M``!I`P```````%X&``"U`P``"@(``$D"```?````"P8``&0!````````````
M`$\"`````````````*8%```P!@``L0$```P&``#2`0``-04``(8!``!<````
M`````#H&``#F`P``&@4``+L$``"M`@```````(````!Z`P``AP8```````"#
M!@``W0$``#4#``#O`0`````````````,````E@,``&,"``">`@``\04`````
M`````````````&0$`````````````.D```"V!0``H08````````>`0``P0,`
M`#L&``!P!0``A`$``&L"````````300``.8&````````Q@8``(\!````````
MPP```!T'````````8P0``','````````#04``#T!``!/!P``;0,``"$&``!$
M````%0<`````````````V`(``$D````[`P``%P0```````#O````:@8`````
M```*!0``4P,```<%```D!0``M08``*D$```'!```1P$``$,&````````````
M```````@!0```````+````"O````+P8``.X&``#C`````````"(&```2`P``
MP00``-D&`````````````'\#```,!```&`,``*P!````````N0$``.(&``#.
M`````````)(!``!^!P``Q0(```(%````````-`$```````"H````+`$```X#
M````````D`0``!D!``"B````4`4```````#I!@``U0(`````````````````
M``D$``"9`0``FP,``*H!```,`@``U`4``/0%``#U`0``#0,```````"=`0``
MQ0````````#&`@``5P```#@````H`@````````````#]`P``IP0``+L%````
M````P@4```````!/`0``'0$``.P&``#X!@``E@0``%`$````````K0$`````
M````````I`$``*D%``"P`@``8P8```````#6`P``%@4``*8#````````&@(`
M```%````````A@<``(`'``#0!0``XP$``*P&``#C`@``P`8``*L"``!P`P``
MD`4``*\!````````T@4``*(&````````M04```````#.!0``;04```````#X
M`@```````-T&`````````````!\#``!]!P``M`0``*8&````````Q`4``*<!
M``!#````G0,``!L"````````3`0````````"`0``EP(``$\%``!``P``>08`
M`-P"````````1@<``&,%``!_!@``1`,``.4```!-!0``P@8`````````````
M``````````#0````6P,``+<```!Y`@``0P4```````!2!@``U@4``$H"```]
M````+04```````!Z!@``X`(``&`$```:`P``````````````````PP0`````
M``#3`P``X@(``'@#``"4````AP<``!H$````````````````````````000`
M`!D&`````````````%`'````````*0,``/T```!7`P`````````````A!P``
M40,``#H"``"3````\P$``%4"``````````````T&````````F00```````!"
M`0``7P(``$L$``!+!P``;@4``+$#````````A`(``$T&````````)@$`````
M``#;`0```````+$%``!P!P``W`0``&D%``"S!@``)P4``#P'``!#!P``2@,`
M`&D$``#/`P```````&@"``"O!0``@`0``'8#``#1`P``4`,``)@!``#A`@``
M3`(``,($````````B`0``&L'``!R````````````````````^@(````````R
M!0``:`,```4'```C`P``?`8```````#H`P``EP0``+4!``#*!@``SP(``"@!
M``"7`0``RP$```````!6!P``4P(``%H#``"&!0```````#`"``#X````F0``
M``````#,````K@(``#0%````````UP````````"E!0``````````````````
M)`8``)@&``#N`0``(0,``#L```"7!@``00$``,8#``",`@``!`<``!4%``!E
M!0``````````````````(@,``(H"```>````@P<``%4'``"M!0``10```'4&
M```X!```PP$``-0!``!"````900``"<'``!O!0``]08``%8````.`0``^04`
M`$T"``#^!```6@(``*,%```$!@``Z`4``"(```!%!0```````$H&``"8!```
MFP8``,$"```#!`````````````"\!@``;@,``!0&``#M!@```````'T%``#H
M````-`,``%H%```2!0``#P$``!X"````````:`4````````O`0``/0(``$T!
M```P`0``)0(``-4`````````)04``&8#``#V````>@(``(X&````````````
M`*,"````````K@$``/P#``!A`0``N````)$```````````````````"5````
M)@,```\``````````````(H#````````?0(``,<%``#&`0```````(8#```@
M!P``G@$```````#;`@``R0$```H!``!5`P``>0```-0$``##`P```````,H!
M```3`P``````````````````;0<``/`$``!V!```"`,````````]!@``V`0`
M``````"A`@``;0```(\%```7!P```````%<'```J!````@```&`"```<!0``
M`````/@%``!.!0```````,@````,`P``BP(```````"E`P``"`4````````Y
M`P``_P$```X'``!=!```"0(```````!,````F@0``-$!```I!0``YP4`````
M``!X`````````&8!``#P````[@4``$L"``"W!0``!04```````!2````ZP,`
M`$L%``#4!@``.0```,@$``"=!0``P`(``%X'```#`0``=P8``$0%``#>!@``
M```````````'````-@4``"L#``#Z````QP8``!0'```"!@``R@```'@!```2
M`0``]P,``.4%``"J!@``4P0``%(!````````!@,``+D"``!-!P``%````)$#
M``"J`@``7`0``-<$```Z`P``,`,``/0```!`!````````-X"``"P!@``````
M``````#;!0``808``,`#``#*`P``[00``%L$``"4`0``B`,``&<'``"$!P``
M```````````3!0``C`8``*0$```P!P``B@$``$,$``";````(`8``/("``!T
M!@````````````"V!````````!`#``#J!@``8`4```````#[!```E`8``.$%
M```I!@````````````#W!````````+H"````````M`$``$0&````````K08`
M`%4&```\!0```````$$````V!````````#("`````````04```````".!0``
M'0,``*<"`````````````%(#```F!@``TP4``/H&````````J`$``&,#```1
M!`````````````!3!@``)P$``+,%````````Y08``-,"````````AP4``(,"
M``"X!@``6`,``($!````````[@0``"0"``#2!@```````#4```"[!@``R0(`
M`*D#``!9`````````#$!````````X`8``+(&```+!0``10$``%H&``"X!```
M-08```````!9!@```````&0````C!@``QP(```````"=````_P````4!``!`
M`@``B00``&D```#7!0``(`$``)X$````````D@(``!0%````````.@$``,\%
M````````%@$```````!X!0``QP```,L&`````````````%X%```C!```]@,`
M`"H%``#G````P`0``*D&```<!@``2@$``#$&`````@``9P,``-X$```V`@``
M``````````#[````JP8``)4&``!1`@```````#(&````("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E
M8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E
M<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X
M:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`
M)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@
M)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D
M<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H
M;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN
M`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N
M="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@
M0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@
M3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D
M9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K
M.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`
M069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N
M;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`
M06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E
M/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA
M=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E
M<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R
M;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`
M06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P
M<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`
M07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS
M:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S
M=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B
M86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO
M<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M
M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N
M:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L
M:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@
M5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI
M8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!"
M;W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A
M<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-2
M0P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN
M`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`
M0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O
M;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO
M="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA
M;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S
M=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R
M=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I
M;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`
M0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@
M4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN
M80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U
M97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@
M9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E
M;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`
M0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B
M87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC
M:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI
M8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`
M0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N
M<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R
M('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O
M;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F
M86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#
M;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@
M<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S
M(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E
M<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E
M<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$
M86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F
M875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3
M:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R
M;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R
M;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R
M<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N
M="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI
M=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO
M860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O
M+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I
M9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y
M`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y
M('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@
M:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%52
M3"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U
M:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI
M8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E
M<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E
M<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE
M8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO
M;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I
M979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O
M92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E
M;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO
M=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`
M1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&
M:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R
M<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`
M1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@
M0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE
M`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W
M87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R
M96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T
M:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R
M86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O
M9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K
M("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES
M=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S
M`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U
M97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A
M=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R
M;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(
M86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE
M8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M
M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/
M;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G
M92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ
M`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R
M`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S
M92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF
M;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A
M8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS
M97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O
M;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@
M869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E
M<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA
M9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C
M<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E
M<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I
M;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!)
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N
M`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A
M;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV
M96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R
M;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y
M`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*
M=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`
M2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN
M9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI
M<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY
M<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`
M3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`
M3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`
M3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI
M8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI
M9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT
M(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@
M5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K
M`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN
M=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`
M3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T
M:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O
M=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E
M96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU
M;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA
M:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-
M86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-
M87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`
M36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I
M=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X
M:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU
M(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T
M>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE
M`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@
M;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L
M:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C
M8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA
M;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT
M:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L
M(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R
M=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P
M92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI
M80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA
M;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@
M4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG
M97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S
M=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L
M871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO
M(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES
M('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI
M960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.
M;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T
M:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R
M>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@
M<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E
M<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T
M96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T
M82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG
M:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET
M*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`
M3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L
M96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O
M9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S
M`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/
M8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@
M<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O
M=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R
M<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN
M(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/
M<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`
M4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@
M4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E
M`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!0
M32!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]3
M25@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A
M:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`
M4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D
M>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S
M<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A
M<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T
M90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`
M4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R
M;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I
M;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE
M<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE
M87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT
M97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U
M($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN
M`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O
M;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E
M<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@
M2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M
M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI
M8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1
M871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I
M;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H
M;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N
M90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L
M(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA
M<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C
M;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D
M('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T
M:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I
M9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG
M:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E
M(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U
M;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O
M;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I
M86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%
M4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD
M($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H
M7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E
M`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E
M<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M
M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&
M:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE
M8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@
M=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS
M;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.
M=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S
M<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O
M<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E
M<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@
M86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA
M=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L
M9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A
M:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N
M;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H
M.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S
M`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3
M;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL
M`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N
M9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O
M<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE
M`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`
M5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L
M97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R
M90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO
M)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X
M='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@
M9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE
M(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE
M(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@
M=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F
M=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD
M(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L
M96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N
M(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y
M<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T
M;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@
M8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N
M8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T
M;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R
M96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T
M+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE
M('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T
M:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@
M=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC
M92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@
M;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V
M86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE
M<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R
M=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@
M)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y
M<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A
M<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ
M92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D
M+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@
M<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R
M871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F
M:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L
M;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU4
M4"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O
M(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U
M;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4
M:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA
M(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O
M;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R
M(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C
M;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4
M:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R
M+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU
M;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#
M;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE
M($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@
M;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`
M5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N
M9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K
M:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E
M>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R
M97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T
M;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@
M)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE
M('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H
M8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S
M="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A
M=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@
M8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@
M9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H
M;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W
M('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5
M;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T
M92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5
M<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S
M92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!2
M96=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L
M960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R
M;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`
M57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A
M9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E
M("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L
M8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX
M.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC
M:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I
M9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S
M`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E
M<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA
M<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`
M66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T
M960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO
M=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F
M:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T
M:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E
M(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E
M<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@
M26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U
M<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@
M=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E
M9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U
M<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S
M=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L
M879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D
M(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'
M<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G
M(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]2
M96UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S
M97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C
M86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP
M=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG
M=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A
M=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`
M9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`
M:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P
M=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O
M9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO
M="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R
M8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF
M9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@
M97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@
M<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,RXQ+C$M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`S+3$R
M(#`P.C,Q*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,RTQ,R`R,CHT
M,"LP,3`P"DQA<W0M5')A;G-L871O<CH@2F%N($MU:7!E<G,@/&IR:W5I<&5R
M<T!L875W97)S8V]L;&5G92YN;#X*3&%N9W5A9V4M5&5A;3H@1'5T8V@@/&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*"5S(&1A9V5N(&=E;&5D96XI
M`"`H4VYE;'1O971S("5S*0`@*&)I;FYE;B`E<R!D86=E;BD`("AV86YD86%G
M*0`@*&UO<F=E;BD`("AG:7-T97)E;BD`(&]P(``B)7,B(&ES(&=E96X@9&ER
M96-T;W)Y+@`B)7,B(&ES(&=E96X@9V5L9&EG92!K975Z92X`(B5S(B!I<R!N
M:65T(&=E8V]N9FEG=7)E97)D(&EN(&AE="!(;W)D92!R96=I<W1E<BX`(B5S
M(B!T<F5E('=E97)G979E<B!N:65T(&=E=F]N9&5N+@`B)7,B(&%A;B!H970@
M9W)O97!E;G-Y<W1E96T@=&]E9V5V;V5G9"X`(B5S(B!A86X@:&5T(')E8VAT
M96YS>7-T965M('1O96=E=F]E9V0N`"(E<R(@:7,@;FEE="!A86YG96UA86MT
M.B`E<RX`)2XR9DU"(&=E8G)U:6MT('9A;B`E+C)F34(@=&]E9V5S=&%A;B`H
M)2XR9B4E*0`E9"`E<R!E;B`E<P`E9"!D86=E;B!T;W0@=7<@=V%C:'1W;V]R
M9"!V97)V86QT+@`E9"UD86<@=F]O<G5I='II8VAT`"5S("T@3W!M97)K:6YG
M`"5S('9I;F=E<F%F9')U:P`E<R!+0@`E<R!/;F1E<FAO=61S=V5R:WIA86UH
M961E;B`M($)E=F5S=&EG:6YG`"5S($EN<W1E;&QE;@`E<R!I;G-C:')I:G9E
M;@`E<R!G96)R=6EK97)S;W9E<F5E;FMO;7-T`"5S(&)E<W1A870@86PN`"5S
M(&]P("5S("5S`"5S(&ES(&=E<F5E9"!O;2!O;F1E<G-T86%N9&4@9V5S96QE
M8W1E97)D92!O;F1E<FAO=61S=V5R:WIA86UH961E;B!U:70@=&4@=F]E<F5N
M+B!6:6YK(&1E(&)E=V5R:VEN9RAE;BD@86%N(&1I92!U(&]P(&1I="!M;VUE
M;G0@=VEL="!U:71V;V5R96XN`"5S(&ES('9E<F5I<W0`)7,@;6EN=71E;@`E
M<R!N:65T(&=E=F]N9&5N+@`E<R!T;W0@)7,@=F%N("5S`"5S)W,@861R97-B
M;V5K`"5S)W,@86=E;F1A`"5S)W,@;F]T:71I96)O96L`)7,G<R!T86ME;FQI
M:G-T`"5S.B`E<P`E<SH@1&ET(&)E<FEC:'0@:V]M="!M:7-S8VAI96X@;FEE
M="!V86X@9&5G96YE(&1I92!H970@8F5W965R="!T92!Z:6IN+B!7965S('9O
M;W)Z:6-H=&EG(&)I:B!H970@:VQI:VME;B!O<"!L:6YK<R!I;B!H970@8F5R
M:6-H="!O9B!D92!A9GIE;F1E<B!P97)S;V]N;&EJ:V4@:6YF;W)M871I92!T
M92!S='5R96XN`"P@=VEN9'9L86=E;B``+"!W:6YD=FQA9V5N("5S("5S`"P@
M=F%R:6%B96P@=F%N("5S('1O="`E<P`M+2!S96QE8W1E<F5N("TM`#$R('5U
M<G-W965R9V%V90`R-"!U=7)S=V5E<F=A=F4`,C0@=75R<P`\5F]R:6=E`$5E
M;B!D871A8F%S92!B86-K96YD(&ES('9E<F5I<W0@=F]O<B!D:70@8FQO:RX`
M17(@:&5E9G0@>FEC:"!E96X@9F%T86QE(&9O=70@=F]O<F=E9&%A;@!%96X@
M;W!E;F)A<F4@4$=0('-L975T96P@:7,@=F5R96ES="!O;2!E96X@8F5R:6-H
M="!T92!C;V1E<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L975T96P@:7,@=F5R
M96ES="!O;2!E96X@;VYD97)T96ME;F0@8F5R:6-H="!T92!V97)I9FGK<F5N
M+@!%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R:7;I(%!'4"!S;&5U=&5L
M(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E<FEC
M:'0@=&4@9&5C;V1E<F5N+@!%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R
M:7;I(%!'4"!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I
M<W0@;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+@!%96X@;W!E;F)A
M<F4@4R]-24U%('-L975T96PL('!R:7;I(%,O34E-12!S;&5U=&5L(&5N('=A
M8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@
M9&5C;V1E<F5N+@!%96X@;W!E;F)A<F4@4R]-24U%('-L975T96PL('!R:7;I
M(%,O34E-12!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I
M<W0@;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+@!%96X@;W!E;F)A
M<F4@4TU)344@<VQE=71E;"!I<R!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E
M(&-O9&5R96XN`$)E=V]L:VEN9R!V;V]R(#$R+C`P('5U<@!,:6-H=&4@<F5G
M96X@=F]O<B`Q,BXP,"!U=7(`4F5G96X@=F]O<B`Q,BXP,"!U=7(`0G5I96X@
M=F]O<B`Q,BXP,"!U=7(`4VYE975W8G5I96X@=F]O<B`Q,BXP,"!U=7(`04TO
M4$T`05!)($E$`$]V97(@9&5Z92!E9&ET;W(`3W9E<BXN+@!!8G-B;W1T;VT`
M06)S;6ED9&QE`%1O96=A;F<@9V5W96EG97)D(&)I:B!H970@;6%K96X@=F%N
M(%9&4R!D:7)E8W1O<GDN`%1O96=A;F<@9V5W96EG97)D(&)I:B!H970@;6%K
M96X@=F%N(%9&4R!B97-T86YD+@!!8V-O=6YT:6YF;W)M871I90!!8V-O=6YT
M=V%C:'1W;V]R9`!!8V-O=6YT(&)E=G)O<F5N+@!697)A;G1W;V]R9&EN9P!4
M;V5V;V5G96X`0VAI;&0@9W)O97`@=&]E=F]E9V5N`$-H:6QD(')E8VAT('1O
M979O96=E;@!(:65R('1O979O96=E;CH`3FEE=7=E(&=R;V5P('1O979O96=E
M;@!.:65U=R!R96-H="!T;V5V;V5G96X`165N(")C:&EL9&=R;V5P(B!A86X@
M(B5S(B!T;V5V;V5G96X`165N(")C:&EL9')E8VAT(B!A86X@(B5S(B!T;V5V
M;V5G96X`3FEE=7=E(&=E8G)U:6ME<B!T;V5V;V5G96XZ`$MO;&]M('1O979O
M96=E;@!.:65U=V4@;&5D96X@=&]E=F]E9V5N`%!A87(@=&]E=F]E9V5N`$AE
M="`E<R!M96YU('1O979O96=E;B!A;',@965N($UO>FEL;&$@4VED96)A<@!6
M;V5G('1O92!A86X@861R97-B;V5K.@!6;V5G('1O92!A86X@;6EJ;B!A9')E
M<V)O96L`1V5B<G5I:V5R('1O979O96=E;@`B)7,B(&%A;B!H970@<WES=&5E
M;2!T;V5G979O96=D+"!M86%R(&MO;B!G965N(&5X=')A(&EN<V-H<FEJ=FEN
M9W-I;F9O<FUA=&EE('1O979O96=E;CH@)7,N`"(E<R(@86%N(&AE="!S>7-T
M965M('1O96=E=F]E9V0N(%4@:W5N="!N=2!A86YM96QD96XN`%1O979O96=E
M;B!V86X@9V5B<G5I:V5R<R!I<R!U:71G97-C:&%K96QD+@!!9')E<P!!9')E
M<V)O96L`0F5H965R("T@<F5C:'1E;B!V;V]R(&%N9&5R92!G96)R=6EK97)S
M(&EN<W1E;&QE;@!"96AE97(`061V97)T96YT:65S`$%F9V%N:7-T86X`06QB
M86YIZP!!;&=E<FEJ90!!;&EA<P!5:71L:6IN96X`56ET;&EJ;FEN9SH`06QL
M90!!;&QE(&=E875T:&5N=&EC965R9&4@9V5B<G5I:V5R<P!!;&QE(&=R;V5P
M96X`06QL92!R96-H=&5N`$%L;&4@=FEE<B!Z:6ID96X`365E<F1E<F4@861R
M97-S96X@=&]E<W1A86X`26YS=&5L;&5N('9A;B!G96]R9&5N9&4@;&EJ<W0@
M='EP92!T;V5S=&%A;C\`0F5S=&%A="!A;`!!;'1E<FYA=&EE=F4@24U34"!A
M86YM96QD:6YG`$%L=&5R;F%T:65F($E-4U`@=V%C:'1W;V]R9`!!;'1E<FYA
M=&EE=F4@24U34"!G96)R=6EK97)S;F%A;0!!;'1E<FYA=&EE9B!E+6UA:6QA
M9')E<P!!;'1E<FYA=&EE=F4@<VIA8FQO;F5N`$%L=&5R;F%T:65V92!T96MS
M=#H`06UE<FEK86%N<R!386UO80!%96X@;VYG96QD:6=E('=A87)D92!O<&=E
M9V5V96XN`$5R(&AE969T('II8V@@965N(&]N8F5K96YD969O=70@=F]O<F=E
M9&%A;BX`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;FEE;64@<')O>'D`
M06YT=V]O<F0`06YT87)C=&EC80!!;G1I9W5A(&5N($)A<F)U9&$`5&]E<&%S
M<VEN9P!4;V5P87-S:6YG96YL:6IS=`!4;V5P87-S:6YG(&ES(&=E<F5E9"X`
M3W`@8VAI;&1S:&%R97,@=&]E<&%S<V5N`$=O961K975R96X`1V5S8VAA='1E
M(&=R;V]T=&4`07!R:6P`07)A8FES8V@@*%=I;F1O=W,M,3(U-BD`07)C:&EE
M9F)E<W1A;F1S9W)O;W1T90!!<F-H:65F;F%A;0!7965T('4@>F5K97(@9&%T
M('4@:&5T(&%A;FUE;&1I;F=S=F5R>F]E:R!V86X@)7,@=VEL="!V97)W:6ID
M97)E;C\`5V5E="!U('IE:V5R(&1A="!U("(E<R(@96X@86QL92!S=6)G<F]E
M<&5N('=I;'0@=F5R=VEJ9&5R96X_`$%R9V5N=&EN:>L`07)M96YIZP!!<FUE
M96YS("A!4DU30TE)+3@I`$MU;G-T`$%R=6)A`$%S8V5N<VEO;B!E:6QA;F0`
M07-C:6D@:W5N<W0`07IIZR]086-I9FES8VAE(%)E9VEO`$]M(&)E=F5S=&EG
M:6YG('9R86=E;B!V;V]R(&AE="!U:71V;V5R96X@=F%N(&]N9&5R:&]U9'-W
M97)K>F%A;6AE9&5N/P!/<&1R86-H="!K;VQO;6UE;@!0;V=I;F<@;VT@965N
M(&YI970@8F5S=&%A;F1E(&=R;V5P('1E('9E<G=I:F1E<F5N+@!0;V=I;F<@
M;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@=F5R=VEJ9&5R96XN`%!O
M9VEN9R!O;2!E96X@;FEE="!B97-T86%N9"!R96-H="!T92!B97=E<FME;BX`
M4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD92!S:&%R92!T92!B97=E<FME
M;BX`071T<FEB=71E;@!!=6=U<W1U<P!!=7-T<F%L:>L`3V]S=&5N<FEJ:P!!
M=71H7V-Y<G-Q;#H@=F5R96ES=&4@:6UA<"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+@!!=71H7V-Y<G5S.B!B86-K96YD(&AE969T(&YI970@9&4@=F5R96ES
M=&4@8F5K=V%A;6AE9&5N+@!!=71H7V-Y<G5S.B!V97)E:7-T92!I;6%P(&5X
M=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?9G1P.B!V97)E:7-T92!&5%`@
M97AT96YT:64@;FEE="!G979O;F1E;BX@0V]M<&EL965R(%!(4"!M970@9&4@
M+2UE;F%B;&4M9G1P(&]P=&EE+@!!=71H7VEM87`Z('9E<F5I<W1E($E-05`@
M97AT96YT:64@;FEE="!G979O;F1E;BX`075T:%]K<F(U.B!V97)E:7-T92!K
M<F(U(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?;&1A<#H@=&]E=F]E
M9V5N('9A;B!G96)R=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@5F5R=VEJ9&5R96X@=F%N
M(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O;F1E<G-T975N9"!V;V]R($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!V97)E:7-T92!,1$%0(&5X=&5N=&EE
M(&YI970@9V5V;VYD96XN`$%U=&A?;&1A<#H@3FEE="!I;B!S=&%A="!G96)R
M=6EK97(@)7,@=&]E('1E('9O96=E;BX@1&4@<V5R=F5R(&UE;&1T.B``075T
M:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!T92!V97)W:6ID
M97)E;@!!=71H7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I:V5R("5S(&)I
M:B!T92!W97)K96X`075T:%]L9&%P.B!":6IW97)K96X@=F%N(&=E8G)U:6ME
M<G,@=V]R9'0@;FEE="!O;F1E<G-T975N9"!V;V]R($%C=&EV92!$:7)E8W1O
M<GDN`$%U=&A?;6-A;#H@=F5R96ES=&4@34-!3"!E>'1E;G1I92!N:65T(&=E
M=F]N9&5N+@!!=71H7W-M8F%U=&@Z('9E<F5I<W1E('-M8F%U=&@@97AT96YT
M:64@;FEE="!G979O;F1E;BX`075T:&5N=&EC871I92!O<"!)34%0('-E<G9E
M<B!M:7-L=6MT+@!!=71H96YT:6-A=&EE(&UI<VQU:W0`075T:&5N=&EC871I
M92!M:7-L=6MT+B`E<P!!=71H96YT:6-A=&EE(&=E=V5I9V5R9"!D;V]R(&1E
M(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:64@;W`@1E10('-E<G9E<B!M
M:7-L=6MT+@!!=71H96YT:6-A=&EE(&]P(&1E(%--0B!S97)V97(@;6ES;'5K
M="X`0F5S8VAI:V)A<F4@=F5L9&5N.@!!>F5R8F%I9'IJ86X`0D]&2"!%>&-U
M<V5S`$%C:'1E<F=R;VYD`$%C:'1E<F=R;VYD:VQE=7(`1F]U="!K97)B97)O
M<W=A8VAT=V]O<F0N`$9O=71E(&ME<F)E<F]S9V5B<G5I:V5R<VYA86TN`$)A
M:&%M87,`0F%H<F5I;@!"86QT:7-C:"`H25-/+3@X-3DM,3,I`$)A;F=L861E
M<V@`0F%R8F%D;W,`0F%S:7,@869B965L9&EN9V5N9&ER96-T;W)Y("(E<R(@
M;FEE="!G979O;F1E;BX`0F%S:7-L:6IN`%=I="!R=7-L86YD`$)E;&=IZP!"
M96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`5F5R:F%A<F1A9P!";&]K("(E
M<R(@=F%N('1O97!A<W-I;F<@(B5S(B!N:65T(&=E=F]N9&5N+@!";&]K:6YS
M=&5L;&EN9V5N`$)L;VMT>7!E`%9E=`!";VQI=FEA`$)O;VMM87)K<P!286YD
M`%)A;F1D:6MT93H`4F%N9&5N`$)O<VYIZR!E;B!(97)Z96=O=FEN80!"96ED
M96X`0F]T<W=A;F$`3VYD97)K86YT`$)O=79E="!E:6QA;F0`0G)A>FEL:>L`
M0G)I=',@26YD:7-C:&4@3V-E86%N(%1E<G)I=&]R:75M`$)R=6YE:2!$87)U
M<W-A;&%M`$)U;&=A<FEJ90!/;F=E;W)D96YD92!L:6IS=`!"=7)K:6YA($9A
M<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I97!U;G1E;@!#7V5L
M96EG96YS8VAA<'!E;BXN+@!#86-H92!I;FET:6%L:7-A=&EE(&ES(&YI970@
M869G97)O;F0N`$%G96YD80!+86QM`$-A;6)O9&IA`$MA;65R;V5N`$MA;B!W
M86-H='=O;W)D(&YI970@875T;VUA=&ES8V@@<F5S971T96XL(&YE96T@8V]N
M=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BX`2V%N(&YI970@;F%A
M<B!B97-T86YD("(E<R(@<V-H<FEJ=F5N`$MA;B!G965N(&5X=&5R;F4@<V5S
M<VEE:&%N9&QE<B!B96AE<F5N+@!+86X@;FEE="!V97)B:6YD96X@;65T($E-
M05`@<V5R=F5R.B`E<P!+86X@8F5S=&%N9"`B)7,B(&YI970@;W!E;F5N+@!#
M86YA9&$`069B<F5K96X`4')O8FQE96UR87!P;W)T(&%F8G)E:V5N`$MA;B!B
M97-T86YD("(E<R(@;FEE="!V97)W:6ID97)E;BX`2V%N(&=E96X@=&EJ9&5L
M:6IK92!D:7)E8W1O<GD@=FEN9&5N+@!+86X@;FEE="!D;V]R9V%A;B!Z;VYD
M97(@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`2V%N(&1I<F5C=&]R>2`B)7,B
M(&YI970@=F5R=VEJ9&5R96XN`$MA;B!N:65T('9E<G=I:F1E<F5N.R`E9"!C
M:&EL9')E;B!B97-T86%N+@!+86X@;FEE="!O<&YI975W(')A;F=S8VAI:VME
M;BP@:&5T(&%A;G1A;"!I;G9O97)E;B!O;2!O<&YI975W('1E(')A;F=S8VAI
M:VME;B!K;VUT(&YI970@;W9E<F5E;B!M970@:&5T(&]P9V5S;&%G96X@86%N
M=&%L+@!+86X@8F5R:6-H="!N:65T(&YA87(@:&5T(&]P9V5G979E;B!N=6UM
M97(@=F5R<W1U<F5N+@!+86%P(%9E<F1E`$]P<V-H<FEF=`!$<F%G97(`0V%T
M96=O<FEEZVX@96X@;&%B96QS`$-A>6UA;B!E:6QA;F1E;@!496PN;G(N;6]B
M:65L`$-E;&5I9V5N<V-H87!P96X`0V5L('9R:6IE(')U:6UT93H`0V5L96EG
M96YS8VAA<'!E;@!#96QS<&%T:>MR:6YG.@!496PN;G(N;6]B:65L`$ME;'1I
M<V-H("A)4T\M.#@U.2TQ-"D`36ED9&5N`$-E;G1R86%L($%F<FEK86%N<V4@
M4F5P=6)L:65K`$-E;G1R86%L($5U<F]P965S("A)4T\M.#@U.2TR*0!#97)T
M:69I8V%A=&1E=&%I;',`0V5R=&EF:6-A871E:6=E;F%A<@!#97)T:69I8V%A
M=&)E;&5I9`!4<VIA860`5VEJ>FEG96X`5VEJ>FEG('5W('=A8VAT=V]O<F0`
M5VEJ>FEG(&1E(&YA86TL(&%D<F5S(&5N(&]N9&5R=&5K96YI;F<@9&EE(&UE
M;B!Z:65T(&)I:B!H970@;&5Z96X@96X@8F5A;G1W;V]R9&5N('9A;B!U=R!E
M+6UA:6QS+@!7:6IZ:6=E;B!V86X@=7<@=V%C:'1W;V]R9"!W;W)D="!N:65T
M(&]N9&5R<W1E=6YD(&1O;W(@9&4@:'5I9&EG92!C;VYF:6=U<F%T:64N($YE
M96T@8V]N=&%C="!O<"!M970@=7<@<WES=&5E;6)E:&5E<F1E<BX`2V%R86MT
M97(`0V]N=%]R;VQE97(@;&EN:RXN+@!#:&EL:0!#:&EN80!#:&EN965S('9E
M<F5E;G9O=61I9V0@*$=",C,Q,BD`0VAI;F5E<R!T<F%D:71I;VYE96P@*$)I
M9S4I`$MI97,@=&]E<&%S<VEN9SH`2VEE<R!E96X@=V%C:'1W;V]R9`!+:65S
M(&5E;B!G96)R=6EK97)S;F%A;0!+:65S(&1A='5M=V5E<F=A=F4Z`$MI97,@
M;&EJ<W1S=&EJ;'1Y<&4@*'9O;W(@9V5O<F1E;F1E(&QI:G-T96XI`$-H<FES
M=&UA<R!E:6QA;F0`0VQA<W-D969I;FET:64@=F%N("5S(&YI970@9V5V;VYD
M96XN`$AE;&1E<@!-4T]F9FEC92!T86=S('=I<W-E;@!7:7,@<75E<GD`5VES
M(&=E8G)U:6ME<CH@)7,`5VES(&=E8G)U:6ME<@!7:7,@9V5B<G5I:V5R<V1A
M=&$`3&%T92!O<&ML87)I;F=E;@!+;&EK(&]M('9E<F1E<B!T92!G86%N`$-L
M:6-K871E;&P@=FEA($A45%``4VQU:70@<V-H97)M`%=O;&ME;@!6<F]E9V4@
M8F5W;VQK:6YG`$)E=V]L:W0`0V]C;W,@*$ME96QI;F<I(&5I;&%N9&5N`%II
M:F)A;&L@:6YK;&%P<&5N`$EN9V5K;&%P=&4@<F%N9&5N`$-O;&]M8FEA`$ML
M975R`$ML975R96YK:65Z97(`2VQE=7)S96QE8W1I90!+;VQO;6UE;CH`2V]L
M;VUT:71E;',`4W1R:7!S`$]P9')A8VAT`$]P9')A8VAT<VAE;&P`3W!M97)K
M:6YG`$%L9V5M96YE(&YA86T`0V]M;W)E;@!"961R:6IF`$-O;7!U=&5R<P!#
M;VYD:71I90!#;VYD:71I97,`5F5R<V-H:6QL96X@:6X@8V]N9FEG=7)A=&EE
M`$-O;F9I9W5R871I92!V;V]R(&AE="!S>6YC:')O;FES97)E;B!M970@4$1!
M)W,L(%-M87)T<&AO;F5S(&5N($]U=&QO;VLN`$-O;F9I9W5R871I92!I<R!V
M97)O=61E<F0N`"5S(&-O;F9I9W5R97)E;@!"979E<W1I9R!W86-H='=O;W)D
M`$MO;F=O`$MO;F=O+"!$92!$96UO8W)A=&ES8VAE(%)E<'5B;&EE:R!V86X@
M9&4`5F5R8FEN9&EN9R!M:7-L=6MT+@!697)B:6YD:6YG(&UI<VQU:W0Z(`!6
M97)B:6YD:6YG+"!M970@9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E<BP@:7,@
M9V5W96EG97)D+@!697)B:6YD:6YG+"!M970@9&4@;W!E;F)A<F4@<VQE=71E
M;'-E<G9E<BP@:7,@9V5W96EG97)D+B!2961E;CH@)7,@*"5S*0!697)B:6YD
M:6YG(&UE="!&5%`@<V5R=F5R(&UI<VQU:W0N`$%D<F5S<V5N`$%D<F5S<V5N
M('II:FX@;65T('-U8V-E<R!A86X@=7<@861R97-B;V5K('1O96=E=F]E9V0N
M`$-O;G1E;G0@='EP92!V86X@9V5C;VUP<FEM965R9"!B97-T86YD.B``26YH
M;W5D('9A;B`B)7,B`$1O;W)G86%N`$-O;VL@96EL86YD96X`0V]O:VEE`$MO
M<&GK<F5N`$MO<&GK<F5N(&UI<VQU:W0Z("5S`$MO<&EE97(@<V5L96-T:64`
M2V]S=&5N($E$`$-O<W1A(%)I8V$`279O;W)K=7-T`$MO;B!01U`@8F5R:6-H
M="!N:65T(&-O9&5R96XZ(`!+;VX@4$=0(&)E<FEC:'0@;FEE="!O;F1E<G1E
M:V5N96XZ(`!+;VX@8F5R:6-H="!N:65T(%,O34E-12!C;V1E<F5N+@!+;VX@
M8F5R:6-H="!N:65T(%,O34E-12!O;F1E<G1E:V5N96XN`$MO;B!A9')E<R`E
M<R!N:65T('1O979O96=E;BX`2V]N(&=E96X@=F5R8FEN9&EN9R!M970@9&4@
M3$1!4"US97)V97(@;6%K96XN`$MO;B!T96=O960@)7,@;FEE="!C;VYT<F]L
M97)E;BX`2V]N(&YI970@=F5R8FEN9&5N(&UE="!,1$%0('-E<G9E<BX`2V]N
M(&YI970@=F5R8FEN9&5N(&UE="!S97)V97(@(B5S(B!M970@1E10.B`E<P!+
M;VX@9V5E;B!D:7-T<FEB=71I96QI:G-T("5S(&UA:V5N+@!+;VX@4$=0(&1A
M=&$@;FEE="!D96-O9&5R96XZ(`!+;VX@4R]-24U%(&1A=&$@;FEE="!D96-O
M9&5R96XN`$MO;B!A9')E<R`E<R!N:65T('9E<G=I:F1E<F5N+@!+;VX@9&ES
M=')I8G5T:65L:6IS="`E<R!N:65T('9E<G=I:F1E<F5N+@!+;VX@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(B!N:65T('9E<G=I:F1E<F5N+@!+;VX@:&5T
M(&4M;6%I;&%D<F5S('9A;B!D92!O;G1V86YG97(@;FEE="!B97!A;&5N+@!+
M;VX@8V]M<&QE=&4@861R97-B;V5K(&YI970@;W!H86QE;BX`2V]N(&-O;7!L
M971E(&1I<W1R:6)U=&EE;&EJ<W0@;FEE="!O<&AA;&5N+@!+;VX@8V]M<&QE
M=&4@;&EJ<W0@=F%N(&1I<W1R:6)U=&EE;&EJ<W1E;B!N:65T(&]P:&%L96XN
M`$MO;B!S=')A=&5G:64@(B5S(B!N:65T(&QA9&5N+@!+;VX@9&ER96-T;W)Y
M("(E<R(@;FEE="!M86ME;BX`2V]N(&1E(&]P96YB87)E('-L975T96P@;FEE
M="!V97)K<FEJ9V5N('9A;B!D92!S;&5U=&5L<V5R=F5R+@!+;VX@(B5S(B!N
M:65T(&]P96YE;B!V;V]R('-C:')I:G9E;BX`2V]N("5S(&YI970@;W!E;F5N
M+@!+;VX@;VYD97)H;W5D<W1A:V5N;6]D=6QE("5S(&YI970@;W!E;F5N`$MO
M;B!D:7)E8W1O<GD@(B5S(B!N:65T(&]P96YE;BX`2V]N(&1E($Q$05`M<V5R
M=F5R(&YI970@8F5R96EK96XN`$MO;B`E<R!N:65T(&QE>F5N+@!+;VX@:&5T
M('=A8VAT=V]O<F0@=F%N(&1E(&=E=V5N<W1E(&=E8G)U:6ME<B!N:65T(')E
M<V5T=&5N+B!3;VUM:6=E(&]F(&%L;&4@9&5T86EL<R!Z:6IN(&YI970@:G5I
M<W0N(%!R;V)E97(@;W!N:65U=R!O9B!N965M(&-O;G1A8W0@;W`@;65T(&1E
M('-Y<W1E96UB96AE97)D97(L('=A;FYE97(@=2!V97)D97)E(&AU;'`@;F]D
M:6<@:&5E9G0N`$MO;B!!0TP@;FEE="!O<&AA;&5N`$MO;B!A9')E<V)O96L@
M)7,@;FEE="!O<&AA;&5N+@!+;VX@9&ES=')I8G5T:65L:6IS="`E<R!N:65T
M(&]P:&%L96XN`$MO;B!D:7-T<FEB=71I96QI:G-T96X@)7,@;FEE="!O<&AA
M;&5N+@!+;VX@<V5R=F5R8F5K=V%A;6AE9&5N(&YI970@;W!H86QE;@!+;VX@
M8V]N9FEG=7)A=&EE(&YI970@=&5R=6=Z971T96XN`$MO;B!D:7)E8W1O<GD@
M(B5S(B!N:65T('9E<G=I:F1E<F5N+@!+;VX@8V]N9FEG=7)A=&EE("5S(&YI
M970@;W!S;&%A;BX`2V]N(&=E96X@8F%C:W5P8V]N9FEG=7)A=&EE(&]P<VQA
M86XN`$MO;B!G965N(&)A8VMU<&-O;F9I9W5R871I92!O<'-L86%N.B`E<P!+
M;VX@<V5T=7`@=7!G<F%D92!S8W)I<'0@;FEE="!O<'-L86%N(&%L<SH@(B5S
M(BX`2V]N(&AE="!B86-K=7!C;VYF:6=U<F%T:65B97-T86YD(&YI970@;W!S
M;&%A;B`E<RX`2V]N(&AE="!C;VYF:6=U<F%T:65B97-T86YD("5S(&YI970@
M;W!S;&%A;BX@52!K=6YT(&]F(.OK;B!V86X@9&4@;W!T:65S(&=E8G)U:6ME
M;B!O;2!D92!C;V1E('1E<G5G(&]P('1E('-L86%N(&]P("5S(&]F(&]N9&5R
M<W1A86YD92!C;V1E(&AA;F1M871I9R!N86%R("5S(&MO<&GK<F5N+@!+;VX@
M9&4@3$1!4"US97)V97(@;FEE="!D;V]R>F]E:V5N+@!+;VX@(B5S(B!N:65T
M(&QO<VMO<'!E;&5N+@!+;VX@861R97,@)7,@;FEE="!B:6IW97)K96XN`$MO
M;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@8FEJ=V5R:V5N+@!+;VX@8V]N
M9FEG=7)A=&EE('9O;W(@(B5S(B!N:65T('=E9W-C:')I:G9E;CH@)7,`2V]N
M(&1E($UO>FEL;&$@4VED96)A<B!N:65T('9I;F1E;BX@6F]R9R!E<G9O;W(@
M9&%T(&1E('-I9&5B87(@;W!E;B!I<RX`2V]N(&=E8G)U:6ME<B`B)7,B(&1E
M('9O;&=E;F1E(')E8VAT96X@;W`@9&4@;6%P("(E<R(@;FEE="!G979E;CH@
M)7,`1V5T96QD92!T96MS=`!,86YD`$-U<G-U<W-E;@!-86ME;@!-86%K(&5E
M;B!L:6YK`$UA86L@965N(&YI975W90!-86%K('-U8FUA<'!E;@!%:6=E;F%A
M<G)E8VAT96X`0W)E9&ET8V%R9&YU;6UE<@!+<F]A=&GK`$-U8F$`2'5I9&EG
M92`T(&9A<V5N`$AU:61I9V4@<V5S<VEE<P!(=6ED:6=E('1I:F0`2'5I9&EG
M92!54DP@:7,`2'5I9&EG92!G96)R=6EK97)S`$AU:61I9R!W965R`$AU:61I
M9V4@8V]N9&ET:64Z(`!(=6ED:6=E('-T:6IL`$%A;G!A<W-E;B!V86X@=&%K
M96X@=&EJ9&5N<R!A86YM96QD:6YG(&)I:B`E<RX`2VYI<'!E;@!396QE8W1I
M92!K;FEP<&5N`$-Y<')U<P!#>7)I;&QI<V-H("A+3TDX+5(I`$-Y<FEL;&ES
M8V@@*%=I;F1O=W,M,3(U,2D`0WER:6QL:7-C:"]5:W)A:6YS("A+3TDX+54I
M`%1S:F5C:&ES8VAE(%)E<'5B;&EE:P!$1`!$4TX@*'II92!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`$1A9V5L:6IK<P!$871A5')E92!B<F]W<V5R`$1A=&%B87-E
M(&1O;W)Z;V5K96X`1&%T=6T`1&%T=6T@3VYT=F%N9V5N`$1A='5M('-E;&5C
M=&EE`$1A9P!697)?=VEJ9&5R(&MO;&]M`$1E8V5M8F5R`$1E8VEM86QE(&=E
M=&%L;&5N`$EN<W!R:6YG96X@=F5R:VQE:6YE;@!3=&%N9&%A<F0`4W1A;F1A
M87)D(&ML975R`%-T86YD86%R9"!I9&5N=&ET96ET`%-T86YD86%R9"!S:&5L
M;`!$969I;FET:65S`%9E<G=I:F1E<F5N`%9E<G=I:F1E<B!C96P`1W)O97`@
M=F5R=VEJ9&5R96X`5F5R=VEJ9&5R(&QO9P!296-H="!V97)W:6ID97)E;@!6
M97)W:6ID97(@96X@=VES(&)E<FEC:'1E;@!697)W:6ID97(@8V5L`%9E<G=I
M:F1E<B!K;VQO;0!"97-T86%N9"!A;'1E<FYA=&EE9B!S:F%B;&]O;B!V97)W
M:6ID97)E;@!697)W:6ID97(@8F5R:6-H=&5N`%)E8VAT96X@=F%N("(E<R(@
M=F5R=VEJ9&5R96X`4F5C:'1E;B!E;B!E=F5N='5E;&4@<W5B<F5C:'1E;B!V
M;V]R("(E<R(@=F5R=VEJ9&5R96X_`%9E<G=I:F1E<B!R:6H`1V5S96QE8W1E
M97)D92!I9&5N=&ET96ET('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!S=6)M87!P
M96X`5F5R=VEJ9&5R(&1E(&AU:61I9V4@:V]L;VT`5F5R=VEJ9&5R(&1E(&AU
M:61I9V4@<FEJ`%-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(@=F5R=VEJ9&5R
M9"X`069L979E<G1I:F0`1&5N96UA<FME;@!"97-C:')I:F8@:&5T('!R;V)L
M965M`$)E<V-H<FEJ=FEN9P!$971A:6QS("AO;VL@:6X@2&]R9&4G<R!L;V=B
M97-T86YD*3H`1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E96UB
M96AE97)D97(N`$]N='=I:VME;&EN9P!$875W<'5N=`!$875W<'5N="!V;V]R
M(&AE="!A9F=E;&]P96X@=75R.B``1&%U=W!U;G0Z(`!2:6-H=&EN9R!L:6YK
M<R!N86%R(')E8VAT`%)I8VAT:6YG(')E8VAT<R!N86%R(&QI;FMS`$1I<F5C
M=&]R>0`R-"UU=7)S('1I:F1W965R9V%V93\`5V5E<F=A=F5O<'1I97,`1V5D
M971A:6QL965R9&4@=V5E<G-V;V]R<W!E;&QI;F<@=&]N96X`5V5E<G-V;V]R
M<W!E;&QI;F<@=&]N96X@*%1!1BD`5V5E<F=A=F5F;W)M86%T`%9O;W)B97)E
M:61I;F=S;F]T:69I8V%T:64`1&II8F]U=&D`3FEE="!V97)W:6ID97)E;@!M
M86EN=&5N86YC92YP:'`@;FEE="!D:7)E8W0@86%N<W!R96ME;@!"979A="!D
M92!E97)S=&4@<FEJ(&1E('9E;&1N86UE;C\@6F\@:F$L(&1I="!H;VMJ92!A
M86YV:6YK96XZ`$1O;6EN:6-A`$1O;6EN:6-A86YS92!297!U8FQI96L`1V5E
M;B!A8V-O=6YT/R!38VAR:6IF('4@:6XN`$1O=VYL;V%D96X`)7,@9&]W;FQO
M861E;@!$;W=N;&]A9"!G96=E;F5R965R9&4@8V]N9FEG=7)A=&EE(&%L<R!0
M2%`@<V-R:7!T+@!$<F]P(&1O=VX@;&EJ<W0`1')U9W,`12U-86EL`$4M;6%I
M;"!N86%R(%--4R!G871E=V%Y('-T=75R<')O9W)A;6UA+"!V;V]R(&1R86=E
M<G,@9&EE(&1E>F4@<V5R=FEC92!O;F1E<G-T975N96XN`$524@!%8W5A9&]R
M`$)E=V5R:V5N`$)L;VL@8F5W97)K96X`1W)O97`@8F5W97)K96X`4F5C:'0@
M8F5W97)K96X`4F5C:'1E;B!B97=E<FME;@!296-H=&5N('9A;B`G)7,G(&)E
M=V5R:V5N`$]P=&EE<R!B97=E<FME;B!V;V]R.@!296-H=&5N('9A;B`B)7,B
M(&)E=V5R:V5N`%)E8VAT96X@=F%N("5S(&)E=V5R:V5N`$]N9&5R=VEJ<P!%
M9WEP=&4`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+6UA:6P`12UM86EL
M861R97,`12UM86EL861R97-S96X@;6]E=&5N(&]V97)E96YK;VUE;BX`12UM
M86EL(&UE="!B979E<W1I9VEN9P!%+6UA:6P@;F%A<B!335,@9V%T97=A>0!%
M;6]T:6-O;G,`3&5E9R!B97)I8VAT+@!'965N(')E<W5L=&%A="X`3&5G92!Z
M;V5K=&5R;65N`$EN=F]E9V5N('9A;B!A9F)E96QD:6YG96X@=6ET(&9O=&]A
M;&)U;7,@:6X@=&5K<W0@:6YS8VAA:V5L96X_`%)E8VAT:VQI:VME;B!C;VYT
M97AT(&UE;G4@:6YS8VAA:V5L96X_`$5I;F1J86%R`%9E<F=R;V]T(&5D:71O
M<@!'965F(&5E;B!B979E:6QI9VEN9W-V<F%A9R!D:64@=2!G979R86%G9"!W
M;W)D="P@=V%N;F5E<B!H970@;F]D:6<@:7,@;VT@=7<@=V%C:'1W;V]R9"!T
M92!R97-E='1E;BP@8BYV+B`G=V%T(&ES(&1E(&YA86T@=F%N('5W(&AU:7-D
M:65R/R<Z`%9O97(@9&4@869B965L9&EN9R!54DP@:&EE<B!I;@!6;V5R(&]N
M9&5R<W1A86YD92!L971T97)S(&EN.@!%<75A=&]R:6%A;"!'=6EN964`17)I
M=')E80!&;W5T`$9O=70@8FEJ(&UA:V5N('9A;B!B;&]K.B`E<P!&;W5T(&)I
M:B!V97)W:6ID97)E;B!V86X@<WEN8R!A;FME<CH@)7,`1F]U="!B:6H@=F5R
M=VEJ9&5R96X@=F%N('-Y;F,@;&]G.B`E<P!&;W5T(&)I:B!O<&AA;&5N('9A
M;B!I;FAO=60Z("5S`$9O=70@8FEJ(&)I:G=E<FME;B!V86X@=V%C:'1W;V]R
M9#H@)7,`1F]U="!M970@92UM86EL8F5R:6-H="X`1F]U="!B:6H@<V-H<FEJ
M=F5N('9A;B`B)7,B+@!%<W1L86YD`$5T:&EO<&GK`$5T;FES8V@`175R;W!A
M`$5L:V4@,34@;6EN=71E;@!%;&ME(#(@;6EN=71E;@!%;&ME(#,P('-E8V]N
M9&5N`$5L:V4@-2!M:6YU=&5N`$5L:V4@86%N;65L9&EN9P!%;&L@:&%L9B!U
M=7(`16QK92!M:6YU=70`5F]O<F)E96QD=V%A<F1E;CH`56ET=F]E<F5N`%5I
M=&ML87!P96X`6FEJ8F%L:R!U:71K;&%P<&5N`%9E<G=A8VAT=&4@)RDG`%9E
M<G=A8VAT=&4@96YK96P@=V]O<F0@;V8@86%N9V5H86%L9&4@>F]E:W1E<FT`
M5F5R=F%L9&%T=6T`17AP;VYE;G0`5F]O<F=R;VYD:VQE=7(`1E10('5P;&]A
M9"!V86X@<V5T=7``3W!H86QE;B!V;V]R:V5U<G-I;G-T96QL:6YG96X@;6ES
M;'5K="X`5F5R8FEN9&EN9R!M970@9&4@3$1!4"US97)V97(@:7,@;6ES;'5K
M="X`5F5R8FEN9&EN9R!M970@9&4@4TU"+7-E<G9E<B!I<R!M:7-L=6MT+@!+
M;W!IZW)E;B!U:70@(B5S(B!I<R!M:7-L=6MT+@!+;W!IZW)E;B!N86%R("(E
M<R(@:7,@;6ES;'5K="X`36%K96X@=F%N(&YI975W92!305-,('9E<F)I;F1I
M;F<@:7,@;6ES;'5K="X`5F5R<&QA871S96X@;F%A<B`B)7,B(&ES(&UI<VQU
M:W0N`$]P:&%L96X@=F%N("5S(&ES(&UI<VQU:W0`36]O:0!&86QK;&%N9"!E
M:6QA;F1E;B`H36%L=FEN87,I`$9A<F_K<B!E:6QA;F1E;@!&871A;&4@9F]U
M=#H`1F%X`$9A>&5N`$9E8G)U87)I`%9O96QT(&%L<P!6;V5L="!A;',Z(`!%
M;FME;&4@8G5I96X`16YI9V4@<VYE975W8G5I96X`5F5L9&UA=')I>`!&:6=L
M970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$)E<W1A;F0`06%N=&%L(&)E
M<W1A;F1E;CH@)7,@8F5S=&%N9`!!86YT86P@8F5S=&%N9&5N.B`E<R!B97-T
M86YD96X`0F5S=&%N9&)E:&5E<@!"97-T86YD<VYA86T`0F5S=&%N9"!K:65Z
M96X`0F5S=&%N9'5P;&]A9`!"97-T86YD=7!L;V%D<R!W;W)D96X@;FEE="!O
M;F1E<G-T975N9"X`1FEL=&5R<P!&:6YL86YD`$5E<G-T92!H96QF=`!%97)S
M=&4@:W=A<G1A86P`5F5R:&]U9&EN9R!H97)S=&5L;&5N`$]M:V5R96X`1')I
M:G9E;@!-:7-T`$UA<"`E<R!B97-T86%T(&YI970`1F]N=&ML975R`%9O961S
M96P`5F]O<B!B<F]W<V5R<R!D:64@9V5E;B!A9F)E96QD:6YG96X@;VYD97)S
M=&5U;F5N`%=E97)S=F]O<G-P96QL:6YG("A4048I`%9O;W)U:71Z:6-H=&1A
M9V5N("AM97)K(&]P(&1A="!H970@9V5G979E;B!V;V]R=6ET>FEC:'0@9&%G
M96X@96X@;F%C:'1E;B!G965F=#L@965N(&=R;V]T(&%A;G1A;"!K86X@<F5S
M=6QT97)E;B!I;B!E96X@8G)E960@8FQO:RD`57<@=V%C:'1W;V]R9"!V97)G
M971E;C\`1F]R;75L:65R96X`1F]R='5N90!&;W)T=6YE='EP90!&;W)T=6YE
M<P!&;W)T=6YE<R`R`$9O<G5M<P!$;V]R<W1U<F5N`%9R`$9R86UE<P!&<F%N
M:W)I:FL`1G)A;FMR:6IK+"!(;V]F9'-T961E;&EJ:P!&<F%N<R!'=7EA;F$`
M1G)A;G,@4&]L>6YE<VGK`$9R86YS92!:=6ED96QI:FME(%1E<G)I=&]R:6$`
M5F%N`%9A;B!D92``5F]L;&5D:6=E(&)E<V-H<FEJ=FEN9P!6;VQL92!M86%N
M`%9O;&QE9&EG92!N86%M`$=A8F]N`$%L8G5M('=A87)U:70@9&4@869B965L
M9&EN9R!G96AA86QD(&1I96YT('1E('=O<F1E;@!!;&)U;3H`1V%M8FEA`$=E
M;F5R965R("5S(&-O;F9I9W5R871I90!'96=E;F5R965R9&4@8V]D90!'96]R
M9VGK`$1U:71S;&%N9`!':&%N80!':6)R86QT87(`5F]O<FYA86T`1VQO8F%L
M92!O<'1I97,`1V$`1V]E9&5L`$=O;V=L92!K86%R=&5N`$=O;V=L92!Z;V5K
M96X`1W)I:G-S8VAA86P`1W)I96ME;FQA;F0`1W)I96MS("A)4T\M.#@U.2TW
M*0!'<F]E;FQA;F0`1W)E;F%D80!'<F]E<'-B96AE97(`1W)O97!N86UE;B!M
M;V=E;B!N:65T(&QE96<@>FEJ;@!'<F]U<%]L9&%P.B!.:65T(&EN('-T86%T
M(&=R;V5P("5S('1O92!T92!V;V5G96XN($1E('-E<G9E<B!M96QD=#H@`$=R
M;W5P7VQD87`Z($YI970@:6X@<W1A870@9W)O97`@)7,@=&4@=F5R=VEJ9&5R
M96X`1W)O=7!?;&1A<#H@3FEE="!I;B!S=&%A="!G<F]E<"`E<R!B:6H@=&4@
M=V5R:V5N`$=R;V5P96X`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R
M;G-E>0!'87-T(')E8VAT96X`1V%S=&5N8F]E:P!'=6EN964`1W5I;F5E+4)I
M<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L
M86%T<W1E(&-E;"!I;B!D92!R:6H@=&4@=F5R=VEJ9&5R96XN`$A434Q!<F5A
M('=E:6=E<G0@;&%F(&]M(&1E(&QA871S=&4@:V]L;VT@:6X@9&4@=&%B96P@
M=&4@=F5R=VEJ9&5R96XN`$A434Q!<F5A('=E:6=E<G0@;&%F(&]M(&1E(&QA
M871S=&4@<FEJ(&EN(&1E('1A8F5L('1E('9E<G=I:F1E<F5N+@!(5%10(&%U
M=&AE;G1I8V%T:64@;FEE="!G979O;F1E;BX`2&%I=&D`2&%S:"UA;&=O<FET
M:&UE`$YE=F5L`$MO<`!+;W!P96X`2&5A<F0@96EL86YD(&5N($UC1&]N86QD
M(&5I;&%N9&5N`%IW87)E(&]N=V5E<G-B=6D`2&5B<F5E=7=S("A)4T\M.#@U
M.2TX+4DI`$AO;V=T90!(96QP`$AE;'`@8FEJ(&=E8G)U:6L@=F%N(&5D:71O
M<@!(96QP97(`2&%L9G)O;F0`2&EE<B!I<R!H970@8F5G:6X@=F%N(&AE="!B
M97-T86YD.@!(;V]G`$AO7VUE`$AO;'D@4V5E("A6871I8V%A;G-T860I`$AO
M;64`061R97,@*'!R:7;I*0!(;VUE9&ER96-T;W)Y`%1E;"YN<BX@*'!R:7;I
M*0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($]N9V5L
M9&EG92`E<R!834P@9&%T82!T96=E;F=E:V]M96X@:6X@8F5R:6-H="`E<P!(
M;W)D92]+;VQA8CH@1V5E;B!B97)I8VAT(&-O<G)E<W!O;F1E97)T(&UE="!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z($=E96X@;V)J96-T('9A;B!T>7!E("5S
M(&=E=F]N9&5N(&EN(&)E<FEC:'0@)7,`2&]R9&4O2V]L86(Z("5S(&UE="!S
M=6-C97,@=F5R=VEJ9&5R9"`B)7,B`$AO<F1E+TMO;&%B.B!$92!I;G1E<F=R
M871I92!V97)E:7-T(&1E("=D;VUX;6PG(&5X=&5N<VEE`$AO<F1E+TMO;&%B
M.B!+86X@9V5E;B!N:65U=V4@6$U,(&)O;VT@;6%K96X@=F]O<B!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z($MA;B`E<R`B)7,B(&YI970@=F5R=VEJ9&5R96XZ
M("5S`$AO<F1E+TMO;&%B.B!.:65T(&EN('-T86%T(&AE="!-24U%($E$+"!V
M;V]R(&AE="!G961E96QT92!M970@='EP92`E<RP@;W`@=&4@:&%L96X`2&]R
M9&4O2V]L86(Z($MA;B`E<R`B)7,B(&YI970@<WEN8VAR;VYI<V5R96XZ("5S
M`$AO<F1E+TMO;&%B.B!+86X@9V5D965L9&4@8G)O;FYE;B!N:65T('-Y;F-H
M<F]N:7-E<F5N.B`E<P!(;W)D92]+;VQA8CH@3VYB96ME;F1E(&=E9&5E;&1E
M(&)R;VX@(B5S(@!(;W)I>F]N=&%L92!L:6IN`$AO<FEZ;VYT86QE('9R:6IE
M(')U:6UT90!(;W)I>F]N=&%A;#H`2&]E(&MW86T@=2!H:65R/R`H1W)A86<@
M<F%P<&]R=&%G92$I`$AO979E96P@:V]L;VUM96X@=VEL="!U('-A;65N=F]E
M9V5N/P!(;V5V965L('9E;&1E;B`H:V]L;VUM96XI('II:FX@97(_`$AO979E
M96P@<FEJ96X@=VEL="!U('-A;65N=F]E9V5N/P!6;V-H=&EG:&5I9`!6;V-H
M=&EG:&5I9#H@`$AU;6]R:7-T96X`2&]N9V%R:6IE`$UA:V5N('9A;B!)34%0
M(&UA:6QB;W@@;6ES;'5K=#H@)7,`5F5R=VEJ9&5R96X@=F%N($E-05`@;6%I
M;&)O>"!M:7-L=6MT.B`E<P!-86ME;B!V86X@24U!4"!M86EL8F]X('%U;W1A
M(&UI<VQU:W0Z("5S`$E0($%D<F5S`$E0(&%D<F5S(&YI970@8F5S8VAI:V)A
M87(N`$E0(&%D<F5S('9A;'0@;FEE="!B:6YN96X@:&5T('1O96=E<W1A;F4@
M0TE$4B!B;&]K+@!)4"!L;V-K9&]W;B!O=F5R=')E9&EN9RX`4FEJ(&E?;G9O
M96=E;B!V;V]R`$E*<VQA;F0`06QL965N('!I8W1O9W)A;6UE;@!0:6-T;V=R
M86UM96X@=F]O<B`E<P!0:6-T;V=R86UM96X@;65T('1E:W-T`$ED96YT:71E
M:71S;F%A;3H`5V%N;F5E<B!H970@;FEE="!G;V5D('=O<F1T('=E97)G96=E
M=F5N+"`E<R!O;2!H970@:6X@965N(&YI975W('-C:&5R;2!T92!O<&5N96XN
M`$%L<R!U(&=E96X@<&EC=&]G<F%M;65N('II970L(&)I:B!G96)R=6EK('9A
M;B!);G1E<FYE="!%>'!L;W)E<BP@:V%N(&AE="!N;V1I9R!Z:6IN(&1I="!V
M86MJ92!A86X@=&4@=FEN:V5N(&]M(%!.1R!T<F%N<W!A<F%T:64@=6ET('1E
M('-C:&%K96QE;BX`5V%N;F5E<B!U(&1I="!B97)I8VAT('II970L(&UA87(@
M9V5E;B!A9F)E96QD:6YG+"!D86X@:V%N(&1E(&%F8F5E;&1I;F<@9&EE('4@
M=VEL="!U<&QO861E;B!N:65T(&1O;W(@=7<@8G)O=W-E<B!W;W)D96X@=V5E
M<F=E9V5V96XN`$%F8F5E;&1I;F=S8F5O;W)D96QI;F<Z`$%F8F5E;&1I;F<@
M55),`$%F8F5E;&1I;F<@55),.@!!9F)E96QD:6YG('5I="!A;&)U;0!!9F)E
M96QD:6YG('5I="!A;&)U;3H`069B965L9&EN9W-U<&QO860`069B965L9&EN
M9V5N`$EM<&]R=&5R96XL('-T87`@)60`1V5I;7!O<G1E97)D('9E;&0Z("5S
M`$=E:6UP;W)T965R9&4@=F5L9&5N.@!2:6H@:6YV;V5G96X@;F$`3VYJ=6ES
M=&4@8F5W97)K:6YG<V-O9&4@;W!G96=E=F5N+@!/;FIU:7-T92!G96)R=6EK
M97)S;F%A;2!E;B]O9B!W86-H='=O;W)D+@!/;FIU:7-T92!G96)R=6EK97)S
M;F%A;2!O9B!A;'1E<FYA=&EE9B!A9')E<RX@4')O8F5E<B!O<&YI975W(&]F
M(&YE96T@8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BP@=V%N
M;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="X`5F5R9W)O;W0@:6YS
M<')I;F=I;F<`26YD:6$`26YD:79I9'5E;&4@9V5B<G5I:V5R<P!);F1O;F5S
M:>L`26YF;P!);F9O<FUA=&EE`$EN9F]R;6%T:64@;FEE="!L86YG97(@8F5S
M8VAI:V)A87(N`$MO;&]M(&EN=F]E9V5N(&YA`$%F8F5E;&1I;F<@:6YV;V5G
M96X`5&%B96P@:6YV;V5G96X`5V5B;&EN:R!I;G9O96=E;@!?2V]L;VT@:6YV
M;V5G96X@=F]O<@!%96X@;FEE=7=E(&MO;&]M(&EN=F]E9V5N(&YA(&1E(&AU
M:61I9V4`165N(&YI975W92!K;VQO;2!I;G9O96=E;B!V;V]R(&1E(&AU:61I
M9V4`165N(&YI975W92!R:6H@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%96X@
M;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H=6ED:6=E`$5E;B!N:65U=V4@
M<&%R86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4@;F]D90!%96X@;FEE
M=7=E('!A<F%G<F%A9B!I;G9O96=E;B!N82!D92!H=6ED:6=E(&YO9&4`06QT
M97)N871I968@<VIA8FQO;VX@:6YV;V5G96X`165N(&4M;6%I;&%D<F5S(&EN
M=F]E9V5N+"!W86%R('4@:&5T(&YI975W92!W86-H='=O;W)D(&MA;B!O;G1V
M86YG96XZ`$-E;"!I;G9O96=E;B!N80!#96P@:6YV;V5G96X@=F]O<@!+;VQO
M;2!I;G9O96=E;B!N80!+;VQO;2!I;G9O96=E;B!V;V]R`$)E<FEC:'1E;B!I
M;G9O96=E;@!087)A9W)A868@:6YV;V5G96X@;F$`4&%R86=R86%F(&EN=F]E
M9V5N('9O;W(`4FEJ(&EN=F]E9V5N(&YA`%)I:B!I;G9O96=E;B!V;V]R`$AE
M="!G97=E;G-T92!A;G1W;V]R9"!V;V]R(&1E(&)E=F5I;&EG:6YG<W9R86%G
M(&EN=F]E9V5N.@!!9F)E96QD:6YG(&EN=F]E9V5N+V%A;G!A<W-E;@!,:6YK
M(&EN=F]E9V5N+V%A;G!A<W-E;@!/;G9O;&1O96YD92!K<F5D:65T(&]M(&YA
M87(@9&4@9&ES=')I8G5T:65L:6IS="!T92!Z96YD96XN`$]N=F]L9&]E;F1E
M(&MR961I970`26YT96=E<@!);G1E9V5R(&QI:G-T`$]N9V5L9&EG92!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`3VYG96QD:6=E(%I)4"!D871A`$]N9V5L
M9&EG92!T;V5P87-S:6YG+@!/;F=E;&1I9R!B871C:"!)1"X`3VYG96QD:6=E
M(&1A=&$@;W!G96=E=F5N+@!/;F=E;&1I9R!B97-T96UM:6YG861R97,N`$]N
M9V5L9&EG('1I:F1F;W)M86%T`$]N9V5L9&EG92!L:6-E;G1I97-L975T96PN
M`$]N9V5L9&EG92!L;V-A=&EE(&]P9V5G979E;BX`3VYG96QD:6<@;7-G7W1Y
M<&4N`$]N9V5L9&EG(&]F(&]N=&)R96ME;F0@87!I7VED+@!/;F=E;&1I9V4@
M;V8@;VYT8G)E:V5N9&4@<&%R86UE=&5R<RX`3VYG96QD:6<@<&%R96YT(')E
M8VAT+@!/;F=E;&1I9R!P87)T;F5R(&ED+@!/;F=E;&1I9V4@<')O9'5C=&EE
M8V]D92X`3VYG96QD:6<@<')O=&]C;VPN`$]N9V5L9&EG92!O;G1V86YG97(Z
M("(E<R(`3VYG96QD:6=E(&=E9&5E;&1E(&)R;VX`3VYG96QD:6<@8G)O;F%D
M<F5S+@!/;F=E;&1I9V4@=6YI8V]D92!D871A+@!);G9E;G1A<FES`%-E;&5C
M=&EE(&]M:V5R96X`27)A;BP@27-L86UI=&ES8VAE(%)E<'5B;&EE:R!V86X`
M27)A:P!)97)L86YD`$5I;&%N9"!-86X`1V5I<V]L965R9&4@;VYW965R<V)U
M:65N`$ES<F'K;`!5:71G979E<@!#=7)S:65F`$ET86QIZP!*86UA:6-A`$IA
M;G5A<FD`2F%P86X`2F%P86YS("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A
M;FGK`$IU;&D`2G5N:0!U:71L:6IN96X`1V5C96YT<F5E<F0@=6ET;&EJ;F5N
M`%9O;&QE9&EG('5I=&QI:FYE;@!,:6YK<R!U:71L:6IN96X`4F5C:'1S('5I
M=&QI:FYE;@!+87IA8VAS=&%N`$]R:6=I;F5E;"!B96AO=61E;C\`2V5N:6$`
M2V5R8F5R;W,@<V5R=F5R('=E:6=E<F1E(&%U=&AE;G1I8V%T:64N`$ME<FYE
M;"!.97=B:65S`%-L975T96P@;6%K96X`4VQE=71E;'9I;F=E<F%F9')U:P!3
M;&5U=&5L;&5N9W1E`%-L975T96QT>7!E`%-L975T96QG96)R=6EK`$1E('-L
M975T96P@8F5S=&%A="!A;"!O<"!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R
M+@!+:6YD97)E;@!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I<V-H92!6;VQK
M<W)E<'5B;&EE:R!V86X`2V]R96$L(%)E<'5B;&EE:R!V86X`2V]R96%A;G,@
M*$550RU+4BD`2V]E=V5I=`!+>7)G:65S:>L`3U]P;6%A:P!486%L`$1E;6]C
M<F%T:7-C:&4@5F]L:W-R97!U8FQI96L@3&%O`$QA871S=&4@:&5L9G0`3&%A
M='-T92!W86-H='=O;W)D=VEJ>FEG:6YG`$QA871S=&4@:W=A<G1I97(`3&%A
M='-T(&)I:F=E=V5R:W0Z`$QA871S=&4@86%N;65L9&EN9SH@)7,`3&%A='-T
M92!A86YM96QD:6YG.B`E<R!V86X@)7,`3&%A='-T92!A86YM96QD:6YG.B!.
M;V]I=`!,971L86YD`%)E8VAT96X`3W!M86%K`$QA870@;&5E9R!V;V]R(&=E
M96X@<F%N9`!,:6)A;F]N`$QI;FMS`$QI;FMS92!K;W``3&EN:W-E('=A87)D
M96X`3&5S;W1H;P!.:79E874`3&EB97)I80!,:6)I<V-H92!!<F%B:7-C:&4@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`%IA8VAT(&)U:71J90!,:6-H=&4@
M<F5G96X`5G)O96<@;&EC:'1E(')E9V5N`$QI8VAT92!R96=E;@!,:6-H=&4@
M<F5G96YB=6D`3&EC:'1E(')E9V5N(&UE="!O;G=E97(`3&EC:'1E('-N965U
M=P!,:6-H=&4@<VYE975W8G5I`$QI;65R:6-K`$QI;FL`3&EN:R!W:6IS="!N
M86%R.@!,:6YK(&AE="!E+6UA:6QA9')E<R!A86X@9&4@;FEE=7<@8F5R:6-H
M="!P86=I;F$@=&EJ9&5N<R!W965R9V%V90!,:6YK<P!,:6YU>"!#;V]K:64`
M3&EJ<W0@+2!G96)R=6EK97(@:V%N(&1E(&UA<"!Z:65N`$1A=&%B87-E;&EJ
M<W0`3&EJ<W0@=F%N(&AE;'`@;VYD97)D96QE;@!486)E;&QI:G-T`$QI:G-T
M+4%R8VAI968`3&EJ<W0M2&5L<`!,:6IS="U)9`!,:6IS="U%:6=E;F%A<@!,
M:6IS="U0;W-T`$QI:G-T+4EN<V-H<FEJ=F5N`$QI:G-T+55I='-C:')I:G9E
M;@!7965R9V5V96X@=F%N('-E<W-I96QI:G-T(&ES(&UI<VQU:W0Z("5S`%=E
M97)G979E;B!V86X@9V5B<G5I:V5R<VQI:G-T(&ES(&UI<VQU:W0Z("5S`%=E
M97)G979E;B!V86X@9V5B<G5I:V5R<VQI:G-T(&ES('5I=&=E<V-H86ME;&0N
M`$QI=&5R871U=7(`3&ET;W5W96X`3&%D96XN+BX`3&]K86QE('1I:F0Z`$QA
M;F1I;G-T96QL:6YG(&5N('1I:F0`3&]C871I90!!86YM96QD96X`3&]G('9A
M;B!V;V]R9V%A;F1E('-Y;F,@<V5S<VEE`$%F;65L9&5N`$%A;FUE;&1E;@!!
M86YM96QD=&%K96X`06%N;65L9&EN9R!M:7-L=6MT(&]M9&%T('5W(&=E8G)U
M:6ME<G-N86%M(&]F('=A8VAT=V]O<F0@;VYJ=6ES="!I<R!I;F=E=F]E<F0N
M`$%A;FUE;&1I;F<@;6ES;'5K="X`3&%N9V4@=&5K<W0`3&EE9F1E`$QA86<`
M1W)I96MS92!K;&5I;F4@;&5T=&5R<P!,871I:FYS92!K;&5I;F4@;&5T=&5R
M<P!+;&5I;F4@4F]M96EN<V4@9V5T86QL96X`3'5X96UB=7)G`$U-`$U/5$0`
M35,M5$Y%1B!B:6IL86=E(&)E=F%T=&4@9V5E;B!D871A+@!-4T<`36%C86\`
M36%C961O;FGK+"!$92!V<F]E9V5R92!*;V5G;W-L879I<V-H92!297!U8FQI
M96L@=F%N`$UA9&%G87-C87(`36%G:64`12UM86EL`$UA:6QB96AE97)D97(`
M36%A:R!L:6Y?:RXN+@!-86QA=VD`36%L96ES:>L`36%L861I=F5N`$UA;&D`
M36%L=&$`0F5H965R('5W(&QI:G-T(&UE="!C871E9V]R:67K;B!E;B!D92!C
M;W)R97-P;VYD97)E;F1E(&ML975R96XL('=A87)M964@;VYD97)D96QE;B!W
M;W)D96X@9V5L86)E;&0`36%P,C0@:V%A<G0`36%P475E<W1K86%R=`!+;W!P
M96QI;F=E;B!O<&=E<VQA9V5N+@!-86%R=`!-87)G90!-87)K965R(&UE="!'
M97II96XO3FEE="!'97II96X@=FQA9V=E;@!-87)K965R(&UE="!A;F1E<F4@
M=FQA9V=E;B`H8BYV+B!"96QA;F=R:6IK+T)E86YT=V]O<F0I`$UA<F-H86QL
M(&5I;&%N9&5N`$UA<G1I;FEQ=64`3W9E<F5E;FMO;65N9&4@=F5L9&5N`$UA
M=7)E=&%N:>L`36%U<FET:75S`$UA>&EM86%L('1O96=E<W1A86X@:W)E9&EE
M="X`36%X:6UU;2!B97)I8VAT;VYD97)D96QE;B!O=F5R<V-H<F5D96XN`$UA
M>&EM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`R-"!U=7(Z(`!-
M87AI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@-B!U=7(Z(`!-
M87AI;75M(&%A;G1A;"!P;W)T86%L8FQO:VME;@!-87AI;75M(&QE;F=T90!-
M96D`36%Y;W1T90!'96YE97-K=6YD90!,961E;@!-96YU(&UO9&4Z`$-E;&QE
M;B!S86UE;G9O96=E;@!"97)I8VAT`$)E<FEC:'0@;65T('-U8V-E<R!G979E
M<FEF:65E<F0L(&UA87(@:&5T(&-E<G1I9FEC86%T('9A;B!D92!O;F1E<F=E
M=&5K96YD92!K;VX@;FEE="!W;W)D96X@9V5V97)I9FEE97)D+@!"97)I8VAT
M('9E<FQO<&5N+@!"97)I8VAT='EP90!-971A<B!7965R`$U%5$%2(&)L;VL@
M:7,@;FEE="!B97-C:&EK8F%A<BX`345405(@8FQO:R!I<R!N:65T(&)E<V-H
M:6MB86%R+B!$971A:6QS('II:FX@9V5L;V=D('9O;W(@9&4@<WES=&5E;6)E
M:&5E<F1E<BX`365T87)$0B!I<R!N:65T('9E<F)O;F1E;BX`365T:&]D90!-
M971H;V1E("(E<R(@:7,@;FEE="!G961E9FEN:65E<F0`365T:&]D92!I<R!N
M:65T(&=E9&5F:6YI965R9"X@06%N9V5R;V5P96X@;65T:&]D93H@)7,`365T
M<FES8V@`365X:6-O`$UI8W)O;F5S:>LL($9E9&5R86QE(%-T871E;B!V86X`
M36ED9&5N`$UI;64@='EP90!-:6YI;75M('1E;7!E<F%T=75R('9A;B!D92!A
M9F=E;&]P96X@,C0@=75R.B``36EN:6UU;2!T96UP97)A='5U<B!V86X@9&4@
M869G96QO<&5N(#8@=75R.B``36EN:6UU;2!W86-H='=O;W)D;&5E9G1I:F0@
M:7,@;F]G(&YI970@=F5R;&]P96X`36ER<F]R`$%L;&5R:&%N9&4`3VYT8G)E
M:V5N9&4@4$5!4B!M;V1U;&4@2%144%]297%U97-T+@!/;G1B<F5K96YD92!C
M;VYF:6=U<F%T:64N(%4@9&EE;G0@9&5Z92!N=2!T92!G96YE<F5R96XL('=A
M;FYE97(@=2!D97IE('1O97!A<W-I;F<@=VEL="!G96)R=6EK96XN`$]N=&)R
M96ME;F0@8F5R:6-H="!)1"X`3VYT8G)E:V5N9&4L('9E<F5I<W1E+"!014%2
M(&UO9'5L92!-86EL+@!/;G1B<F5K96YD('-E<W-I92!)1"X`36$`36]B:65L
M92!E+6UA:6P`1V5M:61D96QD`%=I:GII9VEN9W-D871U;0!7:6IZ:6<@55),
M`$UO9'5L=7,`36]L9&%V:>LL(%)E<'5B;&EE:R!V86X`36]N86-O`$UO;F=O
M;&GK`$UA86YD(&5N(&IA87(`36%A;F1E;&EJ:W,`36]N='-E<G)A=`!-86%N
M9F%S96X`365E<B!V96QD96X@:6X@<F5G96P@)60@9V5V;VYD96XL(&1A;B!D
M92!V97)W86-H='1E("5D+@!-87)O:VMO`%9O;W)N86UE;&EJ:R!O;F)E=V]L
M:W0`5F]O<FYA;65L:6IK(&)E=V]L:W0`5F]O<FYA;65L:6IK(&)E=V]L:W0@
M96X@=VEN9&5R:6<`5F]O<FYA;65L:6IK('IO;FYI9P!.86%R(&)E;F5D96X`
M3F%A<B!L:6YK<P!.86%R(')E8VAT<P!.86%R(&)O=F5N`$YA87(@8F5N961E
M;@!.86%R(&)O=F5N`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI:G-T96X`375L=&EM87`@5DL@:V%A<G0`365E<G9O=61I9V4@<V5L96-T
M:64`36EJ;B!A8V-O=6YT`%5W(&%C8V]U;G1I;F9O<FUA=&EE`$UI:FX@<&]R
M=&%A;`!-:6IN('!O<G1A86QL87EO=70`0FER;6$`3F5E+"!I:R!A8V-E<'1E
M97(@9&4@=F]O<G=A87)D96X@3DE%5`!.86%M`$YA;6EB:>L`3F%U<G4`3F5P
M86P`3F5D97)L86YD`$YE9&5R;&%N9',@06YT:6QL96X`3F5T<V-A<&4@0F%S
M:7,@55),`$YE='-C87!E($-!(&EN=')E:VMI;F<@55),`$YE='-C87!E($-!
M(&)E;&5I9"!54DP`3F5T<V-A<&4@=F5R;FEE=7=I;F<@55),`$YE='-C87!E
M(&EN=')E:VMI;F<@55),`$YE='-C87!E(%-33"!S97)V97)N86%M`$YE='-C
M87!E(&-E<G1I9FEC86%T8V]M;65N=&%A<@!.971S8V%P92!C97)T:69I8V%A
M='1Y<&4`3F5T=V5R:P!.;V]I=`!.:65U=R!#86QE9&]N:>L`3FEE=7=E(&-A
M=&5G;W)I90!.:65U=V4@;6%A;@!.:65U=V4@9V5B<G5I:V5R<VYA86T@*&]P
M=&EO;F5E;"D`3FEE=7<@6F5E;&%N9`!.:65U=R!W86-H='=O;W)D`$YI975W
M('=A8VAT=V]O<F0@>F%L('9E<FQO<&5N(&]P("5X+@!.:65U=V4@5V%C:'1W
M;V]R9&5N(&MO;65N(&YI970@;W9E<F5E;BX`3FEE=7<@<V-H97)M("A?8FQA
M;FLI`$YI975W<P!.:65U=W-G<F]E<&5N`%9O;&=E;F1E`%9O;&=E;F1E(#0@
M9F%S96X`5F]L9V5N9&4@;W!T:65S`%9O;&=E;F1E/@!.:6-A<F%G=6$`3FEG
M97(`3FEG97)I80!.86-H=`!.:75E`$YE90!'965N(&)E<V-H:6MB87)E(&-O
M;F9I9W5R871I961A=&$@;VT@=F5R<V-H:6QL96X@=&4@;&%T96X@>FEE;BX`
M1V5E;B!B97-C:&EK8F%R92!S=')A=&5G:64@=F]O<B!H970@;6%K96X@=F%N
M($E33R!I;6%G97,N`$=E96X@8F%T8VAS:F%B;&]O;BX`17(@8F5S=&%A="!G
M965N(&)L;VL@;W`@9&4@9V5V<F%A9V1E('!O<VET:64`1V5E;B!A9V5N9&%N
M86%M(&]P9V5G979E;B!V;V]R($U#04P@875T:&5N=&EC871I92X`1V5E;B!W
M:6IZ:6=I;F=E;BX`06%N(&1I="!R96-H="!K=6YN96X@9V5E;B!C:&EL9"!R
M96-H=&5N('=O<F1E;B!T;V5G979O96=D+@!'965N(&-O;F9I9W5R871I96EN
M9F]R;6%T:64@;W!G96=E=F5N('9O;W(@)7,N`$=E96X@8V]N9FEG=7)A=&EE
M:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!&5%`@5D93+@!'965N(&-O;F9I
M9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O;W(@4U%,(%9&4RX`1V5E
M;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R(%-13"UB
M97-T86YD(%9&4RX`1V5E;B!K<F5D:65T(&UE97(N`$=E96X@8F5S=&5M;6EN
M9R!O<&=E9V5V96XN`$=E96X@8F5S=&%N9"!U<&QO861E9`!'965N('!I8W1O
M9W)A;6UE;B!G979O;F1E;BX`17(@:7,@9V5E;B!L;V-A=&EE(&EN9V5S=&5L
M9"X`1V5E;B!L;V-A=&EE(&]P9V5G979E;BX`1V5E;B!B97)I8VAT(&=E;&5V
M97)D+@!'965N(&YA86T@;W!G96=E=F5N+@!'965N(&=E=&%L(&]P9V5G979E
M;BX`1V5E;B!B96QE9&EG96YD92!F;W)T=6YE<P!'965N('=A8VAT=V]O<F0@
M;W!G96=E=F5N('9O;W(@2%144"!A=71H96YT:6-A=&EE+@!'965N('=A8VAT
M=V]O<F0@;W!G96=E=F5N('9O;W(@24U!4"!A=71H96YT:6-A=&EE+@!'965N
M('=A8VAT=V]O<F0@;W!G96=E=F5N('9A;B!+97)B97)O<R!A=71H96YT:6-A
M=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@3&]G:6X@875T
M:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R(%!!
M4U-71"!A=71H96YT:6-A=&EE+@!'965N('=A8VAT=V]O<F0@;W!G96=E=F5N
M('9O;W(@4TU"(&%U=&AE;G1I8V%T:64N`$=E96X@<&%D(&YA87(@9&4@3W!E
M;E-33"!B:6YA<GD@;W!G96=E=F5N+B!$92!/<&5N4U-,(&)I;F%R>2!I<R!N
M;V1I9R!O;2!T92!K=6YN96X@=V5R:V5N(&UE="!02T-3(#$R(&1A=&$N`$=E
M96X@:&%N9V5N9&4@:6YS8VAR:6IV:6YG96XN`$=E96X@<75O=&$@:6YG97-T
M96QD+@!'965N(&QI;FGK<FEN9P!'965N('-C:&5I9&EN9W-T96ME;B!O<&=E
M9V5V96XN`$=E96X@>FEJ9&5N`$=E96X@9&5R9V5L:6IK(&)E<W1A;F0`1V5E
M;B!T:6ID96QI:FL@9&ER96-T;W)Y(&)E<V-H:6MB86%R('9O;W(@8V%C:&4N
M`$=E96X@9V5B<G5I:V5R<VYA86T@96XO;V8@=V%C:'1W;V]R9"!V97)Z;VYD
M96XN`$=E96X@9V5L9&EG92!834P@9&%T82!T97)U9V=E<W1U=7)D`$=E96X@
M=V%A<F1E;@!'965N('9E<G-I92!G979O;F1E;B!I;B!O<FEG:6YE;&4@8V]N
M9FEG=7)A=&EE+B!(97)G96YE<F5E<B!C;VYF:6=U<F%T:64N`$=E96X@=F5R
M<VEE(&=E=F]N9&5N(&EN('5W(&-O;F9I9W5R871I92X@2&5R9V5N97)E97(@
M8V]N9FEG=7)A=&EE+@!'965N`$=E96X@*'9E<G!L:6-H="D`3F]O<F0@175R
M;W!E97,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK(&5I;&%N9`!.;V]R9&5L:6IK
M(&AA;&9R;VYD`$UA<FEA;F5N`$YO;W)W96=E;@!.:65T(&YA`$YI970@=F]O
M<@!'965N(&1I<F5C=&]R>0!.:65T(&=E:6UP;&5M96YT965R9"X`3FEE="!I
M;F=E<W1E;&0`3FEE="!O;F1E<G-T975N9"X`3F]T:71I97,`3FEE=',@=&4@
M8FQA9&5R96XL(&=A('1E<G5G+@!.;W9E;6)E<@!'971A;`!!86YT86P@:V%R
M86MT97)S`$%A;G1A;"!K;VQO;6UE;@!!86YT86P@<FEJ96X`1V5T86QL96X@
M;FEE="!O<&=E9V5V96X@=F]O<B!B:6IW97)K96X@:6X@965N(&1I<W1R:6)U
M=&EE;&EJ<W0N`$]+`$]B:F5C=`!/8FIE8W1E:6=E;F%A<@!/8W1A86P`3VMT
M;V)E<@!"96QE9&EG:6YG9FEL=&5R`$MA;G1O;W(`3W5D92!E;B!N:65U=V4@
M=V%C:'1W;V]R9&5N(&1I96YE;B!V97)S8VAI;&QE;F0@=&4@>FEJ;BX`3W5D
M92!W86-H='=O;W)D`$]U9&4@=V%C:'1W;V]R9"!I<R!N:65T(&IU:7-T`$]M
M86X`06QL965N($E-05`@<V5R=F5R<R!O;F1E<G-T975N96X@9V5D965L9&4@
M;6%P<&5N+@!!;&QE96X@8F5L961I9V5N9&4@9F]R='5N97,`4VQE8VAT(.GI
M;B!E+6UA:6QA9')E<R!T;V5G97-T86%N+@!!;&QE96X@9&4@96EG96YA87(@
M;V8@965N('-Y<W1E96UB96AE97)D97(@;6%G(&1E(&5I9V5N86%R<F5C:'1E
M;B!V86X@965N('-H87)E('=I:GII9V5N`$]P96X@:6X@965N(&YI975W('-C
M:&5R;0!/<&5N4U-,(&9O=70Z(&MO;B!G965N(&1A=&$@=6ET(&AE="!O;F1E
M<G1E:V5N9&4@4R]-24U%(&]N9&5R9&5E;"!H86QE;BX`3W!E;G0@9&5Z92!L
M:6YK(&EN(&5E;B!N:65U=R!S8VAE<FT`0F5S='5R:6YG<W-Y=&5E;0!/<'1I
M97,`3W!T:65S('9O;W(@)7,`1V5O<F1E;F1E(&QI:G-T`$]R9V%N:7-T871I
M90!/<F=A;FES871I92!E96YH96ED`$]R9V%N:7-E<F5N`$]R:6=I;F5E;"!T
M;V5P87-S:6YG<W-J86)L;V]N`$]R:6=I;F5L92!S:F%B;&]N96X@:6X@)7,Z
M`$%N9&5R90!!;F1E<F4@:6YF;W)M871I90!%:6=E;F%A<G)E8VAT96X`4$%-
M(&%U=&AE;G1I8V%T:64@:7,@;FEE="!B97-C:&EK8F%A<BX`4$5!4CHZ36%I
M;"!B86-K96YD`$1I9VET86QE(%!'4"!H86YD=&5K96YI;F<`1V5C;V1E97)D
M92!01U`@9&%T80!/<&5N8F%R92!01U`@<VQE=71E;`!/;F1E<G1E:V5N9&4O
M9V5C;V1E97)D92!01U`@9&%T80!02%`@8V]D90!02%`@<VAE;&P`3&EC:'1E
M(')E9V5N(&YA(#$R+C`P('5U<@!296=E;B!N82`Q,BXP,"!U=7(`0G5I96X@
M;F$@,3(N,#`@=75R`%-N965U=R!N82`Q,BXP,"!U=7(`4VYE975W8G5I96X@
M;F$@,3(N,#`@=75R`%IO;B!N82`Q,BXP,"!U=7(`3VYW965R<V)U:65N(&YA
M(#$R+C`P('5U<@!03U-)6"!E>'1E;G-I92!O;G1B<F5E:W0`4$A0(%]3:&5L
M;`!6<FEJ92!R=6EM=&4`4&%K:7-T86X`4&%L874`4&%L97-T:6IN<R!497)R
M:71O<FEU;2P@0F5Z970`4&%N86UA`%!A<'5A($YI975W($=U:6YE80!087)A
M9W5A>0!'961E96QT96QI:FL@8F5W;VQK=`!786-H='=O;W)D`%=A8VAT=V]O
M<F0@;65T('-U8V-E<R!G97=I:GII9V0N`%=A8VAT=V]O<F0@;VYJ=6ES=`!7
M86-H='=O;W)D(&ES('9E<F5I<W0@=F]O<B!2041)55,@875T:&5N=&EC871I
M92X`5V%C:'1W;V]R9"!M970@8F5V97-T:6=I;F<`5V%C:'1W;V]R9#H`5V%C
M:'1W;V]R9#H@`%=A8VAT=V]O<F1E;B!M;V5T96X@;W9E<F5E;FMO;65N+@!0
M;&%K:V5N`%!L86MK96X@=F%N868@<')I:V)O<F0`4&%D`$AA;F=E;F1E(&EN
M<V-H<FEJ=FEN9V5N.@!-96YS96X`4')O8V5N=`!/;F1E<FAO=61S=V5R:WIA
M86UH961E;B!U:71V;V5R96X`3VYD97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET
M=F]E<F5N(&)I:B!A86YM96QD:6YG/P!296-H=`!296-H="`B)7,B(&YI970@
M=F5R=VEJ9&5R9"X`4F5C:'0@9V5W96EG97)D`%)E8VAT96X`4F5C:'1E;F)E
M:&5E<@!097)S;V]N;&EJ:V4@:6YF;W)M871I90!097)U`$AU:7-D:65R96X`
M4&AI;&EP<&EJ;F5N`%1E;&5F;V]N`$9O=&\G<P!0:71C86ER;@!0:7AE;',`
M4&QA=&ET=61E<P!+;&EK(&EN(&5E;B!C96PL(&$N=2YB+@!"979E<W1I9RP@
M9&%T('4@9&ET(&5L96UE;G0@=VEL="!V97)W:6ID97)E;BP@82YU+F(Z`$)E
M=F5S=&EG+"!D870@=2!D:70@96QE;65N="!W:6QT(&QO<VMO<'!E;&5N+"!A
M+G4N8BX`1V5E9B!E96X@;6%A;F0@96X@965N(&IA87(L(&$N=2YB+@!%96X@
M;F%A;2!V;V]R(&1E(&YI975W92!C871E9V]R:64@:6YV;V5R96XL(&$N=2YB
M+CH`1V5E9B!E96X@9V5L9&EG($E0(&%D<F5S+"!A+G4N8BX`1V5E9B!E96X@
M9V5L9&EG92!D871U;2!A+G4N8BXL(&-O;G1R;VQE97(@:&5T(&%A;G1A;"!D
M86=E;B!I;B!D92!M86%N9"X`1V5E9B!E96X@9V5L9&EG92!T:6ID+"!A+G4N
M8BX`1V5E9B!E96X@<V%M96YV871T:6YG('9A;B!H970@<')O8FQE96TL(&$N
M=2YB+@!'965F('5W(&=E8G)U:6ME<G-N86%M(&5N('=A8VAT=V]O<F0L(&$N
M=2YB+@!,965S(&1E('9O;&=E;F1E('1E:W-T+"!A+G4N8BX@52!-3T54(&1E
M('9O;W)W86%R9&5N('1E(&%C8V5P=&5R96X@;VT@:&5T('-Y<W1E96T@=&4@
M:W5N;F5N(&=E8G)U:6ME;BX`1V5E9B!D92!N:65U=V4@8V%T96=O<FEE;F%A
M;2P@82YU+F(N.@!0;VQE;@!0;VQI=&EE:P!096EL:6YG96X`4&]R='5G86P`
M4&]S:71I;VYE<FEN9R!V86X@9&5Z92!A9F)E96QD:6YG`%!O<VET:6]N97)I
M;F<@=F%N(&1E>F4@=&%B96P`4W1U=7(@;F%A<B!D97IE(&UA<"`H;FEE="!A
M9F=E9'=O;F=E;B!D;V]R($E-05`I`$YE97)S;&%G('9A;B!D92!A9F=E;&]P
M96X@)7,@=7)E;CH@`$YE97)S;&%G/&)R("\^:V%N<P!0<F5F<U]L9&%P.B!V
M97)E:7-T92!,1$%0(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`%!R969S7W-E
M<W-I;VXZ('9E<F5I<W1E('-E<W-I92!E>'1E;G1I92!N:65T(&=E=F]N9&5N
M+@!,=6-H=&1R=6L`3'5C:'1D<G5K(&]P('IE96YI=F5A=3H@`$QU8VAT9')U
M:SH@`$)E;V]R9&5L96X`0F5O;W)D965L(&1E(&%F8F5E;&1I;F<@:6X@965N
M(&YI975W('-C:&5R;0!6;W)I9V4@;W!T:65S`$1O8W5M96YT(&%F9')U:VME
M;@!0<FEV92!S;&5U=&5L`%!R;V)L965M`%!R;V)L965M8F5S8VAR:6IV:6YG
M`%!R;VIE8W1E;@!0<F]M<'0@=&5K<W0`3W!E;F)A<F4@<VQE=71E;`!/<&5N
M8F%R92!S;&5U=&5L(&%L9V]R:71H;64`3W!E;F)A<F4@<VQE=71E;&EN9F]R
M;6%T:64`3W!E;F)A87(O4')I=F4@<VQE=71E;'!A87(@;FEE="!G96=E;F5R
M965R9"X`4'5E<G1O(%)I8V\`5VES(&)E<FEC:'1E;@!1=6%T87(`475E<GD`
M475O=&$`4E-!(&]P96YB87)E('-L975T96P@*"5D(&)I="D`2V5U>F5R;VYD
M:F4@<V5L96-T:64`4F5G96X`5G)O96<@<F5G96X`3&%A="!R96=E;@!296=E
M;F)U:0!296=E;B!E;B!S;F5E=7<`4F5G96X@;F%A<B!S;F5E=7<`4F%N9&]M
M($9O<G1U;F4`5F5R:&]U9&EN9P!,97IE;@!,965S(&)E<FEC:'1E;@`E<R!E
M8VAT('9E<G=I:F1E<F5N/R!$97IE(&)E=V5R:VEN9R!K86X@;FEE="!O;F=E
M9&%A;B!G96UA86MT('=O<F1E;BX`1V5B<G5I:V5R<V1A=&$@=F%N(&=E8G)U
M:6ME<B`E<R!E8VAT('9E<G=I:F1E<F5N/R!$97IE(&)E=V5R:VEN9R!K86X@
M;FEE="!O;F=E9&%A;B!G96UA86MT('=O<F1E;BX`2&5R:&%A;'0@=7<@=F]R
M:6=E(&)E=V5R:VEN9P!697)V97)S96X`5F5R=F5R<R!D>6YA;6ES8VAE(&UE
M;G4@;VYD97)D96QE;CH`4&]R=&%L=V5E<F=A=F4@=F5R=F5R<V5N.@!296=E
M>`!"971R96MK:6YG96X@8G)O=W-E<@!(97)L861E;@!/<&UE<FMI;F=E;@!3
M97)V97)S(&]P(&%F<W1A;F0`55),(&]P(&%F<W1A;F0@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!697)W:6ID97)E;@!";&]K('9E<G=I:F1E
M<F5N`$MO;&]M('9E<G=I:F1E<F5N`$]P;6%A:R!V97)W:6ID97)E;@!086%R
M('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!H970@;W!G97-L86=E;B!S8W)I<'0@
M=6ET(&1E('1I:F1E;&EJ:V4@9&ER96-T;W)Y(&]P(&1E('-E<G9E<BX`5F5R
M=VEJ9&5R(&1E`%9E<G=I:F1E<B!D97IE(&YO9&4@=6ET(&AE="!D;V-U;65N
M=`!'96)R=6EK97(@=F5R=VEJ9&5R96X`5F5R=VEJ9&5R(&=E8G)U:6ME<CH@
M)7,`5F5R>F]E:R!K;VX@;FEE="!W;W)D96X@8F5A;G1W;V]R9"X@1V5R971O
M=7)N965R9&4@9F]U=&-O9&4Z(`!$92!G979R86%G9&4@<V5R=FEC92!K;VX@
M;FEE="!W;W)D96X@9V5V;VYD96XN`%9E<F5I<W1E("(E<R(@;FEE="!O<&=E
M9V5V96X@:6X@)7,@8V]N9FEG=7)A=&EE+@!697)E:7-T92`B)7,B(&YI970@
M;W!G96=E=F5N(&EN(%9&4R!C;VYF:6=U<F%T:64N`%9E<F5I<W1E("(E<R(@
M;FEE="!O<&=E9V5V96X@:6X@8V]N9FEG=7)A=&EE+@!697)E:7-T('9E;&0`
M2&5R<W1E;&QE;@!297-E="!W86-H='=O;W)D`%)E<V5T('5W('=A8VAT=V]O
M<F0`5F]O<F=A86YD92!Q=65R>2!H97)S=&5L;&5N`%)E<W5L=&%T96X`5&5R
M=6<@;F%A<B!O<'1I97,`5'EP(&YI975W('=A8VAT=V]O<F0@;W!N:65U=P!2
M975N:6]N`$-O;F9I9W5R871I92!T97)U9WIE='1E;@!2:6-H(%1E>'0@161I
M=&]R(&]P=&EE<P!286%D<V5L<P!296-H=',`4F5C:'1S92!K;W``4F5C:'1S
M92!W86%R9&5N`%)I7VIE:6=E;G-C:&%P<&5N+BXN`%)O;`!2;V5M96YIZP`Q
M.#`@9')A86EE;@!.86%R(&QI;FMS(&1R86%I96X`3F%A<B!R96-H=',@9')A
M86EE;@!2:6H@96EG96YS8VAA<'!E;@!2:6H@96EG96YS8VAA<'!E;@!2:6IE
M;CH`3&EN:>MR:6YG`$QI;FGK<FEN9R!Z86P@=F5R<V-H:6IN96X@='5S<V5N
M(&%L;&4@<FEJ96X@96X@:V]L;VUM96X`3&EN:>MR:6YG('IA;"!A;&QE96X@
M='5S<V5N(&MO;&]M;65N('9E<G-C:&EJ;F5N`$QI;FGK<FEN9R!Z86P@86QL
M965N('1U<W-E;B!R:6IE;B!V97)S8VAI:FYE;@!3=&%R=&5N`%)U<W-I<V-H
M92!&961E<F%T:64`4G=A;F1A`$-R>7!T;V=R869I<V-H92!3+TU)344@:&%N
M9'1E:V5N:6YG`%,O34E-12!G96-O9&5E<F0@8F5R:6-H=`!305-,(&%U=&AE
M;G1I8V%T:64@:7,@;FEE="!B97-C:&EK8F%A<BX`4TU3('9E<G-T=7)E;@!3
M44P@<VAE;&P`4U%,('-T871E;65N="!V;V]R('=A87)D97IO96MO<&1R86-H
M=&5N`%-32`!354-#15,`4U]13"!S:&5L;`!:80!3="!(96QE;F$`4W0@2VET
M=',@96X@3F5V:7,`4W0@3'5C:6$`4W0@4&EE<G)E(&5N($UI<75E;&]N`%-T
M(%9I;F-E;G0@96X@9&4@1W)E;F%D:6YE<P!:96QF9&4@9G)A;64@*%]S96QF
M*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&5N(%!R:6YC:7!E`%-A=&5L
M;&EE='!R;W9I9&5R`%-A=61I($%R86)IZP!/<'-L86%N`"(E<R(@;W!S;&%A
M;@`E<R!O<'-L86%N`$]P=&EE<R!O<'-L86%N`$=E9V5N97)E97)D92!C;VYF
M:6=U<F%T:64@86QS(%!(4"!S8W)I<'0@;W!G97-L86=E;B!I;B!D92!T:6ID
M96QI:FME(&1I<F5C=&]R>2!V86X@=7<@<V5R=F5R+@`E<R!C;VYF:6=U<F%T
M:64@;W!G97-L86=E;@!3971U<"!U<&=R861E('-C<FEP="!O<&=E<VQA9V5N
M(&YA87(Z("(E<R(N`$=E<W!R96ED92!O;G=E97)S8G5I96X`5V5T96YS8VAA
M<`!:;V5K96X`6F]E:VUA8VAI;F5S`$MI97,@8F5S=&%N9&5N`%-E;&5C=&5E
M<B!E96X@9&%T=6T`4V5L96-T965R(&5E;B!G<F]E<"!O;2!T;V4@=&4@=F]E
M9V5N`%-E;&5C=&5E<B!E96X@;FEE=7=E(&5I9V5N86%R`%-E;&5C=&5E<B!E
M96X@<V5R=F5R`%-E;&5C=&5E<B!E96X@9V5B<G5I:V5R(&]M('1O92!T92!V
M;V5G96X`06QL97,@<V5L96-T97)E;@!396QE8W1E97(@86QL92!D871U;6-O
M;7!O;F5N=&5N+@!396QE8W1E97(@965N(&]B:F5C=`!.:65T<R!S96QE8W1E
M<F5N`%-E;&5C=&5E<B!D92!B96YO9&EG9&4@:V%R86MT97)S('5I="!D92!O
M;F1E<G-T86%N9&4@=F%K:F5S+B!5(&MU;G0@9&5Z92!D86X@:V]P:>MR96X@
M96X@<&QA:VME;B!I;B!H970@=&5K<W1G96)I960N`%-E;&5C=&5E<B!H970@
M9&%T=6US8VAE:61I;F=S=&5K96XZ`%-E;&5C=&5E<B!H970@9&%T=6UF;W)M
M86%T.@!396QE8W1E97(@9&4@:61E;G1I=&5I="!D:64@=2!W:6QT('=I:GII
M9V5N.@!396QE8W1E97(@:&5T('1I:F1S8VAE:61I;F=S=&5K96XZ`%-E;&5C
M=&5E<B!H970@=&EJ9'-F;W)M86%T.@!396QE8W1E97(@='=E92!O=F5R965N
M:V]M96YD92!V96QD96XN`%-E;&5C=&5E<B!U=R!K;&5U<G-C:&5M82X`4V5L
M96-T965R('5W(&=E=V5N<W1E('1A86PZ`%!R;V)L965M<F%P<&]R="!V97)Z
M96YD96X`5F5R>F5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`
M4V5R=FGK(&5N($UO;G1E;F5G<F\`4V5R:65N=6UM97(`4V5R=F5R9&%T82!F
M;W5T(&]F(&YI970@8F5S8VAI:V)A87(N`%-E<W-I96)E:&5E<F1E<@!397-S
M:64@240@=F5R;&]P96XN`%-E<W-I97,`26YS=&5L;&5N`$EN<W1E;&QE;B!V
M86X@;W!T:65S(&]M('4@=&]E('1E('-T86%N('5W('=A8VAT=V]O<F0@=&4@
M<F5S971T96XL('=A;FYE97(@=2!D:70@8F5N="!V97)G971E;BX`26YS=&5L
M;&5N('9A;B!S97)V97)S(&]P(&%F<W1A;F0@9&EE('4@=VEL="!B96YA9&5R
M96X@=F%N=6ET('5W('!O<G1A;"X`26YS=&5L;&5N('9A;B!U=R!G97=E;G-T
M92!T86%L+"!T:6ID>F]N92!E;B!D871U;6]P=&EE<RX`26YS=&5L;&5N('9A
M;B!U=R!O<'-T87)T=&]E<&%S<VEN9RP@:VQE=7)S8VAE;6$L('!A9VEN879E
M<G9E<G-I;F<@96X@86YD97)E('=E97)G879E;W!T:65S+@!);G-T96QL96X`
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&)E<V-H:6MB86%R`%9E<G-C:&EL;&5N
M9&4@;&]C871I97,@;6]G96QI:FL@;65T(&1E('!A<F%M871E<CH@`%-E>6-H
M96QL96X`5VEN:V5L96X`2V]R=&4@<V%M96YV871T:6YG`$1I96YE;B!S;F5L
M=&]E='-E;B!V;V]R(&1E(&UE97-T92!L:6YK<R!G961E9FEN:65E<F0@=&4@
M=V]R9&5N/P!7965R9V5V96X`5F5R<V-H:6QL96X@;&%T96X@>FEE;B!T=7-S
M96X@9&4@:'5I9&EG92!O<&=E<VQA9V5N(&-O;F9I9W5R871I92!E;B!D92!N
M:65U=V4@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92X`3&%A='-T92!A86YM
M96QD:6YG<W1I:F0@=V5E<F=E=F5N(&)I:B!A86YM96QD96X_`$]P=&EE('=E
M97)G979E;B!O;2!O<FEG:6YE96P@=&4@8F5W87)E;@!+:65Z97(@=V5E<F=E
M=F5N`%1A8F5L8F5W97)K:6YG<W1A86MB86QK('=E97)G979E;C\`)7,@;65N
M=2!A86X@9&4@;&EN:V5R:V%N="!W965R9V5V96X_`%1A8F5L8V5L96EG96YS
M8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96X`5&%B96QE:6=E;G-C
M:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E;@!486)E;')I:F5I9V5N
M<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`$%F8F5E;&1I;F=S
M96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96X`57!L;V%D
M('=E97)G979E;@!"=6EE;@!"=6EE;B!V<F]E9P!"=6EE;B!L86%T`$)U:65N
M(&EN(&1E(&YA8FEJ:&5I9`!697)K;&5I;F5N`%9E<FML96EN(&]F('9E<G!L
M86%T<R!N86)U<FEG92!B;&]K:V5N(&5E<G-T`%-I97)R82!,96]N90!);G1E
M:V5N96X`2&%N9'1E:V5N:6YG`$AA;F1T96ME;FEN9R!A;&=O<FET:&UE`%-I
M;F=A<&]R90!'<F]O='1E`$]N9&5R:&]U9"!O=F5R<VQA86X`4VQO=V%K:6IE
M`%-L;W9E;FGK`%-N965U=P!3;F5E=7=V;&%A9P!3;F5E=7=B=6EE;@!S;F5E
M=7=B=6EE;B!V<F]E9P!3;F5E=7=B=6EE;B!L86%T`%-N965U=V1I97!T93H@
M`%-N965U=V5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N(&5I;&%N9&5N
M`%-O;6%L:>L`3&EE9&5R96X@96X@9V5D:6-H=&5N`%-O<G1E97)V;VQG;W)D
M92!S96QE8W1I90!"<F]N861R97,`6G5I9"!!9G)I:V$`6G5I9"!%=7)O<&5E
M<R`H25-/+3@X-3DM,RD`6G5I9"!'96]R9VGK(&5N(&1E(%IU:60@4V%N9'=I
M8V@@96EL86YD96X`6G5I9&5L:6IK(&AA;&9R;VYD`%-P871IZW)I;F<@='5S
M<V5N(&%A;F=R96YZ96YD92!C96QL96X`4W!A=&GK<FEN9R!T=7-S96X@:6YH
M;W5D(&5N(')A;F0@:6X@8V5L`%-C:&5I9&EN9W-T96ME;@!3<&%T:>MR:6YG
M`%-P871IZW)I;F<@96X@=G)I:F4@<G5I;71E`%-P86YJ90!3<&%M`%-P96-I
M86%L(&MA<F%K=&5R(&EN=F]E<@!#96P@;W!S<&QI='-E;@!+;VQO;2!O<'-P
M;&ET<V5N`%)I:B!O<'-P;&ET<V5N`%-P;W)T`%-R:2!,86YK80!3=&%N9&%A
M<F0`4W1A<B!4<F5K`%-T87)T:F%A<@!3=&%A="!O9B!P<F]V:6YC:64`4W1A
M='5S`$]P<VQA9V9O<FUA870`061R97,`1&]O<FAA;&5N`%-T<FEN9VQI:G-T
M`%-T<FEP(&1O;65I;B!V86X@:&5T(&%D<F5S`%-T:6IL(%M#4U-=`%IO`%-U
M8F1I<F5C=&]R>2`B)7,B(&YI970@9V5V;VYD96XN`$]N9&5R=V5R<`!"979E
M<W1I9V5N`%9E<GIO96L@=F5R<W1U=7)D(&]M("(E<R(@86%N(&AE="!S>7-T
M965M('1O92!T92!V;V5G96XN(%4@:W5N="!N:65T(&%A;FUE;&1E;B!T;W0@
M=7<@=F5R>F]E:R!I<R!G;V5D9V5K975R9"X`4W5B<V-R:7!T`%-U8V-E<P`B
M)7,B(&UE="!S=6-C97,@86%N(&AE="!S>7-T965M('1O96=E=F]E9V0N`$1A
M=&$@=F%N(&=E8G)U:6ME<B`B)7,B(&UE="!S=6-C97,@=6ET(&AE="!S>7-T
M965M('9E<G=I:F1E<F0N`"(E<R(@;65T('-U8V-E<R!V97)W:6ID97)D+@`B
M)7,B(&UE="!S=6-C97,@=6ET(&AE="!S>7-T965M('9E<G=I:F1E<F0N`$-O
M;F9I9W5R871I92!M970@<W5C8V5S('1E<G5G9V5Z970N(%9E<FYI975W(&]M
M('=I:GII9VEN9V5N('1E('II96XN`$)A8VMU<&-O;F9I9W5R871I92!M970@
M<W5C8V5S<R!O<&=E<VQA9V5N+@!"86-K=7!C;VYF:6=U<F%T:65B97-T86YD
M("5S(&UE="!S=6-C97-S(&]P9V5S;&%G96XN`"(E<R(@;65T('-U8V-E<R!B
M:6IG97=E<FMT`"5S(&UE="!S=6-C97,@9V5S8VAR979E;@!3;V5D86X`4V%M
M96YV871T:6YG`%IO;G-O<&=A;F<`6F]N<V]N9&5R9V%N9P!:;VYN:6<`6F]N
M<V]P9V%N9P!:;VYS;W!G86YG+UIO;G-O;F1E<F=A;F<`6F]N<V]P9V%N9SH@
M`%IO;G-O;F1E<F=A;F<`6F]N<V]N9&5R9V%N9SH@`%-U<&5R<V-R:7!T`$]N
M9&5R<W1E=6YI;F<`4W5R:6YA;64`06-H=&5R;F%A;0!3<&ET<V)E<F=E;B!E
M;B!*86X@36%Y96X`4W=A>FEL86YD`%IW961E;@!:=VET<V5R;&%N9`!3>6YC
M(&QO9R!V97)W:6ID97)D`%-Y;F--3`!3>6YT87AF;W5T(&EN('IO96MT97)M
M96X`4WER:7-C:&4@07)A8FES8VAE(%)E<'5B;&EE:P!/;G=E97)S8G5I`$]N
M=V5E<G-B=6EE;B!E;B!W:6YD97)I9P!/;G=E97)S8G5I96X`3VYW965R<V)U
M:65N('9R;V5G`%135B!B97-T86YD`%1A8F5L96EG96YS8VAA<'!E;@!486)E
M;'-E=`!486)E;&5I9V5N<V-H87!P96X`5&%I=V%N`%1A:7=A;BP@4')O=FEN
M8VEE('9A;B!#:&EN80!4861Z:FEK:7-T86X`5&%N>F%N:6$L(%9E<F5N:6=D
M92!297!U8FQI96L@=F%N`$1O96PZ`%1A:V5N`%1E;&5F;V]N;G5M;65R`%1E
M;7!E<F%T=75R('9A;B!H970@869G96QO<&5N('5U<CH@`%1E;7!E<F%T=75R
M`%1E;7!E<F%T=75R.B``5&5M<&5R871U=7(\8G(@+SXH)7-(;V]G)7,O)7-,
M86%G)7,I("9G<F0[)7,`4VIA8FQO;VX@(B5S(B!N:65T(&=E=F]N9&5N+@!3
M:F%B;&]O;F)E:&5E<@!496MS=`!!;&QE96X@=&5K<W0`5&5K<W0@=6ET;&EJ
M;F5N`%1E:W-T8F]V96YK86YT`$1O`%1H86ES("A425,M-C(P*0!4:&%I;&%N
M9`!$92!&5%`@97AT96YT:64@:7,@;FEE="!B97-C:&EK8F%A<BX`2&5T(&=E
M<V-H:65D96YI<W-Y<W1E96T@:7,@=6ET9V5S8VAA:V5L9"X`1&4@2&]R9&4O
M2V]L86(@:6YT96=R871I92!O;F1E<G-T975N="`B)7,B(&YI970`2&5T($E-
M4U`@;&]G(&MO;B!N:65T('=O<F1E;B!G96EN:71I86QI<V5E<F0N`$1E($UA
M:6YT96YA;F-E.CH@8VQA<W,@=V5R9"!N:65T(&=E;&%D96X`2&5T($]P=&EE
M<W-C:&5R;2!I<R!G97-L;W1E;BX@069S;'5I=&5N+@!$92!B96AE97)D97(@
M9&EE;G0@965N('!E<FUA;F5N="!R96-H=&5N8F%C:V5N9"!T92!C;VYF:6=U
M<F5R96X@86QS('4@<F5C:'1E;B!W:6QT(&=E8G)U:6ME;BX`06QL965N(&1E
M(&]N9&5R:V%N=`!(970@8V]N=&%C="!)1"!N=6UM97(@:7,@;FEE="!O<&=E
M9V5V96XL(&QE96<@9V5L871E;B!O9B!I<R!N:65T(&=E=F]N9&5N(&EN(&1E
M(&1A=&%B87-E+@!(970@861R97,@:7,@;65T('-U8V-E<R!A86X@=7<@861R
M97-B;V5K('1O96=E=F]E9V0N`$AE="!L;W-G96MO<'!E;&1E(%!'4"!O;F1E
M<G1E:V5N:6YG<V)L;VL@:7,@=F5R96ES="!O;2!H970@;VYD97)T96ME;F1E
M(&)E<FEC:'0@=&4@=F5R:69IZW)E;BX`2&5T(&1I<W1R=6)U=&EE;&EJ<W0@
M240@:7,@;FEE="!O<&=E9V5V96XL(&QE96<@9V5L871E;B!O9B!I<R!N:65T
M(&=E=F]N9&5N(&EN(&1E(&1A=&%B87-E+@!$92!D:7-T<FEB=71I96QI:G-T
M(&ES(&YI970@;W!G96=E=F5N+@!$92!C;V1E97)M;V=E;&EJ:VAE9&5N('9E
M<F5I<V5N(&5E;B!B979E:6QI9V1E('=E8G9E<F)I;F1I;F<N`$AE="!B97-T
M86YD("5S(&1I96YT(&5E;B`E<R!I;G-T96QL:6YG('1E(&)E=F%T=&5N+@!(
M970@8F5S=&%N9"`E<R!D:65N="!E;FEG92`E<R!I;G-T96QL:6YG96X@=&4@
M8F5V871T96XN`$AE="!B97-T86YD(&MA;B!N:65T(&YA87(@>FEC:'IE;&8@
M9V5K;W!I965R9"!W;W)D96XN`$AE="!B97-T86YD(&)E=F%T=&4@9V5E;B!D
M871A+@!(970@=F]L9V5N9&4@>FEJ;B!D92!K;W!P96X@=F%N(&1I="!M97-S
M86=E+W)F8S@R,B!B97)I8VAT+@!686X@9&4@=F]L;&5D:6<@<V-H97)M(&UO
M9&4@:7,@8F5K96YD+"!D870@9&ET('!R;V)L96UE;B!K86X@=F5R;V]R>F%K
M96X@;65T($EN=&5R;F5T($5X<&QO<F5R+"!V86YW96=E(&)R;W=S97)B=6=S
M('=A87(@=VEJ(&YI970@;VUH965N(&MU;FYE;BX@2&5T(&ES(&UO9V5L:6IK
M(&1A="!U(')O;6UE;"!I;B!H970@8F5E;&1S8VAE<FTL(&=E8G)E:R!A86X@
M961I=&]R9G5N8W1I97,@96XO;V8@<F%N9&]M(&)R;W=S97(M(&-R87-H97,@
M97)V86%R="X@5V%N;F5E<B!U=R!S>7-T965M(%=I;F1O=W,@.7@@:7,L(&ES
M(&AE="!W86%R<V-H:6IN;&EJ:R!D870@=2!E96X@)T%L9V5M96YE($)E=F5I
M;&EG:6YG<R!&;W5T)R!K<FEJ9W0L(&5N(&]P;FEE=7<@9&EE;G0@=&4@:&5R
M<W1A<G1E;BY<;EQN52!B96YT(&=E=V%A<G-C:'5W9"X@1')U:R!O<"!/2R!W
M86YN965R('4@=&]C:"!D92!V;VQL961I9R!S8VAE<FT@961I=&]R('=I;'0@
M<')O8F5R96XN`$1E(&ED96YT:71E:70@(B5S(B!I<R!V97)W:6ID97)D+@!!
M;&QE96X@9&4@;&EN:V5R:V%N=`!$92!P;&%A=',@=F%N(&AE="!';G501R!P
M<F]G<F%M;6$@9&EE;G0@;W!G96=E=F5N('1E('=O<F1E;B!I;B!D92!#<GEP
M=%]P9W`Z.B!C;&%S<RX`2&5T(&)E<FEC:'0@=F5R<W1U=7)D(&]P("5S(&%A
M;B`E<R!M970@;VYD97)W97)P("(E<R(@:7,@=V5E<F=E9V5V96XN"D1I="!I
M<R!G965N(&=A<F%N=&EE(&1A="!H970@8F5R:6-H="!I<R!G96QE>F5N(&]F
M(&)E9W)E<&5N+@!$92!N86%M(&1I92!G96)R=6EK="!W;W)D="!B:6H@;&EN
M:V5N(&YA87(@9&4@;FEE=7<@8F5R:6-H="!P86=I;F$`2&5T(&%A;G1A;"!V
M96QD96X@9&EE;G0@;G5M97)I96L@=&4@>FEJ;BX`1&4@;W!E;G-S;"!M;V1U
M;&4@:7,@=F5R96ES="!V;V]R(&1E($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA
M<W,N`$1E('9O;W)K975R<VEN<W1E;&QI;F<@(B5S(B!K;VX@;FEE="!W;W)D
M96X@;W!G97-L86=E;BP@;VUD870@9&4@9&%T82!D92!M87AI;75M('1O96QA
M871B87)E(&=R;V]T=&4@;W9E<G-C:')I:F1T+@!(970@<')O9W)A;6UA(&]M
M(&1I="!D871A='EP92`H)7,I('1E(&)E:VEJ:V5N+"!W97)D(&YI970@;W`@
M:&5T('-Y<W1E96T@9V5V;VYD96XN`$AE="!A86YH86QI;F=S=&5K96X@9&EE
M;G0@Z^MN(&5N:V5L('1E:V5N('1E('II:FXN`$%L;&5E;B!D92!R96-H=&5R
M+2!E;B!L:6YK97)K86YT`$%L;&5E;B!D92!R96-H=&5R:V%N=`!(970@<V-H
M96ED:6YG<W1E:V5N(&1I96YT(.OK;B!E;FME;"!T96ME;B!T92!Z:6IN+@!$
M92!S97)V97(@(B5S(B!I<R!V97)W:6ID97)D+@!$92!S97)V97(@(B5S(B!I
M<R!O<&=E<VQA9V5N+@!(970@86%N;65L9&EN9W-V97)Z;V5K('9O;W(@)7,@
M:7,@=F5R=VEJ9&5R9"X`1&4@;W!G96=E=F5N(')I:B`H)60I(&)E<W1A870@
M;FEE="X`2&5T('1I:F1E;&EJ:R!B97-T86YD("(E<R(@8F5S=&%A="!N:65T
M+@!$92!I;F=E=F]E<F1E('1E:W-T(&MO;70@;FEE="!O=F5R965N(&UE="!D
M92!T96MS="!O<"!H970@<V-H97)M+@!!;&QE96X@9&4@8F]V96XM(&5N(&]N
M9&5R:V%N=`!!;&QE96X@9&4@8F]V96YK86YT`$1E('5P;&]A9&5D(&1A=&$@
M:7,@;F$@9&4@=F]O<F=A86YD92!S=&%P('9E<FQO<F5N(&=E9V%A;BX`2&5T
M('5P;&]A9&5D(&)E<W1A;F0@:7,@;FEE="!O<&=E<VQA9V5N+@!(970@=V5A
M=&AE<BYC;VT@8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R+@!4:&5M861I<F5C
M=&]R>2`B)7,B(&YI970@9V5V;VYD96XN`$=E96X@;W!T:65S(&)E<V-H:6MB
M86%R+@!%<B!Z:6IN(&=E96X@;VYD97)D96QE;BP@=V5L:V4@:6YL:6YE('=E
M97)G96=E=F5N(&MU;FYE;B!W;W)D96XN`$5R('II:FX@=&4@=F5E;"!K87)A
M:W1E<G,@:6X@9&ET('9E;&0N(%4@:&5E9G0@)7,@:V%R86MT97)S(&]P9V5G
M979E;CL@=2!D:65N="!M:6YD97(@9&%N("5S(&]P('1E(&=E=F5N+@!%96X@
M<')O8FQE96T@;65T(&AE="!T;V5V;V5G96X@=F%N("(E<R(@86%N(&AE="!S
M>7-T965M.B`E<P!%96X@<')O8FQE96T@;65T(&AE="!V97)W:6ID97)E;B!V
M86X@9&%T82!V86X@9V5B<G5I:V5R("(E<R(@=6ET(&AE="!S>7-T965M.B``
M165N('!R;V)L965M(&UE="!H970@=F5R=VEJ9&5R96X@=F%N("(E<R(@=6ET
M(&AE="!S>7-T965M.B``165N('!R;V)L965M(&UE="!H970@8FEJ=V5R:V5N
M('9A;B`B)7,B.B`E<P!%96X@<')O8FQE96T@;65T(&1E(&)E<W1A;F1S=7!L
M;V%D.B!'965N("5S('=E<F0@9V5U<&QO860N`$5E;B!P<F]B;&5E;2!M970@
M9&4@8F5S=&%N9'-U<&QO860Z($AE="`E<R!I<R!G<F]T97(@9&%N(&1E(&UA
M>&EM=6T@=&]E;&%A=&)A<F4@9W)O;W1T92`H)60@8GET97,I+@!%96X@<')O
M8FQE96T@;65T(&1E(&)E<W1A;F1S=7!L;V%D.B!(970@)7,@:7,@<VQE8VAT
M<R!G961E96QT96QI:FL@9V5U<&QO860N`$5E;B!F;W5T(&)I:B!H970@8F5K
M:6IK96X@=F%N(&1I="!B97)I8VAT;VYD97)D965L`$5E;B!F;W5T(&)I:B!H
M970@:6UP;W)T97)E;B!V86X@9&4@861R97-D871A+@!%96X@9F]U="!B:6H@
M:&5T(&EM<&]R=&5R96X@=F%N(&1E(&E#86QE;F1A<F1A=&$N`$5E;B!F;W5T
M(&EN(&AE="!C;VYF:6=U<F%T:65F;W)M=6QI97(N($UI<W-C:&EE;B!B96YT
M('4@965N('9E<G!L:6-H="!V96QD('9E<F=E=&5N+@!%96X@9F]U="!B:6H@
M:&5T('5I='9O97)E;B!V86X@9&4@;W!G96=E=F5N(&%D<F5S8F]E:V9U;F-T
M:64N(%!R;V)E97(@;&%T97(@;W!N:65U=RP@82YU+F(N`$5E;B!F;W5T(&UE
M="!H970@8FEJ=V5R:V5N('9A;B!D92!A9')E<V1E=&%I;',N(%!R;V)E97(@
M;&%T97(@;W!N:65U=RP@82YU+F(N`$5E;B!F;W5T(&UE="!H970@8FEJ=V5R
M:V5N('9A;B!D92!D:7-T<FEB=71I96QI:G-T+B!0<F]B965R(&QA=&5R(&]P
M;FEE=7<L(&$N=2YB+@!$97IE($E-05`@<V5R=F5R(&]N9&5R<W1E=6YT(&=E
M96X@9&5L:6YG('9A;B!M87!P96XN`$1I="!L:6IK="!N:65T(&5E;B!G96QD
M:6<@<F%R(&)E<W1A;F0@=&4@>FEJ;BX`1&ET(&QI:FMT(&YI970@965N(&=E
M;&1I9R!Z:7`@8F5S=&%N9"!T92!Z:6IN+@!$:70@;&EJ:W0@;FEE="!E96X@
M9V5L9&EG(&MA87)T;G5M;65R('1E('II:FXN`$1I="!S='5U<G!R;V=R86UM
M82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!#
M;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87D@=&4@
M=F5R>F5N9&5N+"!D+FTN=BX@9&4@2%144"!!4$D`1&ET('-T=75R<')O9W)A
M;6UA(&=E969T(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E
M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87D@=&4@=F5R>F5N9&5N
M+"!D+FTN=BX@9&4@2%144"!!4$D`1&ET('-T=75R<')O9W)A;6UA(&=E969T
M(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87D@=&4@=F5R>F5N9&5N
M+"!D+FTN=BX@9&4@2%144"!!4$D`1&ET('-T=75R<')O9W)A;6UA(&=E969T
M(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(%--5%`@9"YM+G8N
M(&1E(%9O9&%F;VYE($ET86QY(&=A=&5W87D@=&4@=F5R>F5N9&5N(&YA87(@
M5F]D869O;F4@;G5M;65R<RX@2&EE<G9O;W(@:7,@965N(%9O9&%F;VYE($ET
M86QY(&4M;6%I;&%D<F5S("AH='1P.B\O=W=W+C$Y,"YI="D@;F]O9'IA:V5L
M:6IK+@!$:70@=F5L9"!I<R!V97)E:7-T`$1I="!V96QD(&UA9R!A;&QE96X@
M:6YT96=E<G,@8F5V871T96XN`$1I="!V96QD(&UA9R!A;&QE96X@9V5T86QL
M96X@96X@9&4@9'5B8F5L92!P=6YT(&)E=F%T=&5N+@!$:70@=F5L9"!M86<@
M86QL965N(&]C=&%A;"!W86%R9&5N(&)E=F%T=&5N+@!$:70@=F5L9"!D:65N
M="!E96X@:V]M;6$@;V8@<W!A=&EE(&=E<V-H96ED96X@;&EJ<W0@;65T(&EN
M=&5G97)S('1E('II:FX`1&5Z92!W86%R9&4@9&EE;G0@965N(&=E;&1I9R!G
M971A;"!T92!Z:6IN+@!$:70@=F5L9"!D:65N="!E96X@:VQE=7)C;V1E(&EN
M(%)'0B!(15@M9F]R;6%A="!T92!B979A='1E;BP@8BYV+B`G(S$R,S1A9B<N
M`$1I="!F;W)M=6QI97(@:7,@<F5E9',@=F5R=V5R:W0N`$1I="!I<R`E<RX`
M1&ET(&ES(&5E;B!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!/;2!D:70@;V)J
M96-T('=E97(@=&4@9V5V96X@:&5E9G0@=2!E96X@92UM86EL(&-L:65N="!N
M;V1I9R!D:64@:&5T($MO;&%B($=R;W5P=V%R92!F;W)M86%T(&)E9W)I:G!T
M+B!6;V]R(&5E;B!L:6IS="!M970@9&5Z92!E+6UA:6QC;&EE;G1S+"!B97IO
M96L@)7,L(&$N=2YB+@!$:70@8F5R:6-H="!I<R!I;B!E96X@86YD97)E(&MA
M<F%K=&5R<V5T("@E<RD@9V5S8VAR979E;BP@9&%N('5W(&5I9V5N+@!$:70@
M9V5T86P@9&EE;G0@=&5N;6EN<W1E(.GI;B!T92!Z:6IN+@!$97IE('-E<G9E
M<B!K86X@9V5E;B!Z:7`@96X@9WII<"!B97-T86YD96X@=6ET<&%K:V5N+@!(
M970@<WES=&5E;2!I<R!M;VUE;G1E96P@=6ET9V5S8VAA:V5L9"X`1&5Z92!W
M86%R9&4@9&EE;G0@965N(&=E=&%L('1E('II:FXN`$1I="!S8VAE<FT@9&EE
M;G0@86%N9V5R;V5P96X@=&4@=V]R9&5N('9A;G5I="!E96X@3W!T:65S<V-H
M97)M`$]N=V5E<@!4:6-K971S`%1I:F0`5&EJ9'!L86YN:6YG`%1I:F1F;W)M
M86%T`%1I:F1S96QE8W1I90!4:6UO<BU,97-T90!4:71E;`!4:71E;"`H=&]O
M;'1I<"DZ`$%A;@!/;2!M965R9&5R92!O;F1E<F1E;&5N('1E('-E;&5C=&5R
M96XL(&AO=60@9&4@0V]N=')O;"`H4$,I(&]F($-O;6UA;F0@*$UA8RD@=&]E
M=',@=F%S="!T:6ID96YS(&ML:6MK96XN`%9A;F1A86<`2%1-3"!B<F]N(&]M
M<V-H86ME;&5N`%1O9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`5&4@=F5E;"!O
M;F=E;&1I9V4@86%N;65L9&EN9V5N(&=E9'5R96YD92!D92!A9F=E;&]P96X@
M;6EN=71E;BX`0F]V96YK86YT`$)O=F5N<W1E(&9R86UE("A?=&]P*0!697)T
M86QI;F=E;@!4<FEN:61A9"!E;B!4;V)A9V\`5')U92!O9B!F86QS90!$:0!4
M=6YE<VGK`%1U<FMI:F4`5'5R:W,@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A
M;@!4=7)K<R!E;B!#86EC;W,@96EL86YD96X`5'5V86QU`%1Y<"!U=R!K975Z
M93H@`%4N5BX@:6YD97@Z(`!54DP`55),('9O;W(@=7<@869L979E<FEN9W-S
M=&%T=7-R87!P;W)T('-C<FEP=`!54DPZ`$]E9V%N9&$`3V5K<F'O;F4`3FEE
M="!I;B!S=&%A="!61E,@9&ER96-T;W)Y(&%A;B!T92!S<')E:V5N+@!.:65T
M(&EN('-T86%T(&5X=')A(&=E8G)U:6ME<G-I;F9O<FUA=&EE('1O92!T92!V
M;V5G96X@8FEJ(&EN<V-H<FEJ=F5N+@!.:65T(&EN('-T86%T(&1E(')E8VAT
M96X@=F%N(%9&4R!B97-T86YD("(E<R(@=&4@=VEJ>FEG96XN`$YI970@:6X@
M<W1A870@9&4@<F5C:'1E;B!V86X@5D93(&)E<W1A;F0@)7,O)7,@=&4@=VEJ
M>FEG96XN`$YI970@:6X@<W1A870@=&4@=VEJ>FEG96X@;F%A<B`E<RX`3FEE
M="!I;B!S=&%A="!B97-T86YD<V=R;V]T=&4@=F%N("(E<R(@=&4@8V]N=')O
M;&5R96XN`$YI970@:6X@<W1A870@8F5S=&%N9'-G<F]O='1E('9A;B`B)7,O
M)7,B('1E(&-O;G1R;VQE<F5N+@!.:65T(&EN('-T86%T(&UE="!D92!344P@
M<V5R=F5R('1E('9E<F)I;F1E;BX`3FEE="!I;B!S=&%A="!M970@4U-,('1E
M('9E<F)I;F1E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!K;W!I
MZW)E;BX`3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y("(E<R(@=&4@;6%K
M96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!M86ME;BX`3FEE
M="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!M86ME;BX`3FEE="!I;B!S=&%A
M="!61E,@;6%P("(E<R(@=&4@;6%K96XN`$YI970@:6X@<W1A870@965N(&QE
M96<@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@:6X@<W1A870@9&%T82!U
M:70@=&4@<&%K:V5N+@!.:65T(&EN('-T86%T("(E<R(@=&4@=F5R=VEJ9&5R
M96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<`3FEE="!I;B!S=&%A="`B
M)7,B.B`E<R!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S=&%A="`E<R!T92!V
M97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y(&ES(&YI970@;&5E9P!.:65T(&EN
M('-T86%T(%9&4R!D:7)E8W1O<GD@<F5C=7)S:65F('1E('9E<G=I:F1E<F5N
M+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@=F5R=VEJ9&5R96XN
M`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!V97)W:6ID97)E
M;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`B)7,B('1E('9E<G=I:F1E
M<F5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('9E<G=I:F1E<F5N
M+@!.:65T(&EN('-T86%T(%9&4R!M87`@(B5S(B!T92!V97)W:6ID97)E;BX`
M3FEE="!I;B!S=&%A="!61E,@)7,@<F5C=7)S:65F('1E('9E<G=I:F1E<F5N
M+@!.:65T(&EN('-T86%T(&AU:61I9V4@9&ER96-T;W)Y('1E(&)E<&%L96XN
M`$YI970@:6X@<W1A870@8V5R=&EF:6-A871D971A:6QS('5I="!T92!F:6QT
M97)E;@!.:65T(&EN('-T86%T(&]M(&1E(&1E9FEN:71I92!V86X@)7,@=&4@
M;&%D96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@=F5R<&QA871S
M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!O<&5N96XN
M`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;W!E;F5N('9O;W(@<V-H
M<FEJ=F5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&]P96YE;BX`
M3FEE="!I;B!S=&%A="!H970@:6YG97!A:W1E(&)E<W1A;F0@=&4@;W!E;F5N
M+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&QE>F5N("AF:6QE<VEZ
M92@I(&UI<VQU:W0I+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&QE
M>F5N("AG971&:6QE4VEZ92@I(&UI<VQU:W0I+@!.:65T(&EN('-T86%T(&)E
M<W1A;F0@=&4@;&5Z96XZ(`!.:65T(&EN('-T86%T('9F<W)O;W0@9&ER96-T
M;W)Y('1E(&]P96YE;BX`3FEE="!I;B!S=&%A="!O;2`E<R!T92!H97)N;V5M
M96X@;F%A<B`E<SH@8F5S=&5M;6EN9W-M87`@8F5S=&%A="!A;`!.:65T(&EN
M('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@:&5R;F]E;65N+@!.:65T(&EN('-T
M86%T(%9&4R!D:7)E8W1O<GD@)7,@=&4@:&5R;F]E;65N+@!.:65T(&EN('-T
M86%T(%9&4R!B97-T86YD("(E<R(@=&4@:&5R;F]E;65N+@!.:65T(&EN('-T
M86%T(%9&4R!B97-T86YD("5S+R5S('1E(&AE<FYO96UE;BX`3FEE="!I;B!S
M=&%A="!61E,@8F5S=&%N9"!T92!H97)N;V5M96XN`$MA;B`G;6MI<V]F<R<@
M;FEE="!U:71V;V5R96XN`$YI970@:6X@<W1A870@9&ET(%=O<F0@9&]C=6UE
M;G0@=&4@=F5R=&%L96X`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`B)7,B
M('1E('-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!S
M8VAR:6IV96X@*&-O<'DH*2!F86EL960I+@!.:65T(&EN('-T86%T(%9&4R!B
M97-T86YD<V1A=&$@=&4@<V-H<FEJ=F5N+@!.:65T(&EN('-T86%T(%9&4R!B
M97-T86YD('1E('-C:')I:G9E;BP@<75O=&$@=V]R9'0@;W9E<G-C:')E9&5N
M+@!/;F1E<G-T<F5P96X`2&5R<W1E;"!W:6IZ:6=I;F=E;@!$;V5T('5W(&QA
M871S=&4@8F5W97)K:6YG('1E;FEE=`!/;G9E<G=A8VAT(&%N='=O;W)D('9A
M;B!D92!S97)V97(@;W`@=F5R8FEN9&EN9SH@`$]N=F5R=V%C:'0@86YT=V]O
M<F0@=F%N('-E<G9E<B!A86XZ(`!/;F)E;F]E;60`56YI8V]D92`H551&+3@I
M`%9E<F5N:6=D92!!<F%B:7-C:&4@16UI<F%T96X`5F5R96YI9V0@2V]N:6YG
M:W)I:FL`5F5R96YI9V1E(%-T871E;@!697)E;FEG9&4@4W1A=&5N+"!K;&5I
M;F4@8G5I=&5N(&QI9V=E;F1E(&5I;&%N9&5N`$5E;FAE9&5N`$]N8F5K96YD
M`$]N8F5K96YD(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`$]N8F5K96YD
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$]N8F5K96YD92!L;V-A
M=&EE(&]P9V5G979E;BX`3VYB96ME;F1E(&=E8G)U:6ME<G-N86%M(&]F('=A
M8VAT=V]O<F0N`$AE="!H=6ED:6=E(&5L96UE;G0@;&]S:V]P<&5L96X`3VYB
M96YO96UD`$YI970@9V5R96-H=&EG9&4@<V-R:7!T<R!K=6YN96X@<')O9W)A
M;6UA;6%T:6<@;FEE="!+;FEP<&5N+TMO<&GK<F5N+U!L86MK96XL('9A;G=E
M9V4@8F5V96EL:6=I;F=S<F5D96YE;BX@2VQI:R!O<"!/2R!O;2!E96X@=&5C
M:&YI<V-H92!O<&UE<FMI;F<@;W`@;6]Z:6QL82YO<F<@=&4@8F5K:6IK96X@
M:&]E('4@965N('-C<FEP="!T;V5S=&%A="!H970@<')I:V)O<F0@=&4@8F5N
M861E<F5N+@!+;&5U<B!T97)U9W-T96QL96X`3FEE="!O;F1E<G-T975N9&4@
M97AT96YT:64`0FEJ=V5R:V5N`"5S(&)I:G=E<FME;@!'96)R=6EK97(@8FEJ
M=V5R:V5N+@`B)7,B(&)I:F=E=V5R:W0N`%5P9W)A9&4@<V-R:7!T('9E<G=I
M:F1E<F0N`%5P;&]A9`!!;&QE('1O97!A<W-I;F<@<V5T=7!B97-T86YD96X@
M;F%A<B!D92!S97)V97(@9V5U<&QO860N`$QA=&EJ;G-E(&AO;V9D;&5T=&5R
M<P!'<F]T92!2;VUE:6YS92!G971A;&QE;@!5<G5G=6%Y`$=E8G)U:6L@:'5I
M9&EG93H@)7,`1V5B<G5I:R!34TP`1V5B<G5I:V5N('=A;FYE97(@;F%A;2]W
M86-H='=O;W)D('9E<G-C:&EL="!M970@24U34"!S97)V97(N`$=E8G)U:6ME
M<@!'96)R=6EK97(@)7,@:7,@;FEE="!G96%U=&]R:7-E97)D('9O;W(@)7,N
M`$=E8G)U:6ME<G-B96AE97(`1V5B<G5I:V5R<V]P=&EE<P!'96)R=6EK97)S
M<F5G:7-T<F%T:64`1V5B<G5I:V5R<W)E9VES=')A=&EE(&ES('5I=&=E<V-H
M86ME;&0@;W`@9&5Z92!S:71E+@!'96)R=6EK97)S86-C;W5N="!N:65T(&=E
M=F]N9&5N+@!'96)R=6EK97)S;F%A;0!'96)R=6EK97)S;F%A;2`B)7,B(&)E
M<W1A870@86PN`$=E8G)U:6ME<G-N86%M.@!'96)R=6EK97)S;F%A;3H@`$=E
M8G)U:6ME<G,@:6X@:&5T('-Y<W1E96TZ`$]E>F)E:VES=&%N`%9&4R!D:7)E
M8W1O<GD@8F5S=&%A="!N:65T+@!!9G=E>FEG:&5I9`!'979O;F1E;B!G96QD
M:6=E(&QO8V%T:65S(&)E=F%T=&5N.B``1V5L9&EG:&5I9`!786%R9&4@:6X@
M;6EN=71E;B!V86YA9B!N=2X`5V%A<F1E(&QI9W0@8F]V96X@9&4@;6%X:6UU
M;2!L96YG=&4@=F%N("5S+@!786%R9&5N`%=A87)D96X@=V%A<G5I="!G97-E
M;&5C=&5E<F0@:V%N('=O<F1E;@!686YU871U`%9A<FEA8F5L90!696YE>G5E
M;&$`5F5R:69I8V%T:64@;6ES;'5K="`M(&5R(&MA;B!M970@9&ET(&)E<FEC
M:'0@9V5K;F]E:60@>FEJ;BX`5F5R<VEE`%9E<G-I96-O;G1R;VQE`%9E<G1I
M:V%A;"!U:71L:6IN96X`5F5R=&EK86QE('9R:6IE(')U:6UT90!697)T:6MA
M86PZ`$5R9R!H;V]G`%9I971N86T`5FEE=&YA;65E<R`H5DE30TE)*0`E<R!B
M96MI:FME;@!"96MI:FL@965N(&5X=&5R;F4@=V5B<&%G:6YA`$)E:VEJ:V5N
M(&%L<R`E<P!-86%G9&5N(&5I;&%N9&5N+"!"<FET<V4`36%A9V1E;B!E:6QA
M;F1E;BP@5BY3+@!::6-H=`!::6-H=#H@`%9O9&%F;VYE($ET86QY('9I82!3
M3510`%=!4DX`5T%!4E-#2%5724Y'(2$A("!615)724I$15(@4T-225!4($A!
M3D1-051)1R!5250@)7,N`%=)3B!V:6$@2%144`!786QL:7,@96X@1G5T=6YA
M`%=A87)S8VAU=VEN9P!7;P!7965R<W9O;W)U:71Z:6-H=`!7965R8F5R:6-H
M="!G96=E=F5N<R!G96QE=F5R9"!D;V]R`%=E871H97(N8V]M`%=E8@!796)S
M:71E`%=E:V5L:6IK<P!796QK;VT`5V5L:V]M(&)I:B`E<P!796QK;VTL("5S
M`%=E<W1E<G,@*$E33RTX.#4Y+3$I`%=E<W1E<G,@*$E33RTX.#4Y+3$U*0!7
M97-T96QI:FME(%-A:&%R80!796QK92!T;V5P87-S:6YG(&1I96YT("5S('=E
M97(@=&4@9V5V96X@;F$@86%N;65L9&EN9S\`5V%T(&ES(&AE="!S8VAE:61I
M;F=S:V%R86MT97(_`%=A="!I<R!H970@8VET86%T:V%R86MT97(_`%=H97)E
M:7,@075S=')A;&GK(&MA87)T`%=E;&ME(&9A<V5N`%=E;&ME('!L=6=I;G,@
M=F]O<B!D92!2:6-H(%1E>'0@961I=&]R(&EN<V-H86ME;&5N+@!"<F5E9'1E
M`$)R965D=&4@:6X@0U-3(&5E;FAE9&5N`$)R965D=&4@=F%N(&AE="`E<R!M
M96YU(&%A;B!D92!L:6YK97)K86YT("AA:W1I968@8FEJ('9O;&=E;F1E(&%A
M;FUE;&1I;F<I.@!"<F5E9'1E('9A;B!D92!T86)E;`!"<F5E9'1E(&5E;FAE
M:60`0G)E961T93H`5VEK:0!7:6YD`%=I;F0@=G)O96<`5VEN9'-N96QH96ED
M(&EN(&MN;W!E;@!7:6YD.@!7:6YD.B``5VEJ<VAE:60`5V5N<VQI:G-T`%=E
M<FL`5V5R:V%D<F5S`%1E;"YN<BX@*'=E<FLI`%9E<FME97)D(&%A;G1A;"!V
M96QD96X@:6X@<F5G96P@)60N(%9E<G=A8VAT("5D+"!G979O;F1E;B`E9"X`
M5F5R:V5E<F0@86%N=&%L('9E;&1E;BX@5F5R=V%C:'0@)60L(&=E=F]N9&5N
M("5D+@!697)K965R9&4@;V9F<V5T("5D(&)I:B!L97IE;B!V86X@5D93(&)E
M<W1A;F0N`%@M4F5F`%@U,#EV,R!B87-I<V)E<&5R:VEN9V5N`%@U,#EV,R!U
M:71G96)R96ED('-L975T96QG96)R=6EK`%@U,#EV,R!A;'1E<FYA=&EE=F4@
M;VYD97)W97)P;F%A;0!8-3`Y=C,@;VYD97)W97)P('-L975T96QI9&5N=&EF
M:6-A=&]R`%@U,#EV,R!E>'1E;G1I97,`2DH`2DI*2@!986AO;R$@;6%P`$IA
M87)L:6IK<P!*96UE;@!*80!*82P@:6L@86-C97!T965R(&1E('9O;W)W86%R
M9&5N`%4@8F5N="!I;B!414M35"!-3T1%+B!'96)R=6EK(&1E(%L\/ET@:VYO
M<"!O;2!N86%R(%=94TE764<@=&5R=6<@=&4@<V-H86ME;&5N+@!(970@:7,@
M=2!N:65T('1O96=E<W1A86X@;VT@;65E<B!D86X@)60@8FQO:VME;B!T92!M
M86ME;BX`52!B96YT(&YI970@9V5A=71H96YT:69I8V5E<F0N`%4@:W5N="!G
M965N("=<)R!K87)A:W1E<B!I;B!U=R!V;VQL96=E(&YA86T@:&5B8F5N+@!5
M(&AE969T(&=E96X@9V5L9&EG(&4M;6%I;&%D<F5S(&]P9V5G979E;BX`52!H
M965F="!G965N('9E;&1E;B!U:70@:&5T(&=E:6UP;W)T965R9&4@8F5S=&%N
M9"!G96MO<'!E;&0@;65T(&1E(&]V97)E96YK;VUS=&EG92!V96QD96X@:6X@
M)7,N`%4@8F5N="!A9F=E;65L9"X`52!D:65N="!E96X@9V5L9&EG(&UO8FEE
M;"!N=6UM97(@:6X@=&4@=F]E<F5N+"!A;&QE96X@8VEJ9F5R<R!M970@965N
M(&]P=&EO;F5L92`G*R<@=F]O<B!H970@:6YT97)N871I;VYA;&4@:VEE<W9O
M;W)V;V5G<V5L+@!5(&1I96YT(&5E;B!G96QD:6=E('=A87)D92!O<"!T92!G
M979E;BX`52!D:65N="!E96X@1&%T851R964@8F%C:V5N9"!T92!C;VYF:6=U
M<F5R96X@;VT@:6YS8VAR:6IV:6YG96X@=&4@:W5N;F5N(&=E8G)U:6ME;BX`
M52!D:65N="!E96X@5D93(&)A8VME;F0@=&4@8V]N9FEG=7)E<F5N+@!5(&1I
M96YT(&AE="!P<F]B;&5E;2!T92!B97-C:')I:G9E;BP@=F]O<F1A="!U(&AE
M="!P<F]B;&5E;7)A<'!O<G0@:W5N="!V97)Z96YD96XN`%4@9&EE;G0@965N
M(%523"!I;B!T92!V;V5R96X@=V%A<FYA87(@9&5Z92!L:6YK('9E<G=I:G-T
M`%4@9&EE;G0@965N('-E<G9E<B!T92!S96QE8W1E<F5N(&]M('1E('9E<G=I
M:F1E<F5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E
M;B!O;2!T92!W:7-S96XN`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P
M('1E(&=E=F5N(&]M('1E('9E<G=I:F1E<F5N+@!5(&1I96YT(&5E;B!G96)R
M=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!T;V4@=&4@=F]E9V5N+@!5(&1I
M96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!B:6H@=&4@
M:W5N;F5N('=E<FME;BX`52!D:65N="!E96X@8F5W97)K:6YG(&]P('1E(&=E
M=F5N('=E;&ME('5I=&=E=F]E<F0@;6]E="!W;W)D96XN`%4@9&EE;G0@965N
M(&YI975W92!C871E9V]R:65N86%M(&]P('1E(&=E=F5N+@!5(&1I96YT(&5E
M;B!)=&%L:6%A;G,@=&5L969O;VYN=6UM97(@;W`@=&4@9V5V96X`57<@)7,@
M<V5S<VEE(&ES('9E<FQO<&5N+B!/<&YI975W(&%A;FUE;&1E;BP@82YU+F(N
M`%5W(&4M;6%I;&%D<F5S`%5W(%9A;CH@861R97,Z`%5W(&EN9F]R;6%T:64`
M57<@:6YT97)N971A9')E<R!I<R!G97=I:GII9V0@<VEN9',@:&5T(&)E9VEN
M('9A;B!U=R`E<R!S97-S:64N($]M('5W('9E:6QI9VAE:60@=&4@8F5S8VAE
M<FUE;BP@9&EE;G0@=2!Z:6-H(&]P;FEE=7<@86%N('1E(&UE;&1E;BX`57<@
M;F%A;3H`2&5T('1O979O96=E;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T
M(&]N9&5R<W1E=6YD(&1O;W(@=7<@875T:&5N=&EC871I92!B86-K96YD+B!7
M86YN965R('4@2&]R9&4@9V5B<G5I:V5R<R!W:6QT(&)E:&5R96XL(&1I96YT
M('4@965N(&%N9&5R(&%U=&AE;G1I8V%T:64@8F%C:V5N9"!T92!G96)R=6EK
M96XN`$AE="!W965R9V5V96X@=F%N(&5E;B!G96)R=6EK97)S;&EJ<W0@=V]R
M9'0@;FEE="!O;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@8F%C
M:V5N9"P@;V8@9&5Z92!O<'1I92!I<R!O;2!A;F1E<F4@<F5D96YE;B!U:71G
M97-C:&%K96QD+@!5=R!B<F]W<V5R(&QI:FMT('1E('II:FX@9V5W:6IZ:6=D
M('-I;F1S(&AE="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL
M:6=H96ED('1E(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A
M;B!T92!M96QD96XN`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z92!M;V=E
M;&EJ:VAE:60@;FEE="X`57<@8G)O=W-E<B!O;F1E<G-T975N="!D97IE('!R
M:6YT;W!T:64@;FEE="X@1')U:R!O<"!#;VYT<F]L+T-O;6UA;F0@*R!0(&]M
M(&%F('1E(&1R=6MK96XN`%5W(&AU:61I9V4@=&EJ9'IO;F4Z`%5W('-T86YD
M86%R9"!I9&5N=&ET96ET(&ES(&=E=VEJ>FEG9"X`57<@<W1A;F1A87)D(&ED
M96YT:71E:70Z`%5W('9O;&QE9&EG92!N86%M.@!5=R!A86YM96QD:6YG(&ES
M('9E<FQO<&5N+@!5=R!N:65U=V4@=V%C:'1W;V]R9"!V;V]R("5S(&ES.B`E
M<P!5=R!O<'1I97,@>FEJ;B!B:6IG97=E<FMT('9O;W(@9&4@9'5U<B!V86X@
M9&5Z92!S97-S:64N`%5W(&]P=&EE<R!Z:6IN(&)I:F=E=V5R:W0N`%5W('=A
M8VAT=V]O<F0@:7,@9V5R97-E=`!5=R!W86-H='=O;W)D(&ES('9E<FYI975W
M9"P@8V]N=')O;&5E<B!U=R!E+6UA:6P@96X@;65L9"!A86X@;65T('5W(&YI
M975W92!W86-H='=O;W)D+@!5=R!W86-H='=O;W)D(&ES('9E<FQO<&5N+@!5
M=R!S97)V97)S(&]P(&%F<W1A;F0Z`$IO96=O<VQA=FGK`%IA[W)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;5F5R8F5R9R!A86YG96AA86QD92!T96MS=%T`
M6U!R;V)L965M<F%P<&]R=%T`6T%A;F=E:&%A;&1E('1E:W-T('=E97)G979E
M;B`M`%M!86YG96AA86QD92!T96MS="`M("5S(')E9V5L<UT`6W)E9V5L("5S
M('9A;B`E<UT`0E]E:&5E<@!?0TQ)`%]$871A5')E90!697)?=VEJ9&5R(')I
M:@!?1W)O97!E;@!?2&5L<`!?069B965L9&EN9W-E:6=E;G-C:&%P<&5N+BXN
M`%]!86YM96QD96X`7T%F;65L9&5N`%]7:6IZ:6<@;&EN:RXN+@!?3W!T:65S
M`%]296-H=&5N`%]697)W:6ID97(@;&EN:RXN+@!?26YS=&5L;&5N`%]486)E
M;&5I9V5N<V-H87!P96XN+BX`1V5?8G)U:6ME<G,`061R97-B;V5K`$=E861R
M97-S965R9&4@;VYB96ME;F0`2V%L96YD97(`2V%L;0!+86X@;W5T<'5T8F5S
M=&%N9"!N:65T(&UA:V5N`$MA;B!I;G!U="!N:65T(&]P96YE;@!+;&EK(&AI
M97(`0V]M;6%N9&]R96=E;"!G96)R=6EK<V9O=70`0V]N9FEG=7)A=&EE9F]U
M=`!+<FET:7-C:"!S>7-T965M8F5S=&%N9"!O;G1B<F5E:W0`1&%T869O<FUA
M871F;W5T`&)E=V5R:V5N`&EN=F]E<B!N:65T(&=E=F]N9&5N`&1A;&5N9`!B
M97-T86YD`'9A;B!D92`E<R`H)7,I(&]P("5S("5S`'9L86=E<FEG`&@Z`&AH
M`&AO<W1N86%M(&]N8F5K96YD`&]N;6ED9&5L:6IK`&EN;&EN90!I;G!U="]O
M=71P=70@9F]U=`!I;G1E<FYE('-O9G1W87)E9F]U=`!R96=E;'-=`&UK:7-O
M9G,@9F]U=&-O9&4@)60@8FEJ(&AE="!A86YM86ME;B!V86X@25-/+@!M;0!N
M86%M`&YI970@=F%N('1O97!A<W-I;F<`3F]G(&YI970@=F%N('1O97!A<W-I
M;F<`;F]T:71I96)O96L`<')O8V5N=`!296-H="!G97=E:6=E<F0`<&EX96QS
M`%)E;6]T92!F;W5T(&EN('!R;W1O8V]L`'-T:6IG96YD`%-E<G9I8V4@;FEE
M="!B97-C:&EK8F%A<@!T;V]N('9E<G-C:&EL;&5N`'-M<S)E;6%I;"!V:6$@
M2%144`!S<P!S=&%B:65L`'-Y<W1E96UF;W5T`'1A:V5N;&EJ<W0`=&EJ9&5L
M:6IK92!M:7-L=6MK:6YG`%9O97(L('1E<B!B979E<W1I9VEN9RP@:&5T('=A
M8VAT=V]O<F0@='=E92!M86%L(&EN`'5N:69I960`;VYB96YO96UD`$=E8G)U
M:6ME<G-E;&5C=&EE`'9#87)D`'<Z`'=E871H97(N8V]M````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N;%].3"]H96QP+GAM
M;```````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``
M,3`U,34T,S$P-C(`,#(P,S$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(
M;W)D93H@:&]R9&4O;&]C86QE+VYL7TY,+VAE;'`N>&UL+'8@,2XR(#(P,#0O
M,#4O,C<@,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@
M:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!0
M86=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED
M97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN
M9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N
M>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/
M6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N
M('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N
M97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M
M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N
M(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE
M<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL
M(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES
M('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@
M8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I
M=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL
M(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I
M=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\
M<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E
M(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O
M;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY
M(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P
M<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L
M93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES
M(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC
M93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O
M(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R
M92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W
M:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E
M('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H
M96QP/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FY?3D\O````````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8R`#`Q-C8U-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N
M;E].3R],0U]-15-304=%4R\`````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-C(`,#(P-#0T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+VYN7TY/+TQ#7TU%4U-!1T53+VAO<F1E+FUO````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,S(P,0`Q,#4Q-30S,3`V,@`P,C(P
M-S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0````"9````'````.0$``#3````K`D```````#X#```"P```/D,```H
M````!0T``!4````N#0``"````$0-```%````30T```,```!3#0``#P```%<-
M```(````9PT```@```!P#0``&0```'D-```'````DPT```P```";#0``#@``
M`*@-```%````MPT``!\```"]#0``.0```-T-```G````%PX``"P````_#@``
M*@```&P.```1````EPX```@```"I#@``"````+(.```&````NPX``!4```#"
M#@``"@```-@.```1````XPX```P```#U#@``!P````(/```0````"@\``"L`
M```;#P``'@```$</```;````9@\``!L```""#P``,P```)X/```O````T@\`
M`"D````"$````@```"P0```%````+Q```!`````U$```!@```$80```4````
M31```"\```!B$```#P```)(0```F````HA````0```#)$```!0```,X0```-
M````U!````4```#B$```$````.@0```0````^1````\````*$0``"P```!H1
M```/````)A$```P````V$0``#P```$,1```>````4Q$``"$```!R$0```P``
M`)01```,````F!$``!0```"E$0``!@```+H1```$````P1$```P```#&$0``
M"@```-,1```%````WA$``!(```#D$0``$````/<1```(````"!(``!`````1
M$@``&@```"(2```&````/1(```<```!$$@```@```$P2```E````3Q(```0`
M``!U$@``#P```'H2```'````BA(```<```"2$@``"0```)H2```'````I!(`
M`!(```"L$@``!````+\2```'````Q!(```4```#,$@``,P```-(2```:````
M!A,```4````A$P``!P```"<3```1````+Q,```@```!!$P``%0```$H3```>
M````8!,``"@```!_$P``"P```*@3```:````M!,```4```#/$P``*````-43
M```I````_A,``!,````H%```,@```#P4```$````;Q0```8```!T%```"P``
M`'L4```%````AQ0``!$```"-%```!````)\4```,````I!0``!H```"Q%```
M%P```,P4```7````Y!0``!L```#\%```&0```!@5```?````,A4``!,```!2
M%0``!````&85```0````:Q4``!<```!\%0``!P```)05```%````G!4``#$`
M``"B%0``.````-05```A````#18``!P````O%@``!0```$P6```#````4A8`
M`"````!6%@``)@```'<6```,````GA8```8```"K%@``$P```+(6```,````
MQA8```@```#3%@``%````-P6```'````\18```8```#Y%@``#0`````7```+
M````#A<```P````:%P``"@```"<7```"````,A<```8````U%P``#````#P7
M``!%````21<``"8```"/%P``)0```+87```P````W!<``!`````-&```<P``
M`!X8```?````DA@``!````"R&```#P```,,8```%````TQ@``&(!``#9&```
M"@```#P:```H````1QH``!0```!P&@``"````(4:```%````CAH```@```"4
M&@``$P```)T:```,````L1H```\```"^&@``'@```,X:```'````[1H```H`
M``#U&@``#@`````;```%````#QL``",````5&P``.P```#D;```M````=1L`
M`"\```"C&P``+@```-,;```3`````AP```<````6'```"````!X<```&````
M)QP``!4````N'```#````$0<```6````41P```X```!H'```!0```'<<```0
M````?1P``"L```".'```'0```+H<```@````V!P``!P```#Y'```,````!8=
M```V````1QT``"P```!^'0```@```*L=```&````KAT``!$```"U'0``!@``
M`,<=```1````SAT``"8```#@'0``$0````<>```C````&1X```4````]'@``
M!@```$,>```.````2AX```0```!9'@``$````%X>```0````;QX```\```"`
M'@``#P```)`>```/````H!X```P```"P'@``$````+T>```?````SAX``",`
M``#N'@``!````!(?```-````%Q\``!0````E'P``!P```#H?```%````0A\`
M``\```!('P``#P```%@?```%````:!\``!,```!N'P``$````((?```%````
MDQ\``!(```"9'P``(````*P?```(````S1\```<```#6'P```@```-X?```E
M````X1\```8````'(```$`````X@```)````'R````<````I(```"0```#$@
M```(````.R```!4```!$(```!````%H@```(````7R````4```!H(```.```
M`&X@```@````IR````<```#((```"@```-`@```1````VR````<```#M(```
M%0```/4@```<````"R$``"P````H(0``!P```%4A```6````72$```<```!T
M(0``)0```'PA```D````HB$``!8```#'(0``+P```-XA```#````#B(```4`
M```2(@``"0```!@B```)````(B(``!8````L(@``!0```$,B```0````22(`
M`!D```!:(@``#P```'0B```/````A"(``!@```"4(@``$````*TB```0````
MOB(``!,```#/(@```P```.,B```5````YR(``!H```#](@``!P```!@C```(
M````(",``"D````I(P``-0```%,C```>````B2,``!X```"H(P``!@```,<C
M```#````SB,``!X```#2(P``*````/$C```/````&B0```@````J)```%```
M`#,D```0````2"0```H```!9)```%````&0D```(````>20```D```"")```
M#P```(PD```,````G"0```\```"I)```#P```+DD```"````R20```4```#,
M)```#@```-(D```Z````X20``"H````<)0``+0```$<E```R````=24```\`
M``"H)0``>0```+@E```F````,B8``!````!9)@``$````&HF```%````>R8`
M``$```!N`````````(L````&````````````````````8P```!,````-````
M``````````"&````@````!D```!/````$@```!H```!U````"0```'8````$
M````*`````4`````````;0```$@````X````0@````````!A````#```````
M````````@0```(T```!#````9@```"P````(`````````#<````^````@@``
M`&@`````````:@```#P```!D`````````$0```!Q````,````%````!Y````
M6@```)````!7````%0`````````1````F0`````````<`````P````````"'
M````/0```'T``````````````'@```!I````*P```(D`````````*0``````
M``!P``````````L```"%````````````````````@P```(H`````````````
M``````!Z```````````````D`````````$<```!8````$````$H````J````
M)@```!0``````````````&4```!=````EP``````````````<P```)0```".
M````CP``````````````-0```'L````R````=P``````````````)0```$T`
M``!5````+0```(0````B````1@`````````T````40`````````?````4@``
M``\``````````@```!X``````````````)4```"3````10```'0```",````
M?P`````````S````?@`````````8````5@``````````````'0``````````
M````-@`````````G``````````````"(````;P```#$```!?````"@``````
M``!4````7@```"``````````<@```&<```"2````20```!8```!.````#@``
M`#L```!`````2P```&(````;````;````)8```!3````.@```'P`````````
M:P```$P```"1````!P```"$`````````60```#D```"8````/P```",```!@
M`````````%P````7````00````````!;````+@```"\`````)7,@+2!.;W1I
M8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E
M<R!497)M<R!O9B!!9W)E96UE;G0`,C0@:&]U<G,`04TO4$T`061D`$%D9"!A
M(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N
M`$%L:6%S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M079A:6QA8FQE(&9I96QD<SH`0FER=&AD87D`0V%L96YD87(`0V%N8V5L`$-A
M;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L:6-K('1O($-O;G1I
M;G5E`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4N`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`
M1$0`1&%I;'D`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5D:70`16UA:6P`16UP='D@<F5S=6QT
M+@!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E
M<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M1F%X`$9I;&4@36%N86=E<@!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<',`
M2&5L<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!,86YG=6%G90!,:7-T($AE;'`@
M5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,;V<@
M;W5T`$U-`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`
M36%I;`!-871C:&EN9R!F:65L9',`365M8F5R<P!-97-S86=E`$UI;64@5'EP
M90!-;VYT:&QY`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YE='=O<FL`3F5V
M97(`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO=&5S`$]P
M=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!H;VYE`%!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$97-C<FEP
M=&EO;@!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+@!296%D`%)E;6]V90!296UO=F4@<&%I<@!297-E=`!2971U
M<FX@=&\@3W!T:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VAO=P!3:VEP($UA
M:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`5&%S
M:W,`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>0!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!5
M4DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5P
M9&%T90!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R;F%M
M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!787)N:6YG`%=E96ML>0!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9
M`%EE87)L>0!997,L($D@06=R964`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R
M;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF
M;W)M871I;VX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@
M)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP
M+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#(M,#8M,#@@,C(Z,S`K,#$P,`I,87-T+51R
M86YS;&%T;W(Z(%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R9SX*3&%N
M9W5A9V4M5&5A;3H@3F]R=V5G:6%N($YY;F]R<VL@/&YY;F]R<VM`;W)S=&$N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET"@`E<R`M($YO=&ES`"5S('9E9&QI:V5H86QD<V]P97)A<VIO
M;F%R("T@4W1A9&9E<W1I;F<`)7,@5FEL:^5R(&9O<B!A=G1A;&4`,C0@=&EM
M87(`04TO4$T`3&5G9R!T:6P`3&5G9R!T:6P@;GD@8G)U:V%R.@!,96=G('1I
M;"!P87(`3&5G9R!T:6P@8G)U:V%R`$QE9V<@=&EL(&)R=6MA<F%R(&5R('-L
MY71T(&%V+@!!9')E<W-E`$%D<F5S<V5B;VL`061M:6YI<W1R97)I;F<`06QI
M87,`16EN('5L;W9L96<@=F5R9&D@=F%R="!S<&5S:69I<V5R="X`4W#X<B!O
M;2!S=&%D9F5S=&EN9R!F^'(@:_AY<FEN9R!A=B!V961L:6ME:&%L9'-O<&5R
M87-J;VYA<C\`4'+X=F1E(.4@<VQE='1E(&5I(&EK:VIE+65K<VES=&5R86YD
M92!G<G5P<&4N`%!R^'9D92#E('-L971T92!E:6X@:6MK:F4M96MS:7-T97)A
M;F1E('1I;&=A;F<N`%!R^'9D92#E(&5N9')E(&5I;B!I:VMJ92UE:W-I<W1E
M<F%N9&4@=&EL9V%N9RX`5&EL9VIE;F=E;&5G92!F96QT.@!"=7)S9&%G`$MA
M;&5N9&5R`$%V8G)Y=`!!=F)R>70@<')O8FQE;7)A<'!O<G0`36]B:6QT96QE
M9F]N`$ML:6MK(&9O<B#E(&AA;&1E(&9R86T`3'5K:R!V:6YD875G970`1FER
M;6$`4W1A9&9E<W0@<&%S<V]R9`!/<'!K;W!L:6YG(&UO="!O9F9E;G1L96<@
M;OAK:V5L=&5N87(@;F5K=&$N`$MU;FYE(&EK:VIE(%!'4"UK;V1E(&UE;&1I
M;F<N`$MU;FYE(&EK:VIE(%!'4"US:6=N97)E(&UE;&1I;F<N`$MU;FYE(&EK
M:VIE(&1E:V]D92!01U`M9&%T82X`2W5N;F4@:6MK:F4@879G:F5R92!M;W1T
M86MA<F5N('-I(&4M<&]S=&%D<F5S<V4N`$MU;FYE(&EK:VIE('-K869F92!O
M9F9E;G1L96<@;OAK:V5L(&9RY2!N^&MK96QT96YA<F5N+@!+=6YN92!I:VMJ
M92!O<&YE($UA:6YT96YA;F-E7U1A<VLM;6]D=6QE;B`E<P!$1`!$86=L96<`
M4W1A;F1A<F1I9&5N=&ET970`4VQE='1E`%-K:6QD<F4@<')O8FQE;65T`$1E
M=&%L:F%R(&5R(&QO9V=A(&9O<B!A9&UI;FES=')A=&]R96XN`%9I<VEN9W-A
M;'1E<FYA=&EV`$EK:VIE(&)R=6L@;6%I;G1E;F%N8V4N<&AP(&1I<F5K=&4N
M`$5N9')E`$4M<&]S=`!4;VUT(')E<W5L=&%T+@!&96EL`$MV87)T(#$U+B!M
M:6YU='0`2W9A<G0@,S`N('-E:W5N9`!+=F%R="`U+B!M:6YU='0`2W9A<B!I
M;FYL;V=G:6YG`$MV87(@:&%L=F4@=&EM90!+=F%R="!M:6YU='0`16MS96UP
M96QV97)D:6%R.@!+=6YN92!I:VMJ92!H96YT92!I;FYS=&EL;&EN9V%R`$MU
M;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN`$9A:W,`1FEL:&%N
M9'-A;6EN9P!'<G5P<&5A9&UI;FES=')E<FEN9P!'<G5P<&5R`$AJ96QP`$%D
M<F5S<V4L('!R:79A=`!496QE9F]N+"!P<FEV870`2&]R9&4`26UP;W)T97)T
M92!F96QT.B`E<P!);7!O<G1E<G1E(&9E;'0Z`%-P<N5K`%9I<R!E;6YE(&9R
MY2!(:F5L<`!,:7-T:6YG(&%V(&)R=6MA<F%R(&5R('-LY71T(&%V+@!,;V=G
M(&EN;@!,;V=G('5T`$U-`$U3+51.148M=F5D;&5G9R!I;FYE:&5L9'0@:6YG
M96X@9&%T82X`12UP;W-T`%-A;7-V87)A;F1E(&9E;'0`365D;&5M;6%R`$UE
M;&1I;F<`34E-12UT>7!E`$WE;F%D;&5G`$Y%22P@96<@97(@24M+2D4@<V%M
M9`!.86UN`$YE='1V97)K`$%L9')I`$EN9V5N(&MO;F9I9W5R87-J;VYS:6YF
M;W)M87-J;VX@<W!E<VEF:7-E<G0@9F]R(%-13"!61E,N`$EN9V5N(&=Y;&1I
M9V4@6$U,+61A=&$@<F5T=7)N97)T`$YO=&%T87(`06QT97)N871I=@!!;FYA
M;B!I;F9O<FUA<VIO;@!087-S;W)D`%!A<W-O<F1A(&WE('-A;7-V87)E+@!+
M^'ER('9E9&QI:V5H86QD<V]P97)A<VIO;F%R`$OX>7(@=F5D;&EK96AA;&1S
M;W!E<F%S:F]N87(@=F5D(&EN;FQO9V=I;F<_`%1I;&=A;F<`5&EL9V%N9W-A
M9&UI;FES=')E<FEN9P!496QE9F]N`%-K<FEV(&EN;B!E:70@<V%M86YD<F%G
M(&%V('!R;V)L96UE="X`4VMR:78@:6YN(&1I='0@8G)U:V%R;F%M;B!O9R!P
M87-S;W)D`%-K:6QD<FEN9R!A=B!P<F]B;&5M970`3V9F96YT;&5G+W!R:79A
M="!N^&MK96QP87(@=F%R="!I:VMJ92!G96YE<F5R="X`3&5S`$9J97)N`$9J
M97)N('!A<@!.=6QL<W1I;&P`5&EL8F%K92!T:6P@86QT97)N871I=@!2;VQL
M90!,86=R92!A;'1E<FYA=&EV`%9E;"!S:VEL:F5T96EK;B!F;W(@9&%T;SH`
M5F5L(&1A=&]F;W)M870Z`%9E;"!T:61S9F]R;6%T.@!696P@=&\@<V%M<W9A
M<F%N9&4@9F5L="X`5F5L(&9A<F=E<VMJ96UA+@!696P@^&YS:V$@<W!RY6LZ
M`%-E;F0@<')O8FQE;7)A<'!O<G0`5FES`$AO<'`@;W9E<B!V961L:6ME:&%L
M9`!);FYT87-T:6YG(&%V('-P97-I86QT96EK;@!3=6MS97-S`$]P<&?E=F5R
M`$ML87-S82!-86EN=&5N86YC93HZ('9A<G0@:6MK:F4@;&%S=&$@:6YN`$MR
M>7!T97)I;F=S9G5N:W-J;VYA;F4@:W)E=B!E:2!S:6MK97(@;F5T=&]P<&MO
M<&QI;F<N`$1E='1E('1A;&5T(&WE('9E<F4@;6EN<W0@96EN+@!$96YN92!V
M97)D:65N(&WE('9E<F4@96ET('1A;"X`5&ET=&5L`%523`!+86X@:6MK:F4@
M:V]P;&4@=&EL(%-13"UT96YA<BX`2V%N(&EK:VIE(&]M<V5T:F4@9&5T=&4@
M5V]R9"UD;VMU;65N=&5T+@!!;F=R92!E;F1R:6YG87(`3W!P9&%T97(`0G)U
M:V%R861M:6YI<W1R97)I;F<`0G)U:V%R86QT97)N871I=@!"<G5K87)N86UN
M`$)R=6MA<F%R(&D@<WES=&5M970Z`,5T=F%R:6YG`$MV87(@=F5K90!696QK
M;VUE;B!T:6P@)7,`5F5L:V]M96XL("5S`$%D<F5S<V4L(&%R8F5I9`!496QE
M9F]N+"!A<F)E:60`Q<4`Q7)L96<`2F$L(&5G(&5R('-A;60`1'4@;>4@<VMI
M;&1R92!P<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!P<F]B;&5M<F%P<&]R
M=&5N+@!$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M;B#E(&9J97)N
M92X`1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!L96=G92!T
M:6PN`-AK=&$@9&D@*"5S*2!H87(@9^5T="!U="!PY2!T:60N($QO9V<@:6YN
M('#E(&YY='0N`$1I;B!I;F9O<FUA<VIO;@!,:7-T:6YG(&%V(&)R=6MA<F%R
M(&5R(&EK:VIE('-T^'1T82!A=B!B86MR92!A=71E;G1I<V5R:6YG+"!E;&QE
M<B!F=6YK<VIO;F5N(&AA<B!A=B!E:6X@96QL97(@86YN86X@9W)U;FX@8FQI
M='0@<VSE='0@878N`$%L=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T(&]P<&1A
M=&5R=&4N`%M0<F]B;&5M<F%P<&]R=%T`6VQI;FIE("5S(&%V("5S70!V0V%R
M9```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+VYN7TY/+VAE;'`N>&UL````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#4Q-30S,3`V,@`P,C`S,C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O
M;FY?3D\O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@
M17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^
M"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@
M;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M
M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G
M97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@
M;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L
M(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S
M;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN
M('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S
M"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N
M97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A
M<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U
M<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP
M;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@
M=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@
M=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N
M($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T
M(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N
M(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES
M(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*
M("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A
M/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E
M;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B
M;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U
M=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]P;%]03"\`````````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C(`,#$V-C4V`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!L7U!,+TQ#7TU%4U-!1T53+P``
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`V,@`P,C`T-#,`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<&Q?
M4$PO3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,30Q,#$U`#$P-3$U-#,Q,#8R`#`R,C$P,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````$$#```<````)!H`
M`%T$```L-````````*!%``!(````H44```X```#J10``#P```/E%```-````
M"48```@````71@``"P```"!&```,````+$8``!L````Y1@``+0```%5&```D
M````@T8``"D```"H1@``&0```-)&```,````[$8```L```#Y1@``$0````5'
M```.````%T<```4````F1P``*````"Q'```(````54<```H```!>1P``$@``
M`&E'```.````?$<```H```"+1P``#0```)9'```.````I$<``!$```"S1P``
M#0```,5'```,````TT<```T```#@1P``!@```.Y'```,````]4<```X````"
M2```#@```!%(```(````($@```D````I2```&@```#-(```R````3D@``#@`
M``"!2```5````+I(``!1````#TD``%H```!A20``5P```+Q)```T````%$H`
M``4```!)2@``$0```$]*```(````84H``!````!J2@``#P```'M*```*````
MBTH```,```"62@``"0```)I*```-````I$H``!(```"R2@``#P```,5*```*
M````U4H```\```#@2@``"````/!*```D````^4H``!0````>2P``%@```#-+
M```(````2DL``"T```!32P``&0```(%+```'````FTL```P```"C2P``#@``
M`+!+```#````OTL```L```##2P``!P```,]+```'````UTL```4```#?2P``
M`P```.5+```7````Z4L```H````!3```#P````Q,```8````'$P```X````U
M3```%````$1,```7````64P``!<```!Q3```%P```(E,```/````H4P``!\`
M``"Q3```!P```-%,```&````V4P```@```#@3```#P```.E,```&````^4P`
M``H`````30``"P````M-```5````%TT```<````M30``!0```#5-```1````
M.TT```P```!-30``"0```%I-```'````9$T```4```!L30``.0```')-```*
M````K$T```8```"W30``"0```+Y-```'````R$T``"\```#030``+@````!.
M``!5````+TX``"T```"%3@``+0```+-.```M````X4X``",````/3P``(P``
M`#-/```M````5T\``#,```"%3P``%0```+E/```9````ST\``"D```#I3P``
M)````!-0```1````.%````H```!*4```#````%50```*````8E```!````!M
M4```%@```'Y0```6````E5````<```"L4```!P```+10```4````O%````H`
M``#14```!P```-Q0```'````Y%````8```#L4```!0```/-0```'````^5``
M``8````!40``"`````A1```.````$5$```H````@40``!P```"M1```)````
M,U$``!8````]40``!````%11```&````65$```@```!@40```P```&E1```#
M````;5$``!,```!Q40``"````(51```(````CE$```@```"740``00```*!1
M```@````XE$```8````#4@``!@````I2```5````$5(``!@````G4@``(@``
M`$!2```=````8U(```H```"!4@``%0```(Q2```*````HE(```\```"M4@``
M#P```+U2```)````S5(``!0```#74@``&````.Q2```=````!5,``!,````C
M4P``$0```#=3```$````25,```8```!.4P``5````%53```.````JE,``$0`
M``"Y4P``!0```/Y3```%````!%0``!$````*5```$0```!Q4```<````+E0`
M`!````!+5```$0```%Q4```,````;E0``!<```![5```$````)-4```(````
MI%0```4```"M5```#````+-4```0````P%0```T```#15```!P```-]4```-
M````YU0```<```#U5```!P```/U4```'````!54``!0````-50``"0```")5
M```*````+%4```P````W50``$````$15```%````554``"4```!;50``$@``
M`(%5```3````E%4``"L```"H50``.P```-15```@````$%8``#8````Q5@``
M$````&A6```(````>58```P```""5@``!````(]6```.````E%8``!X```"C
M5@``&P```,)6```A````WE8``!X`````5P``'@```!]7```N````/E<``!L`
M``!M5P``'@```(E7```S````J%<``"\```#<5P``(`````Q8```2````+5@`
M`"D```!`6```'@```&I8```6````B5@``$$```"@6```!P```.)8```&````
MZE@```T```#Q6```$````/]8```2````$%D```<````C60``!````"M9```,
M````,%D``"@````]60```P```&99```&````:ED```X```!Q60```@```(!9
M```%````@UD```0```")60``#@```(Y9```(````G5D```T```"F60``$```
M`+19```3````Q5D``!,```#960``!@```.U9```,````]%D``!$````!6@``
M&0```!-:```+````+5H```T````Y6@``&P```$=:```T````8UH```H```"8
M6@``&````*-:```9````O%H``!8```#66@``+P```.U:```'````'5L``!0`
M```E6P``+P```#I;```)````:EL``!8```!T6P``#P```(M;```(````FUL`
M``T```"D6P``)@```+);```(````V5L``!(```#B6P``"````/5;```+````
M_EL```4````*7```!@```!!<```'````%UP```0````?7```"@```"1<```/
M````+UP``!`````_7```%P```%!<```1````:%P``!<```!Z7```!0```))<
M```+````F%P```4```"D7```#0```*I<```;````N%P```D```#47```#@``
M`-Y<```-````[5P``"````#[7```$0```!Q=```'````+ET```4````V70``
M$P```#Q=```'````4%T```@```!870``!@```&%=```0````:%T```\```!Y
M70``$````(E=```/````FET```L```"J70``#P```+9=```,````QET```\`
M``#370``!P```.-=```&````ZUT```X```#R70``(0````%>```9````(UX`
M`!<````]7@``%P```%5>```;````;5X```T```")7@``#````)=>```#````
MI%X```@```"H7@``!````+%>```,````MEX```D```##7@``#@```,U>```+
M````W%X``!L```#H7@``!P````1?```'````#%\```0````47P``%0```!E?
M```&````+U\```T````V7P``$````$1?```;````55\```0```!Q7P``!0``
M`'9?```&````?%\```<```"#7P``!0```(M?```)````D5\```(```";7P``
M#0```)Y?```&````K%\```D```"S7P``!P```+U?```&````Q5\```H```#,
M7P``!````-=?```)````W%\```@```#F7P``!@```.]?```-````]E\```8`
M```$8```!`````M@```%````$&```"$````68```!````#A@```$````/6``
M``4```!"8```'0```$A@```$````9F````P```!K8```"@```'A@```(````
M@V````D```",8```!0```)9@```I````G&````<```#&8```!P```,Y@```*
M````UF````\```#A8```$````/%@```&`````F$``!(````)80``$````!QA
M```%````+6$```D````S80``!````#UA```,````0F$``!<```!/80``'```
M`&=A```3````A&$``!0```"880``&0```*UA```$````QV$```<```#,80``
M!@```-1A```&````VV$```4```#B80``!P```.AA```'````\&$```4```#X
M80``!@```/YA```$````!6(```0````*8@``"@````]B```%````&F(```P`
M```@8@``#P```"UB```*````/6(```@```!(8@``*P```%%B```$````?6(`
M``@```""8@``)@```(MB```2````LF(```8```#%8@``"@```,QB```'````
MUV(```@```#?8@``(````.AB```.````"6,``!8````88P``$0```"]C```&
M````06,```<```!(8P``!P```%!C```6````6&,```T```!O8P``$````'UC
M```:````CF,```D```"I8P``"@```+-C```,````OF,```\```#+8P``!@``
M`-MC```'````XF,```L```#J8P``1P```/9C```-````/F0```,```!,9```
M"@```%!D```"````6V0```0```!>9````P```&-D```%````9V0``"H```!M
M9```"@```)AD```$````HV0```8```"H9```"````*]D```(````N&0```0`
M``#!9```!0```,9D``!H````S&0```4````U90``!@```#ME```0````0F4`
M``H```!390``#P```%YE```*````;F4```D```!Y90```P```(-E```'````
MAV4```H```"/90``"P```)IE```'````IF4``!H```"N90``2@```,EE```&
M````%&8```D````;9@``#0```"5F```*````,V8```<````^9@``%````$9F
M```&````6V8```@```!B9@``!P```&MF```*````<V8```L```!^9@``!P``
M`(IF```)````DF8```D```"<9@``"@```*9F```'````L68```D```"Y9@``
M!P```,-F```*````RV8```H```#69@``"0```.%F```'````ZV8```0```#S
M9@``!P```/AF```%`````&<```4````&9P``"P````QG```4````&&<```<`
M```M9P``!0```#5G```-````.V<```P```!)9P``"P```%9G```$````8F<`
M``0```!G9P``#````&QG```)````>6<```4```"#9P``!P```(EG```$````
MD6<```H```"69P``+@```*%G```0````T&<``"T```#A9P``+0````]H```Q
M````/6@``"T```!O:```+@```)UH```O````S&@``"P```#\:```!````"EI
M```.````+FD```8````]:0``$````$1I```'````56D```X```!=:0``!0``
M`&QI```&````<FD```@```!Y:0``$0```()I```.````E&D```(```"C:0``
M!P```*9I```&````KFD```0```"U:0``'P```+II```4````VFD```<```#O
M:0``#@```/=I```,````!FH``!,````3:@``"@```"=J```%````,FH``!$`
M```X:@``$0```$IJ```D````7&H``!4```"!:@``$@```)=J```.````JFH`
M`!D```"Y:@``"````--J```)````W&H```H```#F:@``"````/%J```%````
M^FH```8`````:P``$`````=K```(````&&L```@````A:P``$@```"IK```:
M````/6L```D```!8:P``"@```&)K```5````;6L```4```"#:P``%````(EK
M```>````GFL``"@```"]:P``"@```.9K```/````\6L``!0````!;```!```
M`!9L```+````&VP```4````G;```"````"UL```T````-FP``#0```!K;```
M(````*!L```:````P6P``"@```#<;```*0````5M```&````+VT```@````V
M;0``!P```#]M```+````1VT```<```!3;0``$P```%MM```*````;VT``!0`
M``!Z;0``#P```(]M```R````GVT```L```#2;0``!0```-YM```%````Y&T`
M`!<```#J;0``'@````)N```4````(6X```X````V;@``!@```$5N```,````
M3&X```T```!9;@``"P```&=N```*````<VX```L```!^;@``#P```(IN```%
M````FFX```X```"@;@``$P```*]N```'````PVX``!$```#+;@``!P```-UN
M```8````Y6X```0```#^;@``!P````-O```*````"V\```L````6;P``#```
M`")O```.````+V\``!(````^;P``!@```%%O```8````6&\``"4```!Q;P``
M"0```)=O```#````H6\```H```"E;P``#````+!O```5````O6\```L```#3
M;P``&0```-]O```@````^6\```4````:<```"@```"!P```,````*W````0`
M```X<```"0```#UP```'````1W````P```!/<```!@```%QP```,````8W``
M`!H```!P<```%P```(MP```G````HW```!H```#+<```%P```.9P```;````
M_G```!D````:<0``'P```#1Q```3````5'$```<```!H<0``"0```'!Q```-
M````>G$```,```"(<0``/P```(QQ```W````S'$``%<````$<@``!0```%QR
M```*````8G(```T```!M<@``!````'MR```E````@'(``!T```"F<@``#```
M`,1R```9````T7(```D```#K<@``$P```/5R```)````"7,```0````3<P``
M$````!AS```(````*7,```@````R<P``#P```#MS```'````2W,```P```!3
M<P``&P```&!S```L````?',```4```"I<P``!````*]S```7````M',```H`
M``#,<P``#````-=S```)````Y',```D```#N<P``$0```/AS```&````"G0`
M``X````1=```!P```"!T```&````*'0```<````O=```)@```#=T```X````
M7G0``!H```"7=```*@```+)T```9````W70```4```#W=```#@```/UT```(
M````#'4```D````5=0``!@```!]U```+````)G4``!0````R=0``!@```$=U
M```9````3G4```H```!H=0``'````'-U```%````D'4``!````"6=0``"0``
M`*=U```(````L74``!\```"Z=0``(P```-IU```A````_G4``!\````@=@``
M)P```$!V```?````:'8``#$```"(=@``00```+IV```S````_'8``"4````P
M=P``+P```%9W```P````AG<``"\```"W=P``+````.=W```7````%'@``"(`
M```L>```10```$]X```P````E7@```0```#&>```"P```,MX```%````UW@`
M``(```#=>```60```.!X```%````.GD```0```!`>0``!P```$5Y```(````
M37D```4```!6>0``$P```%QY```-````<'D```<```!^>0``!@```(9Y```4
M````C7D```P```"B>0``!@```*]Y```#````MGD```0```"Z>0``!@```+]Y
M```'````QGD``!<```#.>0``(````.9Y```:````!WH``"8````B>@``#```
M`$EZ```4````5GH```X```!K>@``#0```'IZ```'````B'H```<```"0>@``
M%0```)AZ```&````KGH```8```"U>@``!P```+QZ```,````Q'H``!$```#1
M>@``"````.-Z```=````['H```D````*>P``"@```!1[```4````'WL```H`
M```T>P``"````#][```'````2'L```D```!0>P``!P```%I[```(````8GL`
M``<```!K>P``&0```'-[```*````C7L``!<```"8>P``%````+![```1````
MQ7L```<```#7>P```P```-][```&````XWL```<```#J>P``#0```/)[```+
M`````'P``!0````,?```%0```"%\```.````-WP``"\```!&?```,0```'9\
M```_````J'P```P```#H?```"@```/5\```"`````'T```0````#?0``!@``
M``A]```%````#WT```,````5?0``#````!E]```9````)GT``$4```!`?0``
M)@```(9]```E````K7T``!(```#3?0``$P```.9]```0````^GT``'D````+
M?@``"0```(5^``!R````CWX``',````"?P``%P```'9_```6````CG\```\`
M``"E?P``'P```+5_``!`````U7\``!\````6@```%````#:````*````2X``
M``4```!6@```!@```%R````(````8X```!````!L@```#P```'V````$````
MC8````L```"2@```!P```)Z````%````IH````<```"L@```"````+2````/
M````O8````@```#-@```#````-:````/````XX````8```#S@```!@```/J`
M```,`````8$```@````.@0``!````!>!```$````'($```<````A@0``!P``
M`"F!```%````,8$``%,!```W@0``0P```(N"```.````SX(``!(```#>@@``
M$0```/&"```'`````X,```@````+@P``"@```!2#```B````'X,``"\```!"
M@P``'0```'*#```B````D(,``!X```"S@P``"@```-*#```*````W8,``!``
M``#H@P``#P```/F#```%````"80``"<````/A```#P```#>$```.````1X0`
M`!````!6A```$````&>$```(````>(0``!$```"!A```#0```).$```3````
MH80```P```"UA```"P```,*$```.````SH0```8```#=A```#0```.2$```2
M````\H0``!(````%A0``"````!B%```*````(84``!<````LA0``/P```$2%
M``!(````A(4``%P```#-A0``60```"J&``!B````A(8``%\```#GA@``00``
M`$>'```%````B8<```X```"/AP``#@```)Z'```.````K8<``!(```"\AP``
M!0```,^'```%````U8<```P```#;AP``$````.B'```6````^8<``!D````0
MB```#0```"J(```5````.(@```H```!.B```'@```%F(```;````>(@``"``
M``"4B```$0```+6(```M````QX@``"8```#UB```!0```!R)```0````(HD`
M``T````SB0``!P```$&)```*````28D```<```!4B0``"````%R)```%````
M98D```@```!KB0``(P```'2)```/````F(D``!4```"HB0``%P```+Z)```,
M````UHD``!<```#CB0``%P```/N)```C````$XH``!@````WB@``$P```%"*
M```E````9(H```8```"*B@``!@```)&*```(````F(H```\```"AB@``"0``
M`+&*```*````NXH```D```#&B@``$````-"*```)````X8H```@```#KB@``
M$0```/2*```.````!HL```D````5BP``!P```!^+```%````)XL``#T````M
MBP``"````&N+```(````=(L```D```!]BP``!P```(>+```X````CXL``#@`
M``#(BP``6P````&,```W````78P``#<```"5C```-P```,V,```N````!8T`
M`#(````TC0``-P```&>-```]````GXT``"$```#=C0``)0```/^-```O````
M)8X``#$```!5C@``#@```(>.```+````EHX```P```"BC@```P```*^.```)
M````LXX``!0```"]C@``'P```-*.```,````\HX```<```#_C@``%@````>/
M```*````'H\```@````ICP``!@```#*/```&````.8\```4```!`CP``!P``
M`$:/```&````3H\```X```!5CP``$````&2/```)````=8\```<```!_CP``
M"````(>/```4````D(\```,```"ECP``"````*F/```(````LH\```,```"[
MCP```P```+^/```;````PX\```D```#?CP``"````.F/```'````\H\``$\`
M``#ZCP``+0```$J0```&````>)````8```!_D```&0```(:0```=````H)``
M`"P```"^D```(````.N0```9````#)$``!8````FD0``"0```#V1```3````
M1Y$``!,```!;D0``"0```&^1```6````>9$``!H```"0D0``'P```*N1```5
M````RY$``!8```#AD0``!````/B1```%````_9$``$8````#D@``#P```$J2
M```S````6I(```4```".D@``!0```)22```+````FI(``!<```"FD@``(```
M`+Z2```7````WY(``!8```#WD@``#`````Z3```9````&Y,```T````UDP``
M"````$.3```%````3),```T```!2DP``#````&"3```-````;9,```<```![
MDP``!P```(.3```)````BY,```8```"5DP``!0```)R3```5````HI,```D`
M``"XDP``!P```,*3```.````RI,```\```#9DP``!0```.F3```=````[Y,`
M`!P````-E```'0```"J4```L````2)0``#L```!UE```*0```+&4```^````
MVY0```X````:E0``"````"F5```+````,I4```<````^E0``#0```$:5```K
M````5)4``"@```"`E0``+@```*F5```K````V)4``"H````$E@``.0```"^6
M```E````:98``"@```"/E@``+0```+B6```S````YI8``"8````:EP``%@``
M`$&7```M````6)<``"````"&EP``(@```*>7``!%````RI<```0````0F```
M!@```!68```+````')@```L````HF```%@```#28```)````2Y@```0```!5
MF```"P```%J8```W````9I@```8```">F```!````*68```/````JI@```(`
M``"ZF```"@```+V8```$````R)@```T```#-F```"````-N8```.````Y)@`
M`!(```#SF```%`````:9```4````&YD```0````PF0``"@```#69```0````
M0)D``!D```!1F0``#````&N9```,````>)D``!L```"%F0``.@```*&9```+
M````W)D``!@```#HF0``%0````&:```4````%YH``#0````LF@``!0```&&:
M```-````9YH``#````!UF@``!P```*::```F````KIH``!(```#5F@``!P``
M`.B:```)````\)H``"X```#ZF@``'0```"F;```C````1YL```@```!KFP``
M"P```'2;```)````@)L```8```"*FP``!P```)&;```&````F9L```H```"@
MFP``$0```*N;```1````O9L``!@```#/FP``%0```.B;```8````_IL```4`
M```7G```"````!V<```%````)IP```L````LG```)0```#B<```)````7IP`
M`!````!HG```$````'F<```V````BIP``!````#!G```!P```-*<```$````
MVIP``!<```#?G```!P```/><```'````_YP```8````'G0``$0````Z=```1
M````()T``!(````RG0``$````$6=```4````5IT``!0```!KG0``#P```("=
M```5````D)T```<```"FG0``!@```*Z=```,````M9T``"H```#"G0``'P``
M`.V=```@````#9X``"(````NG@``$P```%&>```+````99X``!````!QG@``
M!````(*>```$````AYX```4```",G@``#P```)*>```+````HIX```L```"N
MG@``#P```+J>```F````RIX```8```#QG@``"0```/B>```(`````I\``!(`
M```+GP``!P```!Z?```0````)I\``!,````WGP``+@```$N?```"````>I\`
M``4```!]GP``!@```(.?```&````BI\```4```"1GP``"0```)>?```#````
MH9\``!,```"EGP``!@```+F?```*````P)\```<```#+GP``$````-.?```)
M````Y)\```0```#NGP``"0```/.?```(````_9\```8````&H```#0````V@
M```&````&Z````0````BH```!0```">@```7````+:````4```!%H```!@``
M`$N@```&````4J```!P```!9H```"````':@```,````?Z````D```",H```
M"````):@```(````GZ````4```"HH```)0```*Z@```%````U*````@```#:
MH```"P```..@```/````[Z```!$```#_H```!P```!&A```4````&:$``!$`
M```NH0``!0```$"A```)````1J$```0```!0H0``#0```%6A```;````8Z$`
M`!T```!_H0``&@```)VA```=````N*$```0```#6H0``!````-NA```(````
MX*$```8```#IH0``!P```/"A```&````^*$```<```#_H0``!P````>B```'
M````#Z(```8````7H@``!@```!ZB```(````):(```H````NH@``!0```#FB
M```0````/Z(```T```!0H@``#@```%ZB```*````;:(``#$```!XH@``!@``
M`*JB```(````L:(``"@```"ZH@``#P```..B```&````\Z(```D```#ZH@``
M"P````2C```%````$*,```0````6HP``%@```!NC```;````,J,``!D```!.
MHP``!0```&BC```'````;J,```<```!VHP``!0```'ZC```-````A*,``!8`
M``"2HP``)P```*FC```%````T:,```P```#7HP``#@```.2C```9````\Z,`
M``<````-I```!P```!6D```6````':0``%<````TI```&P```(RD```%````
MJ*0```H```"NI````@```+FD```$````O*0```,```#!I```!0```,6D```)
M````RZ0```H```#5I```!@```."D```&````YZ0```<```#NI```"````/:D
M```$````_Z0```4````$I0``6P````JE```&````9J4```@```!MI0``#P``
M`':E```)````AJ4```T```"0I0``"@```)ZE```)````J:4```,```"SI0``
M!P```+>E```*````OZ4```X```#*I0``"0```-FE```?````XZ4``%H````#
MI@``!@```%ZF```(````9:8``!0```!NI@``"@```(.F```(````CJ8``!(`
M``"7I@``!@```*JF```(````L:8```H```"ZI@``"@```,6F```-````T*8`
M``8```#>I@``#0```.6F```.````\Z8```\````"IP``#@```!*G```.````
M(:<```X````PIP``"````#^G```%````2*<```H```!.IP``!0```%FG```(
M````7Z<```<```!HIP``!0```'"G```%````=J<```@```!\IP``$P```(6G
M```$````F:<```4```">IP``#@```*2G```.````LZ<```T```#"IP``"@``
M`-"G```(````VZ<```X```#DIP``"0```/.G```%````_:<```<````#J```
M!`````NH```*````$*@``!D````;J```$````#6H```K````1J@``"L```!R
MJ```+P```)ZH```K````SJ@``"P```#ZJ```+0```">I```J````5:D```4`
M``"`J0``!P```(:I```(````CJD``!4```"7J0``#````*VI```.````NJD`
M``4```#)J0``!0```,^I```(````U:D```T```#>J0``#@```.RI```"````
M^ZD```L```#^J0``!0````JJ```$````$*H``"<````5J@``%````#VJ```%
M````4JH```@```!8J@``"P```&&J```7````;:H```L```"%J@``!````)&J
M```/````EJH``!````"FJ@``)P```+>J```2````WZH``!H```#RJ@``$P``
M``VK```L````(:L```<```!.JP``"P```%:K```,````8JL```@```!OJP``
M!0```'BK```&````?JL``!$```"%JP``"````)>K```%````H*L``!,```"F
MJP``%@```+JK```&````T:L```<```#8JP``$P```."K```%````]*L``!``
M``#ZJP``&@````NL```M````)JP```L```!4K```#P```&"L```3````<*P`
M``0```"$K```"````(FL```'````DJP```@```":K```)````*.L```@````
MR*P``!\```#IK```&P````FM```6````):T``"8````\K0``!@```&.M```*
M````:JT```<```!UK0``#@```'VM```'````C*T```T```"4K0``#P```**M
M```;````LJT``!X```#.K0``.@```.VM```)````**X```4````RK@``"0``
M`#BN```>````0JX``"$```!AK@``%@```(.N```.````FJX```0```"IK@``
M"0```*ZN```,````N*X```D```#%K@``!````,^N```0````U*X``!8```#E
MK@``!0```/RN```-`````J\``!,````0KP``!@```"2O```/````*Z\```<`
M```[KP``&0```$.O```*````7:\```<```!HKP``$@```'"O```,````@Z\`
M``T```"0KP``'````)ZO```%````NZ\```8```#!KP``'0```,BO```H````
MYJ\```L````/L````P```!NP```,````'[````T````LL```$P```#JP```+
M````3K```!<```!:L```&0```'*P```%````C+````H```"2L```$````)VP
M```&````KK````L```"UL```"0```,&P```,````R[````8```#8L```#0``
M`-^P```;````[;```!0````)L0``'````!ZQ```;````.[$``!4```!7L0``
M&@```&VQ```8````B+$``!\```"AL0``&0```,&Q```'````V[$```@```#C
ML0``#0```.RQ```%````^K$``#X`````L@``-0```#^R``!6````=;(```P`
M``#,L@``"````-FR```+````XK(```4```#NL@``,P```/2R```7````*+,`
M``P```!`LP``,````$VS```&````?K,``!````"%LP``"````):S```(````
MG[,``!@```"HLP``"````,&S```(````RK,```X```#3LP``!P```.*S```1
M````ZK,``"$```#\LP``$@```!ZT```)````,;0```0````[M```&0```$"T
M```/````6K0```\```!JM```#@```'JT```)````B;0``!0```"3M```!@``
M`*BT```,````K[0```4```"\M```!@```,*T```*````R;0``"````#4M```
M(````/6T```6````%K4``"`````MM0``&0```$ZU```%````:+4``!0```!N
MM0``!P```(.U```%````B[4```<```"1M0``"@```)FU```%````I+4```8`
M``"JM0``!@```+&U```+````N+4```@```#$M0``!P```,VU```.````U;4`
M``L```#DM0``"0```/"U```D````^K4``"`````?M@``'````$"V```<````
M7;8``",```!ZM@``(````)ZV```S````O[8``$<```#SM@``+@```#NW```L
M````:K<``#@```"7MP``,P```-"W```J````!+@``"H````ON```%@```%JX
M```A````<;@``$(```"3N```.````-:X```$````#[D```P````4N0``!0``
M`"&Y```"````)[D``%X````JN0``!````(FY```$````CKD```<```"3N0``
M!0```)NY```%````H;D``!$```"GN0``$````+FY```'````RKD```8```#2
MN0``%````-FY```,````[KD```8```#[N0```P````*Z```$````!KH```8`
M```+N@``!P```!*Z```:````&KH``"D````UN@``(P```%^Z```M````@[H`
M``T```"QN@``'````+^Z```/````W+H```,```#LN@``"````/"Z```)````
M^;H``!L````#NP``"@```!^[```'````*KL```<````RNP``$0```#J[```7
M````3+L``!$```!DNP``)@```':[```2````G;L``!,```"PNP``%P```,2[
M```*````W+L```<```#GNP``!P```.^[```)````][L```8````!O```!P``
M``B\```(````$+P``!`````9O```#0```"J\```:````.+P``"0```!3O```
M#P```'B\```+````B+P```,```"4O```"@```)B\```&````H[P```L```"J
MO```"@```+:\```5````P;P``!8```#7O```$````.Z\```S````_[P``#<`
M```SO0``3P```&N]```.````N[T```T```#*O0```@```-B]```$````V[T`
M``8```#@O0``!0```.>]```#````[;T``!````#QO0``$`````*^```G````
M$[X``#,````[O@``,@```&^^```1````HKX```X```"TO@``$````,.^``"!
M````U+X```H```!6OP``70```&&_``!>````O[\``!P````>P```$P```#O`
M```<````3\```"````!LP```0````(W````F````SL```!4```#UP```"@``
M``O!```$````%L$```8````;P0``"````"+!```4````*\$```X```!`P0``
M!````$_!```,````5,$```8```!AP0``!@```&C!```(````;\$```@```!X
MP0``#0```('!```&````C\$```P```"6P0``#````*/!```-````L,$```P`
M``"^P0``$````,O!```)````W,$```0```#FP0``"````.O!```(````],$`
M``D```#]P0``!0````?"```!````J@``````````````6`````````"\`0``
M`````-H````*````:````#0#``"<`@``$@```#X"``##`0``E0```)4!````
M````1P$``$T!`````````````+("``#!`@``%0```$,"``#*`0``Q@```'``
M``!O`0``70(```H#``"7`@```````)D``````````````%\```#Q````1@(`
M```````P`0``90$``-,"````````RP$```````"E````E@```%P```"%`@``
M#0$``+8"`````````````'8````$`@```````*\```#\`@```````)````#-
M````<@$``-4`````````NP````("``"X`@```````!$`````````S`(``'0`
M``!U`@``B@```#H```#A`0``!0(``%X`````````-0```"8"````````)P,`
M`*8"```"````(0,```,#``#D````-@$```````!U``````````P!``"H`0``
MJP```-H"``"W`@``7P$``+8```!@`0``(`,``",#``"I````]`$````````<
M`0``#P(```````#U`0``'0,``&`"``")````KP$```````!"`0``$@(``#4#
M```0`P``WP$```````#0````0`$``%`"``!J`0```````,4```#W````5@$`
M````````````40````````!F`````````"H#```9`P``D`(```````!:````
M^P```!0!``#Z`0``P0``````````````I0(``#L!````````[@```/L"````
M`````````*,!``!W`0````````````#J`@``V`(```````#&`0``3P```'H!
M````````7P(``$\!`````````````&\"``!%`@``*`(``)\"``#"`0``.`,`
M``````!E````#0(`````````````-@```%<"````````4@```#H#``!3`@``
M`````$````#^`0``,0```*P"``!K`0``_P(```````!A`````````%D!```J
M`@```````&0````'`0```````/L!```I`0```````.D````T`@``_@(``(,!
M``"X`0```````"(#```^````%P(``,L```#=`@``>@(`````````````QP(`
M`-T!```*`@``QP````````!\````#`,``.,"``#"`@``X@````````!J````
M`````*4!``"V`0```````-P!```I`P``/0(``(X`````````2P(```````#'
M`0```````+X!``#/`0``]0(``*$``````````````)X!``">`@``R0$``-8`
M```!`0```````,L"```U`@``S@(``$@````;`@``<0``````````````)@$`
M`(<!```E`P```````"T"``"@`@``IP$``````````````````$L!``#H`0``
M3````#X#````````0P$```4```"_````&@,``$X!``````````````````!B
M`@``M````)@````6`@``/P(``#\!``":`@``L`$``&T`````````30```(0!
M``!I`@``%````,D"`````````````#D!````````?P$``/H```"B`0``?`$`
M`-L```"9`@````````````!V`0``<0(``.(!```[`@``F0$````````<`@``
M`````!H"``#K`0```````/,"`````````0(``(````"]`@``ZP(``/,!``#7
M`@``$`(````````=`@``$0$``$4```#O`@``I````#8#``""`0``,@(`````
M```W````;@(``$@"```;`P``[@(``#````#\`0``!@$```````#P````.```
M``````"C`@``G0(``%@!``!'````.0```/$"```L`@```````+L"```K````
M00``````````````"0(```````"2`0``````````````````\P```/0"``#7
M`0``C0````````!K`@``+0```/<!```:`0``^0(``%0"```G`0``0@```(L"
M```3`0``4@(``'T```#M`@`````````````1`P```````(P`````````````
M```````?``````````````#U````!````-T```!+````;`(```````#C`0``
M`````'`"```L`P``B0(```````!3`0``/@$```````#Y````"`(``$X```"<
M`0```````$8`````````BP```!<#`````````````.<!````````?0(`````
M````````@0```,@"``"]``````````````"X````(@```.<```!C`0``````
M`#P```"U`@``R`$``(("``"P`@``,@```*`!``"2`@```````+D!````````
MG0$``-X````9`@``(0````````!!`P``MP```+D`````````,0(``)@!```S
M`````````*T!``#/````=@(``%8"```6`P```````(@"````````````````
M```&`@```````'L"``!$````60(````#```/````(`(``"X"````````9P``
M`%H"```W`0``#0```$\"```R`P``+P```%@"``"N`````````","```\`0``
M`````-L"````````!P````H!```D`0``A@(``.4`````````:0$``$H```![
M`0``X0```*@```"&`````````+H```"Z`@``7`$``!X!``!^`@```````,D`
M````````U`$````````>````W@$```````#K````DP```*$"```C````````
M`-$!``#2`````````",!````````B@(````````E`@``0`(``)0"```(````
M3@(```````"%````0P```,0!``#:`0``?P```!D```#D`0``!`,``$P!```2
M`0````````````!0`0``O`(```````#7````!P,``#,!``"3`@``/`,``/\!
M``!=`````P$``!D!``"C````F@```,8"````````40$``#0````G````*P(`
M`+<!``"J`0``&@```"4```"%`0``$`$``&8"```R`0``I`$```X"````````
M/0,```````!'`@``D0`````````W`P``\@(```````">````_0$```X!```L
M`0``20```'H````[`P``W````(0"`````````````,,```"4````!`$`````
M```I````>0(``.P!``")`0``O````&\````;``````````````#R`0``````
M``L"```K`0``C0(``(P"``"Z`0```````.0"```.````X`$``&4"```+`0``
MEP$``-L!```@````U0$```````"U`0``_@```&H"``!^`0``)@```)4"``!I
M````]P(``.H!````````$@,``'$!````````"0$``&T"``#``0``?`(``)(`
M``"R`````````!<!```Z`0````````P"``#.````````````````````+0,`
M``````"L`0``JP$```L````!`P``,0$````````P`@``T`(``/$!````````
M.`(``/H"``#9`@``*`,``/@"``#4``````$``,H``````````````*T```#E
M`0``AP(``!8````(`0``<P`````````J`0````````8#``#L`@```````)<`
M```<`P``H`````````#V`````````.\```!L`0``#P$````````D`P``V`$`
M``````#I`@``X```````````````````````````````%`,``'D`````````
MV0```(@!``#P`0``L````&<!``#/`@``70$``"$"`````````````,`"````
M````,P,``!,#``#.`0``IP(``&<"```T`0```````!X#``"I`@``D0(`````
M```?`P``=`$``'T!```5`0```````.8````X`0``=P```)8"```%`P``60``
M`'4!``#0`0``T0`````````Z`@``<P$`````````````S`$```````!>`0``
M80(``%4!``#M````YP(``"<"``"R`0``;@```%$"```Q`P``OP(```````!D
M`@``'0$``.8!``!$`@``G````+X```"-`0``50`````"````````K0(``$$"
M``#F`@``-0$``!4"``"!`0``_0``````````````50(`````````````Z@``
M`.,```!T`@``W@(``&T!``#-`0``LP$``$H"``!``P`````````````1`@``
M3`(``,$!```O`@``````````````````%P```#L```#5`@``*0(```L#```H
M`0``G0````````#@`@``Q````(,"`````````````%X"````````````````
M``".`0```````*\"```%`0``*P,`````````````Z0$```````!X`@``X0(`
M`&P```#H````C@(``%<````>`@``'P(``&````!;`@``5P$``"H```!S`@``
M`````($"````````Q0$``+0"``"3`0``<@(``)8!```=````T@(``!@"````
M````S0(``)H!``"&`0```P````````#1`@``]@(`````````````)````*<`
M``"$`````````'(```!K`````P(``"$!``![`````````$D"````````H@``
M`(\!``#`````LP(``,@`````````2@$``&X!```3````#P,```````!0````
MFP$``+\!```E`0``:`(``!8!``!F`0``D0$``!P```#V`0``K@$``)\```";
M`````````-,!```B`@``BP$``!0"```]`````@,`````````````/P,`````
M``"T`0``1@$``"\!``#]`@``C`$``,,"```F`P``TP```!@!``!;````FP(`
M`*H"``"/````K@(```````"D`@``WP(``"X``````````````&$!``"0`0``
M8P(````````8````V0$``-8"``!;`0``LP```*@"``!D`0``(`$```````"`
M`0``T@$```````!W`@``#0,``-@```"Q`@``/0$``.@"``!<`@``+P,``+4`
M``#M`0``H0$```````#B`@``````````````````O@(``'@!````````#@,`
M```````V`@``L0$`````````````@@```$$!````````^````'D!``#"````
M8@```````````````````%0```"]`0```````*("``#R````WP````````#L
M````/`(``'`!``!$`0``K````)\!```D`@```````'@`````````?@```&(!
M``#%`@```````/@!``"[`0`````````````3`@```````)@"``!:`0``'P$`
M`"(!```;`0```````#D"`````````````%8````(`P``5`$``"P```"F`0``
M%0,```````#Y`0``@P```#\``````````````+D"``!-`@``10$`````````
M````@`(``(\"````````E`$``-P"``#\````+@,``/0````S`@``20$``&@!
M``#$`@``4P````````!2`0``B@$``!````!_`@````````````#E`@``````
M`$("```&````U@$``*L"````````.0,``"X!````````B`````````#*`@``
M_P```"@```#4`@``````````````````[@$```D```"'````!P(```````!C
M````\`(```D#``!(`0``#````*D!````````-P(``+$`````````S`````(!
M``#O`0``,`,`````````````&`,``"T!``"F`````"`F(S$U,3L@)7,@:7,@
M<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C
M:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE
M('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S
M+@`E9"`E<R!A;F0@)7,`)7,@+2!.;W1I8V4`)7,@061M:6YI<W1R871I;VX`
M)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(&%L<F5A
M9'D@97AI<W1S+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F
M;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#
M86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+2T@
M<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO
M=7)S`#Q0<F5V:6]U<P!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+@!!32]030!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8V-O
M=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!
M9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D
M(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P
M86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@
M=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U
M<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S
M<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA
M`$%L9V5R:6$`06QI87,`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;&]W(&UU;'1I<&QE(&%D9')E
M<W-E<P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E
M<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!
M;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5X=#H`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`07!P;&EC
M871I;VX`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<')O=F4`07!R:6P`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R9V5N=&EN80!!<FUE;FEA
M`$%R=6)A`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN
M=&5N86YC92!O<&5R871I;VYS/P!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L
M:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S
M97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I
M;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R
M=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A
M:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R
M;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`
M0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"96QA<G5S`$)E;&=I=6T`0F5L
M:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K(%-E='1I
M;F=S`$)L;V-K(%1Y<&4`0F]L:79I80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(
M97)Z96=O=FEN80!";W1H`$)R87II;`!"=6QG87)I80!#35,`0U)#`$-?96QL
M(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%M8F]D:6$`0V%M97)O;VX`0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%P
M92!697)D90!#871E9V]R:65S(&%N9"!,86)E;',`0V5L;"!0:&]N90!#96QL
M(%!R;W!E<G1I97,`0V5L;"!P<F]P97)T:65S`$-E;&QP:&]N90!#96QT:6,@
M*$E33RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!/=VYE<@!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAE8U]K($QI;FLN+BX`0VAE8VL@
M=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAO;W-E(&$@<&%S<W=O
M<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:')I<W1M87,@27-L86YD`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E
M(%=I;F1O=P!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E
M8F%R`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;'5M;B!T:71L97,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE
M;G0`0V]M;W)O<P!#;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U
M=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`
M0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT
M86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`
M0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@
M;65S<V%G92X`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y
M(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@
M=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2`B)7,B+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN`$-O=6YT<GD`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E
M(&$@;F5W(&]N90!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U
M<G)E;G0@5&EM90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N`$-U=`!#>7!R=7,`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T
M90!$95]L971E($-O;'5M;@!$96-E;6)E<@!$969A=6QT($-O;&]R`$1E9F%U
M;'0@261E;G1I='D`1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI
M<W-I;VYS`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E
M;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&4@
M=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<F5C=&]R>0!$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:FEB;W5T:0!$;R!N
M;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$<G5G<P!%+4UA:6P`16-U861O<@!%9&ET`$5D:70@1W)O=7``
M161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S
M:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N
M<R!F;W(@)7,`16=Y<'0`16P@4V%L=F%D;W(`16UA:6P`16UA:6P@061D<F5S
M<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UO=&EC;VYS`$5M<'1Y
M(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16YA8FQE(')I9VAT(&-L:6-K(&-O
M;G1E>'0@;65N=3\`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%
M<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`175R;W!E`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N
M9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U
M<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD
M`$5X<&%N9"!3:61E8F%R`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y
M('1O("(E<R(N`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&
M87@`1F5B<G5A<GD`1FEJ:0!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@
M<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QT97)S`$9I;FQA;F0`1F]O9`!&;W)G;W0@>6]U<B!P87-S=V]R
M9#\`1G)A;F-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!'86)O;@!'86UB:6$`1V5R
M;6%N>0!':&%N80!':6)R86QT87(`1V\`1V]O9VQE(%-E87)C:`!'<F5E8V4`
M1W)E96YL86YD`$=R96YA9&$`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T
M96UA;&$`1W5E<FYS97D`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A4
M34P`2&%I=&D`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M;'``2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(
M;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@
M(B5S(@!(=6YG87)Y`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E
M>'0`261E;G1I='DG<R!N86UE.@!);6%G97,`26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`26YD:6$`26YD;VYE<VEA`$EN9F\`26YS97)T
M($EM86=E`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI
M8V5N<V4@:V5Y+@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E
M;&%N9`!)<W)A96P`27-S=65R`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A
M;@!*;W)D86X`2G5L>0!*=6YE`$MA>F%K:'-T86X`2V5N>6$`2V5Y($-R96%T
M:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+
M:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9@!+;W)E82P@4F5P=6)L:6,@;V8`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U
M=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI<W0@2&5L<"!4;W!I8W,`3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET:'5A;FEA`$QO861I;F<N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V<@:6X`3&]G(&]U=`!,
M;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F
M86EL960N`$QO=P!,=7AE;6)O=7)G`$U-`$U/5$0`35-'`$UA8V%O`$UA8V5D
M;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S
M8V%R`$UA:6P`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`
M36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B
M96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RX`36%R8V@`36%R9VEN`$UA<G-H86QL($ES;&%N9',`
M36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I
M=7,`36%Y`$UA>6]T=&4`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N`$UE>&EC;P!-:6UE(%1Y<&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O
M8V-O`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO
M=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`37D@06-C;W5N=`!->2!0;W)T
M86P`37EA;FUA<@!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T=V]R:P!.979E<@!.97<@0V%L
M961O;FEA`$YE=R!#871E9V]R>0!.97<@6F5A;&%N9`!.97=S`$YE>'0`3F5X
M="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI=64`3F\@8VAA
M;F=E+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N`$YO(&9I;&4@=7!L;V%D960`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO;F4`3F]R
M9F]L:R!)<VQA;F0`3F]R=V%Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.
M;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1I8V4`3F]V96UB97(`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3TL`3V-T;V)E<@!/9F9I8V4`3VUA
M;@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/=&AE<@!/=&AE<B!)
M;F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'
M4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!07TA0(%-H96QL`%!A
M:VES=&%N`%!A;&%U`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y
M`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S
M="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<R!F;W(`
M4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0:&EL:7!P:6YE<P!0:&]N90!0
M:71C86ER;@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@=F%L:60@
M25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;VQA;F0`4&]R='5G
M86P`4')E=FEE=P!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I
M<'1I;VX`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@
M2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="D`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N
M=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;6]T92!397)V97)S`%)E;6]V
M90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@<&%I<@!296UO
M=F4@=&AE`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297-E=`!297-E
M="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N
M('1O($]P=&EO;G,`4F5U;FEO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`
M4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I
M9VAT`%)O=R!P<F]P97)T:65S`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4U%,(%-H96QL`%-32`!37U%,(%-H96QL`%-A
M:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<P!386UO80!386X@36%R:6YO`%-A=61I($%R86)I80!3
M879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L
M96-T($9I;&5S`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N96=A;`!397!T
M96UB97(`4V5R:6%L($YU;6)E<@!3970`4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@
M;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P
M=&EO;G,N`%-E='5P`%-E>6-H96QL97,`4VAO<G0@4W5M;6%R>0!3:&]W`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VEE<G)A($QE;VYE`%-I9VX@=7`@:68@
M;F]T(')E9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V
M96YI80!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;W5T:"!!9G)I8V$`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-P86EN`%-P86T`4W!E8VEA;"!#
M:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@
M<F]W`%-R:2!,86YK80!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1R965T
M($%D9')E<W,`4W5B:F5C=`!3=6)M:70`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3
M=61A;@!3=6YR:7-E+U-U;G-E=`!3=7)I;F%M90!3=V%Z:6QA;F0`4W=E9&5N
M`%-W:71Z97)L86YD`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%1A:7=A;@!486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E>'0@
M3VYL>0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN
M`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:6UE`%1I;64@9F]R;6%T
M`%1I=&QE`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O9&%Y`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4
M<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'5N:7-I80!4=7)K
M97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U=F%L=0!5
M4DP`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@
M9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N=`!5;F1O($-H86YG97,`56YI=&5D($%R86(@16UI<F%T97,`
M56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FMN;W=N`%5N;F%M960`
M56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&QO860`57)U9W5A>0!5
M<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!686-A=&EO;@!686YU
M871U`%9E;F5Z=65L80!697)S:6]N`%9I970@3F%M`%9I97<@)7,`5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S
M+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%=A;&QI<R!A;F0@1G5T
M=6YA`%=A<FYI;F<`5V5B`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/
M+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%E965D`665A<FQY
M`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%M0<F]B;&5M(%)E<&]R=%T`7T%D;6EN:7-T<F%T:6]N`%]#3$D`
M7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?3&]G(&EN`%],;V<@;W5T`%]-
M;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,
M:6YK+BXN`%]3971U<`!?57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R`&9I
M;&4`;F%M90!N;W1E<&%D`'5N;F%M960`=D-A<F0`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$Q+3(T
M(#(P.C4V*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TQ,2TR-"`R,3HT
M-BLP,3`P"DQA<W0M5')A;G-L871O<CH@2W)Z>7-Z=&]F($MO>FQO=W-K:2`\
M:V]Z:6LQ0&\R+G!L/@I,86YG=6%G92U496%M.B!0;VQI<V@@/'!L0&QI+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@."UB:70*`"5S("T@9V]T;W=Y(&1O('=Y:V]N86YI82!C>6ML:6-Z;GEC
M:"!O<&5R86-J:2!Z87IN86-Z;VYY8V@@<&]N:;]E:BX`("@E<R!D;FD@=&5M
M=2D`*&ML=6-Z(&1O<W3J<'4@)7,I`"`H=R!C:;%G=2`E<R!D;FDI`"`H9'II
MMBD`("AJ=71R;RD`("AW8WIO<F%J*0`B)7,B(&YI92!J97-T('!R87=I9+-O
M=WEM('=Y8F]R96TN`"(E<R(@;FEE(&IE<W0@<VMO;F9I9W5R;W=A;GD@=R!R
M96IE<W1R>F4@2&]R9&4N`%5D8;-O('-IZB!D;V1AYB`B)7,B(&1O(&=R=7`N
M`%5D8;-O('-IZB!D;V1AYB`B)7,B(&1O('5P<F%W;FEE\2X`(B5S(B!N:64@
M>F]S=&&S('5T=V]R>F]N>3H@)7,N`"5D("5S(&D@)7,`)7,@+2!5=V%G80!!
M9&UI;FES=')A8VIA("5S`"5S(&]D8VES:R!P86QC80`E<R!K0@`E<R`M(&]P
M97)A8VIE(&-Y:VQI8WIN92`M('!O='=I97)D>F5N:64`2V]N9FEG=7)A8VIA
M("5S`%)E:F5S=')A8VIA("5S`"5S(&IUOR!I<W1N:65J92X`)7,@:F5S="!W
M>6UA9V%N>0`E<R!M:6YU=``E<R!N:65Z;F%L97II;VYY+@`E<R!D;R`E<R!Z
M("5S`$MS:;&_:V$@861R97-O=V$@)7,`2V%L96YD87)Z("5S`$YO=&%T;FEK
M("5S`$QI<W1A('IA9&'Q("5S`"5S.B`E<P`M+2!W>6)I97)Z("TM`#$R+6=O
M9'II;FYY(&9O<FUA=``R-"UG;V1Z:6YN>2!F;W)M870`,C0@9V]D>BX`/%!O
M<')Z961N:0!.87-TL7!ILR!BL[%D(&MR>71Y8WIN>0!0;W1R>F5B;GD@:F5S
M="!K;'5C>B!P=6)L:6-Z;GD@4$=0(&1O('IA<WIY9G)O=V%N:6$@=VEA9&]M
M;[9C:2X`4&]T<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!S
M<')A=V1Z96YI82!P;V1P:7-A;F5J('=I861O;6^V8VDN`%!O=')Z96)N92!S
ML2!K;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A
M>B!H87.S;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN`%!O=')Z96)N
M92!SL2!K;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@
M;W)A>B!H87.S;R!D;R!P;V1P:7-A;FEA('=I861O;6^V8VDN`%!O=')Z96)N
M92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C>B!P<GEW871N>2!3
M+TU)344@;W)A>B!H87.S;R!D;R!O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN
M`%!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%+"!K;'5C>B!P
M<GEW871N>2!3+TU)344@;W)A>B!H87.S;R!D;R!P;V1P:7-A;FEA('=I861O
M;6^V8VDN`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!334E-12!D
M;R!Z87-Z>69R;W=A;FEA('=I861O;6^V8VDN`$%-+U!-`$\@='EM(&5D>71O
M<GIE`$\@<')O9W)A;6EE+BXN`$AA<[-O(&1O(&MO;G1A`$MO;G1O('IA8FQO
M:V]W86YE+@!+;VYT80!$;V1A:@!$;V1A:B!T=71A:CH`1&]D86H@;F]WL2!G
M<G5PZ@!$;V1A:B!N;W=E('5P<F%W;FEE;FEE`$1O9&%J(&YO=V5G;R!UOWET
M:V]W;FEK83H`1&]D86H@:V]L=6UNZ@!$;V1A:B!N;W=Y8V@@8WJS;VYK\W<`
M1&]D86H@<&%RZ@!$;V1A:B!M96YU("5S(&1O('!A<VMA($UO>FEL;&D`1&]D
M86H@9&\@:W-IL;]K:2!A9')E<V]W96HZ`$1O9&%J(&1O(&UO:F5J(&MS:;%Z
M:VD@861R97-O=V5J`$1O9&%J('6_>71K;W=N:6MA`$1O9&%N;R`B)7,B(&1O
M('-Y<W1E;74N($UOOV5S>B!S:>H@>F%L;V=O=V'F+@!$;V1A=V%N:64@=;]Y
M=&MO=VYI:_-W(&IE<W0@=WFS86-Z;VYE+@!!9')E<P!+<VFQOVMA(&%D<F5S
M;W=A`$%D;6EN:7-T<F%C:F$`4F5K;&%M>0!!9F=A;FES=&%N`$%L8F%N:6$`
M06QG:65R:6$`06QI87,`5W-Z>7-T:V\`5W-Z>7-C>2!U=VEE<GIY=&5L;FEE
M;FD@=;]Y=&MO=VYI8WD`5W-Z>7-T:VEE(&=R=7!Y`%=S>GES=&MI92!U<')A
M=VYI96YI80!0;WIW\VP@;F$@=VEE;&4@861R97/S=P!*=;\@:7-T;FEE:F4`
M06QT97)N871Y=VYY(&QO9VEN($E-4U``06QT97)N871Y=VYY(&AA<[-O($E-
M4U``06QT97)N871Y=VYA(&YA>G=A('6_>71K;W=N:6MA($E-4U``06QT97)N
M871Y=VYY(&%D<F5S(&5M86EL`$%L=&5R;F%T>7=N>2!T96MS=#H`6F]S=&&S
M82!P;V1A;F$@;FEE<')A=VEDLV]W82!W87)T;[;F+@!!;F1O<F$`06YG;VQA
M`$%N9W5I;&QA`$%N;VYI;6]W92!0<F]X>0!/9'!O=VEE9+P`06YT87)K='ED
M80!!<&QI:V%C:F$`07!L:6MA8VIA(&=O=&]W80!:871W:65R9+P`2W=I96-I
M9?$`5VEE;&MOMN8@87)C:&EW=6T`3F%Z=V$@87)C:&EW=6T`07)G96YT>6YA
M`$%R;65N:6$`07)U8F$`4&]P<F^V(&\@<&]T=VEE<F1Z96YI92!P<GIE9"!W
M>6MO;F%N:65M(&]P97)A8VII(&-Y:VQI8WIN>6-H/P!!=')Y8G5T>0!3:65R
M<&EE\0!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G5S.B!.:64@>FYA;&5Z
M:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!I;6%P+@!!=71H7V-Y<G5S
M.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!I;6%P
M+@!!=71H7V9T<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R
M>F5N:6$@1E10+B!3:V]M<&EL=6H@4$A0('H@<&%R86UE=')E;2`M+65N86)L
M92`N`$%U=&A?:6UA<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS
M>F5R>F5N:6$@24U!4"X`075T:%]K<F(U.B!.:64@>FYA;&5Z:6]N;R!W>6UA
M9V%N96=O(')O>G-Z97)Z96YI82!K<F(U+@!!=71H7VQD87`Z($YI92!Z;F%L
M97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA($Q$05`N`$%U=&A?;&1A
M<#H@3FEE('5D8;-O('-IZB!U<W5NL>8@=;]Y=&MO=VYI:V$@)7,`075T:%]L
M9&%P.B!.:64@=61ALV\@<VGJ('5A:W1U86QN:>8@=;]Y=&MO=VYI:V$@)7,`
M075T:%]M8V%L.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z
M96YI82!-0T%,+@!!=71H7W-M8F%U=&@Z($YI92!Z;F%L97II;VYO('=Y;6%G
M86YE9V\@<F]Z<WIE<GIE;FEA('-M8F%U=&@N`%5W:65R>GET96QN:65N:64@
M;FEE('!O=VEO9+-O('-IZ@!5=VEE<GIY=&5L;FEE;FEE(&YI92!P;W=I;V2S
M;R!S:>HN("5S`%5W:65R>GET96QN:65N:64@;V1R>G5C;VYE('!R>F5Z('-E
M<G=E<B!2041)55,N`%5W:65R>GET96QN:65N:64@9&\@<V5R=V5R82!&5%`@
M;FEE('!O=VEO9+-O('-IZBX`1&]S=.IP;F4@<&]L83H`07IE<F)E:F2_86X`
M5WEM\W=K:2!"3T9(`%2S;P!+;VQO<B!TLV$`6K-E(&AA<[-O($ME<F)E<F]S
M82X`6K-A(&YA>G=A('6_>71K;W=N:6MA($ME<F)E<F]S80!7>7-P>2!"86AA
M;6$`0F%H<F%J;@!"8;-T>6-K:2`H25-/+3@X-3DM,3,I`$)A;F=L861E<WH`
M0FEALV]R=;8`0F5L9VEA`$)E;&EZ90!"96YI;@!"97)M=61Y`$)H=71A;@!$
M871A('5R;V1Z96YI80!5<W1A=VEE;FEA(&)L;VMU`%1Y<"!B;&]K=0!";VQI
M=VEA`%IA:[-A9&MI`$)OMFYI82!I($AE<F-E9V]W:6YA`$]B80!"<F%Z>6QI
M80!"=;-G87)I80!#35,`0U)#`%>S8;9C:7=OMF-I(&MO;?-R:VDN+BX@*%]C
M*0!+86QE;F1A<GH`2V%M8F]DOV$`2V%M97)U;@!.:64@=61ALV\@<VGJ('IR
M97-E=&]W8>8@:&%SLV$@875T;VUA='EC>FYI92P@<VMO;G1A:W1U:B!S:>H@
M>B!A9&UI;FES=')A=&]R96TN`$*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!)34%0.B`E<P!+86YA9&$`06YU;'5J`$%N=6QU:B!R87!O
M<G0@;R!P<F]B;&5M:64`3FEE(&UOOVYA('-K87-O=V'F('!L:6MU("(E<R(`
M3FEE('5D8;-O('-IZB!Z;F%L9;SF(&MA=&%L;V=U('1Y;6-Z87-O=V5G;RX`
M3FEE(&UOOVYA('-K87-O=V'F(&MA=&%L;V=U("(E<R(`5WES<'D@6FEE;&]N
M96=O(%!R>GELL61K80!+871E9V]R:64@:2!O>FYA8WIE;FEA`%1E;"X@:V]M
M+@!7LV&V8VEW;[9C:2!K;VWS<FMI`%>S8;9C:7=OMF-I(&MO;?-R:VD`5&5L
M+B!K;VTN`$-E;'1Y8VMI("A)4T\M.#@U.2TQ-"D`4F5P=6)L:6MA(*9R;V1K
M;W=E:B!!9G)Y:VD`IG)O9&MO=V]E=7)O<&5J<VMI("A)4T\M.#@U.2TR*0!3
M>F-Z96?SLWD@8V5R='EF:6MA='4`5[-AMF-I8VEE;"!C97)T>69I:V%T=0!#
M>F%D`%IM:67Q`%IM:67Q(&EM:>HL(&YA>G=I<VMO(&D@861R97,L(&MT\W)Y
M(&EN;FD@=VED>K$@=R!4=V]I8V@@;&ES=&%C:"!E;6%I;"X`4W!R87=DO"!L
M:6YK+BXN`%IA>FYA8WH@<&]Z>6-JZB!D;&$@:W3S<F5J(&-H8V5S>B!W>6MO
M;F'F(&]P97)A8VKJ+@!#:&EL90!#:&EN>0!0;V1A:B!H87.S;P!0;V1A:B!N
M87IWZB!UOWET:V]W;FEK80!7>6)I97)Z('-P;W/S8B!W>;9W:65T;&%N:6$@
M9&%T.@!7>7-P82!";[]E9V\@3F%R;V1Z96YI80!+;&EK;FEJ(&)Y(&MO;G1Y
M;G5O=V'F`%IA;6MN:6H@;VMN;P!7>7-P>2!+;VMO<V]W92`H2V5E;&EN9V$I
M`%-C:&]W86H@<&%S96L`2V]L=6UB:6$`2V]L;W(`5WEB:65R>B!K;VQO<@!7
M>6+S<B!K;VQO<G4`5'ET=;-Y(&MO;'5M;@!+;VUE;F1A`%!O=[-O:V$`2V]M
M96YT87)Z`$MO;6]R>0!&:7)M80!3='?S<GH@=VEA9&]M;[;F("@E<RD`2V]M
M<'5T97)Y`%=A<G5N:VD`4VMO;F9I9W5R=6H@)7,`4&]T=VEE<F2\(&AA<[-O
M`$MO;F=O`$1E;6]K<F%T>6-Z;F$@4F5P=6)L:6MA($MO;F=O`%!OL[%C>F5N
M:64@;FEE('!O=VEO9+-O('-IZBX`4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@
M<VGJ.B``3V1M\W=I;VYO('!OL[%C>F5N:6$@9&\@<'5B;&EC>FYE9V\@<V5R
M=V5R82X`3V1M\W=I;VYO('!OL[%C>F5N:6$@9&\@<'5B;&EC>FYE9V\@<V5R
M=V5R82X@4&]W\V0Z("5S("@E<RD`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-I
MZB!Z('-E<G=E<F5M($944"X`2V]N=&%K='D@>F]S=&&S>2!P;VUYMFQN:64@
M9&]D86YE(&1O(%1W;VIE:B!K<VFQOVMI(&%D<F5S;W=E:BX`6F%W87)T;[;F
M("(E<R(`2V]N>6YU=6H`5WES<'D@0V]O:V$`4VMO<&EU:@!3:V]P:75J('=Y
M8O-R`$YI92!U9&&S;R!S:>H@>F%S>GEF<F]W8>8@*%!'4"D@=VEA9&]M;[9C
M:2X`3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4$=0*2!W:6%D;VUOMF-I+@!.
M:64@=61ALV\@<VGJ('IA<WIY9G)O=V'F("A3+TU)344I('=I861O;6^V8VDN
M`$YI92!U9&&S;R!S:>H@<&]D<&ES8>8@*%,O34E-12D@=VEA9&]M;[9C:2X`
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`N`$*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2`B)7,B('!O<')Z
M97H@1E10.B`E<P!.:64@=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!0
M1U`N`$YI92!U9&&S;R!S:>H@;V1S>GEF<F]W8>8@9&%N>6-H(%,O34E-12X`
M3FEE('5D8;-O('-IZB!U<W1A;&GF(&%D<F5S=2!E+6UA:6P@;V1B:6]R8WDN
M`$YI92!U9&&S;R!S:>H@=7IY<VMAYB!Z('-E<G=E<F$@:VQU8WIA('!B=6QI
M8WIN96=O+@!.:64@=61ALV\@<VGJ(&]T=V]R>GGF("(E<R(@9&\@>F%P:7-U
M+@!.:64@;6^_;F$@;W1W;W)Z>>8@)7,N`$YI92!M;[]N82!O='=O<GIYYB!M
M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<P!.:64@;6^_;F$@;W1W;W)Z>>8@
M:V%T86QO9W4@(B5S(@!.:64@=61ALV\@<VGJ('-K87-O=V'F('!L:6MU("(E
M<R(N`$YI92!U9&&S;R!S:>H@>FYA;&6\YB!P87-K82!-;WII;&QI+B!5<&5W
M;FEJ('-IZBP@OV4@:F5S="!O;B!O='=A<G1Y+@!+<F%J`%-T=_-R>@!3='?S
M<GH@;&EN:P!3='?S<GH@;F]WL0!.=6UE<B!K87)T>2!K<F5D>71O=V5J`$-H
M;W)W86-J80!+=6)A`$]B96-N>2!C>F%S`%-P97)S;VYA;&EZ=6H@>F%D86YI
M82!U<G5C:&%M:6%N92!P<GIY(&QO9V]W86YI=2!D;R`E<RX`5WET;FEJ`$-Y
M<'(`4F5P=6)L:6MA($-Z96-H`$1$`$-O9'II96YN:64`1&%T80!?57-U\2!K
M;VQU;6[J`$=R=61Z:67Q`$1O;7FV;&YY(&MO;&]R`$1O;7FV;&YA('1OOW-A
M;6^VY@!$;VUYMFQN92!U<')A=VYI96YI80!$;VUYMFQN92!U<')A=VYI96YI
M80!5<W7Q`%5S=?$@1W)U<.H`57-U\2!U<')A=VYI96YI80!5<W7Q(&D@=WEC
M>GFVYB!W:6%D;VUOMF-I`%5S=?$@:V]M\W)KZ@!5<W7Q(&MO;'5M;NH`4VMA
M<W5J('5P<F%W;FEE;FEA(&1L82`B)7,B`%-K87-O=V'F('5P<F%W;FEE;FEA
M(&1L82`B)7,B(&D@=W-Z>7-T:VEE('!O9"UU<')A=VYI96YI83\`57-U\2!W
M:65R<WH`4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F`%5S=?$@86MT=6%L;K$@
M:V]L=6UNZ@!5<W7Q(&%K='5A;&YY('=I97)S>@!3:V%S;W=AYB!T;R!U<')A
M=VYI96YI92!I('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_`$1A;FEA`$]P
M:7-Z('!R;V)L96T`4WIC>F5G\[-Y('IO<W1ALWD@>F%L;V=O=V%N92!D;&$@
M861M:6YI<W1R871O<F$N`$MA=&%L;V<`5WFV=VEE=&P@8WIA<R!W(&9O<FUA
M8VEE(#(T+6=O9'II;FYY;3\`57-T87=I96YI82!W>6=LL61U`$2_:6)U=&D`
M3FEE(&MA<W5J`$)R86L@8F5Z<&^V<F5D;FEE9V\@9&]S=.IP=2!D;R!M86EN
M=&5N86YC92YP:'``1&]M:6YI:V$@*%=S</-L;F]T82!$;VUI;FEK:2D`1&]M
M:6YI:V%N82`H4F5P=6)L:6MA($1O;6EN:6MA\7-K82D`IF-IL6=N:6H`IF-I
ML6=N:6H@)7,`3F%R:V]T>6MI`$4M;6%I;`!%:W=A9&]R`$5D>6-J80!5<W7Q
M($=R=7#J`%IM:67Q('5P<F%W;FEE;FEE`%IM:67Q('5P<F%W;FEE;FEA`%IM
M:67Q('5P<F%W;FEE;FEA(&1L82`E<P!:;6EE\2!U<W1A=VEE;FEA(&1L83H`
M6FUI9?$@=7!R87=N:65N:6$@9&QA("5S`$5G:7!T`%-A;'=A9&]R`$5M86EL
M`$%D<F5S(&5M86EL`$%D<F5S>2!E;6%I;"!M=7-ZL2!D;R!S:65B:64@<&%S
M;W=AYBX`16UO=&EK;VYY`%!U<W1A('=I861O;6^VYBX`0G)A:R!R97IU;'1A
M=/-W+@!7L[%C>GGF(&UE;G4@:V]N=&5K<W1O=V4@<&]D('!R87=Y;2!P<GIY
M8VES:VEE;2!M>7-Z>3\`1W=I;F5A(%+S=VYI:V]W80!%<GET<F5A`$*SL60`
M0K.Q9"!P<GIY('IA<&ES:64@(B5S(BX`17-T;VYI80!%=&EO<&EA`$5U<F]P
M80!#;R!K8;]D92`Q-2!M:6YU=`!#;R!K8;]D92`R(&UI;G5T>0!#;R!K8;]D
M92`S,"!S96MU;F0`0V\@:V&_9&4@-2!M:6YU=`!#;R!K8;]D92!Z86QO9V]W
M86YI90!#;R!K8;]D92!P\[,@9V]D>FEN>0!#;R!K8;]DL2!M:6YU=.H`4')Z
M>6NS861O=V4@=V%R=&^V8VDZ`%=Y:V]N86H`4F]Z=VGQ`%)O>G=I\2!P87-E
M:P!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@3$1!4"X`
M0K.Q9"!P;V1C>F%S(&MO<&EO=V%N:6$@>B`B)7,B+@!"L[%D('!O9&-Z87,@
M:V]P:6]W86YI82!D;R`B)7,B+@!"L[%D('!O9&-Z87,@<')Z96YO<WIE;FEA
M(&1O("(E<R(N`$9A;&ML86YD>2`H36%L=VEN>2D`5WES<'D@3W=C>F4`0K.Q
M9"!K<GET>6-Z;GDZ(`!&86MS`$QU='D`1FEDOVD`365N962_97(@<&QI:_-W
M`$YA>G=A('!L:6MU`%=Y8O-R('!L:6MU`%=G<GEW86YI92!P;&EK=0!79W)Y
M=V%N:64@<&QI:_-W(&YI92!J97-T(&]B<[-U9VEW86YE+@!&:6QT<GD`1FEN
M;&%N9&EA`$IE9'IE;FEE`%IA<&]M;FEALV6V(&AA<[-A/P!&<F%N8VIA`$=U
M:F%N82!&<F%N8W5S:V$`4&]L:6YE>FIA($9R86YC=7-K80!&<F%N8W5S:VEE
M(%1E<GET;W)I82!0;[-U9&YI;W=E(&D@06YT87)K='EC>FYE`$]D`$=A8F]N
M`$=A;6)I80!.:65M8WD`1VAA;F$`1VEB<F%L=&%R`$EDO`!7>7-Z=6MI=V%R
M:V$@1V]O9VQE`$=R96-J80!'<F5N;&%N9&EA`$=R96YA9&$`1W)U<'D@9'ES
M:W5S>6IN90!'=V%D96QU<&$`1W5A;0!'=V%T96UA;&$`1W5E<FYS97D`1W=I
M;F5A`$=W:6YE82!":7-S874`1W5J86YA`$A434P`2&%I=&D`5WES<'D@2&5A
M<F0@:2!-8T1O;F%L9&$`4&]M;V,`5WES;VMI`%]3=&%R=`!7871Y:V%N("A3
M=&]L:6-A($%P;W-T;VQS:V$I`%!O8WJQ=&5K`$%D<F5S(&1O;6]W>0!496PN
M(&1O;2X`2&]N9'5R87,`2&]N9TMO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%5D
M8;-O('-IZB!U<W5NL>8@)7,@(B5S(@!7ZF=R>0!)<VQA;F1I80!4>6QK;R!I
M:V]N>0!):V]N>2!Z('1E:W-T96T`3F%Z=V$@=&^_<V%M;[9C:3H`1W)A9FEK
M80!);7!O<G1O=V%N92!P;VQE.B`E<P!);7!O<G1O=V%N92!P;VQA.@!);F1I
M90!);F1O;F5Z:F$`26YF;P!7:VQE:B!O8G)A>F5K`%=Y<[-A;F4@;FEE<')A
M=VEDLV]W92!D86YE+@!.:65P<F%W:62S;W=Y(&%D<F5S(&1O8V5L;W=Y+@!.
M:65P<F%W:62S;W=Y(&9O<FUA="!P;&EK=0!.:65P<F%W:62S;W=Y(&ML=6-Z
M(&QI8V5N8VII+@!)<F%N`$ER86L`27)L86YD:6$`27IR865L`%=Y9&%W8V$`
M5[-O8VAY`$IA;6%J:V$`4W1Y8WIE\0!*87!O;FEA`$IO<F1A;@!,:7!I96,`
M0WIE<G=I96,`2V%Z86-H<W1A;@!+96YI80!4=V]R>F5N:64@:VQU8WIA`$]D
M8VES:R!K;'5C>F$`1+-U9V^VYB!K;'5C>F$`5'EP(&ML=6-Z80!+;'5C>B!J
M=;\@:7-T;FEE:F4@;F$@<'5B;&EC>FYY;2!S97)W97)Z92!K;'5C>GDN`$1Z
M:65C:0!+:7)I8F%T:0!+;W)E8?%S:V$@4F5P=6)L:6MA($QU9&]W;RU$96UO
M:W)A='EC>FYA`%)E<'5B;&EK82!+;W)E:0!+=7=E:G0`2VER9VES=&%N`%=Y
M9VRQ9"`H7WDI`$KJ>GEK`$QA;W,`3W-T871N:64@;&]G;W=A;FEE.B`E<P!/
M<W1A=&YI92!L;V=O=V%N:64Z("5S('H@)7,`3W-T871N:64@;&]G;W=A;FEE
M.B!N:6=D>0"C;W1W80!,97-O=&AO`$QI8F5R:6$`3&EB:6$`3&EE8VAT96YS
M=&5I;@!7>;9W:65T;"!T96UA='D@<&]M;V-Y`$QI<W1O=V%N:64@=;]Y=&MO
M=VYI:_-W(&IE<W0@=WFSL6-Z;VYE+@!,:71W80"C861O=V%N:64N+BX`0WIA
M<R!L;VMA;&YY.B``57-T87=I96YI82!L;VMA;&YE(&D@8WIA<P!:86QO9W5J
M`%=Y;&]G=6H`6F%D86YI82!P<GIY(&QO9V]W86YI=0!,;V=O=V%N:64@;FEE
M('!O=VEO9+-O('-IZBP@<&]N:65W8;\@<&]D8;-EMB!N:65P<F%W:62S;W=E
M(&AA<[-O(&QU8B!N87IWZB!UOWET:V]W;FEK82X`3&]G;W=A;FEE(&YI92!P
M;W=I;V2S;R!S:>HN`$YI<VMI`$QU:W-E;6)U<F<`34T`34]41`!-4T<`36%K
M874`36%C961O;FEA`$UA9&%G87-K87(`4&]C>G1A`$UA;&%W:0!-86QE>FIA
M`$UA;&5D:7=Y`$UA;&D`36%L=&$`6F%R>K%D>F%J(&QI<W2Q(&MA=&5G;W)I
M:2P@:W3S<GEM:2!BZF1Z:65S>B!O>FYA8WIALR!P;WIY8VIE+"!I(&MO;&]R
M86UI('H@;FEM:2!Z=VFQ>F%N>6UI+@!-87)Z96,`36%R9VEN97,`5WES<'D@
M36%R<VAA;&QA`$UA<G1Y;FEK80!087-U:K%C92!P;VQA`$UA=7)E=&%N:6$`
M36%U<FET:75S`$UA:@!-86IO='1A`%1R>6(@;65N=3H`4&^SL6-Z(&MO;?-R
M:VD`5VEA9&]M;[;F`$)L;VL@(DUE=&%R(B!N:64@:F5S="!D;W-TZG!N>2X`
M0FQO:R`B365T87(B(&YI92!J97-T(&1O<W3J<&YY+B!3>F-Z96?SLWD@>F1A
M<GIE;FEA('IO<W1ALWD@>F%L;V=O=V%N92!D;&$@861M:6YI<W1R871O<F$N
M`$UE:W-Y:P!4>7`@36EM90!/<W1A=&YI82!M;V1Y9FEK86-J80!:;6EE\2!L
M:6YK`$UOLV1A=VEA`%)E<'5B;&EK82!-;[-D87=I:0!-;VYA:V\`36]N9V]L
M:6$`0V\@;6EE<VFQ8P!-;VYT<V5R<F%T`$9A>GD@:W-IZK]Y8V$`36%R;VMO
M`%!R>F5S=?$@=R!D\[,`4')Z97-U\2!W(&QE=V\`4')Z97-U\2!W('!R87=O
M`%!R>F5S=?$@=R!G\W+J`%!R>F5N:66V('<@9/.S`%!R>F5S=?$@=R!G\W+J
M`$UO>F%M8FEK`$MO;G1O`$WS:B!P;W)T86P`0FER;6$`3F%Z=VES:V\`3F%M
M:6)I80!.875R=0!.97!A;`!(;VQA;F1I80!!;G1Y;&4@2&]L96YD97)S:VEE
M`%-I9>8`3FEG9'D`3F]W82!+86QE9&]N:6$`3F]W82!K871E9V]R:6$`3F]W
M82!:96QA;F1I80!7:6%D;VUOMF-I`$YA<W3J<&YE`$YA<W3J<&YE(&]P8VIE
M`$YI:V%R86=U80!.:6=E<@!.:6=E<FEA`$YI=64`0F5Z('IM:6%N+@!"<F%K
M(&MO;F9I9W5R86-J:2!D;&$@)7,N`$YI92!W9W)A;F\@<&QI:W4`3FEE('!O
M9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!(5%10+@!.:64@<&]D
M86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($E-05`N`$YI92!P;V1A
M;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@2V5R8F5R;W,N`$YI92!P
M;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@3$1!4"X`3FEE('!O
M9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!,3T=)3BX`3FEE('!O
M9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!005-35T0N`$YI92!P
M;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@4TU"+@"O861N80!.
M;W)F;VQK`$YO<G=E9VEA`$YI92!Z86EM<&QE;65N=&]W86YO+@!.:65U<W1A
M=VEO;F4`3FEE;V)SLW5G:7=A;F4`57=A9VD`57=A9V$`3&ES=&]P860`3&EC
M>F)A(&MO;'5M;@!,:6-Z8F$@=VEE<G-Z>0!/2P!08;QD>FEE<FYI:P!":75R
M;P!/;6%N`%1W\VH@:F5D96X@861R97,@92UM86EL(&IE<W0@9&]Z=V]L;VYY
M+@!/='?S<GH@=R!N;W=Y;2!O:VYI90!/<&-J90!/<&-J92`E<P!/<F=A;FEZ
M86-J80!*961N;W-T:V$@;W)G86YI>F%C>6IN80!/<F=A;FEZ871O<@!);FYE
M`$EN;F4@:6YF;W)M86-J90!);FYE('5P<F%W;FEE;FEA`%5W:65R>GET96QN
M:65N:64@4$%-(&YI92!J97-T(&1O<W3J<&YE+@!#>69R;W=Y('!O9'!I<R!0
M1U``5VEA9&]M;[;F('IA<WIY9G)O=V%N82!01U``2VQU8WH@<'5B;&EC>FYY
M(%!'4`!7:6%D;VUOMN8@>F%S>GEF<F]W86YA+W!O9'!I<V%N82!K;'5C>F5M
M(%!'4`!+;V0@4$A0`%!O=[-O:V$@4$A0`%!O=[-O:V$@4%](4`!086MI<W1A
M;@!086QA=0!086YA;6$`4&%P=6$M3F]W82!'=VEN96$`4&%R86=W86H`2&%S
MLV\`2&%SLV\@;FEE<')A=VEDLV]W90!(87.S;R!Z('!O='=I97)D>F5N:65M
M`$AA<[-O.@!(87.S;SH@`$AA<[-O(&UU<VD@<&%S;W=AYBX`5VML96H`5VML
M96H@>F4@<V-H;W=K80!7>6MO;F%J(&-Y:VQI8WIN92!O<&5R86-J90!7>6MO
M;F%J(&-Y:VQI8WIN92!O<&5R86-J92!P;V1C>F%S(&QO9V]W86YI83\`57!R
M87=N:65N:64`57!R87=N:65N:6$@9&QA`$EN9F]R;6%C:F4@;W-O8FES=&4`
M4&5R=0!&:6QI<&EN>0!496QE9F]N`%!I=&-A:7)N`$YA('!E=VYO('5S=6ZQ
MYB!T96X@=WEB<F%N>2!E;&5M96YT.@!.82!P97=N;R!U<W5NL>8@=WEB<F%N
M>2!E;&5M96YT.@!0<F]S>NH@<&]D8>8@<&]P<F%W;GD@861R97,@25`N`%!R
M;W-ZZB!P;V1AYB!P;W!R87=N>2!C>F%S+@!0<F]S>NH@;W!I<V'F('!R;V)L
M96TN`%!R;W-ZZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O`%!O
M;'-K80!0;W)T=6=A;&EA`%!O9&=LL60`2VQU8WH@<')Y=V%T;GD`4')O8FQE
M;0!/<&ES('!R;V)L96UU`$ML=6-Z('!U8FQI8WIN>0!!;&=O<GET;2!K;'5C
M>F$@<'5B;&EC>FYE9V\`26YF;W)M86-J92!O(&ML=6-Z=2!P=6)L:6-Z;GEM
M`%!A<F$@:VQU8WIY(&]S;V)I<W1Y8V@@;FEE('IO<W1ALV$@=WEG96YE<F]W
M86YA('!O;7FV;&YI92X`4&]R=&]R>6MO`$MA=&%R`%IA<'ET86YI90!+;'5C
M>B!P=6)L:6-Z;GD@4E-!("@E9"!B:73S=RD`3V2V=VEEOR!D>6YA;6EC>FYE
M(&5L96UE;G1Y(&UE;G4Z`$]DMG=I9;\@=VED;VL@<V5R=VES=3H`6F1A;&YE
M('-E<G=E<GD`57-U\0!5<W7Q(&)L;VL`57-U\2!K;VQU;6[J`%5S=?$@<&%R
MZ@!5<W7Q`%5S=?$@=;]Y=&MO=VYI:V$`6F1A;&YE('6_>71K;W=N:6MA.B`E
M<P!+87-U:@!7>6-Z>;;F(&AA<[-O`%=Y8WIYMN8@5'=O:F4@:&%SLV\`5WEN
M:6MI`%!O=W+S="!D;R!O<&-J:0!2975N:6]N`%)O>F)U9&]W86YY(&5D>71O
M<B!T96MS='4`4W1A;F]W:7-K;P!2=6UU;FEA`$]B<O/F(&\@,3@P('-T;W!N
M:0!/8G+SYB!W(&QE=V\`3V)R\^8@=R!P<F%W;P!7LV&V8VEW;[9C:2!R>NID
M=2!0<F]P97)T:65S`%)O<VIA`%)U86YD80!7:6%D;VUOMN8@>F%S>GEF<F]W
M86YA(%,O34E-10!5=VEE<GIY=&5L;FEE;FEE(%-!4TP@;FEE(&IE<W0@9&]S
M=.IP;F4N`%!O=VQO:V$@4U%,`%-32`!0;W>S;VMA(%-?44P`IG=IZG1A($AE
M;&5N80!386EN="!+:71T<R!I($YE=FES`%-A:6YT($QU8VEA`%-A:6YT+5!I
M97)R92!I($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@:2!'<F5N861Y;GD`4V%M
M;V$`4V%N($UA<FEN;P!!<F%B:6$@4V%U9'EJ<VMA`%IA<&ES>@!:87!I<WH@
M(B5S(@!:87!I<WH@)7,`6F%P:7-Z(&]P8VIE`%-Z=6MA:@!7>6)I97)Z('!L
M:6MI`%=Y8FEE<GH@>FYA:R!P;V1Z:6&S=2!D871Y.@!7>6)I97)Z(&9O<FUA
M="!D871Y.@!7>6)I97)Z('1OOW-A;6^VYB!D;R!Z;6EA;GDZ`%=Y8FEE<GH@
M>FYA:R!P;V1Z:6&S=2!D871Y.@!7>6)I97)Z(&9O<FUA="!C>F%S=3H`5WEB
M:65R>B!D=V$@<&%S=6JQ8V4@<&]L82X`5WEB:65R>B!S8VAE;6%T(&MO;&]R
M\W<N`%=Y8FEE<GH@='?S:B!P<F5F97)O=V%N>2!JZGIY:SH`5WFV;&EJ(')A
M<&]R="!O('!R;V)L96UI90!396YE9V%L`%=R>F5S:67Q`$YU;65R('-E<GEJ
M;GD`57-T87<`57-T87<@>F1A;&YE('-E<G=E<GDL(&1O(&MT\W)Y8V@@8VAC
M97-Z(&UI9>8@9&]S=.IP('H@<V5R=VES=2X`57-T87<@<')E9F5R;W=A;GD@
M:NIZ>6LL('-T<F5FZB!C>F%S;W>Q(&D@;W!C:F4@9&%T>2X`57-T87<@=7.S
M=6?J('!O8WJQ=&MO=[$L('-C:&5M870@:V]L;W+S=RP@;V2V=VEEOV%N:64@
M<W1R;VYY(&D@:6YN92!O<&-J92!W>;9W:65T;&%N:6$`2V]N9FEG=7)A8VIA
M`%-Z97-Z96QE`$MR\W1K:2!O<&ES`%!O:V&_`%!O:V%Z>7=AYB!C>F%S(&]S
M=&%T;FEE9V\@>F%L;V=O=V%N:6$@<&\@;&]G;W=A;FEU/P!0;VMAOR!M96YU
M("5S('!O(&QE=V5J/P!3:65R<F$@3&5O;F4`6F%R96IE<W1R=6H@<VGJ+"!J
M9;9L:2!J97-Z8WIE('1E9V\@;FEE('IR;V)ILV6V`%!O9'!I<P!!;&=O<GET
M;2!P;V1P:7-U`%-I;F=A<'5R`%=I96QK;[;F`%!O;6GQ(&]P97)A8VIE(&-Y
M:VQI8WIN90!3LV]W86-J80!3LV]W96YI80!7>7-P>2!386QO;6]N80!3;VUA
M;&EA`%!OLW5D;FEO=V$@069R>6MA`%!OLW5D;FEO=V]E=7)O<&5J<VMI("A)
M4T\M.#@U.2TS*0!'96]R9VEA(%!OLW5D;FEO=V$`2&ES>G!A;FEA`%-P86T`
M161Y8VIA('IN86OS=R!S<&5C:F%L;GEC:`!0;V1Z:65L(&MO;?-R:^H`4&]D
M>FEE;"!K;VQU;6[J`%!O9'II96P@=VEE<G-Z`%-R:2!,86YK80!7;VIE=_-D
MO'1W;R!L=6(@<W1A;@!3=&%T=7,`061R97,@9&]M;W=Y`%1E;6%T`%=YMFQI
M:@!0;W=O9'IE;FEE`%5D8;-O('-IZB!D;V1AYB`B)7,B(&1O('-Y<W1E;74N
M`%5D8;-O('-IZB!U<W5NL>8@(B5S(B!Z('-Y<W1E;74N`%5D8;-O('-IZB!U
M<W5NL>8@(B5S(BX`561ALV\@<VGJ('5S=6ZQYB`B)7,B('H@<WES=&5M=2X`
M561ALV\@<VGJ('5A:W1U86QN:>8@(B5S(@!3=61A;@!7<V-H\V0O>F%C:/-D
M('.S;_%C80!3=7)I;F%M`%-U87II`%-Z=V5C:F$`4WIW86IC87)I80!3>7)I
M80!486IW86X`5&%J=V%N`%1A9+]Y:VES=&%N`%1A;GIA;FEA`%IA9&%N:6$`
M3G5M97(@=&5L969O;G4`5'EL:V\@=&5K<W0`5&%J;&%N9&EA`$1Z:>IK=6IE
M;7D@>F$@:V]R>GES=&%N:64@>B!S97)W:7-U+@!4;[]S86UOMN8@(B5S(B!Z
M;W-T8;-A('5S=6YIZG1A+@!397)W97(@(B5S(B!Z;W-T8;,@=7-U;FGJ='DN
M`%-E<G=E<B`B)7,B('IO<W1ALR!Z87!I<V%N>2X`0FQO:R!W96%T:&5R+F-O
M;2!N:64@:F5S="!D;W-TZG!N>2X`3FEE(&UA(+]A9&YY8V@@9&]S=.IP;GEC
M:"!O<&-J:2X`5WES=+%P:;,@<')O8FQE;2!P<GIY(&1O9&%W86YI=2`B)7,B
M(&1O('-Y<W1E;74Z("5S`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!U<W5W86YI
M=2!D86YY8V@@9&QA('6_>71K;W=N:6MA("(E<R(@=R!S>7-T96UI93H@`%=Y
M<W2Q<&FS('!R;V)L96T@<')Z>2!U<W5W86YI=2`B)7,B('H@<WES=&5M=2X`
M5WES=+%P:;,@<')O8FQE;2!P<GIY('5A:W1U86QN:6%N:74@(B5S(CH@)7,`
M5WES=+%P:;,@8K.Q9"!P;V1C>F%S('=YMG=I971L86YI82!T96H@8WKJMF-I
M('=I861O;6^V8VD`5WES=+%P:;,@8K.Q9"!P;V-Z87,@:6UP;W)T;W=A;FEA
M(&1A;GEC:"!I0V%L96YD87(N`%!L:6L@;FEE('=Y9VRQ9&$@;F$@<&]P<F%W
M;F4@87)C:&EW=6T@4D%2+@!0;&EK(&YI92!W>6=LL61A(&YA('!O<')A=VYE
M(&%R8VAI=W5M(%I)4"X`5&\@<&]L92!J97-T('=Y;6%G86YE+@!4;R!P;VQE
M(&UU<VD@8GGF('!O<')A=VZQ(&QI8WIBL2X`5VEA9&]M;[;F('IO<W1ALV$@
M;F%P:7-A;F$@=R!I;FYE:B!N:;\@='=O:F$@<W1R;VYI92!K;V1O=V5J("@E
M<RDN`%1E;B!S97)W97(@;FEE('!O=')A9FD@<F]Z<&%K;W=Y=V'F(&%R8VAI
M=_-W('II<"!I(&=Z:7`N`$-Z87,`1F]R;6%T(&-Z87-U`%1Y='6S`$1O`$%B
M>2!W>6)R8>8@=VEE;&]K<F]T;F4@<&]L82!P<GIY=')Z>6UA:B!P<GIY8VES
M:R!#=')L("A00RD@;'5B($-O;6UA;F0@*$UA8RD@<&]D8WIA<R!K;&EK86YI
M82X`1'IIM@!4;V=O`%1O:V5L874`2G5T<F\`5&]N9V$`5')Y;FED860@:2!4
M;V)A9V\`4')A=V1A(&QU8B!F8;-S>@!4=6YE>FIA`%1U<F-J80!4=7)E8VMI
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5V86QU`%523`!54DPZ`%5G
M86YD80!5:W)A:6YA`$*SL60@<&]D8WIA<R!Z;6EA;GD@9&\@)7,N`$*SL60@
M<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN`$*SL60@<&]D
M8WIA<R!R;WIP86MO=WEW86YI82!D86YY8V@N`$YI92!M;[]N82!P<GIE=+-U
M;6%C>GGF('1E9V\@9&]K=6UE;G1U(%=O<F0M80!#;V9N:6H@>FUI86YY`%IJ
M961N;V-Z;VYE($5M:7)A='D@07)A8G-K:64`5VEE;&MA($)R>71A;FEA`%53
M00!.:65Z;F%N90!"97H@;F%Z=WD`3FEE;V)SLW5G:7=A;F4@<F]Z<WIE<GIE
M;FEE`%5A:W1U86QN:6H`6F&S861U:@!5<G5G=V%J`$]P8VIE('6_>71K;W=N
M:6MA`%)E:F5S=')A8VIA('6_>71K;W=N:6MA`$YA>G=A('6_>71K;W=N:6MA
M`%6_>71K;W=N:6L@;R!N87IW:64@(B5S(B!J=;\@:7-T;FEE:F4N`$YA>G=A
M('6_>71K;W=N:6MA.@!.87IW82!UOWET:V]W;FEK83H@`%6_>71K;W=N:6-Y
M('<@<WES=&5M:64Z`%5Z8F5K:7-T86X`5V%K86-J90!686YU871U`%=E;F5Z
M=65L80!797)S:F$`5VEE=&YA;0!7:61O:R`E<P!0;VMAOR!S=')O;NH@5U=7
M`%!O:V&_(&IA:V\@)7,`0G)Y='EJ<VMI92!7>7-P>2!$>FEE=VEC>F4`5WES
M<'D@1'II97=I8WIE(%-T86[S=R!::F5D;F]C>F]N>6-H`%=A;&QI<R!I($9U
M='5N80!/<W1R>F6_96YI90!75U<`0V\@='ED>FEE\0!7:71A;7D`5VET86UY
M('<@)7,`5VET86UY+"`E<P!:86-H;V1N:2`H25-/+3@X-3DM,2D`6F%C:&]D
M;FD@*$E33RTX.#4Y+3$U*0!386AA<F$@6F%C:&]D;FEA`$IA:[$@87!L:6MA
M8VKJ(&UA("5S('=YMG=I971L8>8@<&\@>F%L;V=O=V%N:74@<VGJ/P!*86MI
M92!W='EC>FMI(&%K='EW;W=AYB!W(%)O>F)U9&]W86YY;2!E9'ET;W)Z92!T
M96MS='4N`%-Z97)O:V^VYB!L97=E9V\@;65N=2`E<R`H>FUI86YA('IA8WIN
M:64@;V)O=VFQ>GEW8>8@<')Z>2!N87-TZG!N>6T@;&]G;W=A;FEU*3H`061R
M97,@9&\@<')A8WD`5&5L+B!D;R!P<F%C>0!24@!24E)2`$-O(')O:P!*96UE
M;@!486L`5&%K+"!Z9V%D>F%M('-IZ@!7>6QO9V]W8;-EMB!S:>HN`$UU<VES
M>B!O<&ES8>8@<')O8FQE;2!Z86YI;2!G;R!W>;9L97-Z+@!-=7-I<WH@;VMR
M9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S=6ZQYBX`375S
M:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!D;V1A
MYBX`5'?S:B!A9')E<R!E+6UA:6P`5'?S:B!A9')E<R!/9#H`5'=O:F4@:6YF
M;W)M86-J90!4=_-J(&%D<F5S(&EN=&5R;F5T;W=Y('-IZB!Z;6EE;FFS(&]D
M('!O8WJQ=&MU('-E<VII("5S+B!7('IW:;%Z:W4@>B!B97IP:65C>F7Q<W1W
M96T@5'=O:F5G;R!K;VYT82!M=7-I<WH@>F%L;V=O=V'F('-IZB!P;VYO=VYI
M92X`5'=O:F4@:6UIZ@!496X@<WES=&5M(&%U=&5N='EK86-J:2!N:64@;V)S
MLW5G=6IE(&1O9&%W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T82!O<&-J82!Z
M;W-T8;-A('=YL[%C>F]N82X`5&5N('-Y<W1E;2!A=71E;G1Y:V%C:FD@;FEE
M(&]B<[-U9W5J92!L:7-T;W=A;FEA('6_>71K;W=N:6OS=RP@;'5B('1A(&]P
M8VIA('IO<W1ALV$@=WFSL6-Z;VYA+@!4=V]J82!O8F5C;F$@<W1R969A(&-Z
M87-O=V$Z`$1O;7FV;&YA('1OOW-A;6^VYCH`5'=O:F4@<&6S;F4@:6UIZB!I
M(&YA>G=I<VMO.@!4=V]I;2!N;W=Y;2!H87.S96T@=R`E<R!J97-T.B`E<P!4
M=V]J92!U<W1A=VEE;FEA('IO<W1ALWD@=6%K='5A;&YI;VYE(&YA(&-Z87,@
M=')W86YI82!T96H@<V5S:FDN`%1W;VIE('5S=&%W:65N:6$@>F]S=&&S>2!U
M86MT=6%L;FEO;F4N`%1W;VIE('ID86QN92!S97)W97)Y.@!*=6=O<[-A=VEA
M`%IA:7(`6F%M8FEA`%II;6)A8G=E`%M287!O<G0@;R!P<F]B;&5M:65=`%]!
M9&UI;FES=')A8VIA`%]#3$D`7U5S=?$@=VEE<G-Z`%]'<G5P>0!?4&]M;V,`
M7UIA;&]G=6H`7U=Y;&]G=6H`6FUI9?$@;&EN:RXN+@!?3W!C:F4`7U5P<F%W
M;FEE;FEA`%5S=?$@;&EN:RXN+@!?2V]N9FEG=7)A8VIA`%]5OWET:V]W;FEC
M>0!K<VFQOVMA(&%D<F5S;W=A`&MA;&5N9&%R>@!P;&EK`$YA>G=I<VMO`&YO
M=&%T;FEK`&)E>B!N87IW>0!V0V%R9```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O<&Q?4$PO:&5L<"YX;6P`````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,Q,#8R`#`R,#,R
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L
M92]P;%]03"]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$S(&IA
M;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T
M93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R
M83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R
M>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X
M86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S
M86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT
M<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES
M="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD
M('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A
M:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@
M87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A
M(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\
M<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@
M8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA
M;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O
M;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E
M<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I
M;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE
M9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I
M;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H
M:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C
M:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA
M;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN
M=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES
M(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R
M871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@
M875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G
M:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+W!T7T)2+P``````````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,38V-38`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<'1?0E(O3$-?34534T%'15,O
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8R`#`R,#0T,P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P
M=%]"4B],0U]-15-304=%4R]H;W)D92YM;P``````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`T,34Q-3$`,3`U,34T,S$P-C(`,#(R,3`U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X2!)4`````A@<``!P```!,
M/```$PH``'QX````````R*````X```#)H```#P```-B@```-````Z*````@`
M``#VH```"P```/^@```,````"Z$```0````8H0``&````!VA```;````-J$`
M`"T```!2H0``'0```("A```D````GJ$``"D```##H0``&0```.VA```F````
M!Z(```P````NH@``)````#NB```/````8*(```L```!PH@``#@```'RB```%
M````BZ(``"@```"1H@``"````+JB```*````PZ(``!4```#.H@``$@```.2B
M```+````]Z(``(4````#HP``#@```(FC```*````F*,```T```"CHP``#@``
M`+&C```1````P*,```T```#2HP``#````."C```-````[:,```8```#[HP``
ME`````*D```*````EZ0```\```"BI```&````+*D```,````RZ0```X```#8
MI```#@```.>D```(````]J0```D```#_I```+@````FE```:````.*4``#(`
M``!3I0``.````(:E``!4````OZ4``%$````4I@``6@```&:F``!7````P:8`
M`#0````9IP``"0```$ZG```-````6*<```<```!FIP``"@```&ZG```/````
M>:<```4```")IP``!@```(^G```1````EJ<```@```"HIP``"0```+&G```)
M````NZ<``"4```#%IP``(````.NG```3````#*@``!`````@J```#P```#&H
M```*````0:@```,```!,J```#P```%"H```4````8*@```D```!UJ```#0``
M`'^H```2````C:@``!D```"@J```'@```+JH```/````V:@```H```#IJ```
M#P```/2H```(````!*D``"0````-J0``%````#*I```6````1ZD```@```!>
MJ0``3@```&>I```M````MJD``!D```#DJ0``!P```/ZI```,````!JH``"P`
M```3J@``#@```$"J```#````3ZH```L```!3J@``!P```%^J```'````9ZH`
M``4```!OJ@``!0```'6J```*````>ZH```,```"&J@``%P```(JJ```*````
MHJH```\```"MJ@``#@```+VJ```8````S*H``",```#EJ@``#@````FK```4
M````&*L``!<````MJP``%P```$6K```7````7:L``!,```!UJP``#P```(FK
M```.````F:L``!\```"HJP``'0```,BK```'````YJL```8```#NJP``"```
M`/6K```/````_JL```8````.K```"@```!6L```3````(*P```L````TK```
M$````$"L```5````4:P``!4```!GK```!P```'VL```0````A:P```4```"6
MK```%0```)RL```1````LJP```P```#$K```.P```-&L```X````#:T```D`
M``!&K0``!P```%"M```4````6*T```,```!MK0``!0```'&M```0````=ZT`
M``D```"(K0``$P```)*M```Y````IJT``!(```#@K0``)P```/.M```L````
M&ZX``"H```!(K@``)0```'.N```*````F:X```8```"DK@``"0```*NN```'
M````M:X``"\```"]K@``-P```.VN```N````):\``%4```!4KP``+0```*JO
M```M````V*\``#T````&L```/P```$2P```M````A+```$````"RL```(P``
M`/.P```C````%[$``$`````[L0``+0```'RQ```S````JK$``"4```#>L0``
M%0````2R```9````&K(``"D````TL@``)````%ZR```H````@[(``!$```"L
ML@``"@```+ZR```,````R;(```H```#6L@``$````.&R```6````\K(``!8`
M```)LP``!P```""S```'````*+,``!0````PLP``"@```$6S```(````4+,`
M`"<```!9LP``"````(&S```'````BK,```<```"2LP``!@```)JS```%````
MH;,```<```"GLP``!@```*^S```(````MK,``"D```"_LP``#@```.FS```*
M````^+,```0````#M```!P````BT```)````$+0```8````:M```$0```"&T
M```'````,[0``!8````[M```!````%*T```(````5[0```8```!@M```#0``
M`&>T```&````=;0``!X```!\M```$0```)NT```(````K;0```T```"VM```
M#````,2T```'````T;0```,```#9M````P```-VT```7````X;0``!,```#Y
MM```'0````VU```(````*[4```0````TM0``"````#FU```(````0K4``$$`
M``!+M0``&@```(VU```K````J+4``"````#4M0``%0```/6U```&````"[8`
M``8````2M@``%0```!FV```8````+[8``"(```!(M@``+@```&NV```=````
MFK8``"$```"XM@``5````-JV```I````+[<```H```!9MP``!P```&2W```'
M````;+<``!4```!TMP``#@```(JW```*````F;<```\```"DMP``#0```+2W
M```/````PK<```T```#2MP``"0```."W```4````ZK<```8```#_MP``&```
M``:X```=````'[@``!,````]N```$0```%&X```4````8[@```0```!XN```
M!@```'VX```4````A+@``%0```"9N```9````.ZX```$````4[D```X```!8
MN0``!0```&>Y```%````;;D``!L```!SN0``&@```(^Y```3````JKD``!$`
M``"^N0``$0```-"Y```<````XKD``"H```#_N0``$````"JZ```A````.[H`
M``4```!=N@``$P```&.Z```+````=[H``!(```"#N@``"@```):Z```/````
MH;H```T```"QN@``$0```+^Z```3````T;H```P```#EN@``!@```/*Z```,
M````^;H```8````&NP``%P````V[```0````);L``!$````VNP``"````$B[
M```%````4;L```P```!7NP``$````&2[```%````=;L```T```![NP``!@``
M`(F[```'````D+L```T```"8NP``!P```*:[```+````KKL```<```"ZNP``
M!P```,*[```)````RKL```D```#4NP``"@```-Z[```9````Z;L``#T````#
MO```'0```$&\```,````7[P``!````!LO```!0```'V\```E````@[P``!(`
M``"IO```$P```+R\```K````T+P``#L```#\O```(````#B]```(````6;T`
M`#8```!BO0``(0```)F]```0````N[T```@```#,O0``#````-6]```&````
MXKT```0```#IO0``#P```.Z]```.````_KT```<````-O@``"@```!6^```-
M````(+X``!\````NO@``'````$Z^```A````:[X``!X```"-O@``&0```*R^
M```>````QKX``!L```#EO@``(0````&_```N````([\``"8```!2OP``'```
M`'F_```>````EK\``!P```"UOP``)@```-*_```K````^;\``#,````EP```
M)@```%G````K````@,```#@```"LP```'0```.7````5`````\$``"\````9
MP0``(````$G!```2````:L$``"D```!]P0``'@```*?!```@````QL$``!(`
M``#GP0``H@```/K!```6````G<(``",```"TP@``*````-C"```I`````<,`
M`"@````KPP``'P```%3#```5````=,,``"````"*PP``)0```*O#```H````
MT<,``"T```#ZPP``,````"C$``"2````6<0``"$```#LQ```%@````[%```<
M````)<4``"8```!"Q0``*@```&G%``!!````E,4``$0```#6Q0``#````!O&
M```'````*,8```<````PQ@``!@```#C&```-````/\8``!````!-Q@``$@``
M`%[&```3````<<8``!(```"%Q@``!P```)C&```$````H,8``!````"EQ@``
M$````+;&```,````Q\8```X```#4Q@``#0```./&```/````\<8``!,````!
MQP``#0```!7'```H````(\<```,```!,QP``#0```%#'```&````7L<``!$`
M``!EQP``%P```'?'```;````C\<```X```"KQP```@```+K'``!)````O<<`
M``4````'R```$`````W(```/````'L@```0````NR```#0```#/(```.````
M0<@```,```!0R```#@```%3(```(````8\@```\```!LR```#P```'S(```'
M````C,@```T```"4R```$````*+(```-````L\@```L```#!R```!@```,W(
M```+````U,@```P```#@R```"@```.W(```1````^,@``!D````*R0``"P``
M`"3)```-````,,D``"(````^R0``&P```&')```T````?<D```H```"RR0``
M&````+W)```9````ULD``!8```#PR0``(@````?*```-````*LH```<````X
MR@``%````$#*```+````5<H``"(```!AR@``+P```(3*```+````M,H```D`
M``#`R@``&0```,K*```+````Y,H``!<```#PR@``%P````C+```)````(,L`
M`!8````JRP``#P```$'+```9````4<L``!8```!KRP``#@```(++```8````
MD<L```@```"JRP``#0```+/+```F````P<L``$,```#HRP``"````"S,```2
M````-<P``!\```!(S```"````&C,```+````<<P``"\```!]S```#@```*W,
M```%````O,P```8```#"S```10```,G,```#````#\T```<````3S0``!```
M`!O-```*````(,T```H````KS0``#P```#;-```0````1LT``!<```!7S0``
M$0```&_-```9````@<T``!<```";S0``"0```+/-```%````O<T```L```##
MS0``"@```,_-```"````VLT```4```#=S0``#0```./-```;````\<T``!<`
M```-S@``%````"7.```)````.LX```X```!$S@``#0```%/.```2````8<X`
M`#@```!TS@``(````*W.```(````SLX```X```#7S@``>P```.;.```8````
M8L\``!@```![SP``$0```)3/```'````IL\```4```"NSP``&````+3/```>
M````S<\``!L```#LSP``&0````C0```;````(M```!D````^T```$P```%C0
M```'````;-````@```!TT```!@```'W0```&````A-```!````"+T```#P``
M`)S0```0````K-````\```"]T```"P```,W0```/````V=````P```#IT```
M#P```/;0```'````!M$```8````.T0``#@```!71```,````)-$``"@````Q
MT0``#P```%K1```(````:M$```@```!ST0``$P```'S1```>````D-$``"$`
M``"OT0``(````-'1```9````\M$``!<````,T@``)0```"32```7````2M(`
M`!8```!BT@``!````'G2```;````?M(```T```":T@``#````*C2```#````
MM=(```4```"YT@``"````+_2```*````R-(```P```#3T@``"P```.#2```0
M````[-(```P```#]T@``#@````K3```+````&=,```0````ETP``!````"K3
M```3````+],``!0```!#TP``#````%C3```)````9=,```X```!OTP``"P``
M`'[3```;````BM,```<```"FTP``!P```*[3```*````MM,```T```#!TP``
M"0```,_3```$````V=,```4```#>TP```P```.33```8````Z-,```H````!
MU```!`````S4```F````$=0```X````XU```?````$?4```5````Q-0```4`
M``#:U```!P```.#4```,````Z-0```@```#UU```"@```/[4```&````"=4`
M``@````0U0```@```!G5```&````'-4```8````CU0``%````"K5```-````
M/]4``!````!-U0``&P```%[5```$````>M4```D```!_U0``$````(G5```)
M````FM4```D```"DU0``!0```*[5```:````M-4```@```#/U0``!@```-C5
M```9````W]4```X```#YU0``!P````C6```'````$-8```4````8U@``"0``
M`![6```*````*-8```X````SU@```@```$+6```&````1=8```L```!,U@``
M#0```%C6```)````9M8```8```!PU@``$@```'?6```)````BM8```<```"4
MU@``%````)S6```=````L=8``$(```#/U@``)0```!+7```E````.-<```8`
M``!>UP``"@```&77```$````<-<```D```!UUP``"````'_7```1````B-<`
M``D```":UP``!@```*37```-````J]<```8```"YUP``!````,#7```Y````
MQ=<``#T```#_UP``.@```#W8```>````>-@```4```"7V```#@```)W8```$
M````K-@```8```"QV```!P```+C8```A````P-@```T```#BV```%0```/#8
M```&````!MD```0````-V0``$0```!+9```&````)-D```H````KV0``(@``
M`#;9```$````6=D```4```!>V0``'0```&39```$````@MD```P```"'V0``
M#@```)39```*````H]D```@```"NV0``"0```+?9```%````P=D``#H```#'
MV0``,`````+:```U````,]H``"D```!IV@``1P```)/:```X````V]H``"D`
M```4VP``/P```#[;```N````?ML``"T```"MVP``'P```-O;```/````^]L`
M`!(````+W```"P```![<```F````*MP``"D```!1W```)````'O<```F````
MH-P```@```#'W```"@```-#<```)````V]P```<```#EW```(````.W<```@
M````#MT``"8````OW0``"@```%;=```9````8=T``"D```![W0``%@```*7=
M```2````O-T```<```#/W0``"@```-?=```,````XMT```\```#OW0``$```
M`/_=``!`````$-X``'````!1W@``9@```,+>```.````*=\```D````XWP``
M"@```$+?```2````3=\``!,```!@WP``#````'3?```&````@=\```\```"(
MWP``$@```)C?```0````J]\``!$```"\WP``'````,[?```C````Z]\``&H`
M```/X```#P```'K@```%````BN```!````"0X```"0```*'@```$````J^``
M``L```"PX```(````+S@```4````W>````P```#RX```#````/_@```/````
M#.$``!4````<X0``*0```#+A```J````7.$``"8```"'X0``)P```*[A```I
M````UN$``"H`````X@``&0```"OB``!"````1>(``!$```"(X@``$@```)KB
M```3````K>(``!0```#!X@``#P```-;B```6````YN(``!<```#]X@``$```
M`!7C```1````)N,``#0````XXP``$P```&WC```2````@>,``#4```"4XP``
M%````,KC```'````W^,```P```#GXP``(````/3C```0````%>0``!0````F
MY```$0```#OD```7````3>0``!P```!EY```$P```(+D```4````EN0``!H`
M``"KY```$0```,;D```:````V.0``!X```#SY```&@```!+E```3````+>4`
M`!4```!!Y0``$0```%?E```7````:>4``!0```"!Y0``%P```);E```5````
MKN4```D```#$Y0``$````,[E```9````W^4```0```#YY0``!P```/[E```+
M````!N8``!$````2Y@``!@```"3F```&````*^8```8````RY@``!0```#GF
M```'````/^8```<```!'Y@``!0```$_F```6````5>8```8```!LY@``!@``
M`'/F```$````>N8```0```!_Y@``!P```(3F```.````C.8```P```";Y@``
M#````*CF```-````M>8```H```##Y@``#@```,[F```%````W>8``"@```#C
MY@``#@````SG```,````&^<```\````HYP``"@```#CG```(````0^<```D`
M``!,YP``*P```%;G```$````@N<```@```"'YP``)@```)#G```2````M^<`
M``\```#*YP``!@```-KG```*````X><```<```#LYP``"````/3G```@````
M_><```D````>Z```%````"CH```,````/>@```T```!*Z```#@```%CH```6
M````9^@``!$```!^Z```!@```)#H```#````E^@```8```";Z```&0```*+H
M```'````O.@```0```#$Z```"P```,GH```+````U>@```<```#AZ```!0``
M`.GH```'````[^@``!8```#WZ```#0````[I```-````'.D```H````JZ0``
M$````#7I```/````1ND``!$```!6Z0``%P```&CI```*````@.D``!$```"+
MZ0``"````)WI```$````IND```\```"KZ0``.@```+OI```%````]ND```P`
M``#\Z0``'@````GJ```.````*.H``!`````WZ@``"P```$CJ```,````5.H`
M``D```!AZ@``!P```&OJ```*````<^H```D```!^Z@``#@```(CJ```0````
ME^H``!L```"HZ@``&````,3J```:````W>H```H```#XZ@``"0````/K```*
M````#>L```P````8ZP``#P```"7K```(````->L```8````^ZP``'````$7K
M```'````8NL```4```!JZP``"P```'#K``!'````?.L```T```#$ZP``"0``
M`-+K```$````W.L```,```#AZP``$P```.7K```3````^>L``!,````-[```
M"@```"'L```"````+.P```0````O[```)0```#3L```#````6NP```4```!>
M[```*@```&3L```*````C^P```4```":[```!````*#L```*````I>P```T`
M``"P[```!@```+[L```(````Q>P```@```#.[```!````-?L```%````W.P`
M`&@```#B[```"0```$OM```,````5>T``!````!B[0``!0```'/M```&````
M>>T``!L```"`[0``+P```)SM```0````S.T```H```#=[0``#P```.CM```*
M````^.T```D````#[@``$P````WN```;````(>X``!@````][@``%P```%;N
M```?````;NX```X```".[@```P```)WN```'````H>X```@```"I[@``!P``
M`++N```*````NNX```L```#%[@``!P```-'N``!1````V>X``!`````K[P``
M#````#SO```-````2>\``!H```!7[P``2@```'+O```9````O>\```8```#7
M[P``&@```-[O```E````^>\```8````?\```!@```";P```?````+?````8`
M``!-\```"0```%3P```8````7O```!<```!W\```*````(_P```&````N/``
M``T```"_\```(@```,WP``!7````\/```!,```!(\0``(P```%SQ```3````
M@/$```(```"4\0``"P```)?Q```(````H_$```T```"L\0``"@```+KQ```'
M````Q?$``!0```#-\0``!@```.+Q```(````Z?$```X```#R\0``!P````'R
M```*````"?(```L````4\@``,@```"#R```'````4_(```P```!;\@``#0``
M`&CR```,````=O(```D```"#\@``"0```(WR```*````E_(```<```"B\@``
M"0```*KR```'````M/(```H```"\\@``&P```,?R```/````X_(``!(```#S
M\@``"@````;S```6````$?,```D````H\P``$````#+S```'````0_,``!(`
M``!+\P``!````%[S```'````8_,```4```!K\P``!0```''S```+````=_,`
M`!0```"#\P``$0```)CS```:````JO,``!8```#%\P``%````-SS```7````
M\?,``!@````)]```'````"+T```9````/_0```<```!9]```!0```&'T```-
M````9_0```P```!U]```$0```(+T```(````E/0``!<```"=]```"P```+7T
M```,````P?0``!\```#.]```&@```.[T```3````"?4```0````=]0``"@``
M`"+U```$````+?4```T````R]0``#````$#U```%````3?4```D```!3]0``
M!0```%WU```'````8_4```4```!K]0``!````''U```"````=O4``#@```!Y
M]0``+````++U```2````W_4``"D```#R]0``,@```!SV```*````3_8``"P`
M``!:]@``+@```(?V```S````MO8``#,```#J]@``.````![W```/````5_<`
M`!@```!G]P``$````(#W```/````D?<``!,```"A]P``%0```+7W```4````
MR_<``!(```#@]P``%````//W```5````"/@``"T````>^```+0```$SX```Q
M````>O@``"X```"L^```+P```-OX```L````"_D``&(````X^0``$P```)OY
M```-````K_D```@```"]^0``%P```,;Y```(````WOD```P```#G^0``*P``
M`/3Y```A````(/H``!H```!"^@``"0```%WZ``!%````9_H``$$```"M^@``
M!````._Z```3````]/H``!0````(^P``#@```!W[```3````+/L``!@```!`
M^P``!@```%G[```)````8/L```H```!J^P``#P```'7[```0````A?L```<`
M``"6^P``#@```)[[```%````K?L``!L```"S^P``"````,_[```&````V/L`
M`!0```#?^P``$0```/3[```.````!OP``#@````5_````@```$[\```&````
M4?P```X```!8_```!0```&?\```'````;?P```X```!U_```!@```(3\```H
M````B_P```P```"T_```'````,'\```$````WOP``"D```#C_```%P````W]
M```?````)?T``%P```!%_0``%````*+]```^````M_T``!\```#V_0``$```
M`!;^```'````)_X```X````O_@``#````#[^```,````2_X``!,```!8_@``
M"@```&S^```=````=_X``!D```"5_@``!0```*_^```1````M?X``!$```#'
M_@``)````-G^```2````_OX``!4````1_P``$@```"?_```.````.O\``!D`
M``!)_P``"````&/_```)````;/\```T```!V_P``!P```(3_```*````C/\`
M``<```"7_P``#P```)__```&````K_\```L```"V_P``&@```,+_```*````
MW?\```<```#H_P``"````/#_```%````^?\``!\```#__P``!@```!\``0`0
M````)@`!``@````W``$`#0```$```0`(````3@`!`!X```!7``$`$@```'8`
M`0`L````B0`!`!H```"V``$`"0```-$``0`*````VP`!`!4```#F``$`!0``
M`/P``0`4`````@$!``0````7`0$`$````!P!`0`&````+0$!``<````T`0$`
M'@```#P!`0`H````6P$!``H```"$`0$`'````(\!`0`1````K`$!``L```"^
M`0$`&@```,H!`0`4````Y0$!``0```#Z`0$`!````/\!`0`+````!`(!``4`
M```0`@$`!@```!8"`0`(````'0(!``8````F`@$`"@```"T"`0`;````.`(!
M`#0```!4`@$`-````(D"`0`@````O@(!`"D```#?`@$`(`````D#`0!!````
M*@,!`!H```!L`P$`*````(<#`0`I````L`,!`%````#:`P$`(@```"L$`0`&
M````3@0!``@```!5!`$`!0```%X$`0`(````9`0!`!D```!M!`$`&0```(<$
M`0`J````H00!`",```#,!`$`&0```/`$`0`N````"@4!`#0````Y!0$`"```
M`&X%`0`7````=P4!``H```"/!0$`!P```)H%`0`A````H@4!`!````#$!0$`
M#@```-4%`0`+````Y`4!``<```#P!0$`$P```/@%`0`(````#`8!``L````5
M!@$`"@```"$&`0`4````+`8!``\```!!!@$`,@```%$&`0`+````A`8!``4`
M``"0!@$`!0```)8&`0`%````G`8!`!<```"B!@$`#P```+H&`0`$````R@8!
M``H```#/!@$`"0```-H&`0`+````Y`8!``T```#P!@$`#````/X&`0`.````
M"P<!``4````:!P$`!````"`'`0`-````)0<!`#(````S!P$`10```&8'`0`7
M````K`<!``<```#$!P$`'@```,P'`0`4````ZP<!``4`````"`$`%`````8(
M`0`&````&P@!``<````B"`$`#@```"H(`0`J````.0@!``8```!D"`$`#```
M`&L(`0`-````>`@!`!$```"&"`$`"P```)@(`0`V````I`@!``H```#;"`$`
M(@```.8(`0`+````"0D!``\````5"0$`,@```"4)`0`E````6`D!`#````!^
M"0$`,0```*\)`0`M````X0D!``X````/"@$`!0```!X*`0`.````)`H!`!,`
M```S"@$`$@```$<*`0`'````6@H!`!$```!B"@$`$P```'0*`0`'````B`H!
M`!0```"0"@$`&````*4*`0`'````O@H!``4```#&"@$`#````,P*`0`,````
MV0H!`!(```#F"@$`!````/D*`0`'````_@H!``H````&"P$`"P```!$+`0`,
M````'0L!``X````J"P$`#@```#D+`0`%````2`L!``4```!."P$`+@```%0+
M`0`F````@PL!`",```"J"P$``P```,X+`0`2````T@L!``8```#E"P$`'@``
M`.P+`0`8````"PP!`"4````D#`$`#0```$H,`0`)````6`P!`!\```!B#`$`
M`P```((,`0`'````A@P!``H```".#`$``@```)D,`0`,````G`P!`!4```"I
M#`$`"P```+\,`0`9````RPP!`"````#E#`$`$@````8-`0`%````&0T!``H`
M```?#0$`%0```"H-`0`2````0`T!``P```!3#0$`!````&`-`0`)````90T!
M``<```!O#0$`#````'<-`0!2````A`T!`!<```#7#0$`)````.\-`0`2````
M%`X!``<````G#@$`!@```"\.`0`.````-@X!``P```!%#@$`#0```%(.`0`5
M````8`X!`!(```!V#@$`#P```(D.`0`4````F0X!``H```"N#@$`&P```+D.
M`0`0````U0X!``L```#F#@$`:0```/(.`0`:````7`\!`!<```!W#P$`)P``
M`(\/`0`:````MP\!`!<```#2#P$`&P```.H/`0`9````!A`!`!\````@$`$`
M$P```$`0`0`(````5!`!``<```!=$`$`"````&40`0`)````;A`!`!4```!X
M$`$`#0```(X0`0`C````G!`!``T```#`$`$`$P```,X0`0`(````XA`!``,`
M``#K$`$`1@```.\0`0`_````-A$!`#<```!V$0$`5P```*X1`0`%````!A(!
M`!\````,$@$`+P```"P2`0`*````7!(!``@```!G$@$`#0```'`2`0`M````
M?A(!``0```"L$@$`3P```+$2`0`E`````1,!`!P````G$P$`"P```$03`0`?
M````4!,!`!T```!P$P$`)0```(X3`0`@````M!,!`"0```#5$P$`(````/H3
M`0`+````&Q0!``<````G%`$`#0```"\4`0`,````/10!`!<```!*%`$`!@``
M`&(4`0`Y````:10!``P```"C%`$`!P```+`4`0`)````N!0!`!,```#"%`$`
M"0```-84`0`$````X!0!`!````#E%`$`"````/84`0`(````_Q0!``0````(
M%0$`"P````T5`0`,````&14!`!(````F%0$`$0```#D5`0`,````2Q4!`!H`
M``!8%0$`#P```',5`0`'````@Q4!``T```"+%0$`%````)D5`0`.````KA4!
M``P```"]%0$`&P```,H5`0`L````YA4!`!,````3%@$`'````"<6`0`H````
M1!8!``8```!M%@$`!P```'06`0`3````?!8!``4```"0%@$`!````)86`0`7
M````FQ8!``H```"S%@$`#````+X6`0`)````RQ8!``8```#5%@$`"0```-P6
M`0`(````YA8!``D```#O%@$`"@```/D6`0`1````!!<!``8````6%P$`#@``
M`!T7`0`.````+!<!``T````[%P$`"P```$D7`0`=````51<!``L```!S%P$`
M`@```'\7`0`<````@A<!``<```"?%P$`!@```*<7`0!D````KA<!``D````3
M&`$`!P```!T8`0`F````)1@!`#@```!,&`$`&@```(48`0`J````H!@!`#L`
M``#+&`$`*`````<9`0`T````,!D!`!D```!E&0$`%0```'\9`0`%````E1D!
M``<```";&0$`"````*,9`0`'````K!D!``4```"T&0$`!P```+H9`0`.````
MPAD!``D```#1&0$`!@```-L9`0`(````XAD!``L```#K&0$`!P```/<9`0`(
M````_QD!``<````(&@$`%@```!`:`0`)````)QH!``8````Q&@$`"P```#@:
M`0`0````1!H!``8```!5&@$`'````%P:`0`4````>1H!``<```".&@$`$0``
M`)8:`0`(````J!H!``X```"Q&@$`"````,`:`0`%````R1H!`!````#/&@$`
M"0```.`:`0`0````ZAH!``8```#[&@$`&0````(;`0`*````'!L!`!P````G
M&P$`!P```$0;`0`%````3!L!`!````!2&P$`%````&,;`0`+````>!L!``T`
M``"$&P$`*````)(;`0`8````NQL!`!<```#4&P$`!````.P;`0`)````\1L!
M``H```#[&P$`!P````8<`0`"````#AP!``X````1'`$`"````"`<`0`C````
M*1P!`!\```!-'`$`.````&T<`0`F````IAP!`#$```#-'`$`)P```/\<`0!D
M````)QT!`!0```",'0$`50```*$=`0`X````]QT!`$H````P'@$`6P```'L>
M`0`H````UQX!`#@`````'P$`*````#D?`0`L````8A\!`"8```"/'P$`&P``
M`+8?`0`^````TA\!`*D!```1(`$`(P```+LA`0`7````WR$!`$@```#W(0$`
MA0```$`B`0`P````QB(!`"4```#W(@$`00```!TC`0!;````7R,!`$D```"[
M(P$`,0````4D`0`=````-R0!`!@```!5)`$`*P```&XD`0`A````FB0!`!\`
M``"\)`$`*P```-PD`0`F````""4!`"<````O)0$`.@```%<E`0`=````DB4!
M`!$```"P)0$`,P```,(E`0`E````]B4!`"<````<)@$`(````$0F`0`?````
M928!`#````"%)@$`:0```+8F`0`Q````("<!`$$```!2)P$`,P```)0G`0`E
M````R"<!`#T```#N)P$`90```"PH`0!-````DB@!`"\```#@*`$`+@```!`I
M`0`P````/RD!`%0```!P*0$`6@```,4I`0!(````("H!`$H```!I*@$`,@``
M`+0J`0`O````YRH!`"P````7*P$`+0```$0K`0!Q````<BL!`&8```#D*P$`
M;P```$LL`0"S````NRP!`!<```!O+0$`)0```(<M`0`R````K2T!`"D```#@
M+0$`/@````HN`0`B````22X!`%(```!L+@$`)0```+\N`0`+````Y2X!`+$`
M``#Q+@$`10```*,O`0`A````Z2\!`#`````+,`$`)0```#PP`0`<````8C`!
M`#$```!_,`$`!P```+$P`0`'````N3`!``0```#!,`$`#0```,8P`0`+````
MU#`!``X```#@,`$`"P```.\P`0`%````^S`!`!`````!,0$``@```!(Q`0!9
M````%3$!``4```!O,0$`$@```'4Q`0`$````B#$!``<```"-,0$`"````)4Q
M`0`%````GC$!``,```"D,0$`$````*@Q`0`,````N3$!`!,```#&,0$`#0``
M`-HQ`0`"````Z#$!``<```#K,0$`!@```/,Q`0`4````^C$!``P````/,@$`
M&````!PR`0`&````-3(!`!(````\,@$`#````$\R`0`#````7#(!`"H```!@
M,@$`!````(LR`0`&````D#(!``<```"7,@$`'P```)\R`0`U````OS(!`"X`
M``#U,@$`+P```"0S`0`7````5#,!`"(```!L,P$`)0```(\S`0`@````M3,!
M`!L```#6,P$`&````/(S`0`D````"S0!`!\````P-`$`&@```%`T`0`A````
M:S0!`"````"--`$`&@```*XT`0`R````R30!`!H```#\-`$`+P```!<U`0`K
M````1S4!`!\```!S-0$`(P```),U`0`?````MS4!`!H```#7-0$`(0```/(U
M`0`E````%#8!`"8````Z-@$`)0```&$V`0`D````AS8!`!@```"L-@$`'0``
M`,4V`0`D````XS8!`!@````(-P$`(@```"$W`0`L````1#<!`"\```!Q-P$`
M%0```*$W`0`E````MS<!`#P```#=-P$`'P```!HX`0`C````.C@!`!\```!>
M.`$`(````'XX`0`:````GS@!`!@```"Z.`$`)@```-,X`0`>````^C@!`"D`
M```9.0$`'@```$,Y`0`Q````8CD!``D```"4.0$`#````)XY`0`7````JSD!
M`"\```##.0$`)````/,Y`0`'````&#H!``\````@.@$`%````#`Z`0`.````
M13H!``T```!4.@$`)````&(Z`0`%````ASH!``<```"-.@$`(@```)4Z`0`E
M````N#H!`!H```#>.@$`'0```/DZ`0`:````%SL!``<````R.P$`QP```#H[
M`0`+`````CP!`!4````./`$`!@```"0\`0`)````*SP!``L````U/`$`#0``
M`$$\`0`7````3SP!``8```!G/`$`,P```&X\`0`3````HCP!`!,```"V/`$`
M!P```,H\`0`/````TCP!``<```#B/`$`,@```.H\`0`$````'3T!`"$````B
M/0$`$P```$0]`0`,````6#T!`!$```!E/0$`,@```'<]`0`6````JCT!``@`
M``#!/0$`'0```,H]`0`)````Z#T!``H```#R/0$`%````/T]`0`*````$CX!
M`!T````=/@$`"````#L^`0`?````1#X!``@```!D/@$`&@```&T^`0`G````
MB#X!``8```"P/@$`%0```+<^`0`'````S3X!``@```#5/@$`"0```-X^`0`_
M````Z#X!``<````H/P$`#P```#`_`0`.````0#\!`!````!//P$`"0```&`_
M`0`)````:C\!``@```!T/P$`$P```'T_`0`'````D3\!`!D```"9/P$`"@``
M`+,_`0`7````OC\!`!0```#6/P$`"@```.L_`0`,````]C\!`!<````#0`$`
M!````!M``0`J````($`!``P```!+0`$`$0```%A``0`'````:D`!``(```!R
M0`$`$````'5``0`8````AD`!``L```"?0`$``P```*M``0`(````KT`!``8`
M``"X0`$`!P```+]``0`-````QT`!``L```#50`$`%````.%``0`5````]D`!
M``X````,00$`+P```!M!`0`@````2T$!`!P```!L00$`%0```(E!`0`,````
MGT$!`#$```"L00$`!0```-Y!`0`2````Y$$!`#\```#W00$`$@```#="`0`*
M````2D(!``8```!50@$`!````%Q"`0`$````84(!``H```!F0@$`$P```'%"
M`0`%````A4(!``8```"+0@$`!@```))"`0`(````F4(!``0```"B0@$`#```
M`*="`0`*````M$(!`#D```"_0@$`+@```/E"`0`I````*$,!``4```!20P$`
M&````%A#`0`9````<4,!`!\```"+0P$`'0```*M#`0`1````R4,!``(```#;
M0P$`!````-Y#`0`*````XT,!``8```#N0P$`!0```/5#`0`#````^T,!``P`
M``#_0P$`10````Q$`0`R````4D0!`!H```"%1`$`-````*!$`0`H````U40!
M`%,```#^1`$`&0```%)%`0!R````;$4!`"````#?10$`-0````!&`0`A````
M-D8!`$4```!81@$`,````)Y&`0`H````ST8!`"D```#X1@$`)@```")'`0`E
M````24<!`"@```!O1P$`*````)A'`0`B````P4<!`"L```#D1P$`,````!!(
M`0`2````04@!`!,```!42`$`$````&A(`0!Y````>4@!``D```#S2`$`H0``
M`/U(`0!S````GTD!`'P````32@$`*P```)!*`0!4````O$H!`!<````12P$`
M)P```"E+`0`6````44L!``\```!H2P$`%P```'A+`0`?````D$L!`$````"P
M2P$`'P```/%+`0`<````$4P!`%$````N3`$`&@```(!,`0`4````FTP!``H`
M``"P3`$`!0```+M,`0`&````P4P!``@```#(3`$`!0```-%,`0`2````UTP!
M`!````#J3`$`$P```/M,`0`=````#TT!``\````M30$`#P```#U-`0`$````
M34T!``D```!230$`"P```%Q-`0`'````:$T!``4```!P30$`%````'9-`0`'
M````BTT!``@```"330$`#P```)Q-`0`(````K$T!``P```"U30$`#P```,)-
M`0`&````TDT!`!0```#930$`!@```.Y-`0`,````]4T!`!$````"3@$`"```
M`!1.`0`$````'4X!`!D````B3@$`$0```#Q.`0`*````3DX!`!@```!93@$`
M$P```').`0`<````ADX!`!$```"C3@$`!````+5.`0`/````NDX!``<```#*
M3@$`!````-).`0`9````UTX!``<```#Q3@$``@```/E.`0`"````_$X!`!$`
M``#_3@$`"0```!%/`0`&````&T\!`!(````B3P$`%P```#5/`0`&````34\!
M`"<```!43P$``@```'Q/`0`$````?T\!``\```"$3P$`$P```)1/`0`'````
MJ$\!``<```"P3P$`$0```+A/`0`&````RD\!`!@```#13P$`!@```.I/`0`3
M````\4\!`!`````%4`$`$@```!90`0`"````*5`!``8````L4`$`#````#-0
M`0`)````0%`!`!$```!*4`$`(@```%Q0`0`'````?U`!``<```"'4`$`"P``
M`(]0`0`%````FU`!``(```"A4`$`"P```*10`0"E`0``L%`!`!````!64@$`
M%0```&=2`0`-````?5(!``<```"+4@$`"0```)-2`0`(````G5(!``,```"F
M4@$`&````*I2`0`>````PU(!`"\```#B4@$`*P```!)3`0`I````/E,!`"T`
M``!H4P$`&0```)93`0`J````L%,!``H```#;4P$`'@```.93`0`2````!50!
M``H````85`$`%P```"-4`0`%````.U0!`"@```!!5`$`$@```&I4`0`.````
M?50!`!,```",5`$`#0```*!4`0`*````KE0!`)(```"Y5`$`$````$Q5`0`*
M````754!`!(```!H50$`#0```'M5`0`;````B54!``P```"E50$`#P```+)5
M`0`6````PE4!``8```#950$`F0```.!5`0`(````>E8!``T```"#5@$`&```
M`)%6`0`/````JE8!`!````"Z5@$`$````,M6`0`(````W%8!`!````#E5@$`
M/````/96`0`5````,U<!`$,```!)5P$`20```(U7`0!5````UU<!`$T````M
M6`$`<@```'M8`0!J````[E@!`$8```!960$`$````*!9`0`6````L5D!``X`
M``#(60$`$````-=9`0`2````Z%D!``4```#[60$`!@````%:`0`1````"%H!
M``@````:6@$`"0```"-:`0`)````+5H!`"4````W6@$`(P```%U:`0`0````
M@5H!``X```"26@$`$0```*%:`0`&````LUH!``D```"Z6@$`&P```,1:`0`A
M````X%H!``X````"6P$`%````!%;`0`8````)EL!`"4````_6P$`*@```&5;
M`0`:````D%L!`!````"K6P$`%P```+Q;`0`-````U%L!`#4```#B6P$`(P``
M`!A<`0`F````/%P!`!$```!C7`$`6````'5<`0`V````SEP!`"4````%70$`
M"````"M=`0`5````-%T!`#<```!*70$`#0```()=`0`(````D%T!``L```"9
M70$`!P```*5=`0`'````K5T!``<```"U70$`!P```+U=`0`,````Q5T!``4`
M``#270$`&P```-A=`0`,````]%T!`!`````!7@$`$@```!)>`0`<````)5X!
M`"\```!"7@$`"0```')>`0`6````?%X!`!8```"37@$`&````*I>`0`>````
MPUX!`!0```#B7@$`$@```/=>`0`/````"E\!`"$````:7P$`'0```#Q?`0`'
M````6E\!``8```!B7P$`"````&E?`0`-````<E\!``@```"`7P$`"0```(E?
M`0`2````DU\!``D```"F7P$`$P```+!?`0`8````Q%\!`"H```#=7P$`!P``
M``A@`0`2````$&`!``4````C8`$`%@```"E@`0`2````0&`!``\```!38`$`
M0@```&-@`0`Z````IF`!``D```#A8`$`!P```.M@`0`3````\V`!``0````'
M80$`!0````QA`0`-````$F$!``H````@80$`%P```"MA`0!#````0V$!`!4`
M``"'80$`)````)UA`0`K````PF$!`"H```#N80$`,````!EB`0`)````2F(!
M``8```!48@$`"0```%MB`0`'````96(!`#L```!M8@$`/0```*EB`0`Z````
MYV(!`%\````B8P$`.0```()C`0`Y````O&,!`$4```#V8P$`10```#QD`0`Y
M````@F0!`%(```"\9`$`*@````]E`0`L````.F4!`$D```!G90$`.0```+%E
M`0`_````ZV4!`"4````K9@$`%0```%%F`0`9````9V8!`"P```"!9@$`)@``
M`*YF`0`F````U68!`!,```#\9@$`"@```!!G`0`1````&V<!``4````M9P$`
M#````#-G`0`9````0&<!`!L```!:9P$`!P```'9G`0`'````?F<!`!4```"&
M9P$`"@```)QG`0`(````IV<!`#0```"P9P$`$````.5G`0`*````]F<!``<`
M```!:`$`!@````EH`0`%````$&@!``@````6:`$`!0```!]H`0`+````)6@!
M`#(````Q:`$`%@```&1H`0`-````>V@!``<```"):`$`!P```)%H`0`)````
MF6@!``4```"C:`$`$0```*EH`0`&````NV@!`!0```#":`$`!0```-=H`0`(
M````W6@!``8```#F:`$`"P```.UH`0`&````^6@!`"(`````:0$`!@```"-I
M`0`(````*FD!`!0````S:0$`#````$AI`0`'````56D!``,```!=:0$``P``
M`&%I`0`:````96D!`!H```"`:0$`+0```)MI`0`&````R6D!``4```#0:0$`
M"````-9I`0`(````WVD!`%H```#H:0$`(0```$-J`0`\````96H!`"P```"B
M:@$`(0```,]J`0`&````\6H!``@```#X:@$`'@````%K`0`F````(&L!`#$`
M``!':P$`-@```'EK`0`H````L&L!`"\```#9:P$`;0````EL`0`Z````=VP!
M``H```"R;`$`!@```+UL`0`)````Q&P!`!(```#.;`$`#````.%L`0`0````
M[FP!`!8```#_;`$`$0```!9M`0`6````*&T!`!8````_;0$`$````%9M`0`5
M````9VT!``8```!];0$`&P```(1M`0`;````H&T!`!<```"\;0$`&P```-1M
M`0`8````\&T!``8````);@$`!P```!!N`0`0````&&X!`%P````I;@$`8```
M`(9N`0`$````YVX!`!(```#L;@$`!0```/]N`0`%````!6\!`!P````+;P$`
M&0```"AO`0`4````0F\!`!$```!7;P$`$@```&EO`0`:````?&\!`#H```"7
M;P$`#P```-)O`0`O````XF\!``8````2<`$`%````!EP`0`/````+G`!`!,`
M```^<`$`#P```%)P`0`8````8G`!`!(```![<`$`%0```(YP`0`3````I'`!
M``T```"X<`$`!@```,9P`0`2````S7`!``<```#@<`$`#@```.AP`0`6````
M]W`!``\````.<0$`"````!YQ`0`#````)W$!`!`````K<0$`#@```#QQ`0`%
M````2W$!`!,```!1<0$`"@```&5Q`0`'````<'$!`!````!X<0$`"````(EQ
M`0`$````DG$!``<```"7<0$`!P```)]Q`0`,````IW$!``@```"T<0$`"0``
M`+UQ`0`:````QW$!`#X```#B<0$`)@```"%R`0`-````2'(!`!````!6<@$`
M!0```&=R`0`?````;7(!`!$```"-<@$`$@```)]R`0`R````LG(!`$(```#E
M<@$`(0```"AS`0`(````2G,!`$<```!3<P$`*````)MS`0`0````Q',!``D`
M``#5<P$`"@```-]S`0`&````ZG,!``8```#Q<P$`$@```/AS`0`.````"W0!
M``L````:=`$`"@```"9T`0`/````,70!`"P```!!=`$`)P```&YT`0`T````
MEG0!`"\```#+=`$`)@```/MT`0`K````(G4!`"8```!.=0$`)0```'5U`0`]
M````FW4!`#(```#9=0$`*0````QV`0`O````-G8!`"8```!F=@$`-````(UV
M`0!&````PG8!`$$````)=P$`/0```$MW`0`]````B7<!`$<```#'=P$`+```
M``]X`0`H````/'@!`$8```!E>`$`*@```*QX`0`:````UW@!`#4```#R>`$`
M*````"AY`0`L````47D!`!@```!^>0$`R0```)=Y`0`<````87H!`#(```!^
M>@$`,@```+%Z`0`T````Y'H!`#$````9>P$`*0```$M[`0`J````=7L!`"H`
M``"@>P$`,@```,M[`0`U````_GL!`$D````T?`$`.P```'Y\`0"I````NGP!
M`"P```!D?0$`)0```)%]`0`H````MWT!`#8```#@?0$`,@```!=^`0!9````
M2GX!`$X```"D?@$`#0```/-^`0`$`````7\!``8````&?P$`!0````U_`0`-
M````$W\!``X````A?P$`$````#!_`0`5````07\!`!L```!7?P$`!P```'-_
M`0`$````>W\!``X```"`?P$`#@```(]_`0`*````GG\!``T```"I?P$`$P``
M`+=_`0`+````RW\!`!````#7?P$`#````.A_`0`V````]7\!``8````L@`$`
M#@```#.``0`&````0H`!`!$```!)@`$`%P```%N``0`;````<X`!`!````"/
M@`$``@```*"``0!*````HX`!``L```#N@`$`%0```/J``0`:````$($!``0`
M```K@0$`$P```#"!`0`/````1($!``,```!4@0$`#P```%B!`0`(````:($!
M`!````!Q@0$`$````(*!`0`&````DX$!``H```":@0$`$0```*6!`0`,````
MMX$!``H```#$@0$`!P```,^!`0`.````UX$!``T```#F@0$`"P```/2!`0`1
M`````((!`!H````2@@$`#@```"V"`0`.````/((!`",```!+@@$`'````&^"
M`0`\````C((!``T```#)@@$`'@```->"`0`6````]H(!`!4````-@P$`-```
M`".#`0`/````6(,!``D```!H@P$`$P```'*#`0`)````AH,!`#4```"0@P$`
M-P```,:#`0`/````_H,!`!`````.A`$`)0```!^$`0`2````180!`"````!8
MA`$`(````'F$`0`)````FH0!`!L```"DA`$`$@```,"$`0`9````TX0!`!4`
M``#MA`$`#@````.%`0`9````$H4!``<````LA0$`"P```#2%`0`F````0(4!
M`$@```!GA0$`"@```+"%`0`4````NX4!`!\```#0A0$`!@```/"%`0`)````
M]X4!`#`````!A@$`$````#*&`0`&````0X8!``<```!*A@$`5````%*&`0`#
M````IX8!``<```"KA@$`!@```+.&`0`,````NH8!``P```#'A@$`$````-2&
M`0`1````Y88!`!D```#WA@$`$0```!&'`0`9````(X<!`!D````]AP$`"```
M`%>'`0`%````8(<!``L```!FAP$`"P```'*'`0`"````?H<!``8```"!AP$`
M$@```(B'`0`G````FX<!`!@```##AP$`&0```-R'`0`)````]H<!`!,`````
MB`$`%````!2(`0`<````*8@!`$8```!&B`$`+P```(V(`0`,````O8@!``\`
M``#*B`$`B@```-J(`0`<````98D!`!@```""B0$`$````)N)`0`(````K(D!
M``0```"UB0$`%P```+J)`0`K````THD!`"@```#^B0$`&@```">*`0`=````
M0HH!`!$```!@B@$`$P```'**`0`'````AHH!``<```".B@$`!@```):*`0`&
M````G8H!``\```"DB@$`#@```+2*`0`0````PXH!``X```#4B@$`#````..*
M`0`.````\(H!``L```#_B@$`$P````N+`0`(````'XL!``@````HBP$`%@``
M`#&+`0`,````2(L!`#4```!5BP$`$0```(N+`0`(````G8L!`!4```"FBP$`
M)0```+R+`0`;````XHL!`",```#^BP$`(@```"*,`0`8````18P!`!H```!>
MC`$`)0```'F,`0`9````GXP!`!(```"YC`$`!0```,R,`0`9````THP!``L`
M``#LC`$`"P```/B,`0`#````!(T!``4````(C0$`"0````Z-`0`0````&(T!
M`!(````IC0$`$0```#R-`0`*````3HT!``\```!9C0$`#@```&F-`0`,````
M>(T!``0```"%C0$`!P```(J-`0`@````DHT!`"$```"SC0$`%P```-6-`0`/
M````[8T!`!(```#]C0$`$````!".`0`B````(8X!``<```!$C@$`"0```$R.
M`0`/````5HX!``\```!FC@$`"0```':.`0`%````@(X!``H```"&C@$`!0``
M`)&.`0`3````EXX!``P```"KC@$`!@```+B.`0`I````OXX!``X```#IC@$`
M@P```/B.`0`1````?(\!``L```".CP$`!0```)J/`0`-````H(\!``8```"N
MCP$`"````+6/`0`&````OH\!`!$```#%CP$``P```->/`0`'````VX\!``8`
M``#CCP$`%````.J/`0`/````_X\!`!(````/D`$`'````"*0`0`"````/Y`!
M``4```!"D`$`$@```$B0`0`)````6Y`!``T```!ED`$`!0```'.0`0`@````
M>9`!``@```":D`$`!@```*.0`0`:````JI`!``T```#%D`$`!P```-.0`0`(
M````VY`!``0```#DD`$`"0```.F0`0`-````\Y`!``X````!D0$``@```!"1
M`0`&````$Y$!``P````:D0$`$P```">1`0`0````.Y$!``8```!,D0$`$@``
M`%.1`0`*````9I$!``<```!QD0$`%P```'F1`0`I````D9$!`$H```"[D0$`
M)P````:2`0`I````+I(!``8```!8D@$`"0```%^2`0`$````:9(!``D```!N
MD@$`"````'B2`0`7````@9(!`!````"9D@$`!0```*J2`0`,````L)(!``8`
M``"]D@$`!````,22`0!!````R9(!`$(````+DP$`00```$Z3`0`A````D),!
M``4```"RDP$`#@```+B3`0`'````QY,!``D```#/DP$`"0```-F3`0`;````
MXY,!`!````#_DP$`%0```!"4`0`&````)I0!``4````ME`$`#P```#.4`0`*
M````0Y0!``H```!.E`$`'@```%F4`0`$````>)0!``<```!]E`$`)````(64
M`0`&````JI0!`!0```"QE`$`$0```,:4`0`0````V)0!``@```#IE`$`"0``
M`/*4`0`%````_)0!`#L````"E0$`-@```#Z5`0!#````=94!`"D```"YE0$`
M0@```..5`0!"````)I8!`"L```!IE@$`2@```)66`0`O````X)8!`#D````0
MEP$`+P```$J7`0`0````>I<!`!$```"+EP$`"P```)V7`0`M````J9<!`"D`
M``#7EP$`(0````&8`0`H````(Y@!``<```!,F`$`"0```%28`0`*````7I@!
M``<```!IF`$`)````'&8`0`F````EI@!`"T```"]F`$`"P```.N8`0`;````
M]Y@!`"T````3F0$`&````$&9`0`3````6ID!``@```!NF0$`#@```'>9`0`.
M````AID!``X```"5F0$`$P```*29`0!$````N)D!`'X```#]F0$`<0```'R:
M`0`;````[IH!``T````*FP$`#@```!B;`0`1````)YL!`!(````YFP$`#P``
M`$R;`0`'````7)L!`!(```!DFP$`$P```'>;`0`2````BYL!`!,```">FP$`
M*````+*;`0`>````VYL!`(0```#ZFP$`$@```'^<`0`%````DIP!`!0```"8
MG`$`"0```*V<`0`*````MYP!``H```#"G`$`'P```,V<`0`4````[9P!``X`
M```"G0$`#@```!&=`0`3````()T!`!4````TG0$`)````$J=`0`F````;YT!
M`",```"6G0$`)0```+J=`0`A````X)T!`",````"G@$`'0```":>`0!%````
M1)X!`!,```"*G@$`%````)Z>`0`3````LYX!`!0```#'G@$`$0```-R>`0`6
M````[IX!`!<````%GP$`$@```!V?`0`3````,)\!`#P```!$GP$`%@```(&?
M`0`4````F)\!`#X```"MGP$`%0```.R?`0`.`````J`!`!$````1H`$`+0``
M`".@`0`3````4:`!`!,```!EH`$`(````'F@`0`=````FJ`!`!\```"XH`$`
M'0```-B@`0`;````]J`!`"$````2H0$`'````#2A`0`C````4:$!`"$```!U
MH0$`(````)>A`0`@````N*$!`!T```#9H0$`$P```/>A`0`;````"Z(!`!T`
M```GH@$`&P```$6B`0`8````8:(!``H```!ZH@$`$````(6B`0`:````EJ(!
M``8```"QH@$`!P```+BB`0`-````P*(!`!0```#.H@$`!@```..B`0`'````
MZJ(!``<```#RH@$`!@```/JB`0`'`````:,!``<````)HP$`!0```!&C`0`5
M````%Z,!``8````MHP$`"````#2C`0`%````/:,!``4```!#HP$`"@```$FC
M`0`1````5*,!``H```!FHP$`$@```'&C`0`1````A*,!``L```"6HP$`$@``
M`**C`0`&````M:,!`"H```"\HP$`$0```.>C`0`0````^:,!`!H````*I`$`
M$````"6D`0`-````-J0!``P```!$I`$`+P```%&D`0`(````@:0!``@```"*
MI`$`*````).D`0`4````O*0!`!````#1I`$`!@```.*D`0`+````Z:0!``<`
M``#UI`$`!@```/VD`0`A````!*4!``T````FI0$`$````#2E`0`-````1:4!
M`!,```!3I0$`$````&>E`0`?````>*4!`!,```"8I0$`!P```*RE`0`#````
MM*4!``8```"XI0$`'P```+^E`0`&````WZ4!``@```#FI0$`$@```.^E`0`3
M`````J8!``8````6I@$`!````!VF`0`'````(J8!`!8````JI@$`#0```$&F
M`0`-````3Z8!``L```!=I@$`%````&FF`0`6````?J8!`!<```"5I@$`&0``
M`*VF`0`*````QZ8!``T```#2I@$`!@```."F`0`$````YZ8!`!$```#LI@$`
M.P```/ZF`0`%````.J<!``\```!`IP$`(0```%"G`0`6````<J<!`!<```")
MIP$`#@```*&G`0`,````L*<!``D```"]IP$`!P```,>G`0`*````SZ<!``D`
M``#:IP$`#@```.2G`0`0````\Z<!`"`````$J`$`(0```"6H`0`G````1Z@!
M``H```!OJ`$`"````'JH`0`-````@Z@!``P```"1J`$`$@```)ZH`0`&````
ML:@!``@```"XJ`$`)P```,&H`0`+````Z:@!``@```#UJ`$`$@```/ZH`0`\
M````$:D!``\```!.J0$`"P```%ZI`0`$````:JD!``4```!OJ0$`&P```'6I
M`0`<````D:D!`!P```"NJ0$`"@```,NI`0`"````UJD!``0```#9J0$`(0``
M`-ZI`0`#`````*H!``4````$J@$`*0````JJ`0`*````-*H!``8````_J@$`
M!P```$:J`0`8````3JH!``X```!GJ@$`!@```':J`0`'````?:H!``@```"%
MJ@$`!````(ZJ`0`%````DZH!`#P```"9J@$`$````-:J`0`3````YZH!`!4`
M``#[J@$`!0```!&K`0`&````%ZL!`!X````>JP$`,P```#VK`0`.````<:L!
M``D```"`JP$`%@```(JK`0`*````H:L!``@```"LJP$`&0```+6K`0`L````
MSZL!`"D```#\JP$`*````":L`0`A````3ZP!``X```!QK`$`!````("L`0`'
M````A:P!``@```"-K`$`!P```):L`0`-````GJP!``\```"LK`$`"````+RL
M`0!7````Q:P!`!(````=K0$`$````#"M`0`+````0:T!`!L```!-K0$`4```
M`&FM`0`=````NJT!``8```#8K0$`'0```-^M`0`G````_:T!``<````EK@$`
M!@```"VN`0`@````-*X!``0```!5K@$`"0```%JN`0`I````9*X!`"@```".
MK@$`)P```+>N`0`'````WZX!``@```#GK@$`(@```/"N`0!9````$Z\!`!@`
M``!MKP$`)@```(:O`0`6````K:\!``,```#$KP$`#0```,BO`0`'````UJ\!
M``\```#>KP$`"P```.ZO`0`&````^J\!`!4````!L`$`!@```!>P`0`(````
M'K`!``D````GL`$`"P```#&P`0`*````/;`!``P```!(L`$`/0```%6P`0`(
M````D[`!`!(```"<L`$`%````*^P`0`7````Q+`!``P```#<L`$`$````.FP
M`0`/````^K`!``L````*L0$`!@```!:Q`0`%````';$!``H````CL0$`)0``
M`"ZQ`0`7````5+$!`!````!LL0$`"P```'VQ`0`0````B;$!``H```":L0$`
M%````*6Q`0`(````NK$!`!0```##L0$`!````-BQ`0`'````W;$!``4```#E
ML0$`!0```.NQ`0`'````\;$!`!,```#YL0$`%`````VR`0`B````(K(!`"(`
M``!%L@$`'````&BR`0`<````A;(!`"````"BL@$`)0```,.R`0`?````Z;(!
M``0````)LP$`!0````ZS`0`.````%+,!``X````CLP$`%0```#*S`0`(````
M2+,!`!<```!1LP$`#0```&FS`0`*````=[,!`!H```""LP$`'P```)VS`0`4
M````O;,!``@```#2LP$`$@```-NS`0`'````[K,!`!````#VLP$`#P````>T
M`0`(````%[0!``D````@M`$`!0```"JT`0`'````,+0!``4````XM`$`!```
M`#ZT`0`#````0[0!`$$```!'M`$`-0```(FT`0`7````O[0!`"D```#7M`$`
M.0````&U`0`2````.[4!`#@```!.M0$`.````(>U`0`]````P+4!`#T```#^
MM0$`0@```#RV`0`8````?[8!`!D```"8M@$`%@```+*V`0`8````R;8!`"``
M``#BM@$`(`````.W`0`;````)+<!`!D```!`MP$`&P```%JW`0`4````=K<!
M`#$```"+MP$`,0```+VW`0`U````[[<!`#(````EN`$`,P```%BX`0`P````
MC+@!`'<```"]N`$`&0```#6Y`0`6````3[D!``H```!FN0$`(@```'&Y`0`)
M````E+D!`!,```">N0$`-````+*Y`0`E````Y[D!`"`````-N@$`"P```"ZZ
M`0!1````.KH!`$T```",N@$`!P```-JZ`0`7````XKH!`!4```#ZN@$`#```
M`!"[`0`0````';L!`!8````NNP$`!P```$6[`0`(````3;L!``D```!6NP$`
M$@```&"[`0`1````<[L!``\```"%NP$`#@```)6[`0`)````I+L!`!@```"N
MNP$`"````,>[`0`&````T+L!`!0```#7NP$`$0```.R[`0`0````_KL!`$(`
M```/O`$``@```%*\`0`&````5;P!`!$```!<O`$`!0```&Z\`0`'````=+P!
M``\```!\O`$`"@```(R\`0`J````E[P!``P```#"O`$`'@```,^\`0`#````
M[KP!`#<```#RO`$`&````"J]`0`H````0[T!`(8```!LO0$`&````/.]`0!!
M````#+X!`"$```!.O@$`$P```'"^`0`&````A+X!``P```"+O@$`#@```)B^
M`0`+````I[X!`!8```"SO@$`"P```,J^`0`<````UKX!`!8```#SO@$`!0``
M``J_`0`2````$+\!`!H````COP$`)0```#Z_`0`3````9+\!`!8```!XOP$`
M'````(^_`0`1````K+\!`"8```"^OP$`"@```.6_`0`4````\+\!`!8````%
MP`$`$````!S``0`2````+<`!``\```!`P`$`$@```%#``0`/````8\`!`!4`
M``!SP`$`'@```(G``0`5````J,`!``8```"^P`$`"0```,7``0`%````S\`!
M`!T```#5P`$`!@```//``0`0````^L`!``@````+P0$`%````!3!`0`%````
M*<$!`!L````OP0$`#P```$O!`0`M````6\$!`!4```")P0$`!@```)_!`0`'
M````IL$!`!@```"NP0$`!0```,?!`0`>````S<$!``0```#LP0$`%````/'!
M`0`'````!L(!``L````.P@$`(````!K"`0`M````.\(!``D```!IP@$`'```
M`'/"`0`0````D,(!``H```"AP@$`&P```*S"`0`4````R,(!``0```#=P@$`
M%````.+"`0`)````]\(!``@````!PP$`!0````K#`0`(````$,,!``8````9
MPP$`!@```"##`0`A````)\,!`#<```!)PP$`/P```('#`0`B````P<,!`#``
M``#DPP$`*````!7$`0!%````/L0!`"(```"$Q`$`*````*?$`0`E````T,0!
M`%4```#VQ`$`*@```$S%`0`'````=\4!``@```!_Q0$`!P```(C%`0`(````
MD,4!`!0```"9Q0$`%````*[%`0`P````P\4!`"T```#TQ0$`&````"+&`0`U
M````.\8!`#T```!QQ@$`!P```*_&`0`9````M\8!``D```#1Q@$`$````-O&
M`0`B````[,8!`!$````/QP$`$@```"''`0`-````-,<!``@```!"QP$`%0``
M`$O'`0`(````8<<!``L```!JQP$`#0```';'`0`:````A,<!``T```"?QP$`
M/````*W'`0`*````ZL<!``4```#UQP$`"0```/O'`0`%````!<@!`!H````+
MR`$`$0```";(`0`%````.,@!``X````^R`$`$````$W(`0`1````7L@!``P`
M``!PR`$`#P```'W(`0`/````C<@!``<```"=R`$``P```*7(`0`-````J<@!
M`#H```"WR`$`3@```/+(`0`5````0<D!``D```!7R0$`)@```&')`0`=````
MB,D!``4```"FR0$`%0```*S)`0`#````PLD!``L```#&R0$`$@```-+)`0`J
M````Y<D!``<````0R@$`#0```!C*`0`.````)LH!`!(````UR@$`"P```$C*
M`0`[````5,H!``D```"0R@$`'````)K*`0`/````M\H!`!,```#'R@$`/P``
M`-O*`0`N````&\L!`#D```!*RP$`.@```(3+`0`V````O\L!`!$```#VRP$`
M!@````C,`0`0````#\P!`!`````@S`$`#0```#',`0`*````/\P!`!$```!*
MS`$`'0```%S,`0`'````>LP!`!4```""S`$`&@```)C,`0`(````L\P!``<`
M``"\S`$`$0```,3,`0`2````ULP!`!D```#IS`$`!@````/-`0`'````"LT!
M``\````2S0$`%0```"+-`0`4````.,T!`!4```!-S0$`%0```&/-`0`'````
M><T!``8```"!S0$`,0```(C-`0`G````NLT!`"8```#BS0$`"`````G.`0`/
M````$LX!``8````BS@$`'P```"G.`0`A````2<X!`"8```!KS@$`"P```)+.
M`0`4````GLX!`"8```"SS@$``P```-K.`0`'````WLX!`!4```#FS@$``P``
M`/S.`0`,`````,\!`!$````-SP$`"P```!_/`0`4````*\\!`!@```!`SP$`
M%````%G/`0`%````;L\!``H```!TSP$`$P```'_/`0`4````D\\!``X```"H
MSP$`!@```+?/`0`)````OL\!``D```#(SP$`#0```-+/`0!:````X,\!`!8`
M```[T`$`-0```%+0`0`4````B-`!``<```"=T`$`"0```*70`0`4````K]`!
M`!4```#$T`$`$@```-K0`0`A````[=`!`!@````/T0$`%0```"C1`0`C````
M/M$!`!````!BT0$`)P```'/1`0`3````F]$!`!4```"OT0$`<````,71`0`A
M````-M(!`!P```!8T@$`+0```'72`0`A````H](!`!P```#%T@$`)@```.+2
M`0`?````"=,!`!\````ITP$`'````$G3`0`*````9M,!``<```!QTP$`"```
M`'G3`0`(````@M,!`!,```"+TP$`#P```)_3`0`M````K],!`!<```#=TP$`
M%0```/73`0`'````"]0!``<````3U`$`3P```!O4`0!)````:]0!`#X```"U
MU`$`9@```/34`0`,````6]4!`#(```!HU0$`,````)O5`0`)````S-4!``<`
M``#6U0$`!@```-[5`0!`````Y=4!``8````FU@$`0````"W6`0`T````;M8!
M`",```"CU@$`#@```,?6`0`M````UM8!`!P````$UP$`,P```"'7`0`H````
M5=<!`#(```!^UP$`*````+'7`0`-````VM<!``8```#HUP$`#P```._7`0`2
M````_]<!`!4````2V`$`!P```"C8`0!"````,-@!``H```!SV`$`"0```'[8
M`0`*````B-@!`!<```"3V`$`"0```*O8`0`'````M=@!`!(```"]V`$`"@``
M`-#8`0`)````V]@!``0```#EV`$`!P```.K8`0`(````\M@!``\```#[V`$`
M%`````O9`0`6````(-D!`!T````WV0$`#0```%79`0`'````8]D!`!````!K
MV0$`#P```'S9`0`2````C-D!``T```"?V0$`&````*W9`0`H````QMD!``X`
M``#OV0$`'P```/[9`0`I````'MH!``D```!(V@$`"P```%+:`0`4````7MH!
M``<```!SV@$`!````'O:`0`?````@-H!``X```"@V@$`#@```*_:`0`-````
MOMH!``@```#,V@$`"0```-7:`0`&````W]H!``D```#FV@$`"P```/#:`0`3
M````_-H!``@````0VP$`&````!G;`0`+````,ML!``<````^VP$`'@```$;;
M`0`F````9=L!``P```",VP$``P```)G;`0`A````G=L!``<```"_VP$`!@``
M`,?;`0!T````SML!``H```!#W`$`!P```$[<`0`G````5MP!`$````!^W`$`
M&@```+_<`0`E````VMP!`$0`````W0$`*0```$7=`0`]````;]T!`!L```"M
MW0$`%@```,G=`0`%````X-T!``8```#FW0$`"0```.W=`0`*````]]T!``H`
M```"W@$`"0````W>`0`4````%]X!``L````LW@$`"@```#C>`0`,````0]X!
M``P```!0W@$`!P```%W>`0`(````9=X!``D```!NW@$`%````'C>`0`+````
MC=X!``8```"9W@$`!0```*#>`0`+````IMX!``8```"RW@$`)@```+G>`0`8
M````X-X!``H```#YW@$`%@````3?`0`+````&]\!`!0````GWP$`"P```#S?
M`0`&````2-\!`!8```!/WP$`!@```&;?`0`6````;=\!``8```"$WP$`&@``
M`(O?`0`+````IM\!`!8```"RWP$`!0```,G?`0`'````S]\!`!(```#7WP$`
M(````.K?`0`+````"^`!``T````7X`$`+0```"7@`0`;````4^`!`!@```!O
MX`$`!0```(C@`0`-````CN`!`!0```"<X`$`%P```+'@`0`#````R>`!`!,`
M``#-X`$`"0```.'@`0`C````Z^`!`"D````/X0$`,P```#GA`0`E````;>$!
M`#0```"3X0$`)P```,CA`0!I````\.$!`!<```!:X@$`9P```'+B`0!"````
MVN(!`%0````=XP$`;@```'+C`0`M````X>,!`#L````/Y`$`,P```$OD`0`X
M````?^0!`"X```"XY`$`&P```.?D`0`T`````^4!`-<!```XY0$`'P```!#G
M`0`7````,.<!`$H```!(YP$`=P```)/G`0`S````"^@!`"4````_Z`$`00``
M`&7H`0!<````I^@!`%H````$Z0$`*@```%_I`0`C````BND!`!8```"NZ0$`
M*````,7I`0`=````[ND!`!H````,Z@$`+0```"?J`0`E````5>H!`"4```![
MZ@$`.@```*'J`0`C````W.H!`!8`````ZP$`.````!?K`0`E````4.L!`"H`
M``!VZP$`+0```*'K`0`?````S^L!`#@```#OZP$`;0```"CL`0`Q````ENP!
M`$(```#([`$`+@````OM`0`G````.NT!`$````!B[0$`8P```*/M`0!(````
M!^X!`"X```!0[@$`+@```'_N`0`P````KNX!`%\```#?[@$`;P```#_O`0!8
M````K^\!`%D````(\`$`-0```&+P`0`J````F/`!`"H```##\`$`+P```.[P
M`0!K````'O$!`'$```"*\0$`<0```/SQ`0"Y````;O(!`!D````H\P$`+P``
M`$+S`0`P````<O,!`"T```"C\P$`4@```-'S`0`E````)/0!`%,```!*]`$`
M(@```)[T`0`*````P?0!`-@```#,]`$`6````*7U`0`C````_O4!`#@````B
M]@$`*````%OV`0`>````A/8!`#D```"C]@$`!````-WV`0`(````XO8!``0`
M``#K]@$`&0```/#V`0`/````"O<!``\````:]P$`"P```"KW`0`&````-O<!
M``\````]]P$`!````$WW`0!8````4O<!``0```"K]P$`%P```+#W`0`$````
MR/<!``<```#-]P$`!@```-7W`0`%````W/<!``0```#B]P$`%0```.?W`0`)
M````_?<!`!$````'^`$`$P```!GX`0`#````+?@!``<````Q^`$`!P```#GX
M`0`2````0?@!``T```!4^`$`%````&+X`0`&````=_@!`!H```!^^`$`#0``
M`)GX`0`#````I_@!`"L```"K^`$`!````-?X`0`&````W/@!``<```#C^`$`
M(0```.OX`0!`````#?D!`#$```!.^0$`,@```(#Y`0`;````L_D!`#(```#/
M^0$`-0````+Z`0`D````./H!`",```!=^@$`'@```('Z`0`D````H/H!`!\`
M``#%^@$`'0```.7Z`0`E`````_L!`",````I^P$`'@```$W[`0`T````;/L!
M`!P```"A^P$`,0```+[[`0`R````\/L!`"$````C_`$`)0```$7\`0`D````
M:_P!`!\```"0_`$`)````+#\`0`J````U?P!`"@`````_0$`*@```"G]`0`F
M````5/T!`!\```![_0$`(@```)O]`0`K````OOT!`!T```#J_0$`)`````C^
M`0`O````+?X!`#(```!=_@$`&@```)#^`0`G````J_X!`#P```#3_@$`)```
M`!#_`0`F````-?\!`"4```!<_P$`)@```(+_`0`@````J?\!`!X```#*_P$`
M)P```.G_`0`C````$0`"`"X````U``(`)P```&0``@`N````C``"``H```"[
M``(`$P```,8``@`6````V@`"`#,```#Q``(`)@```"4!`@`-````3`$"``\`
M``!:`0(`%@```&H!`@`+````@0$"``X```"-`0(`+````)P!`@`(````R0$"
M``P```#2`0(`)P```-\!`@`J````!P("`"`````R`@(`'P```%,"`@`<````
M<P("``@```"0`@(`U````)D"`@`-````;@,"`!8```!\`P(`"0```),#`@`-
M````G0,"`!$```"K`P(`$````+T#`@`?````S@,"``8```#N`P(`2P```/4#
M`@`<````000"`!P```!>!`(`!P```'L$`@`2````@P0"``P```"6!`(`-@``
M`*,$`@`(````V@0"`"<```#C!`(`&0````L%`@`2````)04"`!0````X!0(`
M,@```$T%`@`?````@`4"``<```"@!0(`%P```*@%`@`(````P`4"``D```#)
M!0(`%````-,%`@`+````Z`4"`!L```#T!0(`!@```!`&`@`J````%P8"``@`
M``!"!@(`(P```$L&`@`K````;P8"``<```";!@(`%P```*,&`@`'````NP8"
M``@```##!@(`"0```,P&`@`^````U@8"``8````5!P(`$@```!P'`@`4````
M+P<"``\```!$!P(`"0```%0'`@`*````7@<"``8```!I!P(`$P```'`'`@`&
M````A`<"`"$```"+!P(`$@```*T'`@`9````P`<"`!4```#:!P(`#````/`'
M`@`.````_0<"`!H````,"`(`!P```"<(`@`M````+P@"``P```!="`(`#P``
M`&H(`@`'````>@@"``,```"""`(`$0```(8(`@`<````F`@"``L```"U"`(`
M`P```,$(`@`(````Q0@"``P```#."`(`"0```-L(`@`/````Y0@"``T```#U
M"`(`%@````,)`@`7````&@D"`!`````R"0(`+P```$,)`@`=````<PD"`!P`
M``"1"0(`&@```*X)`@`+````R0D"`#````#5"0(`!P````8*`@`7````#@H"
M`$4````F"@(`$0```&P*`@`2````?@H"``@```"1"@(`!````)H*`@`%````
MGPH"`!$```"E"@(`&@```+<*`@`&````T@H"``<```#9"@(`"0```.$*`@`0
M````ZPH"``@```#\"@(`$@````4+`@`.````&`L"`$4````G"P(`-@```&T+
M`@`I````I`L"``4```#."P(`&0```-0+`@`D````[@L"`"(````3#`(`*```
M`#8,`@`0````7PP"``(```!P#`(`!````',,`@`+````>`P"``H```"$#`(`
M!0```(\,`@`#````E0P"`!````"9#`(`3P```*H,`@`S````^@P"`!H````N
M#0(`*P```$D-`@`O````=0T"`%,```"E#0(`%@```/D-`@"%````$`X"`"0`
M``"6#@(`0@```+L.`@`E````_@X"`$<````D#P(`*P```&P/`@`S````F`\"
M`"X```#,#P(`+@```/L/`@`P````*A`"`#````!;$`(`+0```(P0`@`R````
MNA`"`#0```#M$`(`-P```"(1`@`6````6A$"`"````!Q$0(`$````)(1`@!\
M````HQ$"``@````@$@(`<````"D2`@!R````FA("`(`````-$P(`)@```(X3
M`@!>````M1,"`!<````4%`(`(P```"P4`@`6````4!0"`!(```!G%`(`%```
M`'H4`@`<````CQ0"`$````"L%`(`'@```.T4`@`9````#!4"`%`````F%0(`
M$@```'<5`@`8````BA4"``H```"C%0(`!0```*X5`@`&````M!4"``@```"[
M%0(`!0```,05`@`6````RA4"`!<```#A%0(`%@```/D5`@`A````$!8"`!``
M```R%@(`#@```$,6`@`$````4A8"``D```!7%@(`#P```&$6`@`'````<18"
M``8```!Y%@(`&@```(`6`@`)````FQ8"``P```"E%@(`$````+(6`@`'````
MPQ8"``L```#+%@(`$````-<6`@`+````Z!8"`!H```#T%@(`"0````\7`@`5
M````&1<"`!4````O%P(`!@```$47`@`%````3!<"`",```!2%P(`&0```'87
M`@`+````D!<"`",```"<%P(`%````,`7`@`K````U1<"`!D````!&`(`!@``
M`!L8`@`7````(A@"``4````Z&`(`!P```$`8`@`;````2!@"``4```!D&`(`
M`@```&H8`@`"````;1@"`!L```!P&`(`"````(P8`@`+````E1@"`!4```"A
M&`(`&````+<8`@`'````T!@"`#,```#8&`(``@````P9`@`$````#QD"`!``
M```4&0(`%@```"49`@`.````/!D"``L```!+&0(`"0```%<9`@`&````81D"
M`!@```!H&0(`"````($9`@`4````BAD"`!$```"?&0(`$@```+$9`@`"````
MQ!D"``<```#'&0(`#P```,\9`@`0````WQD"`!````#P&0(`+`````$:`@`)
M````+AH"``@````X&@(`$@```$$:`@`%````5!H"``(```!:&@(`"P```%T:
M`@`!````T`0``!H$```N!0``70,```````"<`0``:P(``)X$````````D@,`
M`,4!``#X!@``?```````````````A`(``"8'```+`0```````'X'``#!````
M=`4``!,$``#N!0``+````-@#``"^!@``(`<```8"``#_`P``N04``/\&```O
M`P```````*0"``#M!0``8@(``+`"```-!```?P,`````````````````````
M``#3!```3@4``(,$`````````````/0!``!N`@````````````!]`@``+`0`
M```````C`0``H04```````!?!P``X04``(P&```E`0``;08``/($``!L`@``
M<`$``#`'``#``0``SP(``"T$``!M`P``2P<``%H```"B`0``,P$``(8'````
M````>P$``.L```"3!@``O04``%D'``!'!0``R08```````"2!```8`(``/(`
M```G`@``9`(```````#8!```@08``-L%`````````````*4`````````````
M``````"6`P```````$````#A!@```````,L!````````RP4``$8"``"\!0``
M`````/L"``"%!P````````D%````````300``,D%``#J`@``(P4``!<`````
M````-````%@```"[`0````````````"S`@``6`0``&,#``!H`P``7P$`````
M``````````````````#X`0``8@,``&\```#4`0```````'H&````````!0<`
M`)``````````2P,``)D"````````&@,``%H&``#R`0``WP```"8#``#:`0``
MS@$``+0#``!%`P```````!@'```.!P``(P,``/$```"M!0``SP0`````````
M````J0,``*0`````````R`4``%\#``!W`P``DP0```@$````````AP8``+X!
M````````W@0``'4'``#6`P``Y0$```````#\!0``1P<``*D!``!6!```X@$`
M``````!/````FP0``````````````````"T#``!I!P```````+(`````````
ME04``&4$``"A!@``X`$``*X&````````*@```/D!``!H`0``40<``-<#```F
M!@``H00``%$&``!4!```K`8```````";`@``6P```(\&``")`P``J0``````
M``"I!0``TP```)X#``!Z`0``90(``,`#```E!P``>0,``"L`````````-@``
M````````````+P(``(,```#A!````````/,$``!W!```00<```````#W````
M``````````"1`@``MP4````````4!0``J`,``"D"``!W!P```````'($```Y
M`@````````````".`@``C@$``(@$``#<````>0<``%0%``"8`P```0(``#@'
M``!<`P``!@$```````!#!````````"H'``"=`P``I0$`````````````9`4`
M`'$!`````````````$`&``#;````.@<``$H```````````(````````I`0``
M`````%0#````````F@0```````#*`0``7P0``!0#````````)00``&$`````
M`````````",$``!W````ZP,``&,&````````F08``/T%``![`````````!8&
M``"O!````P`````'``#:!0``M`8``,<#``!Z`@``$P<``.P`````````````
M`&,!````````[`(``)H```"2````G`,```````";`0``*`4``&\"``#P`P``
M1`,``+P"``"Y`0``V@0``-,&``"R`P``X`0``,<$``"H!````````!4'```5
M`@``O00``!@!``"O`@````````````#?`P``C0(```````!^`0``^P4``&D!
M```4!@``]@$``"@#``!)`P``<`,``$4$``"6`0``1P```,8!``!O`P``2P8`
M`#H```!=!@``4P```-(&``!T`@```````"L%```D`@``<`8``.T````(!@``
M!````.("``!\`P``@`4``(D!``"1!```_`(``&$'``#D!0``%P$```````"?
M`0``"@<``'D"``!^`````P0```8'```K!@``,@8```````!0`@``OP``````
M``!U`P``_0,````````+````,`4`````````````8P<``"4&``#=````````
M`/("```\!P```````-4#``#7!`````````````!H````"P(``&\&````````
MT`8``,(&``!Q````H````/D&``!``@```````)D$``"W`P``P`````($```,
M!@``3`$``)("``"V!0``H`$``+\!````````!0````````!)!P``U`(``&,`
M````````Q````````````````````.\$````````/04``&P'````````R@8`
M```````5`P``?@8`````````````3P4`````````````\`0``'4$``"@!@``
M;00```@```!>````10<``+@#``!S!0``W@```((#```B!```.`4``/0&``":
M`P``=0(```````!J`0``/`(``+L&``#K!0``O`0```````!L!@```````(D`
M``"C`@```````#$&````````&0<```````!5`0``(`0``#@!````````:P0`
M``````"%`@``=@4``'T%``#6`````````!\"``!,!@``-00``#$"````````
M`````)4#``#\!```_08```4#``!F!@```````.\!``#&````[0,``(\```!8
M!P````````````#D!@``@P,`````````````VP(``"P#``!7`0``\08`````
M``#C`0``_@```$T```#*!```#04````````V`0``C@,``'T!``"7````5P0`
M`'T$``!S````I`4``%8"``"``@```````#\&``!V`0``_`$```````#D!```
M`````"0`````````]00``&D$````````60$``!\$```&````G0(``%P"````
M``````````$&``"1!0```````-X&``",`P``/@```"L!```2`@``U`,``(X&
M```]!P```````&H#````````C`0``*,`````````PP,``%$```"[`@``*@0`
M`!X$``#F!````````"H&``#T`@``+`8``%4%``````````````````"G`@``
M(@,`````````````LP$```````!]````)0,```````!O!P```````(\$````
M````S`$``.T&```(`0````````````````````$``$D%```V!@```````,8%
M```1`0``700``/@#``"<````K@,``,(!````````<P0``&\$``#5`@``QP4`
M`'P!``",`0``````````````````^@4``#,$````````.P<``*(&``#.`P``
MI08``.L!``"F`````````.T"``````````````````"K!```Z0$``/8$``#<
M`P``)@0```````!D!```GP````T&``"W!```YP,```````#&!```60(``(H$
M````````P@(``+L%```_!0``<0<``-,%``"0!@```````&`'````````````
M`!D$````````\0,``%0```#9`````````$@```"6`````````%0"```W````
M'08``#H"``!Q`@```````/$"````````!@0``+4"``"C!```=`<```````#7
M!@``%0````````#6!````````/P`````````'`4``(@%``#U`0``]`4``'H#
M``#5!@``L04``)(%````!0```````````````````````($$``"]`@``S`(`
M``D'``"7`P``_0(```````#Q!```/0(``%,!````````PP0``#(!````````
MR0(``(P``````````````$L!`````````````+<&```)`0``W`$``"0$``"B
M`P``R@4``',!```Q!```#@8``(D$``!B`````````"\```"=!@``-@(``%<"
M``!\!P``1`<``(H%```9`````````*T```#L`P``S@8``'D%```R````N@4`
M`,@"````````\P8``+,&``!8!0``1`$`````````````&P(``!L'``#8!@``
M``````L%````````8`$``#<"``!!`@``N@$``'X#````````*@$``$8```#.
M`@``$08```````!_````0`,``#('```M`0``+P0``-\!````````SP4``+("
M``#F`0``4@,``/4#``![!````````*`#``#2`@``8`,``.@%````````````
M`%\````=`@``,`,``/H"````````<00```````!]!@``-`4``#<%```6!```
M`````'8```"A`P```````)0%``!?!0``$`(``&P!```B`0```````(X`````
M````9P4```````#"!0``&@$``-X!````````D0,``)@`````````@@4``!@`
M````````*04``(0$````````'````)8&``!E!@``^0(``(4!````````2@,`
M`&4'``!X!```#@0``&4```!1!0``P08``'("``#@``````````````"U`P``
M<P,`````````````````````````````7`$````````U!P``?`(``&P`````
M`````````(8"````````RP8```D"```,!0``;0$``"L"``#=!0``Y0(``$T#
M```-`0``8````&<`````````O`8``-<"``"V!@``````````````````Z@``
M`+`$```H`````````"P'````````\P```*<%``#[`0``T@0``!H`````````
M``````````!@!````````,4&``!<!@``3@`````````1`@````````````!(
M!```$P8``",````_````?P4``*8$``"V`@``C@4``.0```!`!````````+4%
M```^!0``'P$``+@!````````F`4```````"U````_@8``"@'````````````
M`*X$````````9@<``'@%``!F````````````````````RP0```<!``!4!@``
M``````````#<!@``70<``#L!```Y!```<P(``.@&```W!```'`<``/H&``!N
M!@``#`$```````!$!@``F@8``+H$``!B!@``!@4``$('````````````````
M``!Q`P``BP```'8'``#0`P``_P$``*,!```J`P```````+$$````````(0<`
M`/\"``#I`@``<````&H&``#8````#P8``$,#``!:!P``\`4``.4&``#.!```
M/0,```````#X!0``8@<``)P&``#0`@```````&L!``#1````A@8``#````#&
M`@``GP0``.H!``#B````:`(``*8!``!:`@```````#8#````````6`8``"D$
M``!>`P``W@4```````#/````DP4``-0&``!#`@````````````"5`0``````
M```````$!@``0P4``/L&````````1P,``&D%``!0!P``T0$``(`!````````
M`````````````````````/H$``!J!```!`0``#P#```=!```W`0```````!:
M`P``?`0```\"```I!@``R`0``!D#````````>P8``'4````#`P``D0$`````
M``"L``````````("``!Y`0``)P0``#$'````````>@```'0`````````````
M`&(!``!4`0``#0```#\!``#;`P``L08``#0'`````````````"8`````````
M``````````"%!0``C00```````!$!```_@4```````"S````4`$``(T&``"R
M`0``%`(``$X"``"%`P``:P<``/,"``"V````[P8``.X#``!1`0``WP0``.P$
M````````S`8````````M`@````````@'``!0`````````%("````````2`8`
M`'\"````````&08```````#P!@``B`8``+L```!9!@```````/<!``"$````
M0P8```````!U`0````````````!"`@``2`$``!,#````````)`$``%<#``#U
M````EP4``%`%``#9!@``.0$``!8'````````B`$``%D%``!5!```/@<``)@"
M```[`P``#P,``*L%``!)`0```````)T$````````/@$``&H```![!0``I0,`
M`*0&```@`````````*X```!+````$@```*0$```!`0``=08```````#3`0``
MN@```.$#``"V`0````````````!F!`````````````"^````N0```'`$````
M````$0```%P%``#C!```'@,``*L!``#F````(`(``)L&``"\`0``\`$``#<&
M``!_!@```````($````0!```N0(``#L$``!_`0``&P```+$"````````NP,`
M`'(%``!C`@``A0````````#+`@``P`8``'P%````````50(``)P%``#N`0``
MJP,```````"'!0``<@$``+$```!_!````````.P&````````#0<``&T"````
M````Z@,````````.`@``%`$``"L#``!"!````````'\'``#=`@```````'@&
M``!&!0```````-@%``"%!````````%L'``#U`@``K00```,"````````(0``
M`/D%``!W`0``.@,```<&``#Q!0``[@(``&X%``"V`P```````-(#``#F`@``
M508```````!Y!```/P,````````H`@``F04``,,%``#7!0``7@4`````````
M````_`8``'<%``!%`@``/````+P```````````````T#``````````````P'
M```T!@``$@0`````````````7P(```0'```Q`P```````$`!```Z!0``````
M`)<&`````````````(<!``#)````Y@,``.`&``"]````BP$``+L$````````
M-`,``#,"```:!0```````(,&``"L!```!0(``.@$``"]`P``````````````
M````1P0``$T&``"S!```<`4``,(#````````:0,``-@!``"P`0```````)`%
M````````Q@8``)\%````````!P,``'L#```3````"P0``,,!```)!```````
M`#\"``!5````X`4```````"J`P```0,``!<$```#!@````````````#G!```
MZ04```@#``"E!0``M00``!8```!2!```-P$``%(%``"B`@``]P(```````!^
M`@``(`4``/D#``!#`0``:`0`````````````/`4``!,!````````[P,``,0$
M``"Z!@```````$8#````````RP,``%H%``!Z!```.@8``/D````;!0``1@$`
M``````"K````5@$``.4$``"-`````````,P#```U!@````````````#+````
MAP```-H#`````````````,D$````````3@<````````6!0```````.0#```Q
M````R@,``(8%```0`0``#@```&<'``"G````S`0``%X'```5!@``V@```"$!
M``"@`@``E@(``%P$```K!```'P<``&4!``!V`@``$`<``!L$``#6!0``F@(`
M`%T`````````W00``&,%```\!@``Y`(```````"O!0````````(#```<!```
M`````````````````04```````"3`0``@@8``'(#``"M`P``]@8```````"0
M!```@P(``!L&````````V0,```````!;`0``5P<``!(#``#O`@``+P<``'$%
M``"F`P``70$``"@&``````````````````"K!@``W0,``$P#``#Y!```-@<`
M`'8$````````+`4``&0&``#4````G@(``/<#````````)04``(('``#J!0``
M<`(````````I``````````0"````````!P<``.($````````3@8`````````
M````(P<``/\%````````1`(``````````````````-4!``#-````-0,```0!
M````````)P<``&X'``!?!@```````'X%``!N`0``K0(``,($```L`@``4P0`
M`````````````````($%```1!```CP(``%,&``#2````K`,``$4&```S!P``
M>`<```````#-!```&`4```````"X!`````````````""`0`````````````A
M`@``6@$````````7!P``+@<``!X"``"F`@``(@<````````X!```AP(``&L`
M``#N!@``-@4``#P!```.!0```````.(%``"*````'`$``*D$``"'`P```P4`
M```````?!0``6P(```````#H`0```````/<$````````W0$``$0%````````
M$`8``(@```#G`@``,@0``.(#``"H!0``"@8``,4#````````/00`````````
M`````````.@"``"?`P``_`,``!4%```S````\P4``','````````:P8`````
M``#)`P``;P$``!P#``!6!0```````(8```"#`0```````+0```"-`P``@@0`
M`"X$``"W`0``EP(``)T%``"T`@``XP(````````P!```H0```"H"``#&`P``
M"0,```````")!0```````!@&``"J!```````````````````:`4```````#6
M`0````````P$```%!@```````"4```#>`P``G@``````````````;P4``!P&
M````````%0$``#L%```=````R@(``)L%``"%!@``C`(``!X%``"4`@``````
M`#T&```^!@``H0$``)X%```E`@`````````````M````1@<``),"``!0!```
M```````````R`@``]04``'0!``!;`P``-0$```````!,!```4P4``*`$```)
M````P`4``($#````````6`$``&<"``#I`P``%P(```````#``@``5@<``$$#
M```Z!```D`$``.0!``#@`P``3P0`````````````J@(```P"```:`@``3@$`
M`$8$```*`````````$D&``#Z`0``+@```(T!````````*0<``.L"``#G`0``
MS0$``&H"`````````````-@"``#!`@``)P```+$#``"/!0```````&X````0
M`````````(L$```;`0``;@0``'('``#^`@``W`4``$\'``"P`P```P<``(L#
M````````BP(``&<!``"``P``O0$``',&``!L!```J@```$P"``!A!0``````
M`(H#```K!P``@`0```````"Z`P``/`0``!8"````````-0(``)`#``""````
M_@,```````````````````T"```3`@``P@```+D#````````S08``"T%``#N
M````O@4```````!%!0``#P<``%4'````!```7@$`````````````UP$``$8&
M``#N!```:08``#4%```W!P``F@$``.$```"Z`@``O`,``!0$````````````
M`)8%``#G!0``\@,````````_!P``%P,``.D$``"3`P````,```8&``"*!@``
M`````&@&``!<!P``+@$``",&````````808``&<#````````6P8``+,#```(
M`@``1P(``!\````)!@``9`$`````````````30(`````````````HP4``"X&
M``"Q`0```````-`!```R!0``A@$``%P`````````.`8``.,#```7!0``N00`
M`*L"````````@````'@#``"$!@``Q04``(`&``#;`0``,P,``.T!````````
M``````P```"4`P``80(``)P"``#O!0``````````````````8@0`````````
M````Z0```+,%``">!@```````!X!``"_`P``.08``&T%``"$`0``:0(`````
M``!+!```XP8```````##!@``CP$```````##````&@<```````!A!```<`<`
M```````*!0``/0$``$P'``!K`P``'P8``$0````2!P````````````#6`@``
M20```#D#```5!````````.\```!G!@````````<%``!1`P``!`4``"$%``"R
M!@``IP0```4$``!'`0``008``````````````````!T%````````L````*\`
M```M!@``ZP8``.,`````````(`8``!`#``"_!```U@8`````````````?0,`
M``H$```6`P``K`$`````````````WP8``,X`````````D@$``'L'``##`@``
M_P0````````T`0```````*@````L`0``#`,```````".!```&0$``*(```!-
M!0```````.8&``#3`@``````````````````!P0``)D!``"9`P``J@$```H"
M``#2!0``\@4``/,!```+`P```````)T!``#%`````````,0"``!7````.```
M`"8"`````````````/L#``"E!```N`4```````"_!0```````$\!```=`0``
MZ08``/4&``"4!```3@0```````"M`0````````````"D`0``I@4``*X"``!@
M!@```````-,#```3!0``I`,````````8`@``_00```````"#!P``?0<``,X%
M``#A`0``J08``.$"``"]!@``J0(``&X#``"-!0``KP$```````#0!0``GP8`
M``````"R!0```````,P%``!J!0```````/8"````````V@8`````````````
M'0,``'H'``"R!```HP8```````#!!0``IP$``$,```";`P``&0(```````!*
M!`````````(!``"5`@``3`4``#X#``!V!@``V@(```````!#!P``8`4``'P&
M``!"`P``Y0```$H%``"_!@```````````````````````-````!9`P``MP``
M`'<"``!`!0```````$\&``#4!0``2`(``#T````J!0```````'<&``#>`@``
M7@0``!@#``````````````````#!!````````-$#``#@`@``=@,``)0```"$
M!P``&`0````````````````````````_!```%P8`````````````30<`````
M```G`P``_0```%4#`````````````!X'``!/`P``.`(``),```#Q`0``4P(`
M``````#V`P``"P8```````"7!````````$(!``!=`@``200``$@'``!K!0``
MKP,```````""`@``2@8````````F`0```````-D!````````K@4``&T'``#9
M!```9@4``+`&```D!0``.0<``$`'``!(`P``9P0``,T#````````9@(``*P%
M``!^!```=`,``,\#``!.`P``F`$``-\"``!*`@``P`0```````"&!```:`<`
M`'(```````````````````#X`@```````"\%``!F`P```@<``"$#``!Y!@``
M`````.4#``"5!```M0$``,<&``#-`@``*`$``)<!``#)`0```````%,'``!1
M`@``6`,``(,%````````+@(``/@```"9`````````,P```"L`@``,04`````
M``#7`````````*(%```````````````````B!@``E08``.P!```?`P``.P``
M`)0&``!!`0``Q`,``(H"```!!P``$@4``&(%```````````````````@`P``
MB`(``!X```"`!P``4@<``*H%``!%````<@8``#8$``#!`0``T@$``$(```!C
M!```)`<``&P%``#R!@``5@````X!``#W!0``2P(``/L$``!8`@``H`4```(&
M``#F!0``(@```$(%````````1P8``)8$``"8!@``OP(```$$````````````
M`+D&``!L`P``$@8``.H&````````>@4``.@````R`P``5P4```\%```/`0``
M'`(```````!E!0```````"\!```[`@``30$``#`!```C`@``U0`````````B
M!0``9`,``/8```!X`@``BP8`````````````H0(```````"N`0``^@,``&$!
M``"X````D0```````````````````)4````D`P``#P``````````````B`,`
M``````![`@``Q`4``,0!````````A`,``!T'``">`0```````-D"``#'`0``
M"@$``%,#``!Y````T00``,$#````````R`$``!$#``````````````````!J
M!P``[00``'0$```&`P```````#L&``#5!````````)\"``!M````C`4``!0'
M````````5`<``"@$```"````7@(``!D%````````]@4``$L%````````R```
M``H#``")`@```````*,#```%!0```````#<#``#]`0``"P<``%L$```'`@``
M`````$P```"8!```SP$``"8%``#E!0```````'@`````````9@$``/````#L
M!0``20(``+0%```"!0```````%(```#H`P``2`4``-$&```Y````Q00``)H%
M``"^`@````````,!``!T!@``004``-L&``````````````<````S!0``*0,`
M`/H```#$!@``$0<````&``#*````>`$``!(!``#T`P``XP4``*<&``!1!```
M4@$````````$`P``MP(``$H'```4````CP,``*@"``!:!```U`0``#@#```N
M`P``]````#X$````````W`(``*T&`````````````-D%``!>!@``O@,``,@#
M``#J!```600``)0!``"&`P``9`<``($'`````````````!`%``")!@``H@0`
M`"T'``"*`0``000``)L````>!@``\`(``'$&`````````````+0$````````
M#@,``.<&``!=!0```````/@$``"1!@``WP4``"<&`````````````/0$````
M````N`(```````"T`0``0@8```````"J!@``4@8``#D%````````00```#0$
M````````,`(```````#^!````````(L%```;`P``I0(`````````````4`,`
M`"0&``#1!0``]P8```````"H`0``80,```\$`````````````%`&```G`0``
ML`4```````#B!@``T0(```````"$!0``@0(``+4&``!6`P``@0$```````#K
M!```(@(``,\&````````-0```+@&``#'`@``IP,``%D`````````,0$`````
M``#=!@``KP8```@%``!%`0``5P8``+8$```S!@```````%8&````````9```
M`"$&``#%`@```````)T```#_````!0$``#X"``"'!```:0```-4%```@`0``
MG`0```````"0`@``$04````````Z`0``S04````````6`0```````'4%``#'
M````R`8`````````````6P4``"$$``#S`P``)P4``.<```"^!```I@8``!H&
M``!*`0``+P8``/X!``!E`P``VP0``#0"`````````````/L```"H!@``D@8`
M`$\"````````,`8````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@
M;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E
M<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@
M;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@
M9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@
M4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`
M06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I
M;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN
M9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D
M9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@
M82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE
M;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3
M:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S
M(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S
M<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA
M`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE
M;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL
M(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L
M=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L
M=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N
M(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@
M86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L
M:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O
M=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U
M-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@
M86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!
M4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R
M=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT
M(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I
M8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@
M<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`
M0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S
M=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`
M0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`
M0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!"
M:7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O
M=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!"
M;V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V
M970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"
M=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S
M(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N
M`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@
M9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E
M<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E
M(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T
M:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA
M;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`
M0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I
M8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@
M1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R
M`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@
M07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N
M86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA
M;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L
M96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z
M("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`
M0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7
M:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI
M;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R
M<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO
M;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@
M4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M
M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF
M9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L
M(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U
M="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG
M;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE
M8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`
M0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#
M;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`
M0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#
M;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@
M(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK
M("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N
M=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#
M<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S
M97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@
M:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD
M:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S
M97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E
M;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N
M=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E
M;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE
M`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N
M=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I
M;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P
M;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y
M(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U
M<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO
M;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL
M($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I
M=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N
M=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET
M<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE
M=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@
M=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`
M179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A
M;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@
M=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X
M<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&
M86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E
M<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I
M;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&
M86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S
M`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&
M965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L
M9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE
M`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL
M92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A
M9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD
M`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A
M=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O
M9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E
M8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@
M='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA
M;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`
M1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A
M;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R
M871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV
M96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`
M1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U
M.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'
M=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI
M<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H
M+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/
M+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP
M97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`
M2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(
M;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E
M<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E
M<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N
M=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ
M(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S
M`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS
M(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM
M86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P
M;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`
M26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA
M=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@
M0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R
M="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@
M8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O
M<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@
M<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T
M+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN
M=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`
M26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T
M`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED
M960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@
M<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP
M:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C
M92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN
M=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q
M`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L
M`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA
M<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`
M2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,
M969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+
M96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`
M2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!2
M97!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`
M3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U
M=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T
M(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB
M>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ
M;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T
M90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,
M:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN
M:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE
M`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E
M<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN
M+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`
M3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R
M<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X
M96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U
M90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L
M;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG
M=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE
M<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R
M(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO
M="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP
M90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO
M=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@
M=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P
M<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER
M960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`
M36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),
M`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA
M`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E
M<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C
M=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO
M<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L
M96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0
M;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!
M9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T
M:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S
M8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S
M8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`
M3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`
M3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`
M3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK
M*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T
M:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E
M`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N
M9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F
M="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`
M3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I
M;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I
M960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX
M.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO
M<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"
M969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E
M=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@
M9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG
M;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@
M4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE
M=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S
M=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T
M`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R
M9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L
M:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT
M:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O
M<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U
M<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W
M`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O
M<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O
M8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@
M2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME
M>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A
M:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO
M=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W
M<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E
M($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E
M('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F
M<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!2
M97%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`
M4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT
M<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI
M;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2
M;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T
M871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P
M97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G
M90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-
M97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO
M;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`
M4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O
M;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B
M:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S
M(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%
M;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!3
M35,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N
M`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO
M=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%
M87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR
M:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U
M<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA
M:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`
M4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@
M3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``
M4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R
M9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I
M;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T
M92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D
M9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G
M(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B
M<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S
M(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B
M`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E
M`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E
M.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA
M;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3
M=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI
M8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS
M($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@
M4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L
M87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S
M(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X
M="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4
M:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4
M:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N
M<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P
M:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO
M=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@
M9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P
M;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B
M<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I
M;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED
M96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S
M="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E
M96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N
M=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q
M=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`
M5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O
M=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S
M(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO
M="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA
M8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D
M(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@
M;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES
M=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S
M(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N
M`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4
M:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E
M<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A
M="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W
M:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4
M:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T
M`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L
M=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C
M;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA
M=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA
M=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U
M;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A
M;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C
M:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S
M+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M
M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE
M('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL
M97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T
M1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA
M8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E
M<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`
M56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T
M871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI
M=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W
M;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N
M<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S
M(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E
M<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5
M<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S
M97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E
M>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S
M96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@
M86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I
M970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R
M:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL
M:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10
M`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S
M=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E
M8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES
M=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O
M9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M
M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@
M2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P
M.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`
M65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G
M<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO
M=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A
M<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T
M92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!:
M:7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO
M=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R
M964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N
M<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@
M4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U
M;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U
M<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E;G1R>2!N
M;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`
M:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M
M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L
M<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA
M=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``
M<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A
M:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF
M:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D90I297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M
M,34@,38Z-3`M,#(P,`I,87-T+51R86YS;&%T;W(Z($9A8FEO($=O;65S(#QF
M;&=O;7-`=6]L+F-O;2YB<CX*3&%N9W5A9V4M5&5A;3H@0G)A>FEL:6%N(%!O
M<G1U9W5E<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ
M(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N97)A
M=&]R.B!+0F%B96P@,2XS+C$*4&QU<F%L+49O<FUS.B`@;G!L=7)A;',],CL@
M<&QU<F%L/2AN(#X@,2D["@`@*"5S(&1I87,@871RX7,I`"`H5&5C;&$@9&4@
M071A;&AO("5S*0`@*&5M("5S(&1I87,I`"`H:&]J92D`("AA;6%N:.,I`"`H
M;VYT96TI`"!A(``B)7,B($[C;R#I('5M(&1I<F5T\W)I;RX`)R5S)R!NXV\@
MZ2!U;6$@97-C;VQH82!VX6QI9&$N`"<E<R<@;N-O(&5S=.$@8V]N9FEG=7)A
M9&\@;F\@4F5G:7-T<F\@9&\@2&]R9&4N`')E;F1E<FEZ861O<B!D92#A<G9O
M<F4@(B5S(B!NXV\@96YC;VYT<F%D;RX`(B5S(B!F;VD@861I8VEO;F%D;R!A
M;R!S:7-T96UA(&1E(&=R=7!O<RX`(B5S(B!F;VD@861I8VEO;F%D;R!A;R!S
M:7-T96UA(&1E('!E<FUI<W/U97,N`"(G)7,B(&[C;R!F;VD@8W)I861O.B`E
M<RX`)2XR9DU"('5S861O<R!D924N,F9-0B!P97)M:71I9&]S("@E+C)F)24I
M`"5D("5S(&4@)7,`)60@9&EA<R!A=.D@<W5A('-E;FAA(&5X<&ER87(N`"5D
M('!R979I<^-O(&1O(&1I80`E<R`M($%V:7-O`$EM<')E<W/C;R!$:6=I=&%L
M(&1E("5S`"5S($M"`"5S($]P97)AY_5E<R!D92!-86YU=&5NY^-O("T@0V]N
M9FER;6'GXV\`0V]N9FEG=7)AY^-O(&1E("5S`$-A9&%S=')O(&1E("5S`"5S
M(%1E<FUO<R!D;R!!8V]R9&\`)7,@:N$@97AI<W1E+@`E<R!A("5S("5S`"5S
M(&5S=.$@<')O;G1O('!A<F$@97AE8W5T87(@87,@;W!E<F'G]65S(&1E(&UA
M;G5T96[GXV\@;6%R8V%D87,@86)A:7AO+B!-87)Q=64@82!C86EX82!P87)A
M('%U86QQ=65R(&]P97)AY^-O('%U92!V;V/J('%U96ER82!E>&5C=71A<B!D
M97-T82!V97HN`"5S(.D@;V)R:6=A=/-R:6\`)7,@;6EN=71O<P`E<R!NXV\@
M96YC;VYT<F%D;RX`)7,@82`E<R!D92`E<P!#873A;&]G;R!D92!%;F1E<F7G
M;W,@9&4@)7,`06=E;F1A(&1E("5S`$%N;W1AY_5E<R!D92`E<P!,:7-T82!D
M92!487)E9F%S(&1E("5S`"5S.B`E<P`E<SH@17-T82!M96YS86=E;2!P;V1E
M(&[C;R!S97(@9&4@<75E;2!E;&$@9&EZ('-E<BX@5&]M92!C=6ED861O(&-O
M;2!Q=6%L<75E<B!L:6YK('!R97-E;G1E(&YE;&$@;W4@96T@9F]R;F5C97(@
M86\@<F5M971E;G1E('%U86QQ=65R(&EN9F]R;6'GXV\@<&5S<V]A;"X`+"!B
M<FES82``+"!B<FES82`E<R`E<P`L('9A<FGA=F5L(&1E("5S('!A<F$@)7,`
M+2T@<V5L96-I;VYE("TM`$9O<FUA=&\@,3(@2&]R87,`1F]R;6%T;R`R-"!(
M;W)A<P`R-"!H;W)A<P`\4.%G:6YA($%N=&5R:6]R`%5M(&-O;F5C=&]R(&1E
M(&)A;F-O(&1E(&1A9&]S(.D@;V)R:6=A=/-R:6\@<&%R82!E<W1E(&)L;V-O
M+@!5;2!E<G)O(&9A=&%L(&]C;W)R974`56UA(&-H879E('#Z8FQI8V$@4$=0
M(.D@;V)R:6=A=/-R:6$@<&%R82!C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M
M+@!5;6$@8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I9V%T\W)I82!P87)A('9E
M<FEF:6-A<B!U;6$@;65N<V%G96T@87-S:6YA9&$N`%5M82!C:&%V92!P<FEV
M861A(%!'4"!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@9&5S
M8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`56UA(&-H879E('!R:79A9&$@
M4$=0(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R82!A<W-I;F%R
M('5M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@
M8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S
M<FEA<R!P87)A(&1E<V-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN`%5M82!C
M:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%
M(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R82!A<W-I;F%R('5M
M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI8V$@4R]-24U%(.D@;V)R:6=A
M=/-R:6$@<&%R82!C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+@!.=79E;G,@
M;6%T=71I;F%S`$-H=79A($9R86-A(%9E<W!E<G1I;F$`0VAU=F$@;6%T=71I
M;F$`0VAU=F%S(&UA='5T:6YA<P!.979A<V-A<R!-871U=&EN87,`04TO4$T`
M05!)($E$`%-O8G)E(&5S=&4@961I=&]R`%-O8G)E+BXN`$%B<V)O='1O;0!!
M8G-M:61D;&4`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!D:7)E=/-R:6\@5D93
M+@!!8V5S<V\@;F5G861O(&%O(&-R:6%R(&%R<75I=F\@5D93+@!3=6%S($EN
M9F]R;6'G]65S`%-E;FAA(&1A($-O;G1A`$-O;G1A(&1E<V%T:79A9&$N`$-O
M;G1A<P!!9&EC:6]N87(`061I8VEO;F%R($=R=7!O(%-U8F]R9&EN861O`$%D
M:6-I;VYA<B!097)M:7-S]65S(%-U8F]R9&EN861A<P!!9&EC:6]N92!!<75I
M.@!!9&EC:6]N87(@3F]V;R!'<G5P;P!!9&EC:6]N87(@3F]V82!097)M:7-S
MXV\`061I8VEO;F%R('5M(&=R=7!O('-U8F]R9&EN861O(&$@)R5S)P!!9&EC
M:6]N87(@=6UA('!E<FUI<W/C;R!S=6)O<F1I;F%D82!A("<E<R<`061I8VEO
M;F%R('5M(&YO=F\@=7-UX7)I;SH`061I8VEO;F%R(&-O;'5N80!!9&EC:6]N
M87(@;F]V;W,@;65M8G)O<P!!9&EC:6]N87(@<&%R`$%D:6-I;VYA<B!O($UE
M;G4@)7,@8V]M;R!U;6$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA`$%D:6-I
M;VYA<B!A;R!C873A;&]G;R!D92!E;F1E<F7G;W,Z`$%D:6-I;VYA<B!A;R!M
M974@8V%TX6QO9V\@9&4@96YD97)EYV]S`$%D:6-I;VYA<B!U<W7A<FEO`"<E
M<R<@861I8VEO;F%D;R!A;R!S:7-T96UA+"!M87,@;N-O('!U9&4@:6YC;'5I
M<B!I;F9O<FUAY_5E<R!A9&EC:6]N86ES(&1O(&-A9&%S=')O.B`E<RX`)7,@
M861I8VEO;F%D;R!A;R!S:7-T96UA+B!6;V/J('!O9&4@<V4@8V]N96-T87(@
M86=O<F$N`$%D:>?C;R!D92!U<W7A<FEO<R!E<W3A(&1E<V%B:6QI=&%D82X`
M16YD97)EYV\`0V%TX6QO9V\@9&4@16YD97)EYV]S`$%D;6EN:7-T<F%R("T@
M8V]N9FEG=7)A('!E<FUI<W/U97,@<&%R82!O=71R;W,@=7-UX7)I;W,`061M
M:6YI<W1R8>?C;P!!;OIN8VEO<P!!9F5G86YI<W3C;P!!;&+B;FEA`$%R9^ER
M:6$`07!E;&ED;P!!;&EN:&%R`$%L:6YH86UE;G1O.@!4;V1O<P!4;V1O<R!5
M<W7A<FEO<R!!=71E;G1I8V%D;W,`5&]D;W,@1W)U<&]S`%1O9&%S(%!E<FUI
M<W/U97,`5&]D;W,@<75A=')O(&QA9&]S`%!E<FUI=&ER(&WZ;'1I<&QO<R!E
M;F1E<F7G;W,`4&5R;6ET:7(@8V]N9FEG=7)A<B!O('1I<&\@9&4@;&ES=&%S
M(&]R9&5N861A<S\`2N$@97AI<W1E`$QO9VEN($E-4U`@06QT97)N871I=F\`
M4V5N:&$@24U34"!!;'1E<FYA=&EV80!5<W7A<FEO($E-4U`@06QT97)N871I
M=F\`16YD97)EYV\@9&4@92UM86EL(&%L=&5R;F%T:79O`$UO9&5L;W,@86QT
M97)N871I=F]S`%1E>'1O(&%L=&5R;F%T:79O.@!386UO82!!;65R:6-A;F$`
M56T@=F%L;W(@:6QE9V%L(&9O:2!E<W!E8VEF:6-A9&\N`$]C;W)R974@=6T@
M97)R;R!D97-C;VYH96-I9&\N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`%!R
M;WAY(&%N]&YI;6\`4F5S<&]S=&$`06YTX7)T:61A`$%N=&EG=6$@92!"87)B
M861O<P!!<&QI8V'GXV\`3&ES=&$@9&4@07!L:6-AY_5E<P!!(&%P;&EC8>?C
M;R!E<W3A('!R;VYT82X`07!L:6-A<B!A;W,@0V]M<&%R=&EL:&%M96YT;W,@
M4W5B;W)D:6YA9&]S`$%P<F]V87(`5&%M86YH;R!!<')O>&EM861O`$%B<FEL
M`$%RX6)I8V\@*%=I;F1O=W,M,3(U-BD`5&%M86YH;R!D;R!!<G%U:79O`$YO
M;64@9&\@07)Q=6EV;P!6;V/J('1E;2!C97)T97IA('%U92!Q=65R(')E;6]V
M97(@82!S;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E<S\`5F]CZB!T96T@
M8V5R=&5Z82!Q=64@9&5S96IA(&5X8VQU:7(@)R5S)R!E('-E=7,@<W5B9W)U
M<&]S/P!!<F=E;G1I;F$`07)MZFYI80!!<FWJ;FEO("A!4DU30TE)+3@I`$%R
M=&4`07)U8F$`26QH82!!<V-E;G/C;P!!<G1E($%S8VEI`,%S:6$O4F5G:>-O
M(&1O(%!A8^UF:6-O`%-O;&EC:71A<B!C;VYF:7)M8>?C;R!A;G1E<R!D92!E
M>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;S\`0V]L=6YA<R!D
M92!D97-I9VYAY^-O`%1E;G1O=2!E>&-L=6ER('5M(&=R=7!O(&EN97AI<W1E
M;G1E+@!496YT;W4@97AC;'5I<B!U;6$@<&5R;6ES<^-O(&[C;R!E>&ES=&5N
M=&4N`%1E;G1O=2!E9&ET87(@=6UA('!E<FUI<W/C;R!NXV\@97AI<W1E;G1E
M+@!496YT;W4@961I=&%R('5M(&-O;7!A<G1I;&AA;65N=&\@;N-O(&5X:7-T
M96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S=')I80!!=71H
M7V-Y<G-Q;#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA<"!N
M96-E<W/A<FEA+@!!=71H7V-Y<G5S.B!/(&-O;F5C=&]R(&[C;R!P;W-S=6D@
M87,@8V%P86-I9&%D97,@;F5C97-SX7)I87,N`$%U=&A?8WER=7,Z($[C;R!F
M;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82X`075T
M:%]F='`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($944"!N96-E
M<W/A<FEA+B!#;VUP:6QE(&\@4$A0(&-O;2!A(&]PY^-O("TM96YA8FQE+69T
M<"X`075T:%]I;6%P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I
M;6%P(&YE8V5S<^%R:6$N`$%U=&A?:W)B-3H@3N-O(&9O:2!E;F-O;G1R861A
M(&$@97AT96YSXV\@:W)B-2!N96-E<W/A<FEA+@!!=71H7VQD87`Z($EN8VQU
M<^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!%>&-L=7/C;R!D92!U<W7A<FEO<R!NXV\@
MZ2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA
M+@!!=71H7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R(&\@=7-UX7)I;R`E
M<RX@27-T;R!F;VD@;R!Q=64@;R!S97)V:61O<B!R97!O<G1O=3H@`$%U=&A?
M;&1A<#H@26UP;W-S[79E;"!R96UO=F5R(&\@=7-UX7)I;R`E<P!!=71H7VQD
M87`Z($EM<&]S<^UV96P@871U86QI>F%R(&\@=7-UX7)I;R`E<P!!=71H7VQD
M87`Z($%T=6%L:7IAY^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P
M87)A($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@3N-O(&9O:2!E;F-O
M;G1R861A(&$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA+@!!=71H7W-M8F%U
M=&@Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O('-M8F%U=&@@;F5C
M97-SX7)I82X`075T96YT:6-AY^-O(&YO('-E<G9I9&]R($E-05`@9F%L:&]U
M+@!&86QH82!N82!A=71E;G1I8V'GXV\`1F%L:&$@;F$@875T96YT:6-AY^-O
M.B`E<P!!=71E;G1I8V'GXV\@<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$
M2553+@!!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+@!!
M(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!334(@9F%L:&]U+@!#86UP;W,@
M9&ES<&]N[79E:7,Z`$%Z97)B86EJXV\`1&5S8W5L<&%S(&1O($)/1D@`1G5N
M9&\`0V]R(&1E($9U;F1O`%-E;FAA(&ME<F)E<F]S(&EN8V]R<F5T82X`57-U
MX7)I;R!K97)B97)O<R!I;F-O<G)E=&\N`$)A:&%M87,`0F%H<F%I;@!"X6QT
M:6-O("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!.XV\@9F]I
M(&5N8V]N=')A9&\@;R!D:7)E=/-R:6\@8F%S92!D92!I;6%G96YS("<E<R<N
M`$QI;FAA(&1E(%!A<G1I9&$`0F5L;W+Z<W-I80!"Z6QG:6-A`$)E;&EZ90!"
M96YI;@!"97)M=61A<P!"=73C;P!!;FEV97)SX7)I;P!.XV\@9F]I(&5N8V]N
M=')A9&\@;R!B;&]C;R`B)7,B(&1A(&%P;&EC8>?C;R`B)7,B+@!#;VYF:6=U
M<F'G]65S(&1O($)L;V-O`%1I<&\@9&4@0FQO8V\`3F5G<FET;P!";VSM=FEA
M`$9A=F]R:71O<P!";W)D80!,87)G=7)A(&1A(&)O<F1A.@!";W)D87,`0O-S
M;FEA(&4@2&5R>F5G;W9I;F$`06UB;W,`0F]T<W5A;F$`4F]D87#I`$EL:&$@
M0F]U=F5T`$)R87-I;`!497)R:73S<FEO(&1O($]C96%N;R#-;F1I8V\@26YG
M;.IS`$)R=6YE:0!"=6QGX7)I80!,:7-T82!C;VT@36%R8V%D;W)E<P!"=7)K
M:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`%!O;G1O<R!D92!$:7-T<FEB=6GG
MXV\@0U),`%!R;W!R:65D861E<R!D82!#Z5]L=6QA+BXN`$$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861A+@!!9V5N9&$`0V%L
M;6\`0V%M8F]D:F$`0V%M87+U97,`3N-O(.D@<&]S<^UV96P@9V5R87(@=6UA
M(&YO=F$@<V5N:&$@875T;VUA=&EC86UE;G1E+"!E;G1R92!E;2!C;VYT871O
M(&-O;2!O(&%D;6EN:7-T<F%D;W(N`$[C;R!C;VYS:6=O(&=R879A<B!O(&%R
M<75I=F\@(B5S(@!.XV\@Z2!P;W-S[79E;"!A9&UI;FES=')A<B!G97)E;F-I
M861O<F5S(&5X=&5R;F]S(&1E('-E<W/C;RX`3N-O(.D@<&]S<^UV96P@8V]N
M96-T87(@86\@<V5R=FED;W(@24U!4#H@)7,`3N-O(&-O;G-I9V\@86)R:7(@
M;R!A<G%U:79O("(E<R(N`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!296QA
M=/-R:6\@9&4@4')O8FQE;6$`3N-O(.D@<&]S<^UV96P@97AC;'5I<B!O(&%R
M<75I=F\@(B5S(BX`3N-O(.D@<&]S<^UV96P@96YC;VYT<F%R('5M(&1I<F5T
M\W)I;R!T96UP;W+A<FEO+@!.XV\@Z2!P;W-S[79E;"!C;VYT:6YU87(@<V5M
M(&\@<&%RXFUE=')O("=T87)G971&:6QE)RX`3N-O(.D@<&]S<^UV96P@97AC
M;'5I<B!O(&1I<F5T\W)I;R`B)7,B+@!.XV\@Z2!P;W-S[79E;"!E>&-L=6ER
M+"`E9"!P;W-S=6D@<W5B;W)D:6YA9&]S+@!.XV\@Z2!P;W-S[79E;"!R96]R
M9&5N87(L(&[Z;65R;R!D92!R96=I<W1R;W,@9F]R;F5C:61O<R!P87)A(')E
M;W)D96YA<B!NXV\@8V]R<F5S<&]N9&4@86\@;OIM97)O(&%R;6%Z96YA9&\N
M`$[C;R#I('!O<W/M=F5L(')O=&5A<B!M96YS86=E;2!P87)A(&\@;OIM97)O
M(&5S<&5C:69I8V%D;RX`0V%B;R!697)D90!4[71U;&\`3W!E<F%D;W)A`$-A
M=&5G;W)I87,@92!.;VUE<P!);&AA<R!#87EM86X`5&5L969O;F4@0V5L=6QA
M<@!0<F]P<FEE9&%D97,@9&$@0^EL=6QA`$UA<F=E;2!D82!CZ6QU;&$Z`%!R
M;W!R:65D861E<R!D82!#Z6QU;&$`17-P8>=A;65N=&\@9&$@8^EL=6QA.@!4
M96QE9F]N92!C96QU;&%R`$/I;'1I8V\@*$E33RTX.#4Y+3$T*0!#96YT<F\`
M4F5P^F)L:6-A(&1A(,%F<FEC82!#96YT<F%L`$5U<F]P82!#96YT<F%L("A)
M4T\M.#@U.2TR*0!$971A;&AE<R!D;R!#97)T:69I8V%D;P!0<F]P<FEE=.%R
M:6\@9&\@0V5R=&EF:6-A9&\`4&]L[71I8V%S(&1O($-E<G1I9FEC861O`%1C
M:&%D90!!;'1E<F%R`$%L=&5R92!3=6$@4V5N:&$`06QT97)A<B!O(&YO;64@
M92!O(&5N9&5R9>=O('%U92!A<R!P97-S;V%S(';J96T@<75A;F1O(&5L87,@
M;.IE;2!E(')E<W!O;F1E;2!S=6%S(&UE;G-A9V5N<RX`06QT97)AY^-O(&1E
M('-E;FAA(&[C;R#I('-U<&]R=&%D82!N82!C;VYF:6=U<F'GXV\@871U86PN
M("!%;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(N`$-H87(`
M5F5R:69I8V%R($QI;E]K+BXN`$-H:6QE`$-H:6YA`$-H:6[J<R!3:6UP;&EF
M:6-A9&\@*$=",C,Q,BD`0VAI;NIS(%1R861I8VEO;F%L("A":6<U*0!%<V-O
M;&AA(&$@07!L:6-AY^-O.@!%<V-O;&AA('5M82!S96YH80!%<V-O;&AA('5M
M('5S=>%R:6\`17-C;VQH82!C;VUO(&5X:6)I<B!D871A<SH`17-C;VQH82!O
M('1I<&\@9&4@97-T:6QO(&1E(&QI<W1A<R`H<&%R82!L:7-T87,@;W)D96YA
M9&%S*0!);&AA<R!#:')I<W1M87,`3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F
M:6YIY^-O(&1E(&-L87-S92!D92`E<RX`3&EM<&%R`$QI;7!A<B!T86=S($U3
M3V9F:6-E`$5X8VQU:7(@=7-UX7)I;P!%>&-L=6ER('5S=>%R:6\Z("5S`$5X
M8VQU:7(@=7-UX7)I;P!%>&-L=6ER(&1A9&]S(&1O('5S=>%R:6\`0^EU(&%B
M97)T;R!A(%1A<F1E`$-L:7%U92!P87)A($-O;G1I;G5A<@!#;&EC:V%T96QL
M('9I82!(5%10`$9E8VAA<B!*86YE;&$`3G5V96YS`$YU8FQA9&\@<&5L82!-
M86YHXP!.=6)L861O`$EL:&%S(&1E($-O8V]S`$-O;G1R86ER($)A<G)A($QA
M=&5R86P`0V]N=')A:7(@8F]R9&%S`$-O;/1M8FEA`$-O<@!086QH971A(&1E
M($-O<F5S`%-E;&7GXV\@9&4@0V]R`$-O;',Z`%3M='5L;W,@9&%S($-O;'5N
M87,`475A9')I;FAO<P!#;VUA;F1O`$QI;FAA(&1E($-O;6%N9&\`0V]M96YT
M87(`3F]M90!#;VUO<F]S`$5M<')E<V$`0V]M<'5T861O<F5S`$-O;F1IY^-O
M`$-O;F1IY_5E<P!$:69E<F5NYV%S(&1E($-O;F9I9W5R8>?C;P!#;VYF:6=U
M<F'GXV\@9&4@<VEN8W)O;FEZ8>?C;R!C;VT@4$1!<RP@4VUA<G1P:&]N97,@
M92!/=71L;V]K+@!#;VYF:6=U<F'GXV\@;F5C97-S:71A(&1E(&%T=6%L:7IA
MY^-O+@!#;VYF:6=U<F%R("5S`$-O;F9I<FUE(&$@4V5N:&$`0V]N9V\`0V]N
M9V\L(%)E</IB;&EC82!$96UO8W+A=&EC82!D;P!&86QH82!N82!C;VYE>.-O
M+@!&86QH82!N82!C;VYE>.-O.B``0V]N97CC;R!R96-U<V%D82!P96QO('-E
M<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX`0V]N97CC;R!R96-U<V%D82!P
M96QO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX@36]T:79O.B`E<R`H
M)7,I`$$@8V]N97CC;R!A;R!S97)V:61O<B!&5%`@9F%L:&]U+@!#;VYT871O
M<P!/<R!C;VYT871O<R!F;W)A;2!A9&EC:6]N861O<R!C;VT@<W5C97-S;R!A
M;R!S974@8V%TX6QO9V\@9&4@96YD97)EYV]S+@!4:7!E(&1E(&-O;G1E^F1O
M(&1O(&%R<75I=F\@8V]M<')I;6ED;SH@`$-O;G1E^F1O(&1E("<E<R<`0V]N
M=&EN=6%R`$EL:&%S($-O;VL`0V]O:VEE`$-O<&EA<@!&86QH82!N82!C\W!I
M83H@)7,`0V]P:6%R('-E;&7GXV\`240@9&4@0W5S=&\`0V]S=&$@4FEC80!#
M;W-T82!D;R!-87)F:6T`26UP;W-S[79E;"!C<FEP=&]G<F%F87(@82!M96YS
M86=E;2!C;VT@4$=0.B``26UP;W-S[79E;"!A<W-I;F%R(&$@;65N<V%G96T@
M8V]M(%!'4#H@`$[C;R!F;VD@<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@;65N
M<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R(&$@
M;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!A9&EC:6]N
M87(@8V]N=&%T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S
M97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L('9E<FEF:6-A<B!O('-A
M;&1O+B`E<P!);7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R($Q$05`N
M`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@)R5S)R!U
M=&EL:7IA;F1O($944#H@)7,`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`26UP;W-S[79E;"!D97-C<FEP=&]G
M<F%F87(@;W,@9&%D;W,@4$=0.B``3N-O(&9O:2!P;W-S[79E;"!D97-C<FEP
M=&]G<F%F87(@;R!D861O(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!E>&-L
M=6ER(&\@8V]N=&%T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER(&$@
M;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&5X
M8VQU:7(@;R!S8W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O
M("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@9&5T97)M:6YA<B!O(&5N9&5R9>=O
M(&1E(&4M;6%I;"!D;R!D97-T:6YA=.%R:6\N`$[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@8V]M<&QE=&%M96YT92!O(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX`
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&$@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&-O;7!L
M971A;65N=&4@82!L:7-T82!D92!L:7-T87,@9&4@9&ES=')I8G5IY^-O+@!.
MXV\@9F]I('!O<W/M=F5L(&-A<G)E9V%R(&$@97-T<F%TZ6=I82`G)7,G+@!.
MXV\@9F]I('!O<W/M=F5L(&-R:6%R(&\@9&ER973S<FEO("<E<R<N`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@82!C:&%V92!P^F)L:6-A(&$@<&%R=&ER(&1O
M('-E<G9I9&]R(&1E(&-H879E<RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`G
M)7,G('!A<F$@9W)A=F'GXV\N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@)7,N
M`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!M\V1U;&\@)TUA:6YT96YA;F-E
M7U1A<VLG("5S`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!D:7)E=/-R:6\@
M)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@<V5R=FED;W(@
M3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!L97(@)7,N`$[C;R!F;VD@<&]S<^UV
M96P@9V5R87(@=6UA(&YO=F$@<V5N:&$@<&%R82!O('5S=>%R:6\@<V]L:6-I
M=&%D;RX@06QG=6YS(&]U('1O9&]S(&]S(&1E=&%L:&5S(&[C;R!E<W3C;R!C
M;W)R971O<RX@5&5N=&4@;F]V86UE;G1E(&]U(&5N=')E(&5M(&-O;G1A=&\@
M8V]M(&\@861M:6YI<W1R861O<B!S92!V;V/J(&YE8V5S<VET82!D92!M86ES
M(&%J=61A+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@04-,`$[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N("5S`$[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N
M("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@;&ES=&%S(&1E(&1I<W1R
M:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A<R!C87!A8VED
M861E<R!D;R!S97)V:61O<@!.XV\@9F]I('!O<W/M=F5L(')E=F5R=&5R(&$@
M8V]N9FEG=7)AY^-O+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!D:7)E
M=/-R:6\@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!S86QV87(@82!C;VYF:6=U
M<F'GXV\@)7,N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R('5M(&)A8VMU<"!D
M82!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R('5M(&)A
M8VMU<"!D82!C;VYF:6=U<F'GXV\Z("5S`$[C;R!F;VD@<&]S<^UV96P@<V%L
M=F%R(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!E
M;3H@)R5S)RX`3N-O(&-O;G-E9W5I('-A;'9A<B!O(&)A8VMU<"!D;R!A<G%U
M:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX`3N-O(&-O;G-E9W5I('-A;'9A<B!O
M(&%R<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B!6;V/J('!O9&4@;W4@=71I
M;&EZ87(@=6UA(&1A<R!O<.?U97,@<&%R82!S86QV87(@;R!C\V1I9V\@9&4@
M=F]L=&$@96T@)7,@;W4@8V]P:6%R(&UA;G5A;&UE;G1E(&\@8_-D:6=O(&%B
M86EX;R!P87)A("5S+@!.XV\@9F]I('!O<W/M=F5L('!E<W%U:7-A<B!N;R!S
M97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!L:6YK
M("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@871U86QI>F%R(&\@8V]N=&%T;RX@
M)7,`3N-O(&9O:2!P;W-S[79E;"!A='5A;&EZ87(@82!L:7-T82!D92!D:7-T
M<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@9W)A=F%R(&$@8V]N9FEG
M=7)AY^-O(&1E("<E<R<Z("5S`$[C;R!F;VD@<&]S<^UV96P@96YC;VYT<F%R
M(&$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA+B!#97)T:69I<75E+7-E('%U
M92!E;&$@97-TX2!A8F5R=&$N`$[C;R!F;VD@<&]S<^UV96P@9&%R(&%O('5S
M=>%R:6\@)7,@;W,@<V5G=6EN=&5S(&1I<F5I=&]S('!A<F$@82!P87-T82`G
M)7,G.B`E<P!497AT;R!C;VYT861O`%!A[7,`0W5R<V]S`$-R:6%R`$-R:6%R
M('5M(&QI;FL`0W)I87(@=6UA(&YO=F$`0W)I87(@<W5B('!A<W1A<P!097)M
M:7-S]65S(&1O(&-R:6%D;W(`3OIM97)O(&1O(&-A<G3C;R!D92!C<NED:71O
M`$-R;^%C:6$`0W5B80`T($9A<V5S($%T=6%I<P!397-S]65S($%T=6%I<P!(
M;W)A($%T=6%L`$$@55),(&%T=6%L(.D`57-UX7)I;W,@;F\@;6]M96YT;P!#
M;&EM82!!='5A;`!#;VYD:>?C;R!A='5A;#H@`$5S=&EL;R!A='5A;`!#=7-T
M;VUI>F$@=&%R969A<R!A('-E<F5M(&5X96-U=&%D87,@86\@8V]N96-T87(@
M82`E<RX`0V]R=&%R`$-O<G1A<B!S96QEY^-O`$-H:7!R90!#:7+M;&EC;R`H
M2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4Q*0!#:7+M;&EC;R]58W)A
M;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A(%1C:&5C80!$1`!$4TX@*'9E:F$@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*0!$:6%R:6%M96YT90!.879E9V%D;W(@9&4@
M1&%T851R964`4&5S<75I<V$@;F\@0F%N8V\@9&4@1&%D;W,`1&%T80!$871A
M(&1E(%)E8V5B:6UE;G1O`%-E;&7GXV\@9&4@9&%T80!$:6$`15]X8VQU:7(@
M0V]L=6YA`$1E>F5M8G)O`$[Z;65R;W,@9&5C:6UA:7,`4F5C=6%R($ED96YT
M8>?C;P!0861RXV\`0V]R(%!A9'+C;P!)9&5N=&ED861E(%!A9'+C;P!3:&5L
M;"!0861RXV\`1&5F:6YIY_5E<P!%>&-L=6ER`$5X8VQU:7(@8^EL=6QA`$5X
M8VQU:7(@1W)U<&\`17AC;'5I<B!,;V<`17AC;'5I<B!097)M:7-SXV\`17AC
M;'5I<B!E('!U<F=A<B!M96YS86=E;G,`17AC;'5I<B!CZ6QU;&$`17AC;'5I
M<B!C;VQU;F$`17AC;'5I<B!M;V1E;&\@<W5B<W1I='5T;R!E>&ES=&5N=&4`
M17AC;'5I<B!P97)M:7-S]65S('!A<F$@)R5S)P!%>&-L=6ER('!E<FUI<W/U
M97,@<&%R82`G)7,G(&4@<75A;'%U97(@;W5T<F$@<W5B+7!E<FUI<W/C;S\`
M17AC;'5I<B!L:6YH80!%>&-L=6ER(&ED96YT:61A9&4@<V5L96-I;VYA9&$`
M17AC;'5I<B!A(&-O;'5N82!A='5A;`!%>&-L=6ER(&$@;&EN:&$@871U86P`
M4V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R`G)7,G(&5X
M8VQU[61O+@!(;W)A(&1E(&5N=')E9V$`1&EN86UA<F-A`$1E<V-R979A(&\@
M<')O8FQE;6$`1&5S8W)IY^-O`$1E=&%L:&5S("AT86UBZ6T@;F\@<F5G:7-T
M<F\@9&4@871I=FED861E<R!D;R!(;W)D92DZ`$]S(&1E=&%L:&5S(&9O<F%M
M(&=R879A9&]S(&5M(&QO9R!P87)A(&\@861M:6YI<W1R861O<BX`1&5S96YV
M;VQV:6UE;G1O`%!O;G1O(&1E($]R=F%L:&\`4&]N=&\@9&4@3W)V86QH;R!P
M87)A(&$@^FQT:6UA(&AO<F$Z(`!0;VYT;R!D92!/<G9A;&AO.B``1&ER9>?C
M;R!D82!E<W%U97)D82!P87)A(&1I<F5I=&$`1&ER9>?C;R!D82!D:7)E:71A
M('!A<F$@97-Q=65R9&$`1&ER973S<FEO`$5X:6)I<B!E;2!F;W)M871O(#(T
M(&AO<F%S/P!/<.?U97,@9&4@17AI8FGGXV\`17AI8FER('!R979I<^-O(&1E
M=&%L:&%D80!%>&EB:7(@<')E=FESXV\@*%1!1BD`17AI8FER(&9O<FUA=&\`
M3F]T:69I8V'GXV\@9&4@1&ES<&]S:>?C;P!$:FEB=71I`$[C;R!E>&-L=6ER
M`$[C;R!A8V5S<V4@9&ER971A;65N=&4@;6%I;G1E;F%N8V4N<&AP`$$@<')I
M;65I<F$@;&EN:&$@8V]N=.EM(&]S(&YO;65S(&1O<R!C86UP;W,_(%-E('-I
M;2P@8VQI<75E(&YE<W1A(&-A:7AA.@!$;VUI;FEC86YA`%)E</IB;&EC82!$
M;VUI;FEC86YA`$[C;R!T96T@=6UA(&-O;G1A/R!#861A<W1R92US92X`0F%I
M>&%R`$)A:7AA<B`E<P!"86EX87(@82!C;VYF:6=U<F'GXV\@9V5R861A(&-O
M;6\@=6T@<V-R:7!T(%!(4"X`3&ES=&$@9&4@<V5L9>?C;P!$<F]G87,`0V]R
M<F5I;P!#;VYE8W1O<B!D;R!G871E=V%Y($5-86EL+7!A<F$M4TU3+"!P87)A
M(&]P97)A9&]R87,@<75E(&1I<W!O;FEB:6QI>F%M(&5S=&4@<V5R=FGG;RX`
M15)2`$5Q=6%D;W(`161I=&%R`$5D:71A<B!";&]C;P!%9&ET87(@1W)U<&\`
M161I=&%R(%!E<FUI<W/C;P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@4&5R
M;6ES<_5E<R!P87)A("5S`$5D:71A<B!O<.?U97,@9&4Z`$5D:71A<B!P97)M
M:7-S]65S('!A<F$@)7,`161I=&%R('!E<FUI<W/U97,@<&%R82`E<P!%9'5C
M8>?C;P!%9VET;P!%;"!386QV861O<@!%;&5M96YT;RXN+@!%;0!%+6UA:6P`
M16YD97)EYV\@9&4@12U-86EL`$\@96YD97)EYV\@9&4@92UM86EL(&1E=F4@
M8V]R<F5S<&]N9&5R+@!-96YS86=E;2!C;VT@8V]N9FER;6'GXV\`1V%T97=A
M>2!D92!%36%I;"UP87)A+5--4P!%;6]T:6-O;G,`365N<V%G96T@96T@8G)A
M;F-O+@!297-U;'1A9&\@96T@8G)A;F-O+@!497)M;W,@9&4@<&5S<75I<V$@
M96T@8G)A;F-O`$AA8FEL:71A<B!I;G-E<N?C;R!D92!I;6%G96YS(&$@<&%R
M=&ER(&1A($=A;&5R:6$@9&4@26UA9V5N<R!N;R!T97AT;S\`2&%B:6QI=&%R
M(&UE;G4@9&4@8V]N=&5X=&\@8V]M(&\@8F]TXV\@9&ER96ET;S\`1FEN86P@
M9&\@86YO`$%U;65N=&%R($5D:71O<@!&;W)N9>=A('5M82!P97)G=6YT82!D
M92!S96=U<F%NYV$@82!Q=6%L('9O8^H@<V5RX2!P97)G=6YT861O('-E('9O
M8^H@;F5C97-S:71A<B!G97)A<B!U;6$@;F]V82!S96YH82P@97@N("=Q=6%L
M(&\@;F]M92!D;R!S974@8V%C:&]R<F\_)SH`1F]R;F7G82!A(%523"!D82!I
M;6%G96T@87%U:0!$:6=I=&4@87,@;&5T<F%S(&%B86EX;SH`1W5I;ND@17%U
M871O<FEA;`!%<FET<NEI80!%<G)O`$5R<F\@86\@8W)I87(@8FQO8V\Z("5S
M`$5R<F\@86\@97AC;'5I<B#B;F-O<F$@9&4@<VEN8W)O;FEZ8>?C;SH@)7,`
M17)R;R!A;R!E>&-L=6ER(&QO9R!D92!S:6YC<F]N:7IAY^-O.B`E<P!%<G)O
M(&%O(&]B=&5R(&-O;G1E^F1O.B`E<P!%<G)O(&%O(&%T=6%L:7IA<B!A('-E
M;FAA.B`E<P!%<G)O(&YA(&UE;G-A9V5M+@!%<G)O(&=R879A;F1O("<E<R<N
M`$5S=/1N:6$`171I\W!I80#)=&YI8V\`175R;W!A`$-A9&$@,34@;6EN=71O
M<P!#861A(#(@;6EN=71O<P!#861A(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU
M=&]S`$-A9&$@0V]N97CC;P!#861A(&UE:6$@:&]R80!#861A(&UI;G5T;P!6
M86QO<F5S(&1E(&5X96UP;&\Z`$5X96-U=&%R`$5X<&%N9&ER`$5X<&%N9&ER
M($)A<G)A($QA=&5R86P`17-P97)A9&\@)RDG`$5S<&5R861O('5M82!P86QA
M=G)A(&]U('1E<FUO(&1E('!E<W%U:7-A(&5N=')E(&%S<&%S`$1A=&$@9&4@
M17AP:7)AY^-O`$5X<&]E;G1E`$-O<B!D;R!P<FEM96ER;R!P;&%N;P!#;VYF
M:6=U<F'GXV\@9&4@96YV:6\@9&4@87)Q=6EV;W,@1E10`$9A;&AA(&]B=&5N
M9&\@<')E9F5RZFYC:6%S+@!&86QH82!A;R!C;VYE8W1A<B!A;R!S97)V:61O
M<B!,1$%0+@!&86QH82!A;R!C;VYE8W1A<B!A;R!S97)V:61O<B!334(N`$9A
M;&AA(&%O(&-O<&EA<B!D92`B)7,B+@!&86QH82!A;R!C;W!I87(@<&%R82`B
M)7,B+@!&86QH82!A;R!C<FEA<B!U;6$@;F]V82!C;VYE>.-O(%-!4TPN`$9A
M;&AA(&%O(&UO=F5R('!A<F$@(B5S(BX`1F%L:&$@86\@;V)T97(Z("5S`$IU
M<W1O`$EL:&%S($9A;&ML86YD("A-86QV:6YA<RD`26QH87,@1F%R;V4`17)R
M;R!&871A;#H`1F%X`$9A>&5S`$9E=F5R96ER;P!396YS8>?C;R!4Z7)M:6-A
M`%-E;G-AY^-O('3I<FUI8V$Z(`!086YC861A<R!D92!#:'5V80!.979E($9R
M86-A`$UA=')I>B!D;R!C86UP;P!&:6=L970@0T%05$-(00!&;VYT92!&:6=L
M970`1FEJ:0!A<G%U:79O`$-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U
M:79O`$-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O<P!'97)E;F-I
M861O<B!D92!!<G%U:79O<P!.;VUE(&1O($%R<75I=F\`4V5L9>?C;R!D92!A
M<G%U:79O`$5N=FEO(&1E(&%R<75I=F\`16YV:6\@9&4@87)Q=6EV;W,@;N-O
M(.D@<W5P;W)T861O+@!&:6QT<F]S`$9I;FSB;F1I80!0<FEM96ER82!-971A
M9&4`4')I;65I<F\@475A<G1O`%1A>&$@9FEX80!':7)A<@!$:7-P;W-IY^-O
M`$[I=F]A`%!A<W1A("5S(&[C;R!E>&ES=&4`0V]R(&1A($9O;G1E`$-O;6ED
M80!087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T86T@:6UA9V5N<P!0
M<F5V:7/C;R`H5$%&*0!$:6%S(%!R979I<W1O<R`H3F]T92!Q=64@82!P<F5V
M:7/C;R!R971O<FYA9&$@97AI8F4@86UB;W,@9&EA(&4@;F]I=&4[('5M(&[Z
M;65R;R!M=6ET;R!A;'1O(&%Q=6D@<&]D92!R97-U;'1A<B!E;2!U;2!B;&]C
M;R!E>'1E;G-O*0!%<W%U96-E=2!A('-E;FAA/P!&;W)M=6SA<FEO<P!3;W)T
M90!4:7!O(&1E(%-O<G1E`%-O<G1E<P!3;W)T97,@,@!&\W)U;G,`4F5D:7)E
M8VEO;F%M96YT;W,`4V5X`%%U861R;W,`1G)A;N=A`$9R86[G82!-971R;W!O
M;&ET86YA`$=U:6%N82!&<F%N8V5S80!0;VQI;NES:6$@1G)A;F-E<V$`5&5R
M<FET\W)I;W,@1G)A;F-E<V5S(&1O(%-U;`!$90!$;RAA*0!$97-C<FGGXV\@
M0V]M<&QE=&$`3'5A($-H96EA`$YO;64@0V]M<&QE=&\`1V%BXV\`1V%L97)I
M82!D92!O;F1E(&]B=&5R(&%S(&EM86=E;G,`1V%L97)I83H`1^)M8FEA`$=E
M<F%R(&$@0V]N9FEG=7)AY^-O(&1E("5S`$/S9&EG;R!'97)A9&\`1V7S<F=I
M80!!;&5M86YH80!'86YA`$=I8G)A;'1A<@!0<FEM96ER;R!.;VUE`$]PY_5E
M<R!';&]B86ES`$ER`$=O961E;`!';V]G;&4@36%P87,`4&5S<75I<V%R(&YO
M($=O;V=L90!%<V-A;&$@9&4@0VEN>F%S`$=RZ6-I80!'<F5G;R`H25-/+3@X
M-3DM-RD`1W)O96SB;F1I80!'<F%N861A`$%D;6EN:7-T<F'GXV\@9&4@1W)U
M<&]S`$YO;65S(&1E(&=R=7!O<R!NXV\@9&5V96T@97-T87(@96T@8G)A;F-O
M`$=R;W5P7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R(&=R=7!O("5S+B!)
M<W1O(.D@;R!Q=64@;R!S97)V:61O<B!D:7-S93H@`$=R;W5P7VQD87`Z($EM
M<&]S<^UV96P@97AC;'5I<B!G<G5P;R`E<P!'<F]U<%]L9&%P.B!);7!O<W/M
M=F5L(&%T=6%L:7IA<B!G<G5P;R`E<P!'<G5P;W,`1W5A9&%L=7!E`$=U86T`
M1W5A=&5L86UA`$=U97)N<V5Y`%!E<FUI<W/U97,@9&4@0V]N=FED861O`$QI
M=G)O(&1E(%9I<VET87,`1W5I;ND`1W5I;NDM0FES<V%U`$=U:6%N80!(5$U,
M`$A434Q!<F5A('-E(&YE9V$@8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL
M=&EM82!CZ6QU;&$@9&$@;&EN:&$N`$A434Q!<F5A('-E(&YE9V$@8V]V87)D
M96UE;G1E(&$@97AC;'5I<B!A(/IL=&EM82!C;VQU;F$@9&$@=&%B96QA+@!(
M5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I
M;6$@;&EN:&$@9&$@=&%B96QA+@!!=71E;G1I8V'GXV\@2%144"!NXV\@96YC
M;VYT<F%D82X`2&%I=&D`06QG;W)I=&UO($AA<V@`3F5B;&EN80!#86)EYV%L
M:&\`0V%B9>=A;&AO`$EL:&$@2&5A<F0@92!);&AA<R!-8T1O;F%L9`!496UP
M97-T861E($9O<G1E`$AE8G)E=2`H25-/+3@X-3DM."U)*0!!;'1U<F$`06IU
M9&$`06IU9&$@9&\@961I=&]R`$%S<VES=&5N=&4`2&5M:7-FZ7)I;P!!<75I
M(&5S=.$@;R!I;NUC:6\@9&\@87)Q=6EV;SH`06QT80!)7V[M8VEO`%-A;G1A
M(%/I("A#:61A9&4M17-T861O(&1O(%9A=&EC86YO*0!);NUC:6\`16YD97)E
MYV\@4F5S:61E;F-I86P`1&ER973S<FEO(%!E<W-O86P`1F]N92!297-I9&5N
M8VEA;`!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($1A
M9&\@6$U,("5S(&EN=N%L:61O(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`
M2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N9&4@86\@
M;V)J971O("5S`$AO<F1E+TMO;&%B.B!.96YH=6T@;V)J971O(&1O('1I<&\@
M)7,@9F]I(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`2&]R9&4O2V]L86(Z
M(%)E;6]V:61O(&-O;2!S=6-E<W-O("5S("(E<R(`2&]R9&4O2V]L86(Z($$@
M96YG:6YE(&1E(&EN=&5G<F'GXV\@<F5Q=65R(&$@97AT96YSXV\@4$A0("=D
M;VUX;6PG`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L(&-R:6%R('5M82!N;W9A
M(.%R=F]R92!834P@<&%R82!O(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@26UP
M;W-S[79E;"!R96UO=F5R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);7!O
M<W/M=F5L(&]B=&5R(&$@:61E;G1I9FEC8>?C;R!-24U%('!A<F$@82!P87)T
M92!D;R!T:7!O("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L('-I;F-R;VYI
M>F%R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!);7!O<W/M=F5L('-I;F-R
M;VYI>F%R(&-O;7!A<G1I;&AA;65N=&]S.B`E<P!(;W)D92]+;VQA8CH@0V]M
M<&%R=&EL:&%M96YT;R!D97-C;VYH96-I9&\@(B5S(@!,:6YH82!(;W)I>F]N
M=&%L`$UA<F=E;2!H;W)I>F]N=&%L`$AO<FEZ;VYT86PZ`$-O;6\@=F]CZB!C
M:&5G;W4@87%U:3\@*%!O<B!F879O<B!C;VUU;FEQ=64A*0!1=6%N=&%S(&-O
M;'5N87,@=F]CZB!G;W-T87)I82!D92!M97-C;&%R/P!1=6%N=&]S(&-A;7!O
M<R`H8V]L=6YA<RD@97AI<W1E;3\`475A;G1A<R!L:6YH87,@=F]CZB!G;W-T
M87)I82!D92!M97-C;&%R/P!5;6ED861E`%5M:61A9&4Z(`!(=6UO<FES=&%S
M`$AU;F=R[6$`1F%L:&$@86\@8W)I87(@8V%I>&$@<&]S=&%L($E-05`Z("5S
M`$9A;&AA(&%O(&5X8VQU:7(@8V%I>&$@<&]S=&%L($E-05`Z("5S`$9A;&AA
M(&%O(&-R:6%R('%U;W1A(&1A(&-A:7AA('!O<W1A;"!)34%0.B`E<P!%;F1E
M<F7G;R!)4`!%;F1E<F7G;R!)4"!NXV\@9&ES<&]N[79E;"X`16YD97)EYV\@
M25`@;N-O(&5S=.$@;F\@8FQO8V\@<&5R;6ET:61O($-)1%(N`%9I;VQAY^-O
M(&1O(&)L;W%U96EO($E0+@!)7VYS:7)A($QI;FAA($%N=&5S`$ES;.)N9&EA
M`%-O;65N=&4@S6-O;F5S`,UC;VYE<R!P87)A("5S`,UC;VYE<R!E('1E>'1O
M`$YO;64@9&$@:61E;G1I9&%D93H`4V4@;N-O(&9O<B!E>&EB:61O(&-O<G)E
M=&%M96YT92P@)7,@<&%R82!A8G+M+6QO(&5M('5M82!N;W9A(&IA;F5L82X`
M4V4@=F]CZB!NXV\@=NH@;F5N:'5M(.UC;VYE(&%O('5T:6QI>F%R(&\@26YT
M97)N970@17AP;&]R97(L('9O8^H@<&]D92!C:&5C87(@97-T82!C86EX82!P
M87)A(&1E<V%B:6QI=&%R(&$@=')A;G-P87+J;F-I82!03D<N`%-E('9O8^H@
M=NH@97-T82!M96YS86=E;2!M87,@;N-O(&$@:6UA9V5M+"!A(&EM86=E;2!Q
M=64@=F]CZB!Q=65R(&5N=FEA<B!NXV\@<&]D92!S97(@97AI8FED82!P96QO
M('-E=2!N879E9V%D;W(N`%!RZ2UV:7-U86QI>F'GXV\@9&$@26UA9V5M.@!5
M4DP@9&$@26UA9V5M`%523"!D82!);6%G96TZ`$EM86=E;2!D82!G86QE<FEA
M`$EM86=E;2!D82!G86QE<FEA.@!%;G9I;R!D92!);6%G96T`26UA9V5N<P!)
M;7!O<G1A<BP@4&%S<V\@)60`0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@
M:6UP;W)T861O<SH`26Y?<V5R:7(@3&EN:&$@07#S<P!#\V1I9V\@9&4@8>?C
M;R!F;W)N96-I9&\@97-TX2!I;F-O<G)E=&\N`%5S=>%R:6\@92]O=2!S96YH
M82!I;F-O<G)E=&]S+@!5<W7A<FEO(&]U(&5N9&5R9>=O(&%L=&5R;F%T:79O
M(&EN8V]R<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O=2!E;G1R92!E;2!C;VYT
M871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@
M;6%I<R!A:G5D82X`075M96YT87(@261E;G1AY^-O`,UN9&EA`%5S=>%R:6]S
M(&EN9&EV:61U86ES`$EN9&]NZ7-I80!);F9O<FUAY^-O`$EN9F]R;6'GXV\`
M3N-O(&5X:7-T96T@;W#G]65S(&1I<W!O;NUV96ES+@!);G-E<FER($-?;VQU
M;F$@07#S<P!);G-E<FER($EM86=E;0!);G-E<FER(%1A8F5L80!);G-E<FER
M($QI;FL@9&$@5V5B`$EN<V5R:7(@7T-O;'5N82!!;G1E<P!);G-E<FER('5M
M82!N;W9A(&-O;'5N82!A</-S(&$@871U86P`26YS97)I<B!U;6$@;F]V82!C
M;VQU;F$@86YT97,@9&$@871U86P`26YS97)I<B!U;6$@;F]V82!L:6YH82!A
M</-S(&$@871U86P`26YS97)I<B!U;6$@;F]V82!L:6YH82!A;G1E<R!D82!A
M='5A;`!);G-E<FER('5M('!A<N%G<F%F;R!A</-S(&\@871U86P`26YS97)I
M<B!U;2!P87+A9W)A9F\@86YT97,@9&\@871U86P`26YS97)I<B!U;2!M;V1E
M;&\@86QT97)N871I=F\`1F]R;F7G82!U;2!E;F1E<F7G;R!D92!E+6UA:6P@
M;F\@<75A;"!V;V/J('!O9&4@<F5C96)E<B!A(&YO=F$@<V5N:&$Z`$EN<V5R
M:7(@8^EL=6QA(&%P\W,`26YS97)I<B!CZ6QU;&$@86YT97,`26YS97)I<B!C
M;VQU;F$@87#S<P!);G-E<FER(&-O;'5N82!A;G1E<P!);G-E<FER(&UE;G-A
M9V5N<P!);G-E<FER('!A<N%G<F%F;R!A</-S`$EN<V5R:7(@<&%RX6=R869O
M(&%N=&5S`$EN<V5R:7(@;&EN:&$@87#S<P!);G-E<FER(&QI;FAA(&%N=&5S
M`$9O<FYEYV$@82!R97-P;W-T82!O8G)I9V%T\W)I82!P87)A(&$@<&5R9W5N
M=&$@9&4@<V5G=7)A;N=A.@!);G-E<FER+T%L=&5R87(@26UA9V5M`$EN<V5R
M:7(O06QT97)A<B!,:6YK`$-RZ61I=&\@:6YS=69I8VEE;G1E('!A<F$@96YV
M:6%R('!A<F$@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N`$-RZ61I=&\@:6YS
M=69I8VEE;G1E+@!.^FUE<F\@26YT96ER;P!,:7-T82!D92!);G1E:7)O<P!#
M1%4@*$-A8F7G86QH;R!D92!$861O<R!D92!5<W7A<FEO*2!I;G;A;&ED;RX`
M1&%D;W,@6DE0(&EN=N%L:61O<P!!<&QI8V'GXV\@:6YVX6QI9&$N`$ED96YT
M:69I8V'GXV\@9&\@8F%T8V@@:6YVX6QI9&$N`$1A9&]S(&5N=FEA9&]S('/C
M;R!I;G;A;&ED;W,N`$5N9&5R9>=O(&1E(&1E<W1I;F\@Z2!I;G;A;&ED;RX`
M1F]R;6%T;R!D;R!A<G%U:79O(.D@:6YVX6QI9&\`3OIM97)O(&1E(&QI8V5N
MYV$@:6YVX6QI9&\N`$QO8V%L:7IAY^-O(&9O<FYE8VED82#I(&EN=N%L:61A
M+@!4:7!O(&1A(&UE;G-A9V5M(.D@:6YVX6QI9&\N`$%P:5]I9"#I(&EN=N%L
M:61O(&]U(&5S=.$@9F%L=&%N9&\N`%!A<N)M971R;W,@:6YVX6QI9&]S(&]U
M(&9A;'1A;F1O+@!097)M:7-S]65S(&1O('!A:2!SXV\@:6YVX6QI9&%S+@!0
M97)M:7-S]65S(&1O('!A:2!SXV\@:6YVX6QI9&%S+@!#\V1I9V\@9&\@<')O
M9'5T;R#I(&EN=N%L:61O+@!0<F]T;V-O;&\@:6YVX6QI9&\N`$1E<W1I;F%T
MX7)I;R!I;G;A;&ED;SH@)R5S)P!/8FIE=&\@8V]M<&%R=&EL:&%D;R!I;G;A
M;&ED;P!&;VYT92!D;R!E;F1E<F7G;R!I;G;A;&ED82X`1&%D;W,@=6YI8V]D
M92!I;G;A;&ED;W,N`$EN=F5N=.%R:6\`26YV97)T97(@<V5L9>?C;P!)<N,L
M(%)E</IB;&EC82!)<VSB;6EC82!D;P!)<F%Q=64`27)L86YD80!);&AA(&1O
M($AO;65M`%1E;7!E<W1A9&5S($ES;VQA9&%S`$ES<F%E;`!%;6ES<V]R`$ET
MX6QI8V\`273A;&EA`$IA;6%I8V$`2F%N96ER;P!*87#C;P!*87!O;NIS("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F3B;FEA`$IU;&AO`$IU;FAO`$IU<W1I
M9FEC87(`06QI;FAA<B!A;R!#96YT<F\`2G5S=&EF:6-A<@!!;&EN:&%R(.`@
M17-Q=65R9&$`06QI;FAA<B#@($1I<F5I=&$`0V%Z87%U:7-TXV\`36%N=&5R
M(&\@;W)I9VEN86P_`%%UZFYI80!397)V:61O<B!K97)B97)O<R!R96IE:71O
M=2!A(&%U=&5N=&EC8>?C;RX`3F]V871O<R!D92!+97)N96P`0W)I8>?C;R!D
M92!#:&%V90!);7!R97-SXV\@1&EG:71A;"!D82!#:&%V90!486UA;FAO(&1A
M($-H879E`%1I<&\@9&$@0VAA=F4`57-O(&1A($-H879E`$-H879E(&KA(&5X
M:7-T92!N;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N`$-R:6%NYV%S
M`$MI<FEB871I`$-O<NEI82P@4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I
M8V$@9&$`0V]RZ6EA+"!297#Z8FQI8V$@9&$`0V]R96%N;R`H155#+4M2*0!+
M=7=A:70`475I<F=U:7-TXV\`3&%?>6]U=`!)9&EO;6$`3&%O(%)E</IB;&EC
M82!$96UO8W+A=&EC82!0;W!U;&%R`-IL=&EM82!-971A9&4`1V5R87(@3F]V
M82!396YH80#:;'1I;6\@475A<G1O`-IL=&EM82!!='5A;&EZ8>?C;SH`VFQT
M:6UO(&QO9VEN.B`E<P#:;'1I;6\@;&]G:6XZ("5S(.`@<&%R=&ER(&1E("5S
M`-IL=&EM;R!L;V=I;CH@3G5N8V$`3&5T]&YI80!,96D`3&%Y;W5T`$1E:7AA
M('9A>FEO('-E('%U:7-E<B!S96T@8F]R9&$`3.UB86YO`$5S<75E<F1A`$-A
M8F7G86QH;R!E<W%U97)D;P!686QO<F5S(&1A(&5S<75E<F1A`$QE<V]T;P!!
M;6]R`$QI8NER:6$`3.UB:6$@P7)A8F4@2F%M86AI<FEY80!,:65C:'1E;G-T
M96EN`$-H:79I<V-O1G)A8V\`0VAU=F$@1G)A8V$`0VAU=F$@1G)A8V$@36%T
M=71I;F$`0VAU=F$@1G)A8V$@5F5S<&5R=&EN80!,979E<R!086YC861A<R!D
M92!#:'5V80!#:'5V87,@1G)A8V%S(&-O;2!4<F]V]65S`$YE=F4@1G)A8V$`
M0G)E=F4@3F5V87-C80!0;^IM87,`3&EN:P!,:6YK(&%P;VYT82!P87)A.@!,
M:6=A<B!O(&5N9&5R9>=O(&1E(&4M;6%I;"#@('#A9VEN82!D92!C;VUP;W-I
MY^-O(&%O(&5X:6)I<@!,:6YK<P!#;V]K:64@9&\@3&EN=7@`3&ES=&%R("T@
M=7-UX7)I;R!P;V1E('9E<B!A('!A<W1A`$QI<W1A<B!"86YC;W,@9&4@1&%D
M;W,`3&ES=&%R(%3S<&EC;W,@9&4@06IU9&$`3&ES=&%R(%1A8F5L87,`3&ES
M="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0
M;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`02!L:7-T86=E
M;2!D92!S97-S]65S(&9A;&AO=3H@)7,`02!L:7-T86=E;2!D92!U<W7A<FEO
M<R!F86QH;W4Z("5S`$QI<W1A9V5M(&1E('5S=>%R:6]S(&5S=.$@9&5S86)I
M;&ET861A+@!,:71E<F%T=7)A`$QI='7B;FEA`$-A<G)E9V%N9&\N+BX`2&]R
M82!L;V-A;#H@`$QO8V%L:7IAY^-O(&4@2&]R80!296=IXV\`0V]N96-T87(`
M3&]G(&1A('-E<W/C;R!D92!S:6YC<F]N:7IAY^-O(&%N=&5R:6]R`$1E<V-O
M;F5C=&%R`$-O;F5C=&%R`%1A<F5F87,@9&4@0V]N97CC;P!/(&QO9VEN(&9A
M;&AO=2!P;W)Q=64@<V5U('5S=>%R:6\@;W4@<V5N:&$@97-T879A(&EN8V]R
M<F5T82X`1F%L:&$@9&4@3&]G:6XN`%1E>'1O(&QO;F=O`$%M;W(`0F%I>&$`
M06QF86)E=&\@9W)E9V\@96T@;6EN^G-C=6QO`$%L9F%B971O(&QA=&EN;R!E
M;2!M:6[Z<V-U;&\`3OIM97)O<R!R;VUA;F]S(&5M(&UI;OIS8W5L;P!,=7AE
M;6)U<F=O`$U-`$U/5$0`3R!A;F5X;R!-4RU43D5&(&[C;R!C;VYTZ6T@9&%D
M;W,N`$U31P!-86-A;P!-86-E9&]N:6$L($%N=&EG82!297#Z8FQI8V$@275G
M;W-LX79I82!D80!-861A9V%S8V%R`$WA9VEC;P!#;W)R96EO`$%D;6EN:7-T
M<F%D;W(@9&\@0V]R<F5I;P!#<FEA<B!L:6Y?:RXN+@!-86QA=VD`36%LX7-I
M80!-86QD:79A<P!-86QI`$UA;'1A`$=E<F5N8VEA(&$@;&ES=&$@9&4@8V%T
M96=O<FEA<R!E(&%S(&-O<F5S(&%S<V]C:6%D87,@82!E;&%S+@!-87!E86UE
M;G1O($UA<#(T`$UA<&5A;65N=&\@36%P475E<W0`36%P96%M96YT;W,@9W)A
M=F%D;W,N`$UA<N=O`$UA<F=E;0!-87)C87(@8V]M(&9L86=S($QI9&$O3N-O
M($QI9&$`36%R8V%R(&-O;2!O=71R;W,@9FQA9W,@*&5X+B!);7!O<G1A;G1E
M+U)E<W!O;F1I9&$I`$EL:&%S($UA<G-H86QL`$UA<G1I;FEC80!#86UP;W,@
M8V]R<F5S<&]N9&5N=&5S`$UA=7)I=.)N:6$`36%U<NUC:6\`0W+I9&ET;R!M
MX7AI;6\@<&5R;6ET:61O+@!.^FUE<F\@;>%X:6UO(&1E('!A<G1E<R!D82!M
M96YS86=E;2!E>&-E9&5U+@!496UP97)A='5R82!MX7AI;6$@;F%S(/IL=&EM
M87,@,C0@:&]R87,Z(`!496UP97)A='5R82!MX7AI;6$@;F%S(/IL=&EM87,@
M-B!H;W)A<SH@`$[Z;65R;R!-X7AI;6\@9&4@0FQO8V]S(&1E(%!O<G1A;`!4
M86UA;FAO(&WA>&EM;P!-86EO`$UA>6]T=&4`365D:6-I;F$`365M8G)O<P!-
M;V1O(&1O(&UE;G4Z`$UE<V-L87(@8^EL=6QA<P!-96YS86=E;0!-96YS86=E
M;2!697)I9FEC861A(&-O;2!3=6-E<W-O(&UA<R!O(&-E<G1I9FEC861O(&1O
M(&%S<VEN86YT92!NXV\@</1D92!S97(@=F5R:69I8V%D;RX`365N<V%G96T@
M97AP:7)A9&$N`%1I<&\@9&4@;65N<V%G96T`0VQI;6$@365T87(`0FQO8V\@
M365T87(@;N-O(&1I<W!O;NUV96PN`$)L;V-O($UE=&%R(&[C;R!D:7-P;V[M
M=F5L+B!$971A;&AE<R!F;W)A;2!G<F%V861O<R!E;2!L;V<@<&%R82!O(&%D
M;6EN:7-T<F%D;W(N`$\@365T87)$0B!NXV\@97-TX2!C;VYE8W1A9&\N`$WI
M=&]D;P!-Z71O9&\@)R5S)R!NXV\@97-TX2!D969I;FED;P!-Z71O9&\@;N-O
M(&1E9FEN:61O+B!-Z71O9&\@8VAA;6%D;SH@)7,`3>ET<FEC80!-Z7AI8V\`
M36EC<F]NZ7-I82P@17-T861O<R!&961E<F%D;W,@9&$`365I;P!4:7!O($UI
M;64`5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#(T(&AO<F%S.B``
M5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,Z(`!)9&%D
M92!M[6YI;6$@9&$@<V5N:&$@86EN9&$@;N-O(&5X<&ER;W4`17-P96QH;P!$
M:79E<G-O<P!086-O=&4@4$5!4B!(5%107U)E<75E<W0@9F%L=&%N9&\N`$-O
M;F9I9W5R8>?C;R!F86QT86YD;RX@5F]CZB!T96T@<75E(&=E<F%R(&5L82!A
M9V]R82!S92!V;V/J('%U97(@=71I;&EZ87(@97-T82!A<&QI8V'GXV\N`$E$
M(&1A(&UE;G-A9V5M(&9A;'1A;F1O+@!086-O=&4@;V)R:6=A=/-R:6\@4$5!
M4B!-86EL(&9A;'1A;F1O+@!)1"!D82!S97-SXV\@9F%L=&%N9&\N`%-E9P!#
M;W)R96EO($WS=F5L`$UO9&5R87(`1&%T82!-;V1I9FEC861A`$%L=&5R87(@
M55),`$WS9'5L;P!-;VQD;W9A+"!297#Z8FQI8V$@9&$`3?1N86-O`$UO;F?S
M;&EA`$WJ<R!E(&%N;P!-96YS86QM96YT90!-;VYT<V5R<F%T`$9A<V5S(&1A
M($QU80!-86ES(&-A;7!O<R!E;F-O;G1R861O<R!N82!L:6YH82`E9"!Q=64@
M;R!N^FUE<F\@97-P97)A9&\@)60N`$UA<G)O8V]S`$=R86YD92!087)T92!,
M:6UP80!'<F%N9&4@4&%R=&4@3G5B;&%D;P!'<F%N9&4@4&%R=&4@16YS;VQA
M<F%D;P!-;W9E<B!!8F%I>&\`36]V97(@X"!%<W%U97)D80!-;W9E<B#@($1I
M<F5I=&$`36]V97(@06-I;6$`06)A:7AO`$%C:6UA`$UOYV%M8FEQ=64`3&ES
M=&%S(&1E('-E;&7GXV\@9&4@;?IL=&EP;&]S(&[M=F5I<P!-87!A<R!);F=L
M97-E<R!-=6QT:6UA<`!396QEY^-O(&WZ;'1I<&QA`$UI;FAA($-O;G1A`%-U
M87,@26YF;W)M8>?U97,`365U(%!O<G1A;`!-974@3&%Y;W5T(&1E(%!O<G1A
M;`!":7)MXFYI80!.PT\L($5U($[#3R!#;VYC;W)D;P!.;VUE`$YA;>UB:6$`
M3F%U<G4`3F5P86P`2&]L86YD80!!;G1I;&AA<R!(;VQA;F1E<V%S`%523"!"
M87-E(&1O($YE='-C87!E`%523"!D92!2979O9V'GXV\@9&4@0T$@9&\@3F5T
M<V-A<&4`55),(&1E('!O;.UT:6-A<R!D92!#02!D;R!.971S8V%P90!54DP@
M9&4@4F5N;W9AY^-O(&1O($YE='-C87!E`%523"!D92!2979O9V'GXV\@9&\@
M3F5T<V-A<&4`3F]M92!D;R!S97)V:61O<B!34TP@9&\@3F5T<V-A<&4`0V]M
M96YTX7)I;R!D;R!C97)T:69I8V%D;R!D;R!.971S8V%P90!4:7!O(&1E(&-E
M<G1I9FEC861O(&1O($YE='-C87!E`%)E9&4`3G5N8V$`3F]V82!#86QE9/1N
M:6$`3F]V82!#871E9V]R:6$`3F]V82!-96YS86=E;2!P87)A("5S`$QU82!.
M;W9A`$YO=F\@57-UX7)I;R`H;W!C:6]N86PI`$YO=F$@6F5LXFYD:6$`3F]V
M82!S96YH80!.;W9A('-E;FAA(&5X<&ER87+A(&5M("5X+@!!<R!N;W9A<R!S
M96YH87,@;N-O('/C;R!I9W5A:7,N`$YO=F$@:F%N96QA("A?8FQA;FLI`$YO
M=.UC:6%S`$=R=7!O<R!D92!.;W3M8VEA<P!0<O-X:6UA`%!R\WAI;6%S(#0@
M1F%S97,`4'+S>&EM87,@;W#G]65S`%!R\WAI;6$^`$YI8V%RX6=U80!.:6=E
M<@!.:6?I<FEA`$YO:71E`$YI=64`3N-O`$YE;FAU;2!D861O(&1E(&-O;F9I
M9W5R8>?C;R!D:7-P;V[M=F5L('!A<F$@97AI8FER(&%S(&1I9F5R96[G87,N
M`$YE;FAU;6$@97-T<F%TZ6=I82!D:7-P;V[M=F5L('!A<F$@8W)I87(@:6UA
M9V5N<R!)4T\N`$YE;FAU;2!M;V1E;&\@9&4@8F%T8V@N`$YE;FAU;2!B;&]C
M;R!E>&ES=&4@;F$@<&]S:>?C;R!S;VQI8VET861A`$YE;FAU;2!N;VUE(&1E
M(&%G96YD82!F;W)N96-I9&\@<&%R82!A(&%U=&5N=&EC8>?C;R!-0T%,+@!.
M96YH=6UA(&%L=&5R8>?C;RX`3F5N:'5M('-U8F]R9&EN861O('!O9&4@<V5R
M(&%D:6-I;VYA9&\@82!E<W1A('!E<FUI<W/C;RX`3F5N:'5M82!I;F9O<FUA
MY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R82`E<RX`3F5N
M:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@
M<&%R82!&5%`@5D93+@!.96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)A
MY^-O(&5S<&5C:69I8V%D82!P87)A(%-13"!61E,N`$YE;FAU;6$@:6YF;W)M
M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@4U%,+49I
M;&4@5D93+@!.96YH=6T@8W+I9&ET;R!R97-T86YT92X`3F5N:'5M(&1E<W1I
M;F\@9F]R;F5C:61O+@!.96YH=6T@87)Q=6EV;R!E;G9I861O`$YE;FAU;2#M
M8V]N92!E;F-O;G1R861O+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R
M861A+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!.96YH=6UA
M(&UE;G-A9V5M(&9O<FYE8VED82X`3F5N:'5M(&YO;64@97-P96-I9FEC861O
M+@!.96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RX`4V5M('-O<G1E<R!O9F5N
M<VEV87,`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC
M8>?C;R!(5%10+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T
M96YT:6-AY^-O($E-05`N`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@
M82!A=71E;G1I8V'GXV\@2V5R8F5R;W,N`$YE;FAU;6$@<V5N:&$@9F]R;F5C
M:61A('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN`$YE;FAU;6$@<V5N:&$@
M9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@4$%34U=$+@!.96YH=6UA
M('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O(%--0BX`3F5N
M:'5M('!A=&@@<&%R82!O(&)I;N%R:6\@9&\@3W!E;E-33"!F;VD@9F]R;F5C
M:61O+B!/(&)I;N%R:6\@9&\@3W!E;E-33"#I(&YE8V5S<^%R:6\@<&%R82!M
M86YI<'5L87(@;W,@9&%D;W,@4$M#4R`Q,BX`3F5N:'5M(&-A9&%S=')O('!E
M;F1E;G1E+@!1=6]T82!NXV\@8V]N9FEG=7)A9&$N`%-E;2!L:6YH87,`3F5N
M:'5M('-E<&%R861O<B!F;VD@97-P96-I9FEC861O+@!396T@;&%D;W,`07)Q
M=6EV;R!I;F5X:7-T96YT90!.96YH=6T@9&ER973S<FEO('1E;7!O<N%R:6\@
M9&ES<&]N[79E;"!P87)A(&\@8V%C:&4N`$YE;FAU;2!U<W7A<FEO(&4O;W4@
M<V5N:&$@9F]R;F5C:61O<RX`3F5N:'5M(&1A9&\@6$U,(';A;&ED;R!R971O
M<FYA9&\`4V5M('9A;&]R97,`3F5N:'5M('9E<G/C;R!E;F-O;G1R861A(&YA
M(&-O;F9I9W5R8>?C;R!O<FEG:6YA;"X@1V5R92!N;W9A;65N=&4@82!C;VYF
M:6=U<F'GXV\N`$YE;FAU;6$@=F5R<^-O(&5N8V]N=')A9&$@;F$@<W5A(&-O
M;F9I9W5R8>?C;RX@1V5R92!N;W9A;65N=&4@82!C;VYF:6=U<F'GXV\N`$YE
M;FAU;6$`3F5N:'5M82`H=7-O(&EM<&SM8VET;RD`3O-R9&EC;R`H25-/+3@X
M-3DM,3`I`$EL:&$@3F]R9F]L:P!(96UI<V;I<FEO($YO<G1E`$EL:&%S($UA
M<FEA;F$@9&\@3F]R=&4`3F]R=65G80!.XV\@07#S<P!.XV\@06YT97,`3N-O
M(.D@=6T@9&ER973S<FEO`$[C;R!);7!L96UE;G1A9&\N`$[C;R!C;VYF:6=U
M<F%D;P!.XV\@<W5P;W)T861O+@!!;F]T8>?U97,`3F%D82!P87)A(&5X:6)I
M<BP@=F]L=&4N`$YO=F5M8G)O`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T97)E
M<P!.^FUE<F\@9&4@8V]L=6YA<P!.^FUE<F\@9&4@;&EN:&%S`$[Z;65R;R!N
MXV\@97-P96-I9FEC861O('!A<F$@871U86QI>F'GXV\@;F$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O+@!/2P!/8FIE=&\`0W)I861O<B!D;R!/8FIE=&\`3V-T
M86P`3W5T=6)R;P!&:6QT<F\@;V9E;G-I=F\`17-C<FET\W)I;P!396YH87,@
M86YT:6=A(&4@;F]V82!D979E;2!S97(@9&EF97)E;G1E<RX`4V5N:&$@86YT
M:6=A`%-E;FAA(&%N=&EG82!NXV\@97-TX2!C;W)R971A+@!/;>,`4V]M96YT
M92!S97)V:61O<F5S($E-05`@<W5P;W)T86T@<&%S=&%S(&-O;7!A<G1I;&AA
M9&%S+@!3;VUE;G1E('-O<G1E<R!O9F5N<VEV87,`4V]M96YT92!U;2!E;F1E
M<F7G;R!D92!E+6UA:6P@<&5R;6ET:61O+@!3;VUE;G1E(&\@<')O<')I973A
M<FEO(&]U(&\@861M:6YI<W1R861O<B!D;R!S:7-T96UA('!O9&5M(&%L=&5R
M87(@87,@<&5R;6ES<_5E<R!D92!P<F]P<FEE9&%D92!O=2!P<F]P<FEE=.%R
M:6\@9&4@=6T@8V]M<&%R=&EL:&%M96YT;P!!8G)I<B!E;2!U;6$@;F]V82!J
M86YE;&$`17)R;R!D;R!/<&5N4U-,.B!.XV\@<'5D92!E>'1R86ER(&1A9&]S
M(&1A('!A<G1E(&%S<VEN861A(%,O34E-12X`06)R92!E<W1E(&QI;FL@96T@
M=6UA(&YO=F$@:F%N96QA`%-I<W1E;6$@3W!E<F%C:6]N86P`3W#G]65S`$]P
MY_5E<R!D92`E<P!,:7-T82!/<F1E;F%D80!/<F=A;FEZ8>?C;P!5;FED861E
M($]R9V%N:7IA8VEO;F%L`$]R9V%N:7IA;F1O`$UO9&5L;R!O<FEG:6YA;"!D
M92!A<&QI8V'GXV\`36]D96QO(&]R:6=I;F%L(&5M("5S.@!/=71R;P!/=71R
M87,@26YF;W)M8>?U97,`4&5R;6ES<_5E<R!D;R!0<F]P<FEE=.%R:6\`075T
M96YT:6-AY^-O(%!!32!NXV\@97-TX2!D:7-P;V[M=F5L+@!#;VYE8W1O<B!0
M14%2.CI-86EL`$%S<VEN871U<F$@1&EG:71A;"!01U``1&%D;W,@0W)I<'1O
M9W)A9F%D;W,@8V]M(%!'4`!#:&%V92!0^F)L:6-A(%!'4`!$861O<R!!<W-I
M;F%D;W,O0W)I<'1O9W)A9F%D;W,@8V]M(%!'4`!#\V1I9V\@4$A0`$QI;FAA
M(&1E($-O;6%N9&\@4$A0`$-H=79A($9R86-A(%9E<W!E<G1I;F$`0VAU=F$@
M5F5S<&5R=&EN80!#:'5V87,@5F5S<&5R=&EN87,`3F5V92!697-P97)T:6YA
M`$YE=F%S8V$@5F5S<&5R=&EN80!.979E(%9E<W!E<G1I;F$`5')O=F]A9&%S
M(%9E<W!E<G1I;F%S`$5S=.$@9F%L=&%N9&\@82!E>'1E;G/C;R!03U-)6`!,
M:6YH82!D92!#;VUA;F1O(%!?2%``36%R9V5M`%!A<75I<W3C;P!086QA=0!0
M86QE<W1I;F\L(%1E<G)I=/-R:6\@3V-U<&%D;P!086YA;>$`4.%P=6$@3F]V
M82!'=6ENZ0!087)A9W5A:0!087)C:6%L;65N=&4@3G5B;&%D;P!396YH80!3
M96YH82!A;'1E<F%D82!C;VT@<W5C97-S;RX`4V5N:&$@:6YC;W)R971A`%-E
M;FAA(&]B<FEG873S<FEA('!A<F$@82!A=71E;G1I8V'GXV\@4D%$2553+@!3
M96YH82!C;VT@8V]N9FER;6'GXV\`4V5N:&$Z`%-E;FAA.B``4V5N:&%S(&1E
M=F5M('-E<B!I9W5A:7,N`$-O;&%R`$-O;&%R(&1A(.%R96$@9&4@=')A;G-F
M97+J;F-I80!0871H`$-A9&%S=')O<R!096YD96YT97,Z`%!E<W-O87,`4&]R
M8V5N=&%G96T`17AE8W5T87(@3W!E<F'G]65S(&1E($UA;G5T96[GXV\`17AE
M8W5T87(@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\@86\@8V]N96-T87(_`%!E
M<FUI<W/C;P!097)M:7-SXV\@(B5S(B!NXV\@97AC;'7M9&$N`%!E<FUI<W/C
M;R!.96=A9&$`4&5R;6ES<_5E<P!!9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U
M97,`26YF;W)M8>?U97,@4&5S<V]A:7,`4&5R=0!!;FEM86ES(&1E($5S=&EM
M8>?C;P!&:6QI<&EN87,`5&5L969O;F4`1F]T;W,`4&ET8V%I<FX`4&EX96QS
M`$-L:6-HZ0!0;W(@9F%V;W(@8VQI<75E(&5M(&%L9W5M82!CZ6QU;&$`4&]R
M(&9A=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@<F5M;W9E<B!E<W1E(&5L
M96UE;G1O.@!0;W(@9F%V;W(@8V]N9FER;64@<75E('9O8^H@<75E<B!R96UO
M=F5R(&\@;&EN:R!D97-T92!E;&5M96YT;RX`4&]R(&9A=F]R(&9O<FYEYV$@
M=6T@;>IS(&4@=6T@86YO+@!0;W(@9F%V;W(@9F]R;F7G82!U;2!N;VUE('!A
M<F$@82!N;W9A(&-A=&5G;W)I83H`4&]R(&9A=F]R(&9O<FYEYV$@=6T@96YD
M97)EYV\@25`@=N%L:61O+@!0;W(@9F%V;W(@9F]R;F7G82!U;6$@9&%T82!V
MX6QI9&$L('9E<FEF:7%U92!O(&[Z;65R;R!D92!D:6%S(&YO(&WJ<RX`4&]R
M(&9A=F]R(&9O<FYEYV$@=6UA(&AO<F$@=N%L:61A+@!0;W(@9F%V;W(@9F]R
M;F7G82!U;2!R97-U;6\@9&\@<')O8FQE;6$N`%!O<B!F879O<B!F;W)N9>=A
M('-E=2!U<W7A<FEO(&4@<V5N:&$`4&]R(&9A=F]R(&QE:6$@;R!T97AT;R!A
M('-E9W5I<BX@5F]CZB!$159%(&-O;F-O<F1A<B!C;VT@;W,@=&5R;6]S(&1E
M('5S;R!D;R!S:7-T96UA+@!0;W(@9F%V;W(@9&EG:71E(&\@;F]M92!D82!N
M;W9A(&-A=&5G;W)I83H`4&]L]&YI80!0;VSM=&EC80!%;G%U971E`%!O<G1U
M9V%L`%!O<VGGXV\@9&5S=&$@:6UA9V5M`%!O<VGGXV\@9&5S=&$@=&%B96QA
M`$5N=FEE('!A<F$@97-T82!P87-T82`H;N-O(.D@;V)R:6=A9&\@<&5L;R!)
M34%0*0!0<F5C:7!I=&'GXV\@<&%R82!A*',I(/IL=&EM82AS*2`E<R!H;W)A
M*',I.B``4')E8VEP:71AY^-O/&)R("\^8VAA;F-E`%!R969S7VQD87`Z($5X
M=&5N<^-O($Q$05`@;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N`%!R969S
M7W-E<W-I;VXZ($5X=&5N<^-O(&1E('-E<W/C;R!O8G)I9V%T\W)I82!NXV\@
M96YC;VYT<F%D82X`4')E<W/C;P!0<F5S<^-O(&5M(&[M=F5L(&1O(&UA<CH@
M`%!R97-SXV\Z(`!0<NDM=FES=6%L:7IAY^-O`%!R979E<B!A(&EM86=E;2!E
M;2!U;6$@;F]V82!J86YE;&$`3W#G]65S(&%N=&5R:6]R97,`26UP<FEM:7(@
M9&]C=6UE;G1O`$-H879E(%!R:79A9&$`4')O8FQE;6$`1&5S8W)IY^-O(&1O
M(%!R;V)L96UA`%!R;VIE=&]S`%1E>'1O(&)R979E`$-H879E(%#Z8FQI8V$`
M06QG;W)I=&UO(&1A($-H879E(%#Z8FQI8V$`0VAA=F4@4/IB;&EC80!087(@
M9&4@8VAA=F5S(%#Z8FQI8V$O4')I=F%D82!NXV\@9F]R86T@9V5R861O<R!C
M;VT@<W5C97-S;RX`4&]R=&\@4FEC;P!1871A<@!#;VYS=6QT87(`46%T87(`
M0VAA=F4@4/IB;&EC82!24T$@*"5D(&)I="D`0F]T]65S(&1E('-E;&7GXV\`
M0VAU=F$`0VAU=F$@36%T=71I;F$`0VAU=F$@5F5S<&5R=&EN80!086YC861A
M<R!D92!#:'5V80!#:'5V82!E($YE=F4`0VAU=F$@<&%R82!.979E`%-O<G1E
M($%L96%T\W)I80!296QAY^-O`$QE<@!,97(@;65N<V%G96YS`$5X8VQU:7(@
M<F5A;&UE;G1E("5S/R!%<W1A(&]P97)AY^-O(&[C;R!P;V1E('-E<B!D97-F
M96ET82X`4F5M;W9E<B!R96%L;65N=&4@;W,@9&%D;W,@9&\@=7-UX7)I;R`E
M<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D92!S97(@9&5S9F5I=&$N`%)E9F%Z
M('-U82#Z;'1I;6$@8>?C;P!!='5A;&EZ87(`071U86QI>F%R($UE;G4@9&4@
M16QE;65N=&]S($1I;N)M:6-O<SH`071U86QI>F%R($5X:6)IY^-O(&1O(%!O
M<G1A;#H`4F5G97@`3F%V96=A9&]R(&1E(%)E;&'G]65S`$QE<@!/8G-E<G9A
MY_5E<P!397)V:61O<F5S(%)E;6]T;W,`55),(%)E;6]T82`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V97(`4F5M;W9E<B!";&]C;P!2
M96UO=F5R(&-O;'5N80!296UO=F5R(&9O<FUA=&'GXV\`4F5M;W9E<B!P87(`
M4F5M;W9E<B!S8W)I<'0@9W)A=F%D;R!N;R!D:7)E=/-R:6\@=&5M<&]RX7)I
M;R!D;R!S97)V:61O<BX`4F5M;W9E<B!O`%)E;6]V97(@97-T92!N\R!D;R!D
M;V-U;65N=&\`4F5M;W9E<B!U<W7A<FEO`%)E;6]V97(@=7-UX7)I;SH@)7,`
M4V]L:6-I=&'GXV\@;N-O('#T9&4@<V5R(')E<W!O;F1I9&$N($/S9&EG;R!D
M92!E<G)O(')E=&]R;F%D;SH@`$\@<V5R=FGG;R!R97%U:7-I=&%D;R!NXV\@
M<&]D92!S97(@96YC;VYT<F%D;RX`)R5S)R!O8G)I9V%T\W)I;R!NXV\@9F]I
M(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@)7,N`"<E<R<@;V)R:6=A
M=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O(%9&
M4RX`)R5S)R!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C
M;VYF:6=U<F'GXV\N`$-A;7!O($]B<FEG873S<FEO`$QI;7!A<@!'97)A<B!.
M;W9A(%-E;FAA`$=E<F%R($YO=F$@4V5N:&$`VFQT:6UO(%%U87)T;P!297-U
M;'1A9&]S`%)E=&]R;F%R(.`@3W#G]65S`$1I9VET92!A(&YO=F$@<V5N:&$@
M;F]V86UE;G1E`%)E=6YIXV\`4F5V97)T97(@0V]N9FEG=7)AY^-O`$]PY_5E
M<R!D;R!%9&ET;W(@4FEC:"!497AT`$-H87)A9&%S`$1I<F5I=&$`0V%B9>=A
M;&AO(&1I<F5I=&\`5F%L;W)E<R!D82!D:7)E:71A`%!R;W!R:65D861E<R!D
M82!?3&EN:&$N+BX`1G5NY^-O`%)O;>IN:6$`1VER87(@,3@P(&=R875S`$=I
M<F%R('!A<F$@82!%<W%U97)D80!':7)A<B!P87)A(&$@1&ER96ET80!0<F]P
M<FEE9&%D97,@9&$@3&EN:&$`4')O<')I961A9&5S(&1A(&QI;FAA`$QI;FAA
M<SH`3&EN:&%S`$QI;FAA<R!A<&%R96-E<N-O(&5N=')E('1O9&%S(&%S(&QI
M;FAA<R!E(&-O;'5N87,`3&EN:&%S(&%P87)E8V5RXV\@<V]M96YT92!E;G1R
M92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O('-O;65N=&4@96YT<F4@;&EN
M:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2=7-S80!2=6%N9&$`07-S:6YA='5R
M82!#<FEP=&]G<N%F:6-A(%,O34E-10!-96YS86=E;2!#<FEP=&]G<F%F861A
M(&-O;2!3+TU)344`075T96YT:6-AY^-O(%-!4TP@;N-O(&5S=.$@9&ES<&]N
M[79E;"X`0V]R<F5I;R!335,`3&EN:&$@9&4@8V]M86YD;R!344P`4V5N=&5N
MYV$@4U%,('!A<F$@<&5S<75I<V%S(&1E('9A;&]R97,`4U-(`%-50T534T\`
M3&EN:&$@9&4@8V]M86YD;R!37U%,`%-A8@!386YT82!(96QE;F$`4^-O($MI
M='1S(&4@3F5V:7,`4V%N=&$@3'5Z:6$`4^-O(%!E9')O(&4@36EQ=65L;VX`
M4^-O(%9I8V5N=&4@92!'<F%N861I;F%S`$UE<VUO('%U861R;R`H7W-E;&8I
M`%-A;6]A`%-A;B!-87)I;F\`4^-O(%1O;>D@92!0<NUN8VEP90!0<F]V961O
M<B!D92!3873I;&ET90!!<N%B:6$@4V%U9&ET80!386QV87(`4V%L=F%R("5S
M`%-A;'9A<B`E<P!386QV87(@3W#G]65S`%-A;'9A<B!C;VYF:6=U<F'GXV\@
M9V5R861A(&-O;6\@=6T@<V-R:7!T(%!(4"!P87)A(&\@9&ER973S<FEO('1E
M;7!O<N%R:6\@9&\@<V5U('-E<G9I9&]R+@!#;VYF:6=U<F'GXV\@)7,@<V%L
M=F$N`%-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@<V%L
M=F\@96TZ("<E<R<N`%1E;7!E<W1A9&5S($ES;VQA9&%S`$-IZFYC:6$`4&5S
M<75I<V%R`$5N9VEN97,@9&4@4&5S<75I<V$@`%-E;&5C:6]N92!O<R!!<G%U
M:79O<P!396QE8VEO;F4@=6UA(&1A=&$`4V5L96-I;VYE('5M(&=R=7!O('!A
M<F$@861I8VEO;F%R`%-E;&5C:6]N92!U;2!N;W9O(&UE;6)R;P!396QE8VEO
M;F4@=6T@<V5R=FED;W(`4V5L96-I;VYE('5M('5S=>%R:6\@<&%R82!A9&EC
M:6]N87(`4V5L96-I;VYA<B!T;V1O<P!396QE8VEO;F4@=&]D;W,@;W,@8V]M
M<&]N96YT97,@9&4@9&%T82X`4V5L96-I;VYE('5M(&]B:F5T;P!.XV\@<V5L
M96-I;VYA<B!N96YH=6T`4V5L96-I;VYE(&]S(&-A<F%C=&5R97,@<75E('9O
M8^H@<')E8VES82!N82!C86EX82!A8F%I>&\N(%9O8^H@<&]D92!E;G3C;R!C
M;W!IX2UL;W,@92!C;VSA+6QO<R!N82#A<F5A(&1E('1E>'1O+@!396QE8VEO
M;F4@=6T@9&5L:6UI=&%D;W(@9&4@9&%T83H`4V5L96-I;VYE(&\@9F]R;6%T
M;R!D92!D871A.@!396QE8VEO;F4@82!I9&5N=&ED861E('%U92!V;V/J('%U
M97(@86QT97)A<CH`4V5L96-I;VYE('5M(&1E;&EM:71A9&]R(&1E(&AO<F$Z
M`%-E;&5C:6]N92!O(&9O<FUA=&\@9&4@:&]R83H`4V5L96-I;VYE(&1O:7,@
M8V%M<&]S(&-O<G)E<W!O;F1E;G1E<RX`4V5L96-I;VYE('-E=2!E<W%U96UA
M(&1E(&-O<F5S+@!396QE8VEO;F4@<V5U(&ED:6]M82!P<F5F97)I9&\Z`$5N
M=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6$`16YV:6%R(%--4P!396YE9V%L
M`%-E;G-O<CH@`%-E=&5M8G)O`%-E<G9I82!E($UO;G1E;F5G<F\`3OIM97)O
M(&1E(%/I<FEE`$1A9&]S(&1O('-E<G9I9&]R(&5R<F%D;W,@;W4@;N-O(&1I
M<W!O;NUV96ES+@!!9&UI;FES=')A9&]R(&1E(%-E<W/C;P!)1"!D82!397-S
MXV\@97AP:7)O=2X`4V5S<_5E<P!!:G5S=&%R`$-O;F9I9W5R82!A<R!O<.?U
M97,@<&%R82!P97)M:71I<B!V;V/J(&=E<F%R('5M82!N;W9A('-E;FAA('-E
M('9O8^H@97-Q=65CZBUL82X`0V]N9FEG=7)A(&]S('-E<G9I9&]R97,@<F5M
M;W1O<R!Q=64@=F]CZB!Q=65R(&%C97-S87(@X"!P87)T:7(@9&\@<&]R=&%L
M+@!#;VYF:6=U<F$@<V5U(&ED:6]M82!P<F5F97)I9&\L(&9U<V\@:&]RX7)I
M;R!E(&]PY_5E<R!D92!D871A+@!#;VYF:6=U<F$@<W5A(&%P;&EC8>?C;R!I
M;FEC:6%L+"!E<W%U96UA(&1E(&-O<F5S+"!A='5A;&EZ8>?C;R!D92!PX6=I
M;F%S(&4@;W5T<F%S(&]PY_5E<R!D92!E>&EB:>?C;RX`0V]N9FEG=7)AY^-O
M`%-C<FEP=',@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O(&1I<W!O
M;NUV96ES`$1I=F5R<V%S(&QO8V%L:61A9&5S('!O<W/M=F5I<R!C;VT@;R!P
M87+B;65T<F\Z(`!396EC:&5L97,`0V]M<')A<P!297-U;6\`5&5C;&%S(&1E
M(&%T86QH;R!D979E<N-O('-E<B!D969I;FED87,@<&%R82!A(&UA:6]R:6$@
M9&]S(&QI;FMS/P!%>&EB:7(`17AI8FER(&%S(&1I9F5R96[G87,@96YT<F4@
M82!C;VYF:6=U<F'GXV\@871U86P@92!A(&YO=F$@9V5R861A+@!%>&EB:7(@
M9&%T82!E(&AO<F$@9&$@^FQT:6UA(&-O;F5XXV\@86\@<V4@8V]N96-T87(_
M`$5X:6)I<B!A(&]PY^-O(&1E(&UA;G1E<B!O(&]R:6=I;F%L`$5X:6)I<B!S
M96QE=&]R`$5X:6)I<B!B87)R82!D92!M96YU(&-O;2!O<&5R8>?U97,@9&4@
M=&%B96QA/P!%>&EB:7(@;R!-96YU("5S(.`@97-Q=65R9&$_`$5X:6)I<B!D
M:>%L;V=O(&1E(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1A(%1A8F5L80!%
M>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&$@5&%B96QA`$5X:6)I
M<B!D:>%L;V=O(&1E(%!R;W!R:65D861E<R!D92!,:6YH87,@9&$@5&%B96QA
M`$5X:6)I<B!D:>%L;V=O(&1E('!R;W!R:65D861E<R!D92!I;6%G96T`17AI
M8FER('5P;&]A9`!#:'5V87,`0VAU=F%S(&UA=&EN86ES`$-H=79A<R!697-P
M97)T:6YA<P!#:'5V87,@;F%S(')E9&]N9&5Z87,`4F5D=7II<@!0<FEM96ER
M86UE;G1E(')E9'5Z82!O=2!T:7)E(&1O(&-A;6EN:&\@;RAS*2!B;&]C;RAS
M*2!A9&IA8V5N=&4H<RD`4V5R<F$@3&5O80!296=I<W1R87(`07-S:6YA='5R
M80!!;&=O<FET;6\@9&$@07-S:6YA='5R80!#:6YG87!U<F$`5&%M86YH;P!)
M9VYO<F%R($UA;G5T96[GXV\`17-L;W;A<75I80!%<VQO=F5N:6$`3F5V90!.
M979A<V-A`$YE=F%S8V%S`$-H=79A<R!M871I;F%I<P!.979A<V-A<R!697-P
M97)T:6YA<P!0<F]F=6YD:61A9&4@9&$@3F5V93H@`$5Q=6EV86QE;G1E(&1E
M(&YE=F4@96T@X6=U83H@`$EL:&%S(%-A;&]MXV\`4V]MX6QI80!#86[G]65S
M("8@4&]E;6%S`$]R9&5N87(@<V5L9>?C;P!%;F1E<F7G;R!D92!O<FEG96T`
MP69R:6-A(&1O(%-U;`!3=6P@175R;W!E=2`H25-/+3@X-3DM,RD`4W5L(&1A
M($=E;W)G:6$@92!3=6P@9&%S($EL:&%S(%-A;F1U[6-H90!(96UI<V;I<FEO
M(%-U;`!%<W!AYV\@96YT<F4@8^EL=6QA<R!A9&IA8V5N=&5S`$5S<&'G;R!E
M;G1R92!O(&-O;G1E^F1O(&4@8F]R9&$@9&$@8^EL=6QA`$5S<&'G861O<@!%
M<W!AYV%M96YT;P!%<W!AYV%M96YT;R!E(&UA<F=E;0!%<W!A;FAA`%-P86T`
M16YT<F%D82!D92!#87)A8W1E<F5S($5S<&5C:6%I<P!$:79I9&ER(&/I;'5L
M80!$:79I9&ER(&-O;'5N80!$:79I9&ER(&QI;FAA`$5S<&]R=&5S`%-R:2!,
M86YK80!0861RXV\`4W1A<B!4<F5K`$%N;R!I;FEC:6%L`$5S=&%D;R!O=2!0
M<F]V[6YC:6$`4VET=6'GXV\`1F]R;6%T;R!D;R!A<FUA>F5N86UE;G1O`$YO
M;64@9&$@4G5A`%1R8>=A9&\`3&ES=&$@9&4@8V%D96EA<R!D92!C87)A8W1E
M<F5S`%)E=&ER87(@82!P87)T92!D;R!D;VWM;FEO(&1O(&5N9&5R9>=O`$5S
M=&EL;R!;0U-370!$;VT`4W5B9&ER973S<FEO("<E<R<@;N-O(&5N8V]N=')A
M9&\N`$%S<W5N=&\`16YV:6%R`$5N=FEA9&$@82!S;VQI8VET8>?C;R!D92!A
M9&EC:6]N87(@(B5S(B!A;R!S:7-T96UA+B!6;V/J(&[C;R!P;V1E(&-O;F5C
M=&%R+7-E(&%TZ2!Q=64@<W5A('-O;&EC:71AY^-O('-E:F$@87!R;W9A9&$N
M`%-U8G-C<F5V97(`4W5C97-S;P`G)7,G(&%D:6-I;VYA9&\@8V]M('-U8V5S
M<V\@86\@<VES=&5M82X`3W,@9&%D;W,@9&\@=7-UX7)I;R`G)7,G(&9O<F%M
M(')E;6]V:61O<R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+@`G)7,G(&5X8VQU
M[61O(&-O;2!S=6-E<W-O+@!%>&-L=>UD;R`G)7,G(&1O('-I<W1E;6$@8V]M
M('-U8V5S<V\N`$-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M('-U8V5S<V\N
M($%T=6%L:7IE('!A<F$@=F5R(&%S(&%L=&5R8>?U97,N`$)A8VMU<"!D82!C
M;VYF:6=U<F'GXV\@<V%L=F$@8V]M('-U8V5S<V\N`$\@8F%C:W5P(&1O(&%R
M<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S(&9O:2!S86QV;R!C;VT@<W5C97-S
M;RX`)R5S)R!A='5A;&EZ861O(&-O;2!S=6-E<W-O`"5S(&=R879A9&\@8V]M
M('-U8V5S<V\`4W5DXV\`4F5S=6UO`$%M86YH96-E<@!0]'(M9&\M4V]L`$5N
M<V]L87)A9&\`06UA;FAE8V5R`$%M86YH96-E<B]0]'(M9&\M4V]L`$%M86YH
M96-E<CH@`%#T<BUD;RU3;VP`4/1R+61O+5-O;#H@`%-O8G)E<V-R979E<@!3
M=7!O<G1E`%-U<FEN86UE`%-O8G)E;F]M90!3=F%L8F%R9"!E($IA;B!-87EE
M;@!3=6%Z:6SB;F1I80!3=>EC:6$`4W7MYV$`3N-O(&5X8VQU:7(`4WEN8TU,
M`$5R<F\@9&4@<VEN=&%X92!N;W,@=&5R;6]S(&1A('!E<W%U:7-A`%)E</IB
M;&EC82#!<F%B92!D82!3[7)I80!496UP97-T861E`%1E;7!E<W1A9&5S(&4@
M5F5N=&%N:6$`5&5M<&5S=&%D97,`5&5M<&5S=&%D97,@36%T:6YA:7,`07)Q
M=6EV;R!44U8`5&%B96QA`%!R;W!R:65D861E<R!D82!486)E;&$`5&%B96QA
M`%!R;W!R:65D861E<R!D82!T86)E;&$`5&%I=V%N`%1A:7=A;BP@4')O=NUN
M8VEA(&1A($-H:6YA`%1A:FEQ=6ES=.-O`%1A;GKB;FEA+"!297#Z8FQI8V$@
M9&$`06QV;SH`5&%R969A<P!.^FUE<F\@9&4@5&5L969O;F4`5&5M<&5R871U
M<F$@<&%R82!A(/IL=&EM82!H;W)A.B``5&5M<&5R871U<F$`5&5M<&5R871U
M<F$Z(`!496UP97)A='5R83QB<B`O/B@E<T%L=&$E<R\E<T)A:7AA)7,I("9D
M96<[)7,`36]D96QO("<E<R<@;N-O(&5N8V]N=')A9&\N`$%D;6EN:7-T<F'G
MXV\@9&4@36]D96QO<P!497AT;P!3;VUE;G1E(%1E>'1O`$%L:6YH86UE;G1O
M(&1E(%1E>'1O`$)O<F1A('-U<&5R:6]R(&1O(%1E>'1O`%%U:0!486EL86YD
MZG,@*%1)4RTV,C`I`%1A:6SB;F1I80!!(&5X=&5N<^-O($944"!NXV\@97-T
MX2!D:7-P;V[M=F5L+@!/(&AI<W3S<FEC;R!D;R!S:7-T96UA(&5S=.$@9&5S
M86)I;&ET861O+@!!(&5N9VEN92!D92!I;G1E9W)AY^-O($AO<F1E+TMO;&%B
M(&[C;R!S=7!O<G1A("(E<R(`3R!L;V<@24U34"!NXV\@<&]D92!S97(@:6YI
M8VEA;&EZ861O+@!!(&-L87-S92`B36%I;G1E;F%N8V4B(&[C;R!F;VD@8V%R
M<F5G861A(&-O;2!S=6-E<W-O`$$@:F%N96QA(&1E($]PY_5E<R!F;VD@9F5C
M:&%D82X@4V%I;F1O+@!/(&%D;6EN:7-T<F%D;W(@<')E8VES82!C;VYF:6=U
M<F%R('5M(&-O;F5C=&]R('!E<FUA;F5N=&4@9&4@4&5R;6ES<_5E<R!S92!V
M;V/J('%U97(@=71I;&EZ87(@4&5R;6ES<_5E<RX`4V]M96YT92!O(&QA9&\@
M9&4@8F%I>&\`3R!N^FUE<F\@240@9&\@8V]N=&%T;R!NXV\@9F]I(&5S<&5C
M:69I8V%D;RP@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R
M861O(&YO(&)A;F-O(&1E(&1A9&]S+@!/(&-O;G1A=&\@9F]I(&%D:6-I;VYA
M9&\@8V]M('-U8V5S<V\@86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX`
M4&%R82!V97)I9FEC87(@82!M96YS86=E;2!A<W-I;F%D82#I(&YE8V5S<^%R
M:6\@=6T@8FQO8V\@<V5P87)A9&\@9&$@87-S:6YA='5R82!01U`N`$\@240@
M9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861O
M+"!D96EX861O(&5M(&)R86YC;R!O=2!NXV\@9F]I(&5N8V]N=')A9&\@;F\@
M8F%N8V\@9&4@9&%D;W,N`$$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F
M;VD@97-P96-I9FEC861A+@!!<R!F=6[G]65S(&1E(&-R:7!T;V=R869I82!R
M97%U97)E;2!U;6$@8V]N97CC;R!W96(@<V5G=7)A+@!/(&%R<75I=F\@)7,@
M9&5V97)I82!C;VYT97(@=6UA(&-O;F9I9W5R8>?C;R!D92`E<RX`3R!A<G%U
M:79O("5S(&1E=F5R:6$@8V]N=&5R(&%L9W5M87,@8V]N9FEG=7)AY_5E<R!D
M92`E<RX`3R!A<G%U:79O(&[C;R!P;V1E('-E<B!C;W!I861O('!A<F$@96QE
M(&UE<VUO+@!/(&%R<75I=F\@;N-O(&-O;G3I;2!D861O<RX`4V5G=65M(&]S
M(&-A8F7G86QH;W,@9&5S=&$@;65N<V%G96TO;65N<V%G96T@<F9C.#(R+@#)
M('-A8FED;R!Q=64@;R!M;V1O('1E;&$@8VAE:6$@8V%U<V$@<')O8FQE;6%S
M(&-O;2!O($EN=&5R;F5T($5X<&QO<F5R+"!E;2!V:7)T=61E(&1E(&)U9W,@
M9&\@;F%V96=A9&]R('%U92!N\W,@;N-O(&5S=&%M;W,@87!T;W,@82!C;VYT
M;W)N87(N(%9O8^H@<&]D92!O8G-E<G9A<B!E<G)O<R!D92!E>&EB:>?C;RP@
M9F%L=&$@9&4@9G5NY_5E<R!D;R!E9&ET;W(@92]O=2!T<F%V86UE;G1O<R!A
M;&5A=/-R:6]S(&1O(&YA=F5G861O<BX@4V4@<V5U('-I<W1E;6$@Z2!7:6YD
M;W=S(#EX(.D@;75I=&\@<')O=N%V96P@<75E('9O8^H@<F5C96)A('5M(&5R
M<F\@9&4@)T9A;&AA($=E<F%L(&1E(%!R;W1EY^-O)R!E('!R96-I<V%RX2!R
M96EN:6-I87(N(%QN7&X@5F]CZB!F;VD@879I<V%D;RX@4&]R(&9A=F]R('!R
M97-S:6]N92!/2R!S92!V;V/J(&%I;F1A('%U97(@=&5N=&%R('5S87(@;R!E
M9&ET;W(@9&4@=&5L82!C:&5I82X`02!I9&5N=&ED861E("(E<R(@9F]I(&5X
M8VQU[61A+@!3;VUE;G1E(&\@;&%D;R!E<W%U97)D;P!!(&QO8V%L:7IAY^-O
M(&1O(&)I;N%R:6\@9&\@1VYU4$<@9&5V92!S97(@9F]R;F5C:61A(.`@8VQA
M<W-E(")#<GEP=%]P9W`B+@!!(&UE;G-A9V5M(&5N=FEA9&$@96T@)7,@<&%R
M82`E<R!C;VT@;R!A<W-U;G1O("(E<R(@9F]I(&5X:6)I9&$N"DES=&\@;N-O
M(&=A<F%N=&4@<75E(&$@;65N<V%G96T@9F]I(&QI9&$@;W4@96YT96YD:61A
M+@!/(&YO;64@=71I;&EZ861O(&%O('9I;F-U;&%R(&$@<.%G:6YA(&1E(&-O
M;7!O<VGGXV\`3R!N^FUE<F\@9&4@8V%M<&]S(&1E=F4@<V5R(&YU;>ER:6-O
M+@!/(&WS9'5L;R!O<&5N<W-L(.D@;V)R:6=A=/-R:6\@<&%R82!A(&-L87-S
M92`B2&]R9&5?0W)Y<'1?<VUI;64B+@!!('!R969E<NIN8VEA("(E<R(@;N-O
M('!O9&4@<V5R('-A;'9A('!O<G%U92!S975S(&1A9&]S(&5X8V5D97)A;2!O
M('1A;6%N:&\@;>%X:6UO('!E<FUI=&ED;P!/('!R;V=R86UA('5T:6QI>F%D
M;R!P87)A('9I<W5A;&EZ87(@97-T92!T:7!O(&1E(&1A9&\@*"5S*2!NXV\@
M9F]I(&5N8V]N=')A9&\@;F\@<VES=&5M82X`3R!C87)A8W1E<F4@<&%R82!C
M:71AY^-O(&1E('-E<B!A<&5N87,@=6TN`%-O;65N=&4@;W,@;&%D;W,@9&ER
M96ET;R!E(&5S<75E<F1O`%-O;65N=&4@;R!L861O(&1I<F5I=&\`3R!S97!A
M<F%D;W(@9&5V92!S97(@=6T@^FYI8V\@8V%R86-T97)E+@!/('-E<G9I9&]R
M("(E<R(@9F]I(&5X8VQU[61O+@!/('-E<G9I9&]R("(E<R(@9F]I('-A;'9O
M+@!!('-O;&EC:71AY^-O(&1E(&-A9&%S=')O(&1E("5S(&9O:2!E>&-L=>UD
M82X`02!L:6YH82!E<W!E8VEF:6-A9&$@*"5D*2!NXV\@97AI<W1E+@!/(&%R
M<75I=F\@=&5M<&]RX7)I;R`B)7,B(&[C;R!E>&ES=&4N`$\@=&5X=&\@<75E
M('9O8^H@9&EG:71O=2!NXV\@8V]R<F5S<&]N9&4@86\@=&5X=&\@;F$@=&5L
M82X`4V]M96YT92!O<R!L861O<R!D92!C:6UA(&4@9&4@8F%I>&\`4V]M96YT
M92!O(&QA9&\@9&4@8VEM80!/<R!D861O<R!E;G9I861O<R!F;W)A;2!P97)D
M:61O<R!D97-D92!O('!A<W-O(&%N=&5R:6]R+@!/(&%R<75I=F\@96YV:6%D
M;R!NXV\@</1D92!S97(@<V%L=F\N`$\@8FQO8V\@(G=E871H97(N8V]M(B!N
MXV\@97-TX2!D:7-P;V[M=F5L+@!/(&1I<F5T\W)I;R!D92!T96UA<R`G)7,G
M(&[C;R!F;VD@96YC;VYT<F%D;RX`3N-O(&5X:7-T96T@;W#G]65S(&1I<W!O
M;NUV96ES+@!.XV\@97AI<W1E;2!P87)T97,@<75E('!O<W-A;2!S97(@97AI
M8FED87,@:6YC;W)P;W)A9&%S+@!%>&ES=&5M(&UU:71O<R!C87)A8W1E<F5S
M(&YE<W1E(&-A;7!O+B!6;V/J('!R965N8VAE=2!C;VT@)7,@8V%R86-T97)E
M<SL@=F]CZB!D979E('!R965N8VAE<B!C;VT@)7,@;W4@;65N;W,N`$AO=79E
M('5M('!R;V)L96UA(&%D:6-I;VYA;F1O("<E<R<@86\@<VES=&5M83H@)7,`
M2&]U=F4@=6T@<')O8FQE;6$@86\@97AC;'5I<B!D;R!S:7-T96UA(&]S(&1A
M9&]S(&1O('5S=>%R:6\@)R5S)SH@`$AO=79E('5M('!R;V)L96UA(&%O(&5X
M8VQU:7(@)R5S)R!D;R!S:7-T96UA.B``2&]U=F4@=6T@<')O8FQE;6$@86\@
M871U86QI>F%R("<E<R<Z("5S`$AO=79E('5M('!R;V)L96UA(&-O;2!O(&5N
M=FEO(&1O(&%R<75I=F\Z($YE;FAU;2`E<R!F;VD@96YV:6%D;RX`2&]U=F4@
M=6T@<')O8FQE;6$@8V]M(&\@96YV:6\@9&\@87)Q=6EV;RX@3R`E<R!E<F$@
M;6%I;W(@<75E(&\@=&%M86YH;R!MX7AI;6\@<&5R;6ET:61O("@E9"!B>71E
M<RDN`$AO=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N
M($\@)7,@9F]I(&5N=FEA9&\@<&%R8VEA;&UE;G1E+@!(;W5V92!U;2!E<G)O
M(&%O(&5X:6)I<B!E<W1A('!A<G1E(&1A(&UE;G-A9V5M`$AO=79E('5M(&5R
M<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@9&\@8V]N=&%T;RX`2&]U=F4@=6T@
M97)R;R!A;R!I;7!O<G1A<B!O<R!D861O<R!D;R!I0V%L96YD87(N`$AO=79E
M('5M(&5R<F\@;F\@9F]R;75LX7)I;R!D92!C;VYF:6=U<F'GXV\N(%1A;'9E
M>B!V;V/J(&1E:7AO=2!U;2!C86UP;R!O8G)I9V%T\W)I;R!E;2!B<F%N8V\N
M`$AO=79E('5M(&5R<F\@86\@97AE8W5T87(@82!F=6[GXV\@9&4@8V%TX6QO
M9V\@9&4@96YD97)EYV]S(&5S<&5C:69I8V%D82X@4&]R(&9A=F]R('1E;G1E
M(&YO=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T=6%L
M:7IA<B!O<R!D971A;&AE<R!D;R!C;VYT871O+B!0;W(@9F%V;W(@=&5N=&4@
M;F]V86UE;G1E(&UA:7,@=&%R9&4N`$AO=79E('5M(&5R<F\@86\@871U86QI
M>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B!0;W(@9F%V;W(@=&5N=&4@
M;F]V86UE;G1E(&UA:7,@=&%R9&4N`$5S=&4@<V5R=FED;W(@24U!4"!NXV\@
M<W5P;W)T82!P87-T87,@8V]M<&%R=&EL:&%D87,N`$5S=&4@;N-O('!A<F5C
M92!S97(@=6T@87)Q=6EV;R!R87(@=N%L:61O+@!%<W1E(&[C;R!P87)E8V4@
M<V5R('5M(&%R<75I=F\@>FEP(';A;&ED;RX`17-T92!NXV\@<&%R96-E('-E
M<B!U;2!N^FUE<F\@9&4@8V%R=.-O(';A;&ED;RX`17-T92!C;VYE8W1O<B!P
M97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!#;&EC:V%T96QL
M("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI+"!U=&EL:7IA;F1O(&$@05!)($A4
M5%``17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R
M87;I<R!D;R!G871E=V%Y('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI+"!U=&EL:7IA;F1O(&\@05!)($A45%``17-T92!C;VYE8W1O<B!P97)M
M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!G871E=V%Y('-M<S)E
M;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!U=&EL:7IA;F1O(&\@05!)
M($A45%``17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!U;6$@;65N<V%G
M96T@=FEA(%--5%`@871R87;I<R!D;R!6;V1A9F]N92!)=&%L:6%N;RP@<V]M
M96YT92!P87)A(&[Z;65R;W,@5F]D869O;F4N(,D@;V)R:6=A=/-R:6\@<&]S
M<W5I<B!U;6$@8V]N=&$@;F\@5F]D869O;F4@271A;&EA;F\@*&AT='`Z+R]W
M=W<N,3DP+FET*2X`17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%<W1E(&-A
M;7!O('!O9&4@8V]N=&5R(&%P96YA<R!N^FUE<F]S(&EN=&5I<F]S+@!%<W1E
M(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!N^FUE<F]S(&4@=NUR9W5L82X`
M17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N
M`$5S=&4@8V%M<&\@9&5V92!S97(@=6UA(&QI<W1A(&1E(&[Z;65R;W,@:6YT
M96ER;W,@<V5P87)A9&$@<&]R(';M<F=U;&%S(&]U(&5S<&'G;W,`17-T92!C
M86UP;R!D979E('-E<B!U;2!N^FUE<F\@=N%L:61O+@!%<W1E(&-A;7!O(&1E
M=F4@8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@96T@9F]R;6%T;R!21T(@2&5X
M82P@<&]R(&5X96UP;&\@)R,Q,C,T868G+@!%<W1E(&9O<FUU;.%R:6\@:N$@
M9F]I('!R;V-E<W-A9&\N`$ES=&\@Z2`E<RX`17-T92#I('5M(&]B:F5T;R!+
M;VQA8B!'<F]U<'=A<F4N(%!A<F$@=FES=6%L:7IA<B!E<W1E(&]B:F5T;R!V
M;V/J('!R96-I<V%RX2!D92!U;2!C;&EE;G1E(&1E(&-O<G)E:6\@<75E(&5N
M=&5N9&$@;R!F;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!U;6$@;&ES
M=&$@9&4@8VQI96YT97,@9&4@8V]R<F5I;R!C;VT@97-T87,@9G5NY_5E<R!P
M;W(@9F%V;W(@=FES:71E("5S`$5S=&$@;65N<V%G96T@9F]I(&5S8W)I=&$@
M96T@=6T@8V]N:G5N=&\@9&4@8V%R86-T97)E<R`H)7,I('%U92!NXV\@Z2!O
M(&UE<VUO('%U92!O('-E=2X`17-T92!N^FUE<F\@9&5V92!S97(@<&5L;R!M
M96YO<R!U;2X`17-T92!S97)V:61O<B!NXV\@<&]D92!D97-C;VUP<FEM:7(@
M87)Q=6EV;W,@>FEP(&4@9WII<"X`17-T92!S:7-T96UA(&5S=.$@871U86QM
M96YT92!D97-A=&EV861O+@!%<W1E('9A;&]R(&1E=F4@<V5R('5M(&[Z;65R
M;RX`17-T82!J86YE;&$@9&5V92!S97(@8VAA;6%D82!A('!A<G1I<B!D82!J
M86YE;&$@9&4@3W#G]65S`%)A:6\`0FEL:&5T97,`2&]R80!!8V]M<&%N:&%M
M96YT;R!D92!(;W+A<FEO`$9O<FUA=&\@9&4@:&]R80!396QEY^-O(&1E(&AO
M<F$`5&EM;W(@3&5S=&4`5.UT=6QO`$%S<W5N=&\@*&1I8V$I.@!087)A`%!A
M<F$@<V5L96-I;VYA<B!M^FQT:7!L;W,@[71E;G,L('-E9W5R92!A('1E8VQA
M($-O;G1R;VP@*%!#*2!O=2!#;VUM86YD("A-86,I(&%O(&-L:6-A<BX`2&]J
M90!4<F]C87(@<&%R82!C\V1I9V\@2%1-3`!4;V=O`%1O:V5L874`06UA;FCC
M`%1O;F=A`%1O<&\`475A9')O(&1O(%1O<&\@*%]T;W`I`%1R861UY_5E<P!4
M<FEN9&%D92!E(%1O8F%G;P!697)D861E:7)O(&]U(&9A;'-O`%1E<@!4=6[M
M<VEA`%1U<G%U:6$`5'5R8V\@*$E33RTX.#4Y+3DI`%1U<F-O;65N:7-TXV\`
M26QH87,@5'5R:W,@92!#86EC;W,`5'5V86QU`%!R965N8VAA(&-O;2!S=6$@
M97-C;VQH83H@`,UN9&EC92!5+E8N.B``55),`%523"!D;R!S974@<F5L873S
M<FEO(&1E('-I='5AY^-O(&1E(&5N=')E9V$`55),.@!59V%N9&$`56-RXFYI
M80!);7!O<W/M=F5L(&%C97-S87(@9&ER973S<FEO(%9&4RX`26UP;W-S[79E
M;"!A9&EC:6]N87(@:6YF;W)M8>?U97,@97AT<F%S(&1E('5S=>%R:6\@86\@
M<F5G:7-T<F%R+@!);7!O<W/M=F5L(&%L=&5R87(@<&5R;6ES<^-O(&1O(&%R
M<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@86QT97)A<B!P97)M:7-SXV\@
M9&\@87)Q=6EV;R!61E,@)7,O)7,N`$EM<&]S<^UV96P@86QT97)A<B!P87)A
M("5S+@!);7!O<W/M=F5L('9E<FEF:6-A<B!O('1A;6%N:&\@9&\@87)Q=6EV
M;R!D92`B)7,B+@!);7!O<W/M=F5L('9E<FEF:6-A<B!O('1A;6%N:&\@9&\@
M87)Q=6EV;R!D92`B)7,O)7,B+@!);7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E
M<G9I9&]R(%-13"X`26UP;W-S[79E;"!C;VYE8W1A<B!U=&EL:7IA;F1O(%-3
M3"X`26UP;W-S[79E;"!C;W!I87(@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@
M8W)I87(@9&ER973S<FEO(%9&4R`B)7,B+@!);7!O<W/M=F5L(&-R:6%R(&1I
M<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!61E,N`$EM
M<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E
M;"!C<FEA<B!A<G%U:79O(%9&4R!V87II;RX`26UP;W-S[79E;"!D97-C;VUP
M<FEM:7(@9&%D;W,N`$EM<&]S<^UV96P@97AC;'5I<B`B)7,B+"!O(&1I<F5T
M\W)I;R!NXV\@97-TX2!V87II;RX`26UP;W-S[79E;"!E>&-L=6ER("(E<R(Z
M("5S+@!);7!O<W/M=F5L(&5X8VQU:7(@)7,L(&\@9&ER973S<FEO(&[C;R!E
M<W3A('9A>FEO`$EM<&]S<^UV96P@97AC;'5I<B!R96-U<G-I=F%M96YT92!O
M(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@97AC;'5I<B!D:7)E=/-R:6\@
M5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@9&ER973S<FEO(%9&4SH@)7,N`$EM
M<&]S<^UV96P@97AC;'5I<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L
M(&5X8VQU:7(@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@97AC;'5I<B!A<G%U
M:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&5X8VQU:7(@5D93(')E8W5R<VEV
M86UE;G1E.B`E<RX`26UP;W-S[79E;"!D971E<FUI;F%R(&\@9&ER973S<FEO
M(&%T=6%L+@!);7!O<W/M=F5L(&5X=')A:7(@9&5T86QH97,@9&\@8V5R=&EF
M:6-A9&\`26UP;W-S[79E;"!C87)R96=A<B!A(&1E9FEN:>?C;R!D92`E<RX`
M26UP;W-S[79E;"!M;W9E<B!O(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&%B
M<FER(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV
M;R!61E,@<&%R82!G<F%V8>?C;RX`26UP;W-S[79E;"!A8G)I<B!A<G%U:79O
M(%9&4RX`26UP;W-S[79E;"!A8G)I<B!A<G%U:79O(&-O;7!R:6UI9&\N`$EM
M<&]S<^UV96P@;&5R(&%R<75I=F\@5D93("AF:6QE<VEZ92@I(&9A;&AO=2DN
M`$EM<&]S<^UV96P@;&5R(&%R<75I=F\@5D93("AG971&:6QE4VEZ92@I(&9A
M;&AO=2DN`$EM<&]S<^UV96P@;&5R(&\@87)Q=6EV;SH@`$EM<&]S<^UV96P@
M;&5R(&$@<F%I>B!D;R!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(')E;F]M
M96%R("5S('!A<F$@)7,Z(&$@<&%S=&$@9&4@9&5S=&EN;R!JX2!E>&ES=&4`
M26UP;W-S[79E;"!R96YO;65A<B!O(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV
M96P@<F5N;VUE87(@9&ER973S<FEO(%9&4SH@)7,N`$EM<&]S<^UV96P@<F5N
M;VUE87(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!R96YO;65A<B!A
M<G%U:79O(%9&4R`E<R\E<RX`26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O
M(%9&4RX`26UP;W-S[79E;"!E>&5C=71A<B`G;6MI<V]F<R<N`$EM<&]S<^UV
M96P@=')A9'5Z:7(@97-T92!D;V-U;65N=&\@5V]R9`!);7!O<W/M=F5L(&=R
M879A<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&=R879A<B!A<G%U
M:79O(%9&4R`H8V]P>2@I(&9A;&AO=2DN`$EM<&]S<^UV96P@9W)A=F%R(&1A
M9&]S(&1O(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&=R879A<B!A<G%U:79O
M(%9&4RP@<75O=&$@97AC961E<N$N`%-U8FQI;FAA9&\`1&5S9F%Z97(@06QT
M97)AY_5E<P!$97-F87H@<W5A(/IL=&EM82!AY^-O`%)E<W!O<W1A(&EN97-P
M97)A9&$@9&\@<V5R=FED;W(@9'5R86YT92!A(&-O;F5XXV\Z(`!297-P;W-T
M82!I;F5S<&5R861A(&1O('-E<G9I9&]R('!A<F$Z(`!396T@8V%T96=O<FEA
M`%5N:6-O9&4@*%541BTX*0!%;6ER861O<R#!<F%B97,@56YI9&]S`%)E:6YO
M(%5N:61O`$5S=&%D;W,@56YI9&]S`$EL:&%S(%!E<FEFZ7)I8V%S($UE;F]R
M97,@9&]S($5S=&%D;W,@56YI9&]S`%5N:61A9&5S`$1E<V-O;FAE8VED;P!A
M<&EM<V=I9"!D97-C;VYH96-I9&\@*$%022!-97-S86=E($E$*2X`8VQI;7-G
M:60@9&5S8V]N:&5C:61O("A#;&EE;G0@365S<V%G92!)1"DN`$YE;FAU;6$@
M;&]C86QI>F'GXV\@8V]N9FEG=7)A9&$N`%5S=>%R:6\@;W4@<V5N:&$@9&5S
M8V]N:&5C:61O<RX`1&5S=FEN8W5L87(@;R!E;&5M96YT;R!A='5A;`!396T@
M3F]M90!38W)I<'1S(&[C;R!P<FEV:6QE9VEA9&]S(&[C;R!P;V1E;2!U=&EL
M:7IA<B!#;W)T87(O0V]P:6%R+T-O;&%R('!O<B!R87KU97,@9&4@<V5G=7)A
M;N=A+B!#;&EQ=64@96T@3TL@<&%R82!V97(@82!N;W1A('3I8VYI8V$@96T@
M;6]Z:6QL82YO<F<@82!Q=6%L(&5N<VEN82!C;VUO('!E<FUI=&ER('-C<FEP
M=',@86-E<W-A<F5M(&$@X7)E82!D92!T<F%N<V9E<NIN8VEA+@!$97-M87)C
M87(@8V]R`$5X=&5N<^-O($[C;R!3=7!O<G1A9&$`071U86QI>F%R`"5S(&%T
M=6%L:7IA9&\`071U86QI>F%R('5S=>%R:6\`)R5S)R!A='5A;&EZ861O+@!3
M8W)I<'0@9&4@871U86QI>F'GXV\@<F5M;W9I9&\N`$5N=FEA<@!4;V1O<R!A
M<G%U:79O<R!D92`@8V]N9FEG=7)AY_5E<R!D87,@87!L:6-AY_5E<R!F;W)A
M;2!E;G9I861O<R!A;R!S97)V:61O<BX`06QF86)E=&\@;&%T:6YO(&5M(&UA
M:?IS8W5L;P!.^FUE<F]S(')O;6%N;W,@96T@;6%I^G-C=6QO`%5R=6=U86D`
M571I;&EZ87(@071U86PZ("5S`%5T:6QI>F%R(%-33`!5=&EL:7IA<B!S92!O
M(&YO;64O<V5N:&$@Z2!D:69E<F5N=&4@;F\@<V5R=FED;W(@24U34"X`57-U
MX7)I;W,`57-UX7)I;R`E<R!NXV\@97-TX2!A=71O<FEZ861O('!A<F$@)7,N
M`$%D;6EN:7-T<F'GXV\@9&4@57-UX7)I;W,`3W#G]65S(&1E(%5S=>%R:6]S
M`%)E9VES=')O(&1E(%5S=>%R:6]S`%)E9VES=')O(&1E(%5S=>%R:6]S(&5S
M=.$@9&5S86)I;&ET861O(&YE<W1E('-I=&4N`$-O;G1A(&1E('5S=>%R:6\@
M;N-O(&5N8V]N=')A9&$`57-UX7)I;P!5<W7A<FEO("<E<R<@:N$@97AI<W1E
M+@!5<W7A<FEO.@!5<W7A<FEO.B``57-UX7)I;W,@;F\@<VES=&5M83H`57IB
M97%U:7-TXV\`3R!D:7)E=/-R:6\@5D93(&[C;R!E>&ES=&4N`$;I<FEA<P!,
M;V-A;&EZ8>?U97,@=N%L:61A<R!E;F-O;G1R861A<R!I;F-L=65M.B``5F%L
M:61A9&4`5F%L;W(@96T@;6EN=71O<R!A('!A<G1I<B!D92!A9V]R82X`3R!V
M86QO<B!E<W3A(&%C:6UA(&1O('1A;6%N:&\@;>%X:6UO(&1E("5S+@!686QO
M<F5S`%9A;&]R97,@<&%R82!S96QE8VEO;F%R`%9A;G5A='4`5F%R:>%V96P`
M5F5N97IU96QA`$9A;&AA(&YA('9E<FEF:6-AY^-O("T@97-T82!M96YS86=E
M;2!P;V1E('1E<B!S:61O(&%D=6QT97)A9&$N`%9E<G/C;P!#;VYT<F]L92!D
M92!697)SXV\`06QI;FAA;65N=&\@=F5R=&EC86P`36%R9V5M('9E<G1I8V%L
M`%9E<G1I8V%L.@!-=6ET;R!!;'1A`%9I971NXP!6:65T;F%M:71A("A625-#
M24DI`%9E<B`E<P!6:7-U86QI>F%R('5M82!PX6=I;F$@=V5B(&5X=&5R;F$`
M5FES=6%L:7IA<B!C;VUO("5S`$EL:&%S(%9I<F=E;G,L($)R:73B;FEC87,`
M26QH87,@5FER9V5N<RP@12Y5+D$N`%9I<VEB:6QI9&%D90!6:7-I8FEL:61A
M9&4Z(`!6;V1A9F]N92!)=&%L:6%N;R!V:6$@4TU44`!!5$5.Q\-/`$%414['
MPT\A(2$@4D5-3U9!($\@4T-225!4($U!3E5!3$U%3E1%($1%("5S+@!724X@
M=FEA($A45%``5V%L;&ES(&4@1G5T=6YA`$%T96[GXV\`475A`%!R979I<^-O
M(&1O(%1E;7!O`$1A9&]S(&1O($-L:6UA(&9O<FYE8VED;R!P;W(`5V5A=&AE
M<BYC;VT`5V5B`%-I=&4@5V5B`%-E;6%N86QM96YT90!"96TM=FEN9&\`0F5M
M+79I;F1O(&%O("5S`$)E;2UV:6YD;RP@)7,`3V-I9&5N=&%L("A)4T\M.#@U
M.2TQ*0!/8VED96YT86P@*$E33RTX.#4Y+3$U*0!386AA<F$@3V-I9&5N=&%L
M`%%U92!A<&QI8V'GXV\@)7,@9&5V97)I82!E>&EB:7(@87#S<R!A(&-O;F5X
MXV\_`%%U86P@;R!C87)A8W1E<F4@9&5L:6UI=&%D;W(_`%%U86P@;R!C87)A
M8W1E<F4@9&4@8VET8>?C;S\`36%P87,@075S=')A;&EA;F]S(%=H97)E:7,`
M475A:7,@9F%S97,`475A:7,@<&QU9VEN<R!H86)I;&ET87(@<&%R82!O(&5D
M:71O<B!2:6-H(%1E>'0N`$QA<F=U<F$`3&%R9W5R82!E;2!U;FED861E<R!#
M4U,`3&%R9W5R82!D;R!M96YU("5S(&1O(&QA9&\@97-Q=65R9&\@*'1E<N$@
M969E:71O(&YA('!R\WAI;6$@8V]N97CC;RDZ`$QA<F=U<F$@9&$@=&%B96QA
M`%5N:61A9&4@9&4@3&%R9W5R80!,87)G=7)A.@!7:6MI`%9E;G1O`%9E;G1O
M<R!P96QA(&UA;FCC`%9E;&]C:61A9&4@9&\@=F5N=&\@96T@;O-S`%9E;G1O
M.@!696YT;SH@`%-A8F5D;W)I80!,:7-T82!D92!P961I9&]S`%1R86)A;&AO
M`$5N9&5R9>=O($-O;65R8VEA;`!&;VYE($-O;65R8VEA;`!.^FUE<F\@:6YC
M;W)R971O(&1E(&-A;7!O<R!N82!L:6YH82`E9"X@17-P97)A9&]S("5D+"!E
M;F-O;G1R861O<R`E9"X`3OIM97)O(&5R<F%D;R!D92!C86UP;W,N($5S<&5R
M861O<R`E9"P@96YC;VYT<F%D;W,@)60N`$]F9G-E="`E9"!I;F-O<G)E=&\@
M86\@;&5R(&\@87)Q=6EV;R!61E,N`%@M4F5F`%)E<W1R:>?U97,@0N%S:6-A
M<R!8-3`Y=C,`571I;&EZ8>?C;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P.78S
M`$YO;64@06QT97)N871I=F\@9&4@07-S=6YT;R!8-3`Y=C,`261E;G1I9FEC
M861O<B!D82!#:&%V92!D92!!<W-U;G1O(%@U,#EV,P!%>'1E;G/U97,@6#4P
M.78S`$%!`$%!04$`36%P82!986AO;R$`06YU86QM96YT90!,ZFUE;@!3:6T`
M4VEM+"!%=2!#;VYC;W)D;P!6;V/J(&5S=.$@96T@34]$3R!415A43RX@(%5T
M:6QI>F$@;R!B;W3C;R!;/#Y=('!A<F$@=F]L=&%R('!A<F$@;R!M;V1O(%=9
M4TE764<N`%9O8^H@;N-O(&5S=.$@875T;W)I>F%D;R!A(&-R:6%R(&UA:7,@
M9&4@)60@8FQO8V]S+@!6;V/J(&[C;R!E<W3A(&%U=&5N=&EC861O+@!6;V/J
M(&[C;R!P;V1E('1E<B!O(&-A<F%C=&5R(%P@;F\@<V5U(&YO;64N`%9O8^H@
M;N-O(&9O<FYE8V5U('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!VX6QI9&\N`%9O
M8^H@;N-O(&UA<&5O=2!N96YH=6T@8V%M<&\@9&\@87)Q=6EV;R!I;7!O<G1A
M9&\@86]S(&-A;7!O<R!C;W)R97-P;VYD96YT97,@96T@)7,N`%9O8^H@9F]I
M(&1E<V-O;F5C=&%D;RX`5F]CZB!D979E('!R965N8VAE<B!U;2!N^FUE<F\@
M9&4@=&5L969O;F4@8V5L=6QA<B!VX6QI9&\L('-O;65N=&4@9.UG:71O<R!C
M;VT@=6T@;W!C:6]N86P@)RLG('!A<F$@9&ES8V%G96T@9&4@<')E9FEX;R!I
M;G1E<FYA8VEO;F%L+@!6;V/J(&1E=F4@<')E96YC:&5R('5M('9A;&]R(';A
M;&ED;RX`5F]CZB!D979E(&-O;F9I9W5R87(@=6T@8V]N96-T;W(@1&%T851R
M964@<&%R82!U=&EL:7IA<B!#861A<W1R;W,N`%9O8^H@9&5V92!C;VYF:6=U
M<F%R('5M(&-O;F5C=&]R(%9&4RX`5F]CZB!D979E(&1E<V-R979E<B!O('!R
M;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!O(')E;&%T\W)I;R!D92!P<F]B;&5M
M82X`5F]CZB!D979E(&9O<FYE8V5R(&$@55),(&]N9&4@;R!L:6YK(&%P;VYT
M80!6;V/J(&1E=F4@<V5L96-I;VYA<B!U;2!S97)V:61O<B!P87)A('-E<B!E
M>&-L=>UD;RX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R
M82!E>&-L=6ER+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P
M87)A(')E;6]V97(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO
M('!A<F$@861I8VEO;F%R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-U
MX7)I;R!P87)A(&%T=6%L:7IA<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M
M82!AY^-O('!A<F$@97AE8W5T87(N`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@
M;F]M92!P87)A(&$@;F]V82!C871E9V]R:6$N`%9O8^H@<')E8VES82!F;W)N
M96-E<B!U;2!N^FUE<F\@9&4@=&5L969O;F4@:71A;&EA;F\`4W5A('-E<W/C
M;R`E<R!E>'!I<F]U+B!0;W(@9F%V;W(L(&-O;F5C=&4M<V4@;F]V86UE;G1E
M+@!3974@16YD97)EYV\@9&4@12UM86EL`%-E=2!%;F1E<F7G;R!D92!296UE
M=&5N=&4@*$1E.BDZ`%-U87,@26YF;W)M8>?U97,`4V5U($5N9&5R9>=O(&1E
M($EN=&5R;F5T(&UU9&]U(&1E<V1E(&\@:6[M8VEO(&1E('-U82!S97-SXV\@
M)7,N(%!A<F$@<')O=&5G97(@<W5A('-E9W5R86[G82!V;V/J(&1E=F4@8V]N
M96-T87(M<V4@;F]V86UE;G1E+@!3974@3F]M90!3974@8F%C:V5N9"!D92!A
M=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E('5S=>%R:6]S+"!O
M=2!A(&9U;N?C;R!F;VD@9&5S86)I;&ET861A('!O<B!A;&=U;6$@;W5T<F$@
M<F%ZXV\N`%-E=2!B86-K96YD(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T
M82!L:7-T86=E;2!D92!U<W7A<FEO<RP@;W4@82!F=6[GXV\@9F]I(&1E<V%B
M:6QI=&%D82!P;W(@86QG=6UA(&]U=')A(')A>N-O+@!3974@;F%V96=A9&]R
M('!A<F5C92!T97(@86QT97)A9&\@9&5S9&4@;R!I;NUC:6\@9&4@<W5A('-E
M<W/C;R`E<RX@4&%R82!P<F]T96=E<B!S=6$@<V5G=7)A;N=A+"!V;V/J(&1E
M=F4@8V]N96-T87(M<V4@;F]V86UE;G1E+@!3974@;F%V96=A9&]R(&[C;R!S
M=7!O<G1A(&5S=&$@9G5NY^-O+@!3974@;F%V96=A9&]R(&[C;R!S=7!O<G1A
M(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S<VEO;F4@0V]N=')O;"]/
M<'1I;VX@*R!0('!A<F$@:6UP<FEM:7(N`%-E=2!F=7-O(&AO<N%R:6\@871U
M86PZ`%-U82!I9&5N=&ED861E('!A9'+C;R!F;VD@86QT97)A9&$N`%-U82!I
M9&5N=&ED861E('!A9'+C;SH`4V5U(&YO;64@8V]M<&QE=&\Z`%-U82!C;VYE
M>.-O(&5X<&ER;W4N`%-U82!N;W9A('-E;FAA('!A<F$@)7,@Z3H@)7,`4W5A
M<R!O<.?U97,@9F]R86T@871U86QI>F%D87,@<&]R(&-A=7-A(&1A(&1U<F'G
MXV\@9&5S=&$@<V5S<^-O+@!3=6%S(&]PY_5E<R!F;W)A;2!A='5A;&EZ861A
M<RX`4W5A(&YO=F$@<V5N:&$@9F]I(&=E<F%D80!3=6$@;F]V82!S96YH82!F
M;VD@9V5R861A+"!V97)I9FEQ=64@<V5U(&4M;6%I;"!E(&-O;F5C=&4M<V4@
M8V]M('-U82!N;W9A('-E;FAA+@!3=6$@<V5N:&$@97AP:7)O=2X`4V5U<R!S
M97)V:61O<F5S(')E;6]T;W,Z`$EU9V]S;.%V:6$`6F%I<F4`6N)M8FEA`%II
M;6)A8G=E`%II<'!Y`%M/8W5L=&%R(%1E>'1O($-I=&%D;UT`6U)E;&%T\W)I
M;R!D92!0<F]B;&5M85T`6T5X:6)I<B!497AT;R!#:71A9&\@+0!;17AI8FER
M(%1E>'1O($-I=&%D;R`M("5S(&QI;FAA<UT`6VQI;FAA("5S(&1E("5S70!?
M061M:6YI<W1R8>?C;P!?0TQ)`$1A=&%?5')E90!%7WAC;'5I<B!#;VQU;F$`
M7T=R=7!O<P!!7VIU9&$`4')O<')I961A9&5S(&1A(%]);6%G96TN+BX`7T-O
M;F5C=&%R`%]$97-C;VYE8W1A<@!!7VQT97)A<B!,:6YK+BXN`%]/<.?U97,`
M7U!E<FUI<W/U97,`7U)E;6]V97(@3&EN:RXN+@!#;VYF:6=U<F%?<@!0<F]P
M<FEE9&%D97,@9&$@7U1A8F5L82XN+@!?57-UX7)I;W,`8V%TX6QO9V\@9&4@
M96YD97)EYV]S`&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!A9V5N9&$`8V%L;6\`
M:6UP;W-S[79E;"!C<FEA<B!A<G%U:79O(&1E(&1E<W1I;F\`:6UP;W-S[79E
M;"!A8G)I<B!A(&]R:6=E;0!C;&EQ=64@87%U:0!E<G)O(&1E('-I;G1A>&4@
M9&$@;&EN:&$@9&4@8V]M86YD;P!E<G)O(&1E(&-O;F9I9W5R8>?C;P!U;2!A
M<G%U:79O(&-R[71I8V\@9&\@<VES=&5M82!E<W3A(&9A;'1A;F1O`&5R<F\@
M;F\@9F]R;6%T;R!D;W,@9&%D;W,`961I=&%R`')E9VES=')O(&[C;R!E;F-O
M;G1R861O`'%U961A`&%R<75I=F\`82!P87)T:7(@9&4@)7,@*"5S*2#@("5S
M("5S`&)R:7-A`&@Z`&AH`&YO;64@9&\@:&]S="#I(&1E<V-O;FAE8VED;P!I
M;65D:6%T;P!I;F-O<G!O<F%D;P!E<G)O(&1E(&5N=')A9&$O<V'M9&$`97)R
M;R!I;G1E<FYO(&1O('!R;V=R86UA`&QI;FAA<UT`8_-D:6=O(&1E(&5R<F\@
M)60@9&\@;6MI<V]F<R!E;G%U86YT;R!G97)A=F$@82!)4T\N`&UM`&YO;64`
M;N-O(&EM<&QE;65N=&%D;P!NXV\@:6UP;&5M96YT861O(&%I;F1A`&)L;V-O
M(&1E(&YO=&%S`'!O<F-E;G1A9V5M`%!E<FUI<W/C;P!P:7AE;',`97)R;R!R
M96UO=&\@;F\@<')O=&]C;VQO`&YA<V-E;G1E`'-E<G9IYV\@:6YD:7-P;V[M
M=F5L`&5X:6)I<B!D:69E<F5NYV%S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!E
M<W3A=F5L`&5R<F\@9&4@<VES=&5M80!L:7-T82!D92!T87)E9F%S`&9A;&AA
M('1E;7!O<N%R:6$`<')E96YC:&$@<W5A('-E;FAA(&1U87,@=F5Z97,@<&%R
M82!C;VYF:7)M87(`=6YI9FEC861O`'-E;2!N;VUE`'-E;&7GXV\@9&4@=7-U
MX7)I;P!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+W!T7T)2+VAE;'`N>&UL````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#4Q-30S,3`V,@`P,C`S
M,C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A
M;&4O<'1?0E(O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J
M86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A
M=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A
M<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA
M<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E
M>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S
M<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N
M=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI
M<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N
M9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT
M86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H
M(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@
M82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@
M/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E
M(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X
M86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@
M;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D
M97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T
M:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L
M969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T
M:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T
M:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET
M8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P
M87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N
M8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN
M=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N
M86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA
M:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I
M;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI
M<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D
M(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO
M9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]P=%]05"\`````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C(`,#$V-C<V`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!T7U!4+TQ#7TU%4U-!1T53
M+P``````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`V,@`P,C`T-C,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M<'1?4%0O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P-#(W,S(W`#$P-3$U-#,Q,#8R`#`R,C$S-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#>$@25`````','```<````
MM#L``.\)``!,=P````````B?``!-````"9\``+\```!7GP``9````!>@``"^
M````?*```)`````[H0``0P```,RA```\````$*(``"L```!-H@``+@```'FB
M```I````J*(``"@```#2H@``10```/NB``!'````0:,``$H```")HP``1P``
M`-2C``!%````'*0``$@```!BI```.0```*ND``!&````Y:0``$@````LI0``
M,````'6E``!%````IJ4``$8```#LI0``3````#.F```T````@*8``#(```"U
MI@``:0```.BF```P````4J<``"4```"#IP``B````*FG``!`````,J@``/8`
M``!SJ```2@```&JI```L````M:D``(4```#BJ0``2````&BJ```.````L:H`
M``\```#`J@``#0```-"J```(````WJH```L```#GJ@``#````/.J```$````
M`*L``!L````%JP``+0```"&K```=````3ZL``"0```!MJP``*0```)*K```9
M````O*L```P```#6JP``$0```..K```E````]:L```\````;K```"P```"NL
M```1````-ZP```X```!)K```!0```%BL```H````7JP```@```"'K```"@``
M`)"L```5````FZP``!(```"QK```"P```,2L```3````T*P```X```#DK```
M"@```/.L```-````_JP``"X````,K0``#@```#NM```1````2JT```T```!<
MK0``#````&JM```-````=ZT```8```"%K0``"@```(RM```/````EZT``!@`
M``"GK0``#````,"M```;````S:T```X```#IK0``#@```/BM```(````!ZX`
M``D````0K@``0@```!JN```N````7:X``!H```",K@``,@```*>N```X````
MVJX``%0````3KP``40```&BO``!:````NJ\``%<````5L```-````&VP```)
M````HK````T```"LL```!P```+JP```*````PK````\```#-L```!0```-VP
M```&````X[```!$```#JL```"````/RP```)````!;$```D````/L0``)0``
M`!FQ```@````/[$``!````!@L0``#P```'&Q```*````@;$```,```",L0``
M#P```)"Q```4````H+$```D```"UL0``#0```+^Q```2````S;$``!D```#@
ML0``'@```/JQ```/````&;(```H````IL@``#P```#2R```(````1+(``"0`
M``!-L@``%````'*R```6````A[(```@```">L@``3@```*>R```M````]K(`
M`!\````DLP``&0```$2S```'````7K,```P```!FLP``+````'.S```.````
MH+,```,```"OLP``"P```+.S```'````O[,```<```#'LP``!0```,^S```%
M````U;,```H```#;LP```P```.:S```7````ZK,```H````"M```#P````VT
M```.````';0``!@````LM```(P```$6T```.````:;0``!0```!XM```%P``
M`(VT```7````I;0``!<```"]M```$P```-6T```/````Z;0```X```#YM```
M'P````BU```=````*+4```<```!&M0``!@```$ZU```(````5;4```\```!>
MM0``!@```&ZU```*````=;4``!,```"`M0``"P```)2U```5````H+4``!4`
M``"VM0``!P```,RU```0````U+4```4```#EM0``%0```.NU```1`````;8`
M``P````3M@``.P```""V```X````7+8```D```"5M@``!P```)^V```4````
MI[8```,```"\M@``!0```,"V```0````QK8```D```#7M@``$P```.&V```Y
M````];8``!(````OMP``)P```$*W```L````:K<``"H```"7MP``)0```,*W
M```*````Z+<```8```#SMP``"0```/JW```'````!+@``"\````,N```-P``
M`#RX```N````=+@``%4```"CN```+0```/FX```M````)[D``"T```!5N0``
M0````(.Y```C````Q+D``",```#HN0``+0````RZ```S````.KH``!4```!N
MN@``&0```(2Z```I````GKH``"0```#(N@``$0```.VZ```*````_[H```P`
M```*NP``"@```!>[```0````(KL``!8````SNP``%@```$J[```'````8;L`
M``<```!INP``%````'&[```*````AKL```@```"1NP``"````)J[```'````
MH[L```<```"KNP``!@```+.[```%````NKL```<```#`NP``!@```,B[```(
M````S[L``"D```#8NP``#@````*\```*````$;P```0````<O```!P```"&\
M```)````*;P```8````SO```$0```#J\```'````3+P``!8```!4O```!```
M`&N\```(````<+P```8```!YO```#0```("\```&````CKP``!X```"5O```
M$0```+2\```B````QKP``!8```#IO```"`````"]```-````";T```P````7
MO0``!P```"2]```#````++T```,````PO0``%P```#2]```3````3+T``!T`
M``!@O0``"````'Z]```$````A[T```@```",O0``"````)6]``!!````GKT`
M`"````#@O0``!@````&^```&````"+X``!4````/O@``&````"6^```B````
M/KX``"X```!AO@``'0```)"^```A````KKX``%0```#0O@``*0```"6_```*
M````3[\```<```!:OP``%0```&*_```.````>+\```H```"'OP``#P```)*_
M```-````HK\```\```"POP``#0```,"_```)````SK\``!0```#8OP``!@``
M`.V_```8````]+\``!T````-P```$P```"O````1````/\```!0```!1P```
M!````&;````&````:\```%0```!RP```!````,?````.````S,```$0```#;
MP```!0```"#!```%````)L$``!L````LP0``&@```$C!```1````8\$``!$`
M``!UP0``'````(?!```J````I,$``!````#/P0``(0```.#!```E`````L(`
M`!D````HP@``!0```$+"```3````2,(``!(```!<P@``"@```&_"```/````
M>L(```T```"*P@``$0```)C"```3````JL(```P```"^P@``!@```,O"```,
M````TL(```8```#?P@``%P```.;"```0````_L(``!$````/PP``"````"'#
M```%````*L,```P````PPP``$````#W#```%````3L,```T```!4PP``!@``
M`&+#```'````:<,```T```!QPP``$````'_#```)````D,,```<```":PP``
M"P```*+#```+````KL,```<```"ZPP``!P```,+#```4````RL,```D```#?
MPP``"0```.G#```*````\\,``!D```#^PP``'0```!C$```,````-L0``!``
M``!#Q```!0```%3$```E````6L0``!(```"`Q```$P```)/$```K````I\0`
M`#L```#3Q```(`````_%```V````,,4``"$```!GQ0``$````(G%```(````
MFL4```P```"CQ0``!@```+#%```$````M\4```X```"\Q0``$````,O%```*
M````W,4```T```#GQ0``'@```/7%```;````%,8``"$````PQ@``'@```%+&
M```9````<<8``!X```"+Q@``&P```*K&```N````QL8``!<```#UQ@``)@``
M``W'```P````-,<``!L```!EQP``'@```(''```<````H,<``"8```"]QP``
M*P```.3'```S````$,@``"8```!$R```*P```&O(```X````E\@``!T```#0
MR```%0```.[(```O````!,D``"`````TR0``$@```%7)```I````:,D``!X`
M``"2R0``$@```+')``"B````Q,D``!8```!GR@``(P```'[*```H````HLH`
M`"D```#+R@``*````/7*```?````'LL``!4````^RP``(````%3+```E````
M=<L``"@```";RP``+0```,3+```P````\LL``)(````CS```(0```+;,```6
M````V,P``!P```#OS```)@````S-```J````,\T``$$```!>S0``1````*#-
M```,````Y<T```<```#RS0``!P```/K-```&`````LX```T````)S@``$```
M`!?.```2````*,X``!,````[S@``$@```$_.```'````8LX```0```!JS@``
M$````&_.```,````@,X```X```"-S@``#P```)S.```3````K,X```T```#`
MS@``*````,[.```#````]\X```T```#[S@``!@````G/```1````$,\``!<`
M```BSP``&P```#K/```.````5L\```(```!ESP``!0```&C/```0````;L\`
M``0```!_SP``#0```(3/```.````DL\```,```"ASP``#@```*7/```(````
MM,\```\```"]SP``#P```,W/```'````W<\```T```#ESP``$````///```3
M````!-```!,````8T```"P```"S0```&````.-````P````_T```$0```$S0
M```9````7M````L```!XT```#0```(30```B````DM```!L```"UT```-```
M`-'0```*````!M$``!@````1T0``&0```"K1```6````1-$``"\```!;T0``
M(@```(O1```-````KM$```<```"\T0``%````,31```+````V=$``"(```#E
MT0``+P````C2```+````.-(```D```!$T@``&0```$[2```+````:-(``!<`
M``!TT@``%P```(S2```)````I-(``!8```"NT@``#P```,72```9````U=(`
M`!8```#OT@``#@````;3```8````%=,```@````NTP``#0```#?3```F````
M1=,``$,```!LTP``"````+#3```2````N=,```@```#,TP``"P```-73```O
M````X=,```X````1U```!0```"#4```&````)M0```,````MU```!P```#'4
M```$````.=0```H````^U```"@```$G4```/````5-0``!````!DU```%P``
M`'74```1````C=0``!D```"?U```%P```+G4```)````T=0```4```#;U```
M"P```.'4```*````[=0```(```#XU```!0```/O4```-`````=4``!L````/
MU0``%P```"O5```)````0]4```X```!-U0``#0```%S5```2````:M4``#@`
M``!]U0``(````+;5```(````U]4```X```#@U0``>P```._5```8````:]8`
M`$````"$U@``$0```,76```'````U]8```4```#?U@``&0```.76```3````
M_]8```<````3UP``!P```!O7```(````(]<```8````LUP``!@```#/7```0
M````.M<```\```!+UP``$````%O7```/````;-<```L```!\UP``#P```(C7
M```,````F-<```\```"EUP``!P```+77```*````O=<```8```#(UP``#@``
M`,_7```,````WM<``"@```#KUP``#P```!38```(````)-@``!8````MV```
M"````$38```3````3=@``!X```!AV```(0```(#8```@````HM@``!D```##
MV```%P```-W8```E````]=@``!<````;V0``!````#/9```;````.-D```T`
M``!4V0``#````&+9```#````;]D```@```!SV0``"@```'S9```,````A]D`
M``L```"4V0``$````*#9```,````L=D```0```"^V0``$P```,/9```4````
MU]D```P```#LV0``"0```/G9```.`````]H```L````2V@``&P```![:```'
M````.MH```<```!"V@``"@```$K:```-````5=H```D```!CV@``!````&W:
M```%````<MH```,```!XV@``&````'S:```*````E=H```0```"@V@``)@``
M`*7:```.````S-H``'P```#;V@``%0```%C;```%````;ML```<```!TVP``
M#````'S;```(````B=L```H```"2VP``!@```)W;```(````I-L``!8```"M
MVP``$@```,3;```"````U]L```8```#:VP``!@```.';```4````Z-L```T`
M``#]VP``$`````O<```;````'-P```0````XW```"0```#W<```0````1]P`
M``D```!8W```"0```&+<```%````;-P```4```!RW```&@```'C<```(````
MD]P```8```"<W```&0```*/<```.````O=P``"(```#,W```!P```._<```'
M````]]P```X```#_W```!0````[=```)````%-T```H````>W0```@```"G=
M```&````+-T```T````SW0``"0```$'=```&````2]T``!(```!2W0``"0``
M`&7=```'````;]T``!0```!WW0``'0```(S=```1````JMT```8```"\W0``
M"@```,/=```$````SMT```D```#3W0``"````-W=```1````YMT``!$```#X
MW0``"0````K>```&````%-X```T````;W@``!@```"G>```$````,-X``#D`
M```UW@``/0```&_>```Z````K=X``!X```#HW@``!0````??```.````#=\`
M``0````<WP``!@```"'?```A````*-\```T```!*WP``%0```%C?```&````
M;M\```0```!UWP``$0```'K?```&````C-\``*````"3WP``"@```#3@```B
M````/^````0```!BX```)0```&?@```%````C>```!T```"3X```!````+'@
M```,````MN````H```##X```"````,[@```)````U^````4```#AX```&P``
M`.?@```Z`````^$``#`````^X0``-0```&_A```I````I>$``"X```#/X0``
M1P```/[A```X````1N(``"D```!_X@``/P```*GB```N````Z>(``"T````8
MXP``'P```$;C```/````9N,``!(```!VXP``"P```(GC```F````E>,``"D`
M``"\XP``)````.;C```F````"^0```@````RY```"@```#OD```)````1N0`
M``<```!0Y```(````%CD```@````>>0``"8```":Y```"@```,'D```9````
MS.0``"D```#FY```%@```!#E```2````)^4```<````ZY0``"@```$+E```/
M````3>4``!````!=Y0``0````&[E``!P````K^4``&8````@Y@``#@```(?F
M```)````EN8```H```"@Y@``$@```*OF```3````ON8```P```#2Y@``!@``
M`-_F```/````YN8``!(```#VY@``$`````GG```1````&N<``!P````LYP``
M(P```$GG``!J````;><```\```#8YP``!0```.CG```0````[N<```D```#_
MYP``!`````GH```+````#N@``"`````:Z```&@```#OH```4````5N@```P`
M``!KZ```#````'CH```/````A>@``!4```"5Z```*0```*OH```J````U>@`
M`"8`````Z0``)P```"?I```I````3^D``"H```!YZ0``&0```*3I``!"````
MOND``!$````!Z@``$@```!/J```3````)NH``!0````ZZ@``#P```$_J```6
M````7^H``!<```!VZ@``$````([J```1````G^H``#0```"QZ@``$P```.;J
M```2````^NH``#4````-ZP``%````$/K```'````6.L```P```!@ZP``(```
M`&WK```0````CNL``!0```"?ZP``$0```+3K```7````QNL``!P```#>ZP``
M$P```/OK```4````#^P``!H````D[```$0```#_L```:````4>P``!X```!L
M[```&@```(OL```3````INP``!4```"Z[```$0```-#L```7````XNP``!0`
M``#Z[```%P````_M```5````)^T```D````][0``&0```$?M```$````8>T`
M``<```!F[0``"P```&[M```1````>NT```8```",[0``!@```)/M```&````
MFNT```4```"A[0``!P```*?M```'````K^T```4```"W[0``%@```+WM```&
M````U.T```8```#;[0``!````.+M```$````Y^T```<```#L[0``#@```/3M
M```,`````^X```P````0[@``#0```!WN```*````*^X```X````V[@``!0``
M`$7N```H````2^X```X```!T[@``#````(/N```/````D.X```H```"@[@``
M"````*ON```)````M.X``"L```"^[@``!````.KN```(````[^X``"8```#X
M[@``$@```!_O```/````,N\```8```!"[P``"@```$GO```'````5.\```@`
M``!<[P``(````&7O```)````AN\```P```"0[P``#0```)WO```.````J^\`
M`!8```"Z[P``$0```-'O```&````X^\```,```#J[P``!@```.[O```9````
M]>\```<````/\```!````!?P```+````'/````L````H\```!P```#3P```'
M````//```!8```!$\```#0```%OP```-````:?````H```!W\```$````(+P
M```/````D_```!$```"C\```%P```+7P```*````S?```!$```#8\```"```
M`.KP```$````\_````\```#X\```.@````CQ```%````0_$```P```!)\0``
M'@```%;Q```.````=?$``!````"$\0``"P```)7Q```,````H?$```D```"N
M\0``!P```+CQ```*````P/$```D```#+\0``#@```-7Q```0````Y/$``!H`
M``#U\0``"@```!#R```)````&_(``!0````E\@``"@```#KR```,````1?(`
M``\```!2\@``"````&+R```&````:_(```<```!R\@``"P```'KR``!'````
MAO(```T```#.\@``"0```-SR```$````YO(```,```#K\@``$P```._R```3
M`````_,``!,````7\P``"@```"OS```"````-O,```0````Y\P``)0```#[S
M```#````9/,```4```!H\P``*@```&[S```*````F?,```4```"D\P``!```
M`*KS```*````K_,```T```"Z\P``0````,CS```3````"?0```8````=]```
M"````"3T```(````+?0```0````V]```!0```#OT``!H````0?0```D```"J
M]```#````+3T```%````P?0```8```#']```&P```,[T```O````ZO0``!``
M```:]0``"@```"OU```/````-O4```H```!&]0``"0```%'U```3````6_4`
M`!L```!O]0``&````(OU```7````I/4```X```"\]0```P```,OU```'````
MS_4```@```#7]0``!P```.#U```*````Z/4```L```#S]0``+0```/_U```5
M````+?8``#````!#]@``)````'3V```'````F?8``%$```"A]@``$````//V
M```,````!/<```T````1]P``&@```!_W``!*````.O<``!D```"%]P``!@``
M`)_W```:````IO<```8```#!]P``!@```,CW```?````S_<```8```#O]P``
M"0```/;W```8`````/@``!<````9^```!@```#'X```-````./@``"(```!&
M^```5P```&GX```3````P?@``",```#5^```$P```/GX```"````#?D```L`
M```0^0``"````!SY```-````)?D```H````S^0``!@```#[Y```'````1?D`
M`!0```!-^0``!@```&+Y```(````:?D```X```!R^0``!P```('Y```*````
MB?D```L```"4^0``!P```*#Y```,````J/D```T```"U^0``#````,/Y```)
M````T/D```D```#:^0``"@```.3Y```'````[_D```D```#W^0``!P````'Z
M```*````"?H``!L````4^@``$@```##Z```*````0_H```D```!.^@``$```
M`%CZ```'````:?H``!(```!Q^@``!````(3Z```'````B?H```4```"1^@``
M!0```)?Z```+````G?H``!0```"I^@``$0```+[Z```:````T/H``!8```#K
M^@``%`````+[```7````%_L``!@````O^P``'````$C[```9````9?L```<`
M``!_^P``!0```(?[```-````C?L```P```";^P``"````*C[```7````L?L`
M``L```#)^P``$P```-7[```$````Z?L```H```#N^P``!````/G[```-````
M_OL```P````,_```!0```!G\```)````'_P```4````I_```!P```"_\```%
M````-_P```0````]_````@```$+\```X````1?P``"P```!^_```$@```*O\
M```I````OOP``#(```#H_```"@```!O]```V````)OT``"P```!=_0``%0``
M`(K]```N````H/T``#,```#/_0``,P````/^```X````-_X```\```!P_@``
M&````(#^```[````F?X``!````#5_@``%````.;^```3````^_X``!4````/
M_P``%````"7_```2````.O\``!0```!-_P``%0```&+_```M````>/\``"T`
M``"F_P``,0```-3_```M````!@`!`"X````T``$`+P```&,``0`L````DP`!
M`&(```#```$`$P```",!`0`(````-P$!``@```!``0$`*P```$D!`0`A````
M=0$!`!H```"7`0$`"0```+(!`0!%````O`$!`$$````"`@$`!````$0"`0`3
M````20(!`!0```!=`@$`#@```'("`0`3````@0(!`!@```"5`@$`!@```*X"
M`0`)````M0(!``H```"_`@$`#P```,H"`0`0````V@(!``<```#K`@$`#@``
M`/,"`0`%`````@,!`!L````(`P$`!@```"0#`0`(````*P,!``8````T`P$`
M%````#L#`0`1````4`,!``X```!B`P$`.````'$#`0`"````J@,!``8```"M
M`P$`#@```+0#`0`:````PP,!``4```#>`P$`!P```.0#`0`.````[`,!``8`
M``#[`P$`!`````($`0`I````!P0!`!<````Q!`$`'P```$D$`0!<````:00!
M`!0```#&!`$`/@```-L$`0`?````&@4!`!`````Z!0$`!P```$L%`0`.````
M4P4!``@```!B!0$`#````&L%`0`,````>`4!`!,```"%!0$`"@```)D%`0`=
M````I`4!`!D```#"!0$`!0```-P%`0`1````X@4!`!$```#T!0$`)`````8&
M`0`5````*P8!`!(```!!!@$`#@```%0&`0`9````8P8!``@```!]!@$`"0``
M`(8&`0`-````D`8!``H```">!@$`!P```*D&`0`/````L08!``8```#!!@$`
M"P```,@&`0`*````U`8!``<```#?!@$`"````.<&`0`%````\`8!`!\```#V
M!@$`!@```!8'`0`0````'0<!``@````N!P$`#0```#<'`0`(````10<!`!(`
M``!.!P$`+````&$'`0`:````C@<!``D```"I!P$`"@```+,'`0`5````O@<!
M``4```#4!P$`%````-H'`0`$````[P<!`!````#T!P$`!@````4(`0`'````
M#`@!`!X````4"`$`*````#,(`0`*````7`@!`!P```!G"`$`&@```(0(`0`/
M````GP@!`!0```"O"`$`!````,0(`0`$````R0@!``L```#."`$`!0```-H(
M`0`&````X`@!``@```#G"`$`!@```/`(`0`*````]P@!`!L````""0$`-```
M`!X)`0`T````4PD!`"````"("0$`*0```*D)`0`@````TPD!`$$```#T"0$`
M&@```#8*`0`H````40H!`"D```!Z"@$`40```*0*`0`O````]@H!`"(````F
M"P$`!@```$D+`0`(````4`L!``4```!9"P$`"````%\+`0`9````:`L!`!D`
M``"""P$`*@```)P+`0`C````QPL!`!D```#K"P$`+@````4,`0`T````-`P!
M``@```!I#`$`%P```'(,`0`*````B@P!``<```"5#`$`(0```)T,`0`0````
MOPP!``X```#0#`$`"P```-\,`0`'````ZPP!`!,```#S#`$`"`````<-`0`+
M````$`T!``H````<#0$`%````"<-`0`/````/`T!`#(```!,#0$`"P```'\-
M`0`%````BPT!``4```"1#0$`%P```)<-`0`/````KPT!``0```"_#0$`"@``
M`,0-`0`)````SPT!``L```#9#0$`#0```.4-`0`,````\PT!``X`````#@$`
M!0````\.`0`$````%0X!``T````:#@$`,@```"@.`0!%````6PX!`!<```"A
M#@$`'@```+D.`0`4````V`X!``4```#M#@$`%````/,.`0`'````"`\!``X`
M```0#P$`*@```!\/`0`&````2@\!``P```!1#P$`#0```%X/`0`1````;`\!
M``L```!^#P$`-@```(H/`0`*````P0\!`"(```#,#P$`"P```.\/`0`/````
M^P\!`#(````+$`$`)0```#X0`0`P````9!`!`#$```"5$`$`+0```,<0`0`.
M````]1`!``4````$$0$`#@````H1`0`3````&1$!``<````M$0$`&@```#41
M`0`(````4!$!`!$```!9$0$`!P```&L1`0`4````<Q$!`!@```"($0$`!P``
M`*$1`0`%````J1$!``P```"O$0$`#````+P1`0`2````R1$!``0```#<$0$`
M!P```.$1`0`*````Z1$!``L```#T$0$`#``````2`0`.````#1(!``X````<
M$@$`!0```"L2`0`%````,1(!`"X````W$@$`)@```&82`0`C````C1(!``,`
M``"Q$@$`$@```+42`0`&````R!(!`!X```#/$@$`&````.X2`0`E````!Q,!
M``T````M$P$`"0```#L3`0`#````11,!``<```!)$P$`"@```%$3`0`"````
M7!,!``P```!?$P$`%0```&P3`0`+````@A,!`!D```".$P$`(````*@3`0`2
M````R1,!``4```#<$P$`"@```.(3`0`5````[1,!`!(````#%`$`#````!84
M`0`$````(Q0!``<````H%`$`"0```#`4`0`,````.A0!`%(```!'%`$`%P``
M`)H4`0`D````LA0!`!(```#7%`$`!P```.H4`0`&````\A0!``X```#Y%`$`
M(@````@5`0`=````*Q4!``P```!)%0$`#0```%85`0`5````9!4!`!(```!Z
M%0$`#P```(T5`0`4````G14!`!L```"R%0$`$````,X5`0!I````WQ4!`!H`
M``!)%@$`%P```&06`0`G````?!8!`!H```"D%@$`%P```+\6`0`;````UQ8!
M`!D```#S%@$`'P````T7`0`3````+1<!``@```!!%P$`!P```$H7`0`(````
M4A<!``D```!;%P$`%0```&47`0`-````>Q<!`",```")%P$`$P```*T7`0`#
M````P1<!`$8```#%%P$`/P````P8`0`W````3!@!`%<```"$&`$`!0```-P8
M`0`?````XA@!`"\````"&0$`"@```#(9`0`(````/1D!``T```!&&0$`+0``
M`%09`0`$````@AD!`$\```"'&0$`)0```-<9`0`<````_1D!``L````:&@$`
M'P```"8:`0`=````1AH!`"4```!D&@$`(````(H:`0`D````JQH!`"````#0
M&@$`"P```/$:`0`'````_1H!``T````%&P$`#````!,;`0`7````(!L!``8`
M```X&P$`.0```#\;`0`,````>1L!``<```"&&P$`&0```(X;`0`)````J!L!
M`!,```"R&P$`"0```,8;`0`$````T!L!`!````#5&P$`"@```.8;`0`(````
M\1L!``@```#Z&P$`!`````,<`0`+````"!P!``P````4'`$`$@```"$<`0`1
M````-!P!``P```!&'`$`&@```%,<`0`/````;AP!``<```!^'`$`#0```(8<
M`0`4````E!P!``X```"I'`$`#````+@<`0`;````Q1P!`"P```#A'`$`$P``
M``X=`0`<````(AT!`"@````_'0$`!@```&@=`0`'````;QT!`!,```!W'0$`
M!0```(L=`0`$````D1T!`!<```"6'0$`"@```*X=`0`,````N1T!``D```#&
M'0$`!@```-`=`0`)````UQT!``@```#A'0$`"0```.H=`0`*````]!T!`!$`
M``#_'0$`!@```!$>`0`8````&!X!``X````Q'@$`#@```$`>`0`-````3QX!
M``L```!='@$`'0```&D>`0`+````AQX!``(```"3'@$`!P```)8>`0`&````
MGAX!`&4```"E'@$`"0````L?`0`'````%1\!`"8````='P$`.````$0?`0`:
M````?1\!`"H```"8'P$`.P```,,?`0`H````_Q\!`#0````H(`$`&0```%T@
M`0`5````=R`!``4```"-(`$`!P```),@`0`(````FR`!``<```"D(`$`!0``
M`*P@`0`'````LB`!``X```"Z(`$`"0```,D@`0`&````TR`!``@```#:(`$`
M"P```.,@`0`'````[R`!``@```#W(`$`!P`````A`0`6````""$!``D````?
M(0$`!@```"DA`0`+````,"$!`!P````\(0$`%````%DA`0`'````;B$!`!$`
M``!V(0$`"````(@A`0`.````D2$!``@```"@(0$`!0```*DA`0`0````KR$!
M`!````#`(0$`!@```-$A`0`9````V"$!``H```#R(0$`'````/TA`0`'````
M&B(!``4````B(@$`$````"@B`0`4````.2(!``L```!.(@$`#0```%HB`0`H
M````:"(!`!@```"1(@$`%P```*HB`0`$````PB(!``D```#'(@$`"@```-$B
M`0`'````W"(!``(```#D(@$`#@```.<B`0`(````]B(!`!\```#_(@$`/@``
M`!\C`0`C````7B,!`#@```""(P$`)@```+LC`0`Q````XB,!`"<````4)`$`
M9````#PD`0`4````H20!`%4```"V)`$`.`````PE`0!*````124!`%L```"0
M)0$`*````.PE`0`X````%28!`"@```!.)@$`+````'<F`0`G````I"8!`!L`
M``#,)@$`/@```.@F`0"I`0``)R<!`"@```#1*`$`(P```/HH`0`7````'BD!
M`$@````V*0$`A0```'\I`0`P````!2H!`$$````V*@$`6P```'@J`0!)````
MU"H!`!T````>*P$`&````#PK`0`A````52L!`!\```!W*P$`*P```)<K`0`A
M````PRL!`"<```#E*P$`'0````TL`0`1````*RP!`#,````]+`$`)0```'$L
M`0`G````ERP!`!\```"_+`$`,````-\L`0!I````$"T!`"L```!Z+0$`,0``
M`*8M`0!!````V"T!`#,````:+@$`)0```$XN`0`]````="X!`&4```"R+@$`
M30```!@O`0`O````9B\!`"X```"6+P$`,````,4O`0!4````]B\!`(,```!+
M,`$`6@```,\P`0!(````*C$!`$H```!S,0$`,@```+XQ`0`O````\3$!`"P`
M```A,@$`+0```$XR`0!Q````?#(!`&\```#N,@$`LP```%XS`0`7````$C0!
M`"4````J-`$`,@```%`T`0`I````@S0!`#X```"M-`$`(@```.PT`0!2````
M#S4!`"4```!B-0$`"P```(@U`0"Q````E#4!`$4```!&-@$`(0```(PV`0`N
M````KC8!`#````#=-@$`)0````XW`0`<````-#<!`#$```!1-P$`!P```(,W
M`0`'````BS<!``0```"3-P$`#0```)@W`0`+````IC<!``X```"R-P$`"P``
M`,$W`0`%````S3<!`!````#3-P$``@```.0W`0!9````YS<!``4```!!.`$`
M$@```$<X`0`$````6C@!``<```!?.`$`"````&<X`0`%````<#@!``,```!V
M.`$`$````'HX`0`*````BS@!``P```"6.`$`$P```*,X`0`-````MS@!``(`
M``#%.`$`!P```,@X`0`&````T#@!`!0```#7.`$`#````.PX`0`8````^3@!
M``8````2.0$`$@```!DY`0`,````+#D!``,````Y.0$`*@```#TY`0`$````
M:#D!``8```!M.0$`!P```'0Y`0`?````?#D!`#4```"<.0$`+@```-(Y`0`O
M`````3H!`!<````Q.@$`(````$DZ`0`;````:CH!`!@```"&.@$`)````)\Z
M`0`?````Q#H!`!H```#D.@$`(````/\Z`0`:````(#L!`#(````[.P$`&@``
M`&X[`0`O````B3L!`"L```"Y.P$`'P```.4[`0`C````!3P!`!\````I/`$`
M&@```$D\`0`E````9#P!`"8```"*/`$`)0```+$\`0`D````USP!`!@```#\
M/`$`'0```!4]`0`D````,ST!`!@```!8/0$`(@```'$]`0`5````E#T!`"4`
M``"J/0$`/````-`]`0`?````#3X!`",````M/@$`'P```%$^`0`@````<3X!
M`!H```"2/@$`&````*T^`0`F````QCX!`!X```#M/@$`*0````P_`0`>````
M-C\!``D```!5/P$`#````%\_`0`7````;#\!`"\```"$/P$`)````+0_`0`'
M````V3\!``\```#A/P$`%````/$_`0`.````!D`!``T````50`$`)````"-`
M`0`%````2$`!``<```!.0`$`(@```%9``0`E````>4`!`!,```"?0`$`&@``
M`+-``0`=````SD`!`!H```#L0`$`!P````=!`0#'````#T$!``L```#700$`
M%0```.-!`0`,````^4$!``8````&0@$`"0````U"`0`+````%T(!``T````C
M0@$`'0```#%"`0`7````3T(!``8```!G0@$`,P```&Y"`0`3````HD(!`!,`
M``"V0@$`!P```,I"`0`&````TD(!``\```#90@$`!P```.E"`0`R````\4(!
M`"$````D0P$`$P```$9#`0`,````6D,!`!$```!G0P$`,@```'E#`0`0````
MK$,!``@```"]0P$`'0```,9#`0`)````Y$,!``H```#N0P$`!0```/E#`0`4
M````_T,!``H````41`$`'0```!]$`0`(````/40!`!\```!&1`$`"````&9$
M`0`:````;T0!`"<```"*1`$`!@```+)$`0`5````N40!``<```#/1`$`"```
M`-=$`0`)````X$0!`#\```#J1`$`!P```"I%`0`/````,D4!``X```!"10$`
M$````%%%`0`)````8D4!``D```!L10$`"````'9%`0`3````?T4!``<```"3
M10$`&0```)M%`0`*````M44!`!<```#`10$`%````-A%`0`*````[44!``P`
M``#X10$`%P````5&`0`$````'48!`"H````B1@$`$0```$U&`0`'````7T8!
M``D```!G1@$``@```'%&`0`0````=$8!`!@```"%1@$`"P```)Y&`0`#````
MJD8!``@```"N1@$`!@```+=&`0`'````OD8!``T```#&1@$`"P```-1&`0`4
M````X$8!`!4```#U1@$`#@````M'`0`O````&D<!`"````!*1P$`'````&M'
M`0`,````B$<!`#$```"51P$`!0```,='`0`2````S4<!`#\```#@1P$`$@``
M`"!(`0`*````,T@!``8````^2`$`!````$5(`0`$````2D@!``H```!/2`$`
M$P```%I(`0`%````;D@!``8```!T2`$`!@```'M(`0`)````@D@!``0```",
M2`$`#````)%(`0`*````GD@!`"````"I2`$`!0```,I(`0`8````T$@!`!D`
M``#I2`$`'P````-)`0`=````(TD!`!$```!!20$``@```%-)`0`$````5DD!
M``H```!;20$`!@```&9)`0`%````;4D!``,```!S20$`#````'=)`0!%````
MA$D!`!H```#*20$`-0```.5)`0`H````&TH!`%,```!$2@$`&0```)A*`0!R
M````LDH!`"`````E2P$`-0```$9+`0`A````?$L!`$4```">2P$`,````.1+
M`0`H````%4P!`"D````^3`$`)@```&A,`0`E````CTP!`"@```"U3`$`*```
M`-Y,`0`B````!TT!`"L````J30$`,````%9-`0`2````ATT!`!,```":30$`
M$````*Y-`0!Y````OTT!``D````Y3@$`<@```$-.`0!S````MDX!`'P````J
M3P$`*P```*=/`0!4````TT\!`!<````H4`$`%@```$!0`0`/````5U`!`&4`
M``!G4`$`'P```,U0`0!`````[5`!`!\````N40$`'````$Y1`0!1````:U$!
M`!0```"]40$`"@```-)1`0`%````W5$!``8```#C40$`"````.I1`0`%````
M\U$!`!(```#Y40$`$`````Q2`0`3````'5(!`!T````Q4@$`#P```$]2`0`/
M````7U(!``0```!O4@$`"0```'12`0`+````?E(!``<```"*4@$`!0```))2
M`0`4````F%(!``<```"M4@$`"````+52`0`/````OE(!``@```#.4@$`#```
M`-=2`0`/````Y%(!``8```#T4@$`%````/M2`0`&````$%,!``P````74P$`
M%0```"13`0`(````.E,!``0```!#4P$`"@```$A3`0`$````4U,!``8```!8
M4P$`!P```%]3`0`$````9U,!``<```!L4P$`&0```'13`0`'````CE,!``(`
M``"64P$``@```)E3`0`)````G%,!``8```"F4P$`!@```*U3`0`G````M%,!
M``(```#<4P$`!````-]3`0`+````Y%,!``D```#P4P$`#P```/I3`0`3````
M"E0!``<````>5`$`!P```"94`0`&````+E0!``8````U5`$`$````#Q4`0`2
M````350!``(```!@5`$`!@```&-4`0`)````:E0!`#,```!T5`$`(@```*A4
M`0`'````RU0!``<```#35`$`!P```-M4`0`+````XU0!``4```#O5`$``@``
M`/54`0`+````^%0!`&(!```$50$`<P```&=6`0"X````VU8!`$(```"45P$`
MP````-=7`0"0````F%@!`$8````I60$`-P```'!9`0`S````J%D!`#8```#<
M60$`+P```!-:`0`N````0UH!`&@```!R6@$`90```-M:`0!G````05L!`&4`
M``"I6P$`9P````]<`0!O````=UP!`#\```#G7`$`9````"==`0!#````C%T!
M`"\```#070$`30````!>`0!$````3EX!`$H```"37@$`,P```-Y>`0`X````
M$E\!`&X```!+7P$`+@```+I?`0`M````Z5\!`(@````78`$`8@```*!@`0`/
M`0```V$!`$X````38@$`-````&)B`0"+````EV(!`%`````C8P$`$````'1C
M`0`5````A6,!`!0```";8P$`!P```+!C`0`)````N&,!``@```#"8P$`!0``
M`,MC`0`>````T6,!`"X```#P8P$`+````!]D`0`I````3&0!`"X```!V9`$`
M&````*5D`0`*````OF0!`!$```#)9`$`*P```-MD`0`3````!V4!`!`````;
M90$`$````"QE`0`4````/64!``4```!290$`*````%AE`0`-````@64!``T`
M``"/90$`$P```)UE`0`-````L64!``L```"_90$`&P```,ME`0`0````YV4!
M``H```#X90$`%@````-F`0`_````&F8!``T```!:9@$`#P```&AF`0`0````
M>&8!``L```")9@$`#0```)5F`0`&````HV8!``T```"J9@$`$P```+AF`0`5
M````S&8!``T```#B9@$`&P```/!F`0`;````#&<!`!,````H9P$`"````#QG
M`0`)````16<!`%@```!/9P$`-````*AG`0`5````W6<!`#T```#S9P$`3@``
M`#%H`0!J````@&@!`&D```#K:`$`<````%5I`0!O````QFD!`$(````V:@$`
M#P```'EJ`0`2````B6H!``X```"<:@$`$P```*MJ`0`/````OVH!``4```#/
M:@$`!@```-5J`0`3````W&H!``D```#P:@$`#P```/IJ`0`1````"FL!`"$`
M```<:P$`(P```#YK`0`6````8FL!`!````!Y:P$`#0```(IK`0`)````F&L!
M`!4```"B:P$`&0```+AK`0`1````TFL!`!4```#D:P$`&````/IK`0`?````
M$VP!`"0````S;`$`&@```%AL`0`0````<VP!`!<```"$;`$`$@```)QL`0`N
M````KVP!`!@```#>;`$`'````/=L`0`4````%&T!`%D````I;0$`*@```(-M
M`0`J````KFT!`"H```#9;0$`"`````1N`0`)````#6X!`#<````7;@$`#0``
M`$]N`0`(````76X!``L```!F;@$`!P```')N`0`'````>FX!``<```"";@$`
M!P```(IN`0`,````DFX!``0```"?;@$`(@```*1N`0`/````QVX!`!,```#7
M;@$`%P```.MN`0`<`````V\!`#`````@;P$`"0```%%O`0`8````6V\!`!X`
M``!T;P$`(P```)-O`0`1````MV\!`!0```#);P$`$@```-YO`0`/````\6\!
M`",````!<`$`'0```"5P`0`'````0W`!``8```!+<`$`!P```%)P`0`:````
M6G`!``@```!U<`$`"@```'YP`0`1````B7`!``D```";<`$`$0```*5P`0`:
M````MW`!``<```#2<`$`$@```-IP`0`%````[7`!`!8```#S<`$`'@````IQ
M`0`/````*7$!`#\````Y<0$`.P```'EQ`0`)````M7$!``<```"_<0$`$P``
M`,=Q`0`$````VW$!``4```#@<0$`$````.9Q`0`*````]W$!`!0````"<@$`
M/````!=R`0`5````5'(!`"T```!J<@$`,@```)AR`0`Q````RW(!`#````#]
M<@$`"0```"YS`0`&````.',!``D````_<P$`!P```$ES`0`[````47,!`#L`
M``"-<P$`.@```,ES`0!?````!'0!`#D```!D=`$`.0```)YT`0`Y````V'0!
M`$L````2=0$`+0```%YU`0`P````C'4!`#D```"]=0$`/P```/=U`0`5````
M-W8!`!D```!-=@$`,@```&=V`0`F````FG8!`!,```#!=@$`"@```-5V`0`0
M````X'8!``4```#Q=@$`#````/=V`0`>````!'<!`",````C=P$`!@```$=W
M`0`%````3G<!`!4```!4=P$`"P```&IW`0`(````=G<!``H```!_=P$`#```
M`(IW`0`'````EW<!``8```"?=P$`!0```*9W`0`'````K'<!``4```"T=P$`
M"P```+IW`0`R````QG<!`!<```#Y=P$`#0```!%X`0`'````'W@!``<````G
M>`$`"@```"]X`0`%````.G@!`!,```!`>`$`!@```%1X`0`2````6W@!``4`
M``!N>`$`"````'1X`0`$````?7@!``L```"">`$`!@```(YX`0`E````E7@!
M`!$```"[>`$`*P```,UX`0`>````^7@!``@````8>0$`#@```"%Y`0`-````
M,'D!``<````^>0$``P```$9Y`0`#````2GD!`!H```!.>0$`(````&EY`0`K
M````BGD!``H```"V>0$`!0```,%Y`0`(````QWD!``@```#0>0$`7@```-EY
M`0`H````.'H!``8```!A>@$`"````&AZ`0`?````<7H!`"0```"1>@$`+P``
M`+9Z`0`R````YGH!`"8````9>P$`)@```$![`0!=````9WL!`#X```#%>P$`
M%P````1\`0`'````''P!`!(````D?`$`#````#=\`0`0````1'P!`!@```!5
M?`$`%P```&Y\`0`8````AGP!`!@```"??`$`"0```+A\`0`5````PGP!``<`
M``#8?`$`&0```.!\`0`;````^GP!`!D````6?0$`$P```#!]`0`8````1'T!
M`!(```!=?0$`!P```'!]`0!;````>'T!``D```#4?0$`%0```-Y]`0`V````
M]'T!`!(````K?@$`&@```#Y^`0`=````67X!`!D```!W?@$`%P```)%^`0`=
M````J7X!`!X```#'?@$`,@```.9^`0`-````&7\!`"P````G?P$`)P```%1_
M`0`=````?'\!``8```":?P$`'````*%_`0`>````OG\!`!H```#=?P$`&@``
M`/A_`0`+````$X`!`!4````?@`$`$P```#6``0`-````28`!``8```!7@`$`
M#P```%Z``0`(````;H`!`!4```!W@`$`%@```(V``0`1````I(`!`!4```"V
M@`$`!0```,R``0`&````TH`!`!$```#9@`$`"````.N``0`3````](`!``(`
M```(@0$`!P````N!`0`3````$X$!`!(````G@0$`"0```#J!`0`*````1($!
M``D```!/@0$`"@```%F!`0`'````9($!``<```!L@0$`#0```'2!`0`,````
M@H$!``@```"/@0$`"0```)B!`0`:````HH$!`"(```"]@0$`#0```."!`0`8
M````[H$!`!X````'@@$`'@```":"`0`/````18(!`!````!5@@$`,````&:"
M`0`_````EX(!`"$```#7@@$`/````/F"`0`H````-H,!``X```!?@P$`"0``
M`&Z#`0`*````>(,!``X```"#@P$`!@```)*#`0`/````F8,!`!8```"I@P$`
M%P```,"#`0`<````V(,!`"X```#U@P$`+````"2$`0`P````480!`"\```""
MA`$`*0```+*$`0`I````W(0!`"8````&A0$`.0```"V%`0`B````9X4!`#``
M``"*A0$`0@```+N%`0`Q````_H4!`#(````PA@$`)0```&.&`0`R````B88!
M`#D```"\A@$`3@```/:&`0`U````18<!`#@```![AP$`0P```+2'`0`D````
M^(<!`!8````=B`$`3P```#2(`0`I````A(@!`!H```"NB`$`.P```,F(`0`B
M````!8D!`!@````HB0$`U0```$&)`0`:````%XH!`"T````RB@$`,````&"*
M`0`Q````D8H!`#(```##B@$`*0```/:*`0`6````((L!`"X````WBP$`-P``
M`&:+`0`Z````GHL!`#T```#9BP$`.@```!>,`0":````4HP!`"L```#MC`$`
M'P```!F-`0`H````.8T!`#<```!BC0$`-@```)J-`0!6````T8T!`%D````H
MC@$`#0```(*.`0`$````D(X!``8```"5C@$`!0```)R.`0`1````HHX!``X`
M``"TC@$`$````,..`0`5````U(X!`!L```#JC@$`%`````:/`0`1````&X\!
M`!8````MCP$`"0```$2/`0`.````3H\!``\```!=CP$`$0```&V/`0`-````
M?X\!`$,```"-CP$`!@```-&/`0`1````V(\!`!,```#JCP$`$0```/Z/`0`7
M````$)`!`!L````HD`$`#P```$20`0`"````5)`!``L```!7D`$`'````&.0
M`0`$````@)`!`!````"%D`$`$````):0`0`#````IY`!``\```"KD`$`"```
M`+N0`0`0````Q)`!`!(```#5D`$`"P```.B0`0`/````])`!`!$````$D0$`
M%@```!:1`0`6````+9$!``H```!$D0$`!P```$^1`0`-````5Y$!`!$```!E
MD0$`&@```'>1`0`.````DI$!``X```"AD0$`)````+"1`0`:````U9$!`#@`
M``#PD0$`#0```"F2`0`?````-Y(!`!D```!7D@$`&````'&2`0`V````BI(!
M`"<```#!D@$`$@```.F2`0`)````_)(!`!,````&DP$`"0```!J3`0`P````
M)),!`#L```!5DP$`#P```)&3`0`0````H9,!`"$```"RDP$`$@```-23`0`C
M````YY,!`",````+E`$`"@```"^4`0`<````.I0!`!8```!7E`$`'@```&Z4
M`0`6````C90!`!<```"DE`$`&0```+R4`0`'````UI0!``L```#>E`$`*@``
M`.J4`0!*````%94!``@```!@E0$`%````&F5`0`'````?I4!``H```"&E0$`
M-P```)&5`0`3````R94!``8```#=E0$`$P```.25`0`#````^)4!`!0```#\
ME0$`!@```!&6`0`,````&)8!``P````EE@$`$0```#*6`0`1````1)8!`!<`
M``!6E@$`$0```&Z6`0`9````@)8!`!<```":E@$`"````+*6`0`&````NY8!
M`!@```#"E@$`"P```-N6`0`"````YY8!`!,```#JE@$`'P```/Z6`0`?````
M'I<!`!@````^EP$`$@```%>7`0`/````:I<!``\```!ZEP$`%0```(J7`0`^
M````H)<!`#(```#?EP$`"@```!*8`0`/````'9@!`*(````MF`$`'@```-"8
M`0!-````[Y@!`!`````]F0$`$@```$Z9`0`$````89D!`"@```!FF0$`%@``
M`(^9`0`&````IID!`!0```"MF0$`*````,*9`0`%````ZYD!``8```#QF0$`
M#P```/B9`0`.````")H!`!`````7F@$`#@```"B:`0`,````-YH!``X```!$
MF@$`"P```%.:`0`0````7YH!``@```!PF@$`"P```'F:`0`(````A9H!`!4`
M``".F@$`#````*2:`0`_````L9H!`!$```#QF@$`"`````.;`0`3````#)L!
M`!4````@FP$`*P```#:;`0`G````8IL!`"(```"*FP$`(0```*V;`0`8````
MSYL!`!H```#HFP$`)0````.<`0`9````*9P!``,```!#G`$`&0```$><`0`+
M````89P!``L```!MG`$``P```'F<`0`)````?9P!``@```"'G`$`"@```)"<
M`0`1````FYP!``T```"MG`$`$````+N<`0`$````S)P!`"````#1G`$`(0``
M`/*<`0`3````%)T!``\````HG0$`$P```#B=`0`7````3)T!`"X```!DG0$`
M!P```).=`0`)````FYT!`!````"EG0$`$````+:=`0`+````QYT!``@```#3
MG0$`"0```-R=`0`(````YIT!`!8```#OG0$`#`````:>`0`&````$YX!`"D`
M```:G@$`#@```$2>`0")````4YX!`!T```#=G@$`!P```/N>`0`%`````Y\!
M``T````)GP$`!0```!>?`0`'````'9\!``8````EGP$`"````"R?`0`D````
M-9\!`!,```!:GP$``@```&Z?`0`(````<9\!`!(```!ZGP$`%0```(V?`0`/
M````HY\!`!(```"SGP$`)P```,:?`0`"````[I\!``,```#QGP$`$@```/6?
M`0`)````"*`!``T````2H`$`!P```""@`0`2````**`!`"`````[H`$`"```
M`%R@`0`3````9:`!`!4```!YH`$`#0```(^@`0`@````G:`!``<```"^H`$`
M'0```,:@`0`/````Y*`!`!$```#TH`$`"0````:A`0`,````$*$!``(````=
MH0$`!0```""A`0`/````)J$!`!(````VH0$`!@```$FA`0`2````4*$!``L`
M``!CH0$`!P```&^A`0`7````=Z$!`"8```"/H0$`$P```+:A`0`&````RJ$!
M``D```#1H0$`!````-NA`0`6````X*$!``@```#WH0$`%@````"B`0`6````
M%Z(!`!`````NH@$`!0```#^B`0`,````1:(!`"````!2H@$`!````'.B`0!%
M````>*(!`$8```"^H@$`10````6C`0`E````2Z,!`!(```!QHP$`$P```(2C
M`0`'````F*,!``D```"@HP$`%@```*JC`0`0````P:,!`!4```#2HP$`!@``
M`.BC`0`%````[Z,!`!0```#UHP$`!0````JD`0"<````$*0!``H```"MI`$`
M'@```+BD`0`$````UZ0!`#,```#<I`$`!0```!"E`0`<````%J4!``0````S
MI0$`$````#BE`0`0````2:4!`!8```!:I0$`#````'&E`0`%````?J4!`!H`
M``"$I0$`,@```)^E`0`W````TJ4!`$`````*I@$`+````$NF`0`R````>*8!
M`$$```"KI@$`2@```.VF`0`Q````.*<!`$4```!JIP$`-0```+"G`0`W````
MYJ<!`"<````>J`$`$````$:H`0`5````5Z@!``L```!MJ`$`*````'FH`0`@
M````HJ@!`"$```##J`$`'P```.6H`0`(````!:D!``H````.J0$`"@```!FI
M`0`4````)*D!`"D````YJ0$`)P```&.I`0`P````BZD!``L```"\J0$`&0``
M`,BI`0`I````XJD!`!H````,J@$`%````">J`0`4````/*H!``T```!1J@$`
M$````%^J`0`3````<*H!`$0```"$J@$`?0```,FJ`0""````1ZL!`!,```#*
MJP$`#0```-ZK`0`.````[*L!`!$```#[JP$`$@````VL`0`6````(*P!``<`
M```WK`$`$@```#^L`0`3````4JP!`!(```!FK`$`%0```'FL`0`L````CZP!
M`"P```"\K`$`;0```.FL`0`5````5ZT!`!(```!MK0$`&````("M`0`6````
MF:T!``H```"PK0$`"@```+NM`0`A````QJT!`!T```#HK0$`%@````:N`0`.
M````':X!``X````LK@$`%0```#NN`0`5````4:X!`"H```!GK@$`*0```)*N
M`0`I````O*X!`"@```#FK@$`)P````^O`0`I````-Z\!`!H```!AKP$`50``
M`'RO`0`3````TJ\!`!4```#FKP$`%0```/RO`0`4````$K`!`!$````GL`$`
M%P```#FP`0`7````4;`!`!0```!IL`$`$P```'ZP`0`Z````DK`!`!@```#-
ML`$`&0```.:P`0`^`````+$!`!4````_L0$`!P```%6Q`0`1````7;$!`"``
M``!OL0$`$P```)"Q`0`3````I+$!`!X```"XL0$`(@```->Q`0`=````^K$!
M`!L````8L@$`&@```#2R`0`B````3[(!`!(```!RL@$`'````(6R`0`A````
MHK(!`!P```#$L@$`&````.&R`0`;````^K(!`!,````6LP$`&P```"JS`0`<
M````1K,!`!P```!CLP$`&````("S`0`*````F;,!`!H```"DLP$`$P```+^S
M`0`4````T[,!``L```#HLP$`%````/2S`0`0````";0!``<````:M`$`!P``
M`"*T`0`2````*K0!``<````]M`$`!P```$6T`0`%````3;0!`!4```!3M`$`
M!@```&FT`0`;````<+0!``4```",M`$`!0```)*T`0`*````F+0!``<```"C
MM`$`"@```*NT`0`5````MK0!`!0```#,M`$`&````.&T`0`5````^K0!`!,`
M```0M0$`+````"2U`0`3````4;4!`!````!EM0$`&@```':U`0`4````D;4!
M``T```"FM0$`$P```+2U`0`Q````R+4!``8```#ZM0$`"0````&V`0`G````
M"[8!`!,````SM@$`$````$>V`0`&````6+8!`!,```!?M@$`"P```'.V`0`&
M````?[8!`"$```"&M@$`$@```*BV`0`2````N[8!`!0```#.M@$`$@```..V
M`0`8````]K8!`!4````/MP$`%````"6W`0`#````.K<!``H````^MP$`(0``
M`$FW`0`&````:[<!``@```!RMP$`%0```'NW`0`2````D;<!``8```"DMP$`
M!P```*NW`0`S````L[<!``P```#GMP$`$P```/2W`0`)````"+@!`!(````2
MN`$`%0```"6X`0`1````.[@!`!4```!-N`$`#0```&.X`0`$````<;@!``H`
M``!VN`$`!P```(&X`0`4````B;@!`$D```">N`$`"````.BX`0`/````\;@!
M`"4````!N0$`%0```">Y`0`8````/;D!``X```!6N0$`$````&6Y`0`.````
M=KD!``L```"%N0$`#0```)&Y`0`3````G[D!`!,```"SN0$`%P```,>Y`0`L
M````W[D!``L````,N@$`%0```!BZ`0`9````+KH!``T```!(N@$`#````%:Z
M`0`:````8[H!``L```!^N@$`!@```(JZ`0`$````D;H!`!(```"6N@$`5@``
M`*FZ`0`6`````+L!``L````7NP$`!````".[`0`%````*+L!`!@````NNP$`
M&0```$>[`0`:````8;L!``H```!\NP$``@```(>[`0`$````BKL!`",```"/
MNP$``P```+.[`0`%````M[L!`"@```"]NP$`"@```.:[`0`%````\;L!``<`
M``#WNP$`&````/^[`0`1````&+P!`%$````JO`$`$@```'R\`0`&````C[P!
M``<```"6O`$`"````)Z\`0`$````I[P!``4```"LO`$`9````+*\`0`*````
M%[T!``T````BO0$`!0```#"]`0`&````-KT!`!D````]O0$`.````%>]`0`.
M````D+T!``D```"?O0$`%P```*F]`0`*````P;T!``@```#,O0$`&0```-6]
M`0`O````[[T!`"D````?O@$`*````$F^`0`2````<KX!``0```"%O@$`!P``
M`(J^`0`(````DKX!``<```";O@$`#0```*.^`0`,````L;X!`#8```"^O@$`
M'P```/6^`0`Q````%;\!`"4```!'OP$`"````&V_`0!9````=K\!`!$```#0
MOP$`$````.*_`0`2````\[\!`!D````&P`$`3@```"#``0`=````;\`!``8`
M``"-P`$`'P```)3``0`'````M,`!``8```"\P`$`(````,/``0`&````Y,`!
M``D```#KP`$`)P```/7``0`F````'<$!``<```!$P0$`"@```$S!`0`E````
M5\$!`$L```!]P0$`&````,G!`0`=````XL$!`!8`````P@$``@```!?"`0`-
M````&L(!``@````HP@$`$P```#'"`0`-````1<(!``8```!3P@$`!@```%K"
M`0`4````8<(!`!0```!VP@$`"````(O"`0`)````E,(!``L```">P@$`"@``
M`*K"`0`+````M<(!`!$```#!P@$`#P```-/"`0`2````X\(!`!,```#VP@$`
M!@````K#`0`5````$<,!`!0````GPP$`!0```#S#`0`&````0L,!``4```!)
MPP$`%P```$_#`0`@````9\,!`!$```"(PP$`#0```)K#`0`,````J,,!`!0`
M``"UPP$`$````,K#`0`1````V\,!``0```#MPP$`%````/+#`0`%````!\0!
M``4````-Q`$`%P```!/$`0`3````*\0!`!0````_Q`$`'````%3$`0`A````
M<<0!`!D```"3Q`$`&0```*W$`0`=````Q\0!`"(```#EQ`$`'`````C%`0`$
M````)<4!``4````JQ0$`#@```##%`0`.````/\4!``@```!.Q0$`(@```%?%
M`0`-````>L4!`!0```"(Q0$`"````)W%`0`2````IL4!``<```"YQ0$`$```
M`,'%`0`/````TL4!``@```#BQ0$`%@```.O%`0`2`````L8!`!P````5Q@$`
M!0```#+&`0`$````.,8!``,````]Q@$`40```$'&`0`_````D\8!`!X```#3
MQ@$`)````/+&`0!!````%\<!`!$```!9QP$`/@```&O'`0`N````JL<!`!P`
M``#9QP$`.@```/;'`0!*````,<@!`%<```!\R`$`7````-3(`0`0````,<D!
M`"(```!"R0$`1P```&7)`0`5````K<D!`"$```##R0$`'@```.7)`0`C````
M!,H!`!\````HR@$`&0```$C*`0`;````8LH!`!,```!^R@$`.0```)+*`0`Y
M````S,H!`#T````&RP$`.0```$3+`0`Z````?LL!`#L```"YRP$`.````/7+
M`0!Q````+LP!`!T```"@S`$`"@```+[,`0`)````R<P!`#````#3S`$`.P``
M``3-`0`I````0,T!``L```!JS0$`2P```';-`0!&````PLT!``<````)S@$`
M%P```!'.`0`5````*<X!``\````_S@$`$````$_.`0`7````8,X!`!````!X
MS@$`#P```(G.`0`.````F<X!`!,```"HS@$`$0```+S.`0`,````SLX!``X`
M``#;S@$`!0```.K.`0`C````\,X!``0````4SP$`"````!G/`0`&````(L\!
M`!0````ISP$`$0```#[/`0`0````4,\!`%(```!ASP$``@```+3/`0`'````
MM\\!`!(```"_SP$`(````-+/`0`%````\\\!``<```#YSP$`&P````'0`0`(
M````'=`!`!`````FT`$`,@```#?0`0`6````:M`!`#(```"!T`$`=@```+30
M`0`5````*]$!`$X```!!T0$`(@```)#1`0`1````L]$!``8```#%T0$`#```
M`,S1`0`'````V=$!``X```#AT0$`"P```/#1`0`6````_-$!``L````3T@$`
M'````!_2`0`8````/-(!``4```!5T@$`$@```%O2`0`2````;M(!`"4```"!
MT@$`%@```*?2`0`5````OM(!`!$```#4T@$`(P```.;2`0`*````"M,!``P`
M```5TP$`%````"+3`0`3````-],!``P```!+TP$`#@```%C3`0`+````9],!
M`!,```!STP$`#0```(?3`0`*````E=,!`!\```"@TP$`$@```,#3`0`7````
MT],!``8```#KTP$`$````/+3`0`5`````]0!`!8````9U`$`#0```##4`0`8
M````/M0!`#$```!7U`$`'0```(G4`0`.````I]0!``\```"VU`$`)````,;4
M`0`%````Z]0!`!$```#QU`$`!P````/5`0`6````"]4!``<````BU0$`"P``
M`"K5`0`@````-M4!`#0```!7U0$`"0```(S5`0`B````EM4!`!L```"YU0$`
M#0```-75`0`4````X]4!``0```#XU0$`%````/W5`0`)````$M8!``@````<
MU@$`"P```"76`0`.````,=8!``8```!`U@$`"@```$?6`0`A````4M8!`#\`
M``!TU@$`0````+36`0`D````]=8!`"T````:UP$`*@```$C7`0!'````<]<!
M`"0```"[UP$`,P```.#7`0!#````%-@!`&$```!8V`$`-````+K8`0`M````
M[]@!``<````=V0$`"````"79`0`)````+MD!`!0````XV0$`&P```$W9`0`;
M````:=D!`#````"%V0$`)0```+;9`0`B````W-D!`#H```#_V0$`0@```#K:
M`0`'````?=H!`!D```"%V@$`"0```)_:`0`(````J=H!`"````"RV@$`$0``
M`-/:`0`4````Y=H!``T```#ZV@$`"`````C;`0`5````$=L!``D````GVP$`
M#P```#';`0`-````0=L!`!H```!/VP$`&````&K;`0`[````@]L!``H```"_
MVP$`#P```,K;`0`&````VML!`!H```#AVP$`$````/S;`0`%````#=P!``T`
M```3W`$`$````"'<`0`)````,MP!``P````\W`$`#````$G<`0`.````5MP!
M``<```!EW`$``P```&W<`0`-````<=P!`#8```!_W`$`2````+;<`0`8````
M_]P!`"4````8W0$`(0```#[=`0`1````8-T!`!4```!RW0$`"P```(C=`0`2
M````E-T!`"D```"GW0$`!P```-'=`0`-````V=T!``X```#GW0$`$@```/;=
M`0`+````"=X!`#P````5W@$`"0```%+>`0`<````7-X!`!(```!YW@$`%@``
M`(S>`0!`````H]X!`"0```#DW@$`/`````G?`0`Z````1M\!`#8```"!WP$`
M$0```+C?`0`&````RM\!`!<```#1WP$`'````.G?`0`*````!N`!`!T````1
MX`$`"P```"_@`0`0````.^`!``<```!,X`$`%0```%3@`0`5````:N`!``D`
M``"`X`$`!P```(K@`0`4````DN`!`!$```"GX`$`&0```+G@`0`%````T^`!
M``<```#9X`$`"0```.'@`0`0````Z^`!``\```#\X`$`%0````SA`0`5````
M(N$!``<````XX0$`!@```$#A`0`Q````1^$!`"D```!YX0$`)0```*/A`0`(
M````R>$!``\```#2X0$`$P```.+A`0`?````]N$!`!X````6X@$`'P```#7B
M`0`-````5>(!``P```!CX@$``P```'#B`0`'````=.(!``T```!\X@$``@``
M`(KB`0`,````C>(!`!$```":X@$`"P```*SB`0`4````N.(!`!@```#-X@$`
M%0```.;B`0`<````_.(!`",````9XP$`$P```#WC`0`6````4>,!``X```!H
MXP$`!P```'?C`0`*````?^,!``P```"*XP$`#@```)?C`0!:````IN,!`!@`
M```!Y`$`+````!KD`0`5````1^0!``<```!=Y`$`"````&7D`0`2````;N0!
M`"L```"!Y`$`)````*WD`0`4````TN0!`!,```#GY`$`(0```/OD`0`8````
M'>4!`!8````VY0$`)````$WE`0`H````<N4!`!4```";Y0$`7P```+'E`0`A
M````$>8!`!T````SY@$`+0```%'F`0`C````?^8!`!T```"CY@$`)````,'F
M`0`@````YN8!`"(````'YP$`'0```"KG`0`*````2.<!`!0```!3YP$`"0``
M`&CG`0`(````<N<!`!,```![YP$`#P```(_G`0`K````G^<!`!4```#+YP$`
M"````.'G`0!@````ZN<!`#\```!+Z`$`4````(OH`0!P````W.@!``H```!-
MZ0$`)0```%CI`0`O````?ND!``D```"NZ0$`!P```+CI`0`-````P.D!`#X`
M``#.Z0$`!P````WJ`0!)````%>H!`"T```!?Z@$`)P```(WJ`0`.````M>H!
M`#<```#$Z@$`'0```/SJ`0!!````&NL!`#8```!<ZP$`/P```)/K`0`U````
MT^L!`!0````)[`$`"@```![L`0`3````*>P!`!8````][`$`&````%3L`0`(
M````;>P!`#$```!V[`$`"@```*CL`0`*````L^P!`"8```"^[`$`"@```.7L
M`0`7````\.P!`!8````([0$`!P```!_M`0`1````)^T!`!$````Y[0$`"@``
M`$OM`0`6````5NT!``0```!M[0$`!0```'+M`0`&````>.T!``\```!_[0$`
M$@```(_M`0`0````HNT!`!T```"S[0$`#0```-'M`0`'````W^T!`!````#G
M[0$`(````/CM`0`2````&>X!``T````L[@$`&@```#KN`0`F````5>X!``X`
M``!\[@$`'P```(ON`0`O````J^X!``D```#;[@$`"P```.7N`0`8````\>X!
M`!`````*[P$`%@```!OO`0`9````,N\!``X```!,[P$`$````%OO`0`-````
M;.\!``D```!Z[P$`+0```(3O`0`&````LN\!``D```"Y[P$`#0```,/O`0`3
M````T>\!``8```#E[P$`'````.SO`0`8````"?`!``\````B\`$`"````#+P
M`0`>````._`!`!L```!:\`$`#````';P`0`"````@_`!``<```"&\`$`"```
M`([P`0!N````E_`!`!`````&\0$`!P```!?Q`0`G````'_$!`$8```!'\0$`
M'````([Q`0`G````J_$!`$0```#3\0$`,0```!CR`0!`````2O(!`!P```"+
M\@$`%@```*CR`0`2````O_(!``8```#2\@$`#0```-GR`0`*````Y_(!``D`
M``#R\@$`#0```/SR`0`1````"O,!``\````<\P$`"@```"SS`0`,````-_,!
M`!````!$\P$`!P```%7S`0`(````7?,!``<```!F\P$`%````&[S`0`4````
M@_,!``\```"8\P$`!0```*CS`0`E````KO,!`!4```#4\P$`"@```.KS`0`4
M````]?,!``L````*]`$`%````!;T`0`+````*_0!``8````W]`$`%@```#[T
M`0`6````5?0!``<```!L]`$`!P```'3T`0`9````?/0!``@```"6]`$`!0``
M`)_T`0`'````I?0!`!(```"M]`$`&P```,#T`0`+````W/0!``T```#H]`$`
M+0```/;T`0`A````)/4!`!@```!&]0$`!0```%_U`0`,````9?4!`!0```!R
M]0$`#0```(?U`0`"````E?4!`!,```"8]0$`$@```*SU`0`?````O_4!`$``
M``#?]0$`(P```"#V`0`T````1/8!`#$```!Y]@$`-````*OV`0`B````X/8!
M`&(````#]P$`%@```&;W`0!N````??<!`#L```#L]P$`5@```"CX`0!Q````
M?_@!`"T```#Q^`$`/````!_Y`0`K````7/D!`#````"(^0$`,````+GY`0`<
M````ZOD!`#H````'^@$`OP$``$+Z`0`K`````OP!`!\````N_`$`%@```$[\
M`0!6````9?P!`(P```"\_`$`,P```$G]`0!`````??T!`%H```"^_0$`4```
M`!G^`0`B````:OX!`!4```"-_@$`'0```*/^`0`=````P?X!`"H```#?_@$`
M'`````K_`0`E````)_\!`",```!-_P$`%@```''_`0`W````B/\!`"H```#`
M_P$`*````.O_`0`:````%``"`#`````O``(`8@```&```@`M````PP`"`#0`
M``#Q``(`10```"8!`@`R````;`$"`"L```"?`0(`1P```,L!`@!E````$P("
M`%H```!Y`@(`,0```-0"`@`N````!@,"`"P````U`P(`60```&(#`@"5````
MO`,"`&P```!2!`(`7````+\$`@!:````'`4"`#(```!W!0(`)0```*H%`@`E
M````T`4"`"L```#V!0(`;@```"(&`@!K````D08"`,````#]!@(`&0```+X'
M`@`G````V`<"`#X`````"`(`+0```#\(`@!1````;0@"`"<```"_"`(`7```
M`.<(`@`>````1`D"``H```!C"0(`W@```&X)`@`[````30H"`"D```")"@(`
M0@```+,*`@`]````]@H"`"4````T"P(`(````%H+`@`_````>PL"``@```"[
M"P(`"````,0+`@`)````S0L"`!,```#7"P(`$````.L+`@`2````_`L"``L`
M```/#`(`!@```!L,`@`.````(@P"``0````Q#`(`7````#8,`@`$````DPP"
M`!$```"8#`(`$@```*H,`@`(````O0P"``8```#&#`(`#@```,T,`@`$````
MW`P"`!8```#A#`(`"@```/@,`@`)`````PT"`!$````-#0(`$P```!\-`@`"
M````,PT"`!0````V#0(`%````$L-`@`2````8`T"``X```!S#0(`%0```((-
M`@`&````F`T"`!8```"?#0(`#0```+8-`@`#````Q`T"`#0```#(#0(`!```
M`/T-`@`3`````@X"``<````6#@(`)````!X.`@!0````0PX"`#D```"4#@(`
M.@```,X.`@`?````"0\"`"<````I#P(`(@```%$/`@`F````=`\"`"@```";
M#P(`(P```,0/`@`E````Z`\"`"P````.$`(`)P```#L0`@`[````8Q`"`"(`
M``"?$`(`.````,(0`@`T````^Q`"`"4````P$0(`*0```%81`@`L````@!$"
M`"<```"M$0(`+````-41`@`M`````A("`#4````P$@(`(0```&82`@`E````
MB!("`"H```"N$@(`,@```-D2`@`E````#!,"`"P````R$P(`&P```%\3`@`E
M````>Q,"`$(```"A$P(`)@```.03`@`J````"Q0"`"T````V%`(`+@```&04
M`@`F````DQ0"`"0```"Z%`(`+@```-\4`@`K````#A4"`#@````Z%0(`'0``
M`',5`@`*````D14"`!,```"<%0(`&0```+`5`@`L````RA4"`",```#W%0(`
M#0```!L6`@`/````*18"`!8````Y%@(`"P```%`6`@`9````7!8"`"H```!V
M%@(`"````*$6`@`,````JA8"`"$```"W%@(`,@```-D6`@`8````#!<"`"L`
M```E%P(`*P```%$7`@`D````?1<"``@```"B%P(`Y@```*L7`@`1````DA@"
M`!8```"D&`(`#````+L8`@`)````R!@"``T```#2&`(`%0```.`8`@`1````
M]A@"`"D````(&0(`(@```#(9`@`&````51D"`$4```!<&0(`'````*(9`@`=
M````OQD"`!T```#=&0(`"P```/L9`@`3````!QH"``D````;&@(`4@```"4:
M`@`J````>!H"`!T```"C&@(`%````,$:`@`7````UAH"`"@```#N&@(`&```
M`!<;`@`2````,!L"`"0```!#&P(`$P```&@;`@`4````?!L"``P```"1&P(`
M&````)X;`@`8````MQL"`!<```#0&P(`"````.@;`@`L````\1L"``D````>
M'`(`*0```"@<`@`H````4AP"``<```!['`(`&P```(,<`@`'````GQP"``@`
M``"G'`(`"0```+`<`@`\````NAP"``8```#W'`(`$P```/X<`@`4````$AT"
M``X````G'0(`"0```#8=`@`*````0!T"`"````!+'0(`$P```&P=`@`-````
M@!T"`!8```".'0(`$@```*4=`@`8````N!T"`!@```#1'0(`#````.H=`@`.
M````]QT"`!@````&'@(`!````!\>`@`O````)!X"``\```!4'@(`!0```&0>
M`@`'````:AX"``(```!R'@(`$0```'4>`@`C````AQX"``L```"K'@(``P``
M`+<>`@`&````NQX"``P```#"'@(`#````,\>`@`1````W!X"`!````#N'@(`
M%@```/\>`@`7````%A\"``4````N'P(`+P```#0?`@`?````9!\"`!X```"$
M'P(`"0```*,?`@`I````K1\"``<```#7'P(`%P```-\?`@`^````]Q\"`!$`
M```V(`(`$@```$@@`@`(````6R`"``0```!D(`(`!0```&D@`@`-````;R`"
M`!H```!](`(`!@```)@@`@`'````GR`"``D```"G(`(`$0```+$@`@`(````
MPR`"`!(```#,(`(`$@```-\@`@`P````\B`"`!0````C(0(`&0```#@A`@`D
M````4B$"`"(```!W(0(`)0```)HA`@`0````P"$"``(```#1(0(`!````-0A
M`@`+````V2$"``H```#E(0(`!0```/`A`@`#````]B$"``T```#Z(0(`1P``
M``@B`@`5````4"("`#(```!F(@(`.0```)DB`@!2````TR("``\````F(P(`
M=@```#8C`@`B````K2,"`$X```#0(P(`+P```!\D`@`V````3R0"`#T```"&
M)`(`*0```,0D`@`G````[B0"`#`````6)0(`-````$<E`@`M````?"4"`"D`
M``"J)0(`+````-0E`@`N`````28"`#$````P)@(`)@```&(F`@`4````B28"
M`!````">)@(`>P```*\F`@`*````*R<"`'@````V)P(`>@```*\G`@!Y````
M*B@"`#````"D*`(`80```-4H`@`4````-RD"`!(```!,*0(`#0```%\I`@"#
M````;2D"`"8```#Q*0(`.0```!@J`@`B````4BH"`"````!U*@(`:P```)8J
M`@`;`````BL"``H````>*P(`!0```"DK`@`&````+RL"``@````V*P(`!0``
M`#\K`@`7````12L"`!D```!=*P(`%P```'<K`@`B````CRL"`!````"R*P(`
M#@```,,K`@`(````TBL"``<```#;*P(`#@```.,K`@`'````\BL"``8```#Z
M*P(`%P````$L`@`'````&2P"``4````A+`(`$@```"<L`@`'````.BP"``L`
M``!"+`(`$P```$XL`@`-````8BP"`!<```!P+`(`#0```(@L`@`)````EBP"
M`!````"@+`(`"@```+$L`@`%````O"P"``L```#"+`(`!0```,XL`@`&````
MU"P"``H```#;+`(`"````.8L`@`,````[RP"`!,```#\+`(`!P```!`M`@`"
M````&"T"``(````;+0(`"````!XM`@`(````)RT"``<````P+0(`+````#@M
M`@`"````92T"``0```!H+0(`#@```&TM`@`.````?"T"`!````"++0(`%0``
M`)PM`@`0````LBT"``L```##+0(`!@```,\M`@`'````UBT"`!(```#>+0(`
M$@```/$M`@`"````!"X"``<````'+@(`$`````\N`@`J````("X"`#8```!+
M+@(`"0```((N`@`(````C"X"``L```"5+@(`'````*$N`@`%````OBX"``8`
M``#$+@(`"P```,LN`@`!````S@4``-<"``#A!0``IP(```<$``!J!@``````
M`%,&``#D!0``,@0``,8```!N`P``N08```````"[`0``>P4````````S`P``
M.@8``&T!``"\!0```````(8!```)`@``Y`,``!,&````````-@(``.P`````
M````8@4``($%```S!@```````%D"``#`!```=`,````!``#E!```"0````<`
M``"W!0```````-\&`````````````,P!```(````:`````T"````````_@0`
M`.D```#S!0``\04```````#1`0``$`8```````````````````````!L`0``
MV`````````"2!@``$P````````!&`@``GP$```````#@`@``TP```"H%``!N
M`````````-4%``!X`@``OP0``!\"``##!```@0(``/\!````````PP8``&L"
M``!=````D`4```````!1`P``)`$``*0```!+!0``F0$``&,!```G`P``````
M`"P#``!-`@``H@8``)D```#0!0``V`,````````G`0``S@```,$&````````
MQP8``'P```"-`````````*4$`````````````',!``!]!@``Z0$``$,#```9
M`@```````$L$``#F`@``,P$``,`&```L`````````-0&``"A!0```````!\!
M````````#````$<```#W`P``3@(``/L$````````(`$``)@&``!2`0``.@(`
M`#D#```H`P``W@$``)8#````````G`4``$L!`````````@$``(\!``#@`0``
MB@0``,L#````````O`$``!H$``!]!0``]0,``)X&````````70,```````#M
M!0``;P4``/(!```*!0```````!X"```)`0``_@,``,D!``#4!```1@$``.$"
M`````````````-X#``!X````6P0``,H```!)`0````````````#3!@``S@,`
M``````"I`P``*`4``+,`````````#04``(H%``!Y````;P$``!X!```9!0``
M`````+$!``!,!@``````````````````<`,`````````````;P(``(($```4
M!@``O04``)\%````````[@```&`'``#B!```B`0``%\#``#O!@```````(0%
M``!R!P``3P<``#H'``#'`P``RP(`````````````Q`,``/,!````````D`,`
M`-\`````````_@4```````""`0``%@4``*(%``#I!@`````````````@`@``
M`````+\#``#3`0``X`8``%H```#W`@```````.D"````````?@$``#P%``"T
M!0``FP(``#4'````````_`0``+$```"B````V@(``&\'```3!0``UP``````
M``#G!@``2@(``.L"``!V!```OP8``/\"``!2!```%@<``$$```!@````<P<`
M`'H$``"E````$0(``-(````N`P``KP8```$#```#!`````````````!+````
MW0,`````````````B@,``!T%``#R!```8P`````````5`P``$@4``"P%``"U
M`P``U@```+$#```_!P``A`8```````#%`@```````/,"````````Z0,``#D"
M``"K!````````&`#```Q!0``$08``/$#``"%````SP0``(("``#+````A0$`
M`%4%``!<`0``YP0```\'```+`0```````'`!``"U!0``'@0``.$#````````
M8@$``(L&`````````````!P"``#M!@```````'$``````````````,T$``"^
M!0```````-T!``!(!P``RP0``#`%``!E`0``A````!,"``"<`0```````!,$
M````````P0,``/X&```1!P```````%`%```Q`0``K`$``,($``"-!0``I0(`
M`"4```#0!`````````````#L`0```````%@%``#_!```D`8``.<!``!R!```
MZP8``$L"````````#00``(`%``!T`@``CP,``(D!``#Y````204``%8"``"9
M`@````````````"2`````````"@'``!6!```I`(`````````````7P(``'T`
M```$!0`````````````+`````````*`#```)!@``*P<```````!X!```&P8`
M`*P&```"````OP(```````!F````FP4``/0%``#B!@````````````"Y!```
M`````*8"``#U!0``AP0``````````````````"D'````````+08``)4!``"X
M!```\0$``+L%```:!@```````&D!``#:!0```````-P````O!```]08`````
M```U````M0```/T#``"F`0```````&H'``#5!@```````$4!```C````.`(`
M``````#S````/P$```````"-!@``A@(``(,$``!.!@``00$``)$#``"8`@``
M``````````"O!0``````````````````W`,``)$&``#N`@```0$``.\!```H
M!````````'\!```?!```30,``'<!```T`P``)04``(H````-!@``1P<``/L#
M``"E!@````````````!_````Y`0````````R````W@8```````!.`0``2@8`
M````````````)P0``.H```#J!0``GP0``*P`````````#@4`````````````
MP04```````"(!0``U@,``,X$``"=`P```````$4%``"I`````````/0```"D
M`0``&0,````````R`@``X`,`````````````.@0``#4"``"L!0```````#T!
M``!4!```^0(``&\````/`P``@P4``&<$````````;04``*@%```.!P``````
M``````##`P```````$\%``#V````/`,``(<```#[````70$``#L"``"%`@``
MN0(``+`!``#1!@``.P0``,H"````````Q`$``%D#```!!0``\`$``,`!````
M`````````/0&````````+`(``$\"``!9`0``U`$``(X#``!G`P``.`$`````
M``!E!0``J0(``'T!```M`P````````````!"!```N0```/`&``!2````7P$`
M`'8%``!$`@``$@$````````D!0``Q0```+,$``"+`@```````+T&``!L````
M"04````````S!P```````%X"``!C!@``NP8``&D#``!8!@``908```````#0
M`@``"`(``.8!````````?@```#4!``#9`P``*@0````````I!```(`0`````
M``!&`````````#H%```[`P``Y0$```````"F!@``2@,``&T`````````````
M`*X`````````6P<``%@'```M!```(`,``*,&````````F````%X!```%`@``
MMP```+D#```^!0``]`(``/,$``"U!@``D@4```````"\`P```````/````#=
M!```K08``#D$``!5`0``,@4``(X"``#^``````````L&``#]!0```````)(!
M``"D`P``900``"0```".````<`(``$T```"+!0``30<``-8%``!8`P``````
M`.$!``"P!0``'P8``#`"``"8!````````%`!````````40$```T!````````
M`````*X#``````````````````#L`P``&`8``!<"``"G!@``4`,``)$%````
M````1@4`````````````S0$```H!`````````````)`"``"T`@``U0,``-("
M````````;P8``.T`````````````````````````KP```"P&``!.!```````
M`(4%````````_P```#P&```K!```+@$```````#5````DP0``*0%``"J!@``
MY04``'H"```B`@``-````,T&``!%!@``!P$```````!^!@``200``.\`````
M````.`8``'(%``!Z`P``:0<````````%`P``F@4``-@%```<!0``G@$``"$#
M````````=`0```````#E````9`(``#$"``````````````````",`@``%@``
M`&0#```C!0``BP````````",!```FP```+0```#G````D@(``'D&``!4`P``
MS04``&P&``#V!0``#P(```````````````````````!>````T@$``"4#``!3
M````EP(``)<```!<`````````'P&````````90(``),&``".`0``=P4``-$%
M````````P@(``$`'```Q``````````````"F!0``%0```$,"``!Z````````
M`%4'``"%!```@0```(`!````````50````````">`P``)@0````````I`0``
M````````````````UP$``&`"```\`@``$`,``(X&``"\````30$``&D"``!?
M!0``9`4``&<&```M!0``E@$```````"L`P``%P,``*T$````````!@$``",&
M``#+!0``&P(``"``````````0P4```````!;`P``````````````````L`8`
M`%<#``#L`@``"`<``(P````0!0``A08```````!$!```P`,```````"V`@``
M`````,P$``"C!```3@``````````````(P(``/P&``!;````"@8``$(%````
M````XP0```````#$!@``J@$```````"9`P``/`<``````````````````%4#
M``#C``````````P'``"Q!```2`0``.X#```/`0``E08``*,#````````_`$`
M`$('``"$!```BP$````````&!@``%08``#8%````````B`8``,X&``":````
M0P<``!<&````````(P<``$D`````````]P4``+$&``!F`P```````,\%``"V
M!@``#@0``!L````R!P``'@4```````#N!```!P<```````"&`P```````+0$
M`````````````/@"``"_!0````````````!3!P``%0(``)<%``!,`@``P@8`
M`"D&``#1!```608`````````````A@0``)4#``#W`````````'@!``"F!```
MQ00````````4`@``B@(``#8#```,!@``ZP```$$&````````Y`(```````#>
M````@0,``',#``!``P``VP8``#L&```M````:P0```````#0!@``>P0``#<$
M````!```.@,``+T$```Z`0```````'X$``!8`0``5P<``-``````````C@4`
M`)H!``#Z!@``90<````````E!@``````````````````QP0``(<#``!1!0``
M``````````!B`@``)P(``/H$``"1!````````"(```"A````V@0``&L````U
M`P``MP,``"@````B`P``8`8``(@#``!)!@``!`$``%$```"A!````````$$#
M``#(````.`,``"$$``"(`@``Z04``*0$``````````````````!W`@``704`
M``0$````````!@<``"H#``"^`@``;00``&0```````````````````#X!```
M/P0```````#N!@``)00```````!J`@```````)D%```8`0```````-D%````
M````H`$``!`'``"0````^P$``.T!```7!P``Q@(``(T$``#"!0``-@<``"H"
M``!`!0```P<``/`"``"3!0``_00```````"B`@``'0,``-\!```^!```+0<`
M`'$$``!`!````````!8"``"<`@``#0<``/4"``!<!@``A`(`````````````
M`P```-0#``!S```````````````#`P``8@8``,\!``!`!@```````#X!````
M````9`0``.4"``#E`P```````"('```<`P``1P,``&8&````````=P,`````
M``#;!0``7P0``-(#``````````````````!;`@``-@$``.,"```^!@``L@``
M`-8"``#5`0```````#@```!4!0```````)L#``"7!```S`````````!:!P``
M$0$````&```0`@```````$L#``#=````)P````````"W`@````````T#``"R
M`@``B````*8```!\`0``[P,```````!V````?P0``,<!``!E`P``(08``"8"
M``"P`@``UP0```````")!@```````',$``"=!````````+$"``#)!@``$`$`
M``````#%!0``Q@8``#4&``!``@``;@(```````"C!0``,P4``#D'``#!````
M?@4``"H!``!!!0``&@,```````!^`P````````L"``"]`@``````````````
M````````````````````9P(``*L#``!@`0``J00``#@%```_`````````*`$
M```X!P``!P(``(`#```````````````````K`0```````,\&````````1`<`
M`,T"```Z``````````````#2!@``0@```$X#`````````````'8&``"V!0``
M9@(``-P&``"*`0```````-D$``"0!```=@$``$\&``"S`0````````````#3
M`@```````(`"``")`````````'4"``"]````,P```)4$``!C!```Y@,`````
M```]````^`$```````"(`0``10,``/L"``!$````FP$`````````````N```
M`-(%```T!0``&0<``(8&```4`P``R`,``+@#````````4`<``)P```!>`P``
M-@0``+\!````````V`(`````````````UP,``)H"````````U@$`````````
M````3`<```@$```K`@``C`4``)P#``!M!@``WP0`````````````]`$`````
M````````Q08``-<&``"7!@``+@```%8!``#O!0``C`,``,P"````````M`8`
M`#`&``#J!@``&`<```````"]`0``JP4```````#*!@``_0```$<%``"!!```
M*P,```````!K`P``>0$``"4'``````````````$$```;`P```````#X```!_
M`P``\`0``.0!```#!0``L@$``(`$``#W`0``ZP$``/8!````````&0$``+,#
M``!;!0``_P4``,X!````````%`$``(T#``#N`0``H@,``!0```"I!0``'@``
M`"(&```2!```'P```!`$````````9P<``(,!````````X0```.(```!A!```
M804``(,#``#<`@````````````"@`@``*P4``"`%``#Z!0``5P$``)T"``"V
M````'0$```$&````````'`8``-P!``"$`0``)`0``*($``"H`P``!P4``.H$
M``#C`P``P@,``+,&``#U`0```````'(&``#9``````````````!8!```````
M`'`'``!>!```S`8``'<&```I`@```````,T`````````80(``,D$``!;`0``
M:`(``#<"``#G`@``+P```)D&``"[!```RP8``$`!```T`0``R`(````````8
M!0```````),!``!'!@```@,``#\#````````:00``-L$``#;`@``````````
M``"N!```G0$``!$`````````P00``%0'`````````````)T%```!`@``40<`
M`.T$```*!P```````/@#``"^`P``IP,````'``!6`P``+@(``#@$````````
M`````(<!``!(!@``KP(``#`'``")!0`````````````8!````````&(````^
M`@``'`0``&P$``#X!@```````'4#``#0`P``308``-T"````````B0,`````
M``!G!0``4`8``(L$``#@!0``<04``/H#``#1`P``U0(``!4'````````F`4`
M`#8```"@!0```````/(``````````````"P'``!J`P``?`(``&`%````````
M"`8``$H$````````&`(`````````````-`<```,!``!W!```\0```',"``#1
M`@```````,0```"Q!0``?@(``+4$``"K`@``,00``#L%``#K!```\`,````%
M``"@`````````*P$```*!```?`4```D$````````:P<``#(&``!:`P``R0(`
M``````#>!````````'D$```D!@```````/<$``!:`@``E`(``$8&``"*!@``
M&00```````!%````*`8``$(&``!=!@``6`````````"M`0``2`$`````````
M````````````````````\@(``"8!``!Q`@``"0,`````````````^`4`````
M``"Z`````````&@$`````````````)@#`````````````+0!``!C!0``0P``
M`&(#```$`@``/`$``&$'```````````````````4!0``&@````H#````````
MB00``"X%````````LP4``"$```"J`@``^```````````````>P,```0````O
M`@``&0```!<%````````2@4``"$!``!7`@``7`0``'("``!2!0``````````
M``!D!P``&@$``.@`````````,P0``'L&``"A`0``600``/,&``"3````XP4`
M``4'````````_`,``.@!``#H`@``-P```*P"```W!0```````.H#````````
M'00``%P'````````7`,``!X'``!P!@```````(\%``#*!```80```&$#``#;
M`P``@P(``,(```"[`@```````!(#``"@!@``A@```$\$```O!0``C`8``!@`
M```=`@``P````.L#```;!0``%@$``$@"``#4````TP4```````!\!```````
M``````#Y!`````````````#R!0````````````!8`@``.04```````#'`@``
M`````'P#````````#`0```P%```G!@``$@<``"8#````````IP0``/P%``">
M````70<``*H$`````````````%$"``"E!0``'P,`````````````508`````
M``!>!0````````````#L!```P`4``#8&``#\````$P<```````````````(`
M`#4$```O!@``00<``*\$``"/`````````(`&``"Z`P```````"<%``#,`P``
M`````%P%``!Y`@``#P8`````````````N@(``)D$``"P````DP,``*4#``!9
M!P``M`,```(%``#9`0``8P(``)0#``#Q!```IP```'H&```]!@``3`4``$D#
M``#8`0``(@0`````````````G0```*0&``!L!P``\@,``$\#````````````
M``@#```N!```K@$```````"^!@``=`8``"P$```,`P``Q@4``*,```"#!@``
MQ0$``(<%``""`P``*`$``/P"``!#!@``-P<`````````````JP```#(#``!>
M!@``5`$``%0```";!@``TP0``,@!```_`@``O@```!T'```>`P```````)H$
M``"R!@``X@,`````````````0P$```````!W`````````"X'````````@@``
M`'\"````````(P,``&0!``!O`P``300````````M`@```````-$```#:````
M``````````!H!@``WP4``"8&``!H`P``?P8``&8!```<`````````)T&````
M`````````.$&``#+`0``:0```#X#````````T`$``.8$``!Y`P```````.8`
M``"W`0```````#D```![````_@$``/<&``"H!```/0,``.`$````````G`0`
M`!(```"V`0``6@$``&X$````````2`,``.`````5!0``^0,``/$"``"O`0``
M`@0``+P$```)!P```````&H````8`P```````%('``!I!@``D@0``',%````
M`````````&('```0````Q`4``#$'`````````````-H!``"W!@``!`,```\%
M``!Z!0``N`$````````%`0``````````````````N`(``#D&``"[`P``2@<`
M``@%``!%!P``#@(``"8```!G`0``A`,```````!3`@```````&X!```W`0``
MF@,```````!A!@``J`$``````````````````%\'````````4`(```````"A
M`P```````/\#``"\`@``]`,``"8%```C!```4P4``'T"`````````````#``
M```B`0``^P8``+($``!J!0``[P(```````#6!@``X@(``+X!``!1!@``:P$`
M`/H```!(!0``5`(``'````!U!@``/0(``&T'``"3`@``$@(```,&````````
M`````)\````.!@``]0```#D!``#7!0```````"H````$!@``'@8```````#M
M`@``<@$``,H!``!Y!0``Z`4``+(#``!6!P````````````!F!P``]00``*L!
M``"/!```K0,``'0`````````4@(``-0"``"G`0``^0$```````#B!0``2@``
M`#T%``!5!```HP$``.@&``!>!P```````,T#``!9````NP```)L$``!5`@``
M`````%<`````````@08``#<&``"?!@``````````````````+P,```````#"
M`0``C0(``````````````````$L&``"Z!@``GP(``#\%`````````````&H$
M``!:!0```````.P%``"P`P`````````````S`@``W`0``#T$``!)`@``````
M`+@&````````]@8``,0$``#C`0``3`,``+D%````````<@```%(#```A!0``
M`````)0$``#;`0``````````````````N@4``&8%``!3`0``K@4``%`$``!=
M!```W04``&<````T!```!08`````````````G@0``$,$``!K!0```````'\%
M```+`P``W@4```````"%`P``N`4``/8#``""!@``*04```````#B`0``````
M``````````````````````#&!```QP4``)0```!H!0```````(T!```J!@``
M%`0``)8%``!B!```Q0,``"@"``!6!0```````/0$``"5`@``&@4``*\#``#K
M!0```````)<!``"1````D@,``/`%````````"`$``&$!```L`0``````````
M``#]!@``4````,H%``!!`@`````````````&`@````````````!)!P``````
M`!<```!7!```BP,```8#````````400``#P$``!+!P``CP8``$8'````````
M'`<```4```"M`@``6@8``%D%``!C`P``!P,`````````````)`(``&H!``"W
M!```.P<``'$#``"M!0```````&@'``"B`0```````'8#````````@```````
M``!$`0``=0```,8!````````E`4``%8&````````%P0``$4"``!:!```V@,`
M`-4$````````R`8``!H'```B!0```@(``)0!```E`0``Y@8``$$$``"R!0``
M``````````!3!```E04``-D"`````````````,D%``#^`@``]@(``-P%``"C
M`@````,``$P!``"S`@``K@(``/8$```A!P``E0```'4!``!O!```Q@,`````
M``"0`0``;@8``.T#````````$P$``'L!```=!@``_0(``,\"``"<!@``C`$`
M``````!C!P``8`0``,0"``#:!@``#P```#(!``!Z`0``*@<```````"I!@``
M<`4``%8```#]`0```````/$&``"^!```SP```#0"``"1`0``"@(`````````
M````4@8```,"````````=00```````#L!@``O`8```````"M````1P$`````
M``#J`0``S@(```````!$!0```````!$#```K`````````-L````9!@``(P$`
M`!\'``!$!@``[@4```````"6!```%@0``'(#```O`0``!@4````````E`@``
MC@0````````%!```K@8``*<%``#6!```0`````````#H!```^P4``,$!```N
M!@``CP(````````Q`P``%00```````!P!```R`0```````#2!```Y08`````
M```+!```WP,``$8$``!7!0``%@,````````.`P``````````````````;`,`
M`#`$```:`@```0<```````##`@```````$8#``!H`0``SP,``*8#``"Y`0``
M`````'0!``#Y!0``^@$``,$"``!Q`0``;@4```````!.!0``*0`````````]
M!P```````$<"```1!0``PP$``/H"````````@0$``',&````````%P$``(<&
M```;`0``P`(``#0&```\````4P,``*H#````````Z00```````"P!```)P<`
M``````"#````[P0``.0```!'!```;`4```````!"`@``"P4```H`````````
M\P,```````":!@``%`<``,D`````````.P```$(#````````(0(``!4!``!/
M`0``5P8``'@%``"U`0``^08``#\&``!]!```G@4`````````````W@(`````
M`````````````/(&``#F!0``#P0```4%``#G!0``"P<``$(!``!U!0``E@(`
M`!(&``!V`@```````/\&```Q!@``JP8```````!Q!P``E@``````````````
M*P8```<&```@!P```````-0%```D!P```````(<"```I`P``3`````````!X
M`P``M@0``$\```!;!@``'P4```````!%!````````!P!``!$`P``J`8``,D#
M``!Q!@```````````````````````-@&```;!```7P8``+8#```[`0``B0(`
M`"T!``"J````7`(```T```#C!@``9`8``&4````P`P``N@0```````#H`P``
M!`<``.$$``#(!0``I0$``*@"``!(````+P<``-@$``!M`@```````+T#``!F
M!````````&X'``!I!0``J@4``-D&``!K!@```````*D!``#*`P``!@```*$"
M``"Z`0``YP,``)$"``"A!@``OP```%T"``#3`P``'0````(&``!,!```PP``
M``8$``"8`0``>`8``'T#``#?`@``#`(```X!````````Z@(````````1!```
M`````((%``"&!0```````$H!```@!@```````!,#``"4!@```@<``)X"```.
M````)@<``%0&````````%@8``$T%````````>P(``&P"```^!P``W08``)8&
M``##!0``=`4``#4%``#'````Y`8``````````````````$X'``"?`P``)`,`
M```````P`0``;0,```P!```W`P``7P```+4"````````EP,`````````````
MS`4``*@`````````&P<````@("U-+"`M+6UE<W-A9V4]34534T%'12`@57-E
M('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O
M;F5S+@`@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE
M('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&\*("`@("`@("`@("`@("`@
M("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I9F9E<F5N
M="!B<F%N8V@@=&\*("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R
M871E9"!C;VUP96YD:75M+@`@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@<&%T
M:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L9"!B
M90H@("`@("`@("`@("`@("`@("`@('5S960N`"`@+6,L("TM8V]M<&5N9&EU
M;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N
M9&EU;2!F:6QE"B`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F
M('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4*("`@("`@
M("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2X`("`M8RP@
M+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I
M;G-T96%D(&]F('1H92!D969A=6QT"B`@("`@("`@("`@("`@("`@("`@("`@
M("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R
M>2DN`"`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E<R!F
M<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RX`("`M9"P@+2UD:7)E8W1O<GD]
M1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN`"`@
M+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92X`("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C86QE+@`@
M("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+@`@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@0VQE
M86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@
M("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS;&%T:6]N<R!O
M;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-
M3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@
M9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5
M<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L
M93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG="!M
M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP96YD:75M+@`@("UN
M+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2X`
M("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L871I;VX@<W1A
M=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N`"`@+70L("TM=&5S="`@("`@("`@
M4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U;B!A;GET
M:&EN9RX`("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P(&9R
M;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+@`@(&-O;6UI
M="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N
M`"`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE($-64R!S
M97)V97(N`"`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F
M:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE"B`@("`@("`@("`@
M("`@8W5R<F5N="!C;VUP96YD:75M+@`@(&5X=')A8W0@("`@($=E;F5R871E
M(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RX`("!H96QP("`@("`@("!3:&]W
M('1H:7,@:&5L<"!M97-S86=E+@`@(&EN:70@("`@("`@($-R96%T92!O;F4@
M;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG.B!4
M:&ES"B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@
M9FEL97,@;V8@=&AI<R!L;V-A;&4N`"`@;6%K92`@("`@("`@0G5I;&0@8FEN
M87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE<RX`("!M
M86ME+6AE;'`@("!-87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F
M:6QE(&)E:6YG('5P+71O+61A=&4@86YD"B`@("`@("`@("`@("`@<')E<&%R
M92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T92UH
M96QP+B!9;W4*("`@("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH
M96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&4*("`@("`@
M("`@("`@("!H96QP(&9I;&4N`"`@;65R9V4@("`@("`@365R9V4@=&AE(&-U
M<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I
M;&4N`"`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E<75E
M;G0N`"`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D
M(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<`H@("`@("`@("`@
M("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@;VYE
M<RX`("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I
M`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M
M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!2
M96=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A
M=&5D.B`E<RX`)60@)7,@86YD("5S`"5D(&)Y=&5S('=R:71T96XN`"5D(&]F
M("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($9I;F=E<G!R
M:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE
M;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(&YO="!W
M<FET86)L92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F
M:7)S="X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#
M86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G
M=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O
M("5S`"TM('-E;&5C="`M+0`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T`
M,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I
M;W5S`#QG971T97AT/B!T86<@;F]T(&-L;W-E9"!I;B!F:6QE("5S+@I/<&5N
M:6YG('1A9R!F;W5N9"!I;B!L:6YE("5D+@!!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN
M`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)
M($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W
M;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@
M1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@
M1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O
M("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!N97<@
M9FEL97,@=&\@<F5P;W-I=&]R>3H`061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G
M:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N
M=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL
M(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!
M;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@
M24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA
M=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T
M92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT
M87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI
M8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V
M90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V
M*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A
M;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%2
M35-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T
M`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@
M8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB
M=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"
M86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V5L
M:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T
M86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV
M:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S
M`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`
M0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U:6QD:6YG($U/(&9I;&5S(&9O
M<B!M;V1U;&4@)7,N+BX`0G5I;&1I;F<@;&]C86QE("5S+BXN(`!"=6QG87)I
M80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#
M87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA
M;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D
M9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE
M`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF
M:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@
M8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@
M870@=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@
M<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"X`0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L
M92`E<RXN+@!#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@`$-L96%R`$-L96%R
M($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`
M0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L
M;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO
M<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@
M=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;6%N9"!O
M<'1I;VYS.@!#;VUM86YD<SH`0V]M;65N=`!#;VUM:71T:6YG.@!#;VUM;VX@
M3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&]S92!-97-S86=E("@E<RD`0V]M
M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF
M9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG
M=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N
M;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#
M;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]P>6EN
M9R`E<R!T;R`E<P!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y("5S('1O("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.@!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD
M:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`
M0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B
M+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S
M=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T
M:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E
M(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N
M;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@
M;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O
M=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C
M86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O
M=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI
M;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O
M<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A
M`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES
M`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@
M<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S
M97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L
M971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@
M26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y
M`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N<P!$969I
M;FET:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N
M`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E
M(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!P97)M
M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN
M=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C
M=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I
M<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N
M<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@
M*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@
M=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI
M;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@)7,`
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$524@!%8W5A9&]R`$5D
M:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET
M(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T
M:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M
M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L
M96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@
M8VAA;F=E9"P@)60@=6YK;F]W;@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A
M`$5R<F]R`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN
M9R`B)7,B+@!%<G)O<CH@`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P
M90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M96-U=&EN9SH`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%
M>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER
M871I;VX@1&%T90!%>'!O;F5N=`!%>'1R86-T:6YG(&9R;VT@)7,N+BX@`$9'
M($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@
M8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO
M=F4@=&\@(B5S(BX`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`
M1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS
M($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E
M<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@
M<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R
M`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O
M<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`
M1F]R=6US`$9O<G=A<F1S`$9O=6YD(&%P<&QI8V%T:6]N<SH@)7,`1F]U;F0@
M9&ER96-T;W)I97,Z`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O
M;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R
M:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1G5Z>GD`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E
M("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5N97)A=&EN9R!S
M=&%T=7,@9F]R(&UO9'5L92`E<RXN+@!'96]R9VEA`$=E<FUA;GD`1V5T;W!T
M($5R<F]R.B``1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L
M`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X
M-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R;6ES<VEO
M;G,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`
M1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E<W1B;V]K
M`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`
M2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V
M>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(
M96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5L<&5R(&%P<&QI8V%T:6]N('1O
M(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@2&]R
M9&4*9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS+@I&;W(@86X@:6YT
M<F]D=6-T:6]N(')E860@=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@9&ER96-T
M;W)Y+@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93H`2&EG:`!(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`
M2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E('1R86YS;&%T:6]N(&=E;F5R871O<@!(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@
M:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@(B5S(@!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y;F-H<F]N
M:7-E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W
M;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I
M;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y
M`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`
M25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N
M('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@
M3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E
M(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A
M9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO
M;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);FET:6%L:7II
M;F<@;6]D=6QE("5S+BXN(`!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A
M=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN
M`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED
M('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H
M87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N
M:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS
M`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*
M87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L
M>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU
M<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG
M:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I
M8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E
M<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I
M8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+
M;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G
M>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T
M960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S
M="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V
M86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`
M3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@
M4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W
M(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H
M92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P
M;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,
M:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES
M="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C
M<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI
M=&AU86YI80!,;V%D:6YG(&QI8G)A<FEE<RXN+@!,;V%D:6YG+BXN`$QO8V%L
M('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O
M=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G
M:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T
M=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`
M3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9
M=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I
M;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA:V4@<W5R92!T:&%T('EO=2!H879E
M(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"X`36%K
M:6YG(&1I<F5C=&]R>2`E<P!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L
M:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P
M`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`
M36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-
M875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!L96YG=&@`36%Y
M`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<F=I;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M
M+BXN(`!-97)G:6YG(&QO8V%L92`E<RXN+B``365R9VEN9R!T:&4@4$\@9FEL
M92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@`$UE<F=I;F<@=')A;G-L
M871I;VX@9F]R(&UO9'5L92`E<RXN+@!-97-S86=E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A
M9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I
M;F5D`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U
M<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE
M<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN
M`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`
M36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L90!-;V1U;'5S`$UO;&1O
M=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A
M<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T
M;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N
M`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@
M=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L
M=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A
M;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI
M8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL
M;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`
M3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI
M`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O
M=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC
M87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P
M97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`
M3F\@8V]M;6%N9"!S<&5C:69I960N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M`$YO(&5N=')Y('=I=&@@=&AE(&ED("(E<R(@97AI<W1S(&EN('1H92!O<FEG
M:6YA;"!H96QP(&9I;&4N`$YO(&9I;&4@=7!L;V%D960`3F\@;&]C86QE('-P
M96-I9FEE9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V
M:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N
M`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R
M=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`
M3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F
M;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA
M;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@
M9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R
M=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E
M`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@
M;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE
M8W0`3V)J96-T($-R96%T;W(`3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`
M3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY
M($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F
M9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A
M('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y
M<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]P=&EO;G,Z`$]R9&5R960@
M3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ
M:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@
M4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`
M4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@
M0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N
M;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;@!097)M:7-S:6]N<R!F;W(`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`
M4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO
M=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@
M=7-E('1H92!S>7-T96TN`%!L96%S92!R97!O<G0@86YY(&)U9W,@=&\@:3$X
M;D!L:7-T<RYH;W)D92YO<F<N`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L
M90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E
M<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@
M870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT
M(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP
M=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+
M97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC
M;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S
M96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E
M<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2
M871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E
M>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2
M96UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA
M='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO
M=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T
M=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T
M(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S
M970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E<W5L
M=',@*&EN8VQU9&EN9R!(;W)D92DZ`%)E<W5L=',Z`%)E='5R;B!T;R!/<'1I
M;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T
M92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S
M`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@
M4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!3
M86EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!3
M86UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI
M=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E("<E
M<R<`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!3
M8VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396%R8VAI;F<@2&]R9&4@
M87!P;&EC871I;VYS(&EN("5S`%-E87)C:&EN9R!G971T97AT(&)I;F%R:65S
M+BXN`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P
M('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E
M;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C
M:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R
M;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E
M<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@240@97AP
M:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E
M;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U
M<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A
M=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE
M<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T
M<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T
M:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM
M87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY
M`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VX@=7`@:68@
M;F]T(')E9VES=&5R960`4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3:VEP<&5D+BXN`%-L
M;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S
M`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E
M<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA
M;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO
M;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I
M;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C
M96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3
M=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC
M90!3=&%T=7,`4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@`%-T;W)A9V4@9F]R
M;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`
M4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`
M4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!2
M97!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M
M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`
M5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`
M5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@
M:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO
M="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE("5S(&AE
M;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@97AI<W0N($-R96%T:6YG(&$@
M;F5W(&]N92X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L
M:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U
M8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI
M=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T
M('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D
M('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F
M96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE
M(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BX`5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\
M/WAM;`!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H
M92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y
M(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!D;V5S;B=T
M('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@)7,N`%1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T
M:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B
M(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I
M;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS
M;&%T:6]N+G!H<"!W:71H('1H92!F;&%G("UD('1O('-E92!A;GD@97)R;W(@
M;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W
M87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@
M96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I
M96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@
M9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@
M86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A
M($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@
M>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G
M92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T
M:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92X`5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L
M:6YE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII
M<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4
M:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E
M;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O
M`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N
M`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R
M;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871E9`!4<F%N
M<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U
M`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI
M<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U
M<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE
M`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S
M+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T
M;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N
M86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO
M=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B
M($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@8V]M;6%N9#H@
M)7,`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN
M86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R
M=&5D($5X=&5N<VEO;@!5;G1R86YS;&%T960`57!D871E`%5P9&%T92`E<P!5
M<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9&%T:6YG("5S(&AE;'`@9FEL
M92!F;W(@)7,N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R
M=6=U87D`57-A9V4Z`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S
M97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T
M<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E
M9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5
M<V5R('!E<FUI<W-I;VYS`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D
M>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S`%5S97)S(&EN
M('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A
M;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L
M80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`
M5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R
M>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6
M:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET
M>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%L
M;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!787)N:6YG.B``5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`
M5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI
M8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H
M(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@
M;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7
M:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T
M<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T<P!7;W)K`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@
M)7,N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT
M96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N
M<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S
M+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M
M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT
M(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`
M66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O
M(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN"DYO="!A
M;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"X`66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`
M66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`
M6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E
M<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M
M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#
M3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E
M(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN
M+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T
M=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A
M;B!E<G)O<B!H87,@;V-C=7)E9#H`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E
M`&1O;F4`9F%I;&5D`&9A;&QI;F<`9FEL90!F;W5N9#H@`&9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!I;6UE9&EA=&4`:6YL:6YE
M`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RX`;6T`;F%M90!N;W0@8VAA;F=E9`!N;W0@9F]U;F0`;F]T(&EM<&QE;65N
M=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L
M<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``
M<W,`<W1E861Y`'1A<VL@;&ES=`!T:&4@2&]R9&4@4$\@9FEL92!F;W(@=&AE
M(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#H`='EP92!T:&4@<&%S<W=O<F0@
M='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7!D871E9`!U<V5R
M('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3$M,C0@
M,#$Z,3@K,#`P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`Q+3(Q(#$X.C(R
M+3`P,#`*3&%S="U4<F%N<VQA=&]R.B!.=6YO($QO=7)E:7)O(#QN=6YO0&5T
M:"YP=#X*3&%N9W5A9V4M5&5A;3H@4&]R='5G86P@4&]R='5G=65S92`\9&5V
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("`M32P@+2UM97-S86=E/4U%3E-!
M1T5-(%5S87(@97-T82!M96YS86=E;2!D92!C;VUE=&EM96YT;R!E;2!V97H@
M9&$*("`@("`@("`@("`@("`@("`@("`@("`@(&UE;G-A9V5M('!O<B!O;6ES
M<^-O+@`@("UA+"`M+6%D9#U!4E%5259/("`@("!!9&EC:6]N87(@97-T92!A
M<G%U:79O(%!/(&%O(&-O;7#J;F1I;RX@571I;"!P87)A"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU:7(@=6T@8V]M<.IN9&EO(&1E('5M(')A;6\@
M9&EF97)E;G1E(&YO"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;7#J;F1I
M;R!G97)A9&\N`"`@+6(L("TM8F%S93TO0T%-22`@0V%M:6YH;R!P87)A(&\@
M9&ER96-T\W)I;R!B87-E("A(;W)D92D@82!U<V%R+@`@("UC+"`M+6-O;7!E
M;F1I=6T]05)152`@26YT96=R87(@;F]V87,@=')A9'7G]65S(&$@97-T92!A
M<G%U:79O(&1E(&-O;7#J;F1I;PH@("`@("`@("`@("`@("`@("`@("`@("`@
M92!NXV\@86\@8V]M<.IN9&EO('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O
M(&YA"B`@("`@("`@("`@("`@("`@("`@("`@("!P87-T82!H;W)D92]P;RX`
M("`M8RP@+2UC;VUP96YD:75M/4%2454@(%5S87(@97-T92!A<G%U:79O(&1E
M(&-O;7#J;F1I;R!E;2!V97H@9&\@87)Q=6EV;PH@("`@("`@("`@("`@("`@
M("`@("`@("`@<&]R(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F$@<&%S=&$@
M:&]R9&4O<&\N`"`@+60L("TM9&5B=6<@("`@("`@36]S=')A<B!M96YS86=E
M;G,@9&4@97)R;R!D;W,@8FENX7)I;W,@97AE8W5T861O<RX`("`M9"P@+2UD
M:7)E8W1O<GD]4$%35$$@0W)I87(@=6T@8V]M<.IN9&EO(&YE<W1A('!A<W1A
M+@`@("UH+"`M+6AE;'`@("`@("`@($UO<W1R87(@97-T82!M96YS86=E;2!D
M92!A:G5D82X`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@87!E;F%S
M(&5S=&$@;&]C86QI>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5
M<V%R(&5S=&$@;&]C86QI>F'GXV\N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@
M(%5S87(@97-T82!L;V-A;&EZ8>?C;RX`("`M;2P@+2UM;V1U;&4]3=-$54Q/
M("`@($-O;G-T<G5I<B!A<G%U:79O<R!-3R!A<&5N87,@<&%R82!E<W1E(&WS
M9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@
M+2UM;V1U;&4]3=-$54Q/("`@($QI;7!A<B!A<G%U:79O<R!03R!A<&5N87,@
M<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO
M<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-O;65T97(@87,@=')A
M9'7G]65S(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@
M("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@
M0W)I87(@;R!A<G%U:79O(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO"B`@
M("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M+6UO9'5L
M93U-TT153$\@("`@26YT96=R87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@
M97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN
M`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!!8W1U86QI>F%R(&%R<75I=F]S
M(&1E(&%J=61A(&%P96YA<R!P87)A(&5S=&4*("`@("`@("`@("`@("`@("`@
M("`@("`@(&WS9'5L;R`H2&]R9&4I+@`@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@06-T=6%L:7IA<B!A<&5N87,@97-T92!M\V1U;&\@*$AO<F1E*2X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($=E<F%R(&%R8VAI=F\@4$]4(&%P96YA
M<R!P87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H
M2&]R9&4I+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@3N-O(&EN=&5G<F%R
M(&YO=F%S('1R861UY_5E<R!N;R!C;VUPZFYD:6\N`"`@+6XL("TM;F\M8V]M
M<&5N9&EU;2`@("!.XV\@=7-A<B!U;2!C;VUPZFYD:6\N`"`@+7,L("TM<W1A
M=&ES=&EC<R`@("`@("!'=6%R9&%R(&5S=&%T[7-T:6-A<R!D92!T<F%D=>?C
M;R!N=6T@9FEC:&5I<F\@;&]C86PN`"`@+70L("TM=&5S="`@("`@("`@36]S
M=')A<B!O<R!P<F]G<F%M87,@82!E>&5C=71A<B!M87,@;N-O(&\@9F%Z97(N
M`"`@8VQE86YU<"`@("`@3&EM<&%R(&]F(&%R<75I=F]S(%!/(&1E(&5N=')A
M9&%S('!O<B!T<F%D=7II<B!O=2!O8G-O;&5T87,N`"`@8V]M;6ET("`@("`@
M0V]M971E<B!A<R!T<F%D=>?U97,@;F\@<V5R=FED;W(@0U93+@`@(&-O;6UI
M="UH96QP($-O;65T97(@87)Q=6EV;W,@9&4@86IU9&$@;F\@<V5R=FED;W(@
M0U93+@`@(&-O;7!E;F1I=6T@(%)E8V]N<W1R=6ER(&\@87)Q=6EV;R!D92!C
M;VUPZFYD:6\N($%T96[GXV\Z($\@;F]V;R!A<G%U:79O"B`@("`@("`@("`@
M("`@<V]B<F5P]64M<V4@86\@86YT:6=O+@`@(&5X=')A8W0@("`@($=E<F%R
M(&%R<75I=F]S(&UO9&5L;R!03R`H+G!O="DN`"`@:&5L<"`@("`@("`@36]S
M=')A<B!E<W1A(&UE;G-A9V5M(&1E(&%J=61A+@`@(&EN:70@("`@("`@($-R
M:6%R('5M(&]U(&UA:7,@87)Q=6EV;W,@4$\@<&%R82!U;6$@;F]V82!L;V-A
M;&EZ8>?C;RX*("`@("`@("`@("`@("!!=&5NY^-O.B!/<R!N;W9O<R!A<G%U
M:79O<R!S;W!R97#U96TM<V4@86]S(&%N=&EG;W,N`"`@;6%K92`@("`@("`@
M0V]N<W1R=6ER(&%R<75I=F]S(&)I;N%R:6]S($U/(&$@<&%R=&ER(&1O<R!A
M<G%U:79O<PH@("`@("`@("`@("`@(%!/(&5S<&5C:69I8V%D;W,N`"`@;6%K
M92UH96QP("`@36%R8V%R('1O9&%S(&%S(&5N=')A9&%S(&YO(&%R<75I=F\@
M6$U,(&1E(&%J=61A(&-O;6\@97-T86YD;PH@("`@("`@("`@("`@(&%C='5A
M;&EZ861A<R!E('!R97!A<F%R(&\@87)Q=6EV;R!P87)A(&$@<'+S>&EM82!E
M>&5C=>?C;PH@("`@("`@("`@("`@(&1E('5P9&%T92UH96QP+B!$979E+7-E
M(&5X96-U=&%R(&UA:V4M:&5L<"!$15!/25,@9&4*("`@("`@("`@("`@("!U
M<&1A=&4M:&5L<"!E(&1E(')E=F5R(&\@87)Q=6EV;R!D92!A:G5D82X`("!M
M97)G92`@("`@("!);G1E9W)A<B!O(&%R<75I=F\@4$\@8V]R<F5N=&4@8V]M
M(&\@87)Q=6EV;R!M;V1E;&\@4$\@8V]R<F5N=&4N`"`@=7!D871E("`@("`@
M17AE8W5T87(@97AT<F%C="!E(&UE<F=E(&5M('-E<77J;F-I82X`("!U<&1A
M=&4M:&5L<"!%>'1R86ER('1O9&%S(&%S(&5N=')A9&%S(&YO=F%S(&4@;6]D
M:69I8V%D87,@9&\@87)Q=6EV;R!D90H@("`@("`@("`@("`@(&%J=61A(%A-
M3"!E;2!I;F=LZG,@92!I;G1E9W+A+6QA<R!C;VT@87,@97AI<W1E;G1E+@`@
M)B,Q-3$[("5S(&5S=.$@<')O;G1O('!A<F$@969E8W1U87(@87,@;W!E<F'G
M]65S(&1E(&UA;G5T96[GXV\@;6%R8V%D87,@86)A:7AO+@`@*"5S(&1I87,@
M871RX7,I`"`H0VAA=F4@9&4@86-E<W-O("5S*0`@*&1E;G1R;R!D92`E<R!D
M:6%S*0`@*&AO:F4I`"`H86UA;FCC*0`@*&]N=&5M*0`@8V]M(``B)7,B(&[C
M;R#I('5M82!E<V-O;&AA(';A;&ED82X`(B5S(B!NXV\@97-TX2!C;VYF:6=U
M<F%D;R!N;R!296=I<W1O(&1O($AO<F1E+@`B)7,B(')E<')E<V5N=&%D;W(@
M9&4@X7)V;W)E(&[C;R!E;F-O;G1R861O+@`B)7,B(&9O:2!A9&EC:6]N861O
M(&%O('-I<W1E;6$@9&4@9W)U<&]S+@`B)7,B)R!F;VD@861I8VEO;F%D;R!A
M;R!S:7-T96UA(&1E('!E<FUI<W/U97,N`"(E<R(@;N-O(&9O:2!C<FEA9&\Z
M("5S+@`E9"`E<R!E("5S`"5D(&)Y=&5S(&5S8W)I=&]S`"5D(&1E("5D(&5N
M=')A9&$@;6%R8V%D87,@8V]M;R!A8W1U86QI>F%D87,`<')E=FESXV\@9&4@
M)60@9&EA<P`E<R`M($YO=&EF:6-AY^-O`"5S($%D;6EN:7-T<F'GXV\`)7,@
M26UP<F5S<^-O($1I9VET86P`)7,@2T(`)7,@3W!E<F'G]65S(&1E($UA;G5T
M96[GXV\@+2!#;VYF:7)M8>?C;P!#;VYF:6=U<F%R("5S`"5S(%-U8G-C<F5V
M97(`)7,@5&5R;6]S(&1O($%C;W)D;P`E<R!JX2!E>&ES=&4N`"5S(&5M("5S
M("5S`&[C;R!S92!P;V1E(&5S8W)E=F5R(&5M("5S+@`E<R#I(&]B<FEG873S
M<FEO`"5S(&UI;G5T;W,`)7,@;N-O(&9O:2!E;F-O;G1R861O+@`E<R!NXV\@
M9F]I(&5N8V]N=')A9&\N($5X96-U=&%R("=T<F%N<VQA=&EO;B!E>'1R86-T
M)R!P<FEM96ER;RX`)7,@82`E<R!D92`E<P!#;VYT86-T;W,@9&4@)7,`0V%L
M96YDX7)I;R!D92`E<P!.;W1A<R!D92`E<P!487)E9F%S(&1E("5S`"5S.B`E
M<P`L(&-O;2!R86IA9&%S`"P@8V]M(')A:F%D87,@)7,@)7,`+"!V87)IX79E
M;"!D92`E<R!A("5S`"TM(&5S8V]L:&$@+2T`+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM`$9O<FUA=&\@9&4@,3(@:&]R87,@*$%-+U!-*0!&;W)M871O
M(&1E(#(T(&AO<F%S`#(T(&AO<F%S`#Q!;G1E<FEO<@!E=&EQ=65T82`\9V5T
M=&5X=#X@<&]R(&9E8VAA<B!N;R!F:6-H96ER;R`E<RX*06)R:6YD;R!A(&5T
M:7%U971A(&5N8V]N=')A9&$@;F$@;&EN:&$@)60N`$5S=&4@8FQO8V\@97AI
M9V4@=6T@;65C86YI<VUO('5S86YD;R!B87-E<R!D92!D861O<RX`3V-O<G)E
M=2!U;2!E<G)O(&9A=&%L`,D@;F5C97-SX7)I82!U;6$@8VAA=F4@</IB;&EC
M82!01U`@<&%R82!E;F-R:7!T87(@82!M96YS86=E;2X`R2!N96-E<W/A<FEA
M('5M82!C:&%V92!P^F)L:6-A(%!'4"!P87)A('9E<FEF:6-A<B!A(&%S<VEN
M871U<F$@9&4@=6UA(&UE;G-A9V5M`%!A<F$@9&5C:69R87(@=6UA(&UE;G-A
M9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!01U`L('5M
M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!F<F%S92UP87-S92X`4&%R82!A
M<W-I;F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E
M('#Z8FQI8V$@4$=0+"!U;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@9G)A
M<V4M<&%S<V4N`%!A<F$@9&5C:69R87(@=6UA(&UE;G-A9V5M('/C;R!N96-E
M<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C:&%V92!P
M<FEV861A(%,O34E-12!E('5M82!F<F%S92UP87-S92X`4&%R82!A<W-I;F%R
M('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI
M8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@9G)A
M<V4M<&%S<V4N`,D@;F5C97-SX7)I82!U;6$@8VAA=F4@</IB;&EC82!3+TU)
M344@<&%R82!E;F-R:7!T87(@=6UA(&UE;G-A9V5M+@!.^G9E;G,@9&4@;6%N
M:.,`0VAU=FES8V]S(&1E($UA;FCC`$-H=79A(&1E(&UA;FCC`$%G=6%C96ER
M;W,@9&4@;6%N:.,`3F5V]65S(&1E(&UA;FCC`$%-+U!-`$%022!)1`!!8V5R
M8V$@9&5S=&4@961I=&]R`$%C97)C82XN+@!"87-E<R!A;&EN:&%D87,`0V5N
M=')O<R!A;&EN:&%D;W,`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!P87-T82!6
M1E,N`$%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q=6EV;R!61E,N`%!A;&%V
M<F$M4&%S<V4@9&$@0V]N=&$`0V]N=&$@8V]N9V5L861A+@!#;VYT86)I;&ED
M861E`$%D:6-I;VYA<@!!9&EC:6]N87(@1W)U<&\@1FEL:&\`061I8VEO;F%R
M(%!E<FUI<W/C;R!&:6QH80!!8W)E<V-E;G1A<B!!<75I.@!!9&1I8VEO;F%R
M($YO=F\@1W)U<&\`061I8VEO;F%R($YO=F$@4&5R;6ES<^-O`$%D:6-I;VYA
M<B!U;2!G<G5P;R!F:6QH;R!A("(E<R(`061I8VEO;F%R('5M82!P97)M:7-S
MXV\@9FEL:&$@82`B)7,B`$%D:6-I;VYA<B!N;W9O('5T:6QI>F%D;W(Z`$%D
M:6-I;VYA<B!C;VQU;F$`061I8VEO;F%R(&YO=F]S(&UE;6)R;W,`061I8VEO
M;F%R('!A<F-E:7)O`$%D:6-I;VYA<B!O($UE;G4@)7,@8V]M;R!"87)R82!,
M871E<F%L($UO>FEL;&$`061I8VEO;F%R(&%O<R!#;VYT86-T;W,Z`$%D:6-I
M;VYA<B!A;W,@;65U<R!C;VYT86-T;W,`061I8VEO;F%R('5T:6QI>F%D;W(`
M061I8VEO;F5I("(E<R(@86\@<VES=&5M82P@;6%S(&[C;R!P=61E(&%D:6-I
M;VYA<B!I;F9O<FUAY^-O(&1E('-U8G-C<FGGXV\@861I8VEO;F%L.B`E<RX`
M061I8VEO;F5I("(E<R(@86\@<VES=&5M82X@2N$@<&]D92!E;G1R87(N`$%D
M:6-I;VYA;F1O(&YO=F]S(&%R<75I=F]S(&%O(')E<&]S:73S<FEO.@!!(&%D
M:>?C;R!D92!U=&EL:7IA9&]R97,@97-TX2!D97-A8W1I=F%D82X`16YD97)E
MYV\`0V]N=&%C=&]S`$%D;6EN:7-T<F%R("T@871R:6)U:7(@<&5R;6ES<_5E
M<R!A(&]U=')O<R!U=&EL:7IA9&]R97,`061M:6YI<W1R8>?C;P!!;OIN8VEO
M<P!!9F5G86YI<W3C;P!!;&+B;FEA`$%R9^EL:6$`06QC=6YH80!!;&EN:&%R
M`$%L:6YH86UE;G1O.@!4=61O`%1O9&]S(&]S(%5T:6QI>F%D;W)E<R!!=71E
M;G1I8V%D;W,`5&]D;W,@;W,@1W)U<&]S`%1O9&%S(&%S(%!E<FUI<W/U97,`
M5&]D;W,@;W,@*'%U871R;RD@;&%D;W,`4&5R;6ET:7(@;?IL=&EP;&]S(&5N
M9&5R9>=O<P!097)M:71I<B!A=')I8G5IY^-O(&1O('1I<&\@9&4@;&ES=&%S
M(&]R9&5N861A<S\`2N$@97AI<W1E`$5N=')A9&$@24U34"!!;'1E<FYA=&EV
M80!086QA=G)A+5!A<W-E($E-4U`@06QT97)N871I=F$`3F]M92!D92!5=&EL
M:7IA9&]R($E-4U`@06QT97)N871I=F\`16YD97)EYV\@:6YVX6QI9&\`36]D
M96QO<R!A;'1E<FYA=&EV;W,`5&5X=&\@86QT97)N871I=F\Z`%-A;6]A($%M
M97)I8V%N80!&;VD@97-P96-I9FEC861O('5M('9A;&]R(&EN=N%L:61O+@!/
M8V]R<F5U('5M(&5R<F\@9&5S8V]N:&5C:61O+@!!;F1O<G)A`$%N9V]L80!!
M;F=U:6QA`$5N=')E<&]S=&\@*'!R;WAY*2!!;O-N:6UO`%)E<W!O<W1A`$%N
M=.%R8W1I8V\`06YT[6=U82!E($)A<F)U9&$`07!L:6-AY^-O`$%P;&EC8>?C
M;R!P<F]N=&$N`$%P;&EC87(@82!087)T:6QH87,@1FEL:&%S`$%P<F]V87(`
M5&%M86YH;R!!<')O>&EM861O`$%B<FEL`$%RX6)I8V\@*%=I;F1O=W,M,3(U
M-BD`5&%M86YH;R!D;R!&:6-H96ER;R!D92!!<G%U:79O`$YO;64@9&\@07)Q
M=6EV;P!496T@82!C97)T97IA('%U92!Q=65R(')E;6]V97(@;R!P961I9&\@
M9&4@<W5B<V-R:>?C;R!P87)A("5S(#\`5&5M(&$@8V5R=&5Z82!Q=64@<75E
M<B!R96UO=F5R("(E<R(@92!Q=6%I<W%U97(@<W5B+6=R=7!O<S\`07)G96YT
M:6YA`$%R;>EN:6$`07)MZ6YI;R`H05)-4T-)22TX*0!!<G1E`$%R=6)A`$EL
M:&$@9&4@07-C96YSXV\`07)T92!!4T-)20!296=IXV\@P7-I82]086/M9FEC
M;P!0961I<B!C;VYF:7)M8>?C;R!A;G1E<R!D92!R96%L:7IA<B!O<&5R8>?U
M97,@9&4@;6%N=71E;N?C;S\`0V]L=6YA<R!D92!A=')I8G5IY^-O`%1E;G1A
M=&EV82!D92!R96UOY^-O(&1E('5M(&=R=7!O(&EN97AI<W1E;G1E+@!496YT
M871I=F$@9&4@<F5M;^?C;R!D92!U;6$@<&5R;6ES<^-O(&EN97AI<W1E;G1E
M+@!496YT871I=F$@9&4@961IY^-O(&1E('5M82!P97)M:7-SXV\@:6YE>&ES
M=&5N=&4N`%1E;G1A=&EV82!D92!E9&GGXV\@9&4@=6UA('!A<G1I;&AA(&EN
M97AI<W1E;G1E+@!!=')I8G5T;W,`06=O<W1O`$%U<W1RX6QI80#!=7-T<FEA
M`$%U=&A?8WER<W%L.B!!(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82!NXV\@
M9F]I(&5N8V]N=')A9&$N`$%U=&A?8WER=7,Z($\@;65C86YI<VUO(&[C;R!T
M96T@87,@8V%P86-I9&%D97,@;F5C97-SX7)I87,N`$%U=&A?8WER=7,Z($$@
M97AT96YSXV\@:6UA<"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`
M075T:%]F='`Z($$@97AT96YSXV\@1E10(&YE8V5S<^%R:6$@;N-O(&9O:2!E
M;F-O;G1R861A+B!#;VUP:6QE(&\@4$A0(&-O;2!A(&]PY^-O("TM96YA8FQE
M+69T<"X`075T:%]I;6%P.B!!(&5X=&5N<^-O($E-05`@;F5C97-SX7)I82!N
MXV\@9F]I(&5N8V]N=')A9&$N`$%U=&A?:W)B-3H@02!E>'1E;G/C;R!K<F(U
M(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!=71H7VQD87`Z($$@
M97AT96YSXV\@3$1!4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`
M075T:%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!U=&EL:7IA9&]R("5S
M+B!%:7,@;R!Q=64@;R!S97)V:61O<B!D:7-S93H@`$%U=&A?;&1A<#H@26UP
M;W-S[79E;"!R96UO=F5R(&\@=71I;&EZ861O<B`E<P!!=71H7VQD87`Z($EM
M<&]S<^UV96P@86-T=6%L:7IA<B!O('5T:6QI>F%D;W(@)7,`075T:%]M8V%L
M.B!!(&5X=&5N<^-O($U#04P@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A
M9&$N`$%U=&A?<VUB875T:#H@02!E>'1E;G/C;R!S;6)A=71H(&YE8V5S<^%R
M:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!(&%U=&5N=&EC8>?C;R!F86QH;W4`
M02!A=71E;G1I8V'GXV\@9F%L:&]U+B`E<P!!(&%U=&5N=&EC8>?C;R!F;VD@
M<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$2553+@!!(&%U=&5N=&EC8>?C
M;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+@!#86UP;W,@9&ES<&]N[79E:7,Z
M`$%Z97)B86EJXV\`1&5S8W5L<&%S(")"3T9((@!&=6YD;P!#;W(@9&\@1G5N
M9&\`4&%L879R82U087-S92!K97)B97)O<R!E<G)A9&$N`$YO;64@9&4@571I
M;&EZ861O<B!K97)B97)O<R!E<G)A9&\N`$)A86UA<P!"87+I;0!"X6QT:6-O
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5C:&4`0F%R8F%D;W,`3&EN:&$@8F%S
M90!":65L;W)R^G-S:6$`0NEL9VEC80!"96QI>F4`0F5N:6T`0F5R;75D80!"
M=73C;P!!;FEV97)SX7)I;P!/(&)L;V-O("(E<R(@9&$@87!L:6-AY^-O("(E
M<R(@;N-O(&9O:2!E;F-O;G1R861O+@!#;VYF:6=U<F'G]65S(&1E($)L;V-O
M<P!4:7!O(&1E($)L;V-O`$YE9W)I=&\`0F]L[79I80!-87)C861O<F5S`$)O
M<F1A`$5S<&5S<W5R82!D82!B;W)D83H`0F]R9&%S`$+S<VYI82U(97)Z96=O
M=FEN80!!;6)A<P!";W1S=6%N80!"87-E`$EL:&$@0F]U=F5T`$)R87-I;`!4
M97)R:73S<FEO($)R:73B;FEC;R!D;R!/8V5A;F\@S6YD:6-O`$)R=6YE:2!$
M87)U<W-A;&%M`$-O;G-T<G5I;F1O(&%R<75I=F]S($U/('!A<F$@;R!M\V1U
M;&\@)7,N+BX`0V]N<W1R=6EN9&\@;&]C86QI>F'GXV\@)7,N+BX@`$)U;&?A
M<FEA`$QI<W0@271E;6EZ861A`$)U<G%U:6YA($9A<V\`0G5R^FYD:0!#35,`
M0U)#`%!O;G1O<R!D92!$:7-T<FEB=6GGXV\@0U),`%!R;W!R:65D861E<R!D
M82AS*2!#Z5]L=6QA*',I+BXN`$EN:6-I86QI>F'GXV\@9&$@(F-A8VAE(B!N
MXV\@9F]I(&-O;F-L=>UD82X`0V%L96YDX7)I;P!#86QM;P!#86UB;V1J80!#
M86UA<O5E<P!.XV\@<&]S<V\@<F5I;FEC:6%R(&$@<&%L879R82UP87-S92!A
M=71O;6%T:6-A;65N=&4L(&-O;G1A8W1E(&\@<V5U(&%D;6EN:7-T<F%D;W(@
M9&4@<VES=&5M87,N`$EM<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@
M24U!4#H@)7,`0V%N863A`$-A;F-E;&%R`$-A;F-E;&%R(%)E;&%T\W)I;R!D
M92!0<F]B;&5M87,`3N-O(&-O;G-I9V\@<F5M;W9E<B!O(&9I8VAE:7)O("(E
M<R(N`$[C;R!C;VYS:6=O(&5N8V]N=')A<B!U;2!D:7)E8W3S<FEO('1E;7!O
M<N%R:6\N`$EM<&]S<^UV96P@8V]N=&EN=6%R('-E;2!O('!A<N)M971R;R`G
M=&%R9V5T1FEL92<N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A
M("(E<R(N`$EM<&]S<^UV96P@<F5M;W9E<BP@97AI<W1E;2`E9"!F:6QH;W,N
M`$[C;R#I('!O<W/M=F5L(')E;W)D96YA<CH@;R!N^FUE<F\@9&4@96YT<F%D
M87,@9F]R;F5C:61A<R!NXV\@8V]R<F5S<&]N9&4@86\@;OIM97)O(&=U87)D
M861O+@!.XV\@9F]I('!O<W/M=F5L(&5N8V%M:6YH87(@82!M96YS86=E;2!P
M87)A(&\@;OIM97)O(&EN9&EC861O+@!297#Z8FQI8V$@9&4@0V%B;R!697)D
M90!,96=E;F1A`$-A=&5G;W)I87,@92!#;W)E<P!);&AA<R!#86EMXV\`5&5L
M969O;F4@0V5L=6QA<@!0<F]P<FEE9&%D97,@9&%S($/I;'5L87,`16YC:&EM
M96YT;R!D87,@0^EL=6QA<SH`4')O<')I961A9&5S(&1A<R!CZ6QU;&%S`$5S
M<&'G86UE;G1O(&1A<R!CZ6QU;&%S.@!496QE;?-V96P`0^EL=&EC;R`H25-/
M+3@X-3DM,30I`$-E;G1R87(`4F5P^F)L:6-A($-E;G1R;R!!9G)I8V%N80!%
M=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM,BD`4&]R;65N;W)E<R!D;R!#97)T
M:69I8V%D;P!$;VYO(&1O($-E<G1I9FEC861O`%!O;.UT:6-A<R!D92!#97)T
M:69I8V%D;P!297#Z8FQI8V$@9&\@0VAA9&4`06QT97)A<@!!;'1E<F4@;R!N
M;VUE(&4@96YD97)EYV\@<75E(&%S('!E<W-O87,@=F5RXV\@<75A;F1O(&QE
M<F5M(&4@<F5S<&]N9&5R96T@X',@<W5A<R!M96YS86=E;G,N`$-A<F%C=&5R
M90!697)I7V9I8V%R($QI9V'GXV\N+BX`36%R<75E(&%S(&]P97)AY_5E<R!Q
M=64@9&5S96IA(&5X96-U=&%R(&YE<W1E(&UO;65N=&\N`%)E</IB;&EC82!D
M;R!#:&EL90!297#Z8FQI8V$@4&]P=6QA<B!D82!#:&EN80!#:&ENZG,@4VEM
M<&QI9FEC861O<R`H1T(R,S$R*0!#:&ENZG,@5')A9&EC:6]N86P@*$)I9S4I
M`$5S8V]L:&$@82!P86QA=G)A+7!A<W-E`$5S8V]L:&$@=6T@3F]M92!D92!5
M=&EL:7IA9&]R`$5S8V]L:&$@8V]M;R!M;W-T<F%R(&%S(&1A=&%S.@!%<V-O
M;&AA(&\@97-T:6QO(&1A<R!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S
M*0!);&AA(&1O($YA=&%L`$[C;R!F;VD@96YC;VYT<F%D82!A(&1E9FEN:>?C
M;R!D82!C;&%S<V4@)7,N`$QI;7!A;F1O(&]S(&%R<75I=F]S(%!/(&1O(&WS
M9'5L;R`E<RXN+@!,:6UP86YD;R!A(&QO8V%L:7IAY^-O("5S+BXN(`!,:6UP
M87(`3&EM<&%R(&5T:7%U971A<R!D;R!-4T]F9FEC90!,:6UP87(@9&%D;W,@
M9&\@=71I;&EZ861O<CH@)7,`3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(`
M3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(`3&EM<&$@5&%R9&4`0VQI<75E
M('!A<F$@0V]N=&EN=6%R`$-L:6-K871E;&P@=FEA($A45%``1F5C:&%R(&IA
M;F5L80!.^G9E;G,`3OIV96YS($UA=&EN86ES`$5N979O861O`$EL:&%S($-O
M8V]S("A+965L:6YG*0!#;VQA<'-A<B!"87)R82!,871E<F%L`$)O<F1A<R!#
M;VQA<'-A9&%S`%)E</IB;&EC82!D82!#;VST;6)I80!#;W)E<P!086QE=&4`
M4V5L96/GXV\@9&4@8V]R97(`0V]L=6YA<SH`5.UT=6QO<R!D87,@8V]L=6YA
M<P!"1`!#;VUA;F1O`$-O;G-O;&$@9&4@0V]M86YD;W,`3W#G]65S(&1O(&-O
M;6%N9&\Z`$-O;6%N9&]S.@!#;VUE;G3A<FEO`$-O;65T96YD;P!.;VUE($-O
M;75M`$-O;6]R;W,`16UP<F5S80!%<V-R979E<B`H)7,I`$-O;7!U=&%D;W)E
M<P!#;VYD:>?C;P!#;VYD:>?U97,`1&EF97)E;N=A<R!D92!#;VYF:6=U<F'G
MXV\`02!C;VYF:6=U<F'GXV\@97-TX2!D97-A8W1U86QI>F%D80!#;VYF:6=U
M<F%R("5S`$-O;F9I<FUE(&$@4&%L879R82U087-S90!297#Z8FQI8V$@1&5M
M;V-RX71I8V$@9&\@0V]N9V\`4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1O($-O
M;F=O`$-O;F5XXV\@9F%L:&]U+@!#;VYE>.-O(&9A;&AO=3H@`$-O;F5XXV\@
M86\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S(')E8W5S861A+@!#;VYE
M>.-O(&%O('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<R!R96-U<V%D82X@
M4F%ZXV\Z("5S("@E<RD`0V]N97CC;R!A;R!S97)V:61O<B!&5%`@<F5C=7-A
M9&$N`$-O;G1A8W1O<R!A9&EC:6]N861O<R!C;VT@<W5C97-S;R!A;R!S974@
M;&EV<F\@9&4@96YD97)EYV]S+@!4:7!O(&1E(&-O;G1E^F1O(&1O(&%R<75I
M=F\@8V]M<')I;6ED;SH@`$-O;G1E^F1O(&1E("5S`$-O;G1I;G5A<@!);&AA
M<R!#;V]K`$)O;&EN:&\@8VAI;NIS`$-O<&EA<@!#;W!I87(@<V5L96/GXV\`
M0V]P:6%N9&\@9&4@)7,@<&%R82`E<P!297#Z8FQI8V$@9&$@0V]S=&$@4FEC
M80!297#Z8FQI8V$@9&$@0V]S=&$@9&\@36%R9FEM`$[C;R!F;VD@<&]S<^UV
M96P@96YC<FEP=&%R(&$@;65N<V%G96T@8V]M(%!'4"X`3N-O(&9O:2!P;W-S
M[79E;"!A<W-I;F%R(&$@;65N<V%G96T@8V]M(%!'4"X`3N-O(&9O:2!P;W-S
M[79E;"!E;F-R:7!A<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@
M<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F
M;VD@<&]S<^UV96P@861I8VEO;F%R(&\@8V]N=&%C=&\N("5S`$9A;&AA(&YA
M(&QI9V'GXV\@*&)I;F0I(&%O('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S
M<^UV96P@=F5R:69I8V%R(&\@<V%L9&\N("5S`$[C;R!F;VD@<&]S<^UV96P@
M8V]N96-T87(@86\@<V5R=FED;W(@(B5S(B!U<V%N9&\@1E10.B`E<P!.XV\@
M9F]I('!O<W/M=F5L(&-O<&EA<B`E<R!P87)A("5S`$[C;R!F;VD@<&]S<^UV
M96P@8W)I87(@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O
M<W/M=F5L(&-R:6%R('!A<W1A(&1E(&QO8V%L:7IAY^-O('!A<F$@82!L;V-A
M;&EZ8>?C;R`E<SH`3N-O(&9O:2!P;W-S[79E;"!D97-E;F-R:7!T87(@;W,@
M9&%D;W,@8V]M(&\@4$=0+@!.XV\@9F]I('!O<W/M=F5L(&1E<V5N8W)I<'1A
M<B!O<R!D861O<R!C;VT@4R]-24U%+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V
M97(@8V]N=&%C=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!L:7-T
M82!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E
M<B!O(")S8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R`B)7,B+@!.XV\@9F]I('!O
M<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T
M<O-N:6-O(&1O(&1E<W1I;F%TX7)I;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E
M<B!O(&QI=G)O(&1E(&5N9&5R9>=O<R!C;VUP;&5T;RX`3N-O(&9O:2!P;W-S
M[79E;"!O8G1E<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!C;VUP;&5T82X`
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&QI<W1A(&-O;7!L971A(&1A<R!L
M:7-T87,@9&4@9&ES=')I8G5IY^-O+@!);7!O<W/M=F5L(&-A<G)E9V%R(&5S
M=')A=.EG:6$@(B5S(BX`26UP;W-S[79E;"!M:V1I<B`B)7,B+@!.XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&$@8VAA=F4@</IB;&EC82!A('!A<G1I<B!D;R!S
M97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N`$[C;R!F;VD@<&]S<^UV96P@
M86)R:7(@(B5S(B!P87)A(&5S8W)I=&$N`$[C;R!F;VD@<&]S<^UV96P@86)R
M:7(@)7,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!M\V1U;&\@9&4@36%N
M=71E;N?C;R!D92!487)E9F%S("5S`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@
M<&%S=&$@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!L97(@)7,N`$[C;R!F;VD@
M<&]S<^UV96P@<F5I;FEC:6%R(&$@<&%L879R82UP87-S92!D;R!U=&EL:7IA
M9&]R(&EN9&EC861O+B!!;&=U;2!O=2!T;V1O<R!O<R!P;W)M96YO<F5S(&[C
M;R!E<W1A=F%M(&-O<G)E8W1O<RX@4&]R(&9A=F]R('1E;G1E(&1E(&YO=F\@
M;W4@8V]N=&%C=&4@;R!S974@861M:6YI<W1R861O<B!D92!S:7-T96UA<R!S
M92!P<F5C:7-A<B!D92!M86ES(&%J=61A+@!.XV\@9F]I('!O<W/M=F5L(&]B
M=&5R($%#3`!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI=G)O(&1E(&5N9&5R
M9>=O<RX@)7,`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L:7-T82!D92!D:7-T
M<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&ES=&%S(&1E
M(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A<R!C
M;VUP973J;F-I87,@9&\@<V5R=FED;W(`3N-O(&9O:2!P;W-S[79E;"!R979E
M<G1E<B!A(&-O;F9I9W5R8>?C;RX`26UP;W-S[79E;"!R;61I<B`B)7,B+@!.
MXV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@)7,N
M`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D92!S
M86QV86=U87)D82X`3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG
M=7)AY^-O(&1E('-A;'9A9W5A<F1A.B`E<P!.XV\@9F]I('!O<W/M=F5L(&=U
M87)D87(@;R`B<V-R:7!T(B!D92!A8W1U86QI>F'GXV\@96TZ("(E<R(N`$[C
M;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D92!S86QV
M86=U87)D82`E<RX`3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&\@87)Q=6EV
M;R!D92!C;VYF:6=U<F'GXV\@)7,N(%!O9&4@=7-A<B!U;6$@9&%S(&]PY_5E
M<R!P87)A(&=U87)D87(@;R!C\V1I9V\@96T@)7,@;W4@8V]P:6%R(&UA;G5A
M;&UE;G1E(&\@8_-D:6=O(&%B86EX;R!P87)A("5S+@!.XV\@9F]I('!O<W/M
M=F5L('!R;V-U<F%R(&YO('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV
M96P@9&5S;&EG87(@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI>F%R
M(&-O;G1A8W1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&%C='5A;&EZ87(@82!L
M:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@97-C
M<F5V97(@82!C;VYF:6=U<F'GXV\@<&%R82`B)7,B.B`E<P!.XV\@96YC;VYT
M<F5I(&$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA+B!!<W-E9W5R92US92!Q
M=64@82!B87)R82!L871E<F%L(&5S=.$@86)E<G1A+@!.XV\@9F]I('!O<W/M
M=F5L(&%T<FEB=6ER(&%O('5T:6QI>F%D;W(@(B5S(B!O<R!S96=U:6YT97,@
M9&ER96ET;W,@<V]B<F4@82!P87-T82`B)7,B.B`E<P!497AT;R!#;VYT861O
M`%!A[7,`0W5R<V]S`$-R:6%R`$-R:6%R('5M82!L:6=AY^-O`$-R:6%R('5M
M82!N;W9A`$-R:6%R('-U8BUP87-T87,`4&5R;6ES<_5E<R!D;R!#<FEA9&]R
M`$[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;P!297#Z8FQI8V$@9&$@0W)O
MX6-I80!297#Z8FQI8V$@9&4@0W5B80!1=6%T<F\@9F%S97,@8V]R<F5N=&5S
M`$1A=&$O2&]R80!54DP@8V]R<F5N=&4@Z0!%<W1A9&\@9&\@5&5M<&\`4VET
M=6'GXV\@86-T=6%L.B``17-T:6QO(&%C='5A;`!097)S;VYA;&EZ87(@87,@
M=&%R969A<R!Q=64@<V5RXV\@97AE8W5T861A<R!A<75A;F1O(&\@;&]G:6X@
M;F\@)7,N`$-O<G1A<@!#;W)T87(@82!S96QE8^?C;P!297#Z8FQI8V$@9&4@
M0VAI<')E`$-I<NUL:6-O("A+3TDX+5(I`$-I<NUL:6-O("A7:6YD;W=S+3$R
M-38I`$-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*0!297#Z8FQI8V$@0VAE
M8V$`1$0`1&EA<FEA;65N=&4`3F%V96=A9&]R(&1E(,%R=F]R92!D92!$861O
M<P!$871A`$1A=&$@9&4@4F5C97#GXV\`4V5L96/GXV\@9&4@9&%T80!$:6$`
M4F5M;W9E<B!#;U]L=6YA`$1E>F5M8G)O`$[Z;65R;W,@9&5C:6UA:7,`4F5D
M=7II<B!I;F1E;G1AY^-O`%!O<B!/;6ES<^-O`$-O<B!0;W(@3VUI<W/C;P!)
M9&5N=&ED861E(%!A9'+C;P!097)M:7-S]65S(%!O<B!/;6ES<^-O`%!E<FUI
M<W/U97,@<&]R(&]M:7-SXV\`1&5F:6YIY_5E<P!296UO=F5R`%)E;6]V97(@
M1W)U<&\`4F5M;W9E<B!097)M:7-SXV\`4F5M;W9E<B!E('!U<F=A<B!M96YS
M86=E;G,`4F5M;W9E<B!CZ6QU;&$`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!M
M;V1E;&\@86QT97)N871I=F\@97AI<W1E;G1E`%)E;6]V97(@<&5R;6ES<_5E
M<R!D92`B)7,B`%)E;6]V97(@<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%I
M<W%U97(@<W5B+7!E<FUI<W/U97,_`%)E;6]V97(@;&EN:&$`4F5M;W9E<B!I
M9&5N=&ED861E('-E;&5C8VEO;F%D80!296UO=F5R(&$@8V]L=6YA(&-O<G)E
M;G1E`%)E;6]V97(@82!L:6YH82!C;W)R96YT90!296UO=F5R(&5S=&$@<&5R
M;6ES<^-O(&4@=&]D87,@87,@<W5A<R!S=6(M<&5R;6ES<_5E<S\`(E-C<FEP
M="(@9&4@86-T=6%L:7IAY^-O("(E<R(@<F5M;W9I9&\N`$UO;65N=&\@9&4@
M96YT<F5G80!$:6YA;6%R8V$`1&5S8W)E=F$@;R!0<F]B;&5M80!$97-C<FGG
MXV\`4&]R;65N;W)E<R`H=&%M8NEM(&YO(')E9VES=&\L(")L;V<B+"!D;R!(
M;W)D92DZ`$]S(&1E=&%L:&5S(&9O<F%M(&5N=FEA9&]S('!A<F$@;R!A9&UI
M;FES=')A9&]R(&1O('-I<W1E;6$N`$1E<V5N=F]L=FEM96YT;P!0;VYT;R!D
M92!/<G9A;&AO`%!O;G1O(&1E($]R=F%L:&\@;F$@^FQT:6UA(&AO<F$Z(`!0
M;VYT;R!D92!O<G9A;&AO.B``1&ER96/GXV\@9&$@97-Q=65R9&$@<&%R82!A
M(&1I<F5I=&$`1&ER96/GXV\@9&$@9&ER96ET82!P87)A(&$@97-Q=65R9&$`
M1&ER96-T\W)I;P!-;W-T<F%R('1E;7!O<R!C;VT@,C0@:&]R87,_`$]PY_5E
M<R!D92!6:7-U86QI>F'GXV\`36]S=')A<B!P<F5V:7/C;R!P;W)M96YO<FEZ
M861A`$UO<W1R87(@<')E=FESXV\@*%1!1BD`1F]R;6%T;R!D92!V:7-U86QI
M>F'GXV\`3F]T:69I8V'GXV\@9&4@1&ES<&]S:>?C;P!$:FEB=71I`$[C;R!R
M96UO=F5R`$[C;R!U=&EL:7IE(&\@;6%I;G1E;F%N8V4N<&AP(&1I<F5C=&%M
M96YT90!!('!R:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M
M<&]S/R!392!S:6TL(&%S<VEN86QA<B!E<W1A(&-A:7AA.@!$;VUI;FEC80!2
M97#Z8FQI8V$@1&]M:6YI8V%N80!296-E8F5R`%)E8V5B97(@)7,`1&5S8V%R
M<F5G87(@82!C;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@(G-C<FEP="(@
M4$A0+@!,:7-T82!D92!D97-E;G)O;&%R`$1R;V=A<P!#;W)R96EO(&5L96-T
M<O-N:6-O`$524@!297#Z8FQI8V$@9&\@17%U861O<@!%9&ET87(`161I=&%R
M($)L;V-O`$5D:71A<B!'<G5P;P!%9&ET87(@4&5R;6ES<_5E<P!%9&ET87(@
M4&5R;6ES<_5E<P!%9&ET87(@<&5R;6ES<_5E<R!D92`E<P!%9&ET87(@;W#G
M]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E<R!D92`B)7,B`$5D:71A<B!P97)M
M:7-S]65S(&1E("5S`$5D=6-AY^-O`$5G:7!T;P!297#Z8FQI8V$@9&4@16P@
M4V%L=F%D;W(`16QE;65N=&\N+BX`16T`0V]R<F5I;R!%;&5C='+S;FEC;P!%
M;F1E<F7G;R!D92!#;W)R96EO($5L96-T<O-N:6-O`$]S(&5N9&5R9>=O<R!T
MZFT@<75E(&-O:6YC:61I<BX`365N<V%G96T@8V]M(&-O;F9I<FUAY^-O`%/M
M;6)O;&]S(&1E($5M;^?C;P!-96YS86=E;2!V87II82X`4V5M(')E<W5L=&%D
M;W,N`%-E;2!T97)M;W,@9&4@<')O8W5R80!!8W1I=F%R(&EN<V5RY^-O(&1E
M(&EM86=E;G,@9&4@1V%L97)I87,@1F]T;V=RX69I8V%S(&YO('1E>'1O/P!!
M8W1I=F%R(&UE;G4@9&4@8V]N=&5X=&\@;F\@8F]TXV\@9&ER96ET;R!D;R!R
M871O/P!!;F\@9&4@9FEM`$%U;65N=&%R($5D:71O<@!);G1R;V1U>F$@=6UA
M('!E<F=U;G1A(&1E('-E9W5R86[G82!Q=64@<V5RX2!C;VYV:61A9&\@82!R
M97-P;VYD97(@<V4@<')E8VES87(@9&4@<F5I;FEC:6%R(&$@<W5A('!A;&%V
M<F$M<&%S<V4L(&4N9RXL("=C;VUO('-E(&-H86UA(&\@<V5U(&%N:6UA;"!D
M92!E<W1I;6'GXV\_)SH`26YT<F]D=7IA(&\@55),(&1A(&EM86=E;2!A<75I
M`$5N=')A9&%S.B`E9"!T;W1A;"P@)60@86-T=6%L:7IA9&%S+"`E9"!N;W9A
M<RP@)60@86QT97)A9&%S+"`E9"!D97-C;VYH96-I9&%S`$=U:6[I($5Q=6%T
M;W)I86P`17-T861O(&1A($5R:71R96EA`$5R<F\`17)R;R!N82!M96YS86=E
M;2!D92!C;W)R96EO(&5L96-T<O-N:6-O+@!%<G)O(&%O(&5S8W)E=F5R("(E
M<R(N`$5R<F\Z(`!297#Z8FQI8V$@9&$@17-T\VYI80!297#Z8FQI8V$@1&5M
M;V-RX71I8V$@1F5D97)A;"!D82!%=&GS<&EA`,ET:6-O`$5U<F]P80!#861A
M(#$U(&UI;G5T;W,`0V%D82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#
M861A(#4@;6EN=71O<P!#861A($5N=')A9&$`0V%D82!M96EA(&AO<F$`0V%D
M82!M:6YU=&\`5F%L;W)E<R!E>&5M<&QO.@!%>&5C=71A<@!%>&5C=71A;F1O
M.@!%>'!A;F1I<@!-;W-T<F%R($)A<G)A($QA=&5R86P`)RDG(&5S<&5R861O
M`$5S<&5R879A('5M82!S:6UP;&5S('!A;&%V<F$@;W4@=6T@=&5R;6\@9&4@
M<')O8W5R82!E;G1R92!A<W!A<P!$871A(&1E($5X<&ER8>?C;P!%>'!O96YT
M90!%>'1R86EN9&\@9&4@)7,N+BX@`$-O<B!D;R!0<FEM96ER;R!0;&%N;P!#
M87)R96=A<B!C;VYF:6=U<F'GXV\@9&4@:6YS=&%L8>?C;R!P;W(@1E10`$[C
M;R!F;VD@<&]S<^UV96P@<'5X87(@87,@<')E9F5RZFYC:6%S+@!&86QH82!N
M82!L:6=AY^-O(&%O('-E<G9I9&]R($Q$05`N`$9A;&AA(&YA(&QI9V'GXV\@
M86\@<V5R=FED;W(@4TU"+@!&86QH82!A;R!C;W!I87(@9&4@(B5S(BX`1F%L
M:&$@86\@8V]P:6%R('!A<F$@(B5S(BX`1F%L:&$@86\@8W)I87(@=6UA(&YO
M=F$@8V]N97CC;R!305-,+@!&86QH82!A;R!M;W9E<B!P87)A("(E<R(N`$)O
M;0!);&AA<R!&86QK;&%N9"`H36%L=FEN87,I`$EL:&%S($9A<F]E`$5R<F\@
M1F%T86PZ`$9A>`!&979E<F5I<F\`07!A<F5N=&$`07!A<F5N=&$Z(`!!;&=U
M;G,@06=U86-E:7)O<P!!;&=U;G,@3F5V]65S`$UA=')I>B!D92!C86UP;W,`
M1FEJ:0!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;P!#;VYT86=E
M;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,`1V5S=.-O(&1E($9I8VAE:7)O
M<P!.;VUE(&1O($%R<75I=F\`4V5L96/GXV\@9&\@87)Q=6EV;P!#87)R96=A
M;65N=&\@9&4@87)Q=6EV;P!#87)R96=A;65N=&]S(&1E(&9I8VAE:7)O<R!N
MXV\@<^-O('-U<&]R=&%D;W,N`$9I;'1R;W,`1FEN;.)N9&EA`%%U87)T;R!#
M<F5S8V5N=&4`475A<G1O($-R97-C96YT90!&:7AA<B!RX6-I;P!);G9E<G1E
M<@!&;'5T=6%N=&4`3F5V;V5I<F\`02!P87-T82`E<R!NXV\@97AI<W1E+@!#
M;W(@9&\@5&5X=&\`0V]M:61A`%!A<F$@;F%V96=A9&]R97,@<75E(&[C;R!S
M=7!O<G1A;2!I;6%G96YS`%!R979I<^-O("A4048I`$1I87,@9&4@4')E=FES
MXV\@*&YO=&4M<V4@<75E(&%S('!R979I<_5E<R!I;F-L=65M('1A;G1O(&1I
M87,@8V]M;R!N;VET97,[('5M('9A;&]R(&1E;6%S:6%D;R!G<F%N9&4@<&]D
M92!R97-U;'1A<B!N=6T@8FQO8V\@;75I=&\@;&%R9V\I`$5S<75E8V5U+7-E
M(&1A('!A;&%V<F$M<&%S<V4_`$UO9&5L;W,`1&ET;W,`5&EP;R!D92!D:71O
M<P!$:71O<P!$:71O<R`R`$;S<G5N<P!2965N=FEO<P!!<&QI8V'G]65S("AM
M\V1U;&]S*2!E;F-O;G1R861A<SH@)7,`4&%S=&%S(&5N8V]N=')A9&%S.@`V
MJ@!-;VQD=7)A<P!297#Z8FQI8V$@1G)A;F-E<V$`1G)A;N=A+"!-971R;W!O
M;&ET86YA`$=U:6%N82!&<F%N8V5S80!0;VQI;NES:6$@1G)A;F-E<V$`5&5R
M<F%S($%U<W1R86ES(&4@06YTX7)C=&EC87,@1G)A;F-E<V%S`$1E`$1E(`!$
M97-C<FGGXV\@0V]M<&QE=&$`3'5A($-H96EA`$YO;64@0V]M<&QE=&\`1&EF
M=7-A<P!297#Z8FQI8V$@1V%B;VYE<V$`1V%L97)I82!D92!O;F1E(')E=&ER
M87(@82!I;6%G96T`1V%L97)I83H`4F5P^F)L:6-A(&1A($?B;6)I80!'97)A
M<B!#;VYF:6=U<F'GXV\@)7,`0_-D:6=O($=E<F%D;P!'97)A;F1O(&\@97-T
M861O(&1O(&WS9'5L;R`E<RXN+@!'9?-R9VEA`%)E</IB;&EC82!&961E<F%L
M(&1A($%L96UA;FAA`$5R<F\@96T@9V5T;W!T.@!297#Z8FQI8V$@9&\@1V%N
M80!':6)R86QT87(`3F]M92!0<O-P<FEO`$ER`$?V9&5L`%!E<W%U:7-A($=O
M;V=L90!.[79E:7,@9&4@8VEN>F5N=&\`1W+I8VEA`$=R96=O("A)4T\M.#@U
M.2TW*0!'<F]N96SB;F1I80!'<F%N861A`$%D;6EN:7-T<F'GXV\@9&4@1W)U
M<&]S`$YO;65S(&1E(&=R=7!O<R!NXV\@<&]D96T@97-T87(@=F%Z:6]S`%!E
M<FUI<W/U97,@9&4@9W)U<&\`1W)U<&]S`$=U861A;'5P90!'=6%M`%)E</IB
M;&EC82!D82!'=6%T96UA;&$`1W5E<FYS97D`4&5R;6ES<_5E<R!D87,@5FES
M:71A<P!097)M:7-S]65S(&1A<R!6:7-I=&%S`$QI=G)O(&1E(%9I<VET87,`
M1W5I;ND`1W5I;NDM0FES<V%U`%)E</IB;&EC82!#;RUO<&5R871I=F$@9&$@
M1W5I86YA`$A434P`3R!(5$U,07)E82!R96-U<V$M<V4@8V]B87)D96UE;G1E
M(&$@<F5M;W9E<B!A(/IL=&EM82!CZ6QU;&$@9&$@;&EN:&$N`$\@2%1-3$%R
M96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I;6$@
M8V]L=6YA(&1A('1A8F5L82X`3R!(5$U,07)E82!R96-U<V$M<V4@8V]B87)D
M96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!L:6YH82!D82!T86)E;&$N`$%U
M=&5N=&EC8>?C;R!(5%!0(&[C;R!F;VD@96YC;VYT<F%D82X`4F5P^F)L:6-A
M(&1O($AA:71I`$%L9V]R:71M;R!D92`B2&%S:"(`3F5B;&EN80!#86)EYV%L
M:&\`26QH87,@2&5A<F0@92!-8T1O;F%L9`!496UP;W)A;"U4($9O<G1E`$AE
M8G)E=2`H25-/+3@X-3DM."U)*0!!;'1U<F$`06IU9&$`06IU9&$@<V]B<F4@
M;R!E9&ET;W(`06IU9&$`07!L:6-AY^-O(&%U>&EL:6%R('!A<F$@8W)I87(@
M92!M86YT97(@=')A9'7G]65S(&1A('!L871A9F]R;6$*2&]R9&4@92!D87,@
M<W5A<R!A<&QI8V'G]65S("AM\V1U;&]S*2X*4&%R82!U;6$@:6YT<F]D=>?C
M;R!L97(@;R!F:6-H96ER;R!214%$344@;F5S=&$@<&%S=&$N`$AE;6ES9NER
M:6\`07%U:2!E<W3A(&\@:6[M8VEO(&1O(&%R<75I=F\Z`$%L=&$`3F]M97,@
M9&%S(&5N=')A9&%S(&AI<W3S<FEA<R!NXV\@<&]D96T@97-T87(@=F%Z:6]S
M`$-A7W-A`$5S=&%D;R!D82!#:61A9&4@9&\@5F%T:6-A;F\`0V%S80!%;F1E
M<F7G;R!D92!#87-A`%1E;&5F;VYE(&1E($-A<V$`4F5P^F)L:6-A(&1A<R!(
M;VYD=7)A<P!(;VYG=65C;VYG=64`2&]R9&4`1V5R861O<B!D92!T<F%D=>?U
M97,@2&]R9&4`2&]R9&4O2V]L86(Z($1A9&]S(%A-3"`E<R!I;G;A;&ED;W,@
M;F$@;65N<V%G96T@)7,`2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@
M8V]R<F5S<&]N9&4@86\@;V)J96-T;R`E<P!(;W)D92]+;VQA8CH@3F5N:'5M
M(&]B:F5C=&\@9&\@=&EP;R`E<R!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S
M`$AO<F1E+TMO;&%B.B!296UOY^-O(&1E("5S("(E<R(@=&5V92!S=6-E<W-O
M`$AO<F1E+TMO;&%B.B!3:6YC<F]N:7IAY^-O(&1E("5S("(E<R(@=&5V92!S
M=6-E<W-O`$AO<F1E+TMO;&%B.B!/(&UO=&]R(&1E(&EN=&5G<F'GXV\@<F5Q
M=65R(&$@97AT96YSXV\@4$A0("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!.XV\@
M9F]I('!O<W/M=F5L(&-R:6%R('5M82!N;W9A(.%R=F]R97,@6$U,('!A<F$@
M;R!O8FIE8W1O("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@;R!)1"!-24U%('!A<F$@82!P87)T92!D92!T:7!O("5S`$AO
M<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L('-I;F-R;VYI>F%R("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L('-I;F-R;VYI
M>F%R('!A<G1I;&AA<SH@)7,`2&]R9&4O2V]L86(Z(%!A<G1I;&AA("(E<R(@
M9&5S8V]N:&5C:61A`%1R8>=O($AO<FEZ;VYT86P`16YC:&EM96YT;R!H;W)I
M>F]N=&%L`$AO<FEZ;VYT86PZ`$-O;6\@8VAE9V]U(&%Q=6D_("A0;W(@9F%V
M;W(@<F5P;W)T92UO(2D`475A;G1A<R!C;VQU;F%S('!R971E;F1E(&IU;G1A
M<C\`475A;G1O<R!C86UP;W,@*&-O;'5N87,I(&5X:7-T96T_`%%U86YT87,@
M;&EN:&%S('!R971E;F1E(&IU;G1A<C\`2'5M:61A9&4`2'5M:61A9&4Z(`!(
M=6UO<FES=&%S`%)E</IB;&EC82!D82!(=6YG<FEA`$$@8W)I8>?C;R!D82!C
M86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S`%)E;6_GXV\@9&$@8V%I>&$@
M<&]S=&%L($E-05`@9F%L:&]U.B`E<P!#<FEAY^-O(&1E('%U;W1A(&1E(&-A
M:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,`16YD97)EYV\@25``16YD97)E
MYV\@25`@:6YD:7-P;V[M=F5L+@!%;F1E<F7G;R!)4"!F;W)A(&1O(&)L;V-O
M($-)1%(@<&5R;6ET:61O+@!6:6]L8>?C;R!D92!B;&]Q=65I;R!D92!)4`!)
M7VYS97)I<B!,:6YH82!!;G1E<P!297#Z8FQI8V$@9&$@27-LXFYD:0!!<&5N
M87,@S6-O;F5S`,UC;VYE<R!C;VT@5&5X=&\`3F]M92!D82!I9&5N=&ED861E
M.@!392!NXV\@9F]R(&UO<W1R861O(&-O<G)E8W1A;65N=&4L("5S('!A<F$@
M;R!A8G)I<B!N=6UA(&YO=F$@:F%N96QA+@!392!NXV\@=FER('%U86QQ=65R
M(.UC;VYE(&%O('5S87(@;R!);G1E<FYE="!%>'!L;W)E<BP@<&]D92!P<F5C
M:7-A<B!D92!S96QE8V-I;VYA<B!E<W1A(&-A:7AA('!A<F$@9&5S;&EG87(@
M82!T<F%N<W!A<NIN8VEA+@!392!V:7(@97-T82!M96YS86=E;2!N;6%S(&[C
M;R!A(&EM86=E;2!P<F]P<FEA;65N=&4@9&ET82P@82!I;6%G96T@<75E('!R
M971E;F1E(&-A<G)E9V%R(&[C;R!P;V1E('-E<B!M;W-T<F%D82!P96QO('-E
M=2!N879E9V%D;W(N`%!R979I<^-O(&1A($EM86=E;3H`55),(&1A(&EM86=E
M;0!54DP@9&$@:6UA9V5M.@!);6%G96T@9&4@9V%L97)I80!);6%G96T@9&4@
M9V%L97)I83H`0V%R<F5G86UE;G1O(&1A(&EM86=E;0!);6%G96YS`$EM<&]R
M=&%R+"!087-S;R`E9`!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O<R!I;7!O
M<G1A9&]S.@!);E]S97)I<B!,:6YH82!$97!O:7,`0_-D:6=O(&1E(&%CY^-O
M(&EN=')O9'5Z:61O(&5S=.$@:6YC;W)R96-T;RX`3F]M92!D92!U=&EL:7IA
M9&]R(&]U('!A;&%V<F$M<&%S<V4@97)R861O<RX`3F]M92!D92!U=&EL:7IA
M9&]R(&]U(&5N9&5R9>=O(&%L=&5R;F%T:79O(&5R<F%D;W,N($-O;G1A8W1E
M(&\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M82!P87)A(&]B=&5R(&%J
M=61A+@!!=6UE;G1A<B!A($EN9&5N=&'GXV\`4F5P^F)L:6-A(&1A(,UN9&EA
M`%5T:6QI>F%D;W)E<R!);F1I=FED=6%I<P!297#Z8FQI8V$@9&$@26YD;V[I
M<VEA`$EN9F]R;6'GXV\`26YF;W)M8>?C;P!);F9O<FUAY^-O(&KA(&[C;R!E
M<W3A(&1I<W!O;NUV96P`26YI8VEA;&EZ86YD;R!O(&WS9'5L;R`E<RXN+B``
M26YS97)I<B!#7V]L=6YA($1E<&]I<P!);G-E<FER($EM86=E;0!);G-E<FER
M(%1A8F5L80!);G-E<FER($QI9V'GXV\@X"!796(`26YS97)I<B!?0V]L=6YA
M($%N=&5S`$EN<VER:7(@=6UA(&YO=F$@8V]L=6YA(&1E<&]I<R!D82!C;W)R
M96YT90!);G-I<FER('5M82!N;W9A(&-O;'5N82!A;G1E<R!D82!C;W)R96YT
M90!);G-I<FER('5M82!N;W9A(&QI;FAA(&1E<&]I<R!D82!C;W)R96YT90!)
M;G-I<FER('5M82!N;W9A(&QI;FAA(&%N=&5S(&1A(&-O<G)E;G1E`$EN<V5R
M:7(@=6T@<&%RX6=R869O(&%P\W,@;R!N\R!C;W)R96YT90!);G-E<FER('5M
M('!A<N%G<F%F;R!A;G1E<R!D;R!N\R!C;W)R96YT90!);G-I<FER(&UO9&5L
M;R!A;'1E<FYA=&EV;P!);G1R;V1U>F$@=6T@96YD97)EYV\@9&4@8V]R<F5I
M;R!E;&5C='+S;FEC;R!O;F1E('!O<W-A(')E8V5B97(@82!N;W9A('!A;&%V
M<F$M<&%S<V4Z`$EN<VER:7(@8^EL=6QA(&%P\W,`26YS97)I<B!CZ6QU;&%S
M(&%N=&5S`$EN<V5R:7(@8^EL=6QA(&1E<&]I<P!);G-E<FER(&-O;'5N82!A
M;G1E<P!);G-E<FER(&UE;G-A9V5N<P!);G-E<FER('!A<N%G<F%F;R!A;G1E
M<P!);G-E<FER('!A<N%G<F%F;R!A;G1E<P!);G-E<FER(&QI;FAA(&1E<&]I
M<P!);G-E<FER(&QI;FAA(&%N=&5S`$EN=')O9'5Z82!A(')E<W!O<W1A(&5X
M:6=I9&$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G83H`26YS97)I<B]-
M;V1I9FEC87(@26UA9V5M`$EN<V5R:7(O36]D:69I8V%R($QI9V'GXV\`0W+I
M9&ET;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@<&%R82!A(&QI<W1A(&1E
M(&1I<W1R:6)U:>?C;RX`0W+I9&ET;R!I;G-U9FEC:65N=&4N`$EN=&5I<F\`
M3&ES=&$@9&4@:6YT96ER;W,`541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G;A
M;&ED;RX`1&%D;W,@6DE0(&EN=N%L:61O<P!!<&QI8V'GXV\@:6YVX6QI9&$N
M`$E$(&1E(&QO=&4@*")B871C:"(I(&EN=N%L:61O+@!/<R!D861O<R!S=6)M
M971I9&]S('/C;R!I;G;A;&ED;W,N`$5N9&5R9>=O(&1E(&1E<W1I;F\@:6YV
MX6QI9&\N`$9O<FUA=&\@9&\@87)Q=6EV;R!I;G;A;&ED;P!#:&%V92!D82!L
M:6-E;N=A(&EN=N%L:61A+@!,;V-A;&EZ8>?C;R!I;G;A;&ED82!E<W!E8VEF
M:6-A9&$N`&US9U]T>7!E(&EN=N%L:61O+@!A<&E?:60@:6YVX6QI9&\@;W4@
M96T@9F%L=&$N`%!A<N)M971R;W,@:6YVX6QI9&]S(&]U(&5M(&9A;'1A+@!0
M97)M:7-SXV\@<&%R96YT86P@:6YVX6QI9&$N`$E$(&1E('!A<F-E:7)O(&EN
M=N%L:61O+@!#\V1I9V\@9&4@<')O9'5T;R!I;G;A;&ED;RX`4')O=&]C;VQO
M(&EN=N%L:61O+@!$97-T:6YA=.%R:6\@:6YVX6QI9&\Z("(E<R(`3V)J96-T
M;R!D92!P87)T:6QH82!I;G;A;&ED;P!%;F1E<F7G;R!D82!O<FEG96T@:6YV
MX6QI9&\N`$1A9&]S('5N:6-O9&4@:6YVX6QI9&]S+@!);G9E;G3A<FEO`%)E
M</IB;&EC82!)<VSB;6EC82!D;R!)<N-O`%)E</IB;&EC82!D;R!)<F%Q=64`
M4F5P^F)L:6-A(&1A($ER;&%N9&$`26QH82!D92!-86X`5&5M<&]R86ES+50@
M27-O;&%D;W,`17-T861O(&1E($ES<F%E;`!%;6ES<V]R`$ETX6QI8V\`4F5P
M^F)L:6-A($ET86QI86YA`$IA;6%I8V$`2F%N96ER;P!*87#C;P!*87!O;NIS
M("A)4T\M,C`R,BU*4"D`2F5R<V5Y`%)E:6YO($AA<VAE;6ET82!D82!*;W)D
MXFYI80!*=6QH;P!*=6YH;P!*=7-T:69I8V%R`$-E;G1R87(`2G5S=&EF:6-A
M<@!*=7-T:69I8V%R(.`@17-Q=65R9&$`2G5S=&EF:6-A<B#@($1I<F5I=&$`
M4F5P^F)L:6-A(&1O($-A>F%Q=6ES=.-O`%!R97-E<G9A<B!O(&]R:6=I;F%L
M/P!297#Z8FQI8V$@9&\@477I;FEA`$\@<V5R=FED;W(@2V5R8F5R;W,@<F5J
M96ET;W4@82!A=71E;G1I8V'GXV\N`$YO=F%T;W,@;F\@(DME<FYE;"(`0W)I
M8>?C;R!D82!#:&%V90!);7!R97-SXV\@9&EG:71A;"!D82!C:&%V90!#;VUP
M<FEM96YT;R!D82!C:&%V90!4:7!O(&1A($-H879E`%5T:6QI>F'GXV\@9&$@
M0VAA=F4`02!C:&%V92!JX2!E>&ES=&4@;F\@<V5R=FED;W(@9&4@8VAA=F5S
M('#Z8FQI8V%S+@!-:?ID;W,`475I<FEB871I`%)E</IB;&EC82!0;W!U;&%R
M($1E;6]C<N%T:6-A(&1A($-O<F5I80!297#Z8FQI8V$@9&$@0V]R96EA`$-O
M<F5A;F\@*$550RU+4BD`2W5W86ET`%)E</IB;&EC82!1=6ER9W5I>F4`7T1I
M<W!O<VGGXV\`261I;VUA`%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A
M($QA;P!1=6%R=&\@1&5C<F5S8V5N=&4`475A<G1O($1E8W)E<V-E;G1E`-IL
M=&EM82!!8W1U86QI>F'GXV\Z`-IL=&EM82!E;G1R861A.B`E<P#:;'1I;6$@
M96YT<F%D83H@)7,@9&4@)7,`VFQT:6UA(&5N=')A9&$Z($YU;F-A`%)E</IB
M;&EC82!D82!,973S;FEA`$QE:0!$:7-P;W-IY^-O`$1E:7AA<B!V87II;R!P
M87)A(&9I8V%R('-E;2!B;W)D80!,[6)A;F\`17-Q=65R9&$`0V%B9>=A;&AO
M(&1A(&5S<75E<F1A`%9A;&]R97,@X"!E<W%U97)D80!,97-O=&\`3&EBZ7)I
M80!'<F%N9&4@2F%M86AI<FEY82!3;V-I86QI<W1A(%!O<'5L87(@P7)A8F4@
M9&$@3.UB:6$`3&ES=&5N<W1A:6YE`$-H=79A(")-;VQH82U4;VQO<R(`0VAU
M=FES8V]S`$-H=79I<V-O<R!-871I;F%I<P!#:'5V:7-C;W,@5F5S<&5R=&EN
M;W,`4&5Q=65N;R!!9W5A8V5I<F\`0VAU=FES8V\@8V]M(%1R;W9O861A`%%U
M961A(&1E($YE=F4`3F5V90`B3&EM97)I8VLB`$QI9V'GXV\`3&EG8>?C;R!A
M<&]N=&$@<&%R83H`3&EG87(@;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T
M<O-N:6-O(.`@<.%G:6YA(&1E(&-O;7!O<VGGXV\@86\@;6]S=')A<@!,:6=A
MY_5E<P!";VQI;FAO(&QI;G5XZG,`3&ES=&$@+2!O('5T:6QI>F%D;W(@<&]D
M92!V97(@82!P87-T80!,:7-T87(@0F%S97,@9&4@1&%D;W,`36]S=')A<B!4
M\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E;&%S`$QI<W1A9V5M+4%R<75I
M=F\`3&ES=&%G96TM06IU9&$`240@9&$@3&ES=&$`3&ES=&%G96TM1&]N;P!,
M:7-T86=E;2U3=6)M:7-S]65S`$QI<W1A9V5M+5-U8G-C<FET87,`3&ES=&%G
M96TM3N-O('-U8G-C<FET87,`02!L:7-T86=E;2!D92!U=&EL:7IA9&]R97,@
M97-TX2!D97-A8W1I=F%D82X`3&ET97)A='5R83H`4F5P^F)L:6-A(&1A($QI
M='7B;FEA`$-A<G)E9V%N9&\@8FEB;&EO=&5C87,N+BX`0V%R<F5G86YD;RXN
M+@!496UP;R!L;V-A;#H`3&]C86QI>F'GXV\@92!&=7-O($AO<N%R:6\`3&]C
M86QI>F'GXV\`16YT<F%R`%-A:7(`5&%R969A<R!D92!%;G1R861A`$$@875T
M96YT:6-AY^-O(&9A;&AO=2!P;W(@;R!.;VUE(&1E(%5T:6QI>F%D;W(@;W4@
M82!086QA=G)A+5!A<W-E(&5S=&%R96T@:6YC;W)R96-T;W,N`$$@875T96YT
M:6-AY^-O(&9A;&AO=2X`5&5X=&\@;&]N9V\`06UO<@!"86EX;P!,971R87,@
M9W)E9V%S(&UI;OIS8W5L87,`3&5T<F%S(&QA=&EN87,@;6EN^G-C=6QA<P!.
M^FUE<F]S(')O;6%N;W,@;6EN^G-C=6QO<P!,=7AE;6)U<F=O`$U-`$U/5$0`
M3R!A;F5X;R!-4RU43D5&(&[C;R!C;VYT:6YH82!D861O<RX`35-'`$UA8V%U
M`$UA8V5D\VYI82P@06YT:6=A(%)E</IB;&EC82!*=6=O<VQA=F$@9&$`36%D
M86?A<V-A<@!-86=I80!#;W)R96EO`$%D;6EN:7-T<F'GXV\@9&4@0V]R<F5I
M;P!&87IE<B!L:5]G8>?C;RXN+@!!<W-E9W5R92US92!D92!Q=64@=&5M(&\@
M4$5!4B!I;G-T86QA9&\@92!N;R!C86UI;FAO(&1E(&EN8VQU<_5E<R`H:6YC
M;'5D92!P871H*2X`0W)I86YD;R!A('!A<W1A("5S`$UA;&%U:0!-86SA<VEA
M`$UA;&1I=F%S`$UA;&D`36%L=&$`1VER82!A(&QI<W1A(&1E(&-A=&5G;W)I
M87,@<75E('!O9&4@871R:6)U:7(@86]S(&ET96YS+"!B96T@8V]M;R!A<R!C
M;W)E<R!Q=64@;&AE<R!E<W3C;R!A<W-O8VEA9&%S+@!-87!A($UA<#(T`$UA
M<&$@36%P475E<W0`36%RYV\`36%R9V5M`$UA<F-A<B!C;VUO($QI9&$O3N-O
M(&QI9&$`36%R8V%R(&1E(&]U=')A<R!F;W)M87,@*&4N9RXL($EM<&]R=&%N
M=&4O4&]R(')E<W!O;F1E<BD`26QH87,@36%R<VAA;&P`36%R=&EN:6-A`$-A
M;7!O<R!Q=64@8V]R<F5S<&]N9&5M`$UA=7)I=.)N:6$`36%U<NUC:6\`3>%X
M:6UO(&-RZ61I=&\@<&5R;6ET:61O+@!-X7AI;6\@;OIM97)O(&1E('!A<G1E
M<R!N=6UA(&UE;G-A9V5M(&5X8V5D:61O+@!496UP97)A='5R82!MX7AI;6$@
M;F%S(/IL=&EM87,@,C0@:&]R87,Z(`!496UP97)A='5R82!MX7AI;6$@;F%S
M(/IL=&EM87,@-B!H;W)A<SH@`$-O;7!R:6UE;G1O(&WA>&EM;P!-86EO`$UA
M>6]T=&4`365D:6-I;F$`365M8G)O<P!-;V1O(&1O(&UE;G4Z`%5N:7(@8^EL
M=6QA<P!);G1E9W)A;F1O('1O9&]S(&]S(&9I8VAE:7)O<R`E<RYP;R!C;VT@
M;R!C;VUPZFYD:6\N+BX`26YT96=R86YD;R!A(&QO8V%L:7IAY^-O("5S+BXN
M(`!);G1E9W)A;F1O(&\@87)Q=6EV;R!03R!D92`E<R!C;VT@;R!C;VUPZFYD
M:6\N+BX@`$EN=&5G<F%N9&\@82!T<F%D=>?C;R!D;R!M\V1U;&\@)7,N+BX`
M365N<V%G96T`365N<V%G96X@5F5R:69I8V%D82!C;VT@4W5C97-S;RP@;6%S
M(&\@8V5R=&EF:6-A9&\@9&\@<W5B<V-R:71O<B!NXV\@</1D92!S97(@=F5R
M:69I8V%D;RX`365N<V%G96T@97AP:7)O=2X`5&EP;R!D92!M96YS86=E;0!-
M971E;W)O;&]G:6$@345405(`0FQO8V\@345405(@:6YD:7-P;V[M=F5L+@!"
M;&]C;R!-151!4B!I;F1I<W!O;NUV96PN($]S('!O<FUE;F]R97,@9F]R86T@
M<F5G:7-T861O<R!P87)A(&\@861M:6YI<W1R861O<BX`02!-971A<D1"(&[C
M;R!E<W3A(&-O;F5C=&%D82X`3>ET;V1O`$\@;>ET;V1O("(E<R(@;N-O(&5S
M=.$@9&5F:6YI9&\`3>ET<FEC;P!-Z7AI8V\`36EC<F]NZ7-I82P@17-T861O
M<R!&961E<F%D;W,@9&$`0V5N=')O`%1I<&\@34E-10!496UP97)A='5R82!M
M[6YI;6$@;F%S(/IL=&EM87,@,C0@:&]R87,`5&5M<&5R871U<F$@;>UN:6UA
M(&YA<R#Z;'1I;6%S(#8@:&]R87,`17-P96QH;P!-:7-C96SB;F5A`%!A8V]T
M92!(5%107U)E<75E<W0@9&\@4$5!4B!E;2!F86QT82X`0V]N9FEG=7)AY^-O
M(&5M(&9A;'1A+B!497+A(&1E(&$@9V5R87(@86=O<F$@<V4@<75I<V5R('5S
M87(@97-T82!A<&QI8V'GXV\N`$E$(&1A(&UE;G-A9V5M(&5M(&9A;'1A+@!0
M86-O=&4@36%I;"!D;R!014%2(&5M(&9A;'1A+@!)1"!D82!S97-SXV\@96T@
M9F%L=&$N`#*J`$-O<G)E:6\@3?-V96P`36]D97)A9&\`1&%T82!D92!-;V1I
M9FEC8>?C;P!-;V1I9FEC87(@55),`$WS9'5L;P!-\V1U;&\`4F5P^F)L:6-A
M(&1A($UO;&1O=F$`4')I;F-I<&%D;R!D;R!-\VYA8V\`36]N9_-L:6$`3>IS
M(&4@86YO`$UE;G-A;&UE;G1E`$UO;G1S97)R870`1F%S92!D82!,=6$`4F5I
M;F\@9&4@36%R<F]C;W,`4V]B<F5T=61O($QI;7!O`%-O8G)E='5D;R!%;F5V
M;V%D;P!3;V)R971U9&\@4V]L87)E;F=O`$1E<V-E<@!-;W9E<B!P87)A(&$@
M17-Q=65R9&$`36]V97(@<&%R82!A($1I<F5I=&$`4W5B:7(`1&5S8V5R`%-U
M8FER`%)E</IB;&EC82!D92!-;^=A;6)I<75E`$QI<W1A<R!D92!D97-E;G)O
M;&%R(&UU;'1I+6[M=F5L`%-E;&5CY^-O(&WZ;'1I<&QA`$$@36EN:&$@0V]N
M=&$`3R!-974@4&]R=&%L`$1I<W!O<VGGXV\@9&\@4&]R=&%L`%5N:>-O(&1E
M($UY86YM87(`3N-O+"!NXV\@8V]N8V]R9&\`3F]M90!297#Z8FQI8V$@9&$@
M3F%M[6)I80!.875R=0!.97!A;`!296EN;R!D;W,@4&'M<V5S($)A:7AO<P!!
M;G1I;&AA<R!(;VQA;F1E<V%S`%523"!D92!"87-E($YE='-C87!E`%523"!D
M92!2979O9V'GXV\@0T$@3F5T<V-A<&4`55),(&-O;2!A('!O;.UT:6-A(&1E
M($-!($YE='-C87!E`%523"!D92!296YO=F'GXV\@3F5T<V-A<&4`55),(&1E
M(%)E=F]G8>?C;R!.971S8V%P90!.;VUE(&1O('-E<G9I9&]R(%-33"!.971S
M8V%P90!#;VUE;G3A<FEO(&1E(&-E<G1I9FEC861O($YE='-C87!E`%1I<&\@
M9&4@8V5R=&EF:6-A9&\@3F5T<V-A<&4`4F5D90!.=6YC80!.;W9A($-A;&5D
M\VYI80!.;W9A($-A=&5G;W)I80!,=6$@3F]V80!.;W9O($YO;64@9&4@571I
M;&EZ861O<B`H;W!C:6]N86PI`$YO=F$@6F5LXFYD:6$`3F]V82!J86YE;&$@
M*%]B;&%N:RD`3F]T[6-I87,`1W)U<&]S(&1E($YO=.UC:6%S`%!R\WAI;6$`
M4'+S>&EM87,@-"!&87-E<P!0<O-X:6UA<R!O<.?U97,`4'+S>&EM83X`4F5P
M^F)L:6-A(&1A($YI8V%RX6=U80!297#Z8FQI8V$@9&\@3NUG97(`4F5P^F)L
M:6-A($9E9&5R86P@9&$@3FEG97)I80!.;VET90!.:75E`$[C;P!.XV\@:.$@
M9&%D;W,@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV96ES(&5M(')E;&'GXV\@
M86]S('%U86ES(&UO<W1R87(@9&EF97)E;N=A<RX`3N-O(&CA(&YE;FAU;6$@
M97-T<F%TZ6=I82!D:7-P;V[M=F5L('!A<F$@<F5A;&EZ87(@:6UA9V5N<R!)
M4T\N`$[C;R!HX2!M;V1E;&\@9&4@;&]T92`B8F%T8V@B+@!.XV\@97AI<W1E
M(&)L;V-O(&YA('!O<VGGXV\@:6YD:6-A9&$`3N-O(&9O:2!F;W)N96-I9&\@
M=6T@;F]M92!D92!C86QE;F3A<FEO('!A<F$@82!A=71E;G1I8V'GXV\@34-!
M3"X`4V5M(&UO9&EF:6-AY_5E<RX`3N-O('-E('!O9&4@861I8VEO;F%R('!E
M<FUI<W/U97,@9&4@9FEL:&]S(&%B86EX;R!D97-T92!N[79E;"X`3N-O('-E
M('!O9&4@861I8VEO;F%R(&9I;&AO<R!A(&5S=&$@<&5R;6ES<^-O+@!.96YH
M=6T@8V]M86YD;R!E<W!E8VEF:6-A9&\N`$[C;R!F;VD@97-P96-I9FEC861A
M(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R82`E<RX`3N-O(&9O
M:2!E<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!P
M87)A(%9&4R!B87-E861O(&5M($944"X`3N-O(&9O:2!E<W!E8VEF:6-A9&$@
M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!N96-E<W/A<FEA('!A<F$@
M;R!61E,@8F%S96%D;R!E;2!344PN`$[C;R!F;VD@97-P96-I9FEC861A(&$@
M:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C97-SX7)I82!P87)A(&\@
M5D93(&)A<V5A9&\@96T@4U%,+49I;&4N`$-RZ61I=&\@97-G;W1O=2X`3F5N
M:'5M(&1E<W1I;F%TX7)I;R!F;VD@9F]R;F5C:61O+@!.XV\@97AI<W1E('%U
M86QQ=65R(&5N=')A9&$@8V]M(&\@:60@(B5S(B!N;R!A<G%U:79O(&1E(&%J
M=61A(&]R:6=I;F%L+@!.XV\@<V4@8V%R<F5G;W4@;F%D82X`3F5N:'5M82!L
M;V-A;&EZ8>?C;R!E<W!E8VEF:6-A9&$N`$9A;'1A(&EN9&EC87(@=6UA(&QO
M8V%L:7IAY^-O+@!!(&QO8V%L:7IAY^-O(&[C;R!F;VD@97-P96-I9FEC861A
M+@!.96YH=6UA(&UE;G-A9V5M(&9O:2!F;W)N96-I9&$N`$YE;FAU;2!N;VUE
M(&5S<&5C:69I8V%D;RX`3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A9&\N`%-E
M;2!D:71O<R!O9F5N<VEV;W,`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP
M87-S92!P87)A(&$@875T96YT:6-AY^-O($A45%`N`$[C;R!F;VD@9F]R;F5C
M:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!)34%0+@!.
MXV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I
M8V'GXV\@2V5R8F5R;W,N`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S
M<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!,1$%0+@!.XV\@9F]I(&9O<FYE8VED
M82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN`$[C
M;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC
M8>?C;R!005-35T0N`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@
M<&%R82!A(&%U=&5N=&EC8>?C;R!334(N`$[C;R!F;VD@:6YD:6-A9&\@8V%M
M:6YH;R!P87)A(&\@8FENX7)I;R!/<&5N4U-,+B!/(&)I;N%R:6\@3W!E;E-3
M3"#I(&YE8V5S<^%R:6\@<&%R82!T<F%B86QH87(@8V]M(&1A9&]S(%!+0U,@
M,3(N`$[C;R!HX2!S=6)S8W)IY_5E<R!P96YD96YT97,N`%-E;2!T<F'G;W,`
M4V5M(&QA9&]S`$[C;R!HX2!P87-T82!T96UP;W+A<FEA(&1I<W!O;NUV96P@
M<&%R82`B8V%C:&4B+@!.XV\@9F]R86T@96YV:6%D;W,@;R!N;VUE(&1O('5T
M:6QI>F%D;W(@;W4@82!P86QA=G)A+7!A<W-E+@!.XV\@9F]R86T@<F5T;W)N
M861O<R!D861O<R!E;2!834P@=N%L:61O<P!396T@=F%L;W)E<P!.XV\@9F]I
M(&5N8V]N=')A9&$@=F5R<^-O(&YA(&-O;F9I9W5R8>?C;R!O<FEG:6YA;"X@
M4F5G96YE<F%R(&-O;F9I9W5R8>?C;RX`3N-O(&9O:2!E;F-O;G1R861A('9E
M<G/C;R!N82!S=6$@8V]N9FEG=7)AY^-O+B!296=E;F5R87(@8V]N9FEG=7)A
MY^-O+@!.96YH=6UA`$YE;FAU;2`H=7-A<B!I;7!L[6-I=&\I`$[S<F1I8V\@
M*$E33RTX.#4Y+3$P*0!);&AA(&1E($YO<F9O;&L`2&5M:7-FZ7)I;R!.;W)T
M90!);&AA<R!-87)I86YA<R!D;R!.;W)T90!296EN;R!D82!.;W)U96=A`$YU
M;F-A($1E<&]I<R!D90!.=6YC82!!;G1E<R!D90!.XV\@Z2!U;2!D:7)E8W3S
M<FEO`$[C;R!I;7!L96UE;G1A9&$N`%!O<B!A=')I8G5I<@!.XV\@<W5P;W)T
M861O+@!.;W1A<P!.861A('!A<F$@;F%V96=A<BP@=F]L=&4@<&%R82!T<N%S
M+@!.;W1A`$YO=F5M8G)O`$[Z;65R;P!.^FUE<F\@9&4@8V%R86-T97)E<P!.
M^FUE<F\@9&4@8V]L=6YA<P!.^FUE<F\@9&4@;&EN:&%S`$YA(&QI<W1A(&1E
M(&1I<W1R:6)U:>?C;R!HX2!N^FUE<F]S('%U92!NXV\@9F]R86T@97-P96-I
M9FEC861O<R!P87)A(&%C='5A;&EZ8>?C;RX`3TL`3V)J96-T;P!#<FEA9&]R
M(&1O($]B:F5C=&\`4&5R;6ES<_5E<R!D;R!C<FEA9&]R(&1O(&]B:F5C=&\`
M3V-T86P`3W5T=6)R;P!&:6QT<F\@9&4@;6%T97)I86P@;V9E;G-I=F\`1V%B
M:6YE=&4`4W5L=&%N871O(&1O($]MXP!3\R!O<R!S97)V:61O<F5S($E-05`@
M<W5P;W)T86T@<&%S=&%S('!A<G1I;&AA9&%S+@!!<&5N87,@9&ET;W,@;V9E
M;G-I=F]S`%/S(.D@<&5R;6ET:61O('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@
M96QE8W1R\VYI8V\N`$%P96YA<R!O(&1O;F\@;W4@=6T@861M:6YI<W1R861O
M<B!D92!S:7-T96UA<R!P;V1E(&%L=&5R87(@82!T:71U;&%R:61A9&4@9&4@
M=6UA('!A<G1I;&AA(&]U(&%S('!E<FUI<W/U97,@9&\@<V5U(&1O;F\`06)R
M92!N=6UA(&YO=F$@:F%N96QA`$5R<F\@3W!E;E-33#H@3N-O(&9O:2!P;W-S
M[79E;"!E>'1R86ER(&1A9&]S(&1E('5M82!P87)T92!A<W-I;F%D82!C;VT@
M4R]-24U%+@!!8G)E(&5S=&$@;&EG8>?C;R!N=6UA(&YO=F$@:F%N96QA`%-I
M<W1E;6$@3W!E<F%T:79O`$]PY_5E<P!/<.?U97,@9&\@)7,`3W#G]65S.@!,
M:7-T82!/<F1E;F%D80!/<F=A;FEZ8>?C;P!5;FED861E($]R9V%N:7IA8VEO
M;F%L`$]R9V%N:7IAY^-O`$UO9&5L;R!O<FEG:6YA;"!D82!A<&QI8V'GXV\`
M36]D96QO<R!O<FEG:6YA:7,@96T@)7,Z`$]U=')O`$]U=')A<R!);F9O<FUA
MY_5E<P!097)M:7-S]65S(&1O($1O;F\`075T96YT:6-AY^-O(%!!32!NXV\@
M97-TX2!D:7-P;V[M=F5L+@!!<W-I;F%T=7)A($1I9VET86P@4$=0`$1A9&]S
M(&5N8W)I<'1A9&]S(%!'4`!#:&%V92!0^F)L:6-A(%!'4`!$861O<R!!<W-I
M;F%D;W,O16YC<FEP=&%D;W,@8V]M(%!'4`!#\V1I9V\@4$A0`$-O;6%N9&]S
M(%!(4`!#:'5V:7-C;W,@<&5L82!487)D90!!9W5A8V5I<F]S(&1E(%1A<F1E
M`$YE=F4@X"!487)D90!.97;U97,@X"!487)D90!3;VP@X"!487)D90!496UP
M;W)A:7,M5"#@(%1A<F1E`$-O;6%N9&]S(%!?2%``16YC:&EM96YT;P!297#Z
M8FQI8V$@27-LXFUI8V$@9&\@4&%Q=6ES=.-O`%)E</IB;&EC82!D92!086QA
M=0!497)R:73S<FEO(%!A;&5S=&EN:6%N;P!086YA;>$`4&%P=6$@3F]V82!'
M=6ENZ0!297#Z8FQI8V$@9&\@4&%R86=U86D`4&%R8VEA;&UE;G1E($5N8V]B
M97)T;P!086QA=G)A+5!A<W-E`%!A;&%V<F$M4&%S<V4@:6YC;W)R96-T80!0
M86QA=G)A+5!A<W-E(&YE8V5S<^%R:6$@<&%R82!A=71E;G1I8V'GXV\@4D%$
M2553`%!A;&%V<F$M4&%S<V4@8V]M(&-O;F9I<FUAY^-O`%!A;&%V<F$M4&%S
M<V4Z`%!A;&%V<F$M4&%S<V4Z(`!!<R!P86QA=G)A<RUP87-S92!TZFT@9&4@
M<V5R(&EG=6%I<RX`0V]L87(`0V]L87(@9&4@<F5C;W)T97,`0V%M:6YH;P!3
M=6)S8W)IY_5E<R!096YD96YT97,Z`%!E<W-O87,`4&5R8V5N=&%G96T`17AE
M8W5T87(@3W!E<F'G]65S(&1E($UA;G5T96[GXV\`17AE8W5T87(@;W!E<F'G
M]65S(&1E(&UA;G5T96[GXV\@87%U86YD;R!D82!E;G1R861A/P!097)M:7-S
MXV\`02!P97)M:7-SXV\@(B5S(B!NXV\@9F]I(')E;6]V:61A+@!!9&UI;FES
M=')AY^-O(&1E(%!E<FUI<W/U97,`4&5R;6ES<_5E<R!D90!);F9O<FUAY_5E
M<R!097-S;V%I<P!097+Z`$%N:6UA:7,@9&4@17-T:6UAY^-O`$9I;&EP:6YA
M<P!496QE9F]N90!&;W1O9W)A9FEA<P!);&AA<R!0:71C86ER;@!0[7AE:7,`
M4&QA=&ET=61E<P!0;W(@9F%V;W(@8VQI<75E('-O8G)E('5M82!CZ6QU;&$`
M4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM96YT92!P<F5T96YD92!R96UO
M=F5R(&5S=&4@96QE;65N=&\Z`%!O<B!F879O<B!C;VYF:7)M92!S92!R96%L
M;65N=&4@<')E=&5N9&4@9&5S;&EG87(@97-T92!E;&5M96YT;RX`4&]R(&9A
M=F]R(&EN=')O9'5Z82!U;2!MZG,@92!U;2!A;F\N`%!O<B!F879O<B!I;G1R
M;V1U>F$@;R!N;VUE(&1A(&YO=F$@8V%T96=O<FEA.@!0;W(@9F%V;W(@:6YT
M<F]D=7IA('5M(&5N9&5R9>=O($E0(';A;&ED;RX`4&]R(&9A=F]R(&EN=')O
M9'5Z82!U;6$@9&%T82!VX6QI9&$[('9E<FEF:7%U92!O(&[Z;65R;R!D92!D
M:6%S(&1O(&WJ<RX`4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@:&]R82!VX6QI
M9&$N`%!O<B!F879O<BP@9F]R;F7G82!U;6$@8G)E=F4@9&5S8W)IY^-O(&1O
M('!R;V)L96UA+@!0;W(@9F%V;W(L(&EN=')O9'5Z82!O('-E=2!.;VUE(&1E
M(%5T:6QI>F%D;W(@92!A('-U82!086QA=G)A+5!A<W-E`%!O<B!F879O<B!L
M96EA(&\@=&5X=&\@<V5G=6EN=&4N(%1E;2!D92!#3TY#3U)$05(@8V]M(&]S
M('1E<FUO<R!D97-T92!A8V]R9&\@<&%R82!U<V%R(&\@<VES=&5M82X`4&]R
M(&9A=F]R(')E<&]R=&4@;W,@97)R;W,@<&%R82!I,3AN0&QI<W1S+FAO<F1E
M+F]R9P!0;W(@9F%V;W(@:6YT<F]D=7IA(&\@;F]M92!D82!N;W9A(&-A=&5G
M;W)I83H`4&]L\VYI80!0;VSM=&EC80!3;VYD86=E;G,`4F5P^F)L:6-A(%!O
M<G1U9W5E<V$`4&]S:6-I;VYA;65N=&\@9&5S=&$@:6UA9V5M`%!O<VEC:6]N
M86UE;G1O(&1E<W1A('1A8F5L80`B4&]S="(@<&%R82!E<W1A('!A<W1A("AN
MXV\@Z2!R97%U:7-I=&\@9&\@24U!4"D`4')E8VEP:71AY^-O(&YA<R#Z;'1I
M;6%S("5S(&AO<F$H<RDZ(`!0<F]B86)I;&ED861E(&1E/&)R("\^4')E8VEP
M:71AY^-O`%!R969S7VQD87`Z($$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA
M(&[C;R!F;VD@96YC;VYT<F%D82X`4')E9G-?<V5S<VEO;CH@02!E>'1E;G/C
M;R!D92!S97-SXV\@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`%!R
M97-SXV\`4')E<W/C;R!A;R!N[79E;"!D;R!M87(Z(`!0<F5S<^-O.B``4')E
M=FESXV\`4')E=F5R(&$@:6UA9V5M(&YU;6$@;F]V82!J86YE;&$`3W#G]65S
M(&%N=&5R:6]R97,`26UP<FEM:7(@;R!D;V-U;65N=&\`0VAA=F4@4')I=F%D
M80!0<F]B;&5M80!$97-C<FGGXV\@9&\@4')O8FQE;6$`4')O:F5C=&]S`$UE
M;G-A9V5M+7!R;VYT;P!#:&%V92!0^F)L:6-A`$%L9V]R:71M;R!D92!#:&%V
M92!0^F)L:6-A`$EN9F]R;6'GXV\@4V]B<F4@82!#:&%V90!/('!A<B!D92!C
M:&%V97,@4'5B;&EC82]0<FEV861A(&[C;R!F;VD@9V5R861A(&-O;2!S=6-E
M<W-O+@!0;W)T;R!2:6-O`$5S=&%D;R!D;R!1871A<@!0961I9&\`0VAA=F4@
M4/IB;&EC82!24T$@*"5D(&)I="D`4V5L96/GXV\@(G+A9&EO(@!#:'5V80!#
M:'5V82!-871I;F%L`$-H=79A(%9E<W!E<G1I;F$`06=U86-E:7)O`$-H=79A
M(&4@3F5V90!#:'5V82!A($YE=F4`1&ET;R!!;&5A=/-R:6\`4F5L8>?C;P!,
M97(`3&5R(&UE;G-A9V5N<P!1=65R(&UE<VUO(')E;6]V97(@)7,_($5S=&$@
M;W!E<F'GXV\@;N-O('1E;2!R96=R97-S;RX`4F5M;W9E<B!M97-M;R!O<R!D
M861O<R!D;R!U=&EL:7IA9&]R("5S/R!%<W1A(&]P97)AY^-O(&[C;R!T96T@
M<F5G<F5S<V\N`%)E9F%Z(&$@<W5A(/IL=&EM82!A8^?C;P!2969R97-C87(@
M16QE;65N=&]S(&1E($UE;G4@1&ENXFUI8V\Z`%)E9G)E<V-A<B!6:7-U86QI
M>F'GXV\@9&\@4&]R=&%L.@!%>'!R97-SXV\@4F5G=6QA<@!.879E9V%D;W(@
M9&4@4F5L8>?U97,`3V)S97)V8>?U97,`4V5R=FED;W)E<R!296UO=&]S`%52
M3"!296UO=&\@*&AT='`Z+R]W=W<N97AE;7!L;RYP="]H;W)D92DZ`%)E;6]V
M97(`4F5M;W9E<B!";&]C;P!296UO=F5R(&-O;'5N80!296UO=F5R(&9O<FUA
M=&'GXV\`4F5M;W9E<B!P87(`4F5M;W9E<B!O(")S8W)I<'0B(&=U87)D861O
M(&1A('!A<W1A('1E;7!O<N%R:6$@9&\@<V5R=FED;W(N`%)E;6]V97(@;P!2
M96UO=F5R(&5S=&4@;O,@9&\@9&]C=6UE;G1O`%)E;6]V97(@571I;&EZ861O
M<@!296UO=F5R('5T:6QI>F%D;W(Z("5S`$[C;R!F;VD@<&]S<^UV96P@<F5S
M<&]N9&5R(&%O('!E9&ED;RX@0_-D:6=O(&1E(&5R<F\@9&5V;VQV:61O.B``
M3R!S97)V:>=O('!E9&ED;R!NXV\@9F]I(&5N8V]N=')A9&$N`"(E<R(@;V)R
M:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O
M(&1E("5S+@`B)7,B(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O
M(&YA(&-O;F9I9W5R8>?C;R!61E,N`"(E<R(@;V)R:6=A=/-R:6\@;N-O(&9O
M:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O+@!#86UP;R!/8G)I9V%T
M\W)I;P!,:6UP87(`4F5I;FEC:6%R(%!A;&%V<F$M4&%S<V4`4F5I;FEC:64@
M82!3=6$@4&%L879R82U087-S90!297-U;'1A9&]S`%)E<W5L=&%D;W,@*&EN
M8VQU:6YD;R!(;W)D92DZ`%)E<W5L=&%D;W,Z`%9O;'1A<B#@<R!/<.?U97,`
M4F5U;FGC;P!2179E<G1E<B!#;VYF:6=U<F'GXV\`3W#G]65S(&1E($5D:>?C
M;R!2:6-A`$%D:79I;FAA<P!$:7)E:71A`$-A8F7G86QH;R!D82!D:7)E:71A
M`%9A;&]R97,@X"!D:7)E:71A`%!R;W!R:65D861E<R!D82!,:6Y?:&$N+BX`
M4F5G<F$`4F]MZ6YI80!2;V1A<B`Q.#``4F]D87(@X"!%<W%U97)D80!2;V1A
M<B#@(&1I<F5I=&$`4')O<')I961A9&5S(&1A($QI;FAA`%!R;W!R:65D861E
M<R!D82!L:6YH80!,:6YH87,Z`%1R8>=O<P!4<F'G;W,@87!A<F5C97+C;R!E
M;G1R92!T;V1A<R!A<R!L:6YH87,@92!C;VQU;F%S`%1R8>=O<R!A<&%R96-E
M<N-O(&%P96YA<R!E;G1R92!A<R!C;VQU;F%S`%1R8>=O<R!A<&%R96-E<N-O
M(&%P96YA<R!E;G1R92!L:6YH87,`17AE8W5T87(`1F5D97)AY^-O(%)U<W-A
M`%)E</IB;&EC82!D;R!2=6%N9&$`07-S:6YA='5R82!#<FEP=&]G<N%F:6-A
M(%,O34E-10!-96YS86=E;2!%;F-R:7!T861A(&-O;2!3+TU)344`075T96YT
M:6-AY^-O(%-!4TP@:6YD:7-P;V[M=F5L+@!-96YS86=E;G,@4TU3`$-O;6%N
M9&]S(%-13`!34T@`4U5#15-33P!#;VUA;F1O<R!37U%,`'/A`%-A;G1A($AE
M;&5N80!3XV\@2VET=',@92!.979I<P!386YT82!,^F-I80!3XV\@4&5D<F\@
M92!-:7%U96QO;@!3XV\@5FEC96YT92!E($=R96YA9&EN97,`365S;6$@;6]L
M9'5R82`H7W-E;&8I`$5S=&%D;R!);F1E<&5N9&5N=&4@9&$@4V%M;V$`4F5P
M^F)L:6-A(%-E<F5N[7-S:6UA(&1E(%/C;R!-87)I;F\`4^-O(%1O;>D@92!0
M<NUN8VEP90!&;W)N96-E9&]R(&1O(%-A=.EL:71E`$%RX6)I82!3875D:71A
M`$=U87)D87(`1W5A<F1A<B`E<P!'=6%R9&%R("<E<R<`1W5A<F1A<B!/<.?U
M97,`1W5A<F1A<B!C;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@(G-C<FEP
M="(@4$A0(&YO(&1I<F5C=/-R:6\@=&5M<&]RX7)I;R!D;R!S974@<V5R=FED
M;W(N`$=U87)D96D@8V]N9FEG=7)AY^-O("5S+@!'=6%R9&5I(&\@(G-C<FEP
M="(@9&4@86-T=6%L:7IAY^-O(&5M.B`B)7,B+@!496UP;W)A:7,M5"!$:7-P
M97)S;W,`0VGJ;F-I80!0<F]C=7)A<@!-;W1O<F5S(&1E(%!R;V-U<F$`4')O
M8W5R86YD;R!A<&QI8V'G]65S("AM\V1U;&]S*2!(;W)D92!E;2`E<P!0<F]C
M=7)A;F1O(&]S(&)I;N%R:6]S(&1E(&=E='1E>'0N+BX`4V5L96-C:6]N87(@
M07)Q=6EV;W,`4V5L96-C:6]N92!U;6$@9&%T80!396QE8V-I;VYE('5M(&=R
M=7!O(&$@86-R97-C96YT87(`4V5L96-C:6]N87(@=6T@;F]V;R!D;VYO`%-E
M;&5C8VEO;F4@=6T@<V5R=FED;W(`4V5L96-C:6]N92!U;2!U=&EL:7IA9&]R
M(&$@861I8VEO;F%R`%-E;&5C8VEO;F4@=&]D;W,@;W,@8V]M<&]N96YT97,@
M9&$@9&%T82X`4V5L96-C:6]N92!U;2!O8FIE8W1O`%-E;&5C8VEO;F4@;W,@
M8V%R86-T97)E<R!N87,@8V%I>&%S(&%B86EX;RX@4&]D97+A(&5N=.-O(&-O
M<&GA+6QO<R!E(&-O;.$M;&]S(&YA(.%R96$@9&4@=&5X=&\N`%-E;&5C8VEO
M;F4@;R!D96QI;6ET861O<B!D82!D871A.@!396QE8V-I;VYE(&\@9F]R;6%T
M;R!D82!D871A.@!396QE8V-I;VYE(&$@:61E;G1I9&%D92!Q=64@<')E=&5N
M9&4@86QT97)A<CH`4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A<R!H;W)A
M<SH`4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@:&]R83H`4V5L96-C:6]N92!D
M;VES(&-A;7!O<R!R96QA8VEO;F%D;W,N`$5S8V]L:&$@;R!S974@8V]N:G5N
M=&\@9&4@8V]R97,N`%-E;&5C8VEO;F4@;R!S974@:61I;VUA('!R969E<FED
M;SH`16YV:6%R(%)E;&%T\W)I;R!D92!0<F]B;&5M87,`16YV:6%R(%--4P!2
M97#Z8FQI8V$@9&\@4V5N96=A;``@4V5N<V]R.B``4V5T96UB<F\`4^ER=FEA
M(&4@36]N=&5N96=R;P!.^FUE<F\@9&4@4^ER:64`1&%D;W,@9&\@<V5R=FED
M;W(@97)R861O<R!O=2!I;F1I<W!O;NUV96ES+@!)1"!D92!S97-SXV\@97AP
M:7)O=2X`071R:6)U:7(`17-T86)E;&7G82!O<.?U97,@<75E(&QH92!P97)M
M:71A;2!R96EN:6-I87(@82!S=6$@<&%L879R82UP87-S92!S92!A;&=U;6$@
M=F5Z(&1E;&$@<V4@97-Q=65C97(N`$5S<&5C:69I8V%R('-E<G9I9&]R97,@
M<F5M;W1O<R!Q=64@9&5S96IA(&%C961E<B!N;R!S974@<&]R=&%L+@!396QE
M8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F97)I9&\L(&\@<V5U(&9U<V\@:&]R
MX7)I;R!E(&%S('-U87,@;W#G]65S(&1E(&1A=&%S+@!%<V-O;&AA(&$@<W5A
M(&%P;&EC8>?C;R!I;FEC:6%L+"!O(&5S<75E;6$@9&4@8V]R97,L(&\@<F5F
M<F5S8V%M96YT;R!D92!PX6=I;F%S(&4@;W5T<F%S(&]PY_5E<R!D92!V:7-U
M86QI>F'GXV\N`$-O;F9I9W5R87(`(E-C<FEP=',B(&1E(&%C='5A;&EZ8>?C
M;R!D:7-P;V[M=F5I<P!6X7)I87,@;&]C86QI>F'G]65S('!O<W/M=F5I<R!C
M;VT@;R!P87+B;65T<F\Z(`!396EC:&5L97,`0V]M<')A<P!"<F5V92!3=6WA
M<FEO`$1E=F5M+7-E(&1E9FEN:7(@=&5C;&%S(&1E(&%C97-S;R!P87)A(&$@
M;6%I;W)I82!D87,@;&EG8>?U97,_`$UO<W1R87(`36]S=')A<B!D:69E<F5N
MYV%S(&5N=')E(&$@8V]N9FEG=7)AY^-O(&=U87)D861A(&4@87%U92!F;VD@
M86=O<F$@9V5R861A+@!-;W-T<F%R(&UO;65N=&\@9&$@^FQT:6UA(&5N=')A
M9&$@;F\@<VES=&5M83\`36]S=')A<B!O<.?C;R!P87)A('!R97-E<G9A<B!O
M(&]R:6=I;F%L`$UO<W1R87(@<&%L971E`$UO<W1R87(@82!B87)R82!D92!M
M96YU(&-O;2!A<R!O<&5R8>?U97,@<V]B<F4@=&%B96QA<S\`36]S=')A<B!O
M($UE;G4@)7,@X"!E<W%U97)D83\`36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO
M9V\@9&%S(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1E(%1A8F5L83\`36]S
M=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!4
M86)E;&%S`$UO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE
M9&%D97,@9&4@3&EN:&%S(&1E(%1A8F5L80!-;W-T<F%R(&$@8V%I>&$@9&4@
M9&GA;&]G;R!D87,@4')O<')I961A9&5S(&1E($EM86=E;0!-;W-T<F%R(&-A
M<G)E9V%M96YT;P!!9W5A8V5I<F]S`$%G=6%C96ER;W,@36%T:6YA:7,`06=U
M86-E:7)O<R!697-P97)T:6YO<P!!9W5A8V5I<F]S(&YA(%9I>FEN:&%NYV$`
M16YC;VQH97(`16YC;VQH82!O=2!M;W9A(&\H<RD@8FQO8V\H<RD@=FEZ:6YH
M;RAS*2!P<FEM96ER;P!397)R82!,9>-O`%-U8G-C<F5V97(`4W5B<V-R979A
M+"!S92!A:6YD82!NXV\@97-TX2!R96=I<W1A9&\`07-S:6YA='5R80!!;&=O
M<FET;6\@9&4@07-S:6YA='5R80!297#Z8FQI8V$@9&4@4VEN9V%P=7)A`%1A
M;6%N:&\`4V%L=&%R($UA;G5T96[GXV\`3N-O('!R;V-E<W-A9&\N+BX`17-L
M;W;A<75I80!297#Z8FQI8V$@9&$@17-L;W;I;FEA`$YE=F4`3F5VXV\`3F5V
M]65S`$YE=O5E<R!-871I;F%I<P!.97;U97,@5F5S<&5R=&EN;W,`06QT=7)A
M(&1E(&YE=F4Z(`!-;W-T<F%R(&5Q=6EV86QE;G1E(&YA(.%G=6$Z(`!);&AA
M<R!386QO;>-O`%-O;>%L:6$`0V%NY_5E<R!E(%!O96UA<P!396QE8^?C;R!D
M;R!S96YT:61O(&1A(&]R9&5N8>?C;P!%;F1E<F7G;R!D92!O<FEG96T`P69R
M:6-A(&1O(%-U;`!%=7)O<&$@9&\@4W5L("A)4T\M.#@U.2TS*0!'9?-R9VEA
M(&1O(%-U;"!E($EL:&%S(%-A;F1W:6-H(&1O(%-U;`!(96UI<V;I<FEO(%-U
M;`!%<W!AYV\@96YT<F4@8^EL=6QA<R!A9&IA8V5N=&5S`$5S<&'G;R!E;G1R
M92!O(&-O;G1E^F1O(&4@82!B;W)D82!D92!U;6$@8^EL=6QA`$5S<&'G861O
M<@!%<W!AYV%M96YT;P!%<W!AYV%M96YT;R!E(&5N8VAI;65N=&\`4F5I;F\@
M9&4@17-P86YH80!#;W)R96EO(&[C;R!S;VQI8VET861O`$EN<V5R:7(@0V%R
M86-T97(@17-P96-I86P`1&EV:61I<B!CZ6QU;&$`061I8VEO;F%R(&-O;'5N
M80!$:79I9&ER(&QI;FAA`$1E<W!O<G1O<P!297#Z8FQI8V$@1&5M;V-RX71I
M8V$@4V]C:6%L:7-T82!D;R!3<FD@3&%N:V$`4&%D<N-O`%-T87(@5')E:P!!
M;F\@9&4@:6[M8VEO`$5S=&%D;R!O=2!0<F]V[6YC:6$`4W1A='5S`$5S=&%D
M;R!D82!L;V-A;&EZ8>?C;R`E<RXN+B``1F]R;6%T;R!D92!A<FUA>F5N86UE
M;G1O`$5N9&5R9>=O(&1E(%)U80!287-U<F%D;P!,:7-T82!D92!C861E:6%S
M(&1E(&-A<F%C=&5R97,`4F5T:7)A<B!D;VWM;FEO(&1O(&5N9&5R9>=O`$5S
M=&EL;R!;0U-370!D;P!!<W-U;G1O`%-U8FUE=&5R`$9O:2!S=6)M971I9&\@
M<&5D:61O('!A<F$@861I8VEO;F%R("(E<R(@86\@<VES=&5M82X@3N-O('!O
M9&5RX2!E;G1R87(@96YQ=6%N=&\@;R!S974@<&5D:61O(&[C;R!F;W(@87!R
M;W9A9&\N`$EN9F5R:6]R(.`@;&EN:&$`4W5C97-S;P`B)7,B(&%D:6-I;VYA
M9&\@8V]M('-U8V5S<V\@86\@<VES=&5M82X`3&EM<&5Z82!D;R!S:7-T96UA
M(&1O<R!D861O<R!D;R!U=&EL:7IA9&]R("(E<R(@<F5A;&EZ861A(&-O;2!S
M=6-E<W-O+@!296UOY^-O(&1E("(E<R(@8V]M('-U8V5S<V\N`%)E;6_GXV\@
M9&4@(B5S(B!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+@!#;VYF:6=U<F'GXV\@
M<F5V97)T:61A(&-O;2!S=6-E<W-O+B!296-A<G)E9W5E('!A<F$@=F5R(&%S
M(&UU9&%NYV%S+@!#;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$@9W5A<F1A
M9&$@8V]M('-U8V5S<V\N`$9I8VAE:7)O(&1E(&-O;F9I9W5R8>?C;R!D92!S
M86QV86=U87)D82`E<R!G=6%R9&%D;R!C;VT@<W5C97-S;RX`(B5S(B!A8W1U
M86QI>F%D;R!C;VT@<W5C97-S;P`E<R!E<V-R:71O(&-O;2!S=6-E<W-O`%)E
M</IB;&EC82!D;R!3=63C;P!297-U;6\`3F%S8V5R(&1O(%-O;`!0]'(@9&\@
M4V]L`%-O;&%R96YG;P!.87-C97(@9&\@4V]L`$YA<V-E<B]0]'(@9&\@4V]L
M`$YA<V-E<B!D;R!3;VPZ(`!0]'(@9&\@4V]L`%#T<B!D;R!3;VPZ(`!3=7!E
M<FEO<B#@(&QI;FAA`%-U<&]R=&4`4W5R:6YA;64`07!E;&ED;P!3=F%L8F%R
M9"!E($IA;B!-87EE;@!296EN;R!D82!3=6%Z:6SB;F1I80!296EN;R!D82!3
M=>EC:6$`4W7MYV$`17)R;R!D92!S:6YT87AE(&YO<R!T97)M;W,@9&4@<')O
M8W5R80!297#Z8FQI8V$@P7)A8F4@4^UR:6$`5&5M<&]R86PM5`!496UP;W)A
M;"U4(&4@5F5N=&]S;P!496UP;W)A:7,M5`!496UP;W)A:7,M5"!-871I;F%I
M<P!!<G%U:79O(%135@!486)E;&$`4')O<')I961A9&5S(&1A(%1A8F5L80!0
M<F]P<FEE9&%D97,@9&$@=&%B96QA`$9O<FUO<V$`1F]R;6]S80!297#Z8FQI
M8V$@9&\@5&%D:FEQ=6ES=.-O`%1A;GKB;FEA`$%L=F\Z`%1A<F5F87,`3OIM
M97)O(&1E(%1E;&5F;VYE`%1E;7!E<F%T=7)A(&1A(/IL=&EM82!H;W)A.@!4
M96UP97)A='5R80!496UP97)A='5R83H@`%1E;7!E<F%T=7)A/&)R("\^*"5S
M06QT825S+R5S0F%I>&$E<RD@)F1E9SLE<P!/(&UO9&5L;R`B)7,B(&[C;R!F
M;VD@96YC;VYT<F%D;RX`061M:6YI<W1R8>?C;R!D92!-;V1E;&]S`%1E>'1O
M`$%P96YA<R!497AT;P!!;&EN:&%M96YT;R!D;R!T97AT;P!4;W!O(&1O('1E
M>'1O`#6J`%1A:6QA;F3J<R`H5$E3+38R,"D`4F5I;F\@9&$@5&%I;.)N9&EA
M`$]B<FEG861O('!O<B!U<V%R(&5S=&4@<VES=&5M82X`3R!A<G%U:79O(&1E
M(&%J=61A("5S('!A<F$@)7,@;N-O(&5X:7-T92!A:6YD82X@0W)I86YD;R!U
M;2!N;W9O+@!!(&5X=&5N<^-O($944"!NXV\@97-TX2!D:7-P;V[M=F5L+@!/
M(&5N9V5N:&\@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA8B!NXV\@<W5P;W)T
M82`B)7,B`$\@<F5G:7-T;R`H(FQO9R(I($E-4U`@;N-O('#T9&4@<V5R(&EN
M:6-I86QI>F%D;RX`02!C;&%S<V4@36%I;G1E;F%N8V4Z.B!NXV\@9F]I(&-A
M<G)E9V%D82!C;VT@<W5C97-S;P!!(&IA;F5L82!D92!/<.?U97,@9F5C:&]U
M+B!38>UN9&\N`$\@861M:6YI<W1R861O<B!T96T@9&4@8V]N9FEG=7)A<B!U
M;2!M96-A;FES;6\@9&4@<&5R;6ES<_5E<R!P97)M86YE;G1E('-E('%U:7-E
M<B!U<V%R(%!E<FUI<W/U97,N`$%P96YA<R!O(&QA9&\@:6YF97)I;W(`3R!N
M^FUE<F\@9&4@240@9&\@8V]N=&%C=&\@;N-O(&9O:2!E<W!E8VEF:6-A9&\L
M(&9O:2!D96EX861O(&5M(&)R86YC;R!O=2!NXV\@9F]I(&5N8V]N=')A9&\@
M;F$@8F%S92!D92!D861O<RX`3R!C;VYT86-T;R!F;VD@861I8VEO;F%D;R#@
M(&QI<W1A(&1E(&-O;G1A8W1O<R!C;VT@<W5C97-S;RX`3R!B;&]C;R!D92!A
M<W-I;F%T=7)A(%!'4"!D97-T86-A9&\@Z2!N96-E<W/A<FEO('!A<F$@=F5R
M:69I8V%R('5M82!M96YS86=E;2!A<W-I;F%D82X`3R!)1"!D82!L:7-T82!D
M92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&\L(&9O:2!D96EX
M861O(&5M(&)R86YC;R!O=2!NXV\@9F]I(&5N8V]N=')A9&\@;F$@8F%S92!D
M92!D861O<RX`02!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E
M8VEF:6-A9&$N`$%S(&9U;F-I;VYA;&ED861E<R!D92!E;F-R:7!T8>?C;R!E
M>&EG96T@=6UA(&QI9V'GXV\@<V5G=7)A+@!/(&%R<75I=F\@)7,@9&5V97)I
M82!C;VYT97(@=6T@871R:6)U=&\@)7,N`$\@87)Q=6EV;R`E<R!D979E<FEA
M(&-O;G1E<B!A;&=U;G,@871R:6)U=&]S("5S+@!/(&9I8VAE:7)O(&[C;R!P
M;V1E('-E<B!C;W!I861O('!A<F$@<VD@<'+S<')I;RX`3R!F:6-H96ER;R!N
MXV\@8V]N=.EM(&1A9&]S+@!!8F%I>&\@97-TXV\@;W,@8V%B9>=A;&AO<R!D
M97-T82!M96YS86=E;2]M96YS86=E;2!R9F,X,C(N`$\@;6]D;R!D92!E8W+C
M(&EN=&5I<F\@8V%U<V$@<')O8FQE;6%S(&YO($EN=&5R;F5T($5X<&QO<F5R
M+"!D979I9&\@82!E<G)O<R!N;R!N879E9V%D;W(@<75E(&[C;R!C;VYS96=U
M:6UO<R!U;'1R87!A<W-A<BX@(%!O9&4@<W5R9VER(&QI>&\L('!O9&5M(&1E
M<V%P87)E8V5R(&9U;F-I;VYA;&ED861E<R!D;R!E9&ET;W(@92]O=2!O('-E
M=2!N879E9V%D;W(@<&]D92!A8F]R=&%R+B!392!O('-E=2!S:7-T96UA(.D@
M=6T@5VEN9&]W<R`Y>"P@Z2!M=6ET;R!P<F]VX79E;"!Q=64@;V)T96YH82!U
M;2`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!E('!R96-I<V4@9&4@<F5I
M;FEC:6%R(&\@<VES=&5M82Y<;EQN1F]I(&%V:7-A9&\N("!0;W(@9F%V;W(@
M<')E<W-I;VYE($]+('-E(&%I;F1A(&%S<VEM('%U:7-E<B!E>'!E<FEM96YT
M87(@;R!E9&ET;W(@9&4@96-RXR!I;G1E:7)O+@!/(&9I8VAE:7)O(&1E(&%J
M=61A("5S(&[C;R!C;VUEYV$@8V]M(#P_>&UL`$$@:61E;G1I9&%D92`B)7,B
M(&9O:2!R96UO=FED82X`07!E;F%S(&\@;&%D;R!E<W%U97)D;P!!(&QO8V%L
M:7IAY^-O(&1O(&%R<75I=F\@97AE8W5TX79E;"!D92!';G501R!T96T@9&4@
M<V5R(&EN9&EC861A(.`@8VQA<W-E($-R>7!T7W!G<#HZ+@!!(&UE;G-A9V5M
M(&5N=FEA9&$@96T@)7,@<&%R82`E<R!C;VT@87-S=6YT;R`B)7,B(&9O:2!M
M;W-T<F%D82X*3N-O(&CA(&=A<F%N=&EA(&1E('%U92!A(&UE;G-A9V5M('1E
M;FAA('-I9&\@<F5A;&UE;G1E(&QI9&$@;W4@8V]M<')E96YD:61A+@!/(&YO
M;64@82!U<V%R('%U86YD;R!L:6=A;F1O(.`@<.%G:6YA(&1E(&-O;7!O<VGG
MXV\`3R!M\V1U;&\@;W!E;G-S;"#I(&YE8V5S<^%R:6\@<&%R82!A(&-L87-S
M92!(;W)D95]#<GEP=%]S;6EM93HZ+@!!(&]PY^-O("(E<R(@;N-O('#T9&4@
M<V5R(&=U87)D861A+"!P;VES(&]S('-E=7,@9&%D;W,@97AC961E;2!A(&1I
M;65N<^-O(&WA>&EM82!P97)M:71I9&$`3R!P<F]G<F%M82!U<V%D;R!P87)A
M('9E<B!E<W1E('1I<&\@9&4@9&%D;W,@*"5S*2!NXV\@9F]I(&5N8V]N=')A
M9&\@;F\@<VES=&5M82X`07!E;F%S(&]S(&QA9&]S(&5S<75E<F1O(&4@9&ER
M96ET;P!!<&5N87,@;R!L861O(&1I<F5I=&\`3R!S97)V:61O<B`B)7,B(&9O
M:2!R96UO=FED;RX`3R!S97)V:61O<B`B)7,B(&9O:2!G=6%R9&%D;RX`3R!P
M961I9&\@9&4@<W5B<V-R:>?C;R!D92`E<R!F;VD@<F5M;W9I9&\N`$$@;&EN
M:&$@:6YD:6-A9&$@;N-O(&5X:7-T92X`3R!A<G%U:79O('1E;7!O<N%R:6\@
M(B5S(B!NXV\@97AI<W1E+@!!<&5N87,@;W,@;&%D;W,@<W5P97)I;W(@92!I
M;F9E<FEO<@!!<&5N87,@;R!L861O('-U<&5R:6]R`$]S(&1A9&]S(&-A<G)E
M9V%D;W,@<&5R9&5R86TM<V4@9&5S9&4@;R!P87-S;R!A;G1E<FEO<BX`3R!A
M<G%U:79O(&-A<G)E9V%D;R!NXV\@</1D92!S97(@9W5A<F1A9&\N`$\@8FQO
M8V\@=V5A=&AE<BYC;VT@;N-O(&5S=.$@9&ES<&]N[79E;"X`3N-O(&CA(&]P
MY_5E<R!D:7-P;V[M=F5I<RX`3N-O(&CA('!A<G1E<R!Q=64@<&]S<V%M('-E
M<B!M;W-T<F%D87,@96T@;&EN:&$N`$CA(&1E;6%S:6%D;W,@8V%R86-T97)E
M<R!N97-T92!C86UP;RX@26YT<F]D=7II=2`E<R!C87)A8W1E<F5S.R!T96T@
M9&4@:6YT<F]D=7II<B!M96YO<R!D;R!Q=64@)7,N`$[C;R!E>&ES=&4@86EN
M9&$@=6T@87)Q=6EV;R!D92!A:G5D82!P87)A("5S+@!/8V]R<F5U('5M('!R
M;V)L96UA(&YA(&%D:>?C;R!D92`B)7,B(&%O('-I<W1E;6$Z("5S`$]C;W)R
M974@=6T@<')O8FQE;6$@86\@;&EM<&%R(&]S(&1A9&]S(&1O('5T:6QI>F%D
M;W(@(B5S(B!D;R!S:7-T96UA+@!/8V]R<F5U('5M('!R;V)L96UA(&YA(')E
M;6_GXV\@9&4@(B5S(B!D;R!S:7-T96UA+@!/8V]R<F5U('5M('!R;V)L96UA
M(&%O(&%C='5A;&EZ87(@(B5S(CH@)7,N`$AO=79E('5M('!R;V)L96UA(&-O
M;2!O(&-A<G)E9V%M96YT;R!D;R!F:6-H96ER;SH@)7,@;N-O(&9O:2!C87)R
M96=A9&\N`$]C;W)R974@=6T@<')O8FQE;6$@8V]M(&\@8V%R<F5G86UE;G1O
M(&1O(&%R<75I=F\Z($\@)7,@97AC961E(&\@=&%M86YH;R!MX7AI;6\@<&5R
M;6ET:61O("@E9"!B>71E<RDN`$]C;W)R974@=6T@<')O8FQE;6$@8V]M(&\@
M8V%R<F5G86UE;G1O(&1O(&%R<75I=F\Z($\@)7,@9F]I(&%P96YA<R!P87)C
M:6%L;65N=&4@8V%R<F5G861O+@!/8V]R<F5U('5M(&5R<F\@86\@;6]S=')A
M<B!E<W1A('!A<G1E(&1A(&UE;G-A9V5M`$]C;W)R974@=6T@97)R;R!A;R!I
M;7!O<G1A<B!D861O<R!D92!C;VYT86-T;RX`3V-O<G)E=2!U;2!E<G)O(&%O
M(&EM<&]R=&%R(&1A9&]S(&E#86QE;F1A<BX`3V-O<G)E=2!U;2!E<G)O(&YO
M(&9O<FUU;.%R:6\@9&4@8V]N9FEG=7)AY^-O+B!486QV97H@=&5N:&$@;VUI
M=&ED;R!U;2!C86UP;R!O8G)I9V%T\W)I;RX`3V-O<G)E=2!U;2!E<G)O(&%O
M(&%B<FER(&\@87)Q=6EV;R`E<RX@17AP97)I;65N=&4@97AE8W5T87(@=')A
M;G-L871I;VXN<&AP(&-O;2!A(&]PY^-O("UD('!A<F$@8V]N<V5G=6ER('9E
M<B!A<R!M96YS86=E;G,@9&4@97)R;R!D;R!A;F%L:7-A9&]R(%A-3"X`3V-O
M<G)E=2!U;2!E<G)O(&%O(')E86QI>F%R(&$@9G5NY^-O(&1E(&QI=G)O(&1E
M(&5N9&5R9>=O<R!E<W!E8VEF:6-A9&$N(%!O<B!F879O<B!T96YT92!D92!N
M;W9O(&UA:7,@=&%R9&4N`$]C;W)R974@=6T@97)R;R!A;R!A8W1U86QI>F%R
M(&]S('!O<FUE;F]R97,@9&\@8V]N=&%C=&\N(%!O<B!F879O<B!T96YT92!D
M92!N;W9O(&UA:7,@=&%R9&4N`$]C;W)R974@=6T@97)R;R!A;R!A8W1U86QI
M>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B!0;W(@9F%V;W(@=&5N=&4@
M9&4@;F]V;R!M86ES('1A<F1E+@!%<W1E('-E<G9I9&]R($E-05`@;N-O('-U
M<&]R=&$@<&%R=&EL:&$@9&4@<&%S=&%S+@!.XV\@<&%R96-E('-E<B!U;2!A
M<G%U:79O(')A<B!VX6QI9&\N`$[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@
M>FEP(';A;&ED;RX`3N-O('!A<F5C92!S97(@=6UA(&[Z;65R;R!D92!C87)T
MXV\@=N%L:61O+@!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D
M92!M96YS86=E;G,@871R87;I<R!D;R!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI+"!U<V%N9&\@82!!4$D@2%144`!%<W1E(&-O;G1R;VQA
M9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@871R87;I<R!D;R!S
M;7,R;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!U<V%N9&\@82!!4$D@
M2%144`!%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS
M86=E;G,@=FEA(%--5%`@871R87;I<R!D82!6;V1A9F]N92!)=.%L:6$@92!A
M<&5N87,@<&%R82!N^FUE<F]S(%9O9&%F;VYE+B!%>&EG92!U;6$@8V]N=&$@
M9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!N82!6;V1A9F]N92!)=.%L:6$@*&AT
M='`Z+R]W=W<N,3DP+FET*2X`17-T92!C86UP;R#I(&]B<FEG873S<FEO+@!%
M<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!I;G1E:7)O<RX`17-T92!C
M86UP;R!P;V1E(&%P96YA<R!C;VYT97(@;OIM97)O<R!E(&\@<^UM8F]L;R!D
M;VES+7!O;G1O<RX`17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L
M;W)E<R!O8W1A:7,N`$5S=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;6$@;&ES
M=&$@9&4@:6YT96ER;W,@<V5P87)A9&]S('!O<B!E<W!AYV]S(&]U(';M<F=U
M;&%S+@!%<W1E(&-A;7!O('1E;2!D92!S97(@=6T@;OIM97)O(';A;&ED;RX`
M17-T92!C86UP;R!T96T@9&4@8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@;F\@
M9F]R;6%T;R!21T(@:&5X861E8VEM86PL('!O<B!E>&5M<&QO("<C,3(S-&%F
M)RX`17-T92!M;V1E;&\@:N$@9F]I('!R;V-E<W-A9&\N`$ES=&\@Z2`E<RX`
M17-T92#I('5M(&]B:F5C=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!E
M<W1E(&]B:F5C=&\@<')E8VES82!D92!U;2!C;&EE;G1E(&1E(&-O<G)E:6\@
M96QE8W1R\VYI8V\@<75E(&-O;FAEYV$@;R!F;W)M871O($MO;&%B($=R;W5P
M=V%R92X@4&%R82!U;6$@;&ES=&$@9&4@8VQI96YT97,@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;R!N97-S87,@8VER8W5N<W3B;F-I87,@=FES:71E("5S`$5S
M=&$@;65N<V%G96T@9F]I(&5S8W)I=&$@;G5M(&/S9&EG;R`H)7,I(&1I9F5R
M96YT92!D;R!S974N`$5S=&4@;OIM97)O('!R96-I<V$@9&4@<V5R('!E;&\@
M;65N;W,@=6TN`$5S=&4@(G-C<FEP="(@=&5M('-E<B!E>&5C=71A9&\@82!P
M87)T:7(@9&4@=6UA(&QI;FAA(&1E(&-O;6%N9&]S+@!%<W1E('-E<G9I9&]R
M(&[C;R!C;VYS96=U92!D97-C;VUP<FEM:7(@87)Q=6EV;W,@>FEP(&]U(&=Z
M:7`N`$5S=&4@<VES=&5M82!E;F-O;G1R82US92!D97-A8W1I=F%D;RX`17-T
M82!V86QO<B!T96T@9&4@<V5R('5M(&[Z;65R;RX`17-T82!J86YE;&$@=&5M
M(&1E('-E<B!C:&%M861A(&$@<&%R=&ER(&1E('5M82!J86YE;&$@9&4@3W#G
M]65S`%1R;W9O861A`$)I;&AE=&5S`$1A=&$O2&]R80!396=U:6UE;G1O(%1E
M;7!O<F%L`$9O<FUA=&\@9&\@=&5M<&\`4V5L96/GXV\@9&%T82]H;W)A`%1I
M;6]R+4QE<W1E`%3M='5L;P!4[71U;&\@*&1I8V$I.@!087)A`%!A<F$@<V5L
M96-C:6]N87(@;?IL=&EP;&]S(&ET96YS+"!C87)R96=U92!E;2!#;VYT<F]L
M("A00RD@;W4@0V]M;6%N9"`H36%C*2!E;G%U86YT;R!C;&EC87(N`$AO:F4`
M5')O8V%R($9O;G1E($A434P`4F5P^F)L:6-A(%1O9V]L97-A`%1O<75E;&%U
M`$%M86YHXP!296EN;R!D;R!4;VYG80!4;W!O`$UO;&1U<F$@9&4@=&]P;R`H
M7W1O<"D`5')A9'5Z:61A<P!4<F%D=>?U97,`5')I;F1A9&4@92!4;V)A9V\`
M5F5R9&%D96ER;R!O=2!F86QS;P`SJ@!297#Z8FQI8V$@9&$@5'5N[7-I80!2
M97#Z8FQI8V$@9&$@5'5R<75I80!4=7)C;R`H25-/+3@X-3DM.2D`5'5R<75E
M;65N:7-TXV\`26QH87,@5'5R8V%S(&4@0V%I8V]S`%1U=F%L=0!%<V-R979A
M(&$@<W5A(&5S8V]L:&$Z`,UN9&EC92!5+E8N.B``55),`%523"!D;R!S974@
M<F5L873S<FEO(&1E(&5S=&%D;R!D;R!E;G9I;R!D92`B<V-R:7!T<R(`55),
M.@!297#Z8FQI8V$@9&\@56=A;F1A`%5C<N)N:6$`3N-O(&9O:2!P;W-S[79E
M;"!A8V5D97(@X"!P87-T82!61E,N`$[C;R!F;VD@<&]S<^UV96P@861I8VEO
M;F%R(&EN9F]R;6'GXV\@9&4@=71I;&EZ861O<B!E>'1R82!A<75A;F1O(&1A
M('-U8G-C<FGGXV\N`$[C;R!F;VD@<&]S<^UV96P@;75D87(@87,@<&5R;6ES
M<_5E<R!D;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&UU
M9&%R(&%S('!E<FUI<W/U97,@9&\@87)Q=6EV;R!61E,@)7,O)7,N`$[C;R!F
M;VD@<&]S<^UV96P@;75D87(@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!L
M:6=A<B!A;R!S97)V:61O<B!344PN`$[C;R!F;VD@<&]S<^UV96P@;&EG87(@
M=7-A;F1O(%-33"X`3N-O(&9O:2!P;W-S[79E;"!C;W!I87(@;R!A<G%U:79O
M(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4R`B)7,B
M+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@<&%S=&$@5D93+@!.XV\@9F]I
M('!O<W/M=F5L(&-R:6%R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV
M96P@8W)I87(@=6T@87)Q=6EV;R!61E,@=F%Z:6\N`$[C;R!F;VD@<&]S<^UV
M96P@9&5S8V]M<')I;6ER(&]S(&1A9&]S+@!.XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@(B5S(BP@<&]I<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA+@!.XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@(B5S(CH@)7,N`$[C;R!F;VD@<&]S<^UV
M96P@<F5M;W9E<B`E<RP@<&]I<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA`$[C
M;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4R!R96-U<G-I=F%M
M96YT92X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93+@!.
MXV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,Z("5S+@!.XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O(%9&4RX`3N-O(&9O:2!P
M;W-S[79E;"!R96UO=F5R(')E8W5R<VEV86UE;G1E.B`E<RX`3N-O(&9O:2!P
M;W-S[79E;"!D971E<FUI;F%R(&$@<&%S=&$@8V]R<F5N=&4N`$[C;R!F;VD@
M<&]S<^UV96P@97AT<F%I<B!O<R!P;W)M96YO<F5S(&1O(&-E<G1I9FEC861O
M`$EM<&]S<^UV96P@;&5R(&$@9&5F:6YIY^-O(&1E("5S+@!.XV\@9F]I('!O
M<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@
M86)R:7(@;R!A<G%U:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&%B
M<FER(&\@87)Q=6EV;R!61E,@<&%R82!E<V-R:71A+@!.XV\@9F]I('!O<W/M
M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@86)R
M:7(@;R!A<G%U:79O(&-O;7!R:6UI9&\N`$[C;R!C;VYS:6=O(&QE<B!O(&%R
M<75I=F\Z(`!.XV\@9F]I('!O<W/M=F5L(&QE<B!A('!A<W1A('9F<W)O;W0N
M`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@)7,@8V]M;R`E<SH@82!P87-T
M82!D92!D97-T:6YO(&KA(&5X:7-T90!.XV\@9F]I('!O<W/M=F5L(')E;F]M
M96%R(&$@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&$@
M<&%S=&$@5D93.B`E<RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!O(&%R
M<75I=F\@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@;R!A
M<G%U:79O(%9&4R`E<R\E<RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A
M<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!E>&5C=71A<B`G;6MI<V]F
M<R<N`$[C;R!F;VD@<&]S<^UV96P@8V]N=F5R=&5R(&5S=&4@9&]C=6UE;G1O
M(%=O<F0`3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!A<G%U:79O(%9&4R`B
M)7,B+@!.XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R(&\@87)Q=6EV;R!61E,@
M*&-O<'DH*2!F86QH;W4I+@!.XV\@8V]N<VEG;R!R96UO=F5R("<E<R<Z("5S
M+@!3=6)L:6YH861O`$1E<V9A>F5R($%L=&5R8>?U97,`1&5S9F%Z(&$@<W5A
M(/IL=&EM82!A8^?C;P!297-P;W-T82!I;F5S<&5R861A(&1O('-E<G9I9&]R
M(&YA(&-O;F5XXV\Z(`!297-P;W-T82!I;F5S<&5R861A(&1O('-E<G9I9&]R
M(&$Z(`!396T@8V%T96=O<FEA`%5N:6-O9&4@*%541BTX*0!%;6ER861O<R#!
M<F%B97,@56YI9&]S`%)E:6YO(%5N:61O`$5S=&%D;W,@56YI9&]S(&1A($%M
MZ7)I8V$`26QH87,@365N;W)E<R!$:7-T86YT97,@9&]S($5S=&%D;W,@56YI
M9&]S`%5N:61A9&5S`$1E<V-O;FAE8VED;P!A<&EM<V=I9"`H240@9&4@365N
M<V%G96T@9&4@05!)*2X`8VQI;7-G:60@9&5S8V]N:&5C:61O("A)1"!D92!-
M96YS86=E;2!D92!#;&EE;G1E*2X`0V]M86YD;R!D97-C;VYH96-I9&\Z("5S
M`$9O:2!F;W)N96-I9&$@=6UA(&QO8V%L:7IAY^-O(&1E<V-O;FAE8VED82X`
M3F]M92!D92!U=&EL:7IA9&]R(&]U('!A;&%V<F$M<&%S<V4@97)R861O<P!2
M96UO=F5R(&QI9V'GXV\@9&\@96QE;65N=&\@8V]R<F5N=&4`4V5M(&YO;64`
M4&]R(')A>O5E<R!D92!S96=U<F%NYV$L(")S8W)I<'1S(B!S96T@<')I=FEL
MZ6=I;R!NXV\@<&]D96T@86-E9&5R(&$@0V]R=&%R+T-O<&EA<B]#;VQA<B!P
M<F]G<F%M871I8V%M96YT92X@0V%R<F5G=64@96T@3TL@<&%R82!V97(@=6UA
M(&YO=&$@=.EC;FEC82!E;2!M;WII;&QA+F]R9R!Q=64@;&AE(&UO<W1R87+A
M(&-O;6\@875T;W)I>F%R('5M(")S8W)I<'0B(&$@86-E9&5R(&%O<R!R96-O
M<G1E<RX`4F5M;W9E<B!C;VQO<F'GXV\`17AT96YSXV\@;N-O(%-U<&]R=&%D
M80!0;W(@=')A9'5Z:7(`36]D:69I8V%R`$%C='5A;&EZ87(@)7,`06-T=6%L
M:7IA<B!U=&EL:7IA9&]R`"(E<R(@86-T=6%L:7IA9&\N`$%C='5A;&EZ86YD
M;R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@)7,N`")38W)I<'0B(&1E(&%C
M='5A;&EZ8>?C;R!R96UO=FED;RX`57!L;V%D`$-A<G)E9V%D;W,@;F\@<V5R
M=FED;W(@=&]D;W,@;W,@87)Q=6EV;W,@9&4@:6YS=&%L8>?C;R!D92!A<&QI
M8V'G]65S+@!,971R87,@;&%T:6YA<R!E;2!M86GZ<V-U;&%S`$[Z;65R;W,@
M<F]M86YO<R!E;2!M86GZ<V-U;&%S`%)E</IB;&EC82!/<FEE;G1A;"!D;R!5
M<G5G=6%I`%5T:6QI>F'GXV\Z`%5S87(@;R!#;W)R96YT93H@)7,`57-A<B!3
M4TPN`%5S87(@<V4@;R!N;VUE(&1E('5T:6QI>F%D;W(@;W4@82!P86QA=G)A
M+7!A<W-E(&9O<F5M(&1I9F5R96YT97,@;F\@<V5R=FED;W(@24U34"X`571I
M;&EZ861O<B`E<R!NXV\@97-TX2!A=71O<FES861O('!A<F$@)7,N`$%D;6EN
M:7-T<F'GXV\@9&4@571I;&EZ861O<F5S`$]PY_5E<R!D;R!5=&EL:7IA9&]R
M`%)E9VES=&\@9&4@571I;&EZ861O<F5S`$\@4F5G:7-T;R!D92!5=&EL:7IA
M9&]R97,@97-TX2!I;F%C=&EV;RX`4&5R;6ES<_5E<R!D;R!U=&EL:7IA9&]R
M`$YO;64@9&4@571I;&EZ861O<@!/($YO;64@9&4@571I;&EZ861O<B`B)7,B
M(&KA(&5X:7-T92X`3F]M92!D92!5=&EL:7IA9&]R.@!.;VUE(&1E(%5T:6QI
M>F%D;W(Z(`!5=&EL:7IA9&]R97,`571I;&EZ861O<F5S(&1O('-I<W1E;6$Z
M`%)E</IB;&EC82!D;R!5>F)E<75I<W3C;P!!('!A<W1A(%9&4R!NXV\@97AI
M<W1E+@!!=7/J;F-I80!!<R!L;V-A;&EZ8>?U97,@=N%L:61A<R!E;F-O;G1R
M861A<R!I;F-L=65M.@!686QI9&%D92X`5F%L;W(@96T@;6EN=71O<R!A('!A
M<G1I<B!D97-T92!I;G-T86YT92X`5F%L;W(@97AC961E(&\@8V]M<')I;65N
M=&\@;>%X:6UO(&1E("5S+@!686QO<F5S`%!O<W/M=F5L('9A;&]R97,@82!E
M<V-O;&AE<@!686YU871U`%9A<FGA=F5L`%9E;F5Z=65L80!697)I9FEC8>?C
M;R!F86QH;W4@+2!E<W1A(&UE;G-A9V5M('!O9&4@=&5R('-I9&\@861U;'1E
M<F%D82X`5F5R<^-O`$-O;G1R;VQO(&1E(%9E<G/U97,`06QI;FAA;65N=&\@
M5F5R=&EC86P`0V%LYV\@5F5R=&EC86P`5F5R=&EC86PZ`$UU:71O($%L=&\`
M4F5P^F)L:6-A(%-O8VEA;&ES=&$@9&\@5FEE=&YA;64`5FEE=&YA;6ET82`H
M5DE30TE)*0!6:7-U86QI>F%R("5S`%9E<B!U;6$@<.%G:6YA(&5X=&5R;F$`
M5FES=6%L:7IA<B!C;VUO("5S`$EL:&%S(%9I<F=E;G,@0G)I=.)N:6-A<P!)
M;&AA<R!6:7)G96YS($%M97)I8V%N87,`5FES:6)I;&ED861E`%9I<VEB:6QI
M9&%D93H@`%9O9&%F;VYE($ETX6QI82!V:6$@4TU44`!!5DE3`$%414['PT\A
M(2$@4D5-3U9!($\@(E-#4DE05"(@34%.54%,345.5$4@1$4@)7,N`%=A;&QI
M<R!E($9U='5N80!!=FES;P!!=FES;SH@`#2J`%!R979I<^-O(&1O(%1E;7!O
M`$1A9&]S(&UE=&5O<F]L\V=I8V]S(&9O<FYE8VED;W,@<&]R`%=E871H97(N
M8V]M`%=E8@!0X6=I;F$`4V5M86YA;&UE;G1E`$)E;2UV:6YD82AO*0!"96TM
M=FEN9&$H;RD@82`E<P!"96TM=FEN9&$H;RDL("5S`$]C:61E;G1A;"`H25-/
M+3@X-3DM,2D`3V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4V%A<F$`475E(&%P
M;&EC8>?C;R!D979E(&\@)7,@;6]S=')A<B!A</-S(&$@96YT<F%D83\`475A
M;"#I(&\@8V%R86-T97)E(&1E;&EM:71A9&]R/P!1=6%L(.D@;R!C87)A8W1E
M<F4@9&4@8VET8>?C;S\`475E(&9A<V5S`%%U92`B<&QU9VEN<R(@86-T:79A
M<B!P87)A(&$@161IY^-O(%)I8V$N`$QA<F=U<F$`3&%R9W5R82!E;2!U;FED
M861E<R!#4U,`3&%R9W5R82!D;R!-96YU("5S(.`@97-Q=65R9&$@*'1E;2!E
M9F5I=&\@;F$@<'+S>&EM82!E;G1R861A*3H`3&%R9W5R82!D82!T86)E;&$`
M56YI9&%D92!D92!L87)G=7)A`$QA<F=U<F$Z`%=I:VD`5F5N=&\`5F5N=&\@
M36%T:6YA;`!696QO8VED861E(&1O('9E;G1O(&5M(&[S<P!696YT;SH`5F5N
M=&\Z(`!386)E9&]R:6$`3&ES=&%S(&1E($1E<V5J;W,`5')A8F%L:&\`16YD
M97)EYV\@*$5M<')E9V\I`%1E;&5F;VYE("A%;7!R96=O*0!%<V-R979E;F1O
M(&%R<75I=F\@9&4@86IU9&$@86-T=6%L:7IA9&\@<&%R82`E<RX`4F5F97+J
M;F-I87,@8W)U>F%D87,`4F5S=')IY_5E<R!"X7-I8V%S(%@U,#EV,P!5=&EL
M:7IAY^-O(&1E($-H879E($5X=&5N9&ED82!8-3`Y=C,`3F]M92!!;'1E<FYA
M=&EV;R!D92!3=6IE:71O(%@U,#EV,P!)9&5N=&EF:6-A9&]R($-H879E(&1E
M(%-U:F5I=&\@6#4P.78S`$5X=&5N<_5E<R!8-3`Y=C,`04$`04%!00!-87!A
M(%EA:&]O(0!!;G5A;&UE;G1E`$GI;65N`%-I;0!3:6TL($-O;F-O<F1O`$5S
M=.$@96T@34]$3R!D92!415A4+B`@57-E(&\@8F]TXV\@6SP^72!P87)A('1R
M;V-A<B!P87)A(&\@;6]D;R!625-504PN`$[C;R!E<W3A(&%U=&5N=&EC861O
M+@!.XV\@<&]D92!T97(@;R!C87)A8W1E<F4@)UPG(&YO('-E=2!N;VUE(&-O
M;7!L971O+@!.XV\@:6YT<F]D=7II=2!U;2!E;F1E<F7G;R!D92!C;W)R96EO
M(&5L96-T<O-N:6-O(';A;&ED;RX`3N-O(&UA<&5O=2!N96YH=6T@8V%M<&\@
M9&\@87)Q=6EV;R!I;7!O<G1A9&\@<&%R82!O<R!C86UP;W,@8V]R<F5S<&]N
M9&5N=&5S(&5M("5S+@!!8V%B;W4@9&4@<V%I<BX`5&5M(&1E(&EN=')O9'5Z
M:7(@=6T@;OIM97)O(&1E('1E;&5M\W9E;"!VX6QI9&\L('/S(&-O;2!D[6=I
M=&]S+"!M87,@8V]M('5M("<K)R!O<&-I;VYA;"!P87)A(&\@<')E9FEX;R!I
M;G1E<FYA8VEO;F%L+@!496T@9&4@:6YT<F]D=7II<B!U;2!V86QO<B!VX6QI
M9&\N`%1E;2!D92!C;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!BX7-I8V\@<&%R
M82!$871A5')E92!S92!Q=6ES97(@=7-A<B!3=6)S8W)IY_5E<P!496T@9&4@
M8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8F%S92!P87)A(&\@5D93+@!$979E
M(&1E<V-R979E<B!O('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!O(')E;&%T
M\W)I;RX`5&5M(&1E(&EN=')O9'5Z:7(@;R!54DP@9&\@<F5C=7)S;R!Q=64@
M97-T82!L:6=AY^-O('-E(')E9F5R90!496T@9&4@<V5L96-C:6]N87(@=6T@
M<V5R=FED;W(@82!R96UO=F5R+@!$979E(&5S<&5C:69I8V%R(&\@=71I;&EZ
M861O<B!A(&QI;7!A<BX`1&5V92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I
M;&EZ861O<B!A(')E;6]V97(N`%1E;2!D92!E<W!E8VEF:6-A<B!O(&YO;64@
M9&\@=71I;&EZ861O<B!A(&%D:6-I;VYA<BX`5&5M(&1E(&5S<&5C:69I8V%R
M(&\@=71I;&EZ861O<B!A(&%C='5A;&EZ87(N`%1E;2!D92!E<W!E8VEF:6-A
M<B!A(&%CY^-O(&$@9&5S96UP96YH87(N`%1E;2!D92!I;G1R;V1U>FER('5M
M(&YO=F\@;F]M92!D92!C871E9V]R:6$N`%1E;2!D92!F;W)N96-E<B!U;2!N
M^FUE<F\@9&4@=&5L969O;F4@:71A;&EA;F\`02!S=6$@<V5S<^-O("5S(&5X
M<&ER;W4N(%!O<B!F879O<B!E;G1R92!D92!N;W9O+@!/('-E=2!%;F1E<F7G
M;R!D92!#;W)R96EO($5L96-T<O-N:6-O.@!/('-E=2!E;F1E<F7G;R`B1&4Z
M(@!!('-U82!);F9O<FUAY^-O`$\@<V5U(&5N9&5R9>=O($E0('!A<F5C92!T
M97(@;75D861O(&1E<V1E(&\@:6[M8VEO(&1A('-E<W/C;R`E<RX@4&%R82!G
M87)A;G1I<B!A('-U82!S96=U<F%NYV$L(&1E=F4@875T96YT:6-A<BUS92!D
M92!N;W9O+@!/(%-E=2!.;VUE`$\@<V5U(&UE8V%N:7-M;R!D92!A=71E;G1I
M8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E('5T:6QI>F%D;W)E<R!O=2!E
M<W1A(&]PY^-O(&9O:2!D97-A8W1I=F%D82!P;W(@86QG=6T@;W5T<F\@;6]T
M:79O+@!/('-E=2!M96-A;FES;6\@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O
M<G1A(&QI<W1A9V5M(&1E('5T:6QI>F%D;W)E<R!O=2!E<W1A(&]PY^-O(&9O
M:2!D97-A8W1I=F%D82!P;W(@86QG=6T@;W5T<F\@;6]T:79O+@!/('-E=2!N
M879E9V%D;W(@<&%R96-E('1E<B!M=61A9&\@9&5S9&4@;R!I;NUC:6\@9&$@
M<V5S<^-O("5S+B!087)A(&=A<F%N=&ER(&$@<W5A('-E9W5R86[G82P@9&5V
M92!A=71E;G1I8V%R+7-E(&1E(&YO=F\N`$\@<V5U(&YA=F5G861O<B!NXV\@
M<W5P;W)T82!E<W1A(&9U;F-I;VYA;&ED861E+@!/('-E=2!N879E9V%D;W(@
M;N-O('-U<&]R=&$@97-T82!O<.?C;R!D92!I;7!R97-SXV\N(%!R97-S:6]N
M92!#;VYT<F]L+T-O;6UA;F0@*R!0('!A<F$@:6UP<FEM:7(N`$9U<V\@:&]R
MX7)I;R!A8W1U86PZ`$ED96YT:61A9&4@<&%D<N-O.@!.;VUE(&-O;7!L971O
M`$$@<W5A('9E<G/C;R!D;R!G971T97AT(.D@9&5M87-I861O(&%N=&EG82P@
M;N-O('-U<&]R=&%N9&\@4$A0(&1E(&9O<FUA(&YA=&EV82X@3F5M('1O9&%S
M(&%S(&-A9&5I87,@9&4@8V%R86-T97)E<R!S97+C;R!E>'1R8>UD87,N`$$@
M<W5A(&YO=F$@<&%L879R82UP87-S92!P87)A("5S(.DZ("5S`$%S('-U87,@
M;W#G]65S(&9O<F%M(&%L=&5R861A<R!A=.D@86\@9FEN86P@9&5S=&$@<V5S
M<^-O+@!!<R!S=6%S(&]PY_5E<R!F;W)A;2!A8W1U86QI>F%D87,N`$$@<W5A
M('!A;&%V<F$M<&%S<V4@9F]I(')E8W)I861A`$$@<W5A('!A;&%V<F$M<&%S
M<V4@9F]I(')E8W)I861A+"!V97)I9FEQ=64@;R!S974@8V]R<F5I;R!E;&5C
M='+S;FEC;R!E(&5N=')E(&-O;2!A('-U82!N;W9A('!A;&%V<F$M<&%S<V4N
M`$]S('-E=7,@<V5R=FED;W)E<R!R96UO=&]S.@!*=6=O<VSA=FEA`%IA:7)E
M`%KB;6)I80!::6UB86)UZ0!::7!P>0!;17-C;VYD97(@5&5X=&\@0VET861O
M70!;4F5L873S<FEO(&1E(%!R;V)L96UA<UT@`%M-;W-T<F%R(%1E>'1O($-I
M=&%D;R`M`%M-;W-T<F%R(%1E>'1O($-I=&%D;R`M("5S(&QI;FAA<UT`6VQI
M;FAA("5S(&1E("5S70!?061M:6YI<W1R8>?C;P!?0V]N<V]L80#!<E]V;W)E
M`%]296UO=F5R($QI;FAA`%]'<G5P;W,`05]J=61A`%!R;W!R:65D861E<R!D
M82!?26UA9V5M`%]%;G1R87(`7U-A:7(`7TUO9&EF:6-A<B!,:6=AY^-O`%]/
M<.?U97,`7U!E<FUI<W/U97,`7U)E;6]V97(@3&EG8>?C;RXN+@!?0V]N9FEG
M=7)AY^-O`%!R;W!R:65D861E<R!D82!?5&%B96QA`%]5=&EL:7IA9&]R97,`
M8V]N=&%C=&]S`&]C;W)R974@=6T@97)R;SH`8V%L96YDX7)I;P!C86QM;P!C
M;&EQ=64@87%U:0!F96ET;P!F86QH;W4`9&EM:6YU:6YD;P!F:6-H96ER;P!E
M;F-O;G1R861O.B``9&\@)7,@*"5S*2#@<R`E<R`E<P!R86IA9&%S`&@Z`&AH
M`&EM961I871O`&5M(&QI;FAA`&QI;FAA<UT`17)R;R!M:VES;V9S(&-O;2!C
M\V1I9V\@)60@86\@8V]N<W1R=6ER($E33RX`;6T`;F]M90!S96T@86QT97)A
MY_5E<P!NXV\@96YC;VYT<F%D;P!NXV\@:6UP;&5M96YT861A`&%I;F1A('!O
M<B!I;7!L96UE;G1A<@!C861E<FYO(&1E(&YO=&%S`'!E<F-E;G1A9V5M`'#M
M>&5I<P!S=6)I;F1O`&UO<W1R87(@9&EF97)E;N=A<P!S;7,R96UA:6P@=FEA
M($A45%``<W,`97-TX79E;`!L:7-T82!D92!T87)E9F%S`$\@9FEC:&5I<F\@
M4$\@<&%R82!O(&QO8V%L92`E<R!NXV\@97AI<W1E+@!I;G1R;V1U>F$@82!P
M86QA=G)A+7!A<W-E(&1U87,@=F5Z97,L('!A<F$@8V]N9FER;6'GXV\`=6YI
M9FEC861O`'-E;2!N;VUE`&%C='5A;&EZ861O`'-E;&5C8VEO;F%D82!P96QO
M('5T:6QI>F%D;W(`=D-A<F0`4F5E;F,Z`'=E871H97(N8V]M````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+W!T7U!4+VAE;'`N>&UL````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S8T-@`Q,#4Q-30S,3`V,@`P,C`S-38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,2(_/@H\(2TM("1(;W)D
M93H@:&]R9&4O;&]C86QE+W!T7U!4+VAE;'`N>&UL+'8@,2XR+C$P+C$@,C`P
M-B\P-R\R-R`Q,SHU,3HP,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R
M>2!I9#TB<W5M;6%R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X8V$S,V8W
M9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U(CX*/'1I=&QE/D$@4.%G:6YA(&1O
M(%!O<G1A;#PO=&ET;&4^"B`\<&%R83X*17-T82!PX6=I;F$@9F]R;F5C92!U
M;2!B<F5V92!S=6WA<FEO(&1E('1O9&$@82!S=6$@:6YF;W)M8>?C;R!I;7!O
M<G1A;G1E+@I0;W(@97AE;7!L;RP@<&]D92!M;W-T<F%R('%U86YT87,@;65N
M<V%G96YS(&YO=F%S(&1E(&4M;6%I;"!E>&ES=&5M(&YA('-U82!)3D)/6"P@
M"F]S(&5V96YT;W,@86=E;F1A9&]S(&YO('-E=2!C86QE;F3A<FEO+"!T87)E
M9F%S(&YA('-U82!L:7-T82!D92!A9F%Z97)E<RQO<R!C86)EYV%L:&]S(&1O
M<R`*<V5R=FGG;W,@9&4@;F]T[6-I87,@<V5L96-C:6]N861O<RP@92!M=6ET
M;R!M86ES+@I-=6ET;W,@9&5S=&5S('-U;>%R:6]S(&-O;G3J;2!A=&%L:&]S
M('+A<&ED;W,@<&%R82!A<R!F=6[G]65S(&UA:7,@8V]M=6YS+"!C;VUO(&-O
M;7!O<VGGXV\*9&4@=6UA(&YO=F$@;65N<V%G96T@9&4@92UM86EL+"!C<FEA
MY^-O(&1E('5M(&YO=F\@8V%L96YDX7)I;R!D92!E=F5N=&]S(&]U('1A<F5F
M87,L(&5T8RX*("`@/"]P87)A/@H@/'!A<F$^"D]S(&-O;G1E^F1O<R!D97-T
M92!P;W)T86P@<^-O('!E<G-O;F%L:7KA=F5I<R!A=')A=NES(&1E('5M(&)O
M=.-O(&1E($QA>6]U="X*4&]R(&5X96UP;&\L('!O9&4@97-C;VQH97(@<75A
M:7,@;W,@:71E;7,@82!I;F-L=6ER(&YE<W1E('!O<G1A;"!E(&$@<W5A(&]R
M9&5M(&1E(&%P<F5S96YT8>?C;PH@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8CAC9C!A93$Y
M934W9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\=&ET;&4^5&AE($%P<&QI8V%T
M:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@I.;R!L861O(&5S
M<75E<F1O(&1A('#A9VEN82!W96(@97-TX2!A(&)A<G)A(&1E(&YA=F5G8>?C
M;RX*0VQI<75E(&YO<R#M8V]N97,@9&5S=&$@8F%R<F$@9&4@;F%V96=AY^-O
M('!A<F$@<N%P:61A(&4@9N%C:6QM96YT92!E<V-O;&AE<B`*87,@87!L:6-A
MY_5E<R!D:7-P;V[M=F5I<RX@"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M
M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT
M:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E
M/"]T:71L93X*("`@(#QP87)A/@I392!P<F5T96YD97(@<F5A;&EZ87(@;W!E
M<F'G]65S(&1E(&UA;G5T96[GXV\@;F\@;&]G:6XL('-E;&5C8VEO;F4@97-T
M82!C86EX82X*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A
M,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^
M4')E9F5RZFYC:6%S.B!-86YU=&5NY^-O.B!#;VYF:7)M87(@36%N=71E;N?C
M;SPO=&ET;&4^"B`@("`\<&%R83X*4V4@<')E=&5N9&5R(&-O;F9I<FUA<B!T
M;V1A<R!A<R!T87)E9F%S(&1E(&UA;G5T96[GXV\@86YT97,@9&4@<V5R96T@
M87!L:6-A9&%S+"!S96QE8V-I;VYE(&5S=&$@8V%I>&$N"E-E(&[C;R!S96QE
M8V-I;VYA<B!E<W1A(&-A:7AA+"!T;V1A<R!A<R!O<&5R8>?U97,@9&4@;6%N
M=71E;N?C;R!S97+C;R!R96%L:7IA9&%S(&%U=&]MX71I8V%M96YT92!S96T@
M82!O<.?C;R!D90IC86YC96QA<B!N;R!L;V=I;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*/"]H96QP/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]R;U]23R\`````````````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C(`,#$V-C<P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+W)O7U)/+TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P
M,C`T-34`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<F]?4D\O3$-?
M34534T%'15,O:&]R9&4N;6\`````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S
M-S$U`#$P-3$U-#,Q,#8R`#`R,C$Q-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````&0````<````/`,``(D```!<
M!@```````(`(```H````@0@```@```"J"```!0```+,(```(````N0@```<`
M``#""```!0```,H(```?````T`@``!$```#P"```"`````()```(````"PD`
M`!4````4"0``"@```"H)```,````-0D```<```!""0``*0```$H)```"````
M=`D```4```!W"0``$````'T)```4````C@D``"\```"C"0``#P```-,)```F
M````XPD```4````*"@``#0```!`*```%````'@H``!`````D"@``$````#4*
M```/````1@H```L```!6"@``#P```&(*```,````<@H```\```!_"@``'@``
M`(\*```A````K@H```,```#0"@``!````-0*```,````V0H```H```#F"@``
M!0```/$*```2````]PH``!`````*"P``"````!L+```0````)`L```8````U
M"P``!P```#P+```"````1`L```0```!'"P``#P```$P+```'````7`L```<`
M``!D"P``!````&P+```%````<0L```4```!W"P``!P```'T+```1````A0L`
M``@```"7"P``'@```*`+```%````OPL``"@```#%"P``*0```.X+```3````
M&`P```L````L#```$0```#@,```$````2@P```P```!/#```&@```%P,```7
M````=PP``!<```"/#```&P```*<,```?````PPP``!,```#C#```$````/<,
M```7````"`T```<````@#0``!0```"@-```A````+@T``!P```!0#0``!0``
M`&T-```#````<PT``"````!W#0``)@```)@-```,````OPT```P```#,#0``
M"````-D-```'````X@T```8```#J#0``#0```/$-```+````_PT```P````+
M#@``"@```!@.```"````(PX```8````F#@``10```"T.```P````<PX``!``
M``"D#@``'P```+4.```0````U0X```\```#F#@``!0```/8.``!;`0``_`X`
M`"@```!8$```"0```($0```%````BQ````\```"1$```!@```*$0```%````
MJ!```",```"N$```%````-(0```/````YQ````@```#W$```$0`````1```-
M````$A$``!$````@$0``"````#(1```H````.Q$```(```!D$0``!@```&<1
M```4````;A$``!````"#$0``,0```)01```2````QA$``"<```#9$0``!0``
M``$2```9````!Q(```8````A$@``$P```"@2```4````/!(``!,```!1$@``
M%````&42```3````>A(``!````".$@``$@```)\2```9````LA(``"8```#,
M$@```P```/,2```$````]Q(```\```#\$@``$@````P3```%````'Q,``!$`
M```E$P``$@```#<3```%````2A,``!H```!0$P``"0```&L3```+````=1,`
M``(```"!$P``#0```(03```=````DA,```4```"P$P``!0```+83```$````
MO!,```D```#!$P``!````,L3```'````T!,```\```#8$P``!@```.@3```B
M````[Q,```<````2%```)P```!H4```P````0A0``!0```!S%```#P```(@4
M```1````F!0``!````"J%```#P```+L4```4````RQ0``!P```#@%```&P``
M`/T4```B````&14``!L````\%0``&````%@5```5````<14``!8```"'%0``
M!@```)X5```'````I14``!8```"M%0``*````,05```%````[14```,```#S
M%0``(@```/<5```N````&A8``!0```!)%@``$@```%X6```*````<18```<`
M``!\%@``"@```(06```<````CQ8``!$```"L%@``$@```+X6```3````T18`
M``(```#E%@``!0```.@6```Z````[A8``#L````I%P``%@```&47```:````
M?!<``!$```"7%P``$0```*D7```1````NQ<```$````D`````````$X````=
M````3P```!<```!%````!P```"(`````````30```"$`````````2P```&(`
M```*````$0`````````,````,@```%,````Q`````````"4```!&````70``
M``````!2````0@```%4`````````1P```"P````O````5@```%$````U````
M$`````@````^````00```%\````K````#P```#D```!*````(P```!@````S
M````0````"@```!@````"P``````````````5```````````````/0````D`
M````````+@```$@```!<````.@`````````.`````````%D`````````-@``
M```````;````/P```!P````:````#0```#L`````````!`````4`````````
M$@`````````3`````````%<````M`````````"8``````````````!4````&
M`````````%L````W````&0````````!>`````````#@````T`````````$D`
M```?````6@```$0`````````'@``````````````8P````````!8````*0``
M```````P```````````````\````9````%``````````%@```"``````````
M`P```&$```!#````*@```"<```!,`````@`````````4`````"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`04TO
M4$T`061D('!A:7(`061D<F5S<P!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N
M9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I
M;F1O=P!#;VUP86YY`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`
M17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M>`!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0@2&5L
M<"!4;W!I8W,`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L
M9',`365S<V%G90!-;VYT:&QY`$YA;64`3F5V97(`3F]T97,`3W!T:6]N<P!/
M=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER`%)E
M='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE
M;2!297!O<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3=6-C97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%52
M3`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57-E
M<B!/<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A
M<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@
M8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA
M=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M
M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M5F5R
M<VEO;CH@2$]21$4@,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U
M.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP."TP,2`P.3HS-"LP
M,CHP,`I,87-T+51R86YS;&%T;W(Z($-O<FYE;&EU($U54T%4(#QC;75S871`
M:V5Y<WES+G)O/@I,86YG=6%G92U496%M.B!23TU!3DE!3B`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:70*`"5S($]P97)A=&EU;FD@9&4@;65N=&5N86YT
M82`M($-O;F9I<FUA<F4`,C0@9&4@;W)E`$%-+U!-`$%D875G82!P97)E8VAE
M80!!9')E<V$`06QI87,`4RUA('-P96-I9FEC870@;R!V86QO87)E(&EN8V]R
M96-T82X`0VEM<'5R:2!D:7-P;VYI8FEL93H`6FEU82!D92!N87-T97)E`$-A
M;&5N9&%R`%)E;G5N=&$@;&$@4F%P;W)T`%1E;&5F;VX@36]B:6P`26YC:&ED
M92!F97)E87-T<F$`0V]M<&%N:6$`3G4@<&]T(&1E<V-H:61E(&UO9'5L=6P@
M9&4@365N=&5N86YT82`E<P!:6@!::6QN:6,`261E;G1I=&%T92!);7!L:6-I
M=&$`1&5S8W)I92!P<F]B;&5M80!$971A;&EI(&EN<F5G:7-T<F%T92!I;B!,
M3T<@<&5N=')U(&%D;6EN:7-T<F%T;W(N`$]P=&EU;FD@9&4@069I<V%R90!4
M92!R;V<@;G4@86-C97-A(&1I<F5C="!M86EN=&5N86YC92YP:'``16UA:6P`
M16UP='D@<F5S=6QT+B`M(&1E('1R861U<P!%<F]A<F4`3R!D871A(&QA(#$U
M(&UI;G5T90!/(&1A=&$@;&$@,S`@<V5C=6YD90!,82!F:65C87)E(#4@;6EN
M=71E`$QA(&9I96-A<F4@0V]N96-T87)E`$\@9&%T82!L82`S,"!M:6YU=&4`
M26X@9FEE8V%R92!M:6YU=`!%>&5M<&QE(&1E('9A;&]R:3H`3G4@<&]T(&-I
M=&D@<')E9F5R:6YT96QE+@!.=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U
M;"!D92!,1$%0+@!&87@`2&5L<`!!9')E<V$@9&4@86-A<V$`5&5L969O;G5L
M(&1E(&%C87-A`$AO<F1E`$-I;7`@:6UP;W)T870Z("5S`$-I;7!U<FD@:6UP
M;W)T871E.@!,:6UB80!,:7-T82!S=6)I96-T96QO<B!D:6X@2&5L<`!#;VYE
M8W1A<F4`1&5C;VYE8W1A<F4`3$P`0V]R97-P;VYD96YT80!#:6UP=7)I('!O
M=')I=FET92`M(&1E('1R861U<P!-97-A:@!,=6YA<@!.=6UE`$YI8VEO9&%T
M80!.;W1E`$]P=&EU;FD`06QT92!I;F9O<FUA=&EI`%!A<F]L80!%>&5C=71A
M($]P97)A=&EU;FEL92!D92!-96YT96YA;G1A`%1E;&5F;VX`5&4@<F]G('-P
M96-I9FEC82!U;B!S=6UA<B!A;"!P<F]B;&5M96DN`%1E(')O9R!I;G1R;V1U
M('5N(&YU;64@9&4@=71I;&EZ871O<B!S:2!O('!A<F]L80!$97-C<FEE<F5A
M('!R;V)L96UE:0!3=&5R9V4@<&5R96-H96$`26YA<&]I(&QA(&]P=&EU;FD`
M4F]L92`M(&1E('1R861U<P!386QV87IA($]P=&EU;FD`1&5L:6UI=&%T;W(@
M9&4@9&%T83H`1F]R;6%T=6P@9&4@869I<V%R92!A(&1A=&5I.@!&;W)M871U
M;"!D92!A9FES87)E(&$@;W)E:3H`4V5L96-T96%Z82!D;W5A(&-I;7!U<FD@
M<&]T<FEV:71E+@!396QE8W1E87IA(&QI;6)A('!R969E<F%T83H`5')I;6ET
M92!287!O<G0@9&4@17)O87)E`%-A<FD@<&5S=&4@365N=&5N86YT80!#87)A
M8W1E<F4@4W!E8VEA;&4@+BXN`%-U8V-E<P!387)C:6YI`%9A;&]A<F5A(&UI
M;FEM82!E<W1E(#$`06-E87-T82!V86QO87)E('1R96)U:64@<V$@9FEE(&YU
M;65R:6-A+@!4:71L=0!54DP`3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R
M=6P@4U%,+@!.=2!P;W0@=')A9'5C92!A8V5S="!D;V-U;65N="!7;W)D("T@
M9&4@=')A9'5S`$%N=6QE87IA(%-C:&EM8F%R:6QE`$]P=&EU;FD@571I;&EZ
M871O<@!5=&EL:7IA=&]R`$%T96YT:64`4V%P=&%M:6YA;`!":6YE(&%I('9E
M;FET(&EN('-I<W1E;75L("5S`$)I;F4@86D@=F5N:70L("5S`$%D<F5S82!L
M82!397)V:6-I=0!496QE9F]N(&QA(%-E<G9I8VEU`$%!`$%N=6%L`%1R96)U
M:64@<V$@9&5S8W)I:2!P<F]B;&5M82!I;F%I;G1E(&1E(&$@=')I;6ET92!R
M87!O<G1U;"X`4V5S:75N96$@=&$@9&4@)7,@82!E>'!I<F%T+B!492!R;V<@
M<V$@9F%C:2!,;V<@26X@9&EN(&YO=2X`26YF;W)M871I:2!D97-P<F4@=&EN
M90!/<'1I=6YI;&4@874@9F]S="!S86QV871E+@!;4F%P;W)T(%!R;V)L96UA
M70!;;&EN:6$@)7,@9&EN("5S70!V0V%R9"`M(&1E('1R861U<P``````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R=5]252\`````````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-C(`,#$V-S`T`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+W)U7U)5+TQ#7TU%4U-!1T53+P``````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,C`T-S$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O<G5?4E4O3$-?34534T%'15,O:&]R9&4N
M;6\``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0R,S<U`#$P-3$U-#,Q,#8R
M`#`R,C$S-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#>$@25`````",!```<````-`D``(4!``!,$@```````&`8```H````
M81@```X```"*&```#@```)D8```(````J!@```4```"Q&```$P```+<8```#
M````RQ@```D```#/&```"````-D8```D````XA@```<````'&0``#`````\9
M```L````'!D```X```!)&0``!0```%@9```7````7AD```H```!V&0``#P``
M`($9```C````D1D``!0```"U&0``%P```,H9```7````XAD``!\```#Z&0``
M"P```!H:```5````)AH``#D````\&@``+````'8:```J````HQH``!$```#.
M&@``"````.`:```.````Z1H```H```#X&@``"`````,;```&````#!L``!4`
M```3&P``%0```"D;```*````/QL``%0```!*&P``1````)\;```3````Y!L`
M`!P```#X&P``#````!4<```0````(AP```<````S'```'0```#L<```I````
M61P```8```"#'```$````(H<```3````FQP```P```"O'```*````+P<```"
M````Y1P```4```#H'```!````.X<```-````\QP``!`````!'0``!@```!(=
M```8````&1T``!0````R'0``+P```$<=```)````=QT``!8```"!'0``#P``
M`)@=```F````J!T``$,```#/'0``"````!,>```+````'!X```0````H'@``
M"@```"T>```7````.!X``!$```!0'@``!0```&(>```-````:!X``"````!V
M'@``!0```)<>```0````G1X```\```"N'@``$````+X>```/````SQX```L`
M``#?'@``#P```.L>```,````^QX```\````('P``!@```!@?```>````'Q\`
M`"$````^'P```P```&`?```$````9!\```P```!I'P``!P```'8?```0````
M?A\```X```"/'P```@```)X?```-````H1\```8```"O'P``$0```+8?```'
M````R!\```0```#0'P``"@```-4?```B````X!\```4````#(```!`````D@
M```,````#B````H````;(```!0```"8@```*````+"````\````W(```$```
M`$<@```&````6"````\```!?(```$@```&\@```0````@B```!````"3(```
M!P```*0@```(````K"````X```"U(```%@```,0@```1````VR````8```#M
M(```$````/0@```/````!2$```@````5(0``!@```!XA```'````)2$```4`
M```M(0``"P```#,A```"````/R$```0```!"(0``:````$<A```/````L"$`
M``H```#`(0``!P```,LA```'````TR$```L```#;(0``"0```.<A```)````
M\2$```H```#[(0``!P````8B```)````#B(```<````8(@``"@```"`B```6
M````*R(```0```!"(@``!0```$<B```,````32(```0```!:(@``!````%\B
M```,````9"(```(```!Q(@``"0```'0B```$````?B(``!,```"#(@``!0``
M`)<B```"````G2(```<```"@(@``#@```*@B```*````MR(``!$```#"(@``
M"````-0B```)````W2(```H```#G(@``'@```/(B```H````$2,```H````Z
M(P``"P```$4C```4````42,```4```!F(P``*0```&PC```H````EB,``"D`
M``"_(P``$````.DC```'````^B,``!,````")```!````!8D```'````&R0`
M`!X````C)```%````$(D```.````5R0``"H```!F)```!@```)$D```,````
MF"0```L```"E)```!0```+$D```1````MR0``!@```#))```!````.(D```$
M````YR0```P```#L)```!@```/DD```/`````"4```H````0)0``"P```!LE
M```:````)R4``!<```!")0``)P```%HE```7````@B4``!L```":)0``&0``
M`+8E```?````T"4``!,```#P)0``/P````0F```W````1"8``%<```!\)@``
M!0```-0F```-````VB8``"T```#H)@``!````!8G```E````&R<``!\```!!
M)P``'0```&$G```&````?R<```0```"&)P``$````(LG```3````G"<``!<`
M``"P)P``!@```,@G```'````SR<```8```#7)P``!P```-XG```T````YB<`
M`!4````;*```#@```#$H```%````0"@```D```!&*```(0```%`H```?````
M<B@``!\```"2*```,````+(H```O````XR@``"$````3*0``'````#4I```'
M````4BD```L```!:*0``!0```&8I```"````;"D``%D```!O*0```P```,DI
M```@````S2D``"0```#N*0``)@```!,J```,````.BH```<```!'*@``!@``
M`$\J```R````5BH```0```")*@``#````(XJ```(````FRH```D```"D*@``
M"@```*XJ```'````N2H``!D```#!*@``!P```-LJ```#````XRH```8```#G
M*@``#0```.XJ```+````_"H``"\````(*P``#````#@K```Q````12L``#\`
M``!W*P``#````+<K```*````Q"L```(```#/*P``!@```-(K```#````V2L`
M`!D```#=*P``10```/<K```P````/2P``!(```!N+```$P```($L```0````
ME2P```D```"F+```%P```+`L```6````R"P```\```#?+```'P```.\L```4
M````#RT``!`````D+0``#P```#4M```/````12T```<```!5+0``!0```%TM
M```(````8RT```@```!L+0``#````'4M```&````@BT```8```")+0``!```
M`)`M```'````E2T```4```"=+0``6@$``*,M```E````_BX```H````D+P``
M"@```"\O```'````.B\```4```!"+P``#@```$@O```(````5R\```D```!@
M+P``#0```&HO```8````>"\```4```"1+P``#@```)<O```S````IB\```H`
M``#:+P``"0```.4O```,````[R\```H```#\+P``"0````<P```>````$3``
M`!,````P,```!P```$0P```6````3#```",```!C,```"@```(<P```)````
MDC```$(```"<,```)````-\P```J````!#$```\````O,0``#0```#\Q```*
M````33$```H```!8,0``"0```&,Q```&````;3$``!@```!T,0``$0```(TQ
M```4````GS$``"$```"T,0``/@```-8Q```4````%3(``!@````J,@``#```
M`$,R```+````4#(```@```!<,@``%0```&4R```J````>S(```<```"F,@``
M%0```*XR```)````Q#(```T```#.,@``(@```-PR```"````_S(```D````"
M,P``!`````PS```1````$3,``!0````C,P``!P```#@S```9````0#,``!``
M``!:,P``-@```&LS```'````HC,``"8```"J,P``$````-$S```L````XC,`
M`$$````/-```"0```%$T```,````6S0```X```!H-```#0```'<T```5````
MA30```D```";-```!0```*4T```2````JS0``"X```"^-```!@```.TT```/
M````]#0```\````$-0``$````!0U```.````)34``!0````T-0``#@```$DU
M```-````6#4``!````!F-0``"0```'<U```C````@34``"4```"E-0``!```
M`,LU```$````T#4```D```#5-0``!P```-\U```9````YS4```8````!-@``
M!P````@V```.````$#8```8````?-@``!0```"8V```)````+#8```D````V
M-@``"0```$`V```T````2C8```8```!_-@``!@```(8V```.````C38``!``
M``"<-@``!@```*TV```-````M#8``!````#"-@``#````-,V```(````X#8`
M``X```#I-@``%@```/@V```3````#S<```P````C-P``"0```#`W```$````
M.C<``!<````_-P``)P```%<W```?````?S<```4```"?-P``&0```*4W```+
M````OS<```P```#+-P``!````-@W```%````W3<```X```#C-P``!````/(W
M```"````]S<```4```#Z-P``,@`````X```0````,S@```L```!$.```"0``
M`%`X```*````6C@```D```!E.```$````&\X```1````@#@``!(```"2.```
M$0```*4X```0````MS@``!$```#(.```#@```-HX```/````Z3@```,```#Y
M.```!P```/TX```/````!3D```<````5.0``!0```!TY```2````(SD```,`
M```V.0``#0```#HY```+````2#D``!(```!4.0``!P```&<Y```"````;SD`
M``D```!R.0``$0```'PY```*````CCD``!$```"9.0``!@```*LY```&````
MLCD```8```"Y.0``(````,`Y```T````X3D```4````6.@``#0```!PZ```&
M````*CH```<````Q.@``(0```#DZ```C````6SH``#(```!_.@``$P```+(Z
M```)````QCH``!$```#0.@``!@```.(Z```(````Z3H``",```#R.@``%0``
M`!8[```0````+#L``"<````].P``!P```&4[```,````;3L```P```!Z.P``
M"````(<[```6````D#L``!\```"G.P``"````,<[```)````T#L``!,```#:
M.P``!0```.X[```/````]#L```L````$/```#@```!`\```@````'SP``!4`
M``!`/```'P```%8\```D````=CP``!X```";/```$P```+H\```0````SCP`
M`!P```#?/```30```/P\``!%````2CT``$P```"0/0``"@```-T]```2````
MZ#T``"8```#[/0``"````"(^```I````*SX``"(```!5/@``&0```'@^```&
M````DCX```8```"9/@``%````*`^```/````M3X``!,```#%/@``!@```-D^
M```$````X#X```8```#E/@``!P```.P^```H````]#X``"(````=/P``%```
M`$`_```&````53\```P```!</P``%````&D_```4````?C\``!<```"3/P``
M-P```*L_```K````XS\``"<````/0```(````#=````'````6$```!(```!@
M0```"0```'-````$````?4```$,```""0````P```,9````F````RD```"0`
M``#Q0```*P```!9!```2````0D$```8```!500``"0```%Q!``!(````9D$`
M``P```"O00``%@```+Q!```0````TT$``!````#D00``$````/5!```+````
M!D(``!4````20@``"````"A"```#````,4(```L````U0@``%0```$%"```4
M````5T(``"4```!L0@``!````))"```Q````ET(``#H```#)0@``#0````1#
M```/````$D,```(````B0P``"````"5#```"````+D,``!0````Q0P``2```
M`$9#``!!````CT,```H```#10P``%@```-Q#```/````\T,```D````#1```
M#`````U$```9````&D0```D````T1```'@```#Y$```1````740``!8```!O
M1```$0```(9$```*````F$0```8```"C1```!@```*I$```%````L40```D`
M``"W1```!0```,%$```*````QT0```P```#21```!P```-]$```/````YT0`
M``4```#W1````0```%H`````````E`````````!<``````````T!```*`0``
MZP```,,````;`````````-4```!U```````````````_`````````-<`````
M````10```*,````+````EP```)4```"O````%0`````````'`0``(P$``-,`
M``!+````L0````````!*````]````#(````Z````9@```(<````\````&@$`
M``````#1````?@````````"%````)@```*````"-````@````&0`````````
MF````/8`````````"`````````#9`````````$\`````````9P```'L`````
M`````````(P```!?`````P$``+X```"D````(`````````#2````@@``````
M````````;P```'8```!>````@0```#@`````````NP```%<````/`0``````
M`$<```">````#````&H```"G`````````!T!``"U````Q@```.D`````````
M```````````$`0``&P$```````#0````O0```-H````>`0``M@```!<`````
M`0``[P```!D!```Q````'@```'@```!-````[0```!,!``!6````%````&$`
M``#\`````````.X`````````$````&,`````````*````,(`````````,```
M`!@!`````````````)(````]``````````````!1````F0```%@````A````
M`@$``.0````:````K````#,````5`0``-@````````#=`````````+D````.
M`0``;````'T```"X````#@```%L````<`0````````````!=````3@```-@`
M````````=````/4``````````````)L`````````Y0```!`!````````%P$`
M`'(````I````B0```)H````2````\````)T```#$````R@````D!``"1````
M`````!T```"W````E@```'````!2````)P```/<```"I````XP````8!````
M````````````````````Z````.(````@`0``@P```!\```#/````U````),`
M``!&``````````,```#-````8@```"4```"E````:0```'\`````````A@``
M`,P`````````*@``````````````QP```)\````^````!0````````!W````
M.0```(0```#X````0P```"X```#)````Q0`````````O`````````/H`````
M````;@```+0```#^`````````!\!```4`0``&`````D```"S`````````%0`
M``".``````````````"K````8````*@```!Q````_0```*H```#Y````\0``
M`&L```#?````W``````````3````!P````@!```M``````````````#A````
M```````````*````$0$``%````"_`````````!8!``#[````[````-L`````
M````#0```-8``````````````"0`````````YP```+````#_````!````(@`
M```"````(@$``",`````````X````$0```!)````4P```',```"M````G```
M`*(````/`````````(L`````````B@`````````1````;0``````````````
MP0```-X````6````"P$``$(```!(````'````,X```"/````L@``````````
M`````````!D````[````60`````````W``````````4!``"0````?````$P`
M``!Y````Y@````````"A````O````&4```!H````(@```"$!````````\P``
M`%4```!Z`````````*X`````````\@````````!`````!@````P!```2`0``
M-````````````````````*8```#`````+````"L```#+````-0````````!!
M````R````.H````````````````````!`0```````+H`````)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`Q,B!(;W5R($9O<FUA
M=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!32]030!!8V-O=6YT($EN9F]R
M;6%T:6]N`$%D9`!!9&0@2&5R93H`061D('!A:7(`061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9')E<W,`061D<F5S<R!";V]K`$%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D
M;6EN:7-T<F%T:6]N`$%L:6%S`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;&]W('-E='1I;F<@;V8@;W)D
M97)E9"!L:7-T('1Y<&4_`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07!P;&EC871I;VX`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`079A:6QA8FQE(&9I96QD<SH`
M0FER=&AD87D`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!#86QE;F1A<@!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A=&5G;W)I97,@86YD($QA
M8F5L<P!#96QL(%!H;VYE`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@96UA:6QS+@!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VQO<V4@
M5VEN9&]W`$-O;&QA<'-E(%-I9&5B87(`0V]M<&%N>0!#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#<F5A=&4`0W)E871E(&$@;F5W(&]N90!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-U<G)E;G0@5&EM90!#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N`$1$`$1A:6QY`$1A=&4`1&5F875L="!#
M;VQO<@!$969A=6QT($ED96YT:71Y`$1E;&5T90!$96QE=&4@<V5L96-T960@
M:61E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@)7,`161I=`!%9&ET($)L;V-K
M`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5M
M86EL`$5M<'1Y(')E<W5L="X`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@
M;65N=3\`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AP86YD`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$9I;&4`1FEL92!-86YA
M9V5R`$9I;'1E<G,`1G5L;"!$97-C<FEP=&EO;@!';&]B86P@3W!T:6]N<P!'
M;P!';V]G;&4@4V5A<F-H`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!(96%D
M97)S`$AE;'``2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z`$AO7VUE`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]R9&4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN9&EV:61U86P@57-E<G,`3&%?>6]U=`!,
M86YG=6%G90!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S
M`$QA<W0@;&]G:6XZ($YE=F5R`$QA>6]U=`!,:7-T($AE;'`@5&]P:6-S`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!487-K<P!-30!-86EL`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA=&-H:6YG(&9I
M96QD<P!-96YU(&UO9&4Z`$UE<W-A9V4`36]N=&AL>0!-;V]N(%!H87-E<P!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!U<`!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`
M3F%M90!.979E<@!.97<@0V%T96=O<GD`3F5W<P!.97AT`$YE>'0@;W!T:6]N
M<P!.;P!.;R!V86QU97,`3F]N90!.;W)T:&5R;B!(96UI<W!H97)E`$YO=&5S
M`$]+`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)G86YI>FEN9P!/=&AE<B!)
M;F9O<FUA=&EO;@!087-S=V]R9`!087-S=V]R9#H`4&%S<W=O<F0Z(`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VYS
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4')E=FEO=7,@;W!T:6]N<P!0<F]B;&5M`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4F5A9`!2969R97-H`%)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296UO=&4@
M4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@<&%I<@!297-E=`!2
M971U<FX@=&\@3W!T:6]N<P!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4F]L
M90!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L96-T(&$@<V5R=F5R`%-E
M;&5C="!A;&P`4V5L96-T(&YO;F4`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N
M9"!0<F]B;&5M(%)E<&]R=`!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`
M4V5T=7``4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU
M(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAR:6YK`%-I
M>F4`4VMI<"!-86EN=&5N86YC90!3;W5T:&5R;B!(96UI<W!H97)E`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-T871U<P!3=6)J96-T`%-U8FUI=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U;G)I<V4O4W5N
M<V5T`%1A<VMS`%1E>'0@3VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+@!4:6-K971S`%1I;64@9F]R;6%T`%1I=&QE`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%523`!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N9FEL960`57!D871E`%5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N`%5S97(`57-E<B!/<'1I;VYS`%5S97)N86UE`%5S97)N86UE.@!5<V5R
M;F%M93H@`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!787)N
M:6YG`%=E8@!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T
M(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7
M:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+@!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EE<P!9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%
M;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA
M=&EO;@!9;W5R($YA;64`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D
M969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!;4')O
M8FQE;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`
M7T=R;W5P<P!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`
M7U-E='5P`%]5<V5R<P!E9&ET`'5N;F%M960`=D-A<F0`4')O:F5C="U)9"U6
M97)S:6]N.B!(;W)D92!V,RXQ+5)#,PI297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M,BTP-R`Q,3HQ,"LP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,3<@
M,3<Z,#`K,#(P,`I,87-T+51R86YS;&%T;W(Z($%L97AE>2!:86MH87)O=B`\
M8F%B97)`;6]S9V$N;F5T/@I,86YG=6%G92U496%M.B!2=7-S:6%N(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U,0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@#.[^7PX/;H_R#O[N3DY?#FZN@@)7,@+2#/
M[N3RXN7PYN3E[>CE`#$R+??@\>[B[ND`,C0M]^#Q[N+NZ0`R-"#WX/'@`$%-
M+U!-`-/WY?+MX/\@Y^#OZ/'\`,3NX>#BZ/+\`,3NX>#BZ/+\.@#$[N'@XNCR
M_"#OX/#S`,3NX>#BZ/+\($UO>FEL;&$@4VED96)A<@#`Y/#E\0#`Y/#E\>W@
M_R#J[>CCX`#-X/'R\.[IZN@@+2#S\?+@[>[BZN`@[_#@XB#DZ_\@Y/#SX^CU
M(._NZ_SG[N+@\N7KY>D`T^_PX.+KY>WHY0#/\>7BY.[MZ.P`PO'E(.+N^.7D
M^.CE`,+QY2#C\//O[_L`PO'E(._PX.+@`-#@Y_#E^.CR_"#N[^7PX/;HZ"#Q
M[B#Q[^CQZN#LZ`#`Z_SRY?#MX/+HXNW[Z2!)4TU0`,_@\.[K_#H`R.S_(._N
MZ_SG[N+@\N7K_R!)4TU0.@#!^^ON(//JX.?@[>X@[>7J[O#PY>KR[>[E(.?M
MX/?E[>CE+@#/\.CK[N;E[>CE`,W@\?+P[N7M[@#'X._PX/CHXN#R_"#O[N3R
MXN7PYN3E[>CE(._E\.7D(.+[[^[K[>7MZ.7L(.[OY?#@]NCI(.[A\>OSYNCB
MX.WH_S\`S^[O^_+JX"#SY.#KZ/+\(.WE\?/YY?'RXO/^^>CE(._PX.+@`,_N
M[_ORZN`@\.7DX.KRZ/#NXN#R_"#MY?'S^>7Q\N+S_OGHY2#O\.#BX`#$[O'R
M\^_M^^4@[^[K_SH`Q.7M_"#P[N;DY>WH_P#-X/'R\.[IZN`Z`-#@\?CH\.7M
MZ.4`RN#KY>WDX/#\`,[R[.7MX`#.\NSE[>`@[O+WY?+@(.X@[_#NX>OE[.4`
MRN#RY>/N\.CH(.@@[.7RZN@`RNOE\N[W[>#_(/#@Y.CN\>+_Y_P`S>#Q\O#N
MZ>KH(.CLY>WH+"#@Y/#E\>`L(._NY._H\>@N`,[R[.7R_/+E(/3KX.;JX.SH
M(.[OY?#@]NC^*.CH*2P@ZN[R[O#[Y2#"^R#U[O+H\N4@[O'S^>7Q\N+H\OPN
M`,+[X>7PZ/+E(._PZ.ONYN7MZ.4Z`-3N\.S@\B#N\N[A\.#FY>WH_R#DX/+[
M.@#'X.KP^_+\(.[J[>X`T^'PX/+\(.SE[?X`RN[L[^#MZ/\`RN[M].CC\_#@
M]NC_(//Q\N#PY>O@`,WE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N
M8V5?5&%S:R`E<P#1[N?DX/+\`-'NY^3@\OP@[>[B^^D@[_#N].CK_`#1[N?D
MX/+EZ_P`TN7J\_GEY2#B\.7L_P#'X.3@]^@L(.?@[_/QZN#E[/OE(._PZ"#B
M]>[DY2#B("5S`,3$`,7FY>3MY>+M[@#$X/+@`-;BY?(@[^X@\^SNZ_?@[>C^
M`,_P[O3HZ_P@[^X@\^SNZ_?@[>C^`-/DX.OH\OP`T^3@Z^CR_"#B^^'PX.WM
M^^D@[_#N].CK_`#.[^CXZ/+E(._P[N'KY>SS`,_NY/#NX>WN\?+H(.'[Z^@@
MY^#OZ/'@[?L@XB#F\_#MX.L@Y.O_(.#D[.CMZ/'R\.#R[O#@+@#*X/+@Z^[C
M`,[R[N'PX.;@\OP@XO#E[/\@XB`R-"WWX/'NXN[L(/3N\.S@\N4_`,3P\^/H
MY2#MX/'R\.[IZN@`S>4@XOOG^^+@Z?+E(&UA:6YT96YA;F-E+G!H<"#MY>_N
M\?#EY/'RXN7M[>X`PB#OY?#B[ND@\?+P[NKE(//JX.?@[?L@Z.SE[>`@[^[K
MY>D_(,7QZ^@@Y.`L(._N\?+@XOSRY2#CX.ON]^KS.B``Q^#C\//GZ/+\`,?@
MX_#SY^CR_"`E<P#0Y>3@ZO+H\.[BX.WHY0#0Y>3@ZO+H\.[BX/+\`-/Q\N#M
M[N+JX"#O\.#B(.3K_R`E<P#-X/'R\.[IZN@`16UA:6P`S?/KY>+NZ2#PY>?S
MZ_SRX/(N`,KN[?+EZO'R[>[E(.SE[?X@[^X@[>#FX/+HZ"#O\.#B[ND@ZNWN
M[^KH(.S[^.@`SOCHX>K@`,K@YN3[Y2`Q-2#LZ.WS\@#*X.;D^^4@,B#LZ.WS
M\OL`RN#FY/OE(#,P(/'EZO/MY`#*X.;D^^4@-2#LZ.WS\@#*X.;D^^D@\.#G
M(._PZ"#B]>[DY0#*X.;D^^4@[^[K]^#QX`#*X.;D\_X@[.CM\_+S`,_PZ.SE
M\"#G[>#WY>WHZ3H`T.#Q^.CPZ/+\`,+N\?'RX.WNXNOE[>CE(.W@\?+P[N7J
M(.WE(//DX.ON\?PN`,WE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@
M3$1!4"X`U.#J\0#4X.GK`-7PX.WHZ^CYX`#4Z.O\\O#[`,_NZ^WNY2#N[^CQ
MX.WHY2#O\.[AZ^7L^SH`S^[P\N#K`,_E\.7I\N@`S^[H\>H@XB!';V]G;&4`
MP_#S[^_[`,/N\?+\`,?@X^[K[N+JZ`#/[N3QZN#GZN``S^[K\_C@\.CE`,WH
MYN4@[_#EY/'RX.+KY>W@(.CM].[P[.#VZ/\@Z.<@\>#L[N/N(.W@]^#KX"#T
MX.GKX#H`S^[P\N#K`,_N\/+@ZP#$[NS@^.WHZ2#@Y/#E\0#$[NS@^.WHZ2#R
MY>OE].[M`,_N\/+@ZP#2[NO\ZNX@Z.KN[>KH`,CJ[NWJZ"#Q(/+EZO'R[NP`
MR.S_(._P[O3HZ_\Z`,K@\/+H[>KH`,CL[^[P\BP@^.#C("5D`,CL[^[P\NCP
M[N+@[>X@[^[KY3H@)7,`R.SO[O#RZ/#NXN#M^R#O[NO_.@#/[NO\Y^[BX/+E
MZ^@`T.#QZNO@Y.K@`-_G^^H`S_#EY/OD\_GHZ2#B]>[D(.'[ZSH@)7,`S_#E
MY/OD\_GHZ2#B]>[D(.'[ZSH@)7,@\2#J[NSO_/[RY?#@("5S`,_PY>3[Y//Y
MZ.D@XO7NY"#MY2#GX/3HZO'H\.[BX.T`POOU[N0`T>_H\>[J(/#@Y^3EZ^[B
M(._NY/'JX.?JZ`#+[NK@Z^CGX/;H_P#0X/'O[NONYN7MZ.4`PO7NY`#"^_7N
MY`#3]^7R[>#_(.?@[^CQ_`#"]>[D`,S,`,_N]_+@`,W@\?+P[NGJX"#Q[^CQ
MZN`@ZN#RY>/N\.CI(.@@]N+E\N[B(.CU(.[R[N'PX.;E[>C_`-'NXN_@Y.#^
M^>CE(._NZ_\`T.7FZ.P@[.7M_CH`T>[NX?GE[>CE`,7FY>SE\?_W[>X`U.#G
M^R#+\^W[`._E\.7LY?'RZ/+\(.+MZ.<`[^7PY>SE\?+H\OP@XNOEXNX`[^7P
MY>SE\?+H\OP@XN_PX.+N`._E\.7LY?'RZ/+\(.+BY?#U`._E\.7LY?'RZ/+\
M(.+MZ.<`[^7PY>SE\?+H\OP@XN+E\/4`T_?E\NW@_R#GX._H\?P`PN#XX"#H
M[?3N\.S@]NC_`,CL_P#-Z.KNX^3@`,WNXN#_(.K@\N7C[O#H_P#-[N+N\?+H
M`,3@Z^7E`-'KY>3S_OG@_R#Q\O#@[>CVX`#-Y?(`S>4@[N_PY>3EZ^7M[@`M
M[>4@XOOA\.#M+0#1Y>+E\.WNY2#O[NOS^.#PZ.4`Q^#LY?+JZ`!/2P#-X/'R
M\.[IZN@`S>#Q\O#NZ>KH(.3K_SH@)7,`SO#CX.W@Z>?E\`#/\.[WX/\@Z.WT
M[O#LX/;H_P#/X/#NZ_P`S^#P[NO\`,_@\.[K_`#.\?/YY?'RXNOE[>CE(.[O
MY?#@]NCI(._NY.3E\.;JZ`#"^^_NZ^WH\OP@[N_E\.#VZ.@@[N'QZ_/FZ.+@
M[>C_(._PZ"#B]>[DY2#B(/'H\?+E[/,_`,_PX.+@`,_PX.+@(.3N\?+S[^``
MR^CW[?OE`-+EZ^7T[NT`PN+EY.CRY2#MX.?BX.WHY2#M[N+NZ2#JX/+EX^[P
MZ.@Z`,_NYN#K\^GQ\N`L(/'N[N'YZ/+E(/'S\OP@[_#NX>OE[/LN`,_NYN#K
M\^GQ\N`L(.+BY>3H\N4@PN#XZ"#H[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\
M`,_PY>3[Y//YX/\@\?+PX.WH]N``S_#NX>OE[.`_`,[OZ/'@[>CE(._P[N'K
MY>S[`-?H\N#R_`#.X>WNXNCR_`#.X>WNXNO_\OP@Y.CMX.SH]^7QZNCE(._S
M[>KR^R#LY>W^.@#.X>WNXNO_\OP@Z.WT[O#LX/;H_CH`S^[W\N[B^^4@\>7P
MXN7PX`#`Y/#E\2#QY?#BY?#@("CMX._PZ.SE\"!H='1P.B\O;6%I;"YR=2D`
MT^3@Z^CR_`#3Y.#KZ/+\(.'K[NH`T^3@Z^CR_"#OX/#S`-'A\.[QZ/+\`,+E
M\.WS\OSQ_R#J(.W@\?+P[NGJX.P`S>#Q\O#NZ>KH(.+HY_/@Z_SM[N/N(/#E
MY.#J\N[PX`#1]N7MX/#HZ0#1[O7PX.WH\OP`T>[U\.#MZ/+\(.W@\?+P[NGJ
MZ`#/[NCQZ@#"^^'E\.CRY2#QY?#BY?``POOA\.#R_"#B\>4`SO+LY>WH\OP@
MXOOA[O``POOAY?#H\N4@\.#GY.7KZ/+EZ_P@[^[KY>D@Y.#R^SH`POOAY?#H
M\N4@].[P[.#R(.3@\OLZ`,+[X>7PZ/+E(._P[O3HZ_P@Y.O_(.W@\?+P[NGJ
MZ#H`POOAY?#H\N4@[O+NX?#@YN7MZ/\@].[P[.#R(.+PY>SE[>@Z`,+[X>7P
MZ/+E(.3BX"#Q[N+OX.3@_OGH]2#O[NO_+@#"X/C@(/;BY?+NXN#_(/'UY>S@
M`-_G^^H@[O+NX?#@YN7MZ/\`S^[QZ^#R_"#Q[N[A^>7MZ.4@[B#O\.[AZ^7L
MY0#$[N_NZ^WH\N7K_.W[Y2#O[O?R[N+[Y2#QY?#BY?#@+"#J(.KN\N[P^^P@
MXOL@]>[RZ/+E(.CLY?+\(.3N\?+S[R#HYR#/[O#RX.O@+@#3\?+@[>[BZN`@
M_^?[ZN`@XOOB[N3@+"#B\.7LY>WM[ND@Y^[M^R#H(/3N\.S@\N`@[O+NX?#@
MYN7MZ/\@XO#E[.7MZ"X`T_'RX.WNXNK@(._PZ.ONYN7MZ/\@[^X@\^SNZ_?@
M[>C^+"#VXN7R[N+NZ2#Q]>7L^R#H(._P[O?H]2#N[_;HZ2#N\N[A\.#FY>WH
M_P#/\.CK[N;E[>C_`,KPX/+J[N4@[N'NX?GE[>CE.@#.[_#EY.7KZ/+\(.'[
M\?+P^^4@ZNO@XNCXZ"#DZ_\@\?'[Z^[J/P#/[NK@Y^#R_`#/[NK@Y_OBX/+\
M(.CM].[P[.#VZ/X@[B#O\.7D^^3S^>7L(.+U[N3E/P#/[NK@Y^#R_"#LY>W^
M(.[OY?#@]NCI(/$@\N#AZ^CVX.SH`,[R[N'PX.;@\OP@[.7M_B`E<R#QZ^7B
MX#\`T?/GZ/+\`-#@Y^SE\`#/\.[O\_'RZ/+\(._NY.3E\.;J\P#>YNWNY2#O
M[NOS^.#PZ.4`T>_E]NC@Z_SM^^4@\>CLXN[K^P#1\N#R\_$`TN7LX`#(\>K@
M\OP`T_'OY?CM[@#1\N#PX/\@ZN[M].CC\_#@]NC_(/'N]?#@[>7MX"#B(/3@
MZ>LZ("5S`,WNXN#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@XCH@)7,`PO#E
M[/\@XN[Q]>[DX"_GX.K@\N``Q^#DX/?H`-+NZ_SJ[B#RY>KQ\@#1Y?#BY?`@
M)7,@X?OK(//DX.OE[0#1Y?#BY?`@)7,@X?OK(/'NY^3@[0#-Y?(@Y.[Q\O/O
M[?OU(.W@\?+P[N7J+@#1[N[A^>7MZ.4@XB#MY>+E\.WN["#T[O#LX/+E(.@@
M[>4@[.[FY?(@X?OR_"#N\N[A\.#FY>WN`,[XZ.'JX"#O\.@@[O+NX?#@YN7M
MZ.@@_?+NZ2#WX/'RZ"#Q[N[A^>7MZ/\`W?+N(/?H\>ON(.WE(.SNYN7R(.'[
M\OP@[.7M_/CE(.7DZ.WH]OLN`-WR[B#G[>#WY>WHY2#D[NOF[>X@X?OR_"#W
MZ/'K[NPN`,?@[_#N\?L`U.[P[.#R(.[R[N'PX.;E[>C_`,?@X^[K[N+NZ@#*
M[NSS`-?R[N'[(.+[X?#@\OP@[>7QZN[K_.KN(/WKY>SE[?+NXBP@\^3E\.;H
MXN#I\N4@[>#FX/+NZ2#JZ^#BZ.;S($-T<FP`55),`,WEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN`,WEXN[G[.[F[>X@Y^#C\//GZ/+\
M(.[O\.7DY>OE[>CE("5S+@#=\N[R(.3NZO/LY>WR(%=O<F0@[>4@[.[FY?(@
MX?OR_"#OY?#EXN7DY>TN`,[R[.7MZ/+\(.CG[.7MY>WH_P#/\_'R[ND`S_#H
M[.7MZ/+\`,CQ[^[K_.?SY?+Q_R#E\>OH(.+@^.@@Z.S_+^_@\.[K_"#DZ_\@
M24U34"#QY?#BY?#@(.[RZ^CWX/[R\?\@[O(@\N7J\_GH]0#/[NO\Y^[BX/+E
MZ_P`S>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_P#([/\@[^[K_.?NXN#RY>O_`,CL
M_R#O[NO\Y^[BX/+EZ_\`R.S_(._NZ_SG[N+@\N7K_P#/\.[Q[.[R\"`E<P#/
M[NK@Y^#R_"#BY>$M\?+PX.WH]O,`PNWH[.#MZ.4`PN7A`,7FY>WEY.7K_.WN
M`,3NX?#N(._NYN#K[N+@\OP@XB`E<P#$[N'P[B#O[N;@Z^[BX/+\+"`E<P#7
M\NX@[O+NX?#@YN#R_"#O[O'KY2#B]>[DX"#B(/'H\?+E[/,Z`-3@Y^``RN#J
MZ.4@[N_VZ.@@X?/D\_(@Y.[Q\O/O[?L@XB#BZ.?SX.O\[>[L(/#EY.#J\N[P
MY0#8Z/#H[>`@[.7M_B`E<R#QZ^7BX"`HX?/DY?(@[_#H[.7MY>W@(._PZ"#Q
MZ^7D\_[YY>P@XO7NY.4I`-#@X>[WZ.D@X.3PY?$`T.#A[O?HZ2#RY>OE].[M
M`,/#`,7FY>/NY.WN`,3@`,+[(.+[^.OH(.CG(/'H\?+E[/LN`,+[(.3NZ^;M
M^R#N[^CQX/+\(._P[N'KY>S[+"#O\.7FY.4@]^7L(/'L[N;E\N4@[O+N\>O@
M\OP@\>[NX?GE[>CE(.X@[>7I+@#"X/C@("5S(/'E\?'H_R#GX.KN[??HZ^#Q
M_"X@S^[FX.OSZ?'RX"P@XN[IY.CRY2#B(/'H\?+E[/,@Y^#M[N+N+@#"X/@@
M16UA:6PZ`,+@^"#@Y/#E\2#N\N_PX.+H\N7K_SH`PN#XX"#H[?3N\.S@]NC_
M`,+@^.4@Z.S_.@#7X/'NXN[I(._N__$`PN#X(._P[O3HZ_P@[^X@\^SNZ_?@
M[>C^.@#"X/CE(.CL_SH`PN#XZ"#MX/'R\.[IZN@@X?OKZ"#NX>WNXNOE[?LN
M`-'R[O#N[>WHZ2#QY?#BY?`Z`%O1[N[A^>7MZ.4@[B#O\.[AZ^7LY5T`6_'R
M\.[JX"`E<R#HYR`E<UT`T^_PX.+KY>WHY0##\//O[_L`S^[L[OG\`,+[]>[D
M`,W@\?+P[NGJZ`#/\.#BX`#/\.CK[N;E[>C_`,_NZ_SG[N+@\N7KZ`#/\.#B
MZ/+\`/+EZO'R(/'N[N'YY>WH_P!V0V%R9```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O<G5?4E4O:&5L<"YX;6P`````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,Q,#8R`#`R,#,U,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]R=5]252]H96QP
M+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$S(&IA;B!%>'`@)"`M+3X*
M/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I
M=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O
M<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U
M<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI
M9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H
M879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A
M;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S
M(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N
M>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO
M<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I
M;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A
M<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@
M8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE
M('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A
M;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A
M;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S
M:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@
M<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO
M;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E
M(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO
M;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO
M;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@
M=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-
M86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L
M9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O
M;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K
M<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F
M="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@
M;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL
M>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-K
M7U-++P``````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,38V-C(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O<VM?4TLO3$-?34534T%'15,O````````````````
M`````````````````````````````````````````````````#`P-#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R`#`R,#0T
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S:U]32R],0U]-15-3
M04=%4R]H;W)D92YM;P``````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,#0Q-S,`
M,3`U,34T,S$P-C(`,#(R,3$S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````8P<``!P````T.P``V0D``$QV````
M````L)T```X```"QG0``#P```,"=```-````T)T```@```#>G0``"P```.>=
M```,````\YT```0`````G@``&`````6>```;````'IX``"T````ZG@``'0``
M`&B>```D````AIX``"D```"KG@``&0```-6>```F````[YX```P````6GP``
M)````".?```/````2)\```L```!8GP``#@```&2?```%````<Y\``"@```!Y
MGP``"````**?```*````JY\``!4```"VGP``$@```,R?```+````WY\``(4`
M``#KGP``#@```'&@```*````@*````T```"+H```#@```)F@```1````J*``
M``T```"ZH```#````,B@```-````U:````8```#CH```E````.J@```*````
M?Z$```\```"*H0``&````)JA```,````LZ$```X```#`H0``#@```,^A```(
M````WJ$```D```#GH0``+@```/&A```:````(*(``#(````[H@``.````&ZB
M``!4````IZ(``%$```#\H@``6@```$ZC``!7````J:,``#0````!I```"0``
M`#:D```-````0*0```<```!.I```"@```%:D```/````8:0```4```!QI```
M!@```'>D```1````?J0```@```"0I```"0```)FD```)````HZ0``"4```"M
MI```(````-.D```3````]*0``!`````(I0``#P```!FE```*````*:4```,`
M```TI0``#P```#BE```4````2*4```D```!=I0``#0```&>E```2````=:4`
M`!D```"(I0``'@```**E```/````P:4```H```#1I0``#P```-RE```(````
M[*4``"0```#UI0``%````!JF```6````+Z8```@```!&I@``3@```$^F```M
M````GJ8``!D```#,I@``!P```.:F```,````[J8``"P```#[I@``#@```"BG
M```#````-Z<```L````[IP``!P```$>G```'````3Z<```4```!7IP``!0``
M`%VG```*````8Z<```,```!NIP``%P```'*G```*````BJ<```\```"5IP``
M#@```*6G```8````M*<``",```#-IP``#@```/&G```4`````*@``!<````5
MJ```%P```"VH```7````1:@``!,```!=J```#P```'&H```.````@:@``!\`
M``"0J```'0```+"H```'````SJ@```8```#6J```"````-VH```/````YJ@`
M``8```#VJ```"@```/VH```3````"*D```L````<J0``$````"BI```5````
M.:D``!4```!/J0``!P```&6I```0````;:D```4```!^J0``$0```(2I```,
M````EJD``#L```"CJ0``.````-^I```)````&*H```<````BJ@```P```"JJ
M```%````+JH``!`````TJ@``"0```$6J```3````3ZH``#D```!CJ@``)P``
M`)VJ```L````Q:H``"H```#RJ@``)0```!VK```*````0ZL```8```!.JP``
M"0```%6K```'````7ZL``"\```!GJP``-P```)>K```N````SZL``%4```#^
MJP``+0```%2L```M````@JP``#T```"PK```/P```.ZL```M````+JT``$``
M``!<K0``(P```)VM```C````P:T``$````#EK0``+0```":N```S````5*X`
M`"4```"(K@``%0```*ZN```9````Q*X``"D```#>K@``)`````BO```H````
M+:\``!$```!6KP``"@```&BO```,````<Z\```H```"`KP``$````(NO```6
M````G*\``!8```"SKP``!P```,JO```'````TJ\```H```#:KP``"````.6O
M```G````[J\```@````6L```!P```!^P```'````)[````8````OL```!0``
M`#:P```'````/+````8```!$L```"````$NP```I````5+````X```!^L```
M"@```(VP```$````F+````<```"=L```"0```*6P```&````K[```!$```"V
ML```!P```,BP```6````T+````0```#GL```"````.RP```&````];````T`
M``#\L```!@````JQ```>````$;$``!$````PL0``"````$*Q```-````2[$`
M``P```!9L0``!P```&:Q```#````;K$```,```!RL0``%P```':Q```3````
MCK$``!T```"BL0``"````,"Q```$````R;$```@```#.L0``"````->Q``!!
M````X+$``!H````BL@``*P```#VR```@````:;(``!4```"*L@``!@```*"R
M```&````I[(``!4```"NL@``&````,2R```B````W;(``"X`````LP``'0``
M`"^S```A````3;,``%0```!OLP``*0```,2S```*````[K,```<```#YLP``
M%0````&T```.````%[0```H````FM```#P```#&T```-````0;0```\```!/
MM```#0```%^T```)````;;0```8```!WM```&````'ZT```3````E[0``!$`
M``"KM```%````+VT```$````TK0```8```#7M```%````-ZT``!4````\[0`
M`&0```!(M0``!````*VU```.````LK4```4```#!M0``!0```,>U```3````
MS;4``!$```#AM0``$0```/.U```<````!;8``"H````BM@``$````$VV```A
M````7K8```4```"`M@``$P```(:V```+````FK8``!(```"FM@``"@```+FV
M```/````Q+8```T```#4M@``$0```.*V```3````]+8```P````(MP``!@``
M`!6W```,````'+<```8````IMP``%P```#"W```0````2+<``!$```!9MP``
M"````&NW```%````=+<```P```!ZMP``$````(>W```%````F+<```T```">
MMP``!@```*RW```'````L[<```T```"[MP``!P```,FW```+````T;<```<`
M``#=MP``!P```.6W```)````[;<```D```#WMP``"@````&X```9````#+@`
M`#T````FN```'0```&2X```,````@K@``!````"/N```!0```*"X```E````
MIK@``!(```#,N```$P```-^X```K````\[@``#L````?N0``(````%NY```(
M````?+D``#8```"%N0``(0```+RY```0````WKD```@```#ON0``#````/BY
M```&````!;H```0````,N@``#P```!&Z```.````(;H```H````PN@``#0``
M`#NZ```?````2;H``!P```!IN@``(0```(:Z```>````J+H``!D```#'N@``
M'@```.&Z```=`````+L``!L````>NP``(````#J[```N````6[L``"8```"*
MNP``'````+&[```>````SKL``!P```#MNP``)@````J\```K````,;P``#,`
M``!=O```)@```)&\```K````N+P``#@```#DO```'0```!V]```5````.[T`
M`"\```!1O0``(````(&]```2````HKT``"D```"UO0``'@```-^]```@````
M_KT``!(````?O@``H@```#*^```6````U;X``",```#LO@``*````!"_```I
M````.;\``"@```!COP``'P```(R_```5````K+\``"````#"OP``)0```.._
M```H````"<```"T````RP```,````&#```"2````D<```"$````DP0``%@``
M`$;!```<````7<$``"8```!ZP0``*@```*'!``!!````S,$``$0````.P@``
M#````%/"```'````8,(```<```!HP@``!@```'#"```-````=\(``!````"%
MP@``$@```);"```3````J<(``!(```"]P@``!P```-#"```$````V,(``!``
M``#=P@``$````.["```,````_\(```X````,PP``#0```!O#```/````*<,`
M`!,````YPP``#0```$W#```H````6\,```,```"$PP``#0```(C#```&````
MEL,```X```"=PP```@```*S#``!)````K\,```4```#YPP``$````/_#```/
M````$,0```0````@Q```#0```"7$```.````,\0```,```!"Q```#@```$;$
M```(````5<0```\```!>Q```#P```&[$```'````?L0```T```"&Q```$```
M`)3$```-````I<0```L```"SQ```!@```+_$```+````QL0```P```#2Q```
M"@```-_$```1````ZL0``!D```#\Q```"P```!;%```-````(L4``"(````P
MQ0``&P```%/%```T````;\4```H```"DQ0``&````*_%```9````R,4``!8`
M``#BQ0``(@```/G%```-````',8```<````JQ@``%````#+&```+````1\8`
M`"(```!3Q@``+P```';&```+````IL8```D```"RQ@``&0```+S&```+````
MUL8``!<```#BQ@``%P```/K&```)````$L<``!8````<QP``#P```#/'```9
M````0\<``!8```!=QP``#@```'3'```8````@\<```@```"<QP``#0```*7'
M```F````L\<``$,```#:QP``"````![(```2````)\@``!\````ZR```"```
M`%K(```+````8\@``"\```!OR```#@```)_(```%````KL@```8```"TR```
M`P```+O(```'````O\@```0```#'R```"@```,S(```*````U\@```\```#B
MR```$````/+(```7`````\D``!$````;R0``&0```"W)```7````1\D```D`
M``!?R0``!0```&G)```+````;\D```H```![R0```@```(;)```%````B<D`
M``T```"/R0``&P```)W)```7````N<D``!0```#1R0``"0```.;)```.````
M\,D```T```#_R0``$@````W*```X````(,H``"````!9R@``"````'K*```.
M````@\H``'L```"2R@``&`````[+```8````)\L``!$```!`RP``!P```%++
M```%````6LL``!@```!@RP``'@```'G+```;````F,L``!D```"TRP``&P``
M`,[+```9````ZLL``!,````$S```!P```!C,```(````(,P```8````IS```
M!@```##,```0````-\P```\```!(S```$````%C,```/````:<P```L```!Y
MS```#P```(7,```,````E<P```\```"BS```!P```++,```&````NLP```X`
M``#!S```#````-#,```H````W<P```\````&S0``"````!;-```(````'\T`
M`!,````HS0``'@```#S-```A````6\T``"````!]S0``&0```)[-```7````
MN,T``"4```#0S0``%P```/;-```6````#LX```0````ES@``&P```"K.```-
M````1LX```P```!4S@```P```&'.```%````9<X```@```!KS@``"@```'3.
M```,````?\X```L```",S@``$````)C.```,````J<X```0```"VS@``!```
M`+O.```3````P,X``!0```#4S@``#````.G.```)````]LX```X`````SP``
M"P````_/```;````&\\```<````WSP``!P```#_/```*````1\\```T```!2
MSP``"0```&#/```$````:L\```4```!OSP```P```'7/```8````><\```H`
M``"2SP``!````)W/```F````HL\```X```#)SP``?````-C/```5````5=``
M``4```!KT```!P```''0```,````>=````@```"&T```"@```(_0```&````
MFM````@```"AT````@```*K0```&````K=````8```"TT```%````+O0```-
M````T-```!````#>T```&P```._0```$````"]$```D````0T0``$````!K1
M```)````*]$```D````UT0``!0```#_1```:````1=$```@```!@T0``!@``
M`&G1```9````<-$```X```"*T0``!P```)G1```'````H=$```4```"IT0``
M"0```*_1```*````N=$```(```#$T0``!@```,?1```+````SM$```T```#:
MT0``"0```.C1```&````\M$```D```#YT0``!P````/2```4````"](``!T`
M```@T@``0@```#[2```E````@=(``"4```"GT@``!@```,W2```*````U-(`
M``0```#?T@``"0```.32```(````[M(``!$```#WT@``"0````G3```&````
M$],```T````:TP``!@```"C3```$````+],``#D````TTP``/0```&[3```Z
M````K-,``!X```#GTP``!0````;4```.````#-0```0````;U```!@```"#4
M```'````)]0``"$````OU```#0```%'4```&````7]0```0```!FU```$0``
M`&O4```&````?=0```H```"$U```(@```(_4```$````LM0```4```"WU```
M'0```+W4```$````V]0```P```#@U```#@```.W4```*````_-0```@````'
MU0``"0```!#5```%````&M4``#H````@U0``,````%O5```U````C-4``"D`
M``#"U0``1P```.S5```X````--8``"D```!MU@``/P```)?6```N````U]8`
M`"T````&UP``'P```#37```/````5-<``!(```!DUP``"P```'?7```F````
M@]<``"D```"JUP``)````-37```F````^=<```@````@V```"@```"G8```)
M````--@```<````^V```(````$;8```@````9]@``"8```"(V```"@```*_8
M```9````NM@``"D```#4V```%@```/[8```2````%=D```<````HV0``"@``
M`##9```,````.]D```\```!(V0``$````%C9``!`````:=D``'````"JV0``
M9@```!O:```.````@MH```D```"1V@``"@```)O:```2````IMH``!,```"Y
MV@``#````,W:```&````VMH```\```#AV@``$@```/':```0````!-L``!$`
M```5VP``'````"?;```C````1-L``&H```!HVP``#P```-/;```%````X]L`
M`!````#IVP``"0```/K;```$````!-P```L````)W```(````!7<```4````
M-MP```P```!+W```#````%C<```/````9=P``!4```!UW```*0```(O<```J
M````M=P``"8```#@W```)P````?=```I````+]T``"H```!9W0``&0```(3=
M``!"````GMT``!$```#AW0``$@```//=```3````!MX``!0````:W@``#P``
M`"_>```6````/]X``!<```!6W@``$````&[>```1````?]X``#0```"1W@``
M$P```,;>```2````VMX``#4```#MW@``%````"/?```'````.-\```P```!`
MWP``(````$W?```0````;M\``!0```!_WP``$0```)3?```7````IM\``!P`
M``"^WP``$P```-O?```4````[]\``!H````$X```$0```!_@```:````,>``
M`!X```!,X```&@```&O@```3````AN```!4```":X```$0```+#@```7````
MPN```!0```#:X```%P```._@```5````!^$```D````=X0``$````"?A```9
M````..$```0```!2X0``!P```%?A```+````7^$``!$```!KX0``!@```'WA
M```&````A.$```8```"+X0``!0```)+A```'````F.$```<```"@X0``!0``
M`*CA```&````KN$```8```"UX0``!````+SA```$````P>$```<```#&X0``
M#@```,[A```,````W>$```P```#JX0``#0```/?A```*````!>(```X````0
MX@``!0```!_B```H````)>(```X```!.X@``#````%WB```/````:N(```H`
M``!ZX@``"````(7B```)````CN(``"L```"8X@``!````,3B```(````R>(`
M`"8```#2X@``$@```/GB```&````#.,```H````3XP``!P```![C```(````
M)N,``"`````OXP``"0```%#C```4````6N,```P```!OXP``#0```'SC```.
M````BN,``!8```"9XP``$0```+#C```&````PN,```,```#)XP``!@```,WC
M```9````U.,```<```#NXP``!````/;C```+````^^,```L````'Y```!P``
M`!/D```%````&^0```<````AY```%@```"GD```-````0.0```T```!.Y```
M"@```%SD```0````9^0```\```!XY```$0```(CD```7````FN0```H```"R
MY```$0```+WD```(````S^0```0```#8Y```#P```-WD```Z````[>0```4`
M```HY0``#````"[E```>````.^4```X```!:Y0``$````&GE```+````>N4`
M``P```"&Y0``"0```)/E```'````G>4```H```"EY0``"0```+#E```.````
MNN4``!````#)Y0``&P```-KE```8````]N4``!H````/Y@``"@```"KF```)
M````->8```H````_Y@``#````$KF```/````5^8```@```!GY@``!@```'#F
M```<````=^8```<```"4Y@``!0```)SF```+````HN8``$<```"NY@``#0``
M`/;F```)````!.<```0````.YP```P```!/G```3````%^<``!,````KYP``
M$P```#_G```*````4^<```(```!>YP``!````&'G```E````9N<```,```",
MYP``!0```)#G```J````EN<```H```#!YP``!0```,SG```$````TN<```H`
M``#7YP``#0```.+G```&````\.<```@```#WYP``"`````#H```$````">@`
M``4````.Z```:````!3H```)````?>@```P```"'Z```$````)3H```%````
MI>@```8```"KZ```&P```++H```O````SN@``!````#^Z```"@````_I```/
M````&ND```H````JZ0``"0```#7I```3````/^D``!L```!3Z0``&````&_I
M```7````B.D``!\```"@Z0``#@```,#I```#````S^D```<```#3Z0``"```
M`-OI```'````Y.D```H```#LZ0``"P```/?I```'`````^H``%$````+Z@``
M$````%WJ```,````;NH```T```![Z@``&@```(GJ``!*````I.H``!D```#O
MZ@``!@````GK```:````$.L``"4````KZP``!@```%'K```&````6.L``!\`
M``!?ZP``!@```'_K```)````ANL``!@```"0ZP``%P```*GK```H````P>L`
M``8```#JZP``#0```/'K```B````_^L``%<````B[```$P```'KL```C````
MCNP``!,```"R[````@```,;L```+````R>P```@```#5[```#0```-[L```*
M````[.P```<```#W[```%````/_L```&````%.T```@````;[0``#@```"3M
M```'````,^T```H````[[0``"P```$;M```R````4NT```<```"%[0``#```
M`(WM```-````FNT```P```"H[0``"0```+7M```)````O^T```H```#)[0``
M!P```-3M```)````W.T```<```#F[0``"@```.[M```;````^>T``!(````5
M[@``"@```"CN```6````,^X```D```!*[@``$````%3N```'````9>X``!(`
M``!M[@``!````(#N```'````A>X```4```"-[@``!0```)/N```+````F>X`
M`!0```"E[@``$0```+KN```:````S.X``!8```#G[@``%````/[N```7````
M$^\``!@````K[P``'````$3O```9````8>\```<```![[P``!0```(/O```-
M````B>\```P```"7[P``$0```*3O```(````MN\``!<```"_[P``"P```-?O
M```,````X^\``!\```#P[P``&@```!#P```3````*_````0````_\```"@``
M`$3P```$````3_````T```!4\```#````&+P```%````;_````D```!U\```
M!0```'_P```'````A?````4```"-\```!````)/P```"````F/```#@```";
M\```+````-3P```2`````?$``"D````4\0``,@```#[Q```*````<?$``"P`
M``!\\0``+@```*GQ```S````V/$``#,````,\@``.````$#R```/````>?(`
M`!@```")\@``$````*+R```/````L_(``!,```##\@``%0```-?R```4````
M[?(``!(````"\P``%````!7S```5````*O,``"T```!`\P``+0```&[S```Q
M````G/,``"X```#.\P``+P```/WS```L````+?0``&(```!:]```$P```+WT
M```-````T?0```@```#?]```%P```.CT```(`````/4```P````)]0``*P``
M`!;U```A````0O4``!H```!D]0``"0```'_U``!%````B?4``$$```#/]0``
M!````!'V```3````%O8```X````J]@``$P```#GV```8````3?8```8```!F
M]@``"0```&WV```*````=_8```\```""]@``$````)+V```'````H_8```X`
M``"K]@``!0```+KV```;````P/8```@```#<]@``!@```.7V```4````[/8`
M`!$````!]P``#@```!/W```X````(O<```(```!;]P``!@```%[W```.````
M9?<```4```!T]P``!P```'KW```.````@O<```8```"1]P``*````)CW```,
M````P?<``!P```#.]P``!````.OW```I````\/<``!<````:^```'P```#+X
M``!<````4O@``!0```"O^```/@```,3X```?`````_D``!`````C^0``!P``
M`#3Y```.````//D```P```!+^0``#````%CY```3````9?D```H```!Y^0``
M'0```(3Y```9````HOD```4```"\^0``$0```,+Y```1````U/D``"0```#F
M^0``$@````OZ```5````'OH``!(````T^@``#@```$?Z```9````5OH```@`
M``!P^@``"0```'GZ```-````@_H```H```"1^@``!P```)SZ```/````I/H`
M``8```"T^@``"P```+OZ```:````Q_H```H```#B^@``!P```.WZ```(````
M]?H```4```#^^@``'P````3[```&````)/L``!`````K^P``"````#S[```-
M````1?L```@```!3^P``'@```%S[```2````>_L``"P```".^P``&@```+O[
M```)````UOL```H```#@^P``%0```.O[```%`````?P``!0````'_```!```
M`!S\```0````(?P```8````R_```!P```#G\```>````0?P``"@```!@_```
M"@```(G\```<````E/P``!$```"Q_```"P```,/\```:````S_P``!0```#J
M_```!````/_\```$````!/T```L````)_0``!0```!7]```&````&_T```@`
M```B_0``!@```"O]```;````,OT``#0```!._0``-````(/]```@````N/T`
M`"D```#9_0``(`````/^``!!````)/X``!H```!F_@``*````('^```I````
MJOX``%````#4_@``(@```"7_```&````2/\```@```!/_P``!0```%C_```(
M````7O\``!D```!G_P``&0```('_```J````F_\``",```#&_P``&0```.K_
M```N````!``!`#0````S``$`"````&@``0`7````<0`!``H```")``$`!P``
M`)0``0`A````G``!`!````"^``$`#@```,\``0`+````W@`!``<```#J``$`
M$P```/(``0`(````!@$!``L````/`0$`"@```!L!`0`4````)@$!``\````[
M`0$`,@```$L!`0`+````?@$!``4```"*`0$`!0```)`!`0`%````E@$!`!<`
M``"<`0$`#P```+0!`0`$````Q`$!``H```#)`0$`"0```-0!`0`+````W@$!
M``T```#J`0$`#````/@!`0`.````!0(!``4````4`@$`!````!H"`0`-````
M'P(!`#(````M`@$`10```&`"`0`7````I@(!``<```"^`@$`'@```,8"`0`4
M````Y0(!``4```#Z`@$`%``````#`0`&````%0,!``<````<`P$`#@```"0#
M`0`J````,P,!``8```!>`P$`#````&4#`0`-````<@,!`!$```"``P$`"P``
M`)(#`0`V````G@,!``H```#5`P$`(@```.`#`0`+`````P0!``\````/!`$`
M,@```!\$`0`E````4@0!`#````!X!`$`,0```*D$`0`M````VP0!``X````)
M!0$`!0```!@%`0`.````'@4!`!,````M!0$`$@```$$%`0`'````5`4!`!$`
M``!<!0$`$P```&X%`0`'````@@4!`!0```"*!0$`&````)\%`0`'````N`4!
M``4```#`!0$`#````,8%`0`,````TP4!`!(```#@!0$`!````/,%`0`'````
M^`4!``H`````!@$`"P````L&`0`,````%P8!``X````D!@$`#@```#,&`0`%
M````0@8!``4```!(!@$`+@```$X&`0`F````?08!`",```"D!@$``P```,@&
M`0`2````S`8!``8```#?!@$`'@```.8&`0`8````!0<!`"4````>!P$`#0``
M`$0'`0`)````4@<!`!\```!<!P$``P```'P'`0`'````@`<!``H```"(!P$`
M`@```),'`0`,````E@<!`!4```"C!P$`"P```+D'`0`9````Q0<!`"````#?
M!P$`$@`````(`0`%````$P@!``H````9"`$`%0```"0(`0`2````.@@!``P`
M``!-"`$`!````%H(`0`)````7P@!``<```!I"`$`#````'$(`0!2````?@@!
M`!<```#1"`$`)````.D(`0`2````#@D!``<````A"0$`!@```"D)`0`.````
M,`D!``P````_"0$`#0```$P)`0`5````6@D!`!(```!P"0$`#P```(,)`0`4
M````DPD!``H```"H"0$`&P```+,)`0`0````SPD!``L```#@"0$`:0```.P)
M`0`:````5@H!`!<```!Q"@$`)P```(D*`0`:````L0H!`!<```#,"@$`&P``
M`.0*`0`9``````L!`!\````:"P$`$P```#H+`0`(````3@L!``<```!7"P$`
M"````%\+`0`)````:`L!`!4```!R"P$`#0```(@+`0`C````E@L!``T```"Z
M"P$`$P```,@+`0`(````W`L!``,```#E"P$`1@```.D+`0`_````,`P!`#<`
M``!P#`$`5P```*@,`0`%``````T!`!\````&#0$`+P```"8-`0`*````5@T!
M``@```!A#0$`#0```&H-`0`M````>`T!``0```"F#0$`3P```*L-`0`E````
M^PT!`!P````A#@$`"P```#X.`0`?````2@X!`!T```!J#@$`)0```(@.`0`@
M````K@X!`"0```#/#@$`(````/0.`0`+````%0\!``<````A#P$`#0```"D/
M`0`,````-P\!`!<```!$#P$`!@```%P/`0`Y````8P\!``P```"=#P$`!P``
M`*H/`0`)````L@\!`!,```"\#P$`"0```-`/`0`$````V@\!`!````#?#P$`
M"````/`/`0`(````^0\!``0````"$`$`"P````<0`0`,````$Q`!`!(````@
M$`$`$0```#,0`0`,````11`!`!H```!2$`$`#P```&T0`0`'````?1`!``T`
M``"%$`$`%````),0`0`.````J!`!``P```"W$`$`+````,00`0`3````\1`!
M`!P````%$0$`*````"(1`0`&````2Q$!``<```!2$0$`$P```%H1`0`%````
M;A$!``0```!T$0$`%P```'D1`0`*````D1$!``P```"<$0$`"0```*D1`0`&
M````LQ$!``D```"Z$0$`"````,01`0`)````S1$!``H```#7$0$`$0```.(1
M`0`&````]!$!``X```#[$0$`#@````H2`0`-````&1(!``L````G$@$`'0``
M`#,2`0`+````41(!``(```!=$@$`'````&`2`0`'````?1(!``8```"%$@$`
M9````(P2`0`)````\1(!``<```#[$@$`)@````,3`0`X````*A,!`!H```!C
M$P$`*@```'X3`0`[````J1,!`"@```#E$P$`-`````X4`0`9````0Q0!`!4`
M``!=%`$`!0```',4`0`'````>10!``@```"!%`$`!P```(H4`0`%````DA0!
M``<```"8%`$`#@```*`4`0`)````KQ0!``8```"Y%`$`"````,`4`0`+````
MR10!``<```#5%`$`"````-T4`0`'````YA0!`!8```#N%`$`"0````45`0`&
M````#Q4!``L````6%0$`$````"(5`0`&````,Q4!`!P````Z%0$`%````%<5
M`0`'````;!4!`!$```!T%0$`"````(85`0`.````CQ4!``@```">%0$`!0``
M`*<5`0`0````K14!`!````"^%0$`!@```,\5`0`9````UA4!``H```#P%0$`
M'````/L5`0`'````&!8!``4````@%@$`$````"86`0`4````-Q8!``L```!,
M%@$`#0```%@6`0`H````9A8!`!@```"/%@$`%P```*@6`0`$````P!8!``D`
M``#%%@$`"@```,\6`0`'````VA8!``(```#B%@$`"````.46`0`C````[A8!
M`#@````2%P$`)@```$L7`0`Q````<A<!`"<```"D%P$`9````,P7`0`4````
M,1@!`%4```!&&`$`.````)P8`0!*````U1@!`%L````@&0$`*````'P9`0`X
M````I1D!`"@```#>&0$`+`````<:`0`F````-!H!`!L```!;&@$`/@```'<:
M`0"I`0``MAH!`",```!@'`$`%P```(0<`0!(````G!P!`(4```#E'`$`,```
M`&L=`0`E````G!T!`$$```#"'0$`6P````0>`0!)````8!X!`#$```"J'@$`
M'0```-P>`0`8````^AX!`"L````3'P$`(0```#\?`0`?````81\!`"L```"!
M'P$`(0```*T?`0`G````SQ\!`#H```#W'P$`'0```#(@`0`1````4"`!`#,`
M``!B(`$`)0```)8@`0`G````O"`!`"````#D(`$`'P````4A`0`P````)2$!
M`&D```!6(0$`,0```,`A`0!!````\B$!`#,````T(@$`)0```&@B`0`]````
MCB(!`&4```#,(@$`30```#(C`0`O````@",!`"X```"P(P$`,````-\C`0!4
M````$"0!`%H```!E)`$`2````,`D`0!*````"24!`#(```!4)0$`+P```(<E
M`0`L````MR4!`"T```#D)0$`<0```!(F`0!F````A"8!`&\```#K)@$`LP``
M`%LG`0`7````#R@!`"4````G*`$`,@```$TH`0`I````@"@!`#X```"J*`$`
M(@```.DH`0!2````#"D!`"4```!?*0$`"P```(4I`0"Q````D2D!`$4```!#
M*@$`(0```(DJ`0`P````JRH!`"4```#<*@$`'`````(K`0`Q````'RL!``<`
M``!1*P$`!P```%DK`0`$````82L!``T```!F*P$`"P```'0K`0`.````@"L!
M``L```"/*P$`!0```)LK`0`0````H2L!``(```"R*P$`60```+4K`0`%````
M#RP!`!(````5+`$`!````"@L`0`'````+2P!``@````U+`$`!0```#XL`0`#
M````1"P!`!````!(+`$`#````%DL`0`3````9BP!``T```!Z+`$``@```(@L
M`0`'````BRP!``8```"3+`$`#````)HL`0`8````IRP!``8```#`+`$`$@``
M`,<L`0`,````VBP!``,```#G+`$`*@```.LL`0`$````%BT!``8````;+0$`
M!P```"(M`0`?````*BT!`#4```!*+0$`+@```(`M`0`O````KRT!`!<```#?
M+0$`(@```/<M`0`E````&BX!`"````!`+@$`&P```&$N`0`8````?2X!`"0`
M``"6+@$`'P```+LN`0`:````VRX!`"$```#V+@$`(````!@O`0`:````.2\!
M`#(```!4+P$`&@```(<O`0`O````HB\!`"L```#2+P$`'P```/XO`0`C````
M'C`!`!\```!",`$`&@```&(P`0`A````?3`!`"4```"?,`$`)@```,4P`0`E
M````[#`!`"0````2,0$`&````#<Q`0`=````4#$!`"0```!N,0$`&````),Q
M`0`B````K#$!`"P```#/,0$`+P```/PQ`0`5````+#(!`"4```!",@$`/```
M`&@R`0`?````I3(!`",```#%,@$`'P```.DR`0`@````"3,!`!H````J,P$`
M&````$4S`0`F````7C,!`!X```"%,P$`*0```*0S`0`>````SC,!`#$```#M
M,P$`"0```!\T`0`,````*30!`!<````V-`$`+P```$XT`0`D````?C0!``<`
M``"C-`$`%````*LT`0`.````P#0!``T```#/-`$`!0```-TT`0`'````XS0!
M`"(```#K-`$`)0````XU`0`:````-#4!`!T```!/-0$`&@```&TU`0`'````
MB#4!`,<```"0-0$`"P```%@V`0`5````9#8!``8```!Z-@$`"0```($V`0`+
M````BS8!``T```"7-@$`%P```*4V`0`&````O38!`#,```#$-@$`$P```/@V
M`0`3````##<!``<````@-P$`#P```"@W`0`'````.#<!`#(```!`-P$`!```
M`',W`0`A````>#<!`!,```":-P$`#````*XW`0`1````NS<!`#(```#--P$`
M%@`````X`0`(````%S@!`!T````@.`$`"0```#XX`0`*````2#@!`!0```!3
M.`$`"@```&@X`0`=````<S@!``@```"1.`$`'P```)HX`0`(````NC@!`!H`
M``##.`$`)P```-XX`0`&````!CD!`!4````-.0$`!P```",Y`0`(````*SD!
M``D````T.0$`/P```#XY`0`'````?CD!``\```"&.0$`#@```)8Y`0`0````
MI3D!``D```"V.0$`"0```,`Y`0`(````RCD!``<```#3.0$`&0```-LY`0`*
M````]3D!`!<`````.@$`%````!@Z`0`*````+3H!``P````X.@$`%P```$4Z
M`0`$````73H!`"H```!B.@$`#````(TZ`0`1````FCH!``<```"L.@$``@``
M`+0Z`0`0````MSH!`!@```#(.@$`"P```.$Z`0`#````[3H!``@```#Q.@$`
M!@```/HZ`0`'`````3L!``T````).P$`"P```!<[`0`.````(SL!`"\````R
M.P$`(````&([`0`<````@SL!`!4```"@.P$`#````+8[`0`Q````PSL!``4`
M``#U.P$`$@```/L[`0`_````#CP!`!(```!./`$`"@```&$\`0`&````;#P!
M``0```!S/`$`!````'@\`0`*````?3P!`!,```"(/`$`!0```)P\`0`&````
MHCP!``8```"I/`$`"````+`\`0`$````N3P!``P```"^/`$`"@```,L\`0`Y
M````UCP!`"X````0/0$`*0```#\]`0`%````:3T!`!@```!O/0$`&0```(@]
M`0`?````HCT!`!T```#"/0$`$0```.`]`0`"````\CT!``0```#U/0$`"@``
M`/H]`0`&````!3X!``4````,/@$``P```!(^`0`,````%CX!`$4````C/@$`
M,@```&D^`0`:````G#X!`#0```"W/@$`*````.P^`0!3````%3\!`!D```!I
M/P$`<@```(,_`0`@````]C\!`#4````70`$`(0```$U``0!%````;T`!`#``
M``"U0`$`*````.9``0`I````#T$!`"8````Y00$`)0```&!!`0`H````AD$!
M`"@```"O00$`(@```-A!`0`K````^T$!`#`````G0@$`$@```%A"`0`3````
M:T(!`!````!_0@$`>0```)!"`0`)````"D,!`*$````40P$`<P```+9#`0!\
M````*D0!`"L```"G1`$`5````--$`0`7````*$4!`"<```!`10$`%@```&A%
M`0`/````?T4!`!<```"/10$`'P```*=%`0!`````QT4!`!\````(1@$`'```
M`"A&`0!1````148!`!H```"71@$`%````+)&`0`*````QT8!``4```#21@$`
M!@```-A&`0`(````WT8!``4```#H1@$`$@```.Y&`0`0`````4<!`!,````2
M1P$`'0```"9'`0`/````1$<!``\```!41P$`!````&1'`0`)````:4<!``L`
M``!S1P$`!P```']'`0`%````AT<!`!0```"-1P$`!P```*)'`0`(````JD<!
M``\```"S1P$`"````,-'`0`,````S$<!``\```#91P$`!@```.E'`0`4````
M\$<!``8````%2`$`#`````Q(`0`1````&4@!``@````K2`$`!````#1(`0`9
M````.4@!`!$```!32`$`"@```&5(`0`8````<$@!`!,```")2`$`'````)U(
M`0`1````ND@!``\```#,2`$`!P```-Q(`0`$````Y$@!`!D```#I2`$`!P``
M``-)`0`"````"TD!``(````.20$`$0```!%)`0`)````(TD!``8````M20$`
M$@```#1)`0`7````1TD!``8```!?20$`)P```&9)`0`"````CDD!``0```"1
M20$`#P```)9)`0`3````IDD!``<```"Z20$`!P```,))`0`1````RDD!``8`
M``#<20$`&````.-)`0`&````_$D!`!,````#2@$`$````!=*`0`2````*$H!
M``(````[2@$`!@```#Y*`0`,````14H!``D```!22@$`$0```%Q*`0`B````
M;DH!``<```"12@$`!P```)E*`0`+````H4H!``4```"M2@$``@```+-*`0`+
M````MDH!`$D!``#"2@$`$`````Q,`0`7````'4P!``L````U3`$`!@```$%,
M`0`)````2$P!``@```!23`$`"@```%M,`0`4````9DP!`!D```![3`$`+0``
M`)5,`0`E````PTP!`"4```#I3`$`(P````]-`0`?````,TT!`"T```!330$`
M"@```(%-`0`J````C$T!`!,```"W30$`#0```,M-`0`+````V4T!``4```#E
M30$`+0```.M-`0`-````&4X!`!T````G3@$`%0```$5.`0`/````6TX!`!$`
M``!K3@$`=````'U.`0`.````\DX!``@````!3P$`$0````I/`0`-````'$\!
M`!8````J3P$`%P```$%/`0`7````64\!`!H```!Q3P$`!@```(Q/`0"_````
MDT\!``L```!34`$`$@```%]0`0`=````<E`!`!````"04`$`$@```*%0`0`2
M````M%`!``@```#'4`$`#P```-!0`0`P````X%`!`!D````140$`-@```"M1
M`0`]````8E$!`%````"@40$`3P```/%1`0!8````05(!`%8```":4@$`.```
M`/%2`0`4````*E,!`!<````_4P$`$0```%=3`0`5````:5,!`!T```!_4P$`
M"````)U3`0`&````IE,!``\```"M4P$`!````+U3`0`0````PE,!``\```#3
M4P$`,@```.-3`0`P````%E0!`!$```!'5`$`#@```%E4`0`1````:%0!``D`
M``!Z5`$`!@```(14`0`9````BU0!`!<```"E5`$`!P```+U4`0`.````Q50!
M`!$```#45`$`'@```.94`0`<````!54!`!,````B50$`#0```#95`0`-````
M1%4!``H```!250$`)@```%U5`0`3````A%4!`!@```"850$`$@```+%5`0!4
M````Q%4!`#<````95@$`)````%%6`0`&````=E8!``<```!]5@$`-@```(56
M`0`-````O%8!``<```#*5@$`"@```-)6`0`(````W58!``@```#F5@$`!0``
M`.]6`0`(````]58!``L```#^5@$`!@````I7`0`C````$5<!``X````U5P$`
M#````$17`0`3````45<!`!8```!E5P$`*P```'Q7`0`+````J%<!`"0```"T
M5P$`%P```-E7`0`D````\5<!`!T````66`$`%````#18`0`2````25@!``X`
M``!<6`$`'````&M8`0`6````B%@!``<```"?6`$`!@```*=8`0`(````KE@!
M``X```"W6`$`!P```,98`0`*````SE@!`!$```#96`$`"0```.M8`0`0````
M]5@!`!@````&60$`*@```!]9`0`(````2ED!`!$```!360$`!0```&59`0`/
M````:UD!``P```![60$`,0```(A9`0`O````NED!``D```#J60$`"````/19
M`0`&````_5D!``4````$6@$`$`````I:`0`,````&UH!`!4````H6@$`-```
M`#Y:`0`H````<UH!`"<```"<6@$`)````,1:`0`Q````Z5H!``@````;6P$`
M!@```"1;`0`)````*UL!``<````U6P$`-P```#U;`0`O````=5L!`#8```"E
M6P$`7@```-Q;`0`U````.UP!`#4```!Q7`$`2@```*=<`0!+````\EP!`#4`
M```^70$`0@```'1=`0`Q````MUT!`#0```#I70$`3````!Y>`0`U````:UX!
M`#L```"A7@$`+````-U>`0`6````"E\!`!H````A7P$`)@```#Q?`0`K````
M8U\!`"L```"/7P$`$0```+M?`0`+````S5\!``P```#97P$`!P```.9?`0`-
M````[E\!`!<```#\7P$`)````!1@`0`&````.6`!``<```!`8`$`"0```$A@
M`0`(````4F`!`"@```!;8`$`#P```(1@`0`*````E&`!``@```"?8`$`!@``
M`*A@`0`%````KV`!``<```"U8`$`!0```+U@`0`*````PV`!`"<```#.8`$`
M$````/9@`0`)````!V$!``4````180$`!P```!=A`0`'````'V$!``4````G
M80$`#0```"UA`0`&````.V$!`!,```!"80$``P```%9A`0`(````6F$!``8`
M``!C80$`#0```&IA`0`(````>&$!`"````"!80$`$0```*)A`0`)````M&$!
M`!(```"^80$`#````-%A`0`'````WF$!``,```#F80$``P```.IA`0`4````
M[F$!`!0````#8@$`,@```!AB`0`(````2V(!``D```!48@$`"````%YB`0`'
M````9V(!`$L```!O8@$`)````+MB`0`M````X&(!`"@````.8P$`(0```#=C
M`0`&````66,!``8```!@8P$`&````&=C`0`A````@&,!`"0```"B8P$`+@``
M`,=C`0`E````]F,!`"T````<9`$`8````$ID`0`N````JV0!`!(```#:9`$`
M!P```.UD`0`3````]60!`!$````)90$`#P```!ME`0`0````*V4!`!`````\
M90$`$````$UE`0`0````7F4!``\```!O90$`"0```']E`0`7````B64!`"$`
M``"A90$`%````,-E`0`8````V&4!``,```#Q90$`!@```/5E`0`1````_&4!
M`%4````.9@$`7````&1F`0`$````P68!`!8```#&9@$`!0```-UF`0`$````
MXV8!`!(```#H9@$`#P```/MF`0`<````"V<!`"0````H9P$`,````$UG`0`/
M````?F<!`",```".9P$`!0```+)G`0`:````N&<!``T```#39P$`&0```.%G
M`0`5````^V<!`!L````1:`$`$0```"UH`0`9````/V@!`!,```!9:`$`#0``
M`&UH`0`&````>V@!``P```"":`$`!P```(]H`0`7````EV@!`!(```"O:`$`
M#@```,)H`0`(````T6@!``4```#::`$`"P```.!H`0`+````[&@!``<```#X
M:`$`#P````!I`0`&````$&D!``8````7:0$`%0```!YI`0`(````-&D!``H`
M```]:0$`!@```$AI`0`*````3VD!``@```!::0$`!````&-I`0`$````:&D!
M`!<```!M:0$`3````(5I`0`D````TFD!``\```#W:0$`#@````=J`0`%````
M%FH!`!P````<:@$`$0```#EJ`0`2````2VH!`"X```!>:@$`/0```(UJ`0`@
M````RVH!``@```#L:@$`,````/5J`0`:````)FL!``H```!!:P$`"@```$QK
M`0`/````5VL!``8```!G:P$`"0```&YK`0`7````>&L!``\```"0:P$`"0``
M`*!K`0`2````JFL!`"T```"]:P$`*P```.MK`0`O````%VP!`"T```!';`$`
M(0```'5L`0`F````EVP!`"4```"^;`$`*0```.1L`0`I````#FT!`#4````X
M;0$`*P```&YM`0`D````FFT!`"8```"_;0$`(0```.9M`0`J````"&X!`#H`
M```S;@$`+@```&YN`0`D````G6X!`#````#";@$`.0```/-N`0`E````+6\!
M`"$```!3;P$`-````'5O`0`E````JF\!`!D```#0;P$`+P```.IO`0`C````
M&G`!`"8````^<`$`&@```&5P`0"Q````@'`!`!(````R<0$`(````$5Q`0`I
M````9G$!`"D```"0<0$`,0```+IQ`0`B````['$!`"$````/<@$`)0```#%R
M`0`I````5W(!`"P```"!<@$`.@```*YR`0`L````Z7(!`),````6<P$`)0``
M`*IS`0`;````T',!`"8```#L<P$`+P```!-T`0`O````0W0!`$8```!S=`$`
M1````+IT`0`-````_W0!``<````-=0$`!0```!5U`0`(````&W4!``X````D
M=0$`#0```#-U`0`5````074!``P```!7=0$`%0```&1U`0`*````>G4!``0`
M``"%=0$`#P```(IU`0`0````FG4!``P```"K=0$`#P```+AU`0`5````R'4!
M`!````#>=0$`%````.]U`0`-````!'8!`$(````2=@$`"@```%5V`0`0````
M8'8!``8```!Q=@$`#P```'AV`0`"````B'8!`$L```"+=@$`!0```-=V`0`C
M````W78!`!<````!=P$`!0```!EW`0`.````'W<!``P````N=P$``P```#MW
M`0`1````/W<!``@```!1=P$`$````%IW`0`1````:W<!``T```!]=P$`$P``
M`(MW`0`;````GW<!`",```"[=P$`"0```-]W`0`'````Z7<!``T```#Q=P$`
M#P```/]W`0`.````#W@!``T````>>`$`&@```"QX`0`-````1W@!``X```!5
M>`$`)P```&1X`0`6````C'@!`"L```"C>`$`#@```,]X`0`8````WG@!`!<`
M``#W>`$`%P````]Y`0`Q````)WD!``T```!9>0$`!@```&=Y`0`/````;GD!
M``4```!^>0$`*P```(1Y`0`L````L'D!``4```#=>0$`"0```.-Y`0`>````
M[7D!``L````,>@$`$@```!AZ`0`2````*WH!``<````^>@$`)@```$9Z`0`5
M````;7H!`!L```"#>@$`&````)]Z`0`1````N'H!`!4```#*>@$`"0```.!Z
M`0`)````ZGH!`",```#T>@$`/0```!A[`0`(````5GL!`!8```!?>P$`'@``
M`'9[`0`(````E7L!``L```">>P$`,@```*I[`0`0````W7L!``4```#N>P$`
M!@```/1[`0`#````^WL!``<```#_>P$`!P````=\`0`,````#WP!``\````<
M?`$`#0```"Q\`0`-````.GP!`!0```!(?`$`%P```%U\`0`6````=7P!`!0`
M``",?`$`"P```*%\`0`%````K7P!``@```"S?`$`"@```+Q\`0`"````QWP!
M``4```#*?`$`$````-!\`0`C````X7P!`!,````%?0$`$@```!E]`0`)````
M+'T!``\````V?0$`$0```$9]`0`:````6'T!`"T```!S?0$`*P```*%]`0`+
M````S7T!``X```#9?0$`=@```.A]`0`3````7WX!`!\```!S?@$`$````)-^
M`0`'````I'X!``4```"L?@$`'0```+)^`0`Q````T'X!`"\````"?P$`'@``
M`#)_`0`@````47\!`!H```!R?P$`&@```(U_`0`(````J'\!``<```"Q?P$`
M!P```+E_`0`&````P7\!`!````#(?P$`#@```-E_`0`1````Z'\!``\```#Z
M?P$`%0````J``0`/````((`!``P````P@`$`"@```#V``0`'````2(`!``@`
M``!0@`$`%````%F``0`.````;H`!`#<```!]@`$`#P```+6``0`(````Q8`!
M``L```#.@`$`&@```-J``0`@````]8`!`"H````6@0$`*0```$&!`0`?````
M:X$!`"````"+@0$`*@```*R!`0`?````UX$!`!@```#W@0$`!0```!""`0`=
M````%H(!``\````T@@$`#@```$2"`0`#````4X(!``0```!7@@$`!P```%R"
M`0`-````9((!``\```!R@@$`"P```(*"`0`5````CH(!``L```"D@@$`!0``
M`+""`0`%````MH(!`!<```"\@@$`&0```-2"`0`/````[H(!``L```#^@@$`
M#`````J#`0`/````%X,!`"8````G@P$`!@```$Z#`0`&````58,!``T```!<
M@P$`"@```&J#`0`+````=8,!``8```"!@P$`#@```(B#`0`$````EX,!`!<`
M``"<@P$`"P```+2#`0`'````P(,!`"H```#(@P$`#P```/.#`0"#`````X0!
M`!(```"'A`$`"0```)J$`0`'````I(0!``L```"LA`$`!P```+B$`0`)````
MP(0!``0```#*A`$`#0```,^$`0`#````W80!``4```#AA`$`"@```.>$`0`3
M````\H0!`!(````&A0$`%````!F%`0`:````+H4!``(```!)A0$`"0```$R%
M`0`+````5H4!``0```!BA0$`"@```&>%`0`%````<H4!`"8```!XA0$`"```
M`)^%`0`&````J(4!`"<```"OA0$`#@```->%`0`'````YH4!``<```#NA0$`
M!0```/:%`0`)````_(4!``L````&A@$`!P```!*&`0`&````&H8!``L````A
MA@$`$````"V&`0`-````/H8!``8```!,A@$`!P```%.&`0`'````6X8!`!0`
M``!CA@$`'0```'B&`0`_````EH8!`"P```#6A@$`,0````.'`0`'````-8<!
M``H````]AP$`!````$B'`0`)````38<!``@```!7AP$`'0```&"'`0`)````
M?H<!``8```"(AP$`#0```(^'`0`&````G8<!``0```"DAP$`,@```*F'`0`T
M````W(<!`#0````1B`$`(P```$:(`0`%````:H@!`!T```!PB`$`!````(Z(
M`0`(````DX@!``@```"<B`$`)````*6(`0`+````RH@!``4```#6B`$`"```
M`-R(`0`?````Y8@!``@````%B0$`"`````Z)`0`6````%XD!``8````NB0$`
M!@```#6)`0`'````/(D!``4```!$B0$`#0```$J)`0`0````6(D!``T```!I
MB0$`"````'>)`0`)````@(D!``4```"*B0$`.P```)")`0`X````S(D!`#P`
M```%B@$`)P```$**`0`X````:HH!`$````"CB@$`,````.2*`0`Z````%8L!
M`#4```!0BP$`/@```(:+`0`I````Q8L!`!(```#OBP$`%@````*,`0`-````
M&8P!`"H````GC`$`'````%*,`0`=````;XP!`!P```"-C`$`!P```*J,`0`)
M````LHP!``D```"\C`$`"````,:,`0`H````SXP!`"<```#XC`$`)0```""-
M`0`)````1HT!`!H```!0C0$`+P```&N-`0`F````FXT!`!$```#"C0$`!@``
M`-2-`0`)````VXT!``P```#EC0$`#````/*-`0`/````_XT!`#8````/C@$`
M@@```$:.`0!V````R8X!``\```!`CP$`"P```%"/`0`,````7(\!`!$```!I
MCP$`$@```'N/`0`0````CH\!``<```"?CP$`#P```*>/`0`4````MX\!`!(`
M``#,CP$`#P```-^/`0`?````[X\!`"H````/D`$`A@```#J0`0`1````P9`!
M``4```#3D`$`%P```-F0`0`)````\9`!``0```#[D`$`"@````"1`0`>````
M"Y$!`!$````JD0$`#@```#R1`0`.````2Y$!``P```!:D0$`$P```&>1`0`>
M````>Y$!`"````":D0$`'@```+N1`0`@````VI$!`!\```#[D0$`(0```!N2
M`0`;````/9(!`#@```!9D@$`#P```)*2`0`1````HI(!`!````"TD@$`$@``
M`,62`0`-````V)(!`!(```#FD@$`%````/F2`0`0````#I,!`!(````?DP$`
M,@```#*3`0`6````99,!`!0```!\DP$`/0```)&3`0`4````SY,!``H```#D
MDP$`$P```.^3`0!!`````Y0!`!L```!%E`$`$P```&&4`0`2````=90!`!T`
M``"(E`$`&````*:4`0`6````OY0!`!<```#6E`$`'@```.Z4`0`:````#94!
M`"@````HE0$`(P```%&5`0`:````=94!`!4```"0E0$`%@```*:5`0`1````
MO94!`!<```#/E0$`&0```.>5`0`9`````98!`!<````;E@$`"````#.6`0`0
M````/)8!``0```!-E@$`!````%*6`0`%````5Y8!``L```!=E@$`#P```&F6
M`0`&````>98!``D```"`E@$`!P```(J6`0`)````DI8!``<```"<E@$`!@``
M`*26`0`(````JY8!``8```"TE@$`!@```+N6`0`#````PI8!``,```#&E@$`
M"````,J6`0`2````TY8!`!$```#FE@$`#@```/B6`0`/````!Y<!``H````7
MEP$`$@```"*7`0`$````-9<!`"@````ZEP$`$@```&.7`0`0````=I<!`!@`
M``"'EP$`"P```*"7`0`)````K)<!``X```"VEP$`+0```,67`0`$````\Y<!
M``@```#XEP$`(@````&8`0`2````))@!``8````WF`$`"0```#Z8`0`'````
M2)@!``4```!0F`$`!````%:8`0`1````6Y@!`!0```!MF`$`#@```(*8`0`6
M````D9@!`!@```"HF`$`'0```,&8`0`;````WY@!``@```#[F`$`!0````29
M`0`&````"ID!`"$````1F0$`!P```#.9`0`%````.YD!``X```!!F0$`#0``
M`%"9`0`'````7ID!``8```!FF0$`!P```&V9`0`%````=9D!``\```![F0$`
M#P```(N9`0`*````FYD!``\```"FF0$`$0```+:9`0`6````R)D!`!0```#?
MF0$`#@```/29`0`6`````YH!``@````:F@$`!0```".:`0`1````*9H!`#8`
M```[F@$`!0```'*:`0`,````>)H!`",```"%F@$`%@```*F:`0`4````P)H!
M`!<```#5F@$`#````.V:`0`)````^IH!``<````$FP$`"@````R;`0`)````
M%YL!``X````AFP$`$````#";`0`=````09L!`",```!?FP$`+@```(.;`0`*
M````LIL!``4```"]FP$`#@```,.;`0`-````TIL!`!$```#@FP$`"````/*;
M`0`+````^YL!`"8````'G`$`"````"Z<`0`+````-YP!`!0```!#G`$`40``
M`%B<`0`4````JIP!``D```"_G`$`!0```,F<`0`%````SYP!`!,```#5G`$`
M%0```.F<`0`3````_YP!``L````3G0$``@```!^=`0`*````(IT!`"H````M
MG0$``P```%B=`0`%````7)T!``H```!BG0$`"@```&V=`0`%````>)T!``4`
M``!^G0$`'@```(2=`0`2````HYT!``8```"VG0$`"````+V=`0`(````QIT!
M``0```#/G0$`!0```-2=`0!A````VIT!``H````\G@$`#0```$>>`0`2````
M59X!``4```!HG@$`!0```&Z>`0`G````=)X!`#0```"<G@$`$P```-&>`0`(
M````Y9X!``P```#NG@$`"@```/N>`0`)````!I\!`!H````0GP$`+````"N?
M`0`J````6)\!`"D```"#GP$`'@```*V?`0`/````S)\!``,```#<GP$`!P``
M`."?`0`(````Z)\!``@```#QGP$`$````/J?`0`,````"Z`!``8````8H`$`
M20```!^@`0`9````::`!``H```"#H`$`#0```(Z@`0`<````G*`!`$T```"Y
MH`$`(`````>A`0`&````**$!`!T````OH0$`*````$VA`0`(````=J$!``8`
M``!_H0$`'0```(:A`0`%````I*$!``@```"JH0$`*@```+.A`0`I````WJ$!
M`"X````(H@$`$0```#>B`0`%````2:(!`!X```!/H@$`70```&ZB`0`0````
MS*(!`"$```#=H@$`$0```/^B`0`#````$:,!``P````5HP$`!@```"*C`0`5
M````*:,!``L````_HP$`!P```$NC`0`)````4Z,!``8```!=HP$`"0```&2C
M`0`,````;J,!``<```![HP$`"@```(.C`0`,````CJ,!`#D```";HP$`!@``
M`-6C`0`.````W*,!`!````#KHP$`$````/RC`0`-````#:0!``X````;I`$`
M#P```"JD`0`-````.J0!``T```!(I`$`#0```%:D`0`(````9*0!`!X```!M
MI`$`$0```(RD`0`*````GJ0!`!<```"II`$`"@```,&D`0`4````S*0!``<`
M``#AI`$`$````.FD`0`$````^J0!``<```#_I`$`!0````>E`0`%````#:4!
M``D````3I0$`$````!VE`0`5````+J4!`"T```!$I0$`'````'*E`0`Q````
MCZ4!`"H```#!I0$`&0```.RE`0`=````!J8!`!@````DI@$`!````#VF`0`%
M````0J8!``X```!(I@$`#@```%>F`0`2````9J8!``,```!YI@$`(P```'VF
M`0`+````H:8!``H```"MI@$`(````+BF`0`:````V:8!`!(```#TI@$`!```
M``>G`0`0````#*<!``4````=IP$`$@```".G`0`1````-J<!``P```!(IP$`
M"0```%6G`0`%````7Z<!``<```!EIP$``P```&VG`0`$````<:<!``,```!V
MIP$`4@```'JG`0!`````S:<!`!T````.J`$`+@```"RH`0`U````6Z@!``T`
M``"1J`$`-@```)^H`0`B````UJ@!`"<```#YJ`$`)P```"&I`0`L````2:D!
M``X```!VJ0$`)````(6I`0`4````JJD!`!P```"_J0$`&@```-RI`0`7````
M]ZD!`!P````/J@$`(0```"RJ`0`;````3JH!`!<```!JJ@$`+````(*J`0`L
M````KZH!`#````#<J@$`+0````VK`0`N````.ZL!`"L```!JJP$`7@```):K
M`0`@````]:L!`!<````6K`$`"````"ZL`0`>````-ZP!``D```!6K`$`#P``
M`&"L`0!`````<*P!`#$```"QK`$`'P```..L`0`.`````ZT!`%4````2K0$`
M3````&BM`0`&````M:T!`"(```"\K0$`#@```-^M`0`0````[JT!`!D```#_
MK0$`!@```!FN`0`*````(*X!``P````KK@$`#@```#BN`0`6````1ZX!``L`
M``!>K@$`$P```&JN`0`(````?JX!`"(```"'K@$`"````*JN`0`%````LZX!
M``P```"YK@$`#0```,:N`0`-````U*X!`#X```#BK@$``@```"&O`0`&````
M)*\!``T````KKP$`"0```#FO`0`'````0Z\!`!$```!+KP$`"@```%VO`0`E
M````:*\!``L```".KP$`(@```)JO`0`$````O:\!`"X```#"KP$`%````/&O
M`0`H````!K`!`&H````OL`$`%````)JP`0!$````K[`!`!\```#TL`$`#P``
M`!2Q`0`*````)+$!``T````OL0$`#P```#VQ`0`+````3;$!`!0```!9L0$`
M#0```&ZQ`0`9````?+$!`!4```"6L0$``P```*RQ`0`1````L+$!``\```#"
ML0$`(P```-*Q`0`1````]K$!`!0````(L@$`'0```!VR`0`0````.[(!`"<`
M``!,L@$`!P```'2R`0`)````?+(!`!0```"&L@$`$@```)NR`0`2````KK(!
M`!H```#!L@$`$@```-RR`0`/````[[(!`!8```#_L@$`"@```!:S`0`)````
M(;,!``@````KLP$`$````#2S`0`2````1;,!``8```!8LP$`$0```%^S`0`(
M````<;,!`!$```!ZLP$`!0```(RS`0`;````DK,!``\```"NLP$`+@```+ZS
M`0`2````[;,!``8`````M`$`!P````>T`0`8````#[0!``8````HM`$`$@``
M`"^T`0`%````0K0!`!D```!(M`$`!0```&*T`0`'````:+0!`!<```!PM`$`
M)P```(BT`0`%````L+0!`!L```"VM`$`$@```-*T`0`%````Y;0!`!(```#K
MM`$`$0```/ZT`0`$````$+4!``\````5M0$`"````"6U`0`'````+K4!``H`
M```VM0$`"````$&U`0`%````2K4!`"````!0M0$`,P```'&U`0`\````I;4!
M`!P```#BM0$`)P```/^U`0`@````)[8!`#X```!(M@$`&@```(>V`0`@````
MHK8!`"\```##M@$`6````/.V`0`G````3+<!``8```!TMP$`"````'NW`0`&
M````A+<!``L```"+MP$`&0```)>W`0`9````L;<!`"P```#+MP$`'P```/BW
M`0`;````&+@!`#8````TN`$`/````&NX`0`$````J+@!`!4```"MN`$`!@``
M`,.X`0`&````RK@!`"0```#1N`$`&0```/:X`0`1````$+D!``T````BN0$`
M!P```#"Y`0`.````.+D!``@```!'N0$`%@```%"Y`0`,````9[D!`!H```!T
MN0$`&P```(^Y`0`X````J[D!``D```#DN0$`!0```.ZY`0`%````]+D!``4`
M``#ZN0$`&P````"Z`0`2````'+H!``0````ON@$`"0```#2Z`0`+````/KH!
M`!````!*N@$`#@```%NZ`0`=````:KH!``\```"(N@$`!0```)BZ`0`%````
MGKH!``P```"DN@$`-0```+&Z`0!9````Y[H!`!X```!!NP$`!P```&"[`0`B
M````:+L!`!L```"+NP$`#P```*>[`0`2````M[L!``T```#*NP$`"````-B[
M`0`1````X;L!`"T```#SNP$`"0```"&\`0`.````*[P!`!`````ZO`$`%@``
M`$N\`0`-````8KP!`#H```!PO`$`"0```*N\`0`?````M;P!`!4```#5O`$`
M&0```.N\`0`[````!;T!`"8```!!O0$`/@```&B]`0`_````I[T!`#L```#G
MO0$`#````".^`0`0````,+X!``T```!!O@$`$@```$^^`0`6````8KX!``@`
M``!YO@$`%````(*^`0`2````E[X!``<```"JO@$`$P```+*^`0`H````QKX!
M``<```#OO@$`!@```/>^`0`/````_KX!``X````.OP$`%0```!V_`0`$````
M,[\!``@````XOP$`#````$&_`0`,````3K\!``T```!;OP$`$0```&F_`0`1
M````>[\!``<```"-OP$`!0```)6_`0`T````F[\!`"0```#0OP$`)````/6_
M`0`'````&L`!``\````BP`$`!@```#+``0`<````.<`!`"$```!6P`$`)```
M`'C``0`.````G<`!``D```"LP`$`'@```+;``0`#````U<`!``8```#9P`$`
M"@```.#``0`"````Z\`!``P```#NP`$`$P```/O``0`+````#\$!`!4````;
MP0$`&0```#'!`0`6````2\$!``4```!BP0$`"@```&C!`0`3````<\$!`!8`
M``"'P0$`#@```)[!`0`&````K<$!``L```"TP0$`"0```,#!`0`1````RL$!
M`%4```#<P0$`'0```#+"`0`Q````4,(!``\```""P@$`!````)+"`0`&````
ME\(!``L```">P@$`#@```*K"`0`-````N<(!`!L```#'P@$`&````./"`0`.
M````_,(!`!\````+PP$`#@```"O#`0`@````.L,!``X```!;PP$`#````&K#
M`0!J````=\,!`"0```#BPP$`%@````?$`0`F````'L0!`"(```!%Q`$`%```
M`&C$`0`9````?<0!`!D```"7Q`$`#@```+'$`0`8````P,0!``H```#9Q`$`
M!P```.3$`0`(````[,0!``D```#UQ`$`%````/_$`0`-````%,4!`#0````B
MQ0$`%````%?%`0`=````;,4!``<```"*Q0$`#@```)+%`0`[````H<4!`$X`
M``#=Q0$`+P```"S&`0!X````7,8!``H```#5Q@$`*````.#&`0`W````"<<!
M``@```!!QP$`"````$K'`0`,````4\<!`#8```!@QP$`"````)?'`0!)````
MH,<!`#D```#JQP$`*````"3(`0`@````3<@!`"<```!NR`$`(0```);(`0`L
M````N,@!`"8```#ER`$`+0````S)`0`F````.LD!`!````!AR0$`"````'+)
M`0`-````>\D!``\```")R0$`#@```)G)`0`'````J,D!`#0```"PR0$`#```
M`.7)`0`0````\LD!``8````#R@$`$@````K*`0`(````'<H!``<````FR@$`
M$````"[*`0`)````/\H!``D```!)R@$`"````%/*`0`0````7,H!`!````!M
MR@$`%0```'[*`0`7````E,H!``T```"LR@$`(@```+K*`0`2````W<H!``@`
M``#PR@$`#@```/G*`0`5````",L!``\````>RP$`#````"[+`0`F````.\L!
M``X```!BRP$`'P```''+`0`E````D<L!``D```"WRP$`!@```,'+`0`2````
MR,L!``H```#;RP$`!````.;+`0`;````Z\L!``X````'S`$`#P```!;,`0`/
M````)LP!``8````VS`$`"0```#W,`0`*````1\P!``D```!2S`$`#@```%S,
M`0`4````:\P!``0```"`S`$`#P```(7,`0`(````E<P!``L```">S`$`#P``
M`*K,`0`9````NLP!``H```#4S`$``@```-_,`0`@````XLP!``<````#S0$`
M!P````O-`0!R````$\T!``L```"&S0$`!@```)+-`0`F````F<T!`#X```#`
MS0$`'````/_-`0`G````',X!`%$```!$S@$`(0```);.`0`R````N,X!`!\`
M``#KS@$`%`````O/`0`%````(,\!``4````FSP$`#````"S/`0`+````.<\!
M``<```!%SP$`#````$W/`0`2````6L\!``X```!MSP$`"P```'S/`0`-````
MB,\!``L```"6SP$`!P```*+/`0`'````JL\!``H```"RSP$`%````+W/`0`)
M````TL\!``<```#<SP$`"P```.3/`0`A````\,\!``8````2T`$`*````!G0
M`0`%````0M`!``4```!(T`$`#P```$[0`0`%````7M`!``H```!DT`$`"0``
M`&_0`0`'````>=`!`!(```"!T`$`$@```)30`0`&````I]`!`!8```"NT`$`
M"P```,70`0`(````T=`!``4```#:T`$`!0```.#0`0`/````YM`!`!P```#V
MT`$`!P```!/1`0`)````&]$!`"8````ET0$`'````$S1`0`-````:=$!``0`
M``!WT0$`"````'S1`0`0````A=$!``D```"6T0$``@```*#1`0`'````H]$!
M`!\```"KT0$`)P```,O1`0`A````\]$!`"H````5T@$`*0```$#2`0!:````
M:M(!`!$```#%T@$`7P```-?2`0`N````-],!`$D```!FTP$`;````+#3`0`>
M````'=0!`#`````\U`$`*````&W4`0`Q````EM0!`"L```#(U`$`'P```/34
M`0`Z````%-4!`,L!``!/U0$`'````!O7`0`/````.-<!`#\```!(UP$`?```
M`(C7`0!#````!=@!`!H```!)V`$`,@```&38`0!>````E]@!`$@```#VV`$`
M(0```#_9`0`7````8=D!`!````!YV0$`'@```(K9`0`9````J=D!`!@```##
MV0$`)P```-S9`0`@````!-H!`!X````EV@$`,0```$3:`0`9````=MH!`!``
M``"0V@$`-````*':`0`C````UMH!`"$```#ZV@$`(0```!S;`0`B````/ML!
M`#D```!AVP$`5````)O;`0`O````\-L!`$<````@W`$`,````&C<`0`G````
MF=P!`$$```#!W`$`7@````/=`0!%````8MT!`#````"HW0$`+````-G=`0`K
M````!MX!`%8````RW@$`3P```(G>`0!*````V=X!`$D````DWP$`,P```&[?
M`0`L````HM\!`"P```#/WP$`+0```/S?`0!E````*N`!`%H```"0X`$`8P``
M`.O@`0"=````3^$!`!4```#MX0$`(P````/B`0`O````)^(!`"\```!7X@$`
M00```(?B`0`@````R>(!`%0```#JX@$`(0```#_C`0`+````8>,!`+4```!M
MXP$`2````"/D`0`?````;.0!`#8```",Y`$`(@```,/D`0`>````YN0!`"P`
M```%Y0$`!P```#+E`0`'````.N4!``,```!"Y0$`#0```$;E`0`+````5.4!
M``H```!@Y0$`"P```&OE`0`'````=^4!`!D```!_Y0$``P```)GE`0!;````
MG>4!``0```#YY0$`)P```/[E`0`$````)N8!``<````KY@$`!@```#/F`0`%
M````.N8!``0```!`Y@$`$P```$7F`0`(````6>8!`!$```!BY@$`%0```'3F
M`0`"````BN8!``<```"-Y@$`!P```)7F`0`,````G>8!``X```"JY@$`!@``
M`+GF`0`4````P.8!``P```#5Y@$``P```.+F`0`G````YN8!``0````.YP$`
M!@```!/G`0`(````&N<!`#`````CYP$`1P```%3G`0`N````G.<!`"\```#+
MYP$`&P```/OG`0`O````%^@!`#(```!'Z`$`)````'KH`0`A````G^@!`",`
M``#!Z`$`*````.7H`0`C````#ND!`"$````RZ0$`*@```%3I`0`I````?^D!
M`"(```"IZ0$`,P```,SI`0`?`````.H!`#`````@Z@$`+0```%'J`0`B````
M?^H!`"8```"BZ@$`)0```,GJ`0`@````[^H!`"D````0ZP$`*0```#KK`0`E
M````9.L!`"\```"*ZP$`'````+KK`0`A````U^L!`"4```#YZP$`*0```!_L
M`0`@````2>P!`"H```!J[`$`/@```)7L`0!!````U.P!`!T````6[0$`)```
M`#3M`0!`````6>T!`"4```":[0$`*0```,#M`0`H````ZNT!`"D````3[@$`
M(P```#WN`0`@````8>X!`"H```""[@$`)0```*WN`0`Y````T^X!`"<````-
M[P$`-0```#7O`0`,````:^\!``P```!X[P$`%````(7O`0`O````FN\!`",`
M``#*[P$`"P```.[O`0`7````^N\!``X````2\`$`%@```"'P`0`(````./`!
M``<```!!\`$`(@```$GP`0`E````;/`!`!X```"2\`$`)P```+'P`0`E````
MV?`!``P```#_\`$`ZP````SQ`0`/````^/$!`!@````(\@$`#````"'R`0`/
M````+O(!`!@````^\@$`'P```%?R`0`?````=_(!``8```"7\@$`-0```)[R
M`0`6````U/(!`!0```#K\@$`!P````#S`0`3````"/,!``H````<\P$`/```
M`"?S`0`*````9/,!`"@```!O\P$`$P```)CS`0`8````K/,!`!<```#%\P$`
M.````-WS`0`@````%O0!`!(````W]`$`)````$KT`0`3````;_0!`!0```"#
M]`$`%0```)CT`0`*````KO0!`!<```"Y]`$`"0```-'T`0`=````V_0!``@`
M``#Y]`$`'`````+U`0`F````'_4!``<```!&]0$`(P```$[U`0`'````<O4!
M``@```!Z]0$`"0```(/U`0`T````C?4!``8```#"]0$`$````,GU`0`5````
MVO4!`!0```#P]0$`"P````7V`0`,````$?8!``<````>]@$`"P```";V`0`<
M````,O8!``\```!/]@$`&````%_V`0`9````>/8!``L```"2]@$`#0```)[V
M`0`7````K/8!``D```#$]@$`*P```,[V`0`,````^O8!``\````']P$`"0``
M`!?W`0`"````(?<!`!$````D]P$`&````#;W`0`+````3_<!``,```!;]P$`
M"P```%_W`0`(````:_<!``<```!T]P$`"P```'SW`0`+````B/<!``X```"4
M]P$`+0```*/W`0`:````T?<!`!H```#L]P$`(0````?X`0`*````*?@!`#H`
M```T^`$`!0```&_X`0`6````=?@!`#<```",^`$`#0```,3X`0`.````TO@!
M``8```#A^`$`!````.CX`0`&````[?@!``L```#T^`$`%P````#Y`0`'````
M&/D!``@````@^0$`!P```"GY`0`(````,?D!``4````Z^0$`#P```$#Y`0`0
M````4/D!`#X```!A^0$`,0```*#Y`0`D````TOD!``4```#W^0$`&@```/WY
M`0`A````&/H!`"$````Z^@$`(P```%SZ`0`1````@/H!``(```"2^@$`!```
M`)7Z`0`*````FOH!``4```"E^@$`!0```*OZ`0`#````L?H!``D```"U^@$`
M3````+_Z`0`E````#/L!`!@````R^P$`+0```$O[`0`E````>?L!`%\```"?
M^P$`$P```/_[`0!Y````$_P!`!P```"-_`$`4P```*K\`0`B````_OP!`#\`
M```A_0$`-````&']`0`L````EOT!`#8```##_0$`-@```/K]`0`U````,?X!
M`#,```!G_@$`*````)O^`0`B````Q/X!`"8```#G_@$`3`````[_`0`4````
M6_\!`#0```!P_P$`#P```*7_`0!O````M?\!``D````E``(`H@```"\``@![
M````T@`"`'````!.`0(`*````+\!`@!4````Z`$"`!H````]`@(`*0```%@"
M`@`7````@@("``H```":`@(`'0```*4"`@`=````PP("`#0```#A`@(`(P``
M`!8#`@`8````.@,"`%0```!3`P(`'@```*@#`@`7````QP,"``H```#?`P(`
M!````.H#`@`&````[P,"``@```#V`P(`!0```/\#`@`5````!00"`!,````;
M!`(`&0```"\$`@`E````200"`!````!O!`(`#@```(`$`@`$````CP0"``D`
M``"4!`(`#P```)X$`@`(````K@0"``D```"W!`(`%@```,$$`@`-````V`0"
M``P```#F!`(`$0```/,$`@`+````!04"``8````1!0(`$P```!@%`@`+````
M+`4"`!8````X!0(`#0```$\%`@`'````704"``\```!E!0(`"````'4%`@`)
M````?@4"`"4```"(!0(`&P```*X%`@`,````R@4"`"0```#7!0(`$@```/P%
M`@`>````#P8"`!0````N!@(`$0```$,&`@`%````508"``4```!;!@(`(0``
M`&$&`@`(````@P8"``(```",!@(``@```(\&`@`6````D@8"``@```"I!@(`
M"````+(&`@`4````NP8"`!8```#0!@(`"````.<&`@`M````\`8"``(````>
M!P(`!````"$'`@`0````)@<"`!<````W!P(`#P```$\'`@`'````7P<"`!(`
M``!G!P(`!0```'H'`@`;````@`<"``4```"<!P(`%@```*('`@`1````N0<"
M`!(```#+!P(``@```-X'`@`(````X0<"``\```#J!P(`"P```/H'`@`-````
M!@@"`"0````4"`(`"P```#D(`@`,````10@"`!,```!2"`(`!0```&8(`@`"
M````;`@"``L```!O"`(``0```'\$``";`@```````$8#``!I`@``+P0``!\&
M````````4P$``%,`````!````P$```````!\`0``V`0``'T$``!!!P``204`
M`#8#```E`P``#@,``'<#```S!```IP$`````````````+0``````````````
M`````,\$````````NP```,T!```%!0``U0,```T"``````````````````#=
M!@``>0$``*T&``"Z`0```````.H!``"D!```4@(``"P!``"^!0``7P4`````
M```U!0``T04``'T!``!<!```(P<```````#U`0``:04``!8#``"V`P``````
M`!D%``#G`0``+@8``&H"``"-!0```````&$"``"Y!0``@```````````````
MOP(``#L"``"K!0``=`(``#4#```=!0``G`$``+\%``#9`0``/@4``+$"``"1
M!0```````.<%```L`````````&,#```5````FP$``'H#``#3`0``30$``$P&
M``#C````[0,``&8!``#'`@``R`(``#H'```9`P````````````!'!0``108`
M`(8!```+!```C00````````+````%P$``!X"````````=@8```````#T!@``
M`````,P"```W!P```````#,`````````M`(``/,%````````-@4``)@%``!J
M`0``S@$````````3!P``7````+$#``![!@```````'T```"-!@```````%D!
M``!-`@``^P$```8```#2``````````````#8````$08```````#O````````
M````````````0P(``*(&````````XP,``&H$```G!0``$`4``*P%``!$````
M`````$D```!B`@``VP4``#L'````````6`4``*D%```4`@``@0$`````````
M````'@8``+T`````````80<``)P&````````'0(``$@%``#0!@``-@```"8%
M`````0``N`$``+$!````````Y`8``%,'````````9```````````````]`,`
M`%4#``#J!0````````4!``#"`@``0P8```````!Z!@``Z`4```````!.`@``
M.P0``-("```1`````````#T!``![!```8@,``(X&````````````````````
M````8`4``/@&```8!```JP$``(8%````````J0```+<"````````````````
M```8`P``EP8``-\#``#Z!````````.0```#Q!```KP0``%P%``#Y`@``!P$`
M``$'``!0!0```````$<#````````Y`4``+0$``"!````!@0``*4&```?!0``
M``````````#9!```90$``%`$``#U`P``$0(```<$``#H`@```````'P$``#.
M!0``G04```````#P`0``:@4```@!``!H!0``KP,````````?`P``1P$``&,&
M``"4`P````````````!\`P``O00``%8$``#;````\@0```````"U!@``"P<`
M`-$$``!I!```H`$``)H%``"R`P``2@,``/(%``!>!@``<0```!P$````````
M2`8``,\!``#@`0```````"@"``!F`@``Q`$```````#I````V`(``)H#````
M````'@4````````0`0``*P$``.L```#7!0```````%$#``#5!@``,0$``!P'
M``!L`0``10,``#8"``"4`````````#$```";!@``M00``&P&``"T`P``````
M`)0%``#U!0``2`0`````````````+`<``/4&```Y!P``30```"D'```M!0``
M)P$```````!:`P```````-<&```F`P```````-<$``!"`````````/P"``"Y
M!```<P8``&8%``![`P``#P0``!(&```4`P```````&T#````````H08`````
M````````U0(``($%``!-!@``&P,```\"````````?@0```@"``!M`0``````
M`/X%```Z`P```````````````````````.(```"/`0``&0$``)X`````````
M\`0`````````````200``!$!``"X````"00``(@%```````````````````^
M````+08``$($``#"!```````````````````1P0```````#<`P``A@,`````
M``#D`@```````+@"```D`P``=@$``(L!```"`@``>`0``#\%```/`P``````
M`)8"``#_!@``,P8``&@"```@`P``%`````````"O`@``O`0``)4```!$!0``
M/08``-8````5`0``U@0``.$&`````````````$$#``#S`P``W`(```````#2
M!0``U`4````````&`0``DP``````````````\04```0````%`P``,````#0&
M```I!@``-08``&D#```\`P``MP8``,T$``">!0``X04``!0$````````=P$`
M`,L&```8!P```````&4"````````G`4````````(!P``E`0`````````````
MC@$``.P%```I````>P4``&,```":`@``S0,``%$```"D`P```````+\$``!O
M!@``GP4``"`"````````W@0``((#```'`@``RP4``*`&``#-````5@8``!X#
M``"2`@``/00```````!Z!0``*@4``+,```!U````3@,``$`#``!N!0``````
M``H```#L`P``````````````````(@<```````"9`0````````````"D!@``
M5P4``$4'````````\@```*L#```2`0```````",$``!S`@```````.`&``"N
M`@``20$``&D&```M!P``?````(0"``#1`0``8`,`````````````10```/0"
M````````[@$``'$#```J````M`$```````#\`0``Z0(``*,$``"_`0``````
M`*H````\!P``S08````````R`@``#`<``+8$``!J````9P(``#D%````````
M"`,```````!"`0``A`8````````:`0``+P4``+(&```5`@``]0(```````#'
M````808``+8&``#&````B`0``!X$````````A0$``/$&``#@````,P<``(<&
M``#C`@````````````"H`@``_0(``%\"```K!0```````#4$```\!```60(`
M`+($``"9!```*@(``.8&``!(`P````````````#(!0````````````"Z!0``
M6`8``*<#``````````````T%````````F`$``.P`````!@``&@4```````!_
M!0``_`,``)8#```[!@```````/D%````````]`````````"`!0``"@<``&T$
M``""!@```````.8$`````````````#<&``"#!0```````.X"``"Y`0``E00`
M`/@#``"W!0``;@$``/X`````````D08``)<%````````9`8``"$&````````
M#0```"`$``"`!@```````"$'````````J`,``!T#``"?`````````$X$````
M````C````"$$``#/!0``IP8``-8&``",`@``````````````````+`4``,T%
M``!&!```&P$`````````````4@$``*T!``"N`0``^P8``/8!``"N!@``2@``
M`!(%``!%!````````&P#```V!```?@4``#H!```^`@``9P$``"@&``!:`@``
M``````\```#*!0``/````````````````````,L!``#.`````````/H%``"3
M!@``(`<``.<#````````,@$`````````````H0,``.@#```%`@``!`,``*`%
M````````%08``+,$````````]P0``+8!````````0@,``)L#``!D`P``Q0(`
M`*P!`````````````!L"```Q!P``'`4``#<%``!/````Y`$``*$````8!0``
M)`0```````"3`@```````+$&``!4````S`0````````3`@``D0$``%$%``!$
M!```<@4``$L%```2!```L@4``%P&``!;!@``7P0```$&```\!@``L`$``(0$
M``"=````8@```/("``#Q`P``;0````````#(`P``%@$``!H"``#_!```5@<`
M```````L`P```````+@&``#/`P``CP(``$\&``#'`0``````````````````
MEP$```````"9`P``=`8```````"8`@``>0```,$#```G`@``,@4``!`&``!D
M`@``_04``,L$````````+`0``,,!```8`@``>04``)<#``!K````#`0`````
M``!9````/04``-D`````````6P$```T!``!Q!``````````````(!@``````
M`&@```"*````5`(```````"^`@``HP8``!,```";!0``9`$``-<!```D`@``
MJP8``)L$```$!@``````````````````8@<``,(%````````,`(``#@%```C
M!@``@P$```$#``!*`0``J`4``,4````<````-0```.\&```C`@```````*4"
M```)`P``DP$```````"'````&P0`````````````CP,````````O````1@8`
M````````````6@<``*D$`````````````"$"``!-!P``N`,``"L$``#:````
M`````!X!``"=`P``&@0``#P!```.!@``6@0````````````````````````E
M!0``F04```````#4!````````%D#```@!0```````#@#````````6P<`````
M``#4````OP```*@````S!0```````)\!```'!@``A@8``$$`````````&`$`
M`#\"````````>`8``!<$```_!P``N@0``+@%```=`````````"H$``!7!```
M`````-`````$`0``C0```*0```"-`@``@@0`````````````KP8``#D&``"^
M`0``!0```&X#``"R````*P(``!8$``"1!```4`(``.,$``#G`@``V@(``#H`
M```"!```*0,``%,#````````Y`,``-X"``#Z`0``_@(```````#)!```%@(`
M``````#Z`@``MP$``-$```!V!0```````#8&``#8`P``TP0``+D````4!@``
MZ00``($$`````````````+D&````````Y@```'T&````````;````(`!```B
M!0``S`$``,P&````````&P8``$X%````````LP8``%P'````````2P```*D&
M```I!0``;@```#,"````````!`4``'$&````````2@4``%D&```9````A`$`
M`-4%```[`P```0(````````>````<@(``&@#``#`!```<@0``.4%``"A`0``
M`````$P$``#E````C`$```H!````````+0(``#\$``#)!0``X00``!("```1
M`P```````#$#````````M``````````&!@````````X!```C`````````%T!
M``#=`P```````````````````````*H#``#S````G@0``)@```!9!0``````
M`$$"````````G@,```````!O`@``5@$``*$"````````+@0``,<$````````
MO@0```````!_!@``^`0```````#N!````````+8```"L`@```P4``#0'```6
M!P``Q`0``",#```T`P``%P```$X&```I`@``UP(``/L#``#7`P``-0(``.4$
M``"H!@```````!P&``#N`````````,H``````````````%4$```F`@``%P(`
M`-T``````````````-\``````````````*\!``!2````"@(```````#V!0``
M`````$8```"-`0``?@8``#H%`````````````-L!```A`P```````-8#````
M````3@<``*8"```M!```R`0``.(!```P`P``5`4``,,#```R!P``)`8`````
M``!H!````````.\!``!;`@``,04``!8`````````<`8``%T%```,!@``N@(`
M`$\#``#+`P``3`,``'8```"O````&P```.H&``!E!@``Z`$``!4$``"I`@``
M`````)(!``!2!0``W@,``#0!``"E!0``<@,``#0$``#<`````````+L%````
M``````````````"#!```J@4```0'``#T`0``-P```)\#``#S`0``````````
M``",!0```````/P```"5`0```````&8#```'!P```````&\#``"&!```GP0`
M`'P"``"E`P```````"L#```J!P``>0,``)$#``"N!```40$``$`"````````
MW`$``/,"``"G````1@4``*`$````````^`$``.T&``!$`@``'@<``,H$``!O
M`0``YP0``.,!``#]`````````!`"``".`P``$P8``%@!```B`@```````(4%
M``!G!```X0(``(<%``!7`P``)@0``%P!````````'0<``)H$``"<`P``@@$`
M`%`!```N!0```````,@!``!`!0``"@,````````K````;@(``*,#``!Z`@``
MF08```````!=`@``R0```#@```"&````$`<``#`!``!^`P``\@8``&X$``##
M`@````````````"*!@``!P```.D&````````S`,```````"Y`@``$@<``&L"
M``#2!@``H@$````````I!```'P```(4"``".````,P,``"X'``!)`P``````
M`#(&```#````P`8```````#8`0``400``,0&````````A`4``#\&``#0!0``
M]0```````````````````(D$``!J!@``4@8``&D!````````8`<```````"C
M!0``-0<```````#P`````````.<&``#O`P``EP```(<"````````70``````
M```.!0``%`$`````````````IP(```````!'`````````,D"``!`!@``````
M`"L'````````]@,``$(%``!+!@``1P(``-T%``!-!```T0(``(X$````````
M]P4```````!8`P``?04``#$$````````8`0``-(!``"N`P``*`<``(H#````
M`````````&P$````````^P```-<````)!P``]P8``&$!``!5!P``*`4`````
M``"7`@``90````````#E`@``10(````````:`P``[`(``&4#``#)`0``W0$`
M`+P%``"0!````````'@%``!(`@````````````#A````G00``$$!``"D!0``
M``````````!+`@``^08``',!```I`0``K`8``$\!```_`P``BP(``%@'````
M````Q00```````#T!0```````$L#````````8`$`````````````]P,`````
M``"2!0``=`0``.L&```P!P``B0```&L#``#I!0```````-0!``![````:`8`
M``````"%!@``VP8```````"#`@``4@,```(`````````[00```````#.!```
MK@```"\&````````'08``*<$``##````80````````!0!@``F@$``%`#```E
M````L`8``(<#```^!P``208``)`"```X!P````````T'```:````<`(``*0"
M``"+!```M04``&8```#?`0``5@,``.\$``"4`@``(`8``#`$``!O````C`,`
M`"($``"B!0``'`,``$(&``#C!0``#@````````!V`@`````````````(!0``
M7@````````!.`0``B`8``$P`````````)P``````````````<@$````%``!Q
M`0``\`(``+\#``"$`P````````````#"!@``D`,````````(````)P<``%@"
M``!>`0``<`$``',$``!(`0```````-$&```X!```4`<``&L%````````5`<`
M````````````?@```/$!``#:`P``5@```%X'```E!@````````D"``#?!0``
M`00``&4$``!)!P``#`,``+X&``#E!@``!`0``%$'``!K!```D`$```X"````
M````]@(```````!?!@```````'T"``#O`@```````$H$``#G````A00``/D`
M``!/!P``WP0``)T&````````;@8``.H#``#Z!@``V`4`````````````O04`
M`````````````````%T#``!>!`````````````#%!@``I@,````````%!@``
M``````````"F!@```````"X!``#$`P``]P$```````#&`0``NP,```,'````
M````2@<``(<$````````\`,``````````````````*\%````````7@4``'`$
M``#)`P``<P```,`#```0````W@```%($``!3`@```````,\"``#*`P``[@8`
M``4'`````````````%0#```]`@``_@8``"@$``"6!@``(@`````````&!P``
M50```#<$``#=!```VP(``*T"````````$@,``.T"```9!P``;0(``,X&```X
M!@``O`,``%\#````````60<``"P"````````S`4``,H"``#C!@``*````!<'
M````````_P```'L"```)!0```````#8!``"C`@``M@(``$4!``"9````JP(`
M`!P"`````````P(`````````````L`4``'0```"+````````````````````
MG`0``%<&``#5`0``I@```$`!``#F!0``-@<```````#=`@``````````````
M````6@```%0&````````)P0``*T%``",!````````'\"``"F!```LP4``#$&
M```P!@``B@(``%8"``"*!0``<P,``%````#0`P```P,``(`$````````````
M``````#^`P``#````)4"``!,!P``D`4``+0%````````C0,```````!W````
M[0$``$<&``"8`P``5@4```````````````````````".`@``Q04``,4#``!+
M!P``W`8``!$%``!H`0``HP```"8&``#>!0``3P(`````````````R@8````"
M``!U`0```````$0'``#Y`0``[0```,D&```C`0```````.D#``"%````50$`
M`&0$``"P`@``#P8``!8%``"\`0```````#0"```"!0``A`````````#!`0``
MA0,``.@$``"7!````````)0&``"5!@``904``/8$``!L!0``LP$``!<%```Y
M!````````/`&``!)`@```````+`$``````````````L!``!Z`0``V@0``$,%
M```+!@``E@$``-\&````````%`4``$,'```M`P``#P4```````!G````T`(`
M````````````<`4```L"``"<`@```````-,```!K!@``8`8`````````````
M````````````````@P8`````````````S@,``'0#```*!0``H`,```````#3
M!0``(@,``)P`````````GP(``#P%``"Z`P``X@0``!D"``!X`P```````/T!
M````````8@4``*@!``#```````````````!?````K`0``&,'```A````````
M``(!```,`@``NP0``!8&``#F`@``!@(``,`%``#&`P``<````#,!``#?`@``
M304`````````````E`$```````!<`P``D@0``&L!`````````````/`%````
M```````````````X`@``=0(```````!@`@``:@,``$('`````````````+H`
M```)````(04```````!\!0``G0$``.X#````````^````#X!``!(````]00`
M`*,!``!:`0``MP,``!T$`````````````"8!``#0!```@@(```P!``!9!```
M>P$``#X&``#Q````V@$``%\!``#V````NP(``-L#`````````````.$!```Y
M`@``.@(```T$````````_`0````````R`P``2P$``.@&```R!````````!L'
M``"K!```<`,``$$$``"(`0``504``"8'````````>0(``'4#``"W````R```
M`)H&``"!!@``^00``#0%``!C`0``Q`4``*D!``!`!````````.H"``!A!0``
M;08``*H&````````9@8```````#>!@``9@0```````"6!0``!@,``#X$```D
M`````````(\$``"/!0``+P,``/0$``!/!````````*T`````````=08`````
M```3!````````!\"```````````````````3`0``1@<``.$#``!W`@``!00`
M``````#&`@``H@0``%H%```T`````````+H&```;!0``GP8``$$%```5`P``
M2P0``+4```#/`````````(8"``""````PP8```D&````````^0,``'H````^
M`P``P0```````````````````&\$``#&!0```````!@&``!Y!@``Q````(,`
M``"]`P``!P,``*0!``"Q!```MP0``"4"``!;````T`$``',%``#F`P``?P``
M````````````U`(``(`"``#K`P``3`4``,,$``#K!0``E04```````!"`@``
M>`$`````````````(0$````````@````8@8```$!```2`````````*`"```D
M`0``Q@8``*T$``#N!0``104``+P``````````````.H```"Q`````@8``*T#
M``"6!```QP4``'\#`````````````+L!``!7!P``J`0````````0!```'P0`
M`!4%````````VP0``/\%````````<04``#<#``"A!0```````.("```J`P``
M>@0``/H#```N`````````.H$``!5!@```````"`!``!C!0``CP8```````#&
M!```6P4```````!D!0``700``!,#```B`0``T@,``.@`````````Y@$``%L$
M```D!P``9P4``(`#``"6````&08``(L%````````L04``-0&``#^!```=@0`
M`,<&````````G0(``)H```".!0``2@8``+4!`````````````*4!```B!@``
M008``-8"``!&`0``9P,``%$&``#\!@``0P```.(#`````````````*(#``"V
M!0``D@8``$X`````````=P4``%0!``"*`0``J@$```````!C!```.@0``"\'
M````````,0(``/\#``!#`P``_P(``%,%``"*!```40(``!\'``"T!@``[`$`
M`#L!``")!0``O08``*P#``#E`P``=@,``%T'``!7````\@$```````#3`@``
M#0,``"0%```[!0``Y0$``"P&``!@````ZP$``#<"````````O`(``'\!``#:
M!@``X@8``-P%`````````````````````````````*``````````3`(`````
M```Z!@``_00``*8%```5!P``=`4``/,$``"+`P```````(@"``!5`@``D@,`
M`/\!``#+`@```````%X#``#5!```"`0``)`````4!P``BP8````````7`P``
M6`0``'T#``!X`@``#@0```````#L!`````````````"B`@``+P(````'```K
M!@``$`,``/(#``!\!@``0````*H$``!G!@``J0,````````]````$0<``-,#
M````````"@0``.L$``#9!0```````!D$``"3!```DP4``+("``#:!0``%P8`
M`/<"````````NP8````````"!P``1`,```<%``"\!@``L``````````/`0``
M;P4```````#*`0````````````#X!0``0P$``"H&````````8P(``,`!``#5
M````U@4```````#"`0````````````!T`0``X`0`````````````X`(`````
M``!B!```/0<```T&``#D!```;`(`````````````+0$```L#``#]!@``(P4`
M`(D!```:!P``>00```````!#!`````````````#-`@``708``+,#```_````
M^P(``````````````````-X!``!$!@``Q0$```````#8!@``,`4``%@```!3
M!@``L`,```````"8!@```````%\'``"1`@``2@(``-D"``!A`P``800``*H"
M``">!@`````````````*!@``\0(``.`%``"2````5`0```L%````````*`$`
M`+4#``"^`P``O0$``)@$`````````````,$%```Y`0``I0```.`#`````P``
MB08``,$$```N`@``"0$``(@#``#/!@``@0,```````!I````O0(``,$&``!'
M!P``^`(```$%```G!@``*@$````````=`0``B````-D&``"R`0``````````
M````````=00`````````````4@<``,(```#$`@````````````",!@``^P4`
M``````"U`@``+P$```````">`0``TP8``)X"````````_`4``((%````````
M#`4``'<$````````0`<`````````````T0,```````"_!@``D0```"4'``!/
M!0``ZP(``*(````.!P``W`0``*<%``"0!@``````````````````````````
M````````-0$````````N`P``)00```\'``"X!```/0,``.P&``#]`P``!`(`
M`+X```#2!````````/8&`````````````.T%````````S@(``#L```"L````
M,@```(,#````````P0(``'4%``"N!0``/P$````````F````>`````````"S
M`@``U`,``%H&``!Q`@```````'(```!M!0``3`$```````#O!0``?@$``!$$
M````````7`(```````"!`@``P`(``!P!``"E!```2`<``/X!``#(!@``AP$`
M`)D"````````CP``````````````V0,``#<!``!^`@``.`$``-8!````````
M5P$```````"K````E0,``,<#``!R!@``!@4````````\`@``1@(``/<```!$
M`0``&````%<"````````8@$``,L```#I`0``I@$``"@#``#[!```30,``/H`
M``#B!0```````(D"```3!0```````,(#`````````````)L`````````````
M`#D````:!@```P8``%,$````````DP,```````!>`@````````````"A!```
M`@,``#D#```?`0````````,$``!W!@``)P,``"4!````````\P8```````#,
M````PP4``(D#``"Y`P``6P,````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME
M>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE
M<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@
M:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`
M(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S
M(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO
M=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@
M5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E
M<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E
M<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R
M`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M
M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@
M0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U
M<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A
M:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!
M4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B
M<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF
M;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C
M;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S
M:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI
M<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@
M;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A
M9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!
M;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI
M<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M
M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`
M06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`
M06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N
M=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES
M=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S
M`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F-H:79E($9I;&4@
M4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`
M07)G96YT:6YA`$%R;65N:6$`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`
M07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S
M=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T
M;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL
M960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL
M960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H
M96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L
M92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`
M0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K
M97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;F=L861E<V@`
M0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U
M;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R
M;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO
M;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S
M.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N
M80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U
M;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D
M:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET
M92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S
M:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N
M`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`
M0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#97)T:69I8V%T92!$
M971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`
M0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAO;W-E($%P<&QI8V%T:6]N
M.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@
M:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC
M92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U
M<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O
M;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D
M<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S
M`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`
M0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L
M=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE
M;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD
M:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O
M;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE
M<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`
M0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H
M92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE
M9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E
M<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#
M;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@
M(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F
M86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A
M<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I
M;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@
M;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F
M<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R
M:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R
M;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I
M=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D
M('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R
M96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R
M96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U
M<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N
M`$-Y<')U<P!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O
M:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E
M($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L
M;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(
M;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O
M<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I
M`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB
M;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`
M1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG
M;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`
M1')U9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET
M($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U
M8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`
M16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA
M:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO
M=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A
M<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO
M=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C
M=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U
M(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T
M:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A
M`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A
M=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%
M<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U
M<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S
M,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H
M86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E
M`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@
M8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A
M=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@
M=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N
M+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z
M("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES
M;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,
M:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S
M`$9I96QD(&UA=')I>`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R
M=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S
M(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-
M971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL
M($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E
M("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M
M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G
M;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96YL
M86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'
M=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S
M=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`
M2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96EG:'0`2&5L<`!(96QP('5S:6YG
M(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI
M;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@
M0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`
M2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$
M(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D
M9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I
M='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N
M<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!)
M;6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE
M<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F
M=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R
M96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`
M26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T
M(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`
M26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T
M(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A
M<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A
M9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@
M26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N
M="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H
M57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A
M<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U
M8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED
M(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C
M871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@
M:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!)
M;G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!)
M;G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`
M26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3
M=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU
M87)Y`$IA<&%N`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S
M=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y
M(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W
M8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`
M2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R
M9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I
M;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E
M<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO
M`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E
M;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A
M<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!2
M86EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R
M`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`
M3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B
M;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R
M`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI
M<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,
M:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4
M:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S
M:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`
M3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R
M(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R
M`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-
M87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O
M=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL
M($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI
M80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!"
M;&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M
M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`
M365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T
M(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E
M<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W
M86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@
M240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I
M;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I
M960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@
M;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N
M='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE
M("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A
M<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,
M969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA
M;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S
M96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY
M(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4
M($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.
M971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P
M92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE
M='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE
M='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E
M<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G92!T;R`E
M<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N
M9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X
M+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA
M;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O
M<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI
M=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H
M86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L
M969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E
M9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A
M=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S
M<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F
M;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I
M9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO
M('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F9O;&L@27-L
M86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O
M<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO
M=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB
M97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M
M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A
M=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A
M;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W
M;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E
M;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA
M:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R
M<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`
M4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG
M`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L
M;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`
M4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0
M87-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P
M<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI
M<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P
M:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R
M(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@
M=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU
M;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0
M;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``
M4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E
M=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B
M;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`
M4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN
M9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475O=&$`4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%
M87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN
M('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A
M9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U
M<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H
M:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E
M`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG
M`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S
M97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A
M<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y
M`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R
M9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V
M86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@
M,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2
M;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@
M2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN
M="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'
M<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U
M9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS
M`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T
M('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@
M)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!3
M96%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE
M8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A
M('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T
M`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A
M;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E
M>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S
M:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG
M`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@
M:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H
M;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``
M4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@
M4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3
M:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`
M4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R
M:6-A`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`
M4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET
M(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3
M=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`
M4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3
M=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL
M92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE
M8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H
M92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S
M="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S
M<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V
M960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3
M=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E
M<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES
M90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U
M<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A
M;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN
M8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T
M97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD
M(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE
M`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I
M=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M
M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T
M=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R
M871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H
M86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ
M960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S
M92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4
M:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I
M;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C
M86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N
M(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE
M="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD
M+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I
M<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/
M2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D
M:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T
M("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S
M(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE
M(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`
M5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS
M90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A
M:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I
M;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U
M<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG
M92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE
M('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@
M96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N
M86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L
M>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN
M`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV
M92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D
M*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H
M92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E
M<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA
M8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D
M871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@
M97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@
M;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O
M;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!T;SH@`%5N9FEL960`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`
M57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E
M<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG
M`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=R`E<P!6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(
M5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E
M8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B
M`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M
M92P@)7,`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R
M96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T
M:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R
M;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I
M<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS
M:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@
M9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O
M;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@
M9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F
M;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T
M(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M
M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`
M66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S
M92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T
M('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P
M<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED
M96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET
M>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S
M:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@
M<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A
M8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=
M`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L
M:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$
M871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P
M97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/
M<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]4
M86)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S
M<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L
M:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E;G1R>2!N
M;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`
M:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M
M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L
M<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA
M=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``
M<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A
M:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF
M:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#8M,#$M,#8@,30Z,3`K,#$P,`I03RU2979I<VEO;BU$871E.B`R,#`V
M+3`Q+3,P(#(Q.C(V*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!)=F%N($YO<FES
M(#QV:7A`=F%Z:V$N<VL^"DQA;F=U86=E+51E86TZ(%-L;W9A:R`\=FEX0'9A
M>FMA+G-K/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X+6)I=`H`("AP<F5D("5S(&3R86UI*0`@*$MLX79E<V]VX2!S
M:W)A=&MA("5S*0`@*&\@)7,@9&[M*0`H9&YE<RD`("AZ86IT<F$I`"`H=NAE
M<F$I`"!R_6-H;&]SNR``(B5S(B!N:64@:F4@861R97/A<BX`(B5S(B!N:64@
M:F4@<&QA=&[A('9OM6)A+@`B)7,B(&YI92!J92!N86MO;F9I9W5R;W9A;ND@
M=B!R96=I<W1R:2!(;W)D92X`>F]B<F%Z;W9AZ"!S=')O;74@(B5S(B!N96)O
M;"!NX6ID96[]+@!3:W5P:6YA("(E<R(@8F]L82!P<FED86[A(&1O('-Y<W3I
M;74N`%!RX79O("(E<R(@8F]L;R!P<FED86[I(&1O('-Y<W3I;74N`"(E<R(@
M;F5B;VQO(&UOOF[I('9Y='9O<FF[.B`E<RX`4&]UOFET_6-H("4N,F9-0B!Z
M(&1O=F]L96[]8V@@)2XR9DU"("@E+C)F)24I`"5D("5S(&$@)7,`)60@9&[M
M(&1O('9Y<'*Y86YI82!P;&%T;F]S=&D@5N&Y:&\@:&5S;&$N`'!R961P;W9E
M[R!N82`E9"!D;NT`)7,@+2!0;WINX6UK80!/9'1L8>AO:R`E<P`E<R!+0@!/
M<&5RX6-I92#Z9'*^8GD@<')E(&%P;&EKX6-I=2`E<R`M(%!O='9R9&5N:64`
M3F%S=&%V96YI92`E<P!296=I<W1R;W9A;FEE(&1O(&%P;&EKX6-I92`E<P!0
M;V1M:65N:WD@<&]UOFET:6$@)7,`)7,@=;X@97AI<W1U:F4N`"5S('9O(';]
MN6ME("5S("5S`$%P;&EKX6-I82`E<R!J92!P<FEP<F%V96[A(&YA('9Y:V]N
M86YI92!O<&5RX6-I[2#Z9'*^8GDN3WIN8>AT92"Y='9O<NAE:R!P<FD@;W!E
M<N%C:>%C:"P@:W1O<ND@8VAC971E('9Y:V]N8;L@=&5R87HN`%!OOF%D=6IE
M('-A("5S`"5S(&UI;OIT`"5S(&YE8F]L(&[A:F1E;OTN`"5S(&&^("5S('H@
M)7,`061R97/A<B!P;W6^[79A=&6U82`E<P!+86QE;F3A<B!P;W6^[79A=&6U
M82`E<P!0;WINX6UK>2!P;W6^[79A=&6U82`E<P!:;WIN86T@^FQO:"!P;W6^
M[79A=&6U82`E<P`E<SH@)7,`)7,Z(%3A=&\@<W!RX79A(&YE;75S[2!B>;L@
M;V0@;V1O<VEE;&%T9;5A+"!K=&]R_2!S82!Z;V)R87IU:F4@86MO(&]D;W-I
M96QA=&6U('-P<N%V>2X@6F%C:&]V86IT92!O<&%T<FYO<[L@<')I(&ML:6MA
M;NT@;F$@;&EN:WD@=B!S<'+A=F4@86QE8F\@<&]S:WET;W9A;NT@;W-O8F[]
M8V@@:6YF;W)MX6-I[2!O9&]S:65L871EM6]V:2X`+"!NX7)A>F]V_2``+"!V
M(&[A<F%Z;V-H("5S("5S`"P@<')E;65N;N$@=B!R;WIS86AU("5S(&&^("5S
M`"TM('9Y8F5R=&4@<VD@+2T`,3(M:&]D:6YO=OT@9F]R;>%T`#(T+6AO9&EN
M;W;](&9O<FWA=``R-"!H;V3M;@`\4')E9&-HX61Z86KZ8V$`4')E('1E;G1O
M(&)L;VL@:F4@<&^^861O=F%N_2!D871A8N%Z;W;](&)A8VME;F0N`%9Y<VMY
M=&QA('-A('KA=F&^;N$@8VAY8F$`3F$@>F&Y:69R;W9A;FEE('-P<N%V>2!J
M92!P;[YA9&]V86[]('9E<F5J;OT@4$A0(&NU^N@N`$YA(&]V97)E;FEE('!O
M9'#M<V%N96H@<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!01U`@:[7Z
MZ"X`3F$@9&6Y:69R;W9A;FEE('-P<N%V>2!S^B!P;W1R96)NZ3H@=F5R96IN
M_2!01U`@:[7ZZ"P@<')I=N%T;GD@4$=0(&NU^N@@82!H97-L;RX`3F$@<&]D
M<.US86YI92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@=G)E:F[](%!'4"!KM?KH
M+"!P<FEVX71N>2!01U`@:[7ZZ"!A(&AE<VQO+@!.82!D9;EI9G)O=F%N:64@
M<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R
M:7;A=&YY(%,O34E-12!KM?KH(&$@:&5S;&\N`$YA('!O9'#M<V%N:64@<W!R
MX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R:7;A
M=&YY(%,O34E-12!KM?KH(&$@:&5S;&\N`$YA('IAN6EF<F]V86YI92!S<'+A
M=GD@:F4@<&^^861O=F%N_2!V97)E:F[](%--24U%(&NU^N@N`%!R961P;VQU
M9&[M;2!O8FQAZ&YO`%!R961P;VQU9&[M;2"U86AK_2!DX;[O`%!R961P;VQU
M9&[M;2!DX;[O`%!R961P;VQU9&[M;2!P<F5HX6YK>0!0<F5D<&]L=61N[6T@
M<VYE:&]VZ2!P<F5HX6YK>0`Q,B!H;V3M;@!!4$D@240`3R!T;VUT;R!E9&ET
M;W)E`$\N+BX`06)S;VSZ=&YY('-P;V1O:P!!8G-O;/IT;GD@<W1R960`4')I
M('9Y=';A<F%N[2!61E,@861R97/A<F$@8F]L('IA;6EE=&YU=/T@<'+M<W1U
M<"X`4')I('9Y=';A<F%N[2!61E,@<_IB;W)U(&)O;"!Z86UI971N=73]('!R
M[7-T=7`N`$EN9F]R;>%C:64@;R#ZZ'1E`$AE<VQO('!R92#ZZ&5T`-KH970@
M>F%B;&]K;W9A;OTN`-KH=&]V86YI90!0<FED8;L`4')I9&&[('!O9')I861E
M;OH@<VMU<&EN=0!0<FED8;L@<&]D<FEA9&5NZ2!P<N%V;P!0<FED8;LZ`%!R
M:61ANR!S:W5P:6YU`%!R:61ANR!N;W;I('!RX79O`%!R:61ANR!D8^ER<VMU
M('-K=7!I;G4@9&\@(B5S(@!0<FED8;L@9&/I<G-K92!P<N%V;R!D;R`B)7,B
M`%!R:61ANR!P;W6^[79A=&6U83H`4')I9&&[('-TY7!E8P!0<FED8;L@Z&QE
M;F]V`%!R:61ANR!PX7(`4')I9&&[(&UE;G4@)7,@86MO($)OZ&[]('!A;F5L
M($UO>FEL;'D`4')I9&&[(&1O(&%D<F5SX7)A.@!0<FED8;L@9&\@;?1J:&\@
M861R97/A<F$`4')I9&&[('!O=;[M=F%T9;5A`"(E<R(@8F]L('!R:61A;OT@
M9&\@<WES=.EM=2P@86QE(&YE;6^^;F\@<')I9&&[(.]A;+EI92!P<FEH;&%S
M;W9A8VEE(&EN9F]R;>%C:64Z("5S+@`B)7,B(&)O;"!P<FED86[](&1O('-Y
M<W3I;74N(%1E<F%Z('-A(&WTOF5T92!P<FEH;.%S:;LN`%!R:63A=F%N:64@
M<&]UONUV871EM6]V(&IE('IA:^%Z86[I+@!!9')E<V$`061R97/A<@!!9&UI
M;FES='+A8VEA("T@;F%S=&%V96YI92!P<N%V('!R92!I;OUC:"!P;W6^[79A
M=&6U;W8`061M:6YI<W1RX6-I80!296ML86UY`$%F9V%N:7-T86X`06QBX6YS
M:V\`06R^[7)S:V\`06QI87,`6F%R;W9N8;L`6F%R;W9N86YI93H`5KEE=&MY
M`%:Y971C:2!A=71E;G1I9FEK;W9A;NT@<&]UONUV871E;&EA`%:Y971K>2!S
M:W5P:6YY`%:Y971K>2!P<N%V80!6N65T:WD@N71Y<FD@<W1R86YY`%!O=F]L
M:;L@=FEA8V5RZ2!A9')E<WD`4&]V;VQINR!N87-T879E;FEE('1Y<'4@>F]R
M861E;NEH;R!Z;WIN86UU/P!5OB!E>&ES='5J90!!;'1E<FYA=.UV;F4@<')I
M:&QA<V]V86-I92!M96YO($E-4U``06QT97)N873M=FYE(&AE<VQO($E-4U``
M06QT97)N873M=FYE('!O=;[M=F%T9;5S:^D@;65N;R!)35-0`$%L=&5R;F%T
M[79N82!E+6UA:6QO=N$@861R97-A`$%L=&5R;F%T[79N92"Y86)L\VYY`$%L
M=&5R;F%T[79N>2!T97AT.@!!;65R:6-KX2!386UO80!";VQA('IA9&%NX2!N
M97!L871NX2!H;V1N;W1A`$YA<W1A;&$@;F5Z;N%M82!C:'EB82X`06YD;W)R
M80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;ND@<')O>'D`3V1P;W9E[P!!;G1A
M<FMT:6MA`$%N=&EG=6$@82!"87)B=61A`$%P;&EKX6-I80!:;WIN86T@87!L
M:6OA8VGM`$%P;&EKX6-I82!J92!P<FEP<F%V96[A+@!!<&QI:V]V8;L@;F$@
M<&]D<FEA9&5NZ2!Z9&EEM6%NZ2!P<FEEZ&EN:WD`4V-H=N%L:;L`4')I8FQI
MOF[A('9EM6MO<[L`07!R[6P`5F6U:V]SNR!A<F-H[79U`$UE;F\@87)C:.UV
M=0!.86]Z86H@8VAC971E('9Y;6%Z8;L@OFEA9&]SNR!O('!R:6ALX7-E;FEE
M("<E<R<_`$YA;WIA:B!C:&-E=&4@=GEM87IANR`B)7,B(&$@=KEE=&MY('!O
M9'-K=7!I;GD_`$%R9V5N=.UN80!!<FWI;G-K;P!5;65N:64`07)U8F$`3W-T
M<F]V($%S8V5N<VEO;@!!<V-I:2!U;65N:64`P7II82]086-I9FEC:_T@<F5G
M:?-N`%9YOF%D;W9ANR!P;W1V<F1E;FEE('!R960@=GEK;VYA;NUM(&]P97+A
M8VGM(/ID<KYB>3\`4&]K=7,@;R!V>6UA>F%N:64@;F5E>&ES='5J^F-E:B!S
M:W5P:6YY+@!0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T=6KZ8V5H;R!P<N%V
M82X`4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J^F-E:&\@<'+A=F$N`%!O:W5S
M(&\@^G!R879U(&YE97AI<W1U:OIC96AO('ID:66U86[I:&\@;V)J96MT=2X`
M071R:6+Z='D`075G=7-T`$%U<W1RX6QI80!286OZ<VMO`$%U=&A?8WER<W%L
M.B!0;[YA9&]V86[I(')O>KGM<F5N:64@:6UA<"!N96)O;&\@;N%J9&5NZ2X`
M075T:%]C>7)U<SH@8F%C:V5N9"!N96WA('!OOF%D;W9A;ND@<V-H;W!N;W-T
M:2X`075T:%]C>7)U<SH@<&^^861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B
M;VQO(&[A:F1E;NDN`$%U=&A?9G1P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@
M1E10(&YE8F]L;R!NX6ID96[I+B!3:V]M<&EL=6IT92!02%`@<R!P<F5P[6YA
MZ&]M("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!P;[YA9&]V86[I(')O>KGM
M<F5N:64@24U!4"!N96)O;&\@;N%J9&5NZ2X`075T:%]K<F(U.B!P;[YA9&]V
M86[I(')O>KGM<F5N:64@:W)B-2!N96)O;&\@;N%J9&5NZ2X`075T:%]L9&%P
M.B!P<FEDX79A;FEE('!O=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;ND@
M<')E($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!V>6UA>N%V86YI92!P
M;W6^[79A=&6U;W8@;FEE(&IE('!O9'!O<F]V86[I('!R92!!8W1I=F4@1&ER
M96-T;W)Y`$%U=&A?;&1A<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($Q$05`@
M;F5B;VQO(&[A:F1E;NDN`$%U=&A?;&1A<#H@3F5P;V1A<FEL;R!S82!P<FED
M8;L@<&]UONUV871EM6$@)7,N(%-E<G9E<B!O9'!O=F5D86PZ(`!!=71H7VQD
M87`Z(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[('!O=;[M=F%T9;5A("5S`$%U
M=&A?;&1A<#H@;F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@<&]UONUV871E
MM6$@)7,`075T:%]L9&%P.B!A:W1U86QI>N%C:6$@<&]UONUV871EM6]V(&YI
M92!J92!P;V1P;W)O=F%NX2!P<F4@06-T:79E($1I<F5C=&]R>0!!=71H7VUC
M86PZ('!OOF%D;W9A;ND@<F]ZN>UR96YI92!-0T%,(&YE8F]L;R!NX6ID96[I
M+@!!=71H7W-M8F%U=&@Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!S;6)A=71H
M(&YE8F]L;R!NX6ID96[I+@!!=71E;G1I9FEKX6-I82!P;VUO8V]U($E-05`@
M<V5R=F5R82!Z;'EH86QA+@!!=71E;G1I9FEKX6-I82!Z;'EH86QA`$%U=&5N
M=&EF:6OA8VEA('IL>6AA;&$N("5S`%-E<G9E<B!2041)55,@>F%M:65T;VP@
M875T96YT:69I:^%C:74N`$%U=&5N=&EF:6OA8VEA('!O;6]C;W4@1E10('-E
M<G9E<F$@>FQY:&%L82X`075T96YT:69I:^%C:6$@<&]M;V-O=2!334(@<V5R
M=F5R82!Z;'EH86QA+@!$;W-T=7!NZ2!P;VQOOFMY.@!!>F5R8F%J9+YA;@!"
M3T9(($5X8W5S97,`4&]Z861I90!&87)B82!P;WIA9&EA`%ILZ2!H97-L;R!P
M<F4@:V5R8F5R;W,N`%ILZ2!P;W6^[79A=&6U<VOI(&UE;F\@<')E(&ME<F)E
M<F]S+@!"86AA;7D`0F%H<F%J;@!"86YG;&%DZ;D`0F%R8F%D;W,`4')I9>AI
M;F]K(',@9W)A9FEK;W4@(B5S(B!N96)O;"!NX6ID96[]+@!:X6ML861N_2!R
M:6%D;VL`0FEE;&]R=7-K;P!"96QG:6-K;P!"96QI>F4`0F5N:6X`0F5R;75D
M>0!"=73A;@!.87)O9&5N:6YY`$)L;VL@(B5S(B!A<&QI:^%C:64@(B5S(B!N
M96)O;"!NX6ID96[]+@!.87-T879E;FEA(&)L;VMU`%1Y<"!B;&]K=0!4=>AN
MZ0!";VSM=FEA`%KA;&^^:WD`3VMR86H`J>UR:V$@;VMR86IA.@!/:W)A:F4`
M0F]S;F$@82!(97)C96=O=FEN80!/8F4`0F]T<W=A;F$`0F]T=&]M`$)O=79E
M="!)<VQA;F0`0G)A>NUL:6$`0G)I='-KZ2#Z>F5M:64@=B!);F1I8VMO;2!O
M8V7A;F4`0G)U;F5I($1A<G5S<V%L86T`0G5L:&%R<VMO`%IO>FYA;2!S(&]D
M<N&^:V%M:0!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$1I<W1R:6)U
MZ&[I(&)O9'D@0U),`%9L87-T;F]S=&D@7V)U;FMY+BXN`$EN8VEA;&EZX6-I
M82!V>7)O=F[A=F%C96H@<&%MY'1I(&YE8F]L82!D;VMO;NAE;N$N`$MA;&5N
M9.%R`$)E>G9E=')I90!+86UB;V2^80!+86UE<G5N`$YE<&]D87)I;&\@<V$@
M875T;VUA=&EC:WD@;V)N;W9INR!H97-L;RP@:V]N=&%K='5J=&4@<W9O:FAO
M(&%D;6EN:7-T<N%T;W)A+@!.97!O9&%R:6QO('-A('IA<.US8;L@9&\@<_IB
M;W)U("(E<R(`3F5M;[YN;R!A9&UI:7-T<F]V8;L@97AT97)NZ2!O=FSA9&'H
M92!S961E;NTN`$YE<&]D87)I;&\@<V$@<W!O:FF[(',@24U!4"!S97)V97)O
M;3H@)7,`3F5P;V1A<FEL;R!S82!O='9O<FF[('/Z8F]R("(E<R(N`$MA;F%D
M80!:<G6Y:;L`6G)UN6F[('-P<N%V=2!O('!R;V)LZ6UE`$YE<&]D87)I;&\@
M<V$@=GEM87IANR!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A(&[A:G.[(&1O
MZ&%S;OT@861R97/A<BX`3F5M;[YN;R!P;VMR8>AO=F&[(&)E>B!P87)A;65T
M<F$@)W1A<F=E=$9I;&4G+@!.97!O9&%R:6QO('-A(&]D<W1RX6YINR!A9')E
M<^%R("(E<R(N`$YE;6^^;F\@;V1S='+A;FF[+"!E>&ES='5J92`E9"!N87-L
M961O=F[M:V]V+@!.96UOOFYO('!R975S<&]R:6%D8;LL('!OZ&5T('!O;&^^
M:65K('!R92!P<F5U<W!O<FEA9&%N:64@;F5S^FAL87/M(',@<&_H=&]M('5L
M;[YE;OUC:"!P;VQOOFEE:RX`3F5P;V1A<FEL;R!S82!S;65R;W9ANR!S<'+A
M=G4@;F$@=7+H96[I(.CM<VQO+@!+87!V97)D<VOI(&]S=')O=GD`5&ET=6QO
M:P!+871E9_-R:64@82!P;W!I<VMY`$MA:FUA;G-KZ2!O<W1R;W9Y`$UO8FEL
M;OT@=&5L96;S;@!6;&%S=&YO<W1I(&)U;FMY`%9Y<&QN96YI92!B=6YK>3H`
M5FQA<W1N;W-T:2!B=6YK>0!2;WIO<W1U<"!B=6YI96LZ`$UO8FEL;OT@=&5L
M96;S;@!$;R!S=')E9'4`4W1R961O869R:6-KX2!R97!U8FQI:V$`4&]D<F]B
M;ND@:6YF;W)MX6-I92!O(&-E<G1I9FEKX71E`%9L87-T;NUK(&-E<G1I9FEK
MX71U`%!O;&ET:6MY('!R92!C97)T:69I:^%T>0#(860`6FUE;FF[`%IM96YI
MNR!68;EE(&AE<VQO`$YA<W1A=F5N:64@;65N82!A(&%D<FEE<RP@:W1O<ND@
M=FED:6$@M75D:6$L(&ME[R#H[71A:OH@82!O9'!O=F5D86KZ(&YA(%9AN64@
M92UM86EL>2X`6FUE;F$@:&5S;&$@;FEE(&IE('8@86MT=>%L;F5J(&MO;F9I
M9W5RX6-I:2!P;V1P;W)O=F%NX2X@($MO;G1A:W1U:G1E('-V;VIH;R!A9&UI
M;FES='+A=&]R82X`6FYA:P!37VMO;G1R;VQO=F&[(&QI;FMU+BXN`$-H:6QE
M`,CM;F$`5GEB97)T92!A<&QI:^%C:74Z`%IV;[5T92!S:2!H97-L;P!:=F^U
M=&4@<VD@<&]UONUV871EM7-KZ2!M96YO`%9Y8F5R=&4@<W#T<V]B('IO8G)A
M>F]V86YI82!DX71U;6]V.@!6>6)E<G1E('1Y<""Y=/UL=2!Z;WIN86UU("AP
M<F4@>F]R861E;ND@>F]Z;F%M>2D`5FEA;F_H;OT@;W-T<F]V`$1E9FEN[6-I
M82!T<FEE9'D@)7,@;F5B;VQA(&[A:F1E;N$N`$IA<VYO`$]D<W1RX6YINR!P
M<NUK87IY($U33V9F:6-E`%9Y;6%Z8;L@9&]T87H`3V1S='+A;FF[('!O=;[M
M=F%T9;5A.B`E<P!/9'-T<N%N:;L@<&]UONUV871EM6$`5GEM87IANR!P;W6^
M[79A=&6U<VOI(/ID86IE`$YE<VOT<B!V>6IA<VYE;FEE`$ML:6MN:71E('!R
M92!P;VMR8>AO=F%N:64`0VQI8VMA=&5L;"!C97H@2%144`!:871V;W)INR!O
M:VYO`$]B;&%K>0!2X6YO(&]B;&'H;F\`3V)L8>AN;P!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!:8F%L:;L@0F_H;OT@<&%N96P`6F)A;&5NZ2!O:W)A:F4`
M2V]L=6UB:6$`1F%R8F$`5OUB97(@9F%R8GD`5OUB97(@9F%R8GD`4W3E<&-E
M.@!.861P:7-Y('-TY7!C;W8`2V]M:6MS`%!R[6MA>@!0<NUK87IO=OT@:6YT
M97)P<F5T97(`2V]M96YTX7(`0F6^;ND@;65N;P!+;VUO<GD`4W!O;&_H;F]S
MNP!0;^CM=&'H90!3=&%V`%-T878`4F]Z9&EE;'D@=B!K;VYF:6=U<N%C:6D`
M2V]N9FEG=7+A8VEA('!R92!S>6YC:')O;FEZX6-I=2!S(%!$02P@:6YT96QI
M9V5N=&[];6D@=&5L96;S;FUI(&$@3W5T;&]O:V]M+@!+;VYF:6=U<N%C:6$@
M<&]T<F5B=6IE(&%K='5A;&EZX6-I=2X`2V]N9FEG=7)O=F&[("5S`%!O='9R
M[W1E(&AE<VQO`$MO;F=O`$1E;6]K<F%T:6-KX2!R97!U8FQI:V$@2V]N9V\`
M4W!O:F5N:64@>FQY:&%L;RX`4W!O:F5N:64@>FQY:&%L;SH@`$NU^N@@8F]L
M('IA;6EE=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU^NAO=BX`2[7ZZ"!B
M;VP@>F%M:65T;G5T_2!S97)V97)O;2!V97)E:F[]8V@@:[7ZZ&]V+B!$]'9O
M9#H@)7,@*"5S*0!3<&]J96YI92!S($944"!S97)V97)O;2!Z;'EH86QO+@!+
M;VYT86MT>0!+;VYT86MT>2!B;VQI(/IS<&6Y;F4@=FQOOF5NX2!D;R!6X;EH
M;R!A9')E<^%R82X`5'EP(&MO;7!R:6UO=F%NZ6AO('/Z8F]R=3H`3V)S86@@
M(B5S(@!0;VMR8>AO=F&[`$-O;VMO=F4@;W-T<F]V>0!#;V]K:64`2V]P[7)O
M=F&[`$MO<.UR;W9A;FEE('IL>6AA;&\Z("5S`$MO<.UR;W9ANR!V_6)E<@!+
M;W-T87)I:V$`4&]B<F6^:64@<VQO;F]V:6YY`$YE<&]D87)I;&\@<V$@>F&Y
M:69R;W9ANR!S<'+A=G4@<&]M;V-O=2!01U`Z(`!.97!O9&%R:6QO('-A('!O
M9'#M<V&[('-P<N%V=2!P;VUO8V]U(%!'4#H@`$YE<&]D87)I;&\@<V$@>F&Y
M:69R;W9ANR!S<'+A=G4@<&]M;V-O=2!3+TU)344N`$YE<&]D87)I;&\@<V$@
M<&]D<.US8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+@!.97!O9&%R:6QO('-A
M('!R:61ANR!K;VYT86MT+B`E<RX`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K
M($Q$05`@<V5R=F5R=2X`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K($Q$05`@
M<V5R=F5R=0!.97!O9&%R:6QO('-A(&]V97)INR!Z;W-T871O:R!N82#ZZ'1E
M+B`E<P!.87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K($Q$05`@<V5R=F5R
M=0!.97!O9&%R:6QO('-A('!R:7!O:FF[(&L@<V5R=F5R=2`B)7,B('!O;6]C
M;W4@1E10.B`E<P!.97!O9&%R:6QO('-A('9Y='9O<FF[('IO>FYA;2!P<NUJ
M96UC;W8N("5S`$YE<&]D87)I;&\@<V$@9&6Y:69R;W9ANR!01U`@^F1A:F4Z
M(`!.97!O9&%R:6QO('-A(&1EN6EF<F]V8;L@4R]-24U%(/ID86IE+@!.97!O
M9&%R:6QO('-A('9Y;6%Z8;L@:V]N=&%K="X@)7,`3F5P;V1A<FEL;R!S82!V
M>6UA>F&[('IO>FYA;2!P<NUJ96UC;W8N("5S`$YE<&]D87)I;&\@<V$@=GEM
M87IANR!S:W)I<'0@;F$@=7!G<F%D92!K;VYF:6=U<N%C:64@(B5S(BX`3F5P
M;V1A<FEL;R!S82!U<NAINR!E+6UA:6QO=OH@861R97-U('!R[6IE;6-U+@!.
M97!O9&%R:6QO('-A('-T:6%H;G6[(&-E;/T@861R97/A<BX`3F5P;V1A<FEL
M;R!S82!Z[7-K8;L@:V]M<&QE=&[]('IO>FYA;2!P<NUJ96UC;W8N`$YE<&]D
M87)I;&\@<V$@>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@>F]Z;F%M;W8@<'+M
M:F5M8V]V+@!.97!O9&%R:6QO('-A(&YAZ.UT8;L@<W1R873I9VEU("(E<R(N
M`$YE<&]D87)I;&\@<V$@<W!U<W1INR!M:V1I<B`B)7,B+@!.97!O9&%R:6QO
M('-A('KM<VMANR!V97)E:F[](&NU^N@@>F\@<V5R=F5R82!KM?KH;W8N`$YE
M<&]D87)I;&\@<V$@;W1V;W)INR`B)7,B('!R92!ZX7!I<RX`3F5P;V1A<FEL
M;R!S82!O='9O<FF[("5S+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@;6]D=6P@
M36%I;G1E;F%N8V5?5&%S:R`E<P!.97!O9&%R:6QO('-A(&]T=F]R:;L@861R
M97/A<B`B)7,B+@!.97!O9&%R:6QO('-A('!R:7!O:FF[(&YA($Q$05`@<V5R
M=F5R+@!.97!O9&%R:6QO('-A('!R9>CM=&&[("5S+@!.97!O9&%R:6QO('-A
M(&]B;F]V:;L@:&5S;&\@>F%D86[I:&\@<&]UONUV871EM6$N($YI96MT;W+I
M(&%L96)O(':Y971K>2!P;V1R;V)N;W-T:2!N:64@<_H@<W!RX79N92X@4VOZ
M<W1E('1O('IN;W9U(&%L96)O(&MO;G1A:W1U:G1E(%;AN6AO(&%D;6EN:7-T
M<N%T;W)A+"!A:R!P;W1R96)U:F5T92!P;VUO8RX`3F5M;[YN;R!Z[7-K8;L@
M04-,`$YE<&]D87)I;&\@<V$@>NUS:V&[(&%D<F5SX7(N("5S`$YE<&]D87)I
M;&\@<V$@>NUS:V&[('IO>FYA;2!P<NUJ96UC;W8N("5S`$YE<&]D87)I;&\@
M<V$@>NUS:V&[('IO>FYA;7D@<'+M:F5M8V]V("5S`$YE;6^^;F\@>NUS:V&[
M(&EN9F]R;>%C:64@;R!V;&%S=&YO<W1I86-H('-E<G9E<F$`3F5P;V1A<FEL
M;R!S82!V<N%T:;L@:V]N9FEG=7+A8VEU+@!.97!O9&%R:6QO('-A('-P=7-T
M:;L@<FUD:7(@(B5S(BX`3F5P;V1A<FEL;R!S82!U;&^^:;L@:V]N9FEG=7+A
M8VEU("5S+@!.97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A
M8VEE+@!.97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A8VEE
M.B`E<P!.97!O9&%R:6QO('-A('5L;[YINR!S:W)I<'0@;F$@=7!G<F%D92!N
M87-T879E;NT@9&\Z("(E<R(N`$YE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H
M=2!K;VYF:6=U<N%C:64@)7,N`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!K;VYF
M:6=U<F'H;OT@<_IB;W(@)7,N($WTOF5T92!P;W6^:;L@;FEE:W1O<OH@>B!M
M;[YN;W-T[2!N82!ZX7!I<R!K\V1U(&YA("5S(&%L96)O('-K;W#M<F]V8;L@
M<G7H;F4@:_-D('5V961E;OT@;FF^N6EE(&1O("5S+@!.97!O9&%R:6QO('-A
M(&BU861ANR!N82!,1$%0('-E<G9E<FDN`$YE<&]D87)I;&\@<V$@=GEM87IA
MNR`B)7,B+@!.97!O9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!K;VYT86MT+B`E
M<P!.97!O9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!Z;WIN86T@<'+M:F5M8V]V
M+B`E<P!.97!O9&%R:6QO('-A('IA<.US8;L@:V]N9FEG=7+A8VEU('!R92`B
M)7,B.B`E<P!.96UOOFYO(&[A:G.[($)OZ&[]('!A;F5L($UO>FEL;'DN(%-K
M;VYT<F]L=6IT92P@OF4@:F4@<&%N96P@;W1V;W)E;OTN`%!O=;[M=F%T9;5O
M=FD@(B5S(B!S82!N97!O9&%R:6QO('!R:61ANR!P<N%V82!P<F4@<')I9>AI
M;F]K("(E<R(Z("5S`%!OZ.UT86[]('1E>'0`2W)A:FEN80!+=7)Z>0!6>71V
M;W)INP!6>71V;W)INR!L:6YK=0!6>71V;W)INR!N;W;]`%9Y='9O<FF[('!O
M9'!R:67H:6YO:P!0<N%V82!T=F]R8W4`R.US;&\@:W)E9&ET;F5J(&MA<G1Y
M`$-H;W)VX71S:V\`2W5B80!!:W1UX6QN92`T(&;A>GD`06MT=>%L;F4@<V5D
M96YI80!!:W1UX6QN>2#H87,`06MT=>%L;F$@55),(&IE`$%K='7A;&YI('!O
M=;[M=F%T96QI80!!:W1UX6QN92!P;^AA<VEE`$%K='7A;&YE('!O9&UI96YK
M>3H@`$%K='7A;&YY(+ET_6P`3F%S=&%V96YI92#Z;&]H+"!K=&]RZ2!S82!S
M</JYNV%J^B!P<FD@<')I:&SA<V5N[2!D;R!A<&QI:^%C:64@)7,N`%9Y<W1R
M:6AN^KL`5GES=')I:&[ZNR!V_6)E<@!#>7!R=7,`R&5S:^$@<F5P=6)L:6MA
M`$1$`$133B`H<&]Z<FD@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$96YN90!0<F5Z
M97)AZ"!DX71O=NEH;R!S=')O;74@*$1A=&%4<F5E*0!6>6BU863A=F%N:64@
M=B!D871A8N%Z90!$X71U;0!$X71U;2!P<FEJ871I80!6_6)E<B!DX71U;74`
M1&7R`$]?9'-T<N%N:;L@<W3E<&5C`$1E8V5M8F5R`$1E<VEA=&MO=ND@Z.US
M;&$`6FUE;KEINR!O9'-A9&5N:64`4')E9&YA<W1A=F5NZ0!0<F5D;F%S=&%V
M96[A(&9A<F)A`%9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET80!0<F5D;F%S
M=&%V96[]('!R[6MA>F]V_2!I;G1E<G!R971E<@!$969I;NUC:64`5GEM87IA
MNP!6>6UA>F&[(&)U;FMU`%9Y;6%Z8;L@<VMU<&EN=0!6>6UA>F&[('KA>FYA
M;0!6>6UA>F&[('!RX79O`%9Y;6%Z8;L@82!O9'-T<N%N:;L@<W!RX79Y`%9Y
M;6%Z8;L@8G5N:W4`5GEM87IANR!S=.5P96,`5GEM87IANR!E>&ES='5J^F-U
M(&%L=&5R;F%T[79N=2"Y86)L\VYU`%9Y;6%Z8;L@<'+A=F$@<')E("(E<R(`
M0VAC971E('9Y;6%Z8;L@(B5S(B!A(':Y971K>2!J96AO('!O9'!RX79A/P!6
M>6UA>F&[(')I861O:P!6>6UA>F&[('9Y8G)A;OH@:61E;G1I='4`5GEM87IA
MNR!A:W1UX6QN>2!S=.5P96,`5GEM87IANR!A:W1UX6QN>2!R:6%D;VL`4VMR
M:7!T(&YA('5P9W)A9&4@:V]N9FEG=7+A8VEE("(E<R(@8F]L('9Y;6%Z86[]
M+@#(87,@9&]R=>AE;FEA`$3A;G-K;P!0;W#MN71E('!R;V)LZ6T`4&]P:7,`
M4&]D<F]B;F]S=&D@*'1I9;X@=B!L;V=O=F%C;VT@<_IB;W)E($AO<F1E*0!$
M971A:6QY(&)O;&D@>F%Z;F%M96YA;ND@<')E(&%D;6EN:7-T<N%T;W)A+@!6
M_79O:@!2;W-N_2!B;V0`4F]S;OT@8F]D('IA('!O<VQE9&[Z(&AO9&EN=3H@
M`%)O<V[](&)O9#H@`%-M97(@>K5A=F$@9&]P<F%V80!3;65R('-P<F%V82!D
M;[5A=F$`061R97/A<@!:;V)R87IO=F&[(.AA<R!V(#(T+6AO9&EN;W9O;2!F
M;W)MX71E/P!.87-T879E;FEE('IO8G)A>F5N:6$`6F]B<F%Z:;L@<&]D<F]B
M;OH@<')E9'!O=F7O`%IO8G)A>FF[('!R961P;W9E[R`H5$%&*0!&;W)MX70@
M>F]B<F%Z96YI80!0;W1V<F1E;FEE(&\@9&]R=>AE;NT`1+YI8G5T<VMO`$YE
M=GEM87IANP!.97!O=;[M=F%J=&4@<')I86UO(&UA:6YT96YA;F-E+G!H<`!/
M8G-A:'5J92!P<G;](')I861O:R!NX7IV>2!P;VSM/R!!:R#A;F\L('IAN6MR
M=&YI=&4@<&]L[>AK;SH@`$1O;6EN:6-A`$1O;6EN:6OA;G-K82!R97!U8FQI
M:V$`3F5MX71E(/KH970_(%IA<F5G:7-T<G5J=&4@<V$N`%-T:6%H;G6[`%-T
M:6%H;G6[("5S`%-T:6%H;G6[('9Y9V5N97)O=F%N^B!K;VYF:6=U<N%C:74@
M86MO(%!(4"!S:W)I<'0N`%IO>FYA;2!S(';]8F5R;VT`1')O9WD`12UM86EL
M`$524@!%:W;A9&]R`%5P<F%V:;L`57!R879INR!B;&]K`%5P<F%V:;L@<VMU
M<&EN=0!5<')A=FF[('!RX79O`%5P<F%V:;L@<'+A=F$`57!R879INR!P<N%V
M82!P<F4@)7,`57!R879INR!N87-T879E;FEA('!R93H`57!R879INR!P<N%V
M82!P<F4@(B5S(@!5<')A=FF[('!RX79A('!R92`E<P!6>F1E;.%V86YI90!%
M9WEP=`!386QVX61O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL;W;A(&%D
M<F5S83H`12UM86EL;W;I(&%D<F5S>2!M=7-I82!B>;L@<F]V;F%KZ2X`12UM
M86EL(',@<&]T=G)D96[M;0!"<N%N82!%;6%I;"UN82U335,`16UO=&EK;VYY
M`%!RX7ID;F$@<W!RX79A+@!0<N%Z9&YY(';]<VQE9&]K+@!0<N%Z9&YE('!O
M9&UI96YK>2!HM6%D86YI80!0;W9O;&F[('9L;[YE;FEE(&]B<N%Z:V]V('H@
M1V%LZ7)I[2!D;R!T97AT=3\`4&]V;VQINR!K;VYT97AT;W;I(&UE;G4@<')E
M('!R87;I('1L8>AI9&QO/P!+;VYI96,@<F]K80!:=N3HN6F[(&5D:71O<@!:
M861A:G1E(&)E>G!EZ&YO<W1N^B!O=.%Z:W4L(&YA(&MT;W+Z(&)U9&5T92!M
M=7-I9;L@;V1P;W9E9&&[(&%K('IA8G5D;F5T92!H97-L;RP@;F%P<BX@)V%K
M;R!S82!V;VSA(&UO:F4@>G9I97)A=&MO/R<Z`%IA9&%J=&4@55),(&]B<N%Z
M:V$`6F%D86IT92!P[7-M96[A('5V961E;ND@;FF^N6EE.@!2;W9N[6MO=N$@
M1W5I;F5A`$5R:71R96$`0VAY8F$`0VAY8F$@<')I('9Y=';A<F%N[2!B;&]K
M=3H@)7,`0VAY8F$@<')I('9Y;6%ZX79A;NT@=6MO='9E;FEA('-Y;F-H<F]N
M:7KA8VEE.B`E<P!#:'EB82!P<FD@=GEM87KA=F%N[2!ZX7IN86UU('-Y;F-H
M<F]N:7KA8VEE.B`E<P!#:'EB82!P<FD@>NUS:V%V86[M(&]B<V%H=3H@)7,`
M0VAY8F$@<')I(&%K='5A;&EZX6-I:2!H97-L83H@)7,`0VAY8F$@=B!E+6UA
M:6QO=F5J('-P<N%V92X`0VAY8F$@<')I('IA<&ES;W9A;NT@(B5S(BX`17-T
M\VYS:V\`171I\W!I80!%=&YI8VOI`$5U<O-P80!+8;YD_6-H(#$U(&UI;OIT
M`$MAOF3I(#(@;6EN^G1Y`$MAOF3]8V@@,S`@<V5K^FYD`$MAOF3]8V@@-2!M
M:6[Z=`!0<FD@:V&^9&]M('!R:6ALX7-E;NT`2V&^9/H@<&]L:&]D:6YU`$MA
MOF3Z(&UI;OIT=0!.87!R[6ML860Z`%-P=7-T:;L`4F]Z8F%L:;L`4F]Z8F%L
M:;L@0F_H;OT@<&%N96P`3^AA:^%V82!S82`G*2<`3^AA:^%V82!S82!S;&]V
M;R!A;&5B;R!P;V1M:65N:V$@:+5A9&%N:6$@=B#Z=F]D>F]V:^%C:`!$X71U
M;2!E>'!I<N%C:64`17AP;VYE;G0`1F%R8F$@=&5X='4`3F%H<F&[(&MO;F9I
M9W5RX6-I=2!N82!&5%``3F5P;V1A<FEL;R!S82!Z[7-K8;L@;F%S=&%V96YI
M82X`3F%S=&%L82!C:'EB82!P<FD@<W!O:F5N[2!S($Q$05`@<V5R=F5R;VTN
M`$YA<W1A;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@4TU"('-E<G9E<G4N`$YE
M<&]D87)I;&\@<V$@:V]P[7)O=F&[('H@(B5S(BX`3F5P;V1A<FEL;R!S82!K
M;W#M<F]V8;L@9&\@(B5S(BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!N;W;I
M(%-!4TP@<W!O:F5N:64N`$YE<&]D87)I;&\@<V$@<')E<W5N^KL@9&\@(B5S
M(BX`3F5P;V1A<FEL;R!S82!Z[7-K8;LZ("5S`$1O8G+I`$9A;&ML86YD<VOI
M(&]S=')O=GD@*$UA;';M;GDI`$9A97)S:^D@;W-T<F]V>0!:X79AOF[A(&-H
M>6)A.@!&87@`1F%X>0!&96)R=>%R`%!O8VET('1E<&QO='D`4&]C:70@=&5P
M;&]T>3H@`$UA;.D@>G+AOFMY`$UA;.D@<VYE:&]VZ2!P<F5HX6YK>0!-871I
M8V$@<&]L[0!&:62^:0!3^F)O<@!0;^AE="!S^F)O<F]V.B`E<R!S^F)O<@!0
M;^AE="!S^F)O<F]V.B`E<R!S^F)O<F]V`%-P<N%V8V$@<_IB;W)O=@!-96YO
M('/Z8F]R=0!6_6)E<B!S^F)O<G4`3F%H<F%T:64@<_IB;W)U`$YA:'+A=F%N
M:64@<_IB;W)O=B!N:64@:F4@<&]D<&]R;W9A;NDN`$9I;'1R90!&[6YS:V\`
M4')VX2!P;VQO=FEC80!0<G;A(+ET=G*[`%!E=F[]('!O;65R`$]T;^AINP!0
M;.%V86KZ8VD@=&5X=`!(;6QA`%!R:67H:6YO:R`E<R!N965X:7-T=6IE`$9A
M<F)A('#M<VUA`%!O=')A=F$`4')E('!R96AL:6%D8>AE+"!K=&]RZ2!N97!O
M9'!O<G5J^B!O8G+A>FMY`%!R961P;W9E[R`H5$%&*0!0<F5D<&]V9>\@;F$@
M=79E9&5N_2!P;^AE="!D;NT@*'!A;>1T86IT92!N82!T;RP@OF4@<')E9'!O
M=F7O(&IE('!R92!D;FD@86H@;F]C:2!A('1A:R!M]+YE('9EM6OI(.CM<VQO
M('9Y='9O<FF[('9EM6UI(+EI<F]K_2!B;&]K*0!:86)U9&QI('-T92!H97-L
M;S\`1F]R;75LX7)E`$9O<G1U;F$`5'EP(&9O<G1U;GD`1F]R='5N>0!&;W)T
M=6YY(#(`1O-R80!0<F5S;65R;W9A;FEA`%!I80!2X6UC90!&<F%N8_IZ<VMO
M`$9R86YC^GIS:V\@*$5U<O-P82D`1G)A;F/Z>G-K82!'=6%Y86YA`$9R86YC
M^GIS:V$@4&]L>6[I>FEA`$9R86YC^GIS:V4@:G6^;ND@=&5R:73S<FGA`$]D
M`%IO('-M97)U(`#:<&QN_2!P;W!I<P!3<&QN`$-E;.D@;65N;SH`1V%B=6X`
M1V%LZ7)I82P@>B!K=&]R96H@8VAC971E('9Z:6&[(&]B<N%Z;VL`1V%LZ7)I
M83H`1V%M8FEA`$=E;F5R;W9ANR!K;VYF:6=U<N%C:74@<')E(&%P;&EKX6-I
M=2`E<P!'96YE<F]V86[](&OS9`!'96]R9VEA`$YE;65C:V\`1VAA;F$`1VEB
M<F%L=.%R`$MR<W1NZ2!M96YO`$]D;W-L8;L`1V]E9&5L`$=O;V=L92!-87!S
M`$BU861ANR!N82!';V]G;&4`3V1T:65N92"Y961E:@!'<NEC:V\`1W+S;G-K
M;P!'<F5N861A`$%D;6EN:7-T<N%C:6$@<VMU<.UN`$UE;N$@<VMU<.UN(&YE
M<VWZ(&)YNR!P<N%Z9&YE`$=R;W5P7VQD87`Z($YE<&]D87)I;&\@<V$@<')I
M9&&[('-K=7!I;G4@)7,N(%-E<G9E<B!O9'!O=F5D86PZ(`!'<F]U<%]L9&%P
M.B!N97!O9&%R:6QO('-A('9Y;6%Z8;L@<VMU<&EN=2`E<P!'<F]U<%]L9&%P
M.B!N97!O9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!S:W5P:6YU("5S`%-K=7!I
M;GD`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!0<N%V82!A
M;F]N>6UN_6-H('!O=;[M=F%T9;5O=@!'=65S=&)O;VL`1W5I;F5A`$=U:6YE
M82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@;F5D;W9O;.T@=GEM87IA
MNR!P;W-L961N^B!B=6YK=2!V(')I861K=2X`2%1-3$%R96$@;F5D;W9O;.T@
M=GEM87IANR!P;W-L961N_2!S=.5P96,@=B!T86)UM6ME+@!(5$U,07)E82!N
M961O=F]L[2!V>6UA>F&[('!O<VQE9&[](')I861O:R!V('1A8G6U:V4N`$A4
M5%`@875T96YT:69I:^%C:6$@;F5B;VQA(&[A:F1E;N$N`$AA:71I`$%L9V]R
M:71M=7,@:&%S:&]V86-E:B!F=6YK8VEE`$]P87(`2&QA=FGH:V$`2&QA=FGH
M:WD`2&5A<F1O=B!O<W1R;W8@82!-8T1O;F%L9&]V92!O<W1R;W9Y`%-I;&[A
M(&+Z<FMA`%;]N6MA`%!O;6]C;NUK`%!O;6]C;NUK('!R92!P;W6^[79A;FEE
M(&5D:71O<F$`4&]M;V-N[6L`4&]L;V=UM6$`5'4@:F4@>F'H:6%T;VL@<_IB
M;W)U.@!6>7-O:^$`1&]?;6]V`%9A=&EKX6X`1&]M;W8`1&]MX6-A(&%D<F5S
M80!$;VWA8VD@<')I9>AI;F]K`%1E;&5F\VX@9&]M;W8`2&]N9'5R87,`2&]N
M9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!V('-P<N%V92`E<R!B;VQI(&[A
M:F1E;ND@;F5P;&%T;ND@)7,@6$U,(/ID86IE`$AO<F1E+TMO;&%B.B!S(&]B
M:F5K=&]M("5S(&YE:V]R9;EP;VYD=6IE(+YI861N82!S<'+A=F$N`$AO<F1E
M+TMO;&%B.B!V('-P<N%V92`E<R!N96)O;"!NX6ID96[](+YI861E;B!O8FIE
M:W0@='EP=2`E<P!(;W)D92]+;VQA8CH@^G-P9;EN92!O9'-T<N%N96[I("5S
M("(E<R(`2&]R9&4O2V]L86(Z(&EN=&5G<N%C:6$@=GF^861U:F4@4$A0(')O
M>KGM<F5N:64@)V1O;7AM;"<`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@
M=GET=F]R:;L@;F]V_2!834P@<W1R;VT@<')E(&]B:F5K="`E<P!(;W)D92]+
M;VQA8CH@;F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@>NUS:V&[($U)344@240@<')E(.AA
M<[L@='EP=2`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O
M;FEZ;W9ANR`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S
M82!S>6YC:')O;FEZ;W9ANR!Z9&EEM6%NZ2!O8FIE:W1Y.B`E<P!(;W)D92]+
M;VQA8CH@;F5Z;N%M>2!Z9&EEM6%N_2!O8FIE:W0@(B5S(@!(;W)I>F]N=.%L
M;F$@Z&EA<F$`2&]R:7IO;G3A;&YE('9Y<&QN96YI90!(;W)I>F]N=.%L;F4Z
M`$%K;R!S=&4@<V$@<V5M(&1O<W1A;&D_("A0<F]S[6T@;F%H;.%S=&4A*0!+
M;[5K;R!S=.5P8V]V(&-H8V5T92!Z;/KH:;L_`%IA9&%J=&4@<&_H970@<&]L
M[2`H<W3E<&-O=BD_`$MOM6MO(')I861K;W8@8VAC971E('IL^NAINS\`5FQH
M:V]SNP!6;&AK;W.[.B``2'5M;W)I<W1I`$UA[V%R<VMO`$YE<&]D87)I;&\@
M<V$@=GET=F]R:;L@24U!4"!S8VARX6YK=3H@)7,`3F5P;V1A<FEL;R!S82!V
M>6UA>F&[($E-05`@<V-H<N%N:W4Z("5S`$YE<&]D87)I;&\@<V$@=GET=F]R
M:;L@24U!4"!K=O-T=3H@)7,`25`@861R97-A`$E0(&%D<F5S82!N:64@:F4@
M9&]S='5P;N$N`$E0(&%D<F5S82!N:64@:F4@=B!RX6UC:2!D;W9O;&5NZ6AO
M($-)1%(@8FQO:W4N`%!O<G6Y96YI92!P<F%V:61L82!O('!E=FYE:B!)4"!A
M9')E<V4N`%9L;[YINR!KM?KH(%]P<F5D`$ES;&%N9`!)8F$@:6MO;GD`26MO
M;GD@<')E("5S`$EK;VYY(&$@=&5X=`!.X7IO=B!I9&5N=&ET>3H`06L@<V$@
M;F5Z;V)R87KM(&MO<F5K=&YE+"`E<R!A(&]T=F]R[2!S82!V(&YO=F]M(&]K
M;F4N`$%K(&YE=FED[71E('!R:2!P;W6^:73M($EN=&5R;F5T($5X<&QO<F5R
M82"^:6%D;F4@:6MO;GDL('!O=')E8G5J971E('IAN6MR=&[ZNR!T^G1O('9O
MM6)U('!R92!V>7!N=71I92!P<FEE<W9I=&YO<W1I(%!.1R!O8G+A>FMO=BX`
M06L@=FED[71E('3Z=&\@<W!RX79U(&$@;F5V:63M=&4@;V)RX7IO:RP@;V)R
MX7IO:RP@:W1O<OT@<W1E(&-H8V5L:2!N86AR8;LL(&YE;?2^92!B>;L@>F]B
M<F%Z96[]('9O(%9AN6]M('!R96AL:6%D8>AI+@!5:^&^:V$@;V)RX7IK83H`
M55),(&]B<N%Z:V$`55),(&]B<N%Z:V$Z`$]B<N%Z;VL@>B!G86SI<FEE`$]B
M<N%Z;VL@>B!G86SI<FEE.@!.86AR871I92!O8G+A>FMU`$]B<N%Z:WD`26UP
M;W)T+"!K<F]K("5D`$EM<&]R=&]V86[I('!O;&4Z("5S`$EM<&]R=&]V86[I
M('!O;&EA.@!6;&^^:;L@:[7ZZ"!?>F$`0F]L('IA9&%N_2!N97-P<N%V;GD@
M:_-D(&%K8VEE+@!.97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&$O86QE
M8F\@:&5S;&\`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!A
M;'1E<FYA=.UV;F$@861R97-A+B!3:_IS=&4@=&\@>FYO=G4@86QE8F\@:V]N
M=&%K='5J=&4@<W!RX79C=2!6X;EH;R!S>7-TZ6UU+"!A:R!P;W1R96)U:F5T
M92!P;VUO8RX`6G;DZ+EINR!O9'-A9&5N:64`26YD:6$`2F5D;F]T;&EV[2!P
M;W6^[79A=&5L:6$`26YD;V[I>FEA`$EN9F\`26YF;W)MX6-I90!);F9O<FWA
M8VEE('6^(&YI92!S^B!D;W-T=7!NZ2X`5FQOOFF[(%]S=.5P96,@>F$`5FQO
MOFF[(&]B<N%Z;VL`5FQOOFF[('1A8G6U:W4`5FQOOFF[(&QI;FMU`%9L;[YI
MNR!?<W3E<&5C('!R960`5FQOOFF[(&YO=OT@<W3E<&5C('IA(&%K='7A;&YY
M`%9L;[YINR!N;W;]('-TY7!E8R!P<F5D(&%K='7A;&YY`%9L;[YINR!N;W;]
M(')I861O:R!Z82!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R:6%D;VL@<')E9"!A
M:W1UX6QN>0!6;&^^:;L@;V1S=&%V96,@>F$@86MT=>%L;GD@8F]D`%9L;[YI
MNR!O9'-T879E8R!P<F5D(&%K='7A;&YY(&)O9`!6;&^^:;L@86QT97)N873M
M=FYU(+EA8FSS;G4`6F%D86IT92!E+6UA:6QO=OH@861R97-U+"!N82!K=&]R
M^B!D;W-T86YE=&4@;F]VZ2!H97-L;SH`5FQOOFF[(&)U;FMU('IA`%9L;[YI
MNR!B=6YK=2!P<F5D`%9L;[YINR!S=.5P96,@>F$`5FQOOFF[('-TY7!E8R!P
M<F5D`%9L;[YT92!S<'+A=GD`5FQOOFF[(&]D<W1A=F5C('IA`%9L;[YINR!O
M9'-T879E8R!P<F5D`%9L;[YINR!R:6%D;VL@>F$`5FQOOFF[(')I861O:R!P
M<F5D`%IA9&%J=&4@<&^^861O=F%N^B!O9'!O=F7O(&YA(&)E>G!EZ&YO<W1N
M^B!O=.%Z:W4Z`%9L;[YINR]U<')A=FF[(&]B<N%Z;VL`5FQOOFF[+W5P<F%V
M:;L@;&EN:W4`3F$@;V1O<VEE;&%N:64@<')E('IO>FYA;2!P<NUJ96UC;W8@
M;F5MX71E(&1O<W1A=&_H;OT@:W)E9&ET+@!.961O<W1A=&_H;OT@:W)E9&ET
M+@!#96SI(.CM<VQO`%IO>FYA;2!C96S]8V@@Z&ES96P`3F5P;&%D;ND@541(
M("A5<V5R($1A=&$@2&5A9&5R+"!(;&%V:>AK82!P;W6^[79A=&6U<VO]8V@@
M^F1A:F]V*2X`3F5P;&%T;ND@^F1A:F4@9F]R;>%T=2!:25`N`$YE<&QA=&[A
M(&%P;&EKX6-I82X`3F5P;&%T;ND@240@9.%V:WDN`$)O;&D@;V1O<VQA;ND@
M;F5P;&%T;ND@^F1A:F4N`$YE<&QA=&[A(&-I9;5O=N$@861R97-A+@!.97!L
M871N_2!F;W)MX70@<_IB;W)U`$YE<&QA=&[](&QI8V5NZ&[](&NU^N@N`$)O
M;&$@>F%D86[A(&YE<&QA=&[A(&QO:V%L:71A+@!.97!L871NX2!H;V1N;W1A
M(&US9U]T>7!E+@!.97!L871NX2!A;&5B;R!C:/UB86KZ8V$@:&]D;F]T82!A
M<&E?:60N`$YE<&QA=&[I(&%L96)O(&-H_6)A:OIC92!P87)A;65T<F4N`$YE
M<&QA=&[I(')O9&GH;W9S:^D@<'+A=F\N`$YE<&QA=&[I(&ED('!A<G1N97)A
M+@!.97!L871N_2!K\V0@<')O9'5K='4N`$YE<&QA=&[]('!R;W1O:V]L`$YE
M<&QA=&[]('!R[6IE;6-A.B`B)7,B`$YE<&QA=&[](&]B:F5K="!Z9&EEM6%N
M:6$`3F5P;&%T;N$@>F1R;VIO=N$@861R97-A+@!.97!L871NZ2#Z9&%J92!U
M;FEC;V1E+@!);G9E;G3A<@!);G9E<G1O=F&[(';]8F5R`$ERX6X`27)A:P#-
M<G-K;P!)<VQE(&]F($UA;@!/:F5D:6YE;.D@8OIR:WD`27IR865L`%9Y9&%V
M871EM0!+=7)Z[79A`%1A;&EA;G-K;P!*86UA:FMA`$IA;G7A<@!*87!O;G-K
M;P!*97)S97D`2F]R9.%N`$KZ;`!*^FX`6F%R;W9N8;L`6F%R;W9N8;L@9&\@
M<W1R961U`%IA<F]V;F&[(&1O(&)L;VMU`%IA<F]V;F&[(':U879O`%IA<F]V
M;F&[('9P<F%V;P!+87IA8VAS=&%N`%!O;F5C:&&[(&]R:6=I;N%L/P!+9?)A
M`$ME<F)E<F]S('-E<G9E<B!Z86UI971O;"!A=71E;G1I9FEKX6-I=2X`2V5R
M;F5L+6YO=N'H:6MO=FEA`%9Y='9O<F5N:64@:[7ZZ&$`1&EG:73A;&YY(&]D
M=&QAZ&]K(&NU^NAA`$3EOFMA(&NU^NAA`%1Y<"!KM?KH80!0;W6^:71I92!K
MM?KH80!+M?KH('6^(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU
M^NAO=BX`1&5T:0!+:7)I8F%T:0"E=61O=F]D96UO:W)A=&EC:^$@<F5P=6)L
M:6MA($OS<F5A`$OS<F5J<VOA(')E<'5B;&EK80!+=79A:G0`2VER9VFY<VMO
M`%9Z7VBU860`2F%Z>6L`3&%O<P!0;W-L961NX2!P;VQO=FEC80!0;W-L961N
MX2!Z;65N82!H97-L80!0;W-L961NX2"Y='9RNP!0;W-L961NX2!A:W1U86QI
M>N%C:6$Z`%!O<VQE9&[I('!R:6ALX7-E;FEE.B`E<P!0;W-L961NZ2!P<FEH
M;.%S96YI93H@)7,@>B`E<P!0;W-L961NZ2!P<FEH;.%S96YI93H@;FEK9'D`
M3&]T>;ES:V\`4'+A=F\`5GIHM6%D`$YE8VAA:G1E('!RX7ID;F4@<')E(+YI
M861E;B!O:W)A:@!,:6)A;F]N`%:U879O`$AL879IZ&MA(':U879O`$AO9&YO
M='D@=K5A=F\`3&5S;W1H;P#:<F]V9?(`3&EBZ7)I80!,[6)Y80!,:6-H=&5N
MN71A:FYS:V\`I6%H:^D@;7)H;VQE;FEE`*5A:&O](&3AON\`4N%N;R"U86AK
M_2!DX;[O`$YE<VOT<B"U86AK_2!DX;[O`*5A:&OI(&1AON]O=ND@<')E:.%N
M:WD`I6%H:_T@9.&^[R!S(&AR;65N[6T`I6%H:^D@<VYEOF5N:64`I6%H:^D@
M<VYE:&]VZ2!P<F5HX6YK>0!,:6UE<FEC:P!,:6YK80!,:6YK82!U:V%Z=6IE
M(&YA.@!0<F5P;VIINR!E+6UA:6QO=OH@861R97-U('-O('-T<N%N:V]U(&YA
M('#M<V%N:64@<&^Y='D`3&EN:WD`3&EN=7@@0V]O:VEE`%IO>FYA;2`M('!O
M=;[M=F%T9;4@=79I9.T@<')I9>AI;F]K`%9Y<.US8;L@>F]Z;F%M(&1A=&%B
MX7H`6F]Z;F%M('3I;2!0;VUO8V[M:V$`5GEP[7-ANR!Z;WIN86T@=&%B=6QI
M96L`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`
M3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`6F]B
M<F%Z96YI92!S961E;NT@>FQY:&%L;SH@)7,`6F]B<F%Z96YI92!P;W6^[79A
M=&6U;W8@>FQY:&%L;SH@)7,`6F]B<F%Z;W9A;FEE('IO>FYA;74@<&]UONUV
M871EM6]V(&IE('IA:^%Z86[I+@!,:71E<F%T^G)A`$QI='9A`$YAZ.UT879A
M('-A+BXN`$UI97-T;GD@Z&%S.B``3&]K86QI>N%C:6$@82#H87,`3&]K86QI
M=&$`4')I:&SA<V5N:64`6N%Z;F%M>2!P<F5D8VCA9'IA:OIC96H@<WEN8VAR
M;VYI>N%C:64`3V1H;.%S:;L`4')I:&SA<V5N:64`VFQO:'D@<')I('!R:6AL
MX7-E;NT`4')I:&SA<V5N:64@>FQY:&%L;RP@<')E=&^^92!S=&4@>F%D86QI
M(&YE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N`%!R
M:6ALX7-E;FEE('IL>6AA;&\N`$1L:/T@=&5X=`!,X7-K80!.[7IK80!-86SI
M(&=RZ6-K92!P[7-M96[A`$UA;.D@;&%T:6YS:^D@<.US;65NX0!-86SI('+M
M;7-K92#H[7-L:6-E`$QU>&5M8G5R<VMO`$U-`%-P<N%V82!D\F$`4'+M;&]H
M82!-4RU43D5&(&YE;V)S86AO=F%L82"^:6%D;F4@^F1A:F4N`$U31P!-86-A
M;P!-86-E9/-N<VMO`$UA9&%G87-K87(`3>%G:6$`4&^Y=&$`4&]S;&&[(&4M
M;6%I;"!A9&UI;FES='+A=&]R;W9I`%9Y='9O<FF[(&QI;E]K=2XN+@!-86QA
M=VD`36%L86IZ:6$`36%L961I=GD`36%L:0!-86QT80!3<')A=F]V8;L@>F]Z
M;F%M(&MA=&5G\W)I[2P@<R!K=&]R_6UI(&]Z;F'H=6IE=&4@<&]L;[YK>2!A
M(&9A<F)Y(&%S;V-I;W9A;ND@<R!T_6UI=&\@:V%T96?S<FEA;6DN`$UA<&$@
M36%P,C0`36%P82!-87!1=65S=`!-87!O=F%N:6$@=6QOOF5NZ2X`36%R96,`
M3VMR86H`3WIN8>AINR!P<NUZ;F%K;6D@4')EZ.UT86[I+TYE<')EZ.UT86[I
M`$]Z;F'H:;L@:6[];6D@<'+M>FYA:VUI("AN87!R+B!$]&QEOFETZ2]:;V1P
M;W9E9&%NZ2D`36%R<VAA;&QO=F4@;W-T<F]V>0!-87)T:6YI:P!::&]D;ND@
M<&]L:6$`36%U<F5TX6YI80!-875R[71I=7,`36%X:6WA;&YY('!O=F]L96[]
M(&MR961I="X`0F]L('!R96MR;^AE;OT@;6%X:6WA;&YY('!OZ&5T(.AA<W3M
M('-P<N%V>2X`3F%J=GFYN6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`R-"!H
M;V3M;CH@`$YA:G9YN;EI82!T97!L;W1A('IA('!O<VQE9&[]8V@@-B!H;V3M
M;CH@`$UA>&EMX6QN>2!P;^AE="!B;&]K;W8@<&]R=.%L=0!-87AI;>%L;F$@
M9.6^:V$`3>%J`$UA>6]T=&4`365D:6/M;F$`R&QE;F]V:6$`6F]B<F%Z96YI
M92!M96YU.@!:;/KH:;L@8G5N:WD`4W!RX79A`%-P<N%V82!B;VQA(/IS<&6Y
M;F4@;W9E<F5NX2P@86QE(&-E<G1I9FEKX70@<&]D<&ES=2!S82!N97!O9&%R
M:6QO(&]V97)INRX`4&QA=&YO<[L@<W!RX79Y('9Y<'*Y86QA+@!4>7`@<W!R
MX79Y`%!OZ&%S:64@365T87(`VF1A:F4@365T87(@;FEE('/Z(&1O<W1U<&[I
M+@#:9&%J92!-971A<B!N:64@<_H@:R!D:7-P;WKM8VEI+B!$971A:6QY(&)O
M;&D@>F%Z;F%M96YA;ND@<')E(&%D;6EN:7-T<N%T;W)A+@!3>7-TZ6T@365T
M87)$0B!N:64@:F4@<')I<&]J96[]+@!-973S9&$`365T\V1A("(E<R(@;FEE
M(&IE(&1E9FEN;W9A;N$`3F5D969I;F]V86[A(&UE=/-D82X@5F]L86[I('H@
M;65T\V1Y.B`E<P!-971R:6-KZ0!-97AI8V\`36EK<F]NZ7IS:V4@9F5D97)A
M=.UV;F4@N73A='D`4W1R960`5'EP($UI;64`3F%J;FF^N6EA('1E<&QO=&$@
M>F$@<&]S;&5D;OUC:"`R-"!H;V3M;CH@`$YA:FYIOKEI82!T97!L;W1A('IA
M('!O<VQE9&[]8V@@-B!H;V3M;CH@`$UI;FEMX6QN82!D;V)A('!L871N;W-T
M:2!H97-L82!EN71E(&YE=GEP<KEA;&$`6G)K861L;W9O(&]B<N%T:;L`4O1Z
M;F4`0VC]8F$@8F%L[6L@4$5!4B!(5%107U)E<75E<W0N`$-H_6)A(&MO;F9I
M9W5RX6-I82X@06L@8VAC971E('!O=;[M=F&[('3Z=&\@87!L:6OA8VEU+"!M
M=7/M=&4@=&5R87H@=GEG96YE<F]V8;L@:V]N9FEG=7+A8VEU+@!#:/UB82!)
M1"!S<'+A=GDN`$-H_6)A('!OOF%D;W9A;OT@4$5!4B!B86SM:R!-86EL+@!#
M:/UB82!)1"!R96SA8VEE+@!0;VX`36]B:6QN_2!M86EL`$UI97)N>0!$X71U
M;2!P;W-L961N96H@>FUE;GD`57!R879INR!54DP`36]D=6QU<P!-;VQD879S
M:V\`36]N86MO`$UO;F=O;'-K;P!-97-I86,@82!R;VL`365S8>AN90!-;VYT
M<V5R<F%T`$UE<V'H;ND@9N%Z>0!.82!R:6%D:W4@)60@8F]L;R!NX6ID96[]
M8V@@=FEA8R!P;VSM(&%K;R!OZ&%KX79A;OUC:"`E9"X`36%R;VMO`%!R979A
MOFYE(&IA<VYO`%!R979AOFYE(&]B;&'H;F\`4')E=F&^;F4@<VQN9>AN;P!0
M<F5S=6[ZNR!D;VQU`%!R97-U;OJ[(':U879O`%!R97-U;OJ[('9P<F%V;P!0
M<F5S=6[ZNR!H;W)E`%!R97-U;OJ[(&1O;'4`4')E<W5N^KL@:&]R90!-;WIA
M8FUI:P!6:6%C^G)O=O)O=ND@=GEB97)A8VEE('IO>FYA;7D`5FEA8V[A<V]B
M;OT@=OUB97(`36]J92!K;VYT;P!);F9O<FWA8VEE(&\@;6]J;VT@^NAT90!-
M]&H@<&]R=.%L`%9Z:+5A9"!M]&IH;R!P;W)TX6QU`$UY86YM87(`3FEE+"!.
M15/:2$Q!4\U-+@!-96YO`$YA;>UB:6$`3F%U<G4`3F5PX6P`2&]L86YD<VMO
M`$AO;&%N9'-KZ2!!;G1I;'D`6N%K;&%D;N$@55),($YE='-C87!E`%523"!P
M<F4@>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O=B!#02!.971S8V%P90!54DP@
M<')E('!O;&ET:6MU($-!($YE='-C87!E`%523"!P<F4@;V)N;W9E;FEE('!L
M871N;W-T:2!C97)T:69I:^%T;W8@3F5T<V-A<&4`55),('!R92!Z;F5P;&%T
M;F5N:64@8V5R=&EF:6OA=&]V($YE='-C87!E`$UE;F\@4U-,('-E<G9E<F$@
M3F5T<V-A<&4`2V]M96YTX7(@8V5R=&EF:6OA='4@3F5T<V-A<&4`5'EP(&-E
M<G1I9FEKX71U($YE='-C87!E`%-I9;L`3FEK9'D`3F]VX2!+86QE9/-N:6$`
M3F]VX2!K871E9_-R:6$`3F]VX2!S<'+A=F$@<')E("5S`$YO=@!.;W;I('!O
M=;[M=F%T9;5S:^D@;65N;R`H;F5P;W9I;F[I*0!.;W;](%KI;&%N9`!.;W;I
M(&AE<VQO`%!L871N;W.[(&YO=NEH;R!H97-L82!V>7!RN>T@)7@N`$YO=ND@
M:&5S;.$@;FEE('/Z(')O=FYA:^DN`$YO=ND@;VMN;R`H7V)L86YK*0!.97=S
M`$1I<VMU<V[I('-K=7!I;GD`SV%L96H`3F%S;&5D=6KZ8V4@-"!FX7IY`,]A
M;+EI92!N87-T879E;FEA`$YA<VQE9'5J^F-A/@!.:6MA<F%G=6$`3FEG97(`
M3FEGZ7)I80!.;V,`3FEU90!.:64`3FEE('/Z(&1O<W1U<&[I(+YI861N92!K
M;VYF:6=U<F'H;ND@^F1A:F4L('!R92!K=&]RZ2!B>2!S82!D86QI('IO8G)A
M>FF[(')O>F1I96QY+@!0<F4@=GET=N%R86YI92!)4T\@;V)R87IO=B!N:64@
M:F4@:R!D:7-P;WKM8VEI(+YI861N82!S=')A=.EG:6$N`$YE97AI<W1U:F4@
MN6%B;/-N82!P<F4@9.%V:W4N`$YA('!OOF%D;W9A;F5J('!O>NUC:6D@;F5E
M>&ES='5J92"^:6%D96X@8FQO:RX`4')E($U#04P@875T96YT:69I:^%C:74@
M;F5B;VQO('IA9&%NZ2!M96YO(&MA;&5N9.%R82X`KFEA9&YA('IM96YA+@!+
M('1O;75T;R!P<N%V=2!N96UOOFYO('!R:61ANR"^:6%D;F4@<&]D<FEA9&5N
MZ2!P<N%V82X`4')E("5S(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!0
M<F4@1E10(%9&4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82X`4')E(%-1
M3"!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`%!R92!344PM1FEL
M92!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`*YI861E;B!K<F5D
M:70N`$YE8F]L;R"Y<&5C:69I:V]V86[I(&UI97-T;R!U<NAE;FEA+@!3^F)O
M<B!N96)O;"!N86AR86[]+@!.96)O;&D@;N%J9&5NZ2"^:6%D;F4@:6MO;GDN
M`$YI92!J92!N87-T879E;N$@;&]K86QI=&$N`$YE8F]L82!Z861A;N$@;&]K
M86QI=&$N`$YE8F]L82!Z861A;N$@OFEA9&YA('-P<N%V82X`3F5B;VQO(+EP
M96-I9FEK;W9A;ND@OFEA9&YE(&UE;F\N`$YE8F]L;R"Y<&5C:69I:V]V86[I
M(.CM<VQO+@"N:6%D;F4@=7+AOFQI=ND@9F]R='5N>0!0<F4@2%144"!A=71E
M;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@24U!4"!A=71E
M;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@2V5R8F5R;W,@
M875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($QO9VEN
M(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!005-3
M5T0@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E(%--
M0B!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!.96)O;&$@
M>F%D86[A(&-E<W1A(&L@<')O9W)A;74@3W!E;E-33"X@4')O9W)A;2!/<&5N
M4U-,(&IE('!O=')E8F[](&YA('!RX6-U(',@^F1A:FUI(%!+0U,@,3(N`*YI
M861N92!P<F5B:65H86KZ8V4@<')I:&SA<V5N:6$N`$MV\W1A(&YI92!J92!N
M87-T879E;N$N`$)E>B#H:6%R`$YE8F]L(+EP96-I9FEK;W9A;OT@;V1D9;5O
M=F'H+@!"97H@<W1RX6X`4_IB;W(@;F5NX6ID96[]`%!R92!V>7)O=F[A=F%C
M:74@<&%MY+L@;FEE(&IE(&1O<W1U<&[](+YI861E;B!D;^AA<V[]('!R:67H
M:6YO:RX`3F5B;VQO(&]D;W-L86[I('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L
M96)O(&AE<VQO+@!.96)O;&D@=G+A=&5NZ2!P;&%T;ND@6$U,(/ID86IE`*YI
M861N92!H;V1N;W1Y`%8@</1V;V1N96H@:V]N9FEG=7+A8VEI(&YE8F]L82!N
MX6ID96[A(+YI861N82!V97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I
M9W5RX6-I=2X`5B!K;VYF:6=U<N%C:6D@;F5B;VQA(&[A:F1E;N$@OFEA9&YA
M('9E<GII82X@5GEG96YE<G5J=&4@>FYO=G4@:V]N9FEG=7+A8VEU+@"N:6%D
M96X`KFEA9&YE("AP;W6^:;L@:6UP;&EC:71N^B!H;V1N;W1U*0!/<W1R;W8@
M3F]R9F]L:P!3979E<F[A('!O;&]G=;5A`%-E=F5R;ND@36%R:>%N<VME(&]S
M=')O=GD`3O-R<VMO`$YE<&QA=.T@<&\`3F5P;&%T[2!P<F5D`$YI92!J92!A
M9')E<^%R`$YI92!J92!I;7!L96UE;G1O=F%NZ2X`3F5N87-T879E;ND`3FEE
M(&IE('!O9'!O<F]V86[I+@!0;WINX6UK>0!.:>@@;F$@<')E>F5R86YI92P@
M=G+ANW1E('-A('-PY+LN`$YO=F5M8F5R`,CM<VQO`%!OZ&5T('IN86MO=@!0
M;^AE="!S=.5P8V]V`%!OZ&5T(')I861K;W8`4')E(&%K='5A;&EZX6-I=2!Z
M;WIN86UU('!R[6IE;6-O=B!N96)O;&D@N7!E8VEF:6MO=F%NZ2#H[7-L82X`
M3TL`3V)J96MT`$%U=&]R(&]B:F5K='4`3W-M:>AK;W;]`$]K=/-B97(`1FEL
M=&5R(&YA(&YA9.%V:WD`4')A8V]V:7-K;P!3=&%RZ2!A(&YO=ND@:&5S;&\@
M;75S:6$@8GF[(&]D;&FY;NDN`%-T87+I(&AE<VQO`%-T87+I(&AE<VQO(&YE
M8F]L;R!Z861A;ND@<W!RX79N92X`3VWA;@!)8F$@24U!4"!S97)V97)Y('!O
M9'!O<G5J^B!Z9&EEM6%NZ2!P<FEEZ&EN:WDN`$EB82!U<N&^;&EVZ2!F;W)T
M=6YY`$IE('!R[7!U<W1NX2!I8F$@:F5D;F$@92UM86EL;W;A(&%D<F5S82X`
M5FQA<W1N[6MA(&%L96)O('!RX79A('9L87-T;NUK82!P<F4@>F1I9;5A;OT@
M;V)J96MT(&WTOF4@>FUE;FF[(&EB82!V;&%S=&[M:R!A;&5B;R!S>7-TZ6UO
M=OT@861M:6YI<W1RX71O<@!/='9O<FF[('8@;F]V;VT@;VMN90!#:'EB82!/
M<&5N4U-,.B!N97!O9&%R:6QO('-A('KM<VMANR#Z9&%J92!Z('!O9'#M<V%N
M96H@Z&%S=&D@4R]-24U%+@!/='9O<FF[('3Z=&\@;&EN:W4@=B!N;W9O;2!O
M:VYE`$]P97)AZ&[]('-Y<W3I;0!.87-T879E;FEA`$YA<W1A=F5N:6$@)7,`
M6F]R861E;OT@>F]Z;F%M`$]R9V%N:7KA8VEA`$]R9V%N:7IAZ&[A(&IE9&YO
M=&MA`$]R9V%N:7IO=F%N:64`4/1V;V1NX2"Y86)L\VYA(&%P;&EKX6-I90!0
M]'9O9&[I(+EA8FSS;GD@=B`E<SH`26[I`,]A;+EI92!I;F9O<FWA8VEE`%!R
MX79A('9L87-T;NUK80!004T@875T96YT:69I:^%C:6$@;FEE(&IE(&1O<W1U
M<&[A+@!014%2.DUA:6P@8F%C:V5N9`!$:6=I=.%L;GD@<&]D<&ES(%!'4`#:
M9&%J92!Z8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4`!01U`@=F5R96IN_2!KM?KH
M`-ID86IE('!O9'#M<V%NZ2]Z8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4`!02%`@
M:_-D`%!(4"!3:&5L;`!0;W!O;'5D;NT@M6%H:_T@9.&^[P!0;W!O;'5D;NT@
M<')E:.%N:WD`4&]P;VQU9&[M('-N9;YE;FEE`%!O<&]L=61N[2!S;F5H;W;I
M('!R96CA;FMY`%!O<&]L=61N[2!S;F6^96YI90!0;W!O;'5D;NT@8OIR:WD`
M0VC]8F$@<F]ZN>UR96YI92!03U-)6`!07TA0(%-H96QL`%9Y<&QN96YI90!0
M86MI<W1A;@!086QA=7-KZ2!O<W1R;W9Y`%!A;&5S=.UN<VME(/IZ96UI90!0
M86YA;6$`4&%P=6$@3F]VX2!'=6EN96$`4&%R86=U87D`R&EA<W1OZ&YE(&]B
M;&'H;F\`2&5S;&\`2&5S;&\@8F]L;R#Z<W!EN6YE('IM96YE;NDN`$YE<W!R
MX79N92!H97-L;P!0<F4@875T96YT:69I:^%C:74@4D%$2553(&IE('9YOF%D
M;W9A;ND@:&5S;&\N`$AE<VQO(',@<&]T=G)D96[M;0!(97-L;SH`2&5S;&\Z
M(`!(97-LX2!M=7-I82!B>;L@<F]V;F%KZ2X`5FQOOFF[`%9L;[YINR!Z;R!S
M8VARX6YK>0!#97-T80!0<F5B:65H86KZ8V4@<F5G:7-T<N%C:64Z`*5U9&EA
M`%!E<F-E;G0`5GEK;VYANR!O<&5RX6-I92#Z9'*^8GD`5GEK;VYANR!O<&5R
MX6-I92#Z9'*^8GD@<')I('!R:6ALX7-E;NT_`%!RX79O`%!RX79O("(E<R(@
M;F5B;VQO('9Y;6%Z86[I+@!0<NUS='5P('IA;6EE=&YU=/T`4'+A=F$`061M
M:6YI<W1RX6-I82!P<N%V`$]S;V)NZ2!I;F9O<FWA8VEE`%!E<G4`1&]MX6-E
M('IV:65R873A`$9I;&EP[6YY`%1E;&5F\VX`1F]T;V=R869I90!0:71C86ER
M;@!";V1O=@!+;&EK;FET92!P<F]S[6T@9&\@;F5J86ME:B!B=6YK>0!0;W1V
M<N]T92!P<F]S[6TL(+YE(&-H8V5T92!O9'-T<N%N:;L@=&5N=&\@96QE;65N
M=#H`4&]T=G+O=&4@<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[(&QI;FMU
M('H@=&]H=&\@96QE;65N='4N`%IA9&%J=&4@<')O<^UM(&UE<VEA8R!A(')O
M:RX`6F%D86IT92!P<F]S[6T@;65N;R!P<F4@;F]V^B!K871E9_-R:74Z`%IA
M9&%J=&4@<')O<^UM('!L871N^B!)4"!A9')E<W4N`%IA9&%J=&4@<')O<^UM
M('!L871N_2!DX71U;2P@<VMO;G1R;VQU:G1E('!OZ&5T(&1N[2!V(&UE<VEA
M8VDN`%IA9&%J=&4@<')O<^UM('!L871N_2#H87,N`%!R;W/M;2!U=F7O=&4@
M>FAR;G5T:64@<')O8FSI;74N`%!R;W/M;2!Z861A:G1E('-V;VIE('!O=;[M
M=F%T9;5S:^D@;65N;R!A(&AE<VQO`%!R9>CM=&%J=&4@<VD@<')O<^UM(&YA
M<VQE9'5J^F-I('1E>'0N($U54\U412!S^FAL87-INR!S('!O9&UI96YK86UI
M('!O=;[M=F%N:6$@<WES=.EM=2X`6F%D86IT92!P<F]S[6T@;65N;R!P<F4@
M;F]V^B!K871E9_-R:74Z`%!OM7-K;P!0;VQI=&EK80!!;FME='D`4&]R='5G
M86QS:V\`56UI97-T;F5N:64@=&]H=&\@;V)RX7IK=0!5;6EE<W1N96YI92!T
M96IT;R!T86)UM6MY`$]D;W-L8;L@9&\@=&]H=&\@<')I9>AI;FMA("AN979Y
M;G5C=6IE($E-05`I`%IRX;YK>2!Z82!P;W-L961N_6-H("5S(&AO9.UN.B``
M4')A=F1E<&]D;V)N;W.[/&)R("\^>G+AOF]K`%!R969S7VQD87`Z('!OOF%D
M;W9A;ND@<F]ZN>UR96YI92!,1$%0(&YE8F]L;R!NX6ID96[I+@!0<F5F<U]S
M97-S:6]N.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<V5S<VEO;B!N96)O;&\@
M;N%J9&5NZ2X`5&QA:P!4;&%K(&YA(/IR;W9N:2!M;W)A.B``5&QA:SH@`%5K
MX;YK80!:;V)R87IINR!U:^&^:W4@;V)RX7IK=2!V(&YO=F]M(&]K;F4`4')E
M9&-HX61Z86KZ8V4@;F%S=&%V96YI80!6>71L8>AINR!D;VMU;65N=`!0<FEV
MX71N>2!KM?KH`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K='D`5OUZ
M=F$@;F$@>F%D86YI92!T97AT=0!697)E:F[](&NU^N@`06QG;W)I=&UU<R!V
M97)E:F[I:&\@:[7ZZ&$`26YF;W)MX6-I92!O('9E<F5J;F]M(&NU^NAI`%9E
M<F5J;OTO<')I=N%T;GD@:[7ZZ&]V_2!PX7(@;F5B;VP@^G-P9;EN92!V>6=E
M;F5R;W9A;OTN`%!O<G1O<FEK;P!+871A<@!$;W1A>@!+=O-T80!24T$@=F5R
M96IN_2!KM?KH("@E9"!B:71O=BD`4')E<.UN8>@@<R!V_6)E<F]M`$3AON\`
M4N%N;R!DX;[O`$YE<VOT<B!DX;[O`$1AON]O=ND@<')E:.%N:WD`1.&^[R!S
M;R!S;F5H;VT`1.&^[R!P<F5C:.%D>F%J^F-I('8@<VYEOF5N:64`3N%H;V1N
MX2!F;W)T=6YA`%!O;65R`,CM=&&[`,CM=&&[('-P<N%V>0!.86]Z86H@=GEM
M87IANR`E<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO('9RX71INR!S<.2[+@!.
M86]Z86H@=GEM87IANR!P;W6^[79A=&6U<VOI(/ID86IE('!R92!P;W6^[79A
M=&6U82`E<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO('9RX71INR!S<.2[+@!6
M<N%T:2!S<.2[(%9AN74@<&]S;&5D;OH@86MC:74`3V)N;W9INP!/8FYO=FF[
M(&5L96UE;G1Y(&1Y;F%M:6-KZ6AO(&UE;G4Z`$]B;F]V:;L@>F]B<F%Z96YI
M92!P;W)TX6QU.@!296=U;.%R;GD@=OUR87H`4')E:&QI861AZ"!V>KMA:&]V
M`%IN;W9U(&YAZ.UT8;L`4&]S=')E:'D`5GID:6%L96[I('-E<G9E<GD`5GID
M:6%L96[A(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D
M<W1RX6YINP!/9'-T<N%N:;L@8FQO:P!/9'-T<N%N:;L@<W3E<&5C`$]D<W1R
MX6YINR!F;W)MX71O=F%N:64`3V1S='+A;FF[('#A<@!/9'-T<N%N:;L@=6QO
MOF5N_2!S:W)I<'0@>B!D;^AA<V[I:&\@<')I9>AI;FMA(&YA('-E<G9E<FDN
M`$]D<W1RX6YINP!/9'-T<N%N:;L@=&5N=&\@8F]D('H@9&]K=6UE;G1U`$]D
M<W1RX6YINR!P;W6^[79A=&6U80!/9'-T<N%N:;L@<&]UONUV871EM6$Z("5S
M`$YA('!OOFEA9&%V:W4@;F5B;VQO(&UOOF[I(&]D<&]V961ANRX@3N%V<F%T
M;W;](&OS9"!C:'EB>3H@`%!OOF%D;W9A;OH@<VQUOF)U('-A(&YE<&]D87)I
M;&\@;N%J<[LN`%8@:V]N9FEG=7+A8VEI("5S(&YI92!J92"Y<&5C:69I:V]V
M86[A('!OOF%D;W9A;N$@<&]L;[YK82`B)7,B`%8@:V]N9FEG=7+A8VEI(%9&
M4R!N:64@:F4@N7!E8VEF:6MO=F%NX2!P;[YA9&]V86[A('!O;&^^:V$@(B5S
M(@!6(&MO;F9I9W5RX6-I:2!N:64@:F4@N7!E8VEF:6MO=F%NX2!P;[YA9&]V
M86[A('!O;&^^:V$@(B5S(@!0;W9I;F[I('!O;&4`5GEM87IANR!F;W)M=6SA
M<@!/8FYO=FF[(&AE<VQO`$]B;F]V:;L@5F&Y92!H97-L;P!/8FYO=FF[('!O
M<VQE9&[](&1O=&%Z`%;]<VQE9&MY`$[A=G)A="!N82!N87-T879E;FEA`%IA
M9&%J=&4@;F]VZ2!H97-L;P!2975N:6]N`%9RX71INR!K;VYF:6=U<N%C:74`
M3F%S=&%V96YI82!R;WJY[7)E;NEH;R!T97AT;W;I:&\@961I=&]R=0!(X61A
M;FMY`%9P<F%V;P!(;&%V:>AK82!V<')A=F\`2&]D;F]T>2!V<')A=F\`5FQA
M<W1N;W-T:2!?<FEA9&MA+BXN`%)O;&$`4G5M=6YS:V\`3W1OZ&F[(&\@,3@P
M`$]T;^AINR!VM6%V;P!/=&_H:;L@=G!R879O`%9L87-T;F]S=&D@<FEA9&MA
M`%9L87-T;F]S=&D@<FEA9&MA`%)I861K>3H`R&EA<GD`R&EA<GD@<V$@>F]B
M<F%Z:6$@;65D>FD@=KEE=&O];6D@<FEA9&MA;6D@82!S=.5P8V%M:0#(:6%R
M>2!S82!Z;V)R87II82!I8F$@;65D>FD@<W3E<&-A;6D`R&EA<GD@<V$@>F]B
M<F%Z:6$@:6)A(&UE9'II(')I861K86UI`%-P=7-T:;L`4G5S:^$@9F5D97+A
M8VEA`%)W86YD80!3+TU)344@:W)Y<'1O9W)A9FEC:_T@<&]D<&ES`%-P<N%V
M82!Z8;EI9G)O=F%NX2!P;VUO8V]U(%,O34E-10!305-,(&%U=&5N=&EF:6OA
M8VEA(&YI92!J92!D;W-T=7!NX2X`4&]S:65L86YI92!335,`4U%,(%-H96QL
M`%-13"!P<NUK87H@<')E(&BU861A;FEE(&AO9&[T=`!34T@`VE-014-(`%-?
M44P@4VAE;&P`4V\`4W;D=.$@2&5L96YA`%-VY'3]($MI='1S(&$@3F5V:7,`
M4W;D=.$@3'5C:6$`4W8N(%!I97)R92!A($UI<75E;&]N`%-VY'3](%9I;F-E
M;G0@82!'<F5N861I;GD`5&5N(&ES=/T@<N%M96,@*%]S96QF*0!386UO80!3
M86X@36%R:6YO`%-A;R!4;VUE(&$@4')I;F-I<&4`4V%T96QI=&[]('!O<VMY
M=&]V871EM0!3875D<VOA($%RX6)I80!5;&^^:;L`56QOOFF[("(E<R(`56QO
MOFF[("5S`%5L;[YINR!N87-T879E;FEA`%5L;[YINR!V>6=E;F5R;W9A;OH@
M:V]N9FEG=7+A8VEU(&%K;R!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!P<FEE
MZ&EN:V$@5N&Y:&\@<V5R=F5R82X`2V]N9FEG=7+A8VEA("5S(&)O;&$@=6QO
MOF5NX2X`4VMR:7!T(&YA('5P9W)A9&4@;F%S=&%V96[M(&)O;"!U;&^^96[]
M(&1O.B`B)7,B+@!/:F5D:6YE;.D@8OIR:WD`5F5D80!(M6%D8;L`5GEHM6%D
MX79AZ&4`5GEB97)T92!S^F)O<GD`5GEB97)T92!DX71U;0!6>6)E<G1E('-K
M=7!I;G4@;F$@<')I9&%N:64`5GEB97)T92!N;W;I:&\@=FQA<W1N[6MA`%9Y
M8F5R=&4@<V5R=F5R`%9Y8F5R=&4@<&]UONUV871EM6$@;F$@<')I9&%N:64`
M5GEB97)T92!VN65T:WD`5GEB97)T92!VN65T:WD@:V]M<&]N96YT>2!DX71U
M;74`5GEB97)T92!O8FIE:W0`6G)UN6F[(';]8F5R`%9Y8F5R=&4@>FYA:WDL
M(&MT;W+I('!O=')E8G5J971E+"!Z(&]K:65N;VL@;FF^N6EE+B!0;W1O;2!I
M8V@@;?2^971E('-K;W#M<F]V8;L@82!V;&^^:;L@>B!T97AT;W;I:&\@<&^U
M82X`5GEB97)T92!O9&1EM6]V8>@@=F\@9F]R;>%T92!DX71U;74Z`%9Y8F5R
M=&4@9F]R;>%T(&3A='5M=3H`5GEB97)T92!I9&5N=&ET=2P@:W1O<OH@8VAC
M971E('IM96YINSH`5GEB97)T92!O9&1EM6]V8>@@=F\@9F]R;>%T92#H87-U
M.@!6>6)E<G1E(&9O<FWA="#H87-U.@!6>6)E<G1E(&1V92!Z:&]D;ND@<&]L
M:6$N`%9Y8F5R=&4@<VD@9F%R96)N^B!S8VCI;74`5GEB97)T92!J87IY:SH`
M4&]S;&&[('-P<N%V=2!O('!R;V)LZ6UE`%!O<VQANR!335,`4V5N96=A;`!3
M96YZ;W(Z(`!397!T96UB97(`4W)B<VMO(&$@R&EE<FYA(&AO<F$`4^ER:6]V
MZ2#H[7-L;P#:9&%J92!Z;R!S97)V97)A('/Z(&YE<W!RX79N92!A;&5B;R!N
M:64@<_H@9&]S='5P;NDN`$%D;6EN:7-T<N%C:6$@<V5D96[M`%!L871N;W.[
M($E$('-E9&5N:6$@=GEP<KEA;&$N`%-E9&5N:6$`36YOOFEN82!H;V1N]'0`
M3F%S=&%V=&4@;6^^;F]S=&D@;F$@;V)N;W9E;FEE(%;AN6AO(&AE<VQA(&%K
M(&AO('IA8G5D;F5T92X`3F%S=&%V96YI92!V>F1I86QE;OUC:"!S97)V97)O
M=BP@:W4@:W1O<OUM(&-H8V5T92!P<FES='5P;W9ANR!Z(%;AN6AO('!O<G3A
M;'4N`%9Y8F5R=&4@:F%Z>6LL(.AA<V]V^B!Z\VYU(&$@;F%S=&%V96YI82!D
MX71U;74N`$YA<W1A=F5N:64@87!L:6OA8VEE('-P^KF[86YE:B!P<FD@N71A
M<G1E+"!F87)E8FYE:B!S8VCI;7DL(&EN=&5R=F%L=2!O8FYO=F]V86YI82!S
M='+A;FMY(&$@:6[]8V@@=FQA<W1N;W-T[2!Z;V)R87IE;FEA+@!.87-T879E
M;FEE`%/Z(&1O<W1U<&[I('-K<FEP='D@;F$@=7!G<F%D92!N87-T879E;NT`
M1&\@^G9A:'D@<')I8VCA9'IA(&YI96MOM6MO(&QO:V%L[70@<&]M;V-O=2!P
M87)A;65T<F$Z(`!397EC:&5L>0!3:&]P<&EN9P!+<N%T:WD@<_IH<FX`36%J
M^B!S82!P<F4@=N3HN6EN=2!L:6YI96L@=GET=F]R:;L@<VMR871K;W;I(&ML
MX79E<WD_`%IO8G)A>FF[`%IO8G)A>FF[(')O>F1I96QY(&UE9'II('!RX79E
M('5L;[YE;F]U(&$@;F]V;W9Y9V5N97)O=F%N;W4@:V]N9FEG=7+A8VEO=2X`
M3>$@<V$@<')I('!R:6ALX7-E;NT@>F]B<F%Z:;L@Z&%S('!O<VQE9&[I:&\@
M<')I:&SA<V5N:6$_`%IO8G)A>FF[(&UOOFYO<[L@;F$@<&]N96-H86YI92!O
M<FEG:6[A;'4`6F]B<F%Z:;L@;N%S=')O:B!N82!V_6)E<B!F87)I96(`6F]B
M<F%Z:;L@;65N=2!P<F4@;W!E<N%C:64@<R!T86)UM6MA;6D_`%IO8G)A>FF[
M(&UE;G4@)7,@;F$@M6%V96H@<W1R86YE/P!:;V)R87IINR!D:6%L\V<@<R!V
M;&%S=&YO<[MA;6D@8G5N:WD@=&%B=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V
M;&%S=&YO<[MA;6D@=&%B=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO
M<[MA;6D@<FEA9&MU('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N
M;W.[86UI(&]B<N%Z:W4`6F]B<F%Z:;L@;F%H<F%NZ0!0<F5HX6YK>0!2X6YO
M('!R96CA;FMY`$YE<VOT<B!P<F5HX6YK>0!:<N&^:WD@=B!O:V]L[0!:;65N
MN6F[`$YA:G!R=B!M=7/M=&4@>FUE;KEINR!A;&5B;R!P<F5S=6[ZNR!S=7-E
M9&[](&)L;VLH>2D`4VEE<G)A($QE;VYE`%IA<F5G:7-T<F]V8;L@<V$`4&]D
M<&ES`$%L9V]R:71M=7,@<&]D<&ES=0!3:6YG87!U<@!69;5K;W.[`%!R97-K
M;^AINR#Z9'*^8G4`4VQO=F5N<VMO`%-L;W9I;G-K;P!3;F6^96YI90!3;F5H
M;W;A('!R96CA;FMA`%-N96AO=ND@<')E:.%N:WD`4N%N;R!S;F5H;W;I('!R
M96CA;FMY`$YE<VOT<B!S;F5H;W;I('!R96CA;FMY`$CE8FMA('-N96AU.B``
M36YOOG-T=F\@=F]D>2!E:W9I=F%L96YT;ND@<VYE:'4Z(`"I86QA;?IN;W9E
M(&]S=')O=GD`4V]MX6QS:V\`4&EE<VYE(&$@8N%S;F4`5OUB97(@<VUE<G4@
M=')I961E;FEA`%ID<F]J;W;A(&%D<F5S80!*=;YNX2!!9G)I:V$`2G6^;N$@
M1V5O<F=I82!A(%-O=71H(%-A;F1W:6-H($ES;&%N9',`2G6^;N$@<&]L;V=U
MM6$`365D>F5R82!M961Z:2!S=7-E9&[];6D@8G5N:V%M:0!-961Z97)A(&UE
M9'II(&]B<V%H;VT@82!O:W)A:F]M(&)U;FMY`$]D9&6U;W9AZ`!/9'-T=7``
M3V1S='5P(&$@=GEP;&YE;FEE`*EP86YI96QS:V\`4W!A;0!6;&^^96YI92"Y
M<&5C:>%L;GEC:"!Z;F%K;W8`4F]Z9&5L:;L@8G5N:W4`4F]Z9&5L:;L@<W3E
M<&5C`%)O>F1E;&F[(')I861O:P"I<&]R='D`4W+M($QA;FMA`*ET86YD87)D
M;ND`4W1A<B!4<F5K`%!OZ&EA=&_H;OT@<F]K`*ETX70@86QE8F\@<')O=FEN
M8VEA`%-T878`1F]R;>%T('5L;[YE;FEA`$)Y9&QI<VMO`%!R9;EK<G1N=73I
M`%IO>FYA;2!R9;MA>F-O=@!/9'-T<N%N:;L@9&]MZ6YU('H@861R97-Y`*ET
M_6P@6T-34UT`3F4`4&]D<')I9>AI;F]K("(E<R(@;F5B;VP@;N%J9&5N_2X`
M4')E9&UE=`!/9&]S;&&[`%!OOFEA9&%V:V$@;F$@<')I9&%N:64@(B5S(B!D
M;R!S>7-TZ6UU(&)O;&$@;V1O<VQA;N$N($YE;?2^971E('-A('!R:6ALX7-I
MNRP@:_UM(&YE8G5D92!68;EA('!OOFEA9&%V:V$@<V-H=N%L96[A+@!$;VQN
M_2!I;F1E>`#:<W!E8V@`4')I9&%N:64@(B5S(B!D;R!S>7-TZ6UU(&)O;&\@
M^G-P9;ENZ2X`5GEM87IA;FEE(/ID86IO=B!Z;R!S>7-TZ6UU('!R92!P;W6^
M[79A=&6U82`B)7,B(&)O;&\@^G-P9;ENZ2X`5GEM87IA;FEE("(E<R(@8F]L
M;R#Z<W!EN6[I+@!6>6UA>F%N:64@(B5S(B!Z;R!S>7-TZ6UU(&)O;&\@^G-P
M9;ENZ2X`3N%V<F%T(&MU(&MO;F9I9W5RX6-I:2!B;VP@^G-P9;EN_2X@4')E
M('IO8G)A>F5N:64@>FUI96X@>FYO=G4@;F'H[71A:G1E('-T<N%N:W4N`%KA
M;&]H82!K;VYF:6=U<N%C:64@8F]L82!U;&^^96[A+@!:X6QOOF[](&MO;F9I
M9W5R8>AN_2!S^F)O<B`E<R!B;VP@^G-P9;EN92!U;&^^96[]+@!!:W1U86QI
M>N%C:6$@(B5S(B!B;VQA(/IS<&6Y;N$N`%KA<&ES("5S(&)O;"#Z<W!EN6[]
M`%-U9.%N`%/Z:')N`%;]8VAO9"!S;&YK80!:X7!A9"!S;&YK80!3;&YEZ&YO
M`%;]8VAO9"!S;&YK80!6_6-H;V0O>N%P860@<VQN:V$`5OUC:&]D('-L;FMA
M.B``6N%P860@<VQN:V$`6N%P860@<VQN:V$Z(`!(;W)N_2!I;F1E>`!0;V1P
M;W)A`%-U<FEN86T`4')I97IV:7-K;P!3=F%L8F%R9"!A($IA;B!-87EE;@!3
M=F%Z:6IS:V\`J7;I9'-K;P"I=F%JZ&EA<G-K;P!:X7IN86UY(&\@<WEN8VAR
M;VYI>N%C:6D@=GEM87IA;ND`4WEN8TU,`%-Y;G1A:W1I8VOA(&-H>6)A('8@
M<&]D;6EE;FMA8V@@:+5A9&%N:6$`4_UR:6$`0OIR:V$`0OIR:V$@82!V971E
M<FYO`$+Z<FMY`%+A;F\@8OIR:WD`5%-6('/Z8F]R`%1A8G6U:V$`5FQA<W1N
M;W-T:2!T86)UM6MY`%9L87-T;F]S=&D@=&%B=;5K>0!486EW86X`5&%I=V%N
M+"!P<F]V:6YC:6$@R.UN>0!4862^:6MI<W1A;@!486YZX6YI80!#:66U.@#:
M;&]H>0!496QE9O-N;F4@Z.US;&\`5&5P;&]T82!Z82!P;W-L961N^B!H;V1I
M;G4Z(`!497!L;W1A`%1E<&QO=&$Z(`!497!L;W1A/&)R("\^*"5S36%X)7,O
M)7--:6XE<RD@)F1E9SLE<P"I86)L\VYA("(E<R(@;F5B;VQA(&[A:F1E;N$N
M`%-P<N%V82"Y86)L\VX`5&5X=`!)8F$@=&5X=`!:87)O=FYA;FEE('1E>'1U
M`%1E>'0@:&]R90"I=`!4:&%J<VMO`%)O>KGM<F5N:64@1E10(&YI92!J92!D
M;W-T=7!NZ2X`26YT96=RX6-I82!(;W)D92]+;VQA8B!N97!O9'!O<G5J92`B
M)7,B`$E-4U`@>N%Z;F%M('-A(&YE<&]D87)I;&\@=6QOOFF[+@!4<FEE9&$@
M36%I;G1E;F%N8V4Z.B!S82!N96YAZ.UT86QA(/IS<&6Y;F4`3VMN;R!S(&YA
M<W1A=F5N:6%M:2!S82!Z871V;W)I;&\N($MO;FEE8RX`061M:6YI<W1RX71O
M<B!M=7/M(&YA:V]N9FEG=7)O=F&[('!E<FUA;F5N=&[](&)A8VME;F0@<')E
M(%!RX79A+"!A:R!C:&-E=&4@<&]UONUV8;L@4'+A=F$N`$EB82!S<&]D;N$@
M<W1R86YA`$E$(.CM<VQO(&MO;G1A:W1U(&YE8F]L;R"Y<&5C:69I:V]V86[I
M+"!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID96[I
M('8@9&%T86+A>F4N`$MO;G1A:W0@8F]L(/IS<&6Y;F4@=FQOOF5N_2!D;R!6
MX;EH;R!A9')E<^%R82X`3F$@;W9E<F5N:64@<&]D<.US86YE:B!S<'+A=GD@
M:F4@<&^^861O=F%N_2!O9&1E;&5N_2!B;&]K(',@4$=0('!O9'!I<V]M+@!)
M1"!Z;WIN86UU('!R[6IE;6-O=B!B=>\@;F5B;VQO(+EP96-I9FEK;W9A;NDL
M(&%L96)O(&)O;&\@<&]N96-H86[I('!RX7ID;F4@86QE8F\@;F5B;VQO(&[A
M:F1E;ND@=B!D871A8N%Z92X`3F5B;VP@=7+H96[]('IO>FYA;2!P<NUJ96UC
M;W8N`*EI9G)O=F%N:64@=GF^861U:F4@8F5Z<&7H;ND@<')I<&]J96YI92`H
M:'1T<',I+@!3^F)O<B`E<R!B>2!M86P@;V)S86AO=F&[(&YA<W1A=F5N:64@
M)7,N`%/Z8F]R("5S(&)Y(&UA;"!O8G-A:&]V8;L@;FEE:W1O<ND@;F%S=&%V
M96YI82`E<RX`6F1R;VIO=OT@82!C:66U;W;]('/Z8F]R(&UU<VEA(&)YNR!O
M9&QIN6[I+@!3^F)O<B!N96]B<V%H;W9A;""^:6%D;F4@^F1A:F4N`$YA<VQE
M9'5J^B!H;&%V:>AK>2!T96IT;R!S<'+A=GD@=F\@9F]R;>%T92!M97-S86=E
M+W)F8S@R,BX`0V5L;V]B<F%Z;W9K;W;](')EOFEM('-P]'-O8G5J92!P<F]B
M;.EM>2!V($EN=&5R;F5T($5X<&QO<F5R:2!K=O1L:2!C:'EBX6T@<')E:&QI
M861AZ&$L(&MT;W+I('-A(&[A;2!N97!O9&%R:6QO(&]B[7.[+B!-]+YU('-A
M('!R96IA=FF[(&YE<W!RX79N>6T@>F]B<F%Z96[M;2P@8VC]8F%J^F-I;6D@
M9G5N:V-I86UI(&5D:71O<F$@82]A;&5B;R!NX6AO9&[];6D@<.%D;6D@<')E
M:&QI861AZ&$N($%K(&IE(%;AN2!S>7-TZ6T@5VEN9&]W<R`Y>"P@:F4@=F6U
M;6D@<')A=F1E<&]D;V)NZ2P@OF4@<V$@>F]B<F%Z[2!C:'EB82`G1V5N97)A
M;"!0<F]T96-T:6]N($9A=6QT)R!A(&)U9&5T92!M=7-I9;L@<F6Y=&%R=&]V
M8;L@<&_H[71AZ"Y<;EQN5F%R;W9A;&D@<VUE(%;A<RX@4W1L8>AT92!P<F]S
M[6T@3TL@86L@;F%O>F%J(&-H8V5T92!P;W6^:;L@961I=&]R('8@8V5L;V]B
M<F%Z;W9K;W9O;2!R9;YI;64N`$ED96YT:71A("(E<R(@8F]L82!V>6UA>F%N
MX2X`26)A(+5A=N$@<W1R86YA`%1R:65D82!#<GEP=%]P9W`Z.B!P;W1R96)U
M:F4@<&]Z;F&[('5M:65S=&YE;FEE('!R;V=R86UU($=N=5!'+@!3<'+A=F$@
M;V1O<VQA;N$@)7,@<')E("5S(',@<')E9&UE=&]M("(E<R(@8F]L82!Z;V)R
M87IE;N$N"DYE97AI<W1U:F4@=KEA:R!ZX7)U:V$L(+YE('-P<N%V82!B;VQA
M('!R9>CM=&%NX2!A;&5B;R!P;V-H;W!E;N$N`$UE;F\L(&MT;W+I('-A(&WA
M('!O=;YINR!P<FD@;&EN:V]V86[M(&YA('-T<N%N:W4@;F$@<.US86YI92!S
M<'+A=B``4&_H970@<&]L[2!M=7/M(&)YNR#H[7-L;RX`5')I961A($AO<F1E
M7T-R>7!T7W-M:6UE.CH@=GF^861U:F4@;6]D=6P@;W!E;G-S;"X`3F%S=&%V
M96YI92`B)7,B('-A(&YE<&]D87)I;&\@=6QOOFF[+"!P<F5T;[YE(&IE:&\@
M^F1A:F4@<')E:W)AZ'5J^B!M87AI;>%L;G4@<&]V;VQE;OH@=F6U:V]SNP!0
M<F]G<F%M('!O=;[M=F%N_2!N82!Z;V)R87IE;FEE('1O:'1O(/ID86IO=NEH
M;R!T>7!U("@E<RD@;F5B;VP@;N%J9&5N_2X`6FYA:R!C:73A8VEE(&UU<^T@
M8GF[(&IE9&5N('IN86LN`$EB82!P<F%VX2!A(+5A=N$@<W1R86YA`$EB82!P
M<F%VX2!S=')A;F$`3V1D9;5O=F'H(&UU<^T@8GF[(&IE9&5N('IN86LN`%-E
M<G9E<B`B)7,B(&)O;"!V>6UA>F%N_2X`4V5R=F5R("(E<R(@8F]L('5L;[YE
M;OTN`*YI861O<[L@;R!P<FEH;.%S96YI92`E<R!B;VQA('9Y;6%Z86[A+@"I
M<&5C:69I:V]V86[](')I861O:R!N965X:7-T=6IE+@!$;^AA<V[]('/Z8F]R
M("(E<R(@;F5E>&ES='5J92X`6F%D86[]('1E>'0@;FEE(&IE(')O=FYA:_T@
M86MO('1E>'0@;F$@;V)R87IO=FME+@!)8F$@:&]R;N$@82!S<&]D;N$@<W1R
M86YA`$EB82!H;W)NX2!S=')A;F$`3F%H<F%NZ2#Z9&%J92!S82!O9"!P<F5D
M8VCA9'IA:OIC96AO(&MR;VMU('-T<F%T:6QI+@!.86AR86[]('/Z8F]R('-A
M(&YE<&]D87)I;&\@=6QOOFF[+@!";&]K('=E871H97(N8V]M(&YI92!J92!D
M;W-T=7!N_2X`4')I9>AI;F]K('3I;2`B)7,B(&YE8F]L(&[A:F1E;OTN`*YI
M861N92!N87-T879E;FEA(&YI92!S^B!D;W-T=7!NZ2X`KFEA9&YE(&%L=&5R
M;F%T[79N92#H87-T:2!N96UOOFYO('IO8G)A>FF[('8@=&5L92!S<'+A=GDN
M`%8@=&]M=&\@<&]L:2!J92!P<NUL:;D@=F6U82!Z;F%K;W8N(%IA9&%L:2!S
M=&4@)7,@>FYA:V]V.R!M=7/M=&4@>F%D8;L@;65N96H@86MO("5S+@!.87-T
M86QA(&-H>6)A('!R:2!P<FEDX79A;NT@(B5S(B!D;R!S>7-TZ6UU.B`E<P!.
M87-T86QA(&-H>6)A('!R:2!O9'-T<F'R;W9A;NT@<&]UONUV871EM7-K_6-H
M(/ID86IO=B`B)7,B('IO('-Y<W3I;74Z(`!.87-T86QA(&-H>6)A('!R:2!O
M9'-T<F'R;W9A;NT@(B5S(B!Z;R!S>7-TZ6UU.B``3F%S=&%L82!C:'EB82!P
M<FD@86MT=6%L:7KA8VEI("(E<R(Z("5S`%9Y<VMY=&]L('-A('!R;V)LZ6T@
M<R!N86ARX79A;NUM('/Z8F]R=3H@KFEA9&5N("5S(&YE8F]L(&YA:')A;OTN
M`%9Y<VMY=&]L('-A('!R;V)LZ6T@<R!N86ARX79A;NUM('/Z8F]R=3H@)7,@
M8F]L(';DZ+GM(&%K;R!N86IVY.BY[2!P;W9O;&5N_2!L:6UI="`H)60@8F%J
M=&]V*2X`5GES:WET;VP@<V$@<')O8FSI;2!S('5K;&%D86[M;2!S^F)O<G4Z
M("5S(&)O;"!N86AR86[](&QE;B#H:6%S=&_H;F4N`$YA<W1A;&$@8VAY8F$@
M<')I('IO8G)A>F]V86[M('1E:G1O(.AA<W1I('-P<N%V>0!.87-T86QA(&-H
M>6)A('!R:2!I;7!O<G1E(/ID86IO=B!O(&MO;G1A:W1E+@!.87-T86QA(&-H
M>6)A('!R:2!I;7!O<G1E(/ID86IO=B!I0V%L96YD87(N`$YA<W1A;&$@8VAY
M8F$@=B!K;VYF:6=U<F'H;F]M(&9O<FUU;.%R:2X@4')A=F1E<&]D;V)N92!S
M=&4@;F5V>7!L;FEL:2!P;[YA9&]V86[I('!O;&4N`$YA<W1A;&$@8VAY8F$@
M<')I('9Y:V]NX79A;NT@=7+H96YE:B!F=6YK8VEE(&%D<F5SX7)A+B!0<F]S
M[6T@<VOZ<W1E('1O(&YE<VOT<BX`3F%S=&%L82!C:'EB82!P<FD@86MT=6%L
M:7KA8VEI(&1E=&%I;&]V(&MO;G1A:W1U+B!0<F]S[6T@<VOZ<W1E('1O(&YE
M<VOT<BX`3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI('IO>FYA;74@
M<'+M:F5M8V]V+B!0<F]S[6T@<VOZ<W1E('1O('IN;W9U+@!496YT;R!)34%0
M('-E<G9E<B!N97!O9'!O<G5J92!Z9&EEM6%N:64@<')I9>AI;FMO=BX`5&]T
M;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV(')A<BX`5&]T
M;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV('II<"X`5&]T
M;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;ND@Z.US;&\@:V%R='DN`%1E
M;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L86YI92!S<'+A=B!C97H@8G+A
M;G4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P;VUO8V]U
M($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L86YI92!S
M<'+A=B!C97H@8G+A;G4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@<&]M;V-O
M=2!(5%10($%020!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@
M<W!RX78@8V5Z(&)RX6YU('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI('!O;6]C;W4@2%144"!!4$D`5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P
M;W-I96QANR!S<'+A=GD@8V5Z(%--5%`@8V5Z(&)RX6YU(%9O9&%F;VYE($ET
M86QY("AI8F$@;F$@Z.US;&$@5F]D869O;F4I+B!6>;YA9'5J92!E+6UA:6QO
M=OT@^NAE="!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4
M;W1O('!O;&4@:F4@<&]V:6YNZ2X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[
M(&EB82#H[7-L82X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[(&EB82#H[7-L
M82!A(&1V;VIB;V1K=2X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[(&EB82!O
M<VUIZ&MO=ND@:&]D;F]T>2X`5&]T;R!P;VQE(&UU<^T@8GF[('IO>FYA;2#H
M[7-E;"!O9&1E;&5N_6-H(.AI87)K;W4@86QE8F\@;65D>F5R;W4`5&]T;R!P
M;VQE(&UU<^T@8GF[('!L871NZ2#H[7-L;RX`5&]T;R!P;VQE(&UU<^T@;V)S
M86AO=F&[(&OS9"!F87)B>2!V(+EE<W1NX7-T:V]V;VT@9F]R;>%T92!21T(L
M(&YA<'+M:VQA9"`G(S$R,S1A9B<N`%1E;G1O(&9O<FUU;.%R('6^(&)O;"!S
M<')A8V]V86[]+@!4;W1O(&IE("5S+@!4;W1O(&IE(&]B:F5K="!+;VQA8B!'
M<F]U<'=A<F4N(%!R92!Z;V)R87IE;FEE('1O:'1O(&]B:F5K='4@<&]T<F5B
M=6IE=&4@92UM86EL;W;I:&\@:VQI96YT82P@:W1O<OT@<F]Z=6UI92!F;W)M
MX71U($MO;&%B($=R;W5P=V%R92X@4')E('IO>FYA;2!T86O]8VAT;R!K;&EE
M;G1O=B!N87:Y=.UV=&4@<')O<^UM("5S`%3A=&\@<W!RX79A(&)O;&$@;F%P
M[7-A;N$@=B!I;F5J(&%K;R!686UI('!O=;[M=F%N96H@>FYA:V]V96H@<V%D
M92`H)7,I+@!4;W1O(.CM<VQO(&UU<^T@8GF[(&YA:FUE;F5J(#$N`%1E;G1O
M('-E<G9E<B!N961O:^&^92!D96MO;7!R:6UO=F&[('/Z8F]R>2!Z:7`@82!G
M>FEP+@!3>7-TZ6T@:F4@;6]M96YTX6QN92!D96%K=&EV;W9A;OTN`%3A=&\@
M:&]D;F]T82!M=7/M(&)YNR#H[7-E;&[A+@!4;W1O(&]K;F\@;75S[2!B>;L@
M>F%V;VQA;ND@>B!O:VYA($YA<W1A=F5N[0!(<FUE;FEE`%1I8VME=',`R&%S
M`%1I;64@5')A8VMI;F<`1F]R;>%T(.AA<W4`5OUB97(@Z&%S=0!4:6UO<BU,
M97-T90!4:71U;&]K`$YA9'!I<R`H8G5B;&EN;W;](';]<&ES*3H`4')E`%!R
M92!V_6)E<B!V:6%C97+]8V@@<&]L;[YI96L@9'*^=&4@<&_H87,@:VQI:V%N
M:6$@:VSA=F5S=2!#;VYT<F]L("A00RD@86QE8F\@0V]M;6%N9"`H36%C*2X`
M1&YE<P!0<F5P;OJ[('IO8G)A>F5N:64@>F1R;VIO=NEH;R!K\V1U($A434P`
M5&]G;P!4;VME;&%U`%IA:G1R80!4;VYG80!6<F-H`%9R8VAN_2!RX6UE8R`H
M7W1O<"D`4')E:VQA9'D`5')I;FED860@82!4;V)A9V\`4')A=F1A(&%L96)O
M(&YE<')A=F1A`%5T`%1U;FES:V\`5'5R96-K;P!4=7)K;65N:7-T86X`5'5R
M:W,@82!#86EC;W,`5'5V86QU`%IA9&%J=&4@5F&Y=2!V;[5B=3H@`%4N5BX@
M:6YD97@Z(`!54DP`55),(%;AN6AO('-K<FEP='4@<')E('-P<N%V=2!O(&1O
M<G7H96[M`%523#H`56=A;F1A`%5K<F%J:6YA`$YE<&]D87)I;&\@<V$@=7-K
M=71OZ&YINR!P<NUS='5P(&L@5D93(&%D<F5SX7)U+@!.97!O9&%R:6QO('-A
M('!R:61ANR#O86RY:64@:6YF;W)MX6-I92!O('!O=;[M=F%T9;5O=FD@<')I
M(')E9VES='+A8VEI+@!.97!O9&%R:6QO('-A('IM96YINR!P<N%V;R!P<F4@
M5D93('/Z8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@>FUE;FF[('!RX79O('!R
M92!61E,@<_IB;W(@)7,O)7,N`$YE<&]D87)I;&\@<V$@>FUE;FF[(&YA("5S
M+@!.97!O9&%R:6QO('-A('-K;VYT<F]L;W9ANR!V9;5K;W.[('/Z8F]R=2`B
M)7,B+@!.97!O9&%R:6QO('-A('-K;VYT<F]L;W9ANR!V9;5K;W.[('/Z8F]R
M=2`B)7,O)7,B+@!.97!O9&%R:6QO('-A('-P;VIINR!S(%-13"!S97)V97)O
M;2X`3F5P;V1A<FEL;R!S82!S<&]J:;L@<&]M;V-O=2!34TPN`$YE<&]D87)I
M;&\@<V$@<VMO<.UR;W9ANR!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@=GET
M=F]R:;L@5D93(&%D<F5SX7(@(B5S(BX`3F5P;V1A<FEL;R!S82!V>71V;W)I
MNR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@<_IB
M;W(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('!R:67H:6YO:R`B)7,B
M+@!.97!O9&%R:6QO('-A('9Y='9O<FF[('!RX7ID;GD@5D93('/Z8F]R+@!.
M97!O9&%R:6QO('-A(&1E:V]M<')I;6]V8;L@^F1A:F4N`$YE<&]D87)I;&\@
M<V$@=GEM87IANR`B)7,B+"!A9')E<^%R(&YI92!J92!P<N%Z9&YY+@!.97!O
M9&%R:6QO('-A('9Y;6%Z8;L@(B5S(CH@)7,N`$YE<&]D87)I;&\@<V$@=GEM
M87IANR`E<RP@861R97/A<B!N:64@:F4@<'+A>F1N>0!.97!O9&%R:6QO('-A
M(')E:W5R>NUV;F4@=GEM87IANR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S
M82!V>6UA>F&[(%9&4R!A9')E<^%R+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@
M5D93(&%D<F5SX7(Z("5S+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z
M8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB;W(N`$YE
M<&]D87)I;&\@<V$@=GEM87IANR!61E,@<')I9>AI;F]K("(E<R(N`$YE<&]D
M87)I;&\@<V$@<F5K=7)Z[79N92!V>6UA>F&[(%9&4SH@)7,N`$YE<&]D87)I
M;&\@<V$@=7+H:;L@86MT=>%L;GD@861R97/A<BX`3F5P;V1A<FEL;R!S82!Z
M:7-T:;L@<&]D<F]B;F]S=&D@;R!C97)T:69I:^%T92X`3F5M;[YNZ2!N86AR
M8;L@9&5F:6[M8VEU("5S+@!.97!O9&%R:6QO('-A('!R97-U;OJ[(%9&4R!S
M^F)O<BX`3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B`B)7,B+@!.
M97!O9&%R:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R(&YA('KA<&ES+@!.97!O
M9&%R:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A(&]T
M=F]R:;L@:V]M<')I;6]V86[](&%R8VCM=BX`3F5P;V1A<FEL;R!S82!P<F7H
M[71ANR!61E,@<_IB;W(@*&9U;FMC:6$@9FEL97-I>F4H*2!Z;'EH86QA*2X`
M3F5P;V1A<FEL;R!S82!P<F7H[71ANR!61E,@<_IB;W(@*&9U;FMC:6$@9V5T
M1FEL95-I>F4H*2!Z;'EH86QA*2X`3F5P;V1A<FEL;R!S82!P<F7H[71ANR!S
M^F)O<CH`3F5P;V1A<FEL;R!S82#H[71ANR!A9')E<^%R('9F<W)O;W0N`$YE
M<&]D87)I;&\@<V$@<')E;65N;W9ANR`E<R!N82`E<SH@8VEEM6]V_2!P<FEE
MZ&EN;VL@=;X@97AI<W1U:F4`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&
M4R!A9')E<^%R+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93(&%D<F5S
MX7(Z("5S+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R("(E
M<R(N`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@)7,O)7,N
M`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(N`$YE<&]D87)I
M;&\@<V$@<W!U<W1INR`G;6MI<V]F<R<N`$YE<&]D87)I;&\@<V$@<')E;&^^
M:;L@=&5N=&\@9&]K=6UE;G0@5V]R9`!.97!O9&%R:6QO('-A('IA<.US8;L@
M5D93('/Z8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!61E,@<_IB
M;W(@*&9U;FMC:6$@8V]P>2@I('IL>6AA;&$I+@!.97!O9&%R:6QO('-A('IA
M<.US8;L@^F1A:F4@5D93('/Z8F]R=2X`3F5P;V1A<FEL;R!S82!Z87#M<V&[
M(%9&4R!S^F)O<BP@:W;S=&$@:F4@<')E:W)OZ&5NX2X`4&]DZ&EA<FMN=73I
M`%IR=;EINR!Z;65N>0!:<G6Y[2!P;W-L961N^B!A:V-I=0!.96_H86OA=F%N
MX2!O9'!O=F7O(&]D('-E<G9E<F$@<&_H87,@<W!O:F5N:6$Z(`!.96_H86OA
M=F%NX2!O9'!O=F7O(&]D('-E<G9E<F$@;F$Z(`!.96YA<W1A=F5NX0!3<&]J
M96[I(&%R86)S:^D@96UI<N%T>0!69;5KX2!"<FETX6YI80!3<&]J96[I(+ET
MX71Y($%M97)I8VOI`$IE9&YO=&MY`$YE>F[A;64`3F5Z;N%M92!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+@!.97INX6UE(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN`$)O;&$@>F%D86[A(&YE<&QA=&[A(&QO:V%L:71A+@!.
M97INX6UE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!H97-L;RX`3V1S='+A
M;FF[(&QI;FMU('H@86MT=>%L;F5H;R!E;&5M96YT=0!.97!O;65N;W9A;N$`
M3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M86KZ('H@8F5Z<&7H;F]S=&[]
M8V@@9/1V;V1O=B!P<NUS='5P(&L@=F^U8N%M(%9Y<W1R:6AN^KLO2V]P[7)O
M=F&[+U9L;[YINRX@2VQI:VYI=&4@;F$@3TL@82!Z;V)R87KM('-A('1E8VAN
M:6-KX2!I;F9O<FWA8VEA(&YA('-T<N%N:V4@;6]Z:6QL82YO<F<L(&MT;W+A
M(%;A<R!I;F9O<FUU:F4L(&%K;R!U;6^^;FF[('-K<FEP='4@<'+M<W1U<"!K
M('-C:'+A;FME+@!/9'-T<N%N:;L@9F%R8G4`3F5P;V1P;W)O=F%NZ2!R;WJY
M[7)E;FEE`$%K='5A;&EZX6-I80!!:W1U86QI>F]V8;L@)7,`06MT=6%L:7IO
M=F&[('!O=;[M=F%T9;5A`$%K='5A;&EZX6-I82`B)7,B(&)O;&$@^G-P9;EN
MX2X`4VMR:7!T(&YA('5P9W)A9&4@8F]L('9Y;6%Z86[]+@!.86AR8;L`5KEE
M=&MY('/Z8F]R>2!S(&MO;F9I9W5RX6-I;W4@8F]L:2!N86AR86[I(&YA('-E
M<G9E<BX`5F6U:^D@;&%T:6YS:^D@<.US;65NX0!69;5KZ2!R[6US:V4@Z.US
M;&EC90!5<G5G=6%Y`%!O=;YINR!A:W1UX6QN93H@)7,`4&]UOFF[(%-33`!0
M;W6^:71E('8@<'+M<&%D92P@OF4@:F4@;65N;R]H97-L;R!O9&QIN6[I('!R
M92!)35-0('-E<G9E<BX`4&]UONUV871EM0!0;W6^[79A=&6U("5S(&YI92!J
M92!A=71O<FEZ;W9A;OT@;F$@)7,N`%-P<N%V82!P;W6^[79A=&6U;W8`4&]U
MONUV871EM7-KZ2!N87-T879E;FEA`%)E9VES='+A8VEA('!O=;[M=F%T9;5A
M`%)E9VES='+A8VEA('!O=;[M=F%T9;5O=B!B;VQA('!R92!T96YT;R!S>7-T
MZ6T@>F%KX7IA;N$N`%!O=;[M=F%T9;5S:_T@^NAE="!N96)O;"!NX6ID96[]
M`%!O=;[M=F%T9;5S:^D@;65N;P!0;W6^[79A=&6U<VOI(&UE;F\@(B5S(B!U
MOB!E>&ES='5J92X`4&]UONUV871EM7-KZ2!M96YO.@!0;W6^[79A=&6U<VOI
M(&UE;F\Z(`!0;W6^[79A=&5L:6$@<WES=.EM=3H`57IB96MI<W1A;@!61E,@
M861R97/A<B!N965X:7-T=6IE+@!$;W9O;&5N:V$`4&QA=&[I('5M:65S=&YE
M;FEA('IA:.#R86KZ.B``4&QA=&YO<[L`4&QA=&YO<[L@=B!M:6[Z=&%C:"!O
M9'1E<F%Z+@!(;V1N;W1A('!R96MR;^AI;&$@;6%X:6WA;&YU(&3EOFMU("5S
M+@!(;V1N;W1Y`$AO9&YO='DL('H@:W1O<OUC:"!S:2!M]+YE=&4@=GEB<F&[
M`%9A;G5A='4`4')E;65N;N$`5F5N97IU96QA`$]V97)E;FEE('IL>6AA;&\@
M+2!TX71O('-P<N%V82!M;VAL82!B>;L@<V9A;+EO=F%NX2X`5F5R>FEA`$UA
M;F&^;65N="!V97)Z:>T`5F5R=&EKX6QN92!Z87)O=FYA;FEE`%9E<G1I:^%L
M;F4@=GEP;&YE;FEE`%9E<G1I:^%L;F4Z`%9EM6UI('9Y<V]KX0!6:65T;F%M
M`%IO8G)A>FF[("5S`%IO8G)A>FF[(&5X=&5R;OH@=W=W('-T<N%N:W4`6F]B
M<F%Z:;L@86MO("5S`$)R:71S:^D@4&%N96YS:^D@;W-T<F]V>0!!;65R:6-K
MZ2!086YE;G-KZ2!O<W1R;W9Y`%9I9&ET9;5N;W.[`%9I9&ET9;5N;W.[.B``
M5F]D869O;F4@271A;'D@8V5Z(%--5%``5D%23U9!3DE%`%503UI/4DY%3DE%
M(2$A($]$4U12P=)412!32U))4%0@6B`E<R!25<A.12X`5TE.(&-E>B!(5%10
M`%=A;&QI<R!A($9U='5N80!687)O=F%N:64`4W0`4')E9'!O=F7O('!OZ&%S
M:6$`VF1A:F4@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H97(N8V]M`%=E8@!7
M5U<@<W1RX6YK80!4_;YD96YN90!6:71A:G1E`%;M=&$@5N%S("5S`%9I=&%J
M=&4L("5S`%KA<&%D;N$@4V%H87)A`$MT;W+Z(&%P;&EKX6-I=2!MX2`E<R!Z
M;V)R87IINR!P;R!P<FEH;.%S96[M/P!!:_T@:F4@>FYA:R!P<F4@;V1D9;5O
M=F'H/P!!:_T@:F4@>FYA:R!P<F4@^G9O9'IO=FMU/P!-87!A($%U<W1RX6QI
M92!P<F4@<VQUOF)U(%=H97)E:7,`2W1O<ND@9N%Z>0!+=&]RZ2!ZX7-U=F[I
M(&UO9'5L>2!P;W9O;&F[('!R92!R;WJY[7)E;OT@=&5X=&]V_2!E9&ET;W(N
M`*GM<FMA`*GM<FMA('8@:F5D;F]T:^%C:"!#4U,`J>UR:V$@;65N=2`E<R!V
MM6%V;R`H<')E:F%V[2!S82!P<FD@[V%LN6]M('!R:6ALX7-E;NTI.@"I[7)K
M82!T86)UM6MY`$IE9&YO=&MA(+GM<FMY`*GM<FMA.@!7:6MI`%9I971O<@!2
MX6YO('9I971O<@!2_6-H;&]SNR!V971R82!V('5Z;&]C:`!6:65T;W(Z`%9I
M971O<CH@`$WZ9')O<[L`5VES:&QI<W0`4'+A8V$`061R97-A(&1O('!RX6-E
M`%1E;&5F\VX@9&\@<'+A8V4`3F5S<'+A=FYY('!OZ&5T('!O;.T@;F$@<FEA
M9&MU("5D+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`3F5S<'+A=FYY
M('!OZ&5T('!O;.TN($_H86OA=F$@<V$@)60L(&YAN6QO('-A("5D+@!:;/T@
M;V9F<V5T("5D('!R:2#H[71A;NT@5D93('/Z8F]R=2X`6"U2968`6N%K;&%D
M;ND@;V)M961Z96YI82!8-3`Y=C,`4&]UOFET:64@<F]ZN>UR96[I:&\@:[7Z
MZ&$@6#4P.78S`$%L=&5R;F%T[79N92!M96YO('-U8FIE:W1U(%@U,#EV,P!)
M9&5N=&EF:6OA=&]R(&NU^NAA('-U8FIE:W1U(%@U,#EV,P!8-3`Y=C,@<F]Z
MN>UR96YI80!960!965E9`%EA:&]O(2!M87``4F_H;F4`2F5M96X`06YO`%/Z
M:&QA<^UM+@!3=&4@=B!415A43U9/32!21:Y)344N(%!O=;YI=&4@=&QAZ&ED
M;&\@6SP^72!N82!P<F5P;G5T:64@;F%S<.2[(&1O(%=94TE764<N`$YE;?2^
M971E('9Y='9O<FF[('9I86,@86MO("5D(&)L;VMO=BX`3FEE('-T92!A=71E
M;G1I9FEK;W9A;OTN`%9O(%9AN6]M('!L;F]M(&UE;F4@;F5M]+YE=&4@<&]U
MOFF[('IN86L@)UPG+@!.97IA9&%L:2!S=&4@<&QA=&[Z(&4M;6%I;&]V^B!A
M9')E<W4N`$YE=7+H:6QI('-T92!V>KMA:"!M961Z:2"^:6%D;GEM:2!P;VQI
M86UI('H@:6UP;W)T;W9A;NEH;R!S^F)O<G4@82!Z;V1P;W9E9&%J^F-I;6D@
M<&^U86UI('8@)7,N`$)O;&D@<W1E(&]D:&SA<V5N_2X`375S[71E('IA9&&[
M('!L871NZ2#H[7-L;R!M;V)I;&[I:&\@=&5L96;S;G4L(&MT;W+I(&]B<V%H
M=6IE(&EB82#H[7-L82!S('9O;&ET9;5N_6T@<')E9FEX;VT@)RLG('!R92!M
M961Z:6[A<F]D;OT@9F]R;>%T+@!-=7/M=&4@>F%D8;L@<&QA=&[Z(&AO9&YO
M='4N`$%B>2!S=&4@;6]H;&D@<&]UONUV8;L@4F5G:7-T<N%C:64L(&UU<^UT
M92!N86IS:_1R(&YA:V]N9FEG=7)O=F&[($1A=&%4<F5E(&)A8VME;F0N`$UU
M<^UT92!N86MO;F9I9W5R;W9ANR!61E,@8F%C:V5N9"X`375S[71E('!O<.US
M8;L@<')O8FSI;2!P<F5D=/UM+"!A:V\@;V1ON6QE=&4@<W!RX79U(&\@<')O
M8FSI;64N`$UU<^UT92!Z861ANR!54DP@861R97-U+"!N82!K=&]R^B!TX71O
M(&QI;FMA('5K87IU:F4`375S[71E('9Y8G)ANR!S97)V97(L(&MT;W+](&WA
M(&)YNR!V>6UA>F%N_2X`375S[71E('5RZ&F[(&UE;F\@<&]UONUV871EM6$L
M(&MT;W+I:&\@8VAC971E('9Y;6%Z8;LN`$UU<^UT92!U<NAINR!M96YO('!O
M=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!V>6UA>F&[+@!-=7/M=&4@=7+H
M:;L@;65N;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@<')I9&&[+@!-
M=7/M=&4@=7+H:;L@<&]UONUV871EM6$L(&MT;W+]('-A(&WA(&%K='5A;&EZ
M;W9ANRX`375S[71E('5RZ&F[(&%K8VEU+"!K=&]RX2!S82!MX2!V>6MO;F&[
M+@!-=7/M=&4@>F%D8;L@;65N;R!N;W9E:B!K871E9_-R:64N`$UU<^UT92!Z
M861ANR!T86QI86YS:V4@=&5L96;S;FYE(.CM<VQO`%!L871N;W.[(%9AN65J
M(')E;.%C:64@<')E(&%P;&EKX6-I=2`E<R!V>7!RN6%L82X@4')O<^UM('!R
M:6ALX7-T92!S82!Z;F]V=2X`5F&Y82!%;6%I;&]VX2!A9')E<V$`5F&Y82!%
M;6%I;&]VX2!A9')E<V$@<&]UOFETX2!P<F4@;V1C:.%D>F%J^F-U('!ON71U
M.@!68;EE(&EN9F]R;>%C:64`5F&Y82!I;G1E<FYE=&]VX2!A9')E<V$@<V$@
M>FUE;FEL82!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@5F&Y
M=2!B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN`%9AN64@
M;65N;P!6X;D@875T96YT:69I:V'H;OT@;6]D=6P@;F5P;V1P;W)U:F4@<')I
M9.%V86YI92!P;W6^[79A=&6U;W8N($%K('-I(+YE;.%T92!P;W6^:;L@2&]R
M9&4@;F$@<W!RX79U('!O=;[M=F%T9;5S:_UC:"#ZZ'1O=BP@;75S[71E('!O
M=;YINR!I;OT@875T96YT:69I:V'H;OT@8F%C:V5N9"X`5N&Y(&%U=&5N=&EF
M:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('IO8G)A>F]V86YI92!Z;WIN86UU
M('!O=;[M=F%T9;5O=BP@86QE8F\@8F]L82!TX71O(&UOOFYO<[L@>B!N96IA
M:^EH;R!D]'9O9'4@>F%KX7IA;N$N`%IDX2!S82P@OF4@5N&Y('!R96AL:6%D
M8>@@<V$@>FUE;FEL(&]D('IAZ&EA=&MU(%9AN65J(')E;.%C:64@)7,N(%!R
M92!68;EU(&)E>G!EZ&YO<[L@<V$@;75S[71E('IN;W9U('!R:6ALX7-INRX`
M5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU+@!6X;D@
M<')E:&QI861AZ"!N97!O9'!O<G5J92!T^G1O(&9U;FMC:74@=&QAZ&4N(%-T
M;&'H=&4@0V]N=')O;"]#;VUM86YD("L@4"!P<F4@=&QAZ"X`5F&Y82!A:W1U
MX6QN82#H87-O=N$@>O-N83H`5F&Y82!P<F5D;F%S=&%V96[A(&ED96YT:71A
M(&)O;&$@>FUE;F5NX2X`4')E9&YA<W1A=F5NX2!I9&5N=&ET83H`5F&Y92!M
M96YO.@!0;&%T;F]SNR!6X;EH;R#ZZ'1U('9Y<'*Y86QA+@!68;EE(&YO=ND@
M:&5S;&\@<')E("5S(&IE.B`E<P!68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U
M86QI>F]V86[I('!R92!T;W1O('-E9&5N:64N`%9AN64@;F%S=&%V96YI82!B
M;VQI(&%K='5A;&EZ;W9A;NDN`%9AN64@:&5S;&\@8F]L;R!O8FYO=F5NZ0!6
M8;EE(&AE<VQO(&)O;&\@;V)N;W9E;NDL('-K;VYT<F]L=6IT92!S:2!P;[ET
M=2!A('!R:6ALX7-T92!S82!S(%9AN>UM(&YO=OUM(&AE<VQO;2X`4&QA=&YO
M<[L@5N&Y:&\@:&5S;&$@=GEP<KEA;&$N`%9AN64@=GID:6%L96[I('-E<G9E
M<GDZ`$IU:&]S;.%V:6$`6F%I<@!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6U-K
M<GF[(&-I=&]V86[]('1E>'1=`%M3<'+A=F$@;R!P<F]B;.EM95T`6UIO8G)A
M>FF[(&-I=&]V86[]('1E>'0@+0!;6F]B<F%Z:;L@8VET;W9A;OT@=&5X="`M
M("5S(')I861K;W9=`%MR:6%D;VL@)7,@>B`E<UT`7T%D;6EN:7-T<N%C:6$`
M7T-,20!?1&%T851R964`7U9Y;6%Z8;L@<FEA9&]K`%]3:W5P:6YY`%]0;VUO
M8V[M:P!6;&%S=&YO<W1I(%]O8G+A>FMU+BXN`%]0<FEH;.%S:;L@<V$`7T]D
M:&SA<VF[('-A`%]5<')A=FF[(&QI;FMU+BXN`%].87-T879E;FEA`%]0<N%V
M80!/9'-T7W+A;FF[(&QI;FMU+BXN`$YA7W-T879E;FEE`%9L87-T;F]S=&D@
M7W1A8G6U:WDN+BX`4&]?=;[M=F%T96QI80!A9')E<^%R`&%D<F5SX70@;F5Z
M;N%M>0!K86QE;F3A<@!B97IV971R:64`;F5P;V1A<FEL;R!S82!V>71V;W)I
MNR!V_7-T=7!N_2!S^F)O<@!N97!O9&%R:6QO('-A(&]T=F]R:;L@=G-T=7``
M:VQI:VYI=&4@<V5M`&-H>6)A('!R:2!P;W6^:73M('!R[6MA>F]VZ6AO(')I
M861K=0!C:'EB82!K;VYF:6=U<N%C:64`8VC]8F$@9/1L9;YI=/T@<WES=.EM
M;W;]('/Z8F]R`&-H>6)A(&9O<FWA='4@^F1A:F]V`'!O;&^^:V$@;F5NX6ID
M96[A`&ML97/A`'/Z8F]R`'IO('-M97)U("5S("@E<RD@<OUC:&QO<[MO=2`E
M<R`E<P!NX7)A>F]V_0!V.@!H:`!N97INX6UE(&UE;F\@:&]S=&ET9;5A`&]K
M86V^:71E`'8@<W!RX79E`&-H>6)A('9S='5P=2]V_7-T=7!U`&EN=&5R;N$@
M8VAY8F$@<V]F=';I<G4`<FEA9&MO=ET`<&_H87,@=GET=N%R86YI82!)4T\@
M;F%S=&%L82!C:'EB82!M:VES;V9S("5D`&UM`&UE;F\`;F5I;7!L96UE;G1O
M=F%NZ0!Z871I8;4@;F5I;7!L96UE;G1O=F%NZ0!P;WINX6UK;W;](&)L;VL`
M<&5R8V5N=`!P<NUS='5P('IA;6EE=&YU=/T`8F]D;W8`=GID:6%L96[A(&-H
M>6)A('8@<')O=&]K;VQE`'-T^G!A`'-L=;YB82!N:64@:F4@9&]S='5P;N$`
M>F]B<F%Z:;L@<F]Z9&EE;'D`<VUS,F5M86EL(&-E>B!(5%10`'-S`'5S=.%L
M96[]`'-Y<W3I;6]VX2!C:'EB80!Z;WIN86T@^FQO:`!D;^AA<V[A(&-H>6)A
M`'!R92!P;W1V<F1E;FEE('IA9&%J=&4@:&5S;&\@9'9A:W+A=`!U;FEF:6MO
M=F%NZ0!N97!O;65N;W9A;N$`9&5F:6YU:F4@<&]UONUV871EM0!V0V%R9`"Y
M.@!W96%T:&5R+F-O;0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-K7U-++VAE;'`N>&UL
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q
M,#4Q-30S,3`V,@`P,C`S,C<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO
M<F1E.B!H;W)D92]L;V-A;&4O<VM?4TLO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P
M-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A
M9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E
M<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF
M;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY
M(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8
M+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@
M>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE
M=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM
M87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@
M9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S
M<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@
M971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@
M<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B
M=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET
M96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@
M87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET
M;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP
M87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@
M:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N
M('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@
M86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P
M;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@
M8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E
M(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I
M;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@
M=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S;%]322\`````````````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-C(`,#$V-C8Q`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-L
M7U-)+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,C`T-#8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O<VQ?4TDO3$-?34534T%'15,O:&]R9&4N;6\`````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S4P,#,S`#$P-3$U-#,Q,#8R`#`R,C$P
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````)P&```<````_#0``-L(``#<:0```````$B-```.````28T```\`
M``!8C0``#0```&B-```(````=HT```L```!_C0``#````(N-```$````F(T`
M`!@```"=C0``&P```+:-```M````THT``!T`````C@``)````!Z.```I````
M0XX``!D```!MC@``)@```(>.```,````KHX``"0```"[C@``#P```.".```+
M````\(X```X```#\C@``!0````N/```H````$8\```@````ZCP``"@```$./
M```5````3H\``!(```!DCP``"P```'>/``"%````@X\```X````)D```"@``
M`!B0```-````(Y````X````QD```$0```$"0```-````4I````P```!@D```
M#0```&V0```&````>Y```)0```""D```"@```!>1```/````(I$``!@````R
MD0``#````$N1```.````6)$```X```!GD0``"````':1```)````?Y$``"X`
M``")D0``&@```+B1```R````TY$``#@````&D@``5````#^2``!1````E)(`
M`%H```#FD@``5P```$&3```T````F9,```D```#.DP``#0```-B3```'````
MYI,```H```#NDP``#P```/F3```%````"90```8````/E```"````!:4```E
M````'Y0``"````!%E```$P```&:4```0````>I0```\```"+E```"@```)N4
M```#````II0```\```"JE```%````+J4```)````SY0```T```#9E```$@``
M`.>4```9````^I0``!X````4E0``#P```#.5```*````0Y4```\```!.E0``
M"````%Z5```D````9Y4``!0```",E0``%@```*&5```(````N)4``$X```#!
ME0``+0```!"6```9````/I8```<```!8E@``#````&"6```L````;98```X`
M``":E@```P```*F6```+````K98```<```"YE@``!P```,&6```%````R98`
M``,```#/E@``%P```-.6```*````ZY8```\```#VE@``&`````:7```C````
M'Y<```X```!#EP``%````%*7```7````9Y<``!<```!_EP``%P```)>7```3
M````KY<```X```##EP``'P```-*7```=````\I<```<````0F```!@```!B8
M```(````'Y@```\````HF```!@```#B8```*````/Y@``!,```!*F```"P``
M`%Z8```0````:I@``!4```![F```%0```)&8```'````IY@```4```"OF```
M%0```+68```1````RY@```P```#=F```.P```.J8```X````)ID```D```!?
MF0``!P```&F9```4````<9D```,```"&F0``!0```(J9```)````D)D``!,`
M``":F0``.0```*Z9```2````Z)D``"<```#[F0``+````".:```J````4)H`
M`"4```![F@``"@```*&:```&````K)H```D```"SF@``!P```+V:```O````
MQ9H``#<```#UF@``+@```"V;``!5````7)L``"T```"RFP``+0```.";```]
M````#IP``#\```!,G```+0```(R<``!`````NIP``",```#[G```(P```!^=
M``!`````0YT``"T```"$G0``,P```+*=```E````YIT``!4````,G@``&0``
M`"*>```I````/)X``"0```!FG@``*````(N>```1````M)X```H```#&G@``
M#````-&>```6````WIX``!8```#UG@``!P````R?```'````%)\``!0````<
MGP``"@```#&?```(````/)\``"<```!%GP``!P```&V?```'````=9\```8`
M``!]GP``!0```(2?```'````BI\```8```"2GP``"````)F?```I````HI\`
M``X```#,GP``"@```-N?```'````YI\```D```#NGP``%@```/B?```$````
M#Z````@````4H```#0```!V@```&````*Z```!X````RH```$0```%&@```(
M````8Z````P```!LH```!P```'F@```#````@:````,```"%H```%P```(F@
M```=````H:````@```"_H```!````,B@```(````S:````@```#6H```*P``
M`-^@```@````"Z$``!4````LH0``!@```$*A```&````2:$``!4```!0H0``
M.@```&:A```8````H:$``"(```"ZH0``,P```-VA```N````$:(``!T```!`
MH@``(0```%ZB``!4````@*(``$````#5H@``*0```!:C```9````0*,```H`
M``!:HP``!P```&6C```5````;:,```X```"#HP``"@```)*C```)````G:,`
M`!0```"GHP``&````+RC```=````U:,``!,```#SHP``$0````>D```4````
M&:0```0````NI```!@```#.D```4````.J0``%0```!/I```9````*2D```%
M````":4```4````/I0``&P```!6E```:````,:4``!,```!,I0``$0```&"E
M```1````<J4``!P```"$I0``$````*&E```A````LJ4```4```#4I0``"P``
M`-JE```2````YJ4```H```#YI0``#P````2F```-````%*8``!$````BI@``
M$P```#2F```,````2*8```8```!5I@``#````%RF```&````::8``!<```!P
MI@``$````(BF```(````F:8```4```"BI@``#````*BF```0````M:8```T`
M``#&I@``!@```-2F```'````VZ8```T```#CI@``!P```/&F```+````^:8`
M``<````%IP``!P````VG```)````%:<```D````?IP``"@```"FG```9````
M-*<``#T```!.IP``'0```(RG```,````JJ<``!````"WIP``!0```,BG```E
M````SJ<``!(```#TIP``$P````>H```K````&Z@``#L```!'J```(````(.H
M```(````I*@``#8```"MJ```(0```.2H```0````!JD```@````7J0``#```
M`""I```&````+:D```\````TJ0``!P```$2I```*````3*D```T```!7J0``
M'P```&6I```<````A:D``"$```"BJ0``'@```,2I```9````XZD``!X```#]
MJ0``&P```!RJ```A````.*H``"X```!:J@``)@```(FJ```<````L*H``!X`
M``#-J@``'````.RJ```F````":L``"L````PJP``,P```%RK```F````D*L`
M`"L```"WJP``.````..K```=````'*P``!4````ZK```+P```%"L```@````
M@*P``!(```"AK```*0```+2L```>````WJP``"````#]K```$@```!ZM``"B
M````,:T``!8```#4K0``(P```.NM```H````#ZX``"D````XK@``*````&*N
M```?````BZX``!4```"KK@``(````,&N```E````XJX``"@````(KP``+0``
M`#&O```P````7Z\``)(```"0KP``(0```".P```6````1;```!P```!<L```
M)@```'FP```J````H+```$$```#+L```1`````VQ```,````4K$```<```!?
ML0``!P```&>Q```&````;[$``!````!VL0``$@```(>Q```3````FK$``!(`
M``"NL0``!P```,&Q```$````R;$``!````#.L0``$````-^Q```,````\+$`
M``T```#]L0``#P````NR```3````&[(``"@````OL@``!@```%BR```1````
M7[(``!<```!QL@``&P```(FR```.````I;(```(```"TL@``20```+>R```%
M`````;,``!`````'LP``#P```!BS```$````*+,```T````MLP``#@```#NS
M```#````2K,```@```!.LP``!P```%>S```-````7[,``!````!MLP``#0``
M`'ZS```+````C+,```8```"8LP``#````)^S```*````K+,``!$```"WLP``
M&0```,FS```B````X[,```\````&M```&P```!:T```T````,K0``!@```!G
MM```$@```("T```B````D[0```T```"VM```!P```,2T```4````S+0```L`
M``#AM```(@```.VT```O````$+4```L```!`M0``"0```$RU```9````5K4`
M``L```!PM0``"0```'RU```6````AK4```\```"=M0``&0```*VU```6````
MQ[4```X```#>M0``&````.VU```(````!K8```T````/M@``)@```!VV``!#
M````1+8```@```"(M@``$@```)&V```?````I+8```L```#$M@``+P```-"V
M```.`````+<```4````/MP``!@```!6W``!%````'+<```,```!BMP``!P``
M`&:W```$````;K<```H```!SMP``"@```'ZW```/````B;<``!````"9MP``
M%P```*JW```1````PK<``!D```#4MP``%P```.ZW```)````!K@```4````0
MN```"P```!:X```%````(K@```T````HN```&P```#:X```7````4K@``!0`
M``!JN```"0```'^X```.````B;@```T```"8N```$@```*:X```X````N;@`
M`"````#RN```"````!.Y``![````'+D``!@```"8N0``$0```+&Y```'````
MP[D```4```#+N0``&````-&Y```>````ZKD``!L````)N@``&0```"6Z```;
M````/[H``!D```!;N@``$P```'6Z```'````B;H```@```"1N@``!@```)JZ
M```&````H;H``!````"HN@``#P```+FZ```0````R;H```\```#:N@``"P``
M`.JZ```/````]KH```P````&NP``#P```!.[```'````([L```8````KNP``
M#````#*[```H````/[L```\```!HNP``"````'B[```3````@;L``!X```"5
MNP``(0```+2[```@````UKL``!D```#WNP``%P```!&\```E````*;P``!<`
M``!/O```%@```&>\```$````?KP``!L```"#O```#0```)^\```,````K;P`
M``,```"ZO```!0```+Z\```(````Q+P```H```#-O```#````-B\```+````
MY;P``!````#QO```#`````*]```.````#[T```L````>O0``!````"J]```$
M````+[T``!,````TO0``%````$B]```,````7;T```D```!JO0``#@```'2]
M```+````@[T``!L```"/O0``!P```*N]```'````L[T```H```"[O0``#0``
M`,:]```)````U+T```0```#>O0```P```..]```8````Y[T```0`````O@``
M#@````6^``!\````%+X``!4```"1O@``!0```*>^```'````K;X```P```"U
MO@``"````,*^```*````R[X```8```#6O@``"````-V^```"````YKX```8`
M``#IO@``%````/"^```-````!;\``!`````3OP``&P```"2_```$````0+\`
M``D```!%OP``$````$^_```)````8+\```D```!JOP``!0```'2_```&````
M>K\``!D```"!OP``#@```)N_```'````JK\```<```"ROP``!0```+J_```)
M````P+\```H```#*OP``#@```-6_```"````Y+\```L```#GOP``#0```/._
M```)`````<````8````+P```$@```!+````)````)<````<````OP```%```
M`#?````=````3,```$(```!JP```)0```*W````E````T\````8```#YP```
M"@````#!```$````"\$```D````0P0``"````!K!```1````(\$```D````U
MP0``!@```#_!```-````1L$```8```!4P0``!````%O!```>````8,$```4`
M``!_P0``#@```(7!```$````E,$```8```"9P0``!P```*#!```A````J,$`
M``T```#*P0``%0```-C!```&````[L$```0```#UP0``!@```/K!```*````
M`<(``"(````,P@``!````"_"```%````-,(``!T````ZP@``#````%C"```.
M````9<(```H```!TP@``"````'_"```)````B,(```4```"2P@``.@```)C"
M```P````T\(``#4````$PP``*0```#K#``!'````9,,``#@```"LPP``*0``
M`.7#```_````#\0``"X```!/Q```+0```'[$```?````K,0``"0```#,Q```
M"````/'$```*````^L0```D````%Q0``!P````_%```@````%\4``"`````X
MQ0``)@```%G%```*````@,4``!D```"+Q0``*0```*7%```6````S\4```<`
M``#FQ0``"@```.[%```,````^<4```\````&Q@``$````!;&``!`````)\8`
M`&8```!HQ@``#````,_&```&````W,8```\```#CQ@``$@```//&```0````
M!L<``!P````7QP``(P```#3'``!J````6,<```4```##QP``$````,G'```)
M````VL<```L```#DQP``(````/#'```9````$<@``$(````KR```#P```&[(
M```T````?L@``#4```"SR```%````.G(```'````_L@```P````&R0``(```
M`!/)```0````-,D``!0```!%R0``$0```%K)```7````;,D``!P```"$R0``
M$P```*')```4````M<D``!H```#*R0``$0```.7)```:````]\D``!X````2
MR@``&@```#'*```3````3,H``!4```!@R@``$0```';*```7````B,H``!0`
M``"@R@``%P```+7*```5````S<H```D```#CR@``$````.W*```9````_LH`
M``0````8RP``!P```!W+```1````)<L```8````WRP``!@```#[+```%````
M1<L```<```!+RP``!P```%/+```%````6\L``!8```!ARP``!@```'C+```&
M````?\L```0```"&RP``!````(O+```*````D,L```X```";RP``!0```*K+
M```H````L,L```X```#9RP``#````.C+```/````]<L```H````%S```"```
M`!#,```)````&<P``"L````CS```!````$_,```(````5,P``"8```!=S```
M$@```(3,```/````E\P```8```"GS```"@```*[,```(````N<P``"````#"
MS```"0```./,```4````[<P```P````"S0``#0````_-```.````'<T``!8`
M```LS0``$0```$/-```&````5<T```,```!<S0``!P```&#-```+````:,T`
M``L```!TS0``!P```(#-```%````B,T```<```".S0``%@```);-```-````
MK<T```T```"[S0``"@```,G-```0````U,T```\```#ES0``$0```/7-```7
M````!\X```H````?S@``$0```"K.```$````/,X``#H```!!S@``!0```'S.
M```,````@LX``!X```"/S@``#@```*[.```0````O<X```L```#.S@``#```
M`-K.```)````Y\X```<```#QS@``"@```/G.```)````!,\```X````.SP``
M$````!W/```;````+L\``!@```!*SP``&@```&//```*````?L\```D```")
MSP``"@```)//```,````GL\```\```"KSP``"````+O/```&````Q,\``!P`
M``#+SP``!P```.C/```%````\,\```L```#VSP``1P````+0```-````2M``
M``D```!8T```!````&+0```#````9]````H```!KT````@```';0```$````
M>=```"4```!^T````P```*30```%````J-```"H```"NT```"@```-G0```%
M````Y-````0```#JT```"@```._0```&````^M````@````!T0``"`````K1
M```$````$]$```4````8T0``:````![1```)````A]$```P```"1T0``$```
M`)[1```%````K]$``!L```"UT0``+P```-'1```0`````=(```H````2T@``
M#P```!W2```*````+=(```D````XT@``$P```$+2```;````5M(``!@```!R
MT@``%P```(O2```?````H](```X```##T@```P```-+2```'````UM(```@`
M``#>T@``!P```.?2```*````[](```<```#ZT@``40````+3```0````5-,`
M``P```!ETP``#0```'+3```:````@-,``$H```";TP``&0```.;3```&````
M`-0``!H````'U```)0```"+4```&````2-0```8```!/U```'P```%;4```)
M````=M0``!@```"`U```%P```)G4```H````L=0```8```#:U```#0```.'4
M```B````[]0``!,````2U0``(P```";5```3````2M4```(```!>U0``"P``
M`&'5```(````;=4```T```!VU0``!P```(35```4````C-4```8```"AU0``
M"````*C5```.````L=4```<```#`U0``"@```,C5```+````T]4``#(```#?
MU0``!P```!+6```,````&M8```T````GU@``%P```#76```,````3=8```D`
M``!:U@``"0```&36```*````;M8```<```!YU@``"0```('6```'````B]8`
M``H```"3U@``&P```)[6```/````NM8``!(```#*U@``"@```-W6```6````
MZ-8```D```#_U@``$`````G7```'````&M<``!(````BUP``!````#77```'
M````.M<```4```!"UP``!0```$C7```+````3M<``!0```!:UP``$0```&_7
M```:````@=<``!8```"<UP``%````+/7```7````R-<``!@```#@UP``'```
M`/G7```9````%M@```<````PV```!0```#C8```-````/M@```P```!,V```
M"````%G8```7````8M@```L```!ZV```#````(;8```?````D]@``!H```"S
MV```!````,[8```*````T]@```0```#>V```#0```./8```,````\=@```4`
M``#^V```"0````39```%````#MD```<````4V0``!0```!S9```$````(MD`
M``(````GV0``.````"K9```L````8]D``!(```"0V0``*0```*/9```R````
MS=D```H`````V@``+`````O:```N````.-H``#,```!GV@``,P```)O:```X
M````S]H```\````(VP``&````!C;```0````,=L```\```!"VP``$P```%+;
M```5````9ML``!0```!\VP``$@```)';```4````I-L``!4```"YVP``8@``
M`,_;```3````,MP```T```!&W```%P```%3<```,````;-P``"L```!YW```
M(0```*7<```:````Q]P```D```#BW```10```.S<``!!````,MT```0```!T
MW0``%````'G=```.````CMT``!,```"=W0``&````+'=```&````RMT```D`
M``#1W0``"@```-O=```/````YMT``!````#VW0``#@````?>```%````%MX`
M`!L````<W@``"````#C>```&````0=X``!0```!(W@``$0```%W>```.````
M;]X``#@```!^W@``!@```+?>```.````OMX```4```#-W@``!P```-/>```&
M````V]X``"@```#BW@``#`````O?```<````&-\```0````UWP``*0```#K?
M```7````9-\``!\```!\WP``7````)S?```4````^=\``#X````.X```$```
M`$W@```'````7N````X```!FX```#````'7@```3````@N````H```"6X```
M'0```*'@```9````O^````4```#9X```$0```-_@```1````\>```"0````#
MX0``$@```"CA```5````.^$``!(```!1X0``#@```&3A```9````<^$```@`
M``"-X0``"0```);A```-````H.$```<```"NX0``"@```+;A```'````P>$`
M``\```#)X0``!@```-GA```+````X.$``!H```#LX0``"@````?B```(````
M$N(```4````;X@``'P```"'B```&````0>(``!````!(X@``"````%GB```-
M````8N(```@```!PX@``'@```'GB```2````F.(``"P```"KX@``&@```-CB
M```)````\^(```H```#]X@``%0````CC```%````'N,``!`````DXP``!@``
M`#7C```>````/.,``"@```!;XP``"@```(3C```<````C^,``!$```"LXP``
M"P```+[C```:````RN,``!0```#EXP``!````/KC```$````_^,```L````$
MY```!0```!#D```&````%N0```@````=Y```(````";D```I````1^0``"``
M``!QY```00```)+D```:````U.0``"@```#OY```*0```!CE``!0````0N4`
M`"(```"3Y0``!@```+;E```(````O>4```4```#&Y0``"````,SE```J````
MU>4``",`````Y@``&0```"3F```N````/N8```@```!MY@``%P```';F```*
M````CN8```<```"9Y@``$````*'F```+````LN8```<```"^Y@``$P```,;F
M```(````VN8```L```#CY@``"@```._F```4````^N8```\````/YP``,@``
M`!_G```+````4N<```X```!>YP``!0```&WG```%````<^<```4```!YYP``
M%P```'_G```/````E^<```0```"GYP``"@```*SG```)````M^<```L```#!
MYP``#0```,WG```,````V^<```X```#HYP``!0```/?G```$````_><```T`
M```"Z```,@```!#H``!%````0^@```<```")Z```'@```)'H```4````L.@`
M``4```#%Z```%````,OH```&````X.@```<```#GZ```#@```._H```J````
M_N@```8````IZ0``#0```##I```+````/ND``#8```!*Z0``"P```('I```/
M````C>D``#(```"=Z0``)0```-#I```P````]ND``#$````GZ@``+0```%GJ
M```.````A^H```4```"6Z@``#@```)SJ```3````J^H``!(```"_Z@``!P``
M`-+J```1````VNH``!,```#LZ@``!P````#K```4````".L``!@````=ZP``
M!P```#;K```,````/NL```P```!+ZP``!````%CK```'````7>L```H```!E
MZP``"P```'#K```,````?.L```,```")ZP``$@```(WK```&````H.L``!X`
M``"GZP``&````,;K```E````W^L```T````%[```"0```!/L```?````'>P`
M``,````][```!P```$'L```*````2>P```(```!4[```#````%?L```5````
M9.P```L```!Z[```&0```(;L```@````H.P```4```#![```"@```,?L```5
M````TNP``!(```#H[```#````/OL```$````".T```D````-[0``!P```!?M
M```,````'^T``%(````L[0``%P```'_M```D````E^T``!(```"\[0``!P``
M`,_M```&````U^T```X```#>[0``#````.WM```-````^NT``!4````([@``
M$@```![N```/````,>X``!0```!![@``"@```%;N```;````8>X``!````!]
M[@``"P```([N``!I````FNX``!H````$[P``%P```!_O```G````-^\``!H`
M``!?[P``%P```'KO```;````DN\``!D```"N[P``'P```,CO```3````Z.\`
M``@```#\[P``!P````7P```(````#?````D````6\```%0```"#P```-````
M-O```",```!$\```#0```&CP```3````=O````@```"*\````P```)/P``!&
M````E_```#\```#>\```-P```![Q``!7````5O$```4```"N\0``'P```+3Q
M```O````U/$```H````$\@``"`````_R```-````&/(``"T````F\@``!```
M`%3R``!/````6?(``"4```"I\@``'````,_R```+````[/(``!\```#X\@``
M'0```!CS```+````-O,```<```!"\P``#0```$KS```,````6/,``!<```!E
M\P``!@```'WS```Y````A/,```P```"^\P``!P```,OS```)````T_,``!,`
M``#=\P``"0```/'S```$````^_,``!``````]```"````!'T```(````&O0`
M``0````C]```"P```"CT```,````-/0``!(```!!]```$0```%3T```,````
M9O0``!H```!S]```#P```([T```'````GO0```T```"F]```%````+3T```.
M````R?0```P```#8]```&P```.7T```L`````?4``!,````N]0``!@```$+U
M```%````2?4```0```!/]0``%P```%3U```&````;/4```D```!S]0``"```
M`'WU```)````AO4```H```"0]0``$0```)OU```&````K?4```X```"T]0``
M#@```,/U```+````TO4``!T```#>]0```@```/SU```<````__4```<````<
M]@``!@```"3V``!D````*_8```<```"0]@``)@```)CV```X````O_8``!H`
M``#X]@``*@```!/W```[````/O<``"@```!Z]P``-````*/W```9````V/<`
M`!4```#R]P``!0````CX```(````#O@```<````7^```!0```!_X```'````
M)?@```X````M^```"0```#SX```&````1O@```@```!-^```!P```%;X```(
M````7O@```<```!G^```%@```&_X```)````AO@```8```"0^```"P```)?X
M```0````H_@```8```"T^```'````+OX```4````V/@```<```#M^```$0``
M`/7X```(````!_D```@````0^0``"0```!GY```&````(_D``!D````J^0``
M"@```$3Y```<````3_D```4```!L^0``$````'+Y```4````@_D```L```"8
M^0``#0```*3Y```H````LOD``!@```#;^0``%P```/3Y```$````#/H```D`
M```1^@```@```!OZ```(````'OH``",````G^@``'P```$OZ```X````:_H`
M`"8```"D^@``,0```,OZ```G````_?H``&0````E^P``50```(K[```X````
MX/L``$H````9_```6P```&3\```H````P/P``#@```#I_```*````"+]```L
M````2_T``!L```!X_0``(P```)3]``!(````N/T``(4````!_@``,````(?^
M```E````N/X``$$```#>_@``6P```"#_``!)````?/\``#$```#&_P``*P``
M`/C_```A````)``!`!\```!&``$`)@```&8``0`Z````C0`!`#,```#(``$`
M)0```/P``0`G````(@$!`"````!*`0$`'P```&L!`0`P````BP$!`&D```"\
M`0$`,0```"8"`0!!````6`(!`#,```":`@$`)0```,X"`0`]````]`(!`&4`
M```R`P$`30```)@#`0`O````Y@,!`"X````6!`$`,````$4$`0!4````=@0!
M`%H```#+!`$`2````"8%`0!*````;P4!`#(```"Z!0$`+P```.T%`0`L````
M'08!`"T```!*!@$`<0```'@&`0!F````Z@8!`&\```!1!P$`LP```,$'`0`7
M````=0@!`"4```"-"`$`,@```+,(`0`I````Y@@!`#X````0"0$`(@```$\)
M`0!2````<@D!`"4```#%"0$`"P```.L)`0"Q````]PD!`$4```"I"@$`(0``
M`.\*`0`P````$0L!`"4```!""P$`'````&@+`0`Q````A0L!``<```"W"P$`
M!P```+\+`0`$````QPL!``T```#,"P$`"P```-H+`0`.````Y@L!``4```#U
M"P$``@```/L+`0!9````_@L!``4```!8#`$`!````%X,`0`'````8PP!``@`
M``!K#`$`!0```'0,`0`P````>@P!``P```"K#`$`$P```+@,`0`-````S`P!
M``(```#:#`$`!P```-T,`0`&````Y0P!`!0```#L#`$`#`````$-`0`8````
M#@T!``8````G#0$`$@```"X-`0`,````00T!``,```!.#0$`*@```%(-`0`&
M````?0T!``<```"$#0$`'P```(P-`0`N````K`T!`"\```#;#0$`%P````L.
M`0`B````(PX!`"4```!&#@$`&P```&P.`0`8````B`X!`"0```"A#@$`'P``
M`,8.`0`:````Y@X!`"$````!#P$`(````",/`0`:````1`\!`#(```!?#P$`
M&@```)(/`0`O````K0\!`"L```#=#P$`'P````D0`0`C````*1`!`!\```!-
M$`$`&@```&T0`0`A````B!`!`"4```"J$`$`)@```-`0`0`E````]Q`!`"0`
M```=$0$`&````$(1`0`=````6Q$!`"0```!Y$0$`&````)X1`0`B````MQ$!
M`"P```#:$0$`%0````<2`0`E````'1(!`#P```!#$@$`'P```(`2`0`C````
MH!(!`!\```#$$@$`(````.02`0`:````!1,!`!@````@$P$`)@```#D3`0`I
M````8!,!`!X```"*$P$`*0```*D3`0`>````TQ,!`#$```#R$P$`#````"04
M`0`O````,10!`"0```!A%`$`!P```(84`0`/````CA0!`!0```">%`$`#@``
M`+,4`0`-````PA0!`"0```#0%`$`!0```/44`0`'````^Q0!`"(````#%0$`
M)0```"85`0`:````3!4!`!T```!G%0$`!P```(45`0`5````C14!``8```"C
M%0$`"0```*H5`0`+````M!4!``T```#`%0$`%P```,X5`0`&````YA4!`#,`
M``#M%0$`!P```"$6`0`/````*18!``<````Y%@$`,@```$$6`0`$````=!8!
M`"$```!Y%@$`$P```)L6`0`,````KQ8!`!$```"\%@$`,@```,X6`0`6````
M`1<!``@````8%P$`'0```"$7`0`)````/Q<!``H```!)%P$`%````%07`0`*
M````:1<!`!T```!T%P$`"````)(7`0`?````FQ<!``@```"[%P$`&@```,07
M`0`G````WQ<!``8````'&`$`%0````X8`0`'````)!@!``@````L&`$`"0``
M`#48`0`_````/Q@!``<```!_&`$`#P```(<8`0`)````EQ@!``@```"A&`$`
M$P```*H8`0`'````OA@!`!D```#&&`$`%P```.`8`0`4````^!@!``H````-
M&0$`#````!@9`0`7````)1D!``0````]&0$`*@```$(9`0`,````;1D!`!$`
M``!Z&0$`!P```(P9`0`"````E!D!`!````"7&0$`&````*@9`0`+````P1D!
M``,```#-&0$`"````-$9`0`&````VAD!``<```#A&0$`#0```.D9`0`+````
M]QD!`!0````#&@$`%0```!@:`0`.````+AH!`"\````]&@$`(````&T:`0`<
M````CAH!`!4```"K&@$`#````,$:`0`Q````SAH!`!(`````&P$`/P```!,;
M`0`$````4QL!``0```!8&P$`"@```%T;`0`3````:!L!``4```!\&P$`!@``
M`((;`0`&````B1L!``@```"0&P$`!````)D;`0`,````GAL!``H```"K&P$`
M.0```+8;`0`N````\!L!`"D````?'`$`!0```$D<`0`8````3QP!`!D```!H
M'`$`'P```((<`0`=````HAP!`!$```#`'`$``@```-(<`0`$````U1P!``H`
M``#:'`$`!@```.4<`0`%````[!P!``,```#R'`$`#````/8<`0`R`````QT!
M`!H````V'0$`-````%$=`0`H````AAT!`%,```"O'0$`&0````,>`0!R````
M'1X!`"````"0'@$`-0```+$>`0`A````YQX!`$4````)'P$`*````$\?`0`I
M````>!\!`"8```"B'P$`)0```,D?`0`H````[Q\!`"@````8(`$`(@```$$@
M`0`K````9"`!`#````"0(`$`$@```,$@`0`3````U"`!`!````#H(`$`>0``
M`/D@`0`)````<R$!`*$```!](0$`<P```!\B`0!\````DR(!`"L````0(P$`
M5````#PC`0`7````D2,!`"<```"I(P$`%@```-$C`0`/````Z",!`!<```#X
M(P$`'P```!`D`0!`````,"0!`!\```!Q)`$`'````)$D`0!1````KB0!`!H`
M````)0$`%````!LE`0`*````,"4!``4````[)0$`!@```$$E`0`(````2"4!
M`!(```!1)0$`$````&0E`0`3````=24!`!T```"))0$`#P```*<E`0`$````
MMR4!``D```"\)0$`!P```,8E`0`%````SB4!``<```#4)0$`"````-PE`0`(
M````Y24!``P```#N)0$`!@```/LE`0`&`````B8!``P````))@$`$0```!8F
M`0`(````*"8!``0````Q)@$`&0```#8F`0`1````4"8!``H```!B)@$`&```
M`&TF`0`3````AB8!`!P```":)@$`$0```+<F`0`$````R28!``\```#.)@$`
M!P```-XF`0`$````YB8!`!D```#K)@$`!P````4G`0`"````#2<!``(````0
M)P$`$0```!,G`0`)````)2<!``8````O)P$`$@```#8G`0`7````22<!``8`
M``!A)P$`)P```&@G`0`"````D"<!``0```"3)P$`#P```)@G`0`3````J"<!
M``<```"\)P$`$0```,0G`0`8````UB<!``8```#O)P$`$P```/8G`0`0````
M"B@!`!(````;*`$``@```"XH`0`&````,2@!``P````X*`$`"0```$4H`0`1
M````3R@!`"(```!A*`$`!P```(0H`0`'````C"@!``L```"4*`$`!0```*`H
M`0`"````IB@!``L```"I*`$`,0$``+4H`0`0````YRD!`!0```#X*0$`#```
M``TJ`0`'````&BH!``8````B*@$`"0```"DJ`0`$````,RH!``X````X*@$`
M&0```$<J`0`C````82H!`"````"%*@$`)0```*8J`0`G````S"H!`!8```#T
M*@$`,0````LK`0`+````/2L!`!H```!)*P$`$0```&0K`0`5````=BL!``@`
M``",*P$`!0```)4K`0`@````FRL!``@```"\*P$`"@```,4K`0`)````T"L!
M``\```#:*P$`"P```.HK`0"'````]BL!``X```!^+`$`"````(TL`0`,````
MEBP!``X```"C+`$`"0```+(L`0`*````O"P!``L```#'+`$`"P```-,L`0`&
M````WRP!`*D```#F+`$`"0```)`M`0`.````FBT!`!L```"I+0$`#````,4M
M`0`,````TBT!``P```#?+0$`!0```.PM`0`2````\BT!`#<````%+@$`&P``
M`#TN`0`S````62X!`#8```"-+@$`4P```,0N`0!/````&"\!`%4```!H+P$`
M50```+XO`0`X````%#`!``@```!-,`$`$P```%8P`0`-````:C`!``X```!X
M,`$`%P```(<P`0`%````GS`!``8```"E,`$`!P```*PP`0`K````M#`!`"X`
M``#@,`$`#0````\Q`0`,````'3$!``<````J,0$`!P```#(Q`0`%````.C$!
M`!,```!`,0$`%P```%0Q`0`*````;#$!`!(```!W,0$`%0```(HQ`0`8````
MH#$!`!P```"Y,0$`&````-8Q`0`-````[S$!`!$```#],0$`"0````\R`0`?
M````&3(!``\````Y,@$`$P```$DR`0`0````73(!`%,```!N,@$`+0```,(R
M`0`F````\#(!``8````7,P$`!@```!XS`0`E````)3,!``L```!+,P$`!P``
M`%<S`0`*````7S,!``@```!J,P$`"0```',S`0`'````?3,!``,```"%,P$`
M%P```(DS`0`+````H3,!``X```"M,P$`&@```+PS`0`3````US,!``T```#K
M,P$`(````/DS`0`5````&C0!`"`````P-`$`'0```%$T`0`1````;S0!`!$`
M``"!-`$`)0```),T`0`5````N30!``8```#/-`$`!@```-8T`0`(````W30!
M``X```#F-`$`!P```/4T`0`*````_30!`!(````(-0$`"@```!LU`0`0````
M)C4!`!H````W-0$`&0```%(U`0`&````;#4!``4```!S-0$`%@```'DU`0`8
M````D#4!``H```"I-0$`0@```+0U`0!`````]S4!``D````X-@$`"````$(V
M`0`4````2S8!``@```!@-@$`!0```&DV`0`.````;S8!`!8```!^-@$`,@``
M`)4V`0`0````R#8!`"0```#9-@$`*0```/XV`0`J````*#<!`"4```!3-P$`
M"0```'DW`0`&````@S<!``H```"*-P$`"````)4W`0`R````GC<!`"\```#1
M-P$`,0````$X`0!;````,S@!`"<```"/.`$`,````+<X`0`]````Z#@!`$(`
M```F.0$`,````&DY`0!!````FCD!`"P```#<.0$`+0````DZ`0!`````-SH!
M`#````!X.@$`.P```*DZ`0`E````Y3H!`!0````+.P$`%P```"`[`0`F````
M.#L!`"4```!?.P$`)0```(4[`0`3````JSL!``T```"_.P$`#P```,T[`0`8
M````W3L!`",```#V.P$`!@```!H\`0`'````(3P!`!0````I/`$`"@```#X\
M`0`(````23P!`#````!2/`$`"@```(,\`0`'````CCP!``8```"6/`$`!0``
M`)T\`0`/````HSP!``4```"S/`$`"P```+D\`0`J````Q3P!`!,```#P/`$`
M#`````0]`0`(````$3T!``P````:/0$`%````"<]`0`%````/#T!``<```!"
M/0$`$0```$H]`0`)````7#T!`"4```!F/0$`!@```(P]`0`)````DST!``P`
M``"=/0$`!P```*H]`0`#````LCT!``,```"V/0$`&0```+H]`0`J````U#T!
M``<```#_/0$`!P````<^`0`)````#SX!``<````9/@$`*````"$^`0`U````
M2CX!`"$```"`/@$`!@```*(^`0`'````J3X!`"````"Q/@$`-@```-(^`0`A
M````"3\!`!L````K/P$`-P```$<_`0`W````?S\!`!\```"W/P$`)P```-<_
M`0!5````_S\!`#T```!50`$`-````)-``0`9````R$`!`!````#B0`$`"P``
M`/-``0`4````_T`!``\````400$`#P```"1!`0`/````-$$!`!4```!$00$`
M'````%I!`0`<````=T$!`!0```"400$`$````*E!`0`0````ND$!``,```#+
M00$`"````,]!`0`6````V$$!`'D```#O00$`5````&E"`0`%````OD(!``@`
M``#$0@$`(P```,U"`0`A````\4(!`!(````30P$`#````"9#`0`7````,T,!
M`!8```!+0P$`#P```&)#`0`D````<D,!``4```"70P$`$P```)U#`0`B````
ML4,!`!,```#40P$`&P```.A#`0`.````!$0!`!<````31`$`%@```"M$`0`*
M````0D0!``8```!-1`$`$````%1$`0`(````940!``X```!N1`$`%0```'U$
M`0`)````DT0!``4```"=1`$`#@```*-$`0`.````LD0!``\```#!1`$`!@``
M`-%$`0`$````V$0!``T```#=1`$`"````.M$`0`*````]$0!``<```#_1`$`
M!P````=%`0`,````#T4!``H````<10$`"@```"=%`0`2````,D4!`"D```!%
M10$`(@```&]%`0`*````DD4!``P```"=10$`!0```*I%`0`>````L$4!`!,`
M``#/10$`$P```.-%`0`R````]T4!`$(````J1@$`)0```&U&`0`%````DT8!
M`"T```"91@$`'0```,=&`0`.````Y48!``@```#T1@$`#0```/U&`0`)````
M"T<!`!<````51P$`"P```"U'`0`)````.4<!`!8```!#1P$`(@```%I'`0`>
M````?4<!`"@```"<1P$`)````,5'`0`=````ZD<!`"<````(2`$`(@```#!(
M`0`G````4T@!`$(```![2`$`+@```+Y(`0`E````[4@!`"<````320$`'0``
M`#M)`0`O````64D!`#D```")20$`-@```,-)`0`G````^DD!`#@````B2@$`
M/P```%M*`0`E````FTH!`!L```#!2@$`.P```-U*`0`C````&4L!`!8````]
M2P$`-0```%1+`0`@````BDL!`",```"K2P$`%P```,]+`0"Y````YTL!`!H`
M``"A3`$`(@```+Q,`0`S````WTP!`#,````330$`&@```$=-`0`Q````8DT!
M`!T```"430$`)0```+)-`0`S````V$T!`#8````,3@$`/0```$-.`0!`````
M@4X!`)4```#"3@$`(P```%A/`0`F````?$\!`!\```"C3P$`+P```,-/`0`M
M````\T\!`#`````A4`$`0P```%)0`0`3````EE`!``<```"J4`$`!P```+)0
M`0`'````NE`!``P```#"4`$`#P```,]0`0`/````WU`!`!L```#O4`$`"```
M``M1`0`$````%%$!`!H````940$`#````#11`0`,````05$!`!(```!.40$`
M#0```&%1`0`/````;U$!`#P```!_40$`!0```+Q1`0`0````PE$!`!<```#3
M40$`'````.M1`0`1````"%(!``(````:4@$`3````!U2`0`&````:E(!`"$`
M``!Q4@$`%P```)-2`0`%````JU(!``T```"Q4@$`#0```+]2`0`#````S5(!
M``@```#14@$`"````-I2`0`.````XU(!`!,```#R4@$`#P````93`0`+````
M%E,!``<````B4P$`#P```"I3`0`/````.E,!`!(```!*4P$`(````%U3`0`G
M````?E,!`!,```"F4P$`&P```+I3`0`R````UE,!`!L````)5`$`$0```"54
M`0`Z````-U0!``P```!R5`$`!@```']4`0`0````AE0!``0```"75`$`*@``
M`)Q4`0`O````QU0!``8```#W5`$`"0```/Y4`0`;````"%4!``H````D50$`
M!@```"]5`0`C````-E4!`!<```!:50$`&0```')5`0`6````C%4!`!$```"C
M50$`'@```+55`0`(````U%4!``H```#=50$`*0```.A5`0`_````$E8!``@`
M``!25@$`%@```%M6`0`F````<E8!``H```"95@$`,P```*16`0`.````V%8!
M``@```#G5@$`$@```/!6`0!'`````U<!``,```!+5P$`!P```$]7`0`%````
M5U<!``T```!=5P$`#0```&M7`0`0````>5<!`!````"*5P$`%P```)M7`0`3
M````LU<!`!@```#'5P$`%@```.!7`0`.````]U<!``4````&6`$`"`````Q8
M`0`2````%5@!`!(````H6`$`(P```#M8`0`@````7U@!`!````"`6`$`!P``
M`)%8`0`3````F5@!`!````"M6`$`#P```+Y8`0`S````SE@!`!X````"60$`
M"@```"%9`0"&````+%D!`!8```"S60$`%````,I9`0`(````WUD!``8```#H
M60$`(@```.]9`0`P````$EH!`#````!#6@$`&P```'1:`0`A````D%H!`"(`
M``"R6@$`&````-5:`0`(````[EH!``@```#W6@$`"`````!;`0`&````"5L!
M``\````06P$`#@```"!;`0`0````+UL!``X```!`6P$`#0```$];`0`-````
M75L!``P```!K6P$`$0```'A;`0`&````BEL!``@```"16P$`#P```)I;`0`Z
M````JEL!`!````#E6P$`"0```/9;`0`:`````%P!`"$````;7`$`)@```#U<
M`0`E````9%P!`!T```"*7`$`'0```*A<`0`I````QEP!`!L```#P7`$`%P``
M``Q=`0`(````)%T!`!$````M70$`#0```#]=`0`,````35T!``,```!:70$`
M!````%Y=`0`'````8UT!`!````!K70$`$0```'Q=`0`-````CET!`!<```"<
M70$`#0```+1=`0`.````PET!``T```#170$`!@```-]=`0`(````YET!`!L`
M``#O70$`&P````M>`0`2````)UX!``P````Z7@$`$````$=>`0`0````6%X!
M`!L```!I7@$`!@```(5>`0`&````C%X!``T```"37@$`#@```*%>`0`0````
ML%X!``4```#!7@$`!0```,=>`0`3````S5X!``4```#A7@$`#0```.=>`0`N
M````]5X!`!D````D7P$`!@```#Y?`0`&````15\!``8```!,7P$`!@```%-?
M`0`(````6E\!``\```!C7P$`#0```'-?`0`"````@5\!``@```"$7P$`'@``
M`(U?`0`2````K%\!`!4```"_7P$`&P```-5?`0`"````\5\!``,```#T7P$`
M"@```/A?`0`*`````V`!``D````.8`$`!0```!A@`0`'````'F`!`!4````F
M8`$`#@```#Q@`0`'````2V`!``@```!38`$`!````%Q@`0`)````86`!``@`
M``!K8`$`$@```'1@`0`%````AV`!``T```"-8`$`$````)M@`0`0````K&`!
M``<```"]8`$`$P```,5@`0`+````V6`!``<```#E8`$`&````.U@`0`A````
M!F$!`#X````H80$`*````&=A`0`I````D&$!``<```"Z80$`"@```,)A`0`$
M````S6$!``D```#280$`"````-QA`0`3````Y6$!``T```#Y80$`!P````=B
M`0`.````#V(!``<````>8@$`!````"9B`0`=````*V(!``4```!)8@$`#@``
M`$]B`0`'````7F(!``4```!F8@$`!0```&QB`0`A````<F(!``X```"48@$`
M&````*-B`0`'````O&(!``8```#$8@$`"@```,MB`0`'````UF(!`!L```#>
M8@$`!@```/IB`0`%`````6,!``<````'8P$`#@````]C`0`&````'F,!``\`
M```E8P$`"````#5C`0`)````/F,!``4```!(8P$`/0```$YC`0`Y````C&,!
M`#P```#&8P$`*`````-D`0!"````+&0!`#,```!O9`$`+````*-D`0`^````
MT&0!`#`````/90$`+0```$!E`0`A````;F4!`!T```"090$`"0```*YE`0`+
M````N&4!``D```#$90$`"@```,YE`0`J````V64!`"<````$9@$`,0```"QF
M`0`)````7F8!`!H```!H9@$`)@```(-F`0`-````JF8!``D```"X9@$`"@``
M`,)F`0`+````S68!`!$```#99@$`%0```.MF`0`V`````6<!`'4````X9P$`
M"P```*YG`0`%````NF<!``X```#`9P$`$@```,]G`0`/````XF<!`!L```#R
M9P$`*0````YH`0"*````.&@!``8```##:`$`%0```,IH`0`*````X&@!`!8`
M``#K:`$`(0````)I`0`:````)&D!`$(````_:0$`$P```()I`0`R````EFD!
M`$````#):0$`'P````IJ`0`-````*FH!`!0````X:@$`(P```$UJ`0`8````
M<6H!`!8```"*:@$`%````*%J`0`E````MFH!`!T```#<:@$`'````/IJ`0`<
M````%VL!`!@````T:P$`$P```$UK`0`A````86L!`"4```"#:P$`'P```*EK
M`0`9````R6L!`!@```#C:P$`%````/QK`0`:````$6P!`!P````L;`$`&@``
M`$EL`0`:````9&P!``\```!_;`$`"P```(]L`0`8````FVP!``0```"T;`$`
M!0```+EL`0`1````OVP!``8```#1;`$`"@```-AL`0`'````XVP!``<```#K
M;`$`!@```/-L`0`(````^FP!`!8````#;0$`!@```!IM`0`)````(6T!``4`
M```K;0$`!0```#%M`0`)````-VT!`!(```!!;0$`!@```%1M`0`D````6VT!
M``X```"`;0$`#P```(]M`0`-````GVT!`!````"M;0$`#````+YM`0`0````
MRVT!`#(```#<;0$`!@````]N`0`)````%FX!`"@````@;@$`$@```$EN`0`1
M````7&X!``<```!N;@$`"@```'9N`0`%````@6X!`"0```"';@$`#P```*QN
M`0`8````O&X!`!````#5;@$`$P```.9N`0`3````^FX!`!@````.;P$`%@``
M`"=O`0`(````/F\!``4```!';P$`!P```$UO`0`-````56\!`!$```!C;P$`
M!@```'5O`0`%````?&\!``@```"";P$`!P```(MO`0`.````DV\!``P```"B
M;P$`"@```*]O`0`1````NF\!`!````#,;P$`!0```-UO`0`0````XV\!``H`
M``#T;P$`#@```/]O`0`(````#G`!`$,````7<`$`"````%MP`0`/````9'`!
M`"(```!T<`$`%@```)=P`0`3````KG`!``P```#"<`$`#P```,]P`0`/````
MWW`!`!$```#O<`$`$0````%Q`0`.````$W$!``X````B<0$`#0```#%Q`0`@
M````/W$!`"$```!@<0$`'0```()Q`0`*````H'$!``8```"K<0$`"@```+)Q
M`0`-````O7$!``P```#+<0$`!0```-AQ`0`'````WG$!`!T```#F<0$`!@``
M``1R`0`'````"W(!`!,````3<@$`00```"=R`0`1````:7(!``X```![<@$`
M"````(IR`0`%````DW(!``H```"9<@$``@```*1R`0`0````IW(!`"<```"X
M<@$``P```.!R`0`%````Y'(!`"P```#J<@$`"@```!=S`0`(````(G,!`!(`
M```K<P$`%````#YS`0`&````4W,!``@```!:<P$`!P```&-S`0`$````:W,!
M``4```!P<P$`9````'9S`0`/````VW,!`!(```#K<P$`$@```/YS`0`%````
M$70!`"4````7=`$`.0```#UT`0`3````=W0!``H```"+=`$`#0```)9T`0`+
M````I'0!``D```"P=`$`&````+IT`0`H````TW0!`"4```#\=`$`)````")U
M`0`B````1W4!`!,```!J=0$``P```'YU`0`'````@G4!`!,```"*=0$`!@``
M`)YU`0`+````I74!``H```"Q=0$`7P```+QU`0`6````''8!``X````S=@$`
M"P```$)V`0`;````3G8!`"\```!J=@$`$P```)IV`0`(````KG8!`!H```"W
M=@$`*0```-)V`0`)````_'8!``8````&=P$`(`````UW`0`,````+G<!`"0`
M```[=P$`(P```&!W`0`F````A'<!``@```"K=P$`#0```+1W`0`D````PG<!
M`!D```#G=P$`+P````%X`0`3````,7@!``(```!%>`$`#@```$AX`0`&````
M5W@!``\```!>>`$`!@```&YX`0`4````=7@!``8```"*>`$`"0```)%X`0`-
M````FW@!``@```"I>`$`"@```+)X`0`+````O7@!`#,```#)>`$`!@```/UX
M`0`/````!'D!`!(````4>0$`'@```"=Y`0`1````1GD!``X```!8>0$`$0``
M`&=Y`0`2````>7D!``X```",>0$`#@```)MY`0`.````JGD!``@```"Y>0$`
M'0```,)Y`0`6````X'D!`!$```#W>0$`"@````EZ`0`6````%'H!``H````K
M>@$`%P```#9Z`0`'````3GH!`!(```!6>@$``P```&EZ`0`(````;7H!``4`
M``!V>@$`!0```'QZ`0`*````@GH!`!$```"->@$`%````)]Z`0`;````M'H!
M`!L```#0>@$`&0```.QZ`0`8````!GL!`!L````?>P$`&````#M[`0`8````
M5'L!``@```!M>P$`!@```'9[`0`/````?7L!``\```"->P$`"0```)U[`0`5
M````IWL!``X```"]>P$`"@```,Q[`0`9````UWL!`!<```#Q>P$`!@````E\
M`0`3````$'P!``D````D?`$`$P```"Y\`0`2````0GP!``H```!5?`$`"0``
M`&!\`0`%````:GP!``@```!P?`$`!0```'E\`0`$````?WP!``<```"$?`$`
M/````(Q\`0`M````R7P!`!,```#W?`$`)0````M]`0`F````,7T!``X```!8
M?0$`+P```&=]`0`T````EWT!`"(```#,?0$`(P```.]]`0`L````$WX!`!4`
M``!`?@$`#@```%9^`0`6````97X!``\```!\?@$`%0```(Q^`0`5````HGX!
M`!X```"X?@$`'````-=^`0`A````]'X!`!D````6?P$`=````#!_`0`>````
MI7\!`!\```#$?P$`&0```.1_`0`0````_G\!`"D````/@`$`-0```#F``0`C
M````;X`!``X```"3@`$`3P```**``0!*````\H`!``<````]@0$`%@```$6!
M`0`0````7($!``\```!M@0$`%P```'V!`0`)````E8$!``H```"?@0$`!P``
M`*J!`0`)````LH$!``P```"\@0$`"P```,F!`0`'````U8$!`"X```#=@0$`
M"`````R"`0`(````%8(!``\````>@@$`$0```"Z"`0`/````0((!`$,```!0
M@@$`!@```)2"`0`5````FX(!``@```"Q@@$`!P```+J"`0`'````PH(!`"H`
M``#*@@$`"P```/6"`0`8`````8,!``0````:@P$`,@```!^#`0`4````4H,!
M`"4```!G@P$`7@```(V#`0`2````[(,!`$0```#_@P$`$0```$2$`0`)````
M5H0!``\```!@A`$`#````'"$`0`4````?80!``P```"2A`$`&@```)^$`0`6
M````NH0!``4```#1A`$`$@```->$`0`3````ZH0!`!,```#^A`$`%@```!*%
M`0`4````*84!`!0````^A0$`#P```%.%`0`>````8X4!``@```""A0$`"@``
M`(N%`0`3````EH4!``T```"JA0$`#P```+B%`0`.````R(4!`!@```#7A0$`
M#@```/"%`0`0````_X4!`!L````0A@$`"@```"R&`0`(````-X8!``4```!`
MA@$`'@```$:&`0`&````988!`!(```!LA@$`"````'^&`0`.````B(8!``4`
M``"7A@$`&@```)V&`0`0````N(8!`"8```#)A@$`$@```/"&`0`&`````X<!
M``<````*AP$`%@```!*'`0`'````*8<!`!(````QAP$`!@```$2'`0`9````
M2X<!`"8```!EAP$`"@```(R'`0`=````EX<!`!@```"UAP$`"@```,Z'`0`6
M````V8<!`!(```#PAP$`!`````.(`0`,````"(@!``@````5B`$`!P```!Z(
M`0`+````)H@!``@````RB`$`(@```#N(`0`H````7H@!`"<```"'B`$`1```
M`*^(`0`B````](@!`"<````7B0$`,@```#^)`0!F````<HD!`"0```#9B0$`
M!P```/Z)`0`(````!HH!``8````/B@$`"P```!:*`0`F````(HH!`!L```!)
MB@$`%````&6*`0`P````>HH!``0```"KB@$`%P```+"*`0`&````R(H!``D`
M``#/B@$`$P```-F*`0`.````[8H!``<```#\B@$`%0````2+`0`(````&HL!
M`!,````CBP$`#````#>+`0`9````1(L!`!L```!>BP$`-0```'J+`0`)````
ML(L!`!0```"ZBP$`!0```,^+`0`)````U8L!``4```#?BP$`&P```.6+`0`.
M`````8P!``0````0C`$`#````!6,`0`-````(HP!``4````PC`$`#````#:,
M`0`+````0XP!``8```!/C`$`"````%:,`0`$````7XP!``\```!DC`$`1P``
M`'2,`0!I````O(P!``<````FC0$`(@```"Z-`0`/````48T!``4```!AC0$`
M$0```&>-`0`/````>8T!``@```")C0$`%````)*-`0`L````IXT!``@```#4
MC0$`$````-V-`0`,````[HT!`#@```#[C0$`$P```#2.`0`8````2(X!`#0`
M``!AC@$`'@```):.`0`X````M8X!`#D```#NC@$`)0```"B/`0`2````3H\!
M``D```!ACP$`#P```&N/`0`7````>X\!`!D```"3CP$`!P```*V/`0`4````
MM8\!`!L```#*CP$`#P```.:/`0`4````]H\!`"H````+D`$`!@```#:0`0`-
M````/9`!``\```!+D`$`"````%N0`0`(````9)`!``P```!MD`$`#0```'J0
M`0`.````B)`!``<```"7D`$`!@```)^0`0`&````II`!`!P```"MD`$`&@``
M`,J0`0`8````Y9`!``X```#^D`$`"@````V1`0`A````&)$!``,````ZD0$`
M!0```#Z1`0`*````1)$!``(```!/D0$`#````%*1`0`6````7Y$!``L```!V
MD0$`&@```(*1`0`:````G9$!``4```"XD0$`"@```+Z1`0`4````R9$!`!8`
M``#>D0$`#P```/61`0`&````!9(!``L````,D@$`"@```!B2`0`0````(Y(!
M`%X````TD@$`&@```).2`0`S````KI(!`!T```#BD@$`!P````"3`0`&````
M"),!``D````/DP$`#P```!F3`0`,````*9,!`"4````VDP$`%@```%R3`0`0
M````<Y,!`"<```"$DP$`"@```*R3`0`3````MY,!``X```#+DP$`#0```-J3
M`0!J````Z),!`!8```!3E`$`%0```&J4`0`O````@)0!`!0```"PE`$`$@``
M`,64`0`?````V)0!`"$```#XE`$`#P```!J5`0`;````*I4!``L```!&E0$`
M!P```%*5`0`'````6I4!``D```!BE0$`%````&R5`0`2````@94!`#(```"4
ME0$`$P```,>5`0`3````VY4!``0```#OE0$`!P```/25`0!/````_)4!`$H`
M``!,E@$`+````)>6`0`]````Q)8!``<````"EP$`,0````J7`0`E````/)<!
M``@```!BEP$`"P```&N7`0`/````=Y<!`"@```"'EP$`!P```+"7`0!,````
MN)<!`"@````%F`$`)0```"Z8`0`<````5)@!`"H```!QF`$`(0```)R8`0`/
M````OI@!``4```#.F`$`#0```-28`0`.````XI@!`!````#QF`$`!@````*9
M`0`N````"9D!``P````XF0$`"@```$69`0`&````4)D!`!0```!7F0$`"```
M`&R9`0`(````=9D!`!8```!^F0$`"0```)69`0`)````GYD!``0```"IF0$`
M#0```*Z9`0`-````O)D!`!4```#*F0$`%@```."9`0`.````]YD!`"(````&
MF@$`$````"F:`0`(````.IH!`!````!#F@$`%@```%2:`0`+````:YH!``T`
M``!WF@$`'````(6:`0`G````HIH!``X```#*F@$`"P```-F:`0`(````Y9H!
M`!(```#NF@$`%0````&;`0`'````%YL!``H````?FP$`"@```"J;`0`-````
M-9L!``T```!#FP$`%````%&;`0`&````9IL!`!$```!MFP$`#````'^;`0`4
M````C)L!`!L```"AFP$``@```+V;`0`6````P)L!``8```#7FP$`"0```-Z;
M`0!?````Z)L!``4```!(G`$`(@```$Z<`0`G````<9P!`!L```"9G`$`)P``
M`+6<`0!/````W9P!`#(````MG0$`/0```&"=`0`A````GIT!`!@```#`G0$`
M!0```-F=`0`-````WYT!``T```#MG0$`!P```/N=`0`-`````YX!`!,````1
MG@$`#0```"6>`0`-````,YX!``X```!!G@$`!P```%">`0`'````6)X!``<`
M``!@G@$`%0```&B>`0`%````?IX!``@```"$G@$`!@```(V>`0`A````E)X!
M``X```"VG@$`(@```,6>`0`:````Z)X!``<````#GP$`'`````N?`0`2````
M*)\!``P````[GP$`$0```$B?`0`&````6I\!`!@```!AGP$`#````'J?`0`>
M````AY\!``@```"FGP$`%````*^?`0`9````Q)\!``L```#>GP$`#0```.J?
M`0`H````^)\!`!8````AH`$`$P```#B@`0`(````3*`!``T```!5H`$``@``
M`&.@`0`&````9J`!`!,```!MH`$`&0```(&@`0`G````FZ`!`"<```##H`$`
M+@```.N@`0`K````&J$!`#<```!&H0$`00```'ZA`0!'````P*$!`$X````(
MH@$`/@```%>B`0`8````EJ(!`#,```"OH@$`+@```..B`0`O````$J,!`"4`
M``!"HP$`'P```&BC`0`]````B*,!`'H```#&HP$`-````$&D`0`@````=J0!
M`#<```"7I`$`7P```,^D`0`^````+Z4!`#,```!NI0$`,0```**E`0`?````
MU*4!`!L```#TI0$`(````!"F`0`P````,:8!`#X```!BI@$`)P```*&F`0`8
M````R:8!`!H```#BI@$`&@```/VF`0`>````&*<!`%8````WIP$`-0```(ZG
M`0`V````Q*<!`#8```#[IP$`,````#*H`0!(````8Z@!`'````"LJ`$`1@``
M`!VI`0`J````9*D!`"X```"/J0$`+@```+ZI`0!8````[:D!`&````!&J@$`
M3P```*>J`0!)````]ZH!`"0```!!JP$`&0```&:K`0`<````@*L!`",```"=
MJP$`1````,&K`0`]````!JP!`$,```!$K`$`C0```(BL`0`4````%JT!`"@`
M```KK0$`+@```%2M`0`C````@ZT!`$8```"GK0$`(````.ZM`0!+````#ZX!
M`!\```!;K@$`"0```'NN`0"Z````A:X!`$,```!`KP$`'P```(2O`0`Q````
MI*\!`!X```#6KP$`(````/6O`0`H````%K`!``4````_L`$`!P```$6P`0`$
M````3;`!``T```!2L`$`#````&"P`0`,````;;`!``8```!ZL`$``@```(&P
M`0!M````A+`!``,```#RL`$`!````/:P`0`'````^[`!``<````#L0$`!0``
M``NQ`0`L````$;$!``P````^L0$`$@```$NQ`0`)````7K$!``,```!HL0$`
M"````&RQ`0`'````=;$!`!0```!]L0$`#````)*Q`0`7````G[$!``8```"W
ML0$`&````+ZQ`0`,````U[$!``,```#DL0$`+P```.BQ`0`&````&+(!``@`
M```?L@$`'0```"BR`0`Q````1K(!`"P```!XL@$`&@```*6R`0`<````P+(!
M`"D```#=L@$`&P````>S`0`?````([,!`"````!#LP$`'P```&2S`0`@````
MA+,!`"````"ELP$`(````,:S`0`<````Y[,!`"@````$M`$`'````"VT`0`H
M````2K0!`!L```!SM`$`&P```(^T`0`C````J[0!`"$```#/M`$`(````/&T
M`0`A````$K4!`!L````TM0$`)0```%"U`0`H````=K4!`!H```"?M0$`(0``
M`+JU`0`>````W+4!`#````#[M0$`'@```"RV`0`E````2[8!`"D```!QM@$`
M(P```)NV`0`H````O[8!`"X```#HM@$`(@```!>W`0`F````.K<!`"@```!A
MMP$`*0```(JW`0`C````M+<!`!H```#8MP$`*P```/.W`0`S````'[@!`"0`
M``!3N`$`*@```'BX`0`J````H[@!`#0```#.N`$`%`````.Y`0`Q````&+D!
M`#(```!*N0$`#````'VY`0`.````BKD!`!D```"9N0$`%````+.Y`0`1````
MR+D!`"8```#:N0$`!0````&Z`0`)````![H!`"<````1N@$`,0```#FZ`0`5
M````:[H!`",```"!N@$`"@```*6Z`0`5````L+H!``@```#&N@$`"P```,^Z
M`0`5````V[H!`!$```#QN@$`(`````.[`0`'````)+L!`#D````LNP$`!P``
M`&:[`0`3````;KL!``L```""NP$`0P```(Z[`0`)````TKL!`!\```#<NP$`
M%````/R[`0`7````$;P!`!<````IO`$`.````$&\`0`=````>KP!`!````"8
MO`$`)P```*F\`0`2````T;P!`!(```#DO`$`'````/>\`0`*````%+T!`!8`
M```?O0$`"0```#:]`0`A````0+T!``H```!BO0$`(@```&V]`0`H````D+T!
M``D```"YO0$`&P```,.]`0`'````W[T!``H```#GO0$`"0```/*]`0!`````
M_+T!``H````]O@$`"@```$B^`0`+````4[X!``<```!?O@$`$P```&>^`0`)
M````>[X!`!\```"%O@$`&@```*6^`0`4````P+X!``H```#5O@$`"P```."^
M`0`:````[+X!``D````'OP$`+````!&_`0`.````/K\!`!````!-OP$`"0``
M`%Z_`0`"````:+\!`!$```!KOP$`&@```'V_`0`+````F+\!``4```"DOP$`
M#0```*J_`0`(````N+\!``L```#!OP$`*P```,V_`0`/````^;\!`!0````)
MP`$`%````![``0`.````,\`!`"X```!"P`$`&0```''``0`9````B\`!`!P`
M``"EP`$`$````,+``0`R````T\`!`!0````&P0$`0````!O!`0`$````7,$!
M``<```!AP0$`$````&G!`0`6````>L$!``8```"1P0$`!P```)C!`0`'````
MH,$!``P```"HP0$`!P```+7!`0`0````O<$!`!$```#.P0$`00```.#!`0`V
M````(L(!`"L```!9P@$`!0```(7"`0`7````B\(!`"(```"CP@$`'@```,;"
M`0`>````Y<(!`!(````$PP$``@```!?#`0`$````&L,!`!`````?PP$`!0``
M`###`0`%````-L,!``,````\PP$`$````$##`0`O````4<,!`!$```"!PP$`
M(@```)/#`0`P````ML,!`%(```#GPP$`%````#K$`0!O````3\0!`"(```"_
MQ`$`0@```.+$`0`>````)<4!`$H```!$Q0$`*0```(_%`0`^````N<4!`$``
M``#XQ0$`/````#G&`0!`````=L8!`"H```"WQ@$`'@```.+&`0`N`````<<!
M`$@````PQP$`&````'G'`0`,````DL<!``T```"?QP$`;0```*W'`0`*````
M&\@!`*L````FR`$`<P```-+(`0!Q````1LD!`"8```"XR0$`;````-_)`0`;
M````3,H!`"X```!HR@$`$P```)?*`0`*````J\H!`!D```"VR@$`'0```-#*
M`0`V````[LH!`"8````ERP$`(@```$S+`0!E````;\L!`!<```#5RP$`&@``
M`.W+`0`+````",P!``0````4S`$`!P```!G,`0`(````(<P!`!D````JS`$`
M%````$3,`0`<````6<P!`"<```!VS`$`$@```)[,`0`$````L<P!``D```"V
MS`$`"````,#,`0`&````R<P!``<```#0S`$`!@```-C,`0`)````W\P!``H`
M``#IS`$`"````/3,`0`+````_<P!``8````)S0$`$````!#-`0`'````(<T!
M``4````IS0$`(P```"_-`0`6````4\T!``D```!JS0$`(````'3-`0`6````
ME<T!`"8```"LS0$`%@```-/-`0`%````ZLT!`!L```#PS0$`"`````S.`0`(
M````%<X!`!(````>S@$`!@```#'.`0`"````.,X!``(````[S@$`%@```#[.
M`0`%````5<X!``T```!;S@$`%0```&G.`0`9````?\X!``<```"9S@$`+P``
M`*'.`0`"````T<X!``,```#4S@$`#0```-C.`0`.````YLX!``@```#US@$`
M&````/[.`0`<````%\\!``L````TSP$`$P```$#/`0`/````5,\!`!0```!D
MSP$``@```'G/`0`(````?,\!`!$```"%SP$`#P```)?/`0`0````I\\!`"0`
M``"XSP$`!@```-W/`0`*````Y,\!`!(```#OSP$`"0````+0`0`"````#-`!
M``L````/T`$``0```.T```#7`P``:0```&T!````````]P4``"@&``!'`0``
M2P,``.@%````````VP,``.$%``!J````H00```````!G`P``&00``$,%``"M
M!0``9P$``"$&`````````````)$!``"3!0````````(!``#(!0``:P0`````
M``#4!```M04``+\````E`0``,P0``-,$``!!````"@8``)\```!B`0``)@$`
M`*8!````````C`0``+,``````````````$@!````````3@(`````````````
MC@$`````````````608`````````````````````````````0````&P%``#Y
M!0````````````"%`0``-@0``"`$````````=P$``&,%````````B@8``-X%
M``!6!@``&0(````````"`P`````````````;`0``B0(``.(!``!I`P``````
M`*H"````````'P4``,8%``"[!```/0```.8$``!-`P``G@```%T%````````
M`````"@````V`@```````*````!?`0``/P8``!P"``````````````````!M
M`@``>P4```````!4`P``V@(``($"``!+!@```````"@!``!5`P``B@,``"<&
M``#L`0``````````````````=P8``#0```"D`0````4``*`"``!H`0``````
M`&8$``",`0```````+,#````````.0$``.T%```G`0``R0$``#<%``!2`P``
M4P,``+L#``"O!```)P4``!<```"S!```408````````^`0``^00``&X!```Z
M!@``+0,``%8```#]`0``=@$```($``!?````\0```%P&``#Q`0```````-0"
M``"^`P``&P4``'T"``!D!```=P4`````````````[@(``.P$``"_`P``.@(`
M``````!O!```#`4``"4```!<!```.P```'0%``#!!```[P$``",&```Y!0``
MS`(``#8&``#)``````````````#H`@````````````"<!```]`0``'X`````
M````O`(``*@`````````1P```&H&``!R````A04```````"&!0``7`4``-D`
M``"(!0``/@```.\$```I!```EP````````#2````7@```!X$````````1`(`
M``````"?!0```````$$"``"]`0```````,8!```N`@``P0(``&L&```M`@``
M``````````#R!0```````'<"``"X`P```````$X#```%````-@$``%0!``")
M!```9@,``*D%````````2P```)4&``!J`0``80,```````!1!```!08`````
M``````````````H$````````M00``(P"````````J0,``$8#```Z````6`$`
M``````"'!@``C0$``*T$``!]!@``F0$``"\#````````]`(``)8"````````
MQ0(``*T```!)!@```````"$#``#$`````````)0&``#W!````@(``"8#``"R
M!0``?0````````"G!```0P8``+P$```C````*@4```````"\`P``0P(``%8"
M````````:`(``&4$````````H`,``$4%``!`!```500``*4$```-`````0,`
M`*0"``!?`P``M`4```,"``!U`P```````'8#```.`P``QP(``&<$```#!0``
M-P$``)D&``".!0``K`4``%@$``!_!@```````,L```"N````QP$```````#E
M`@``````````````````W0$``&,```#^`P``P`,```````!*`@``-@4`````
M````````_@$```````"4!0```````#H%````````_P```.@#``!X!@``3P$`
M`(@"``!L!@``E0,``.<!`````````````!($``!S!0``M`$``/(!```2````
M`````"8````T`P``!@(``)8$```C!0``````````````````XP(``#0&``##
M`P``!`0```````!:!@``^@$````````<`P````````\#``"D!````````&D$
M``"*````X0(``*D```#,`````````'D$``!_!````````.,```"<````````
M`#0!````````+P8```4"``"@`0``&`(``"0"``!R`P``G04``/D!```,`@``
M`````"L"``#1!```4@````````"+`P```````,D"``!^`P``,@(```H%``!]
M!```B`0`````````````DP(``$T$``"N`@``S`4``)8&``!N````IP(`````
M```^`P``I@0``,X%```6`P```````!P!``#1`P``AP```!$```"'!0``$P0`
M``````"-`````````!P%``!M!```=@(``*(!````````4P```#@```!;`@``
M<@(``%8%````````L04``-,```#/````;`,``"H"`````````````$P%```T
M!```\P`````````G````C@,````````0`0```````"("```I!0```````+D`
M````````!04````````:!@``4P4```````!X````X@```.X%````````30``
M```````%`P``````````````````_`,``$<%``#T`0``'@```,@$``".!@``
M`````(,```!5!@``]@,``/H#``#>!```>P0``+X%```?`0````````````"<
M`0```````$P"``!*!@``'````-\$```^!0``J@0``)@"``#0`0``]P(``'L!
M``!^!0``+@```"4#``!7`P``2`0```````"S`0``%P0````````S````SP0`
M`)`!``"/!0```````,@````]`@``;`(``"<#````````]0,``'T#````````
M2P4``&`&``#I`@``?`,``!,#``"7!0``[0(``-8%``#(`@```````&X"````
M````^P0```D!```:`P``#04```````!%!@```````+<`````````Y`(``-D!
M``"0`@``?P4``%D"````````4@8```0&``#P!0``$````!D!``#0`@``[```
M`/$$``!=````ZP```%$"````````FP(```````#<`@```````,X!``#2!```
M+@0`````````````IP4``*P```"L!````````!T"```6!@``P@(``&\"````
M````N`$```````#F`@``^`4``.4#``#R````Q0$``/L%``"&!@```````-<$
M````````?@$``#H#`````````````%P```"F`P``YP0```````#5!0``````
M`%`"````````/@(``,`%```]!0```````-(!````````S00``"4%``":````
M4@(``)T!``#`!```G@$``&L!``"*`0``&@(``(L%```8`P``G0(``)$```!M
M`````````(`$```Y`P`````````````5!0``Y`0``"`&```$`P``>P,``.H%
M``#X`0```````',"````````[0$``&$$``!7`@``*`(``*4#``"E!0``S0,`
M`$P#`````````````'@$````````9P```%0&``""!@``404````````[`0``
M``````<!``!1`0```````"P&```T!0```````+\!```<!@``P`$``%4"```/
M!0````````X````J!@``[@,``!\#``#>`@```````/T#``")!0``P0,``-`#
M```@!0``#0,``%H$``#H!```O`4``(\$````````/P$```D```!.`0``.P8`
M`%,"````````Y0```)\$``#J`@``:`,``-8"``!N!0``O@```)0$``"B!0``
M``````````!Z`P``C08``%8$````````N0$```````"&`@``!`$``$\```!,
M!@``*@,``,D%``";`P```````&````"-`@``%0```"X&``!*`0```````$<$
M````````U````#<&``!P`@``T0(``)@!``#_`@``>@(``$($``#2`P``1@4`
M`$,!````````]P`````````R!0``_P0``)<&``"Z!```X00``$`!``#0!0``
M`````+(#````````-0,``(P&````````V@0``.D```#9`@``<@8``#P$``"J
M`````````.<#``!=!```%@(``'0&``!O!0``?P(``(H%````````D04``,\"
M``!E`@``J`$``)\!`````````00``'`#```1!```<@0``(0"``#@!0``C@0`
M`(X"``````````````L`````````(P0````````7!@``-P0```````!D!0``
M)````.L$```+`@``````````````````$P8```````!,!`````````P$``"(
M`0``@08```````"E`@```````+`%``!!!@```````.8%``"'`0``F````*\`
M``#F`0```````#L%```A````_@0```````#9`P```````%@"``#(`0``0P0`
M`/@"``"V!0``,@8``-L"``!7`0``"P8````````U!```````````````````
MT0$``"\"`````````@```.($````````\P0``&8%````````[`(````````S
M!@``G@0``)8```#[`@``DP$`````````````_@```(H$``"`!0``?`(`````
M````````6`4``/P%```,`0```````+8"``!"`````````"\$``!S!@``000`
M````````````(P,```````"+!@``M@0``-@"``"=`````````/8!``!``P``
M!P``````````````CP,``"X!```9`P``/````)(#`````````````(P`````
M````L@0``'T!``"<`P``>`,``'4%``"4````E0```'$&```]`0``AP0``*L$
M````````4P$```````````````0``-8#````````!`4`````````````A```
M`)X"``"E````@@$```8!``#,!```"`,```,```"_`@```P0``-H!``"J`P``
M6P```&`$```#`P``B`8``)X#``!C!```@0````````!/`P``N@``````````
M````W0,``#<#```?!@```````!H!``!H!```-`(``.,!```&!@``8`4``.L#
M``"B`P``^P$```````!^`@``<P```"L#``#_`0``M@$``/H%``#K`@``````
M`"T%````````NP4``&X&``#*!```MP4`````````````1`8```````!B!```
M$P$``$H#``!S!```L0(```````#<`P``.`,``"P"````````P04``(,!```D
M!0```````/D"``!>!```6P8```$&``!D`````````.0#``"-!```4````%@&
M````````D`8``(<"``!#`P``]0```*D!``#W`P```````*$```"5!0``A0,`
M`%<```#>````4`$```````#4!0``Y````&\#``!>!@``HP4```\$``"+`0``
MG@4``-T%````````$`(``$\&``#A`0``FP8```````"%!@``@P4``/8```#M
M!```#@$```````!+!```D@$``*,$```Q!@````````H`````````0`(``.H#
M``!S`P``2P$``/D`````````MP,``)$#``#7`@``8`$```````!G!@``:0(`
M`,`"``#+`P``,0$``````````````````.D$```.!0``1P(``.L%```Z`0``
MT@4``($!``#I`0``^@````\"`````````````#$"````````M`,`````````
M````808```````#+!```@0,``(,#`````````````,````!:!0```````,<`
M`````@```````"$"``"K!0```````+@%``"A!0``+`0``.,%```B!```604`
M`+D$```6!0``<`4``'P````W`@````````````!H````R@(```````#]````
MG`(``%L!```8!```*0,```````"(`P``$@(``$@```"L`@``R@``````````
M````1@```$0%```(!0`````````````#`0``,`0```````"9!````````'H!
M```E!```Q`,``$4!``!O`````````!L`````````/`4``-,"````````>P8`
M`)L```#T!0``&@```$D```!%!````````"(&``#.```````````````N!0``
M\04`````````````6@(```````!K````7P4```````![````]P$```````#U
M`0``V00``*@$`````````````!(!````````\````$@%``"2`````````'$`
M``!F````F@0```````"2`@``308`````````````````````````````A@0`
M`-<%```O!0``$P```)<$``#T`````````*\"``"$!```600``/(#```P`P``
M```````````.!```X@(``.0%``!@`P``(@,```````#=`@``L00``!X"```L
M````*@0``*@%```!`0``O````*L!``!B!0````````(%````````````````
M```S`@```````&$```"K`@``A00``$X%```&!0````````````!P!```_00`
M`-P```";!```%`0``!4"``#U!```@@```*,```#>`0```````)0#```M!```
MIP,``'X&```L`0``P@0``.4!```P````>`4``(`#``!"!@``/P(``.4$```'
M!0``@@4``&<%`````````````$D$```8!@```````%8!``#3`0``#P8``)`%
M````````D@8``,,$``#?`@``P@$``*D$`````P``:08``+`$``"1`@``=08`
M`!8```!B`@``)08`````````````,0````H#``"<!@```````%L%``!\!0``
M`````$("```#!@```````/0#````````QP,`````````````-@,```````"M
M`P``R@4``)<!``#E!0````````````""`P``D`````````#N!````````#H$
M````````K@4``(T%``"T`````````$@&``!(`P```````&8"````````N@,`
M`&(&``#@`@``^@0```````"N`0``V@4``"<$```4````E0(```````#\````
MC0,``$(#``"/!@```````*\%``!,`0``A`,``/X"``#4`P``80(```@`````
M````F@,```````"P`@``)0(``$8!````````-08```````!U`````````#P!
M``!C`P``R0,```````"&`````````.D%```J`````````&L#``"B````I`4`
M`$4````X`@``K`$``%($``"%`@``70(`````````````&P8``"8$``"9!0``
MW`4``(\"`````````````(8#``!*!```1````!0#`````````````"0#````
M````7@$``*L#``"J`0```````'D!`````````````'0#```-`0``<00`````
M```;!````````-8$`````````````&4&```?````````````````````(0$`
M`)H&``#\!```<@4`````````````;P8``#X$``"9`@``Q`(``,L"```=!0``
MQ04`````````````9`$``(H"``!H!0``ZP$``+(!``#1````L`,``'D"```1
M`P``^@(``%\&`````````````"H!``!<`P```````,(`````````W00``/$#
M```W````P0```!$&```R````%@$```````!/!0``4P8```````"C`@``````
M`$L"``!9`P``%@0````````B!0``H`0``&H%``",`P```````"P%``#V`@``
M`````+$#`````````````#D$````````/P0``*0````D`0``BP````````"]
M`@``TP4``)@$``!E!0``^P````````!8`P``"P,``'H%``!:````````````
M````````WP$``+X$````````N`````\!``"Q`````````",!````````,P$`
M```````I`@``D`0``%4!``````````````````"A`@``GP(``&0"``#D`0``
M?P$```````"O`0``NP(``&L%````````:04````````&````0P```"D!``#.
M!```WP,``$`%```;`P``>0,``,T!``"'`P```````$X&``!_````4@4``)D`
M``#U`@``M@`````````````````````````P`@````````````"F````%0,`
M`.H!```8````1`0`````````````@`$``!0%``#@`P``:@,``*<!```=!@``
M"P4``%H#``!,````*P8```````#S`@``M0,``$8$``!0`P``V````'`!```\
M`P```````(D```!J!```````````````````"`0``*X#``#9!0``U@``````
M````````L@`````````A!0``P0$`````````````D00``,(%``!Q`P``Z`$`
M``D%``#(`P``VP$``-@$``!F!@``@@(``&,"````````DP8``-\```!4`@``
MWP4``$D!````````9@$``%P!``!9````4@$``%$#```U`@``?`$``+D%``"L
M`P``8@,```````#/`0``E@$```````#]`@``Q`0``+T```#8`0``7@,```<#
M```!!0``L````.\%````````N`(``.H````H!0``````````````````E`$`
M`!$"```R`0``00$``-T```#X`P``N0(``!$%````````K0$``)($```U`0``
M304``$0#``````````````````#.`@``.`4````````F!@``K0(```````"Z
M`@``;0,````````=!```00,```````#:````XP0``%$````?`@``U`$```8$
M``"3`P``XP,``$<&``"6`P```````"(`````````>`$```<&```@`P``!@,`
M`+4!``#:`P``F@(``'$!``"P`0``70$```````!E`0``3@```#$$``#\`0``
M`````#T$````````MP(```````!?!```"`(``'\#```S!0``R@,```````"C
M`P```````,<%``"E`0``4P0``!,%``#3`P``204``*L````[!````````%@`
M````````20,```````"Y`P``;`$``+<!```Y!@``FP4``&0#``!0!0``````
M`/("``##`0````````<$``"7`P``*P````````!^!```"`$`````````````
MIP```'L"``#O`P``"@$``#$%``!W`P``A@$```P&```+!```PP4`````````
M````EP(``($$``#%`P````````D&``"%````N@4``(L"``!T`@``/P```#,#
M``".````Q@````````#R!```.P,``+,%``!B````%`(```````!*````*P0`
M`&X#``#Q`@``\`0```````!\!```=P```!D%``##`````````$X$``"=`P``
M90,``+\%``!E````;04``#D"````````M`0``"T````)`@````````````!D
M!@``5P4``'@"```_`P``_P,``&\!``"2!0``VP````H"``#5`@```````"(!
M`````````````*$#``````````8``-P$``!T````M0```","``#*`0``U0$`
M`&,&````````@04``+X"```"!@``=P0````````0!0``5@,``/L#``#@````
M``````0"````````T````+8#````````H@0``%H!``!$`0``:P(```P````1
M`0``DP```',!``"+!````````#@&``"[````&08``"T!````````>@```/T%
M``#$!0``$@8````````.`@``Z0,``/@$``!A!0``F@4```<"``#>`P``````
M````````````=`0```````")`0```````)L!``!5!0``J0(`````````````
M$P(```````##`@``.0````4$``!7!@``9P(`````````````M0(``.<%``#'
M!````````%X"``!!!0``'@4``+@$``"9`P```````!T#```<!````````+T%
M``!A`0``#P```,0!``#B!0``%`8``.P#````````N@$```````!]!0``%P4`
M``X&``!"`0``/08``(0&``#<`0``UP$````````7`@``30$``!`#````````
M&`4```````"H`P``LP(``#@!``"C`0``O`$``"0&```P!@```````!(#``"1
M!@``=@0````````@`0``A`4`````````````H@(``.<```"W!````````$4#
M``!P!@``I@4``!4&``#X````*08``!`&```8`0```````%D!```\!@``_`(`
M`/,!```F!0``S0```````````````0(``$4"``!-`@```````&P$````````
MDP0```````!M!@``_@4```0````G`@````````````#;!0``E0$``-@#``!;
M`P``M`(``)@#``!V!@````````T"```4`0``Z````/`#``#M`P``'@8``'(!
M````````(`(``.H$````````1@8``"0$``#A`P``````````````````U@$`
M``T$``!>!0``(````!X!```+`0``OP0``%`&```5!```,@,``'P&``#;!```
ME00``%T&```;`@``SP,``+T$```5`0``X0```+L!````````0`8``'8%``"H
M`@``X`$``$\"`````````````!<#````````>@0```````#S`P```````.X!
M`````````````)T$``#5````.P(````````2!0```````&P`````````RP4`
M`(,$``!=`P``'0$```D#``#5!```&@4``'4"``#B`P``[@```"P#```?!```
MI@(````!``#)!```S`$`````````````1@(``)@%```O````C`4``"8"``"`
M!@``[`4```````"#!@``.`0``-("``")!@``,`$``,8"```=````<04``%<$
M````````*`0```````"J!0``L@(``"T&````````````````````````\`(`
M`````````````````%L$``!T`0``-@```$@"``"/````/@8``/4%``#+`0``
M>0```,T"```U!0``\P4``/8%``#P`0``8`(```````"$`0``GP,``!`$````
M````,@0``*0#``"6!0````````@&`````````````*X$``#7````&@0`````
M`````````````'4$```\`@``:0$``(``````````L0$`````````````````
M`,X#```-!@```````&@&``!*!0``Q@0``(\!``#5`P``4`0```````"^`0``
M>@8```D$``#0!```,`4```````!/!```*0```'$"``"0`P``F@$`````````
M````/0,`````````````*P4``"X#````````X`0```P#``""!```@`(`````
M``"4`@``G`4`````````````````````````````8P$``*$!``!4!```>08`
M`!X#``"]`P``(00``%0```````````````````#O`@``T04``'8```#,`P``
M_P4``.8````_!0```````.8#````````P@,`````````````0@4```````"#
M`@``^0,```````!<`@``20(``-@%````````F`8```````")`P``B````&X$
M``!?`@``*P$``!<!``#&`P``SP4``&H"``"O`P```````#4```#%!```&0``
M`,4```!4!0``H`4````````%`0``<``````````H`P``>04``,T%````````
M+P$``.<"```Q`P``[P```$<#``!5````=0$``/8$````("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E
M8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E
M<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X
M:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`
M)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@
M)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D
M<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H
M;W=E<G,`04TO4$T`05!)($E$`$%B;W5T+BXN`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D
M`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O
M=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O
M=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E
M<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U
M<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@
M=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E
M<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E
M9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET
M:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M
M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I
M;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&P`
M06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES
M<VEO;G,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS
M=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO
M;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L
M>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O
M=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S
M(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N
M:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-I:2!!<G0`07-I82]086-I
M9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S
M=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T
M;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL
M960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL
M960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H
M96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L
M92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A9"!K97)B97)O
M<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A
M:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O
M<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F5L
M87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T
M:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD
M+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&EV:6$`0F]O:VUA<FMS
M`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W5V970@
M27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`
M0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD
M;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@
M;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I
M;F%T:6]N(&%R92!T:&4@<V%M92X`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T(&UO
M=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A;FYO="!W<FET92!T
M;R!F:6QE("(E<R(`0V%P92!697)D90!#87)R:65R`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&QP:&]N90!#
M96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`
M0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T
M86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#
M:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&EL90!#
M:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R(%%U97)Y`$-L96%R(&]U="!U
M<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,
M871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO
M<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;VUB:6$`0V]L
M;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L=6UN('1I=&QE
M<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N
M($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N
M9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E
M("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C
M=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT
M:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D@9F%I;&5D.B`E<P!#;W-T
M($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($94
M4#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M
M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG
M+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E
M<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@
M;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@
M(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A
M=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@
M=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@
M;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U
M;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN
M9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT
M`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;F5W(&]N90!#<F5A
M=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R
M9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N
M="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!5<V5R<P!#=7)R96YT
M(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-Y<')U<P!#>7)I;&QI8R`H2T])
M."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E
M($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y
M`$1E8V5M8F5R`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT
M:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'
M<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S
M=6(@9F]L9&5R<P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N
M`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$
M97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A
M=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES
M('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T
M:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D9')E<W,`16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T
M:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S
M86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@
M:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T
M97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A
M<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE
M(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R
M;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R
M;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG
M("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!E
M8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1E10('5P;&]A9"!O9B!S
M971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D
M('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@
M<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R
M>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO
M=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@
M9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT
M.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T
M:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&
M:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R
M871I;P!&;&EP`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]O9`!&
M;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U
M;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&
M<@!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1V%B;VX`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`
M1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A
M<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O;V=L92!-87!S`$=O
M;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM
M-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O
M=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S
M:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A4
M34P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M
M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M
M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE($%D9')E<W,`2&]M92!$
M:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P
M;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E
M<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S
M`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!
M4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U
M;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D
M($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`26-E;&%N9`!)
M8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I
M='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!)
M;6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL
M86)L92X`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA
M:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P
M87-S=V]R9#H`26YS97)T(&UE<W-A9V5S`$EN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS=69F:6-I96YT
M(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS
M=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!)
M;G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N
M`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@
M<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O
M=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@
M;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D
M92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<V]L871E9"!4+5-T;W)M
M<P!)<W)A96P`27-S=65R`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*
M87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE
M`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+
M97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y
M<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N
M("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA;F=U86=E`$QA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W
M;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO
M9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE
M=F5R`$QA='9I80!,87<`3&5B86YO;@!,969T(&AE861E<@!,969T('9A;'5E
M<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY
M80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H
M="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E
M<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N
M;W<@4VAO=V5R`$QI;FL`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K
M:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A
M<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E
M`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M
M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G
M(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I
M;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I
M;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,=7AE;6)O=7)G`$U-`$U/
M5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`
M36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC
M(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L
M86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD
M<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I
M=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X
M8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-
M87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE
M;G4@;6]D93H`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V
M97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@
M5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N
M`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T
M(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:6UE(%1Y<&4`36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI
M;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R
M`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1U;'5S`$UO;&1O=F$L
M(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-
M;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-
M;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7
M:6YD>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I
M9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I
M<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I
M;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$
M;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA
M;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE
M='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!5
M4DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC
M871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K
M`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE
M=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R
M9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R
M9',@9&]N)W0@;6%T8V@N`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0
M:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@
M9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA
M=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N
M`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O
M('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@
M9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@
M<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE
M9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO
M(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO('%U;W1A('-E="X`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@
M<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;W)D
M:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI
M<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F
M=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E
M9"X`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O
M(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.
M=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/
M8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9I8V4`3VQD
M(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S
M<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U
M;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`
M3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9V%N
M:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N
M<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ
M36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP
M=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN
M`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-
M(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE
M;&P`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@
M0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M`%!A<W1E`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D
M96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U
M`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E
M<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L
M:71I8W,`4&]L;',`4&]R='5G86P`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R
M90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`
M4')E=FEO=7,@;W!T:6]N<P!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0
M=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E
M<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`475E<GD`475O=&$`4E-!
M(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I
M;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!2
M86EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE
M<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2969R97-H
M`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A
M;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M
M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!C;VQU;6X`4F5M;W9E
M('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!2
M97-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S
M`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO
M;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,`4FED9&QE<P!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O;&4`4F]M
M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2=6X`
M4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI
M8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!3
M44P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`
M4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T
M<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U
M96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UO80!3
M86X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O
M=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V
M92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!0
M2%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E
M`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@
M9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R
M`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@
M86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J
M96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E
M9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD
M('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M
M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L
M96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R
M`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@
M>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@
M<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S
M`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E
M(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO
M=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('5P;&]A9`!3:&]W97)S
M`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@
M=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I
M>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N
M;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO
M=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E
M;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@
M069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(
M96UI<W!H97)E`%-P86-E<@!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T
M87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R
M;6%T`%-T<F5E="!!9&1R97-S`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E
M<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U
M<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6-C97-S`%-U8V-E<W-F
M=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D
M("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5D86X`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O
M4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P<&]R=`!3=7)I
M;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD
M`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B
M;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5%-6(&9I
M;&4`5&%B;&4@4V5T`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487-K
M<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E
M<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S
M+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M
M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&@`5&AA:6QA
M;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI
M<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U3
M4"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I
M;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B
M(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM
M=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED
M(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R
M>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA
M8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D
M(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@
M;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O
M8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES
M=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S
M(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I
M;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F
M:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N
M`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4
M:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E
M<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A
M="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W
M:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4
M:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T
M`%1I;64@<V5L96-T:6]N`%1I=&QE`%1O`%1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V\`5&]K96QA=0!4
M;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@
M=&AE(&QA<W0@;6EN=71E<RX`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4
M;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@
M`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@
M9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!T<FEG9V5R(&9R
M964O8G5S>2!U<&1A=&4@9F]R("5S`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL
M960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1O
M($-H86YG97,`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A
M=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;F%M960`56YS
M=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S
M97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO
M860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E
M<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R
M;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L
M90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO
M;B!#;VYT<F]L`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#
M24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL
M:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).
M`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!7
M24X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T
M:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R
M+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)
M4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S
M:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED
M=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:6MI`%=I;F0`
M5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7
M:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@
M)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A
M(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV
M,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`
M665S`%EE<RP@22!!9W)E90!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T
M92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A
M=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E
M<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG
M('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U
M(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG
M;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R
M97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H
M96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@
M0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I
M;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG
M960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO
M=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S
M<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S
M;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M(:61E(%%U;W1E9"!497AT
M70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]#3$D`
M7T1A=&%4<F5E`%]'<F]U<',`7TAE;'``7TQO9R!I;@!?3&]G(&]U=`!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U-E='5P`%]5<V5R<P!A9&1R97-S(&)O;VL`
M861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M
M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I
M=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E
M9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N
M`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L
M('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@:6UP;&5M96YT960`;F]T
M('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<FUI<W-I;VX@9&5N:65D`')E
M;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL
M86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S
M=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R
M90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`
M=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J
M96-T+4ED+59E<G-I;VXZ("X*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#<M,C4@
M,3$Z,S`K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`T+3,P(#$P.C,R
M*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!D=6-K0&]B86QA+FYE=`I,86YG=6%G
M92U496%M.B!S;%]322`\9'5C:T!O8F%L82YN970^"DU)344M5F5R<VEO;CH@
M,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UU=&8M.`I#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*'!R960@)7,@9&YE
M=FDI`"`H1&]S=&]P;F$@=&EP:V$@)7,I`"`H=B`E<R!D;F5H*0`H9&%N97,I
M`$IU=')I(``H=L2-97)A:BD`(&]B(``B)7,B(&YI(&EM96YI:P`B)7,B(&IE
M(&YE=F5L:F%V;F$@:7IB:7)A`"(E<R(@;F4@>F%Z;F%M('8@2&]R9&]V96T@
M<F5G:7-T<G4@`"<E<R<@;F4@;F%J9&5M(&1R979E<V$@>F$@:7IR:7,N`"<E
M<R<@:F4@8FEL(&1O9&%N('-K=7!I;G-K96UU('-I<W1E;74`)R5S)R!J92!B
M:6P@9&]D86X@:R!D;W!U<W1N96UU('-I<W1E;74N`"<E<R<@;FD@=7-T=F%R
M:F5N.B`E<R``57!O<F%B;&IE;FEH("4N,F9-0B!O9"`E+C)F34(@9&]V;VQJ
M96YI:"`H)2XR9B4E*0`E9"`E<R!I;B`E<P#%H&4@)60@9&YI(&1O('!O=&5K
M82!G97-L80`E9"UD;F5V;F$@;F%P;W9E9``E<R#B@),@0F]D:71E('!O>F]R
M;FD`)7,@3V1T:7,`)7,@2T(`)7,@5GID<L6^979A;&YA(&1E;&$@+2!0;W1R
M9&ET978`)7,@("`@("``)7,@<')I:F%V80`E<R!0;V=O:FD`)7,@Q;YE(&]B
M<W1A:F$N`"5S(&]B("5S("5S`"5S(&IE('!R:7!R879L:F5N(&YA(&EZ=F%J
M86YJ92!V>F1RQ;YE=F%L;FEH(&]P97)A8VEJ+"!P<F5V97)I('-P;V1A:BY0
M<F5V97)I(&YA8FER86QN:6L@>F$@=G-E(&]P97)A8VEJ92P@:VD@8FD@:FEH
M(')A9"!O<')A=FEL('-E9&%J+@!0;W1R96)U:F5M("5S(``E<R!M:6YU=``E
M<R!N92!N86ID96T`)7,@;V(@)7,@;V0@)7,`26UE;FEK("5S`$MO;&5D87(@
M)7,`0F5L9<6^:V$@)7,`)7,@3W!R879I;&$`)7,Z("5S`"5S.B!T;R!S<&]R
M;\2-:6QO(&UO9V_$C64@;FD@;V0@<&_%H6EL:F%T96QJ82P@:V%T97)I('!R
M879I(&1A(&IE+B!087II=&4@<V4@:V%T97)I:&MO;&D@<&]V97IA=B!V('-P
M;W)OQ(UI;'4@86QI('!O9&%J86YJ=2!K871E<FEH(&MO;&D@;W-E8FYI:"!I
M;F9O<FUA8VEJ(&YA('1A(&YA<VQO=BX`+"!G;W-T:6T@`"P@9V]S=&EM("5S
M("5S`"P@<W!R96UE;FQJ:79K82!O9"`E<R!D;R`E<P`M+2!I>F)E<FD@+2T`
M,3(@=7(@9F]R;6%T`#(T('5R(&9O<FUA=``R-"!U<@!0<F5JQ:%N:F$@;6_%
MOFYO<W0`6F$@=&$@8FQO:R!J92!P;W1R96)N82!P;W9E>F%V82!N82!P;V1A
M=&MO=FYI('-T<F7%OFYI:P!0;VIA=FEL82!S92!J92!H=61A(&YA<&%K82X`
M6F$@:V]D:7)A=&D@<W!O<F_$C6EL;R!P;W1R96)U:F5M(&IA=FYI(%!'4"!K
M;&IUQ(TN`$IA=FYI(%!'4"!K;&IUQ(T@:F4@<&]T<F5B96X@>F$@;V1K;&5P
M86YJ92!S<&]R;\2-:6QA+@!*879N:2!01U`@:VQJ=<2-+"!Z87-E8FYI(%!'
M4"!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@;V1K;&5P86YJ92!S
M<&]R;\2-:6QA+@!*879N:2!01U`@:VQJ=<2-+"!Z87-E8FYI(%!'4"!K;&IU
MQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@<&]D<&ES('-P;W)OQ(UI;&$N
M`$IA=FYI(%,O34E-12!K;&IUQ(TL('IA<V5B;FD@4R]-24U%(&ML:G7$C2!I
M;B!G97-L;R!S;R!P;W1R96)N:2!Z82!P;V1P:7,@<W!O<F_$C6EL82X`2F%V
M;FD@4R]-24U%(&ML:G7$C2P@>F%S96)N:2!3+TU)344@:VQJ=<2-(&EN(&=E
M<VQO('-O('!O=')E8FYI('IA('!O9'!I<R!S<&]R;\2-:6QA+@`@2F%V;FD@
M4TU)344@:VQJ=64@:F4@<&]T<F5B96X@>F$@;V1K;&5P86YJ92!S<&]R;\2-
M:6QA(`!/8FQAQ(UN;P!*=71R86YJ:2!286AE;"!D9<6^`$IU=')A;FII(&1E
MQ;X`2G5T<F%N:FD@;F%L:78`2G5T<F%N:FD@<VYEQ;YN:2!M971EQ;X`04TO
M4$T`05!)($E$`$]P:7,N+BX`4')E<&]V961A;B!D;W-T;W`@>F$@=7-T=F%R
M:F%N:F4@;6%P92!61E,N(`!0<F5P;W9E9&%N(&1O<W1O<"!Z82!U<W1V87)J
M86YJ92!D871O=&5K92!61E,N`%9AQ:%I('!O9&%T:VD`4&]T<F1I(&=E<VQO
M`$EZ=F%J86T`27IV86IA;0!$;V1A:@!$;V1A:B!S:W5P:6YO(&]T<F]K`$1O
M9&%J(&1O=F]L:F5N:F$@;W1R;VMA`$1E9&%J('-E;3H`1&]D86H@;F]V;R!S
M:W5P:6YO`$1O9&%J(&YO=F$@9&]V;VQJ96YJ80!$;V1A:B!S:W5P:6YO(&]T
M<F]K("(E<R(`1&]D86H@9&]V;VQJ96YJ92!O=')O:V$@(B5S(@!$;V1A:B!N
M;W9E9V$@=7!O<F%B;FEK83H`1&]D86H@<W1O;'!E8P!$;V1A:B!N;W9E(,2-
M;&%N90!$;V1A:B!P87(`1&]D86H@)7,@365N=2!V($UO>FEL;&$@4VED96)A
M<@!$;V1A:B!V(&EM96YI:SH`1&]D86H@=B!M;VH@:6UE;FEK.@!$;V1A:B!U
M<&]R86)N:6MA`"!$;V1A;"`G)7,G('-I<W1E;74L('9E;F1A<B!B;R!N96UO
M9V_$C64@9&]D86IA;FIE(&1O9&%T;FEH('9P:7-N:6@@:6YF;W)M86-I:CH@
M)7,N`$1O9&%N("<E<R<@<VES=&5M=2X@4V5D86H@<V4@;&%H:V\@<')I:F%V
M:71E+@!$;V1A:F%N:F4@=7!O<F%B;FEK;W8@:F4@;VYE;6]G;\2-96YO+@!.
M87-L;W8`26UE;FEK`%5R961I(&1O=F]L:F5N:F$@>F$@;W-T86QE('5P;W)A
M8FYI:V4`57!R879L:F%N:F4`4F5K;&%M90!!9FAA;FES=&%N`$%L8F%N:6IA
M`$%LQ;YI<FEJ80!/>FER;VUA`%9S90!6<VD@;W9E<FIE;FD@=7!O<F%B;FEK
M:0!6<V4@<VMU<&EN90!6<V$@1&]V;VQJ96YJ80!$;W9O;&D@;6YO9V]K<F%T
M;F4@;F%S;&]V90!$;W9O;&D@;F%S=&%V:71V92`@`,."Q;UE(&]B<W1A:F$`
M3F%D;VUE<W1N;R!)35-0('5P;W)A8FYIQ:%K;R!I;64`3F%D;VUE<W1N;R!)
M35-0(&=E<VQO`$YA9&]M97-T;F\@24U34"!U<&]R86)N:<6A:V\@:6UE`$YA
M9&]M97-T;FD@96QE:W1R;VYS:VD@;F%S;&]V`$YA9&]M97-T;FD@=GIO<F-I
M`"!!;65R:<6A:V$@4V%M;V$@`$YA=F5D96YA(&IE(&)I;&$@;F5Z86MO;FET
M82!V<F5D;F]S="X`<&]J879I;&$@<V4@:F4@;F%P86MA`$%N9&]R80!!;F=O
M;&$`06YG=6EL;&$`06YO;FEM96X@4')O>'D`3V1G;W9O<@!!;G1A<FMT:6-A
M`$%N=&EG=6$@:6X@0F%R8G5D80!!<&QI:V%C:6IA`%-E>FYA;2!A<&QI:V%C
M:6H`07!L:6MA8VEJ82!J92!P<FEP<F%V;&IE;F$`4')I:F%V:2!O=')O:V]V
M92!D96QN:6-E(`!0;W1R9&D`07!R:6P`07)A8G-K:2`H5VEN9&]W<RTQ,C4V
M*0!696QI:V]S="!D871O=&5K92!!<FAI=B``26UE($%R:&EV80!3=&4@<')E
M<')IQ(UA;FDL(&1A(,6^96QI=&4@<')E:VQI8V%T:2!Z86AT979O('IA('!R
M:6IA=F\@>F$@)7,@/R``4W1E('!R97!R:<2-86YI+"!D82#%OF5L:71E(&EZ
M8G)I<V%T:2`G)7,G(&EN(&]S=&%L92!P;V1S:W5P:6YE/P!!<F=E;G1I;F$`
M07)M96YI:F$`07)M96YS:VD@*$%235-#24DM."D`56UE=&YO<W0`07)U8F$`
M56UE=&YO<W1I(,2-<FL`07II82]086-I9FG%H6ME(')E9VEJ90!6<')AQ:%A
M:B!Z82!P;W1R9&ET978@<')E9"!I>G9A:F%N:F5M('9Z9'+%OF5V86YJ80!$
M;V1E;&IE;F4@:V]L;VYE`%!O<VMU<R!I>F)R:7-A(&YE;V)S=&]J9<2-92!S
M:W5P:6YE+@!0;W-K=7,@:7IB<FES82!N96]B<W1O:F7$C65G82!D;W9O;&IE
M;FIA+@!0;W-K=7,@=7)E9&ET=F4@;F5O8G-T;VIEQ(UE9V$@9&]V;VQJ96YJ
M82X`4&]S:W5S('5R961I='9E(&YE;V)S=&]J9<2-92!D96QN:6-E+@!,87-T
M;F]S=&D`079G=7-T`$%V<W1R86QI:F$`079S=')I:F$`($%U=&A?8WER=7,Z
M(%IA:'1E=F%N;R!I;6%P(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X`075T:%]C
M>7)U<SH@0F%C:V5N9"!N:6UA('IA:'1E=F%N:6@@>FUOQ;YN;W-T:2X`075T
M:%]C>7)U<SH@6F%H=&5V86YO(&EM87`@Q:%I<FET978@;FES96T@;F'%H65L
M+@!!=71H7V9T<#H@6F%H=&5V86YO($944"#%H6ER:71E=B!N:7-E;2!N8<6A
M96PN($EZ<&]L;FD@4$A0('H@+6]N96UO9V_$C65N;RT@9G1P('IA;65N:F%V
M;RX@`$%U=&A?:6UA<&AT979A;F\@24U!4&ET978@;FES96T@;F'%H65L+@!!
M=71H7VMR8C4Z(%IA:'1E=F%N;R!K<F(U(,6A:7)I=&5V(&YI<V5M(&YAQ:%E
M;"X`075T:%]L9&%P.B!.:2!M;\6^;F\@9&]D86IA;FIE('5P;W)A8FYI:V]V
M('8@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($YI(&UOQ;YN;R!O9'-T
M<F%N:F5V86YJ92!U<&]R86)N:6MO=B!V($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!:86AT979A;F\@3$1!4"#%H6ER:71E=B!N:7-E;2!N8<6A96PN
M`$%U=&A?;&1A<#H@3F4@;6]R96T@9&]D871I('5P;W)A8FYI:V$@)7,N(%-P
M;W)OQ(UI;&\@<W1R9<6^;FEK83H@`$%U=&A?;&1A<#H@3F4@;6]R96T@;V1S
M=')A;FET:2!U<&]R86)N:6MA("5S`$%U=&A?;&1A<#H@3F4@;6]R96T@;F%D
M9W)A9&ET:2!U<&]R86)N:6MA("5S(`!!=71H7VQD87`Z(&YE(&UO<F5M(&YA
M9&=R86IE=F%T:2!U<&]R86)N:6MO=B!V($%C=&EV92!$:7)E<W1O<GDN`$%U
M=&A?;6-A;#H@6F%H=&5V86YO($U#04P@Q:%I<FET978@;FES96T@;F'%H65L
M+@!!=71H7W-M8F%U=&@Z(%IA:'1E=F%N96=A('-M8F%U=&@@>F$@Q:%I<FET
M978@;FES96T@;F'%H65L+@!/=F5R:F%N:F4@>F$@1E10('-T<F7%OFYI:R!N
M:2!U<W!E;&\N`$]V97)J86YJ92!N:2!U<W!E;&\N`$]V97)J86YJ92!N:2!U
M<W!E;&\N("5S`$]V97)J86YJ92!J92!Z879R;FEL(%)!1$E54R!S=')EQ;YN
M:6LN`$]V97)J86YJ92!Z82!&5%`@<W1R9<6^;FEK(&YI('5S<&5L;RX`3W9E
M<FIA;FIE('IA(%--0B!S=')EQ;YN:6L@;FD@=7-P96QO+@!0;VQJ82!N82!R
M87IP;VQA9V\Z`$%Z97)B86IDQ;YA;B``3F5U;6YI(&EZ9V]V;W)I`$YA<&'$
MC6YO(&ME<F)E<F]S(&=E<VQO+@!.87!AQ(UN;R!K97)B97)O<R!U<&]R86)N
M:<6A:V\@:6UE+@!"86AA;6D`0F%H<F%I;@!"86QT:6L@*$E33RTX.#4Y+3$S
M*0!"86YG;&%D9<6A`$)A<F)A9&]S`$YI<V5M(&YAQ:%E;"!O<VYO=FYE9V$@
M9W)A9FG$C6YE9V$@:6UE;FEK82`B)7,B+@!"96QO<G5S:6IA`$)E;&=I:F$`
M0F5L:7IE`$)E;FEN`$)E<FUU9'-K:2!O=&]K:0!"=71A;@!2;VIS=&YI(&1A
M;@!.:7-E;2!N8<6A96P@8FQO:V$@(B5S(BP@87!L:6MA8VEJ92`B)7,B("X`
M6F%U<W1A=FD@3F%S=&%V:71V90!:875S=&%V:2!4:7``0F]L:79I:F$`4')I
M;&IU8FQJ96YE`$)O<VYA(&EN($AE<F-E9V]V:6YA`$]B;VII`$)O8W9A;F$`
M0F]U=F5T;W9O(&]T;\2-:F4`0G)A>FEL:6IA`"!"<FET86YS:V\@;WIE;6QJ
M92!);F1I:G-K96=A(&]C96%N82``0G)U;F5I`$)O;&=A<FEJ80!"=7)K:6YA
M($9A<V\`0G5R=6YD:0!-4T<`0U)#`"!#4DP@<F%Z9&5L:71V96YE('1OQ(UK
M92``3F%S=&%V;&IA;FIE('!R961P;VUN:6QN:6MA(&YI(&1O:V]NQ(UA;F\N
M`$MO;&5D87(`6F)R:<6A:0!+86UB;V3%OF$`2V%M97)U;@!.92!M;W)E:F\@
M=7!R879L:F%T:2!Z=6YA;FII('5P<F%V;&IA;&-I`$YE(&UO<F5M('9Z<&]S
M=&%V:71I('!O=F5Z879E('H@24U!4"!S=')EQ;YN:6MO;3H@)7,@`$YI(&UO
M9V_$C64@;V1P<F5T:2`B)7,B(&1A=&]T96ME+@!+86YA9&$`6F)R:<6A:0!P
M;W)OQ(UI;&\@;R!T9<6^879A:"!Z(&)R:7-A;FIE;0!.92!M;W)E;2!K;W!I
M<F%T:2!D871O=&5K("AE*2`M('9I<B!I;B!C:6QJ82!S=&$@:7-T82X`3F4@
M;6]R96T@:7IB<FES871I(&1A=&]T96ME("(E<R(N`$YE(&YA:F1E;2!Z8<2-
M87-N92!D871O=&5K+@!.92!M;W)E;2!P<F5M86MN:71I(&1A=&]T96L@*&4I
M("T@8VEL:B!J92!Z;F]T<F%J('9I<F$N`$YE(&UO<F5M(&YA9&%L:F5V871I
M(&)R97H@<&%R86UE=')O=B`G8VEL:FYE(&1A=&]T96ME)RX`(B5S(B!);65N
M:6MA(&YE(&UO<F5M('IB<FES871I+@!.92!M;W)E;2!O9'-T<F%N:71I.R!O
M8G-T86IA("5D('!O9'9E;&H`3F4@;6]R96T@<&]N;W9N;R!U<F5D:71I+"#%
MH71E=FEL;R!D86YI:"!V;F]S;W8@<V4@;F4@<VML861A(',@Q:%T979I;&]M
M("!S:')A;FIE;FEH+@!.92!M;W)E;2!A=G1O;6%T<VMO('!O;F%S=&%V:71I
M(&=E<VQA+"!O8G)N:71E('-E(&YA('-K<F)N:6MA`$YE(&UO<F5M('!R975S
M;65R:71I('-P;W)OQ(UI;&$@;F%V961E;F5M=2#%H71E=FEL=2X`0V%N;F]T
M('=R:71E('1O(&9I;&4@(B5S(@!+87!V97)D<VMI(&]T;VMI`%!R:6YAQ:%A
M;&5C`$MA=&5G;W)I:F4@:6X@>FYA;6ME`$MA>6UA;G-K:2!O=&]K:0!-;V)I
M;&YI('1E;&5F;VX`36]B:6QN:2!T96QE9F]N`$ME;'1S:VD@*$E33RTX.#4Y
M+3$T*0!#96YT<F%L;F\@069R:<6A:V$@4F5P=6)L:6MA`%-R961N:F5E=G)O
M<'-K:2`H25-/+3@X-3DM,BD`4&]D<F]B;F]S=&D@<&]T<F1I;&$`3&%S=&YI
M:R!P;W1R9&EL80!0<F%V:6QA('!O=')D:6QA`$5A9`!3<')E;65N:0!S<')E
M;65N:71E('9AQ:%E(&=E<VQO`%-P<F5M96YI=&4@:6UE(&EN(&YA<VQO=B!V
M8<6A96=A(&5L96MT<F]N<VME9V$@;F%S;&]V82P@:VD@9V$@=FED:6IO<')E
M:F5M;FEK:2!O8B!B<F%N:G4@:6X@;V1G;W9A<FIA;FIU(&YA('9AQ:%O('!O
MQ:%T;RX`5B!T<F5N=71N:2!K;VYF:6=U<F%C:6IE(&YE(&UO<F5T92!S<')E
M;65N:71I(&=E<VQA+B!+;VYT86MT:7)A:G1E('9AQ:%E9V$@<VMR8FYI:V$N
M`,2-:6QE`$MI=&%J<VMA`%!O96YO<W1A=FQJ96YA(&MI=&%JQ:'$C6EN82A'
M0C(S,3(I`%1R861I8VEO;F%L;F$@:VET86K%H<2-:6YA("A":6<U*0!)>F)E
M<FD@87!L:6MA8VEJ;SH`27IB97)I(&=E<VQO`$EZ8F5R:2!U<&]R86)N:<6A
M:V\@:6UE`$MA:V\@<')I:V%Z871I(&1A='5M93H`0F_%OFG$C6YI(&]T;VMI
M`$YI<V5M(&YAQ:%E;"!D969I;FEC:6IE('9R<W1E('IA("5S+@!*87-N;P!0
M<F7$C6ES=&D@<&]I>G9E9&)E`$]D<W1R86YI('IU;F%N:F5G82!U<&]R86)N
M:6MA.B`E<R``3V1S=')A;FD@=7!O<F%B;FEK80!)>F)R:<6A:2!P;V1A=&5K
M('5P;W)A8FYI:V$`:7IB<FG%H6D@<&]T96T`2VQI:VYI('IA(&YA9&%L:F5V
M86YJ92``0VQI8VMA=&5L;"!P<F]T;VT@2%144`!:87!R:2!O:VYO`$]B;&%K
M:0!::G5T<F%J($]B;&'$C6YO`$]B;&'$C6YO`$MO:V]S;W9I(&]T;VMI`%ID
M<G7%OFD@<W1R86YS:V\@;VMN;P!+;VQU;6)I:F$`0F%R=F$`27IB:7)A;&5C
M(&)A<G8`($EZ8FER82!"87)V92``3F%S;&]V('-T;VQP:6-A`%-T<FEP:0!5
M:V%Z`%5K87IN82!L=7!I;F$`2V]M96YT87(`4VMU<&YO(&EM90!+;VUO<FD@
M`$1R=<6^8F$`4F'$C75N86QN:6MI`$YA<W1A=FET978`3F%S=&%V:71V90!2
M87IL:6ME(&YA<W1A=FET=F4`3F%S=&%V:71V92!Z82!S:6YK<F]N:7IA8VEJ
M86\@9&QA;L2-;FEK;W8`3F%S=&%V:71V92!P;W1R96)U:F5J;R!AQ;YU<FER
M86YJ90!.87-T879I("5S`%!O=')D:2!G97-L;P!+;VYG;P!+;VYG;RP@1&5M
M;VMR871IQ(UN82!R97!U8FQI:V$`4&]V97IA=F$@;FD@=7-P96QA+@!0;W9E
M>F%V82!N:2!U<W!E;&$Z`%IA=G)N:F5N82!P;W9E>F%V82!Z(&IA=FYI;2!K
M;&IUQ(UN:6T@<W1R9<6^;FEK;VTN`%IA=G)N:F5N82!P;W9E>F%V82!Z(&IA
M=FYI;2!K;&IUQ(UN:6T@<W1R9<6^;FEK;VTN(%)A>FQO9SH@)7,@*"5S*0!0
M;W9E>F%V82!S($944"!S=')EQ;YN:6MO;2!N:2!U<W!E;&$N`%-T:6MI`%-T
M:6L@:F4@8FEL('5S<&7%H6YO(&1O9&%N(&L@=F'%H6EM(&YA<VQO=F]M+@!4
M:7`@<W1I:V$@<W1I<VYJ96YE(&1A=&]T96ME.@!6<V5B:6YE(&]D(B5S(@!.
M861A;&IU:@!#;V]K;W9I(&]T;VMI`%!IQ:%K;W1E:P!+;W!I<F%N:F4@;FD@
M=7-P96QO.B`E<P!)1"!S=')OQ:%E:P!+;W-T87)I:V$`(%-L;VYO:V_%H<2-
M96YA(&]B86QA(`!01U`@;F4@;6]R92#%H6EF<FER871I('-P;W)OQ(UI;&$Z
M`$YI(&UO9V]E(%!'4"!P;V1P:7,@<W!O<F]E:6QA+@!.:2!M;V=OQ(UE(%,O
M34E-12#%H6EF<FER871I('-P;W)OQ(UI;&$N`$YI(&UO9V_$C64@4R]-24U%
M('!O9'!I<R!S<&]R;\2-:6QA+@!.:2!M;V=OQ(UE(&1O9&%T:2!S=&EK;W8N
M("5S+@!0;W9E>F%V82!Z($Q$05`@<W1R9<6^;FEK;VT@;FD@;6]G;\2-82X`
M3FD@;6]G;\2-92!K;VYT<F]L:7)A=&D@/S\_/S\_("5S+@!0;W9E>F%V82!Z
M($Q$05`@<W1R9<6^;FEK;VT@;FD@;6]G;\2-82X`3F4@;6]R96T@=GIP;W-T
M879I=&D@<&]V97IA=F4@<R!S=')EQ;YN:6MO;2`B)7,B('H@=7!O<F%B;R!&
M5%`Z("5S`$YE(&UO<F5M('5S='9A<FET:2!S97IN86UA('IA(&1I<W1R:6)U
M8VEJ;RX@)7,`3FD@;6]G;\2-92!D9<6A:69R:7)A=&D@4$=0('!O9&%T:V]V
M.@!.:2!M;V=OQ(UE(&1EQ:%I9G)I<F%T:2!3+TU)344@<&]D871K92X`3F4@
M;6]R96T@:7IB<FES871I('-T:6MO=BX@)7,`3F4@;6]R96T@:7IB<FES871I
M(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M82X@)7,`3F4@;6]R96T@:7IB<FES
M871I(&YA<W1A=FET=F5N92!AQ;YU<F%C:6IS:V4@<VMR:7!T92`B)7,B`$YI
M(&UO9V_$C64@9&]L;\2-:71I(&5L96MT<F]N<VME9V$@;F%S;&]V82!P<F5J
M96UN:6MA+@!.:2!M;V=OQ(UE(&1O;&_$C6ET:2!C96QO=&YE9V$@:6UE;FEK
M82X`3FD@;6]G;\2-92!D;VQOQ(UI=&D@8V5L;W1N96=A(&1I<W1R:6)U8VEJ
M<VME9V$@<V5Z;F%M82X`3FD@;6]G;\2-92!D;VQOQ(UI=&D@8V5L;W1N96=A
M('-E>FYA;6$@9&ES=')I8G5C:6IS:VEH('-E>FYA;6]V`$YI(&UO9V_$C64@
M;F%L;\6^:71I('-T<F%T96=I:F4@(B5S(BX`3F4@;6]R96T@='9O<FET:2!M
M87!E("(E<R(N`$YI(&UO9V_$C64@9&]B:71I(&IA=FYE9V$@:VQJ=<2-82!O
M9"!K;&IUQ(UN96=A('-T<F7%OFYI:V$N`$YI(&UO9V_$C64@;V1P<F5T:2`B
M)7,B('IA('!I<V%N:F4N`$YI(&UO9V_$C64@;V1P<F5T:2`E<RX`3FD@;6]G
M;\2-92!O9'!R971I(&UO9'5L82!O(&]P<F%V:6QU7W9Z9'+%OF5V86YJ82`E
M<R``3FD@;6]G;\2-92!P<F5B<F%T:2!I;65N:6L@(B5S(BX`3FD@;6]G;\2-
M92!D;W-EQ(UI($Q$05`@<W1R9<6^;FEK82X`3FD@;6]G;\2-92!P<F5B<F%T
M:2`E<RX`3FD@;6_%OFYO('!O;F%S=&%V:71I(&=E<VQA('IA('IA:'1E=F%N
M96=A('5P;W)A8FYI:V$N($YE:V%T97)E(&%L:2!V<V5P;V1R;V)N;W-T:2!N
M:7-O('!R879I;&YE+B!0;W-K=7-I=&4@>FYO=F$@86QI(&MO;G1A:W1I<F%J
M=&4@=F'%H65G875P<F%V:71E;&IA+"#$C64@<&]T<F5B=6IE=&4@;F%D86QJ
M;FIO('!O;6_$C2X`3FD@=7-P96QO('9Z<&]S=&%V:71I.B`E<R``3FD@=7-P
M96QO('9Z<&]S=&%V:71I(&EM96YI:V$Z("5S(`!.:2!U<W!E;&\@=GIP;W-T
M879I=&D@9&ES=')I8G5C:6IS:V5G82!S97IN86UA.B`E<R``3FD@=7-P96QO
M('9Z<&]S=&%V:71I(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M83H@)7,@`$YI
M('5S<&5L;R!V>G!O<W1A=FET:3H@)7,@`%IA:'1E=F%N:2`G)7,G(&YI('!O
M9')O8FYO(&]B;&EK;W9A;B!V("5S('!O9&]B:2X`3F4@;6]R96T@:7IB<FES
M871I(&UA<&4@(B5S(BX`)7,@:V]N9FEG=7)A8VEJ92!N:2!M;V=OQ(UE('-H
M<F%N:71I+@!+;VYF:6=U<F%C:6IE('9A<FYO<W1N92!K;W!I:F4@;FD@;6]G
M;\2-92!S:')A;FET:2X`2V]N9FEG=7)A8VEJ92!V87)N;W-T;F4@:V]P:6IE
M(&YI(&UO9V_$C64@<VAR86YI=&DZ("5S`$YE(&UO<F5M('-H<F%N:71I(&YA
M<W1A=FET=F5N92!AQ;YU<F%C:6IS:V4@<VMR:7!T92!N83H@(B5S(BX`3F4@
M;6]R96T@<VAR86YI=&D@:V]N9FEG=7)A8VEJ<VMO(&1A=&]T96MO("5S+"!V
M87)N;W-T;F4@:V]P:6IE+@!.92!M;W)E;2!S:')A;FET:2`@:V]N9FEG=7)A
M8VEJ<VME(&1A=&]T96ME("5S+B!,86AK;R!U<&]R86)I=&4@86QI(&5N;R!O
M9"!O<&-I:B!Z82!S:')A;FET:2!K;V1O('IA9&%J(&YA("5S(&%L:2!R;\2-
M;F\@:V]P:7)A=&4@<W!O9&YJ;R!K;V1O(&YA("5S+@!.:2!M;V=OQ(UE(&ES
M:V%N:F4@3$1!4"!S=')EQ;YN:6MA+@!.:2!M;V=OQ(UE(&]D<W1R86YI=&D@
M<&]V97IA=F4@>B`B)7,B+@!.:2!M;V=OQ(UE(&'%OG5R:7)A=&D@<W1I:RX@
M)7,N`$YI(&UO9V_$C64@8<6^=7)I<F%T:2!D:7-T<FEB=6-I:G-K:2!S97IN
M86TN("5S`$YI(&UO9V_$C64@;F%P:7-A=&D@:V]N9FEG=7)A8VEJ92!Z82`B
M)7,B.B`E<P!.92!N86ID96T@36]Z:6QL82!3:61E8F%R+B!0<F5V97)I(&%L
M:2!J92!O9'!R="X`(B5S(B!U<&]R86)N:6MU(&YE(&UO<F5M(&1O9&5L:71I
M('-L961EQ(UI:"!P<F%V:6,@>F$@;6%P;R`B)7,B.B`E<P!0<F7%H71E=&\@
M8F5S961I;&\@`$1RQ;YA=F$`5&7$C6%J:0!5<W1V87)I`%5S='9A<FD@;F]V
M;P!5<W1V87)I('!O9&UA<&4`079T;W(@9&]V;VQJ96YJ`,6@=&5V:6QK82!K
M<F5D:71N92!K87)T:6-E(`!(<G9AQ:%K80!+=6)A`%-E9&%N:F4@-"!R87IV
M;VIN92!S=&]P;FIE`%-E9&%N:F4@<V5J90!3961A;FII(,2-87,`4V5D86YJ
M:2!U<&]R86)N:6MI`%-E9&%N:F4@=G)E;64`4V5D86YJ92!S=&%N:F4Z`$YA
M<W1A=FET92!A:W1I=FYO<W1I+"!K:2!S92!B;V1O(&EZ=G+%H6EL92!O8B!P
M<FEJ879I(&YA("5S+@!#:7!E<@!#:7)I;&EC82A+3TDX+5(I`$-I<FEL:6-A
M("A7:6YD;W=S+3$R-3$I`$-I<FEL:6-A+U5K<F%J:6YS:VD@*$M/23@M52D`
MQ(UEQ:%K82!R97!U8FQI:V$`1$0`1$Y3("AP;V=L96H@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0!$;F5V;F\`4')E9VQE9&]V86QN:6L@9')E=F5S;F4@<W1R=6MT
M=7)E`%!O:7IV961B82!B87IE('!O9&%T:V]V`$1A='5M`$1A='5M('!R96IE
M;6$`27IB:7)A(&1A='5M80!$86X`1&5C96UB97(`4')I=GIE=&\`4')I=GIE
M=&$@0F%R=F$`4')I=GIE=&$@:61E;G1I=&5T80!0<FEV>F5T82!L=7!I;F$`
M3W!R961E;&ET=F4`6F)R:<6A:0!:8G)IQ:%I('-K=7!I;F\`6F)R:<6A:2!D
M;F5V;FEK`%IB<FG%H6D@9&]V;VQJ96YJ90!)>F)R:<6A:2!I;B!P<F7$C6ES
M=&D@<W!O<F_$C6EL80!)>F)R:<6A:2!O8G-T;VIEQ(UI(&%L=&5R;F%T:79N
M:2!V>F]R96,`27IB<FG%H6D@<W!O<F_$C6EL80!)>F)R:<6A:2!D;W9O;&IE
M;FIA('IA("(E<R(`27IB<FG%H65M(&1O=F]L:F5N:F4@>F$@(B5S(B!I;B!V
M<V$@<&]D9&]V;VQJ96YJ83\`27IB<FG%H6D@:7IB<F%N;R!I9&5N=&ET971O
M`$EZ8G)IQ:%I('!O9"!M87!E`$YE(&UO<F5M(&EZ8G)I<V%T:2!N87-T879I
M='9E;F4@8<6^=7)A8VEJ<VME('-K<FEP=&4@(B5S(BX`Q(QA<R!D;W-T879E
M`$1A;G-K80!/<&G%H6ET92!T9<6^879O`$]P:7,`4&]D<F]B;F]S=&D@*'1U
M9&D@=B!(;W)D;W9I(&QO9R!D871O=&5K:2DZ`%!O9')O8FYO<W1I('-O(&)I
M;&4@<')I:F%V;&IE;F4@>F$@=7!R879L:F%L8V$N`%)A>G9O:@!2;W-IQ:'$
MC64`4F]S:<6AQ(UE('IA('!R96K%H6YJ;R!U<F\Z`%)O<VG%H<2-93H`26UE
M;FEK`%!R:6MAQ;YE;2#$C6%S('!O(#(T('5R;F5M('-I<W1E;74_`$YA<W1A
M=FET=F4@<')I:V%Z;W9A;FIA`%!R:6MAQ;YI('!O9')O8FYO(&YA<&]V960`
M4')I:V'%OFD@;F%P;W9E9"`H5$%&*0!0<FEK8<6^:2!V96QI:V]S=`!/8G9E
M<W1I;&\@;R!D;W-T879L:F5N:2!P;\6A=&D`1,6^:6)U=&D`3F4@>F)R:<6A
M:0!.92!D;W-T;W!A:B!N97!O<W)E9&YO(&1O(&]H<F%N:F%N:F$N<&AP(`!!
M;&D@<')V82!V<G-T82!V<V5B=6IE(&EM96YA('!O;&H_(,2-92!J:6@L('!R
M979E<FD@;F%B:7)A;&YI:SH`1&]M:6YI8V$`1&]M:6YI:V%N<VMA(%)E<'5B
M;&EK80!.:7-T92!R96=I<W1R:7)A;FD_(%)E9VES=')I<F%J=&4@<V4N(`!0
M<F5N97-I("5S`%!R96YE<VET92!G96YE<FER86YO(&MO;F9I9W5R86-I:F\@
M:V]T(%!(4"!S:W)I<'1O+@!0861A:F_$C6D@;65N:0!:9')A=FEL80!%;&5K
M=')O;G-K:2!N87-L;W8`4')E;F]S(&5L96MT<F]N<VMI:"!S<&]R;\2-:6P@
M=B!335,M:F4@>F$@;W!E<F%T97)J92P@:VD@=&\@;VUO9V_$C6%J;RX`15)2
M`$5K=F%D;W(`57)E9&D`57)E9&D@<W1O;'!E8P!5<F5D:2!S:W5P:6YO`%5R
M961I(&1O=F]L:F5N:F4`57)E9&D@9&]V;VQJ96YJ80!5<F5D:2!D;W9O;&IE
M;FIA('IA("5S(`!5<F5D:2!M;\6^;F]S=&D@>F$Z`%5R961I(&1O=F]L:F5N
M:F$@>F$@(B5S(@!5<F5D:2!D;W9O;&IE;FIA('IA("5S`$EZ;V)R8<6^979A
M;FIE`$5G:7!T`%-A;'9A9&]R`$5L96MT<F]N<VMA('!OQ:%T80!%;&5K=')O
M;G-K:2!N87-L;W8`16QE:W1R;VYS:VD@;F%S;&]V('-E(&UO<F$@=6IE;6%T
M:2X`16QE:W1R;VYS:V$@<&_%H71A(',@<&]T<F1I='9I:F\`16UA:6PM4TU3
M(%!R96AO9`!3;67%H6MI`%!R87IE;F\@<W!O<F_$C6EL;RX`4')A>F5N(')E
M>G5L=&%T+@!0<F%Z96X@:7-K86QN:6L`27IK;&]P:6T@=G-T879L:F%N:F4@
M<VQI:R!I>B!&;W1O($=A;&5R:6IE('8@=&5K<W0_`$EZ:VQO<&EM(&UE;FD@
M>B!D97-N:6T@:VQI:V]M/P!+;VYE8R!L971A`%9N97-I=&4@=F%R;F]S=&YO
M('9P<F'%H6%N:F4L(&MI(&)O('!O<W1A=FQJ96YO+"#$C64@8F]S=&4@<&]T
M<F5B;W9A;&EP;VYA<W1A=FET:2!V8<6A92!G97-L;RP@;G!R+B##@N*`GFEM
M92!V8<6A96=A(&QJ=6)L:F5NQ(UK82!J93\Z`%9N97-I=&4@<W!O9&YJ92#$
MC7)K93H`16MV871O<FEA;&YA($=V:6YE:F$`17)I=')E:F$`3F%P86MA`$YA
M<&%K82!P<FD@=7-T=F%R:F%N:G4@<W1O;'!A.B`E<RX`3F%P86MA('!R:2!B
M<FES86YJ=2!P;W9E>F%V92!S:6YH<F]N(&EZ86-I:F4Z("5S`$YA<&%K82!P
M<FD@8G)I<V%N:G4@9&YE=FYI:V$@<VEN:')O;FEZ86-I:F4Z("5S+@!.87!A
M:V$@<')I('!O=F5Z;W9A;FIU.B`E<RX`3F%P86MA('!R:2!AQ;YU<FER86YJ
M=2!G97-L83H@)7,N`$YA<&%K82!Z(&5L96MT<F]N<VMI;2!S<&]R;\2-:6QO
M;2X`3F%P86MA('!R:2!P:7-A;FIU("(E<R(N`$5S=&]N:6IA`$5T:6]P:6IA
M`$5S=&]N:6IA`$5V<F]P80!6<V%K:6@@,34@;6EN=70`5G-A:VD@,B!M:6YU
M=&D`5G-A:VEH(#,P('-E:W5N9`!6<V%K:6@@-2!M:6YU=`!6<V%K82!P<FEJ
M879A`%9S86ME('!O;"!U<F4`5G-A:V\@;6EN=71O`%!R:6UE<B!V<F5D;F]S
M=&DZ`$EZ=F5D:0!0;W9EQ(UA:@!0<FG$C6%K;W9A;B`G*2<`4')IQ(UA:V]V
M86YA(&IE(&)I;&$@8F5S961A(&%L:2!B97-E9&YA('IV97IA('8@;F%V961N
M:6-A:`!$871U;2!Z87!A9&QO<W1I`%IA<W1O<&YI:P!&5%`@;F%L;\6^:71E
M=B!N86UE<W1I='9E+@!.:2!U<W!E;&\@=GIP;W-T879I=&D@<')E9F5R96YC
M92X`4&]V97IA=F$@>B!,1$%0('-T<F7%OFYI:V]M(&YI('5S<&5L82X`4&]V
M97IA=F$@<R!334(@<W1R9<6^;FEK;VT@;FD@=7-P96QA(`!+;W!I<F%N:F4@
M:7H@(B5S(BP@;FD@=7-P96QO+@!+;W!I<F%N:F4@;F$@(B5S(BP@;FD@=7-P
M96QO+@!.:2!U<W!E;&\@=GIP;W-T879I=&D@;F]V;R!305-,('!O=F5Z879O
M+@!.:2!U<W!E;&\@<')E;6%K;FET:2!K.B`E<R``3F5M;V=OQ(UE('!R96)R
M871I.B`E<R``3V1D86QJ;F\`1F%L:VQA;F1S:VD@;W1O:VD`1F5R<VMI(&]T
M;VMI(`!(=61A(&YA<&%K82$`1F%X`$9A>&D`1F5B<G5A<@!0;\2-=71I=&D@
M<V4@:V]T`%!OQ(UU=&ET:2!S92!K;W0Z`$YE:V%J(&YA;&EV;W8`3F5K86H@
M<VYEQ;YN:6@@;65T9<6^978`36%T<FEC82!P;VQJ80!&:6=L970@0T%05$-(
M00!&:6=L970@<&ES879A`$9I9,6^:0!$871O=&5K80#%H'1E=&IE($1A=&]T
M96LZ("5S(&1A=&]T96L`Q:!T971J92!$871O=&5K.B`E<R!D871O=&5K`%5P
M<F%V:71E;&H@9&%T;W1E:P!);64@9&%T;W1E:V4`27IB:7)A(&1A=&]T96ME
M+@!.86QOQ;YI(&1A=&]T96MO`$1O9&%N82!D871O=&5K82!N:2!P;V1P<G1A
M+@!&:6QT<FD`1FEN<VMA`%!R=F$@<&]L;W9I8V$`4')V82#$C65T<G1I;F$`
M4W1A;&YE('9E;&EK;W-T:0!/8G)N:0!-96=L80`E<R!M87!A(&YE(&]B<W1A
M:F$@`$AR86YA`$YA<&]V960@*%1!1BD`1&YE=FD@;F%P;W9E9&DN("A.87!O
M=F5D82!L92!L86AK;R!Z96QO(&1O;&=A*0!3=&4@<&]Z86)I;&D@=F'%H64@
M9V5S;&\_`&]B;&EK90!3<F7$C6$`4W)EQ(UE`%-R9<2-90!3<F7$C64@,@!4
M86)L82!P;V=O=F]R;W8`4')E=7-M97)I=&5V90!&<@!&<F%N8VEJ80!&<F%N
M8VEJ82P@2V]L;VYI86QN82!M971R;W!O;&$`1G)A;F-O<VMA($=V86IA;F$@
M`$9R86YC;W-K82!0;VQI;F5Z:6IA(`!&<F%N8V]S:VD@:G7%OFYI('1E<FET
M;W)I:B``3V0`3V0@`%!O;&X@3W!I<SH`4&]L;F$@;'5N80!0;VQN;R!I;64`
M1V%B;VX`1V%M8FEJ80!5<W1V87)I("5S($YA<W1A=FET=F4`1V5N97)I<F%J
M(&MO9&\`1W)U>FEJ80!.96W$C6EJ80!'86YA`$=I8G)A;'1A<@!$86YO(&EM
M90!3<&QOQ:%N92!-;\6^;F]S=&D`4&]J9&D`1V]O9VQO=F4@;6%P90!)Q:'$
MC6D@>B!';V]G;&]M`$QE<W1V:6-A('-I=FEN92``1W+$C6EJ80!'<L6A:VD@
M*$E33RTX.#4Y+3<I`$=R96YL86YD:6IA`$=R96YA9&$`4VMU<&EN<VMA(&%D
M;6EN:7-T<F%C:6IA`$EM96YA(%-K=7!I;B!N92!S;65J;R!B:71I('!R87IN
M80!!=71H7VQD87`Z($YE(&UO<F5M(&1O9&%T:2!S:W5P:6YE("5S+B!3<&]R
M;\2-:6QO('-T<F7%OFYI:V$Z(`!3:W5P7VQD87`Z($YE(&UO<F5M(&EZ8G)I
M<V%T:2!S:W5P:6YE("5S`%-K=7!?;&1A<#H@3F4@;6]R96T@;F%D9W)A9&ET
M:2!S:W5P:6YE("5S`%-K=7!I;F4`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!$;W9O;&IE;FIA('IA(&=O<W1E`$MN:FEG82!G;W-T;W8`
M1W9I;F5J80!'=FEN96IA+4)I<W-A;P!'=F%J86YA`$A434P`3W9E<FIE;F5G
M82!(5%10($YI<V5M(&YAQ:%E;"X`2&%I=&D`2&%S:"!!;&=O<FET96T`365G
M;&EC80!';&%V80!';&%V90!(96%R9"!O=&]K(&EN($UC1&]N86QD;W9O(&]T
M;\2-:F4`36_$C6YA(&YE=FEH=&$`2&5B<F5J<VMI("A)4T\M.#@U.2TX+4DI
M`%9IQ:%I;F$`4&]M;\2-`%!O;6_$C6QN:6L`4&]L;V)L80!4=6MA:B!J92!Z
M8<2-971E:R!D871O=&5K93H`5FES;VMO`$1O;6]V`%9A=&EK86X`1&]M8<2-
M:2!N87-L;W8`26UE;FEK`$1O;6'$C6D@=&5L969O;@!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($YE=F5L:F%V96X@)7,@6$U,('!O
M9&%T96L@;F%J9&5N('8@<W!O<F_$C6EL=2`E<P!(;W)D92]+;VQA8CH@3F]B
M96YO('-P;W)OQ(UI;&\@<V4@;F4@=6IE;6$@<R!P<F5D;65T;VT@)7,`2&]R
M9&4O2V]L86(Z(%8@<W!O<F_$C6EL=2`E<R!N:2!N86ID96X@;F]B96X@<')E
M9&UE="!T:7!A("5S`$AO<F1E+TMO;&%B.B!5<W!EQ:%N;R!O9'-T<F%N:F5N
M("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%C:6IS:V$@;F%P<F%V82!Z
M86AT979A("=D;VUX;6PG(%!(4"!E:W-T96YZ:6IO`$AO<F1E+TMO;&%B.B!.
M92!M;W)E('5S='9A<FET:2!N;W9O(%A-3"!D<F5V;R!Z82`E<P!(;W)D92]+
M;VQA8CH@3F4@;6]R96T@;V1S=')A;FET:2`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@3F4@;6]R96T@<&]I>G9E9&5T:2!Z82!-24U%($E$('IA(&1E;"!O
M9"!V<G-T92`E<P!(;W)D92]+;VQA8CH@3F4@;6]R96T@<VEN:')O;FEZ:7)A
M=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE(&UO<F5M('-I;FAR;VYI
M>FER871I(&1E;&4Z("5S`$AO<F1E+TMO;&%B.B!.97IN86YA(&1E;&ET978@
M(B5S(@!+;VQI:V\@<&]L:B`H<W1O;'!C978I:F4@=&%M/P!6;&'%OFYO<W0`
M5FQAQ;YN;W-T.B``2'5M;W)I<W1I`$UA9,6^87)S:V$`57-T=F%R:F%N:F4@
M24U!4"!N86)I<F%L;FEK82!N:2!U<W!E;&\Z("5S`$)R:7-A;FIE($E-05`@
M;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<P!5<W1V87)J86YJ92!K=F]T92!)
M34%0(&YA8FER86QN:6MA+"!N:2!U<W!E;&\Z("5S`$E0($YA<VQO=@!)4"!.
M87-L;W8@;FD@;F$@<F%Z<&]L86=O+@!)4"!.87-L;W8@;FD@=B!D;W9O;&IE
M;FD@0TE$4B!S:W5P:6YI+@!:86ML96YJ96X@25`N`$ES;&%N9&EJ80!386UO
M(&EK;VYE`$EK;VYE('IA("5S`$EK;VYE('H@8F5S961I;&]M`$ED96YT:69I
M:V%C:6IS:V\@:6UE.@`E<R!Z82!O9'!R971I('8@;F]V96T@;VMN=2P@Q(UE
M(&YI('!R879I;&YO('!R:6MA>F%N;RX`Q(UE('9I9&ET92!T;R!S<&]R;\2-
M:6QO(&EN('-L:<2-:6-E(&YE+"!P;VUE;FDL(&1A('9AQ:$@8G)S:V%L;FEK
M(&YE(&UO<F4@;V1P<F5T:2!S;&G$C6EC92P@:VD@:F\@Q;YE;&ET92!N86QO
MQ;YI=&DN`$1O9&%J('-L:6MO`%-L:6ME`%9N;W,L($MO<F%K("5D`%9N9<6A
M96YO('!O;&IE.B`E<P!6;F7%H65N82!P;VQJ83H`4&]S<F5D;W9A;B!N97!R
M879I;&5N('5K87HN`$YE<')A=FEL;F\@=7!O<F%B;FG%H6MO(&EM92!I;B]A
M;&D@9V5S;&\N`$YE<')A=FEL;F\@=7!O<F%B;FG%H6MO(&EM92!A;&D@86QT
M97)N871I=F5N(&YA<VQO=BX@4&]S:W5S:71E('IN;W9A(&%L:2!K;VYT86MT
M:7)A:G1E('9AQ:%E9V$@<VMR8FYI:V$L(,2-92!P;W1R96)U:F5T92!N861A
M;&IN:F\@<&]M;\2-+@!);F1I:F$`4&]S86UE>FYI(%5P;W)A8FYI:VD@`$EN
M9&]N97II:F$`26YF;W)M86-I:F4@;R!S97-T86YK=0!);F9O<FUA8VEJ92!N
M:7-O('9EQ(T@9&]S96=L:FEV92X`5G-T879I(&%L=&5R;F%T:79E;B!V>F]R
M96,`5G-T879I=&4@96QE:W1R;VYS:VD@;F%S;&]V(&YA(&MA=&5R96=A(&QA
M:&MO('!R96IM971E(&YO=F\@9V5S;&\Z`%9S=&%V:71E('-P;W)OQ(UI;&\`
M5G!IQ:%I=&4@>F%H=&5V86X@;V1G;W9O<B!N82!V87)N;W-T;F\@=G!R8<6A
M86YJ93H`4W1A;FIE(&YA(')AQ(UU;G4@;F4@>F%D;W-T=6IE('IA('!OQ:%I
M;&IA;FIE(&YA(,6^96QJ96X@<W!I<V5K+@!3=&%N:F4@;F$@<F'$C75N=2!N
M92!Z861O<W1U:F4N`$-E;&\@Q:%T979I;&\`4V5Z;F%M(&-E;&EH(,6A=&5V
M:6P`3F5V96QJ879E;B!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`3F5V96QJ
M879E;B!:25`@<&]D871E:RX@`$YE=F5L:F%V;F$@87!L:6MA8VEJ82X`3F5V
M96QJ879N:2!)1"!P86ME="X`3F5V96QJ879N:2!P;V1A=&MI('-O(&)I;&D@
M;V1P;W-L86YI+@!.979E;&IA=F5N(&YA<VQO=B!N87-L;W9N:6MA+@`@3F5V
M96QJ879N82!O8FQI:V$@9&%T;W1E:V4@`$YE=F5L:F%V96X@;&EC96[$C6YI
M(&ML:G7$C2X`3V1R96IE;B!N979E;&IA=F5N(&MR86HN`$YE=F5L:F%V96X@
M=&EP7VUS9RX`3F5V96QJ879E;B!A;&D@;6%N:FMA:F_$C2!A<&E?:60N`$YE
M=F5L:F%V;FD@86QI(&UA;FIK86IOQ(UI('!A<F%M971R:2X`3F5V96QJ879N
M;R!D;W9O;&IE;FIE('-T87+%H65V+@!.979E;&IA=F5N('!A<G1N97)J978@
M:60N`$YE=F5L:F%V;F$@:V]D82!A<G1I:VQA+@!.979E;&IA=F5N('!R;W1O
M:V]L+@!.979E;&IA=F5N(&YA<VQO=FYI:SH@(B5S(@`@3F5V96QJ879E;B!O
M8FIE:W0@9&5L:F5N:F$@`$YE=F5L:F%V96X@:7IV;W)N:2!N87-L;W8N`"!.
M979E;&IA=F5N('5N:6MO9"!P;V1A=&5K`$EN=F5N='5R82]P;W!I<P!/8G)N
M:2!I>F)O<@!)<F%N+"!)<VQA;7-K82!297!U8FQI:V$`27)A:P!)<G-K80!0
M;W-A;65Z;F4@;F5V:6AT90!)>G)A96P`27ID86IA=&5L:@!)=&%L:6IA`$IA
M;6%J:V$`2F%N=6%R`$IA<&]N<VMA`$IA<&]N<VMI("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;FEJ80!*=6QI:@!*=6YI:@!+87IA:'-T86X`3V)D<L6^
M:6T@:7IV:7)N:6L_`$ME;FEJ80!+97)B97)O<R!S=')EQ;YN:6L@>F%V<FYI
M;"!O=F5R:71E=BX`2V5R;F5L(&YO=FEN8VD`57-T=F%R:2!+;&IUQ(T@`$]D
M=&ES($ML:G7$C6$`1&]LQ;YI;F$@2VQJ=<2-80!4:7`@2VQJ=<2-82``57!O
M<F%B82!+;&IUQ(UA(`!+;&IUQ(T@Q;YE(&]B<W1A:F$@;F$@:F%V;F5M(&ML
M:G7$C6YE;2!S=')EQ;YN:6MU+@!/=')O8VD`2VER:6)A=&D@`$MO<F5J82P@
M1&5M;VMR871IQ(UN82!L:G5D<VMA(')E<'5B;&EK82``2V]R96IA+"!297!U
M8FQI:V$@`$MO<F5J<VMI("A%54,M2U(I`$MU=F%J="``2VER9VEZ:6IA(`!*
M97II:P!,86]S(&QJ=61S:V$@9&5M;VMR871IQ(UN82!R97!U8FQI:V$`6F%D
M;FIA('!O;&]V:6-A`%IA9&YJ82!S<')E;65M8F$@9V5S;&$Z(`!:861N:F$@
MQ(UE=')T:6YA`%IA9&YJ92!AQ;YU<FER86YJ93H`6F%D;FIA('!R:6IA=F$Z
M("5S(`!:861N:F$@<')I:F%V83H@)7,@:7H@)7,`6F%D;FIA('!R:6IA=F$Z
M($YI:V]L:0!,871V:6IA(`!0<F%V;P!,:6)A;F]N`$QE=F\@;V=L879L:F4`
M5G)E9&YO<W1I(&YA(&QE=FD`3&5S;W1O`%)A=F5N`$QI8F5R:6IA`$QI8FEJ
M82``3&EE8VAT96YS=&5I;B``4F%H96P@<'+%H65C`%)A:&5L(&1EQ;X`6F=O
M9&%J(')A:&5L(&1EQ;X`4&]Z;F\@<F%H96P@9&7%O@!0;&]H80!0;&]H82!Z
M(&=R;65N:F5M`%)A:&5L('-N96<`4VYEQ;YN:2!M971EQ;X`4&]V97IA=F$`
M4&]V9<6^:2!E+6YA<VQO=B!S(&]B<F%Z8V5M('IA('-E<W1A=F\@;F]V92!P
M;\6A=&\@;64@<')I:V%Z;W9A;FIE;0!0;W9E>F%V90!,:6YU>"!P:<6A:V]T
M96L`4V5Z;F%M("T@=7!O<F%B;FEK(&QA:&MO('9I9&D@;6%P;P!397IN86T@
M<&]D871K;W9N:6@@8F%Z`%-E>FYA;2!496T@4&]M;\2-:2``4V5Z;F%M('1A
M8F5L`"!397IN86T@07)H:79A(`!397IN86T@4&]M;\2-:2``4V5Z;F%M($ED
M96YT:71E="``4V5Z;F%M($QA<W1N:6MO=B``4V5Z;F%M(%!OQ:%T92``4V5Z
M;F%M(%!R:6IA=B``4V5Z;F%M($]D:F%V(`!3<&ES96L@<V5Z;F%M82!S96H@
M;FD@=7-P96PZ("5S+@!397IN86T@=7!O<F%B;FEK;W8@;FD@;6]G;\2-93H@
M)7,`4V5Z;F%M('5P;W)A8FYI:V]V(&YI(&UO9V_$C2X`3&ET97)A='5R80!,
M:71V82``3F%L86=A;2XN+@!,;VMA;&YI(,2-87,Z`$QO:V%L:7IA8VEJ80!-
M97-T;P!0<FEJ879A`$]D:F%V82!S('!R961H;V1N92!S>6YC('-E:F4@`$]D
M:F%V80!0<FEJ879A`%!R:6IA=F$@;F$@;W!R879I;&$`4')I:F%V82!N:2!U
M<W!E;&$N(%5P;W)A8FYIQ:%K;R!I;64@86QI(&=E<VQO(&YE<')A=FEL;F\@
M=FYEQ:%E;F\`4')I:F%V82!N:2!U<W!E;&$`1&]L9V\@0F5S961I;&\`3&IU
M8F5Z96X`3FEZ96L`3'5K<V5M8G5R9P!-30!3<&]R;\2-:6QO(&1N979A`$U3
M+51.148@4')I<&]N:V$@;FD@=G-E8F]V86QA('!O9&%T:V]V+@!-4T<`36%C
M874`36%K961O;FEJ82P@9F]R;6%L;F$@2G5G;W-L;W9A;G-K82!R97!U8FQI
M:V$`36%D86=A<VMA<@#$C6%R;V)E;@!%;&5K=')O;G-K:2!N87-L;W8`061M
M:6YI<W1R871O<B!P;\6A=&4`36%L879I`$UA;&5Z:6IA`$UA;&1I=FD`36%L
M:0!-86QT80!5<F5D:71E('-E>FYA;2!K871E9V]R:6H@<R!K871E<FEM:2!B
M;W-T92!O>FYAQ(UI;&D@<&]S=&%V:V4@:6X@<')I<&%D86IOQ(UE(&)A<G9E
M('IA('1E(&MA=&5G;W)I:F4N`%IE;6QJ979I9"!-87`R-`!:96UL:F5V:60@
M36%P47)E<W0`4VAR86YJ96YE('!O=F5Z879E`$UA<F5C`$]Z;F'$C6D@>B!Z
M87-T879I8V%M:2!6:61E;F\O3F5V:61E;F\`3WIN8<2-:2!Z(&]S=&%L:6UI
M('IA<W1A=FEC86UI*&YP<BX@4&]M96UB;F\O3V1G;W9O<FIE;F\I`$UA<G-H
M86QL;W9O(&]T;\2-:F4`36%R=&EN:7%U90!5:F5M86YJ92!P;VQJ`$UA=G)E
M=&%N:6IA`$UA=G)I8VEU<P!.96IV9<2-(&1O=F]L:F5N:2!Z;F5S96L`36%K
M<VEM86QN:2!D96QI('-P;W)OQ(UI;&$@<')E:V]R8<2-96YI+@!-86MS:6UA
M;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@,C0@=7(Z`$UA:W-I;6%L;F$@=&5M
M<&5R871U<F$@>F%D;FII:"`V('5R.@!-86MS:6UA;&YO(,6A=&5V:6QO(&)L
M;VMO=B!P;W)T86QA`$UA:W-I;6%L;F$@9&]LQ;YI;F$`36%J`$UA>6]T=&4`
M6F1R879I;&\@*$UE9&EC:6YA*0#$C6QA;FD`5&EP(&UE;FEJ83H`4W!O<F_$
MC6EL;P!3<&]R;\2-:6QO(&IE(&)I;&\@=7-P9<6A;F\@<')E=F5R:F5N;RP@
M=&]D82!P;V1P:7-N:6MO=F5G82!P;W1R9&EL82!N:2!B:6QO(&UO9V_$C64@
M<')E=F5R:71I+@!3<&]R;\2-:6QO(&IE('!O=&5K;&\N`%1I<"!3<&]R;\2-
M:6QA`$UE=&%R('9R96UE`$UE=&%R(&)L;VL@;FD@;F$@<F%Z<&]L86=O+@!0
M;V1R;V)N;W-T:2!S;R!B:6QE('!R:6IA=FQJ96YE('IA('5P<F%V;&IA;&-A
M+@!-971A<D1"(&YI('!O=F5Z86XN`%!O<W1O<&5K`"<E<R<@<&]S=&]P96L@
M;FD@9&]L;\2-96XN`%!O<W1O<&5K(&YI(&1O;&_$C65N+B!0;W-T;W!E:R!C
M96QI8V4Z("5S`$UE=')IQ(UN:0!-96AI:V$`36EK<F]N97II:F$L($9E9&5R
M871I=FYA(&1RQ;YA=F$`5&EP(&1A=&]T96ME`$UI;FEM86QN82!T96UP97)A
M='5R82!Z861N:FEH(#(T('5R.@!-:6YI;6%L;F$@=&5M<&5R871U<F$@>F%D
M;FII:"`V('5R.@!-:6YI;6%L;F$@<W1A<F]S="!G97-L82#%H64@;FD@<&]T
M96ML80!/9VQE9&%L;P!-;F]G;W-T<F%N<VMA`%!O9W)EQ:%A;B!014%2('!A
M:V5T+"!(5%10('IA:'1E=F%N+@!0;V=R9<6A86YO($E$('-P;W)OQ(UI;&\N
M`%!O9W)EQ:%A;F\@<W!O<F_$C6EL;R!O('IA:'1E=F%N96T@4$5!4B!P86ME
M='4N`%!O9W)EQ:%A;F$@240@<V5J82X`4&\`36]B:6QN82!P;\6A=&$`6FUE
M<FYO`$1A='5M('-P<F5M96UB90!-;V1U;&D`36]L9&%V:6IA+"!R97!U8FQI
M:V$`36]N86MO`$UO;F=O;&EJ80!-97-E8R!I;B!L971O`$UE<V7$C6YO`$UO
M;G1S97)R870`3'5N:6YE(&UE;F4`5B!V<G-T:2`E9"!J92!N86ID96YI:"!V
M9<2-('!O;&H@;V0@<')E9'9I9&5N:6@@)60N`$UA<F]K;P!0<F5T9<6^;F\@
M:F%S;F\`4')E=&7%OFYO(&]B;&'$C6YO`%!R971EQ;YN;R!O8FQAQ(UN;R!I
M;B!V971R;W9N;P!0<F5T9<6^;F\@<V]NQ(UN;P!0;VUA:VYI('-E(&1O;`!0
M;VUA:VYI('-E('8@;&5V;P!0;VUA:VYI('-E('8@9&5S;F\`4&]M86MN:2!S
M92!G;W(`4&]M86MN:2!S92!D;VP`4&]M86MN:2!S92!G;W(`36]Z86UB:6L`
M5F7$C2!N:79O:FYI('!A9&%J;\2-:2!S<&ES:VD`375L=&EM87`@54L@>F5M
M;&IE=FED+@!-;F]G;VMR871E;B!I>F)O<@!-;VH@<F'$C75N`%!O9&%T:VD@
M;6]J96=A(')AQ(UU;F$`36]J('!O<G1A;`!/8FQI:V$@;6]J92!P<G9E('-T
M<F%N:0!-:F%N;6%R`$YE+"!S92!N92!S=')I;FIA;0!);64`3F%M:6)I:F$`
M3F%U<G4`3F5P86P`3FEZ;WIE;7-K80!.:7IO>F5M<VMI($%N=&EL:0!.971S
M8V%P92!O<VYO=FYI(%523``@3F5T<V-A<&4@0T$@55),('IA('!R96ML:6,`
M3F%S;&]V($YE='-C87!E(&-E<G1I9FEK871A`"!.971S8V%P92!O8FYO=FET
M=F5N:2!54DP`($YE='-C87!E(%523"!Z82!P<F5K;&EC`$YE='-C87!E(%-3
M3"!I;64@<W1R9<6^;FEK80!.971S8V%P92!U<F%D;FD@:V]M96YT87(`5&EP
M($YE='-C87!E(&-E<G1I9FEK871A`$]M<F7%OFIE`$YI:V]L:0!.;W9A($MA
M;&5D;VYI:F$`3F]V82!K871E9V]R:6IA`$YO=F$@3'5N80!.;W9O('5P;W)A
M8FYIQ:%K;R!I;64`3F]V82!:96QA;F1I:F$`3F]V;R!G97-L;P!.;W9O(&=E
M<VQO(&)O('!O=&5K;&\@)7@N`$YO=F\@9V5S;&\@<V4@;F4@=6IE;6$N`$YO
M=FEC90!.;W9IQ(UA<G-K82!S:W5P:6YA`$YA<VQE9&YJ:0!.87-L961N:F4@
M-"!S=&]P;FIE`$YA<VQE9&YJ82!M;\6^;F]S=`!.87-L961N:FD^`$YI:V%R
M86=V80!.:6=E<@!.:6=E<FEJ80!.:6=E<@!.:75E`$YO8F5D96X`3FD@9&]S
M=&]P;FEH('!O9&%T:V]V(&\@:V]N9FEG=7)A8VEJ:2!D82!B:2!P;VMA>F%L
M(')A>FQI:V4N`%-T<F%T96=I:F$@>F$@:7ID96QA=F\@25-/('-L:6LL(&YI
M(&1O<W1O<&YA+@!.:2!P86ME=&YE('!R961L;V=E`$YA(,6^96QE;F5M(&UE
M<W0@8F5L9<6^:V$@;F4@;V)S=&%J82X`6F$@34-!3"!O=F5R:71E=B!N:2!K
M;VQE9&%R<VME9V$@:6UE;F$`;FD@<W!R96UE;FIE;F\`3F$@=&5J('-T;W!N
M:FD@;F4@9&]D86IA;6\@;W1R;\6A:VEH(&1O=F]L:F5N:BX`6F$@)7,@;FD@
M<W!E8VEF:6-I<F%N:6@@:V]N9FEG=7)A8VEJ<VMI:"!I;F9O<FUA8VEJ+@!:
M82!&5%`@5D93(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN`"!:82!344P@5D93
M(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN`"!:82!D871O=&5K;RU344P@5D93
M(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN`$YI('-T86YJ82!N82!R8<2-=6YU
M+@!.:2!D97-T:6YA8VEJ90!.:2!N86QOQ;YE;FEH(&1A=&]T96LN`$YE(&YA
M:F1E;2!I:V]N+@!-97-T;R!N:2!N87-T879L:F5N;RX`365S=&\@;FD@;F%S
M=&%V;&IE;F\N`$YO8F5N;R!S<&]R;\2-:6QO(&1O<W1A=FQJ96YO+@!.:2!S
M<&5C:69I8VER86YO(&YO8F5N;R!I;64N`$YI('-P96-I9FEC:7)A;F\@;F]B
M96YO(,6A=&5V:6QO+@!.;V)E;FEH(&]F96YZ:79N:6@@<W)EQ(TN`%!O="!D
M;R!B:6YA<FYE(&1A=&]T96ME($]P96Y34TP@;FD@8FEL82!N87-T879L:F5N
M82X@3W!E;E-33"!B:6YA<FYA(&1A=&]T96MA(&IE('!O=')E8FYA('IA(&1E
M;&\@<R!02T-3(#$R('!O9&%T:VDN`$YE('-P<F5J96UA;6\@>F'$C6%S;FEH
M('!R:6IA=@!+=F]T82!N:2!N87-T879L:F5N82]D;VQOQ(UE;F$N`$YI('-P
M96-I9FEC:7)A;F\@;&_$C6EL;RX`3FD@=&%K92!D871O=&5K90!.92!N86ID
M96T@>F'$C6%S;F4@;6%P92!Z82!P<F5D<&]M;FEL;FEK+@!.;V)E;F\@=7!O
M<F%B;FG%H6MO(&EM92!I;B]A;&D@9V5S;&\@;FD@8FEL;R!P;W-L86YO+@!0
M;W9R871N:6@@=F5L:F%V;FEH(%A-3"!P;V1A=&MO=B!N:0!"<F5Z('9R961N
M;W-T:0!6(&]R:6=I;F%L;FD@:V]N9FEG=7)A8VEJ:2!N92!N86ID96T@;F]B
M96YE(')A>FQIQ(UI8V4N($]B;F]V:71I(&MO;F9I9W5R86-I:F\N`%8@=F'%
MH6D@:V]N9FEG=7)A8VEJ:2!N92!N86ID96T@;F]B96YE(')A>FQIQ(UI8V4N
M($]B;F]V:71E(&MO;F9I9W5R86-I:F\N`$YO8F5D96X`3F]R9&EJ<VMI("A)
M4T\M.#@U.2TQ,`!.;W)F;VS%H6MI(&]T;VMI`%-E=F5R;F$@<&]L;V)L80!3
M979E<FYI($UA<FEA;G-K:2!O=&]K:0!.;W)V9<6A:V$`3F4@:V%S;F5J90!.
M92!P<F5J`$YI(&EM96YI:P!.:2!I>G9E9&5N;RX`3F4@<&]D<&ER86T`6F%P
M:7-K:0!.:2!V<&ES86YI:"!B97-E9"!Z82!I<VMA;FIE+"!V<FYI=&4@<V4@
M;F%Z86HN`$YO=F5M8F5R`,6@=&5V:6QO`,6@=&5V:6QO('IN86MO=@#%H'1E
M=FEL;R!S=&]L<&-E=@#%H'1E=FEL;R!V<G-T:6,`3FD@<W!E8VEF:6-I<F%N
M:6@@Q:%T979I;&L@>F$@8<6^=7)I<F%N:F4@:6X@9&ES=')I8G5C:6IS:VD@
M<V5Z;F%M+@!:861E=F$`57-T=F%R:F%L96,@<')E9&UE=&]V`$]S;6G%H6MI
M`$]K=&]B97(`4&ES87)N80!3=&%R;R!I;B!N;W9O(&=E<VQO(&UO<F%T82!B
M:71I(')A>FQIQ(UN82X`4W1A<F\@1V5S;&\`4W1A<F\@9V5S;&\@;FD@<')A
M=FEL;F\N`$]M86X`36%P92!V('-K=7!N:2!U<&]R86)I('!O9'!I<F$@<V%M
M;R!)34%0('-T<F7%OFYI:RX`4V%M;R!N97-R86UN92!I>FIA=F4`1&]V;VQJ
M96X@:F4@;&4@96X@96QE:W1R;VYS:VD@;F%S;&]V+@!,92!L87-T;FEK(&%L
M:2!U<')A=FYI:R!S:7-T96UA(&QA:&MO('IA;65N:F$@;&%S=&YIQ:%T=F\@
M86QI(&QA<W1N:6MO=F\@9&]V;VQJ96YJ92!Z82!D96QEQ;XN`$]D<')I('8@
M;F]V96T@;VMN=0!/9'!R=&%34TP@;F%P86MA.B!.92!M;W)E;2!P;W9Z971I
M(&1A='5M82!I>B!O>FYAQ(UE;F5G82!3+TU)32!D96QA+@!/<&5R871I=FYI
M('-I<W1E;0!-;\6^;F]S=&D`36_%OFYO<W1I('IA("5S`$]R9V%N:7IA8VEJ
M80!/<F=A;FEZ86-I:G-K82!E;F]T80!/<F=A;FEZ86-I:F$`27IV:7)N92#%
MH6%B;&]N92!A<&QI:V%C:6H`27IV:7)N:2#%H6%B;&]N92!V("5S.@!$<G5G
M;P!/<W1A;&4@:6YF;W)M86-I:F4`1&]V;VQJ96YJ82!L87-T;FEK80!/=F5R
M:F5N:F4@;FD@=7-P96QO`%!%05(Z.B!G;VYI;&YI:R!0;\6A=&4`1&EG:71A
M;&5N('!O9'!I<R!01U``2V]D:7)A;FD@4$=0('!O9&%T:VD`2F%V;FD@:VQJ
M=64@4$=0`%!O9'!I<V%N:2]K;V1I<F%N:2!01U`@<&]D871K:0!02%`@:V]D
M80!02%`@;'5P:6YA`%!O<&]L9&YE(')A:&5L(&1EQ;X`4&]P;VQD;F4@9&7%
MO@!0;W!O;&1N92!N86QI=FD`4&]P;VQD;F4@<VYE9RX`4&]P;VQD;F4@<VYE
MQ;YN:2!M971EQ;YI`%!O<&]L9&YE('-O;F-E`%!O<&]L9&YE(&YE=FEH=&4`
M4&]G<F7%H6%N82!03U-)6"!E:W-T96YZ:6IA`%!(4"!L=7!I;F$`4&%K:7-T
M86X`4&%L874`4&%L97-T:6YK:2!O:W5P:7)A;FD@=&5R:71O<FEJ`%!A;F%M
M80!087!U82!.;W9A($=V:6YE:F$`4&%R86=V86H`1&5L;F\@;V)L8<2-;F\`
M1V5S;&\`1V5S;&\@=7-P9<6A;F\@<W!R96UE;FIE;F\`3F5P<F%V:6QN;R!G
M97-L;P!:82!2041)55,@;W9E<FET978@:F4@>F%H=&5V86YO(&=E<VQO+@!'
M97-L;R!I;B!P;W1R9&ET978`1V5S;&\Z`$=E<VQO.B``1V5S;&\@<V4@;6]R
M82!U:F5M871I+@!0<FEL97!I`$YE<&]T<FIE;F4@<')I:F%V90!,:G5D:F4`
M27IV<L6A:2!V>F1RQ;YE=F%L;F$@9&5L80!)>G9RQ:%I;2!V>F1RQ;YE=F%L
M;F$@9&5L82!O8B!P<FEJ879I/P!$;W9O;&IE;FIE`"(E<R(@9&]V;VQJ96YJ
M92!N:2!I>F)R:7-A;F\N`$1O=F]L:F5N:F4@:F4@>F%V<FYJ96YO+@!$;W9O
M;&IE;FIA`%5P<F%V;FG%H6MA(&1O=F]L:F5N:F$`3W-E8FYE(&EN9F]R;6%C
M:6IE`%!E<G4`3&IU8FQJ96[$C6MI`$9I;&EP:6YI`%1E;&5F;VX`1F]T;V=R
M869I:F4`4&ET8V%I<FX`4')O<VEM;RP@9&$@=FYE<V5T92!M97-E8R!I;B!L
M971O+@!0<F]S:6UO+"!D82!V;F5S971E(&EM92!N;W9E(&MA=&5G;W)I:F4Z
M`%!R;W-I;6\L(&1A('9N97-E=&4@=F5L:F%V96X@25`@;F%S;&]V+@!0<F]S
M:6UO+"!D82!V;F5S971E('9E;&IA=F5N(&1A='5M.B!P<F5V97)I=&4@Q:%T
M979I;&\@9&YI('8@;65S96-U+@!0<F]S:6UO+"!D82!V;F5S971E('!R879I
M;&5N(,2-87,N`%!R;W-I;6\L(&1A('!R:7!R879I=&4@<&]V>F5T96L@=&7%
MOF%V+@!0<F]S:6UO+"!D82!S:2!I>F)E<F5T92!U<&]R86)N:<6A:V\@:6UE
M(&EN(&=E<VQO+@!0<F]S:6UO+"!P<F5B97)I=&4@<VQE9&7$C64@8F5S961I
M;&\N(,2-92#%OF5L:71E('5P;W)A8FQJ871I('1A('-I<W1E;2P@<V4@;6]R
M871E('-T<FEN:F%T:2!S('!O9V]J:2X`4')O<VEM+"!V;F5S:71E(&EM92!N
M;W9E(&MA=&5G;W)I:F4Z`%!O;&IS:V$`4&]L:71I:V$`06YK971E`%!O<G1U
M9V%L<VMA`$]D9&%J('8@=&\@;6%P;R`H;FD@>F%H=&5V86YO(&]D($E-05`I
M`%!A9&%V:6YE('8@>F%D;FII:"`E<R!U<F%H.@!0861A=FEN93QB<B`O/F-H
M86YC90`@4')E9G-?;&1A<#H@>F%H=&5V86YE9V$@3$1!4"!R87IT96=A(&YE
M(&YA:F1E;2X`5&QA:P!4;&%K(&YA(&UO<G-K:2!V:<6A:6YI.@!4;&%K.B``
M4')E9&]G;&5D`%!R96K%H6YJ92!M;\6^;F]S=&D`6F%S96)E;B!K;&IUQ(T`
M4')O8FQE;0!:(&]P:7-O;2!S;R!T9<6^879E+BX`4')O:F5K=&D`5&%K;VK%
MH6YJ92!B97-E9&EL;P!*879N:2!K;&IUQ(T`06QG;W)I=&5M(&IA=FYE9V$@
M:VQJ=<2-80!);F9O<FUA8VEJ92!J879N96=A(&ML:G7$C6$`2F%V;FDO>F%S
M96)N:2!P87(@:VQJ=<2-978@;FD@8FEL('5S<&7%H6YO(&=E;F5R:7)A;BX`
M4&]R=&]R:6MO`%!R9<2-:7-T:2!S<&]R;\2-:6QA`$MA=&%R`%!O:7IV961B
M80!+=F]T80!24T$@:F%V;FD@:VQJ=<2-("@E9"!B:71O=BD`27IB97)I=&4@
M<F%D:6\`1&7%O@!$9<6^('IJ=71R86H`1&7%OB!P;W!O;&1N90!.86QI=@!$
M9<6^(&EN('-N96<`1&7%OB!V('-N96<`4W)EQ(UA`%)A>FUE<FIE`$)E<FD`
M0F5R:2!S<&]R;\2-:6QO`%-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!Z
M8G)I<V%T:2`E<S\@27IB<FES82!N:2!M;V=OQ(UE('!R96ML:6-A=&DN`%-T
M92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!Z8G)I<V%T:2!U<&]R86)N:6MO
M=F4@<&]D871K92!Z82!U<&]R86)N:6MA)7,_($EZ8G)I<V$@;FD@;6]G;\2-
M92!P<F5K;&EC871I+@!/<W9EQ;YI`$]S=F7%OFD@9&EN86UIQ(UN:2!M96YI
M(&5L96UE;G1O=CH`3W-V9<6^:2!P;W)T86PZ`%)E9V5X`$ES:V%L;FEK(')A
M>FUE<FEJ`%!O;F]V;F\@;F%L;\6^:0!0<FEP;VUB90!/9&1A;&IE;FD@<W1R
M9<6^;FEK:0!/9&1A;&IE;B!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@!/9'-T<F%N:0!/9'-T<F%N:2!S=&]L<&5C`$]D<W1R86YI('!A
M<@!/9'-T<F%N:2!S:')A;FIE;F\@<VMR:7!T;R!I>B!S=')EQ;YN:6MO=F4@
M>F'$C6%S;F4@;6%P90!/9'-T<F%N:2!U<&]R86)N:6MA`$]D<W1R86YI('5P
M;W)A8FYI:V$Z("5S(`!:86AT979I(&YE(&UO<F5M('5G;V1I=&DN(%9R;FIE
M;F$@:F4@;F%P8<2-;F$@:V]D83H@`$YE(&YA:F1E;2!Z86AT979A;F5G82!S
M97)V:7-A+@!:86AT979A;FD@(B5S(B!N:2!P;V1R;V)N;R!O8FQI:V]V86X@
M=B`E<R!K;VYF:6=U<F%C:6II+@!:86AT979A;FD@(B5S(B!N:2!P;V1R;V)N
M;R!O8FQI:V]V86X@=B!62%,@:V]N9FEG=7)A8VEJ:2X`6F%H=&5V86YI("<E
M<R<@;FD@<&]D<F]B;F\@;V)L:6MO=F%N+@!:86AT979A;F$@9&%T;W1E:V$`
M4&]N87-T879I`%!O;F%S=&%V:2!G97-L;P!0;VYA<W1A=FET92!V8<6A92!G
M97-L;P!/8FYO=FET92!Z861N:F\@<&]I>G9E9&)O`%IA9&5T:VD`5G)N:2!S
M92!N82!-;\6^;F]S=&D`4&]N;W9N;R!V<&G%H6ET92!N;W9O(&=E<VQO`%!O
M;F]V;F\@>F1R=<6^:0!0;W9R;FD@:V]N9FEG=7)A8VEJ;P!6<FYI('-E(&YA
M(&UOQ;YN;W-T:2!U<F5J979A;&YI:V$@8F5S961I;&$`16YI9VUE`$1E<VYO
M(&]G;&%V:F4`1&5S;F4@=G)E9&YO<W1I`$9U;FMC:6IA`%)O;75N:6IA`$]B
M<FYI('IA(#$X,`!/8G)N:2!N82!L979O`$]B<FYI(&YA(&1E<VYO`%IAQ;YE
M;FD`4G5S:6IA`%)U86YD80`@4R]-24U%(&MR:7!T;V=R869S:VD@<&]D<&ES
M`%,O34E-12!K;V1I<F%N;R!S<&]R;\2-:6QO`%-!4TP@3W9E<FIA;FIE(&YI
M('5S<&5L;P!335,@<W!O<F_$C6EL;P!344P@;'5P:6YA`%-13"!S=&%V96L@
M>F$@<&]I>G9E9&)O('9R961N;W-T:0!34T@`55-014@`4U%,(&QU<&EN80!3
M80!3=F5T82!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES(`!386EN="!,
M=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N(`!386EN="!6:6YC96YT
M(&EN($=R96YA9&EN90!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&EN(%!R
M:6YC:7!E`%-A=&5L:71S:VD@;W-K<F)O=F%L96,`4V%U9'-K82!!<F%B:6IA
M`%-H<F%N:0!3:')A;FD@(B5S(@!3:')A;FD@)7,@`%-H<F%N:2!-;\6^;F]S
M=&D`4VAR86YI=&4@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO(&MO="!02%`@
M<VMR:7!T;R!N82!Z8<2-87-N:2!M87!I('9AQ:%E9V%S=')EQ;YN:6MA9&ER
M96-T;W)Y+@!3:')A;FIE;F$@)7,@:V]N9FEG=7)A8VEJ80!3:')A;FIE;F$@
M;F%S=&%V:71V96YE('-K<FEP=&$@;F%D9W)A9&YJ92!N83H@(B5S(BX`4F%Z
M9&EV:F%N82!N979I:'1A('H@9W)M96YJ96T`6FYA;F]S=`!)Q:'$C6D`27-K
M86QN:6MI`$EZ8F5R:2!D871O=&5K;P!)>F)E<FD@9&%T=6T`27IB97)I('-K
M=7!I;F\L(&MI(&IO(,6^96QIQ:$@9&]D871I+@!)>F)E<FD@;F]V96=A(&QA
M<W1N:6MA`$EZ8F5R:2!S=')EQ;YN:6L`27IB97)I('5P;W)A8FYI:V$L(&MI
M(&=A(,6^96QIQ:$@9&]D871I`$EZ8F5R:2!V<V4`27IB97)I('!O<&]L;B!D
M871U;0!)>F)E<FD@<')E9&UE=`!/9&ML:G5K86H@=G-E`%IN86ME+"!K:2!J
M:6@@<&]T<F5B=6IE=&4@:7IB97)I=&4@:7H@;VMV:7)J978@<W!O9&%J+B!.
M871O(&II:"!L86AK;R!K;W!I<F%T92!I;B!P<FEL97!I=&4@=B]I>B!B97-E
M9&EL82X`1&]L;\2-:2!K;V[$C6YI(&1A='5M.@!)>F)E<FD@;V)L:6MO(&1A
M='5M83H`27IB97)I=&4@:61E;G1I=&5T;RP@:V%T97)O(,6^96QI=&4@<W!R
M96UE;FET:3H`1&]L;\2-:2!K;V[$C6YO('5R;SH`27IB97)I(&]B;&EK;R!U
M<F4Z`$EZ8F5R:2!D=F4@=6IE;6%J;\2-:2!S92!P;VQJ:3H`27IB97)I=&4@
M=F'%H64@8F%R=FYO(&MO;6)I;F%C:6IO`$EZ8F5R:71E(&IE>FEK.@!0;\6A
M;&II('!O<F_$C6EL;R!O(&YA<&%K86@`4&_%H6QJ:2!335,`4V5N96=A;`!3
M96YZ;W(Z`%-E<')E;6)E<@!3<F)I:F$@:6X@Q(UR;F$@9V]R80!397)I:G-K
M82#%H71E=FEL:V$`4W1R9<6^;FEK;W8@9&%T=6T@:F4@;F%P8<2-96X@86QI
M(&YI(&YA(')A>G!O;&%G;RX`061M:6YI<W1R86-I:F$@<V5J90!)1"!S96IE
M(&IE('!O=&5K;&$N`%-E:F4`3F%M97-T:0!.87-T879I(&]P8VEJ;RP@9&$@
M=B!P<FEM97)U+"!D82!P;WIA8FET92!V8<6A92!G97-L;RP@;&%H:V\@<&]N
M87-T879I=&4@;&4M=&\N`%5R961I=&4@;V1D86QJ96YE('-T<F7%OFYI:V4@
M;F$@:V%T97)E(,6^96QI=&4@9&]S=&]P871I('H@=F'%H65G82!P;W)T86QA
M`$YA<W1A=FET92!P<FEV>F5T(&IE>FEK(&EN(&YA<W1A=FET=F4@9&%T=6UA
M`%5R961I('IAQ(UE=&YE(&)A<G9N92!S:&5M92P@87!L:6MA8VEJ92P@;W-V
M9<6^:71V92!S=')A;FDN+BX`3F%M97-T:0!.87-T879I('-K<FEP=&\@>F$@
M;W-V9<6^:71E=B!K;W0@<F%Z<&]L;\6^;&II=F\N`$UOQ;YN:6@@:F4@=F7$
MC2!L;VMA8VEJ(',@<&%R86UE=')O;3H`4V5JQ:%E;&D`3F%K=7!O=F%N:F4`
M2W)A=&5K('!O=GIE=&5K`$YA=&%V:6T@=&EP:V%R<VME(&)L:<6^;FEC92!N
M82!P;W9E>F%V93\`4&]K8<6^:0!0;VMAQ;YI(')A>FQI:V4@;65D('-E9&%J
M('-H<F%N:F5N;R!I;B!N86IN;W9E:L6A;R!G96YE<FER86YO(&MO;F9I9W5R
M86-I:F\N`%!R:6MAQ;YI(&1A='5M('IA9&YJ92!P<FEJ879E('!O('9S=&]P
M=3\`4')I:V'%OFD@;W!C:6IE('IA(&]B9'+%OF%T:2!O<FEG:6YA;`!0;VMA
MQ;YI('1I<W1E9V$L(&MI('-P<F5J96UA`%!R:6MAQ;YI(&UE;FEJ<VMO('9R
M<W1I8V\@9&5L;W9A;FIA('1A8F5L90!0<FEK8<6^96T@)7,@;65N:2!N82!L
M979I('-T<F%N:3\`1&]D86H@;F%L86=A;FIE`%!L;VAE`%IJ=71R86H@<&QO
M:&4`4&]P;VQD;F4@<&QO:&4`5B!B;&G%OFEN:2!P;&]H90!3:W+$C6D`3F%J
M<')E:B!S:W+$C6D@86QI('!R96UA:VYI('-O<V5D;FIE(&)E;&7%OFME+@!3
M:65R<F$@3&5O;F4`4')I:F%V:2!S90!0;V1P:7,`06QG;W)I=&UIQ(UE;B!P
M;V1P:7,`4VEN9V%P=7(`5F5L:6MO<W0`4')E<VMOQ(UI('9Z9'+%OF5V86YJ
M90!3;&]V8<6A:V$`4VQO=F5N:6IA`%-N96<`4VYEQ;YN82!P;&]H80!3;F7%
MOFYE('!L;VAE`%IJ=71R86H@<VYEQ;YN92!P;&]H90!0;W!O;&1N92!S;F7%
MOFYE('!L;VAE`%9IQ:%I;F$@<VYE9V$Z`%-N96=U(&5K=FEV86QE;G1N82!K
M;VQIQ(UI;F$@=F]D93H`4V%L;VUO;F]V:2!O=&]K:0!3;VUA;&EJ80!097-M
M:2!I;B!P;V5Z:6IE`%9R<W1A('5R96IE;F5G82!I>F)O<F$`3F%S;&]V('9I
M<F$`2G7%OFYA($%F<FEK80!*=<6^;F\M979R;W!S:VD@*$E33RTX.#4Y+3,I
M`$IUQ;YN82!'96]R9VEA(&EN(&]T;VMI($IUQ;YN:2!386YD=VEC:`!*=<6^
M;F$@<&]L;V)L80!0<F5S;&5D;FEC80#%H'!A;FEJ80!.97IAQ;YE;&5N82!P
M;\6A=&$`5FAO9"!Z82!P;W-E8FYE('IN86ME`,6@<&]R=&D`Q:!R:2!,86YK
M80!3=&%N9&%R9&5N`%IV97ID;F4@<W1E>F4`6F'$C65T;F\@;&5T;P!$<L6^
M879A(&%L:2!P<F]V:6YC80!3=&%T=7,`3V)L:6MA('!O;6YI;&YI:V$`3F%S
M;&]V('5L:6-E`%-P:7-E:R!B97-E9&YI:"!Z=F5Z`#\_/S\_/S\_/S]D;VUE
M;F$@:7H@;F%S;&]V80!.90!.92!N86ID96T@<&]D;6%P92`B)7,B`%IA9&5V
M80!0<F5D;&_%OFD`4W!R96IE;&D@<VUO('IA:'1E=F5K('IA('9P:7,@(B5S
M(BX@3F4@;6]R971E('-E('!R:6IA=FET:2!D;VML97(@=F'%H6$@>F%H=&5V
M96L@;F4@<&\@<&]T<FIE;BX`57-P96@`(B5S(B!S96T@=7-P9<6A;F\@9&]D
M86P@:R!S:7-T96UU+@`G)7,G('-E;2!U<W!EQ:%N;R!O9'-T<F%N:6P@:7H@
M<VES=&5M82X`(B5S(B!S96T@=7-P9<6A;F\@:7IB<FES86PN`"(E<R(@<V5M
M('5S<&7%H6YO(&]D<W1R86YI;"!I>B!S:7-T96UA+@!5<W!EQ:%N;R!O8G)N
M:F5N82!K;VYF:6=U<F%C:6IA+B#$C64@Q;YE;&G%H2!V:61E=&D@<W!R96UE
M;6)E+"!P;VYO=FYO(&YA;&_%OFDN`%5S<&7%H6YO('-H<F%N:F5N82!V87)N
M;W-T;F$@:V]P:6IA(&MO;F9I9W5R86-I:F4N`%5S<&7%H6YO('-H<F%N:F5N
M82!V87)N;W-T;F$@:V]P:6IA(&MO9FEG=7)A8VEJ92!D871O=&5K92`E<RX`
M(B5S(B!J92!B:6P@=7-P9<6A;F\@<&]S;V1O8FQJ96XN`"5S('-E;2!U<W!E
MQ:%N;R!Z87!I<V%L+@!3=61A;@!3;V[$C6YI('9Z:&]D`%-O;L2-;FD@>F%H
M;V0`4V]NQ(UN;P!3;V[$C6YI('9Z:&]D`%-O;L2-;FD@=GIH;V0O>F%H;V0`
M4V]NQ(UN:2!V>FAO9`!3;V[$C6YI('IA:&]D`%-O;L2-;FD@>F%H;V0Z`%!O
M9'!O<F$`4W5R:6YA;0!0<FEI;65K`%-V86QB87)D(&EN($IA;B!-87EE;@!3
M=F%Z:0#%H'9E9'-K80#%H'9I8V$`27IB<FES86X@<VEN:W)O;FEZ86-I:G-K
M:2!D;F5V;FEK`%-I;FMR;VYI>F%C:6IA`$YA<&%K82!V('-I;G1A:W-I(&ES
M:V%L;FEH('!O9V]J978`4VER:6IS:V$@87)A8G-K82!R97!U8FQI:V$`1W)M
M96YJ90!.979I:'1A('H@9W)M96YJ96T@:6X@=F5T<F]M`$YE=FEH=&$@>B!G
M<FUE;FIE;0!44U8@9&%T;W1E:V$`3F%S=&%V:71E=B!T86)E;&4`5&%J=F%N
M`%1A:7=A;BP@9&7%OF5L82!+:71A:G-K90!4863%OFEK:7-T86X`5&%N>F%N
M:6IA+"!:9')UQ;YE;F$@<F5P=6)L:6MA`$]P<F%V:6QA`%1E;&5F;VYS:V$@
MQ:%T979I;&MA`%1E;7!E<F%T=7)A('8@>F%D;FII('5R:3H`5&5M<&5R871U
M<F$`5&5M<&5R871U<F$Z(`!496UP97)A='5R83QB<B`O/B@E<TAI)7,O)7-,
M;R5S*2`F9&5G.R5S`"(E<R(@=GIO<F-A(&YE(&YA:F1E;2X`57)E:F5V86QN
M:6L@Q:%A8FQO;@!"97-E9&EL;P!386UO($)E<V5D:6QO`%1O`%1A:G-K80!/
M=F5R:F5N:F4@;FD@=7-P96QO`%IG;V1O=FEN82!J92!I>FML;W!L:F5N82X`
M2&]R9&4O2V]L86(@:6YT96=R86-I:F$@;F4@<&]D<&ER82`B)7,B`%!O<V]D
M;V)L:F5N(&1A=&]T96ME(&YE(&UO<F5M('-H<F%N:71I+@!6>F1RQ;YE=F%N
M:F4Z(')A>G)E9"!N:2!B:6P@=7-P9<6A;F\@;F%L;\6^96XN`$]K;F\@36_%
MOFYO<W1I(&IE(&)I;&\@>F%P<G1O+B!:86ML:G5E=6IE;2X`061M:6YI<W1R
M871O<B!M;W)A(&YA:G!R96H@;F%S=&%V:71I('-I<W1E;2!Z82!P<F%V:6-E
M+@!+;VYT86MT;FD@240@;FD@8FEL('!O<W)E9&]V86X@86QI(&YI(&)I;"!N
M86ID978@=B!B87II('!O9&%T:V]V+@!3=&EK(&IE(&)I;"!U<W!EQ:%N;R!D
M;V1A;B!K('9AQ:%I;2!N87-L;W9O;2X@2VQI:VYI=&4@<W!O9&%J('IA(&]G
M;&5D.@!0;W1R96)U:F5M(&QOQ(UE;F\@4$=0('!O9'!I<V%N;R!B96QEQ;YN
M:6-O+"!D82!P<F5V:7)I;2!P;V1P:7-A;F\@<W!O<F_$C6EL;RX`240@<V5Z
M;F%M82!N:2!B:6P@<&]S<F5D;W9A(&%L:2!N:2!B:6P@;F%J9&5N('8@8F%Z
M:2!P;V1A=&MO=BX`5&\@9&5J86YJ92!N:6UA('!O9'!O<F4N`$MO9&ER86YA
M('9S96)I;F$@>F%H=&5V82!V87)N;R!I;G1E<FYE=&YO('!O=F5Z879O+@`E
M<R!D871O=&5K82!B:2!M;W)A;&$@=G-E8F]V871I("5S(&YA<W1A=FET=G(N
M`"5S(&1A=&]T96MA(&)I(&UO<F%L82!V<V5B;W9A=&D@)7,@;F%S=&%V:71V
M92X@`$1A=&]T96MA(&YE('9S96)U:F4@;F]B96YI:"!P;V1A=&MO=BX`4W1R
M9<6^;FEK("(E<R(@:F4@8FEL(&EZ8G)I<V%N+@!-97-T;R!';G501R!P<F]G
M<F%M82!M;W)A(&)I=&D@<&]S<F5D;W9A;F\@<F%Z<F5D=2!#<GEP=%]P9W`N
M`%-P;W)OQ(UI;&\@<&]S;&%N;R!D;F4@)7,@>F$@)7,@>B!N87-L;W9O;2`B
M)7,B(&IE(&)I;"!P<F5B<F%N+@I.:2!Z86=O=&]V:6QA(&1A(&IE(&)I;&\@
M9&5J86YS:V\@<')E8G)A;F\@86QI(')A>G5M;&IE;F\N`$EM92!Z82!P;W9E
M>F%V;R!N82!S=')A;B!Z82!S97-T879L:F%N:F4@<W!O<F_$C6EL82X`5&$@
M=G)E9&YO<W0@;6]R82!B:71I(,6A=&5V:6QK82X`4&]T<F5B=6IE;2!O<&5N
M<W-L(&UO9'5L('IA($AO<F1E7T-R>7!T7W-M:6UE.CH@<F%Z<F5D+@!.87-T
M879I96YE(&1A=&]T96ME("(E<R(@;F4@;6]R92!S:')A;FET:2P@:V5R(&YJ
M96YI('!O9&%T:VD@<')E<V5G86IO;F%J=F7$C6II(&1O=F]L:F5N(&]B<V5G
M+@!0<F]G<F%M82P@:VD@;V1P:7)A('!O9&%T:V4@=&4@=G)S=&4@*"5S*2!N
M92!N86ID96T@=B!S:7-T96UU+@!287IM96II=&5V(&UO<F$@8FET:2!S97-T
M879L:F5N82!L92!I>B!E;F5G82!Z;F%K82X`3&_$C6ET978@;6]R82!B:71I
M('-E<W1A=FQJ96YA(&QE(&EZ(&5N96=A('IN86MA+@!3=')EQ;YN:6L@(B5S
M(B!J92!B:6P@:7IB<FES86XN`%-T<F7%OFYI:R`B)7,B(&IE('-H<F%N:F5N
M+@!)>F)R86YA('9R<W1I8V$@*"5D*2!N92!O8G-T86IA+@!6;F7%H65N;R!B
M97-E9&EL;R!N92!U<W1R97IA(&)E<V5D:6QO(&YA(&5K<F%N=2X`4&]S;V1O
M8FQJ96YI('!O9&%T:VD@<V\@8FEL:2!I>F=U8FQJ96YI('!R:2!P<F5JQ:%N
M:F5M(&MO<F%K=2X`4&]S;V1O8FQJ96X@9&%T;W1E:V4@;F4@;6]R96T@<VAR
M86YI=&DN`'=E871H97(N8V]M(&YI(&YA('9O;&IO+@!.92!N86ID96T@;6%P
M92!O8FQI:R`B)7,B+@!.:2!M;\6^;F]S=&D@;F$@<F%Z<&]L86=O+@!$96QI
M(&YE(&UO<F5J;R!B:71I('!R:6MA>F%N:2X`5B!P;VQJ=2!J92!P<F5V9<2-
M('IN86MO=BX@5G1I<&MA;&D@<W1E("5S('IN86MO=BX@5G1I<&MA=&D@;6]R
M871E(&UA;FH@:V]T("5S('IN86MO=BX`4')IQ:%L;R!J92!D;R!N87!A:V4@
M<')I(&1O9&%J86YJ=2`G)7,G(&L@<VES=&5M=3H@)7,`4')IQ:%L;R!J92!D
M;R!N87!A:V4@<')I(&]D<W1R86YJ86YJ=2`G)7,G(&EZ('-I<W1E;6$N`%!R
M:<6A;&\@:F4@9&\@;F%P86ME('!R:2!O9'-T<F%N:F%N:G4@)R5S)R!I>B!S
M:7-T96UA+@!0<FG%H6QO(&IE(&1O(&YA<&%K92!P<FD@<&]S;V1A8FQJ86YJ
M=2`G)7,G.B`E<R``4')I(&YA;&%G86YJ=2!D871O=&5K92!J92!P<FG%H6QO
M(&1O(&YA<&%K92X@3F]B961E;B`E<R!N:2!B:6P@;F%L;\6^96XN`%!R:2!N
M86QA9V%N:G4@9&%T;W1E:V4@:F4@<')IQ:%L;R!D;R!N87!A:V4N("5S('IA
M<V5D82!V9<2-('!R;W-T;W)A+"!K;W0@:F4@9&]V;VQJ96YO+B!$;W9O;&IE
M;F\@:F4@*"5D(&)Y=&]V*2X`4')I(&YA;&%G86YJ=2!D871O=&5K92!J92!P
M<FG%H6QO(&1O(&YA<&%K92X@)7,@:F4@;&4@9&5L;F\@;F%L;\6^96YA+@!6
M('-P;W)O96EL=2!S92!J92!P;VIA=FEL82!N97IN86YA(&YA<&%K82X`4')I
M('-P<F5J96UA;FIU(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME+@!0
M<FD@<W!R96IE;6%N:G4@:V]N=&%K=&$@:F4@<')IQ:%L;R!D;R!N87!A:V4N
M`$MO;F9I9W5R86-I:G-K:2!O8G)A>F5C('9S96)U:F4@;F%P86MO+B!697)J
M971N;R!S=&4@<&]Z86)I;&D@;F%S=&%V:71I('IA:'1E=F%N;R!P;VQJ92X`
M4')IQ:%L;R!J92!D;R!N87!A:V4@<')I('!R;V-E<VER86YJ=2!I>F)R86YE
M9V$@:6UE;FEK82X@4')O<VEM;R!P;W-K=7-I=&4@>FYO=F%N96MO;&EK;R!K
M87-N96IE`%!R:2!S<')E:F5M86YJ=2!K;VYT86MT82!J92!P<FG%H6QO(&1O
M(&YA<&%K92X@4')O<VEM;R!P;W-K=7-I=&4@>FYO=F$@:V%S;F5J92X`4')I
M('-P<F5J96UA;FIU(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME+B!0
M<F]S:6UO('!O<VMU<VET92!K87-N96IE+@!68<6A(&)R<VMA;&YI:R!N92!P
M;V1P:7)A('1E('!O=&5Z92X`5&\@;FD@=F5L:F%V96X@4D%2(&%R:&EV+@!4
M;R!N:2!V96QJ879N82!Z:7`@9&%T;W1E:V$N`,2"XH":Q:!T979I;&MA(&MA
M<G1I8V4@;FD@=F5L:F%V;F$N`$=O;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA
M;FIE('-P;W)OQ(UI;"!P<F5K;R!O<&5R871E<FIA($-L:6-K871E;&PN`$=O
M;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA;FIE('-P;W)OQ(UI;"!P<F5K;R!O
M<&5R871E<FIA(%=)3BX`1V]N:6QN:6L@;VUO9V_$C64@<&_%H6EL:F%N:F4@
M<W!O<F_$C6EL('!R96MO(&]P97)A=&5R:F$@<VUS,F5M86EL+@!';VYI;&YI
M:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S<&]R;\2-:6P@<')E:V\@:71A;&IA
M;G-K96=A(&]P97)A=&5R:F$@5F]D;V%F;VYE+EIA('!OQ:%I;&IA;FIE(&UO
M<F5T92!I;65T:2!R96=I<W1R:7)A;FD@;F$@:'1T<#HO+W=W=RXQ.3`N:70`
M4&]T<F5B=6IE;2!T;R!P;VQJ92X`5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!L
M92!C96QA(,6A=&5V:6QA+@!4;R!P;VQJ92!L86AK;R!V<V5B=6IE(&QE(,6A
M=&5V:6QA(&EN('-T;VQP96,N`%1O('!O;&IE(&QA:&MO('9S96)U:F4@;&4@
MQ:%T979I;&$N`%!O;&IE(&UO<F$@=G-E8F]V871I('-E>FYA;2#%H71E=FEL
M+"!L;\2-96YI:"!Z('9E:FEC;R!A;&D@<')E<VQE9&MO;2X`5&$@=G)E9&YO
M<W0@;6]R82!B:71I(,6A=&5V:6QK82X`5&\@<&]L:F4@;6]R82!V<V5B;W9A
M=&D@8F%R=FYO(&MO9&\@=B!21T(@2&5X(&9O<FUA='4L(&YA('!R:6UE<B`G
M(S$R,S1A9B<N`%1A(&]B;&EK82!J92!B:6QA(,6^92!O8F1E;&%N82X`5&\@
M:F4@)7,N`%1O(&IE('!O9&%T96L@<VMU<&EN<VMA('5P<F%V;&IA;FIE($MO
M;&%B+B!:82!P<F5G;&5D('1E9V$@<&]D871K82!P;W1R96)U:F5T97!R96=L
M961L;W9A;&YI:RP@:VD@<&]D<&ER82!N8<2-:6X@>F%P:7-A($MO;&%B($=R
M;W5P=V%R92X@6F$@<V5Z;F%M(&]D:F5M86QC979K:2!T;R!P;V1P:7)A:F\@
M;V)IQ:'$C6ET92`E<P!3<&]R;\2-:6QO(&IE(&)I;&\@;F%P:7-A;F\@=B!K
M;V1N:2!T86)E;&D@9')U9V'$C6YE(&]D('9AQ:%E("@E<RDN`%1O(,6A=&5V
M:6QO(&UO<F$@8FET:2!V<V%J(&5N82X`5&$@<W1R9<6^;FEK(&YE(&UO<F4@
M;V1P<F5T:2!Z:7`@:6X@9WII<"!D871O=&5K+@!3:7-T96T@:F4@=')E;G5T
M;F\@;F5A:VET:79E;BX`5&$@=G)E9&YO<W0@;6]R82!B:71I(,6A=&5V:6QK
M82X`5&\@;VMN;R!M;W)A=&4@<&]G;F%T:2!Z(&]K;F$@36_%OFYO<W1I+@!"
M;&ES:P!0<FEJ879E`,2-87,`4VQE9&YJ92#$C6%S80!/8FQI:V$@Q(UA<V$`
M27IB:7)A(&5A<V$N`$YA<VQO=@!:80!EQ(T@Q;YE;&ET92!I>F)R871I('9E
MQ(T@<')E9&UE=&]V+"!P<FET:7-N:71E($-O;G1R;VP@*%!#*2!A;&D@0V]M
M;6%N9"`H36%C*2!T:7!K;RP@;65D=&5M(&MO(&YA;FIE(&ML:6MA=&4N`&1A
M;@!4;V=O`%1O:V5L874`2V]M;W)I(`!4;VYG80!0<F5V9<2-(&YE=7-P96QI
M:"!P;W9E>F%V('8@>F%D;FII:"!M:6YU=&%H+@!/<F=A;FEZ86-I:F$`5')I
M;FED860@:6X@5&]B86=O`$1A(&%L:2!N90#$C&4`5'5N:7II:F$`5'5R96EJ
M80!4=7+%H6MI("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5RQ:%K:2!I
M;B!#86EC;W,@;W1O:VD`5'5V86QU`%9T:7!K86IT92!V8<6A;R!I>F)I<F\Z
M(`!5+E8N(&EN9&5K<SH`55),`%523"!V8<6A92!S:W)I<'1E('IA('!O<F_$
MC6%N:F4@<W1A='5S82!D;W-T879E`%5G86YD80!5:W)A:FEN80!.:6UA;2!D
M;W-T;W!A(&1O(%9&4R!I;65N:6MA+@!.92!M;W)E;2!S<')E;65N:71I('!R
M879I8V4@>F$@5D93(&1A=&]T96MO("(E<R(N`$1O=F]L:F5N:F$@>F$@5D93
M("5S+R5S(&YE(&UO<F5M('-P<F5M96YI=&DN`$YE(&UO<F5M('-P<F5M96YI
M=&D@;F$@)7,N`$YE(&UO<F5M('-P<F5M96YI=&D@;F$@(B5S(BX`3F4@;6]R
M96T@<')E:6UE;F]V871I(%9&4R!D871O=&5K92`E<R\E<RX`3F4@;6]R96T@
M<V4@<&]V97IA=&D@<R!34TPN`%9&4R!D871O=&5K92!N92!M;W)E;2!K;W!I
M<F%T:2X`3F4@;6]R96T@=7-T879R:71I(&EM96YI:V$@(B5S(BX`5D93(&EM
M96YI:V$@;F4@;6]R96T@=7-T879R:71I+@!61E,@9&%T;W1E:V4@;F4@;6]R
M96T@=7-T=F%R:71I+@!.92!M<F]E;2!U<W1V87)I=&D@:6UE;FEK82`B)7,B
M+@!61E,@9&%T;W1E:V4@;F4@;6]R96T@=7-T=F%R:71I+@!0;V1A=&MO=B!N
M92!M;W)E;2!S<')O<W1I=&DN`$YE(&UO<F5M(&EZ8G)I<V%T:2`E<RP@:6UE
M;FEK(&YI('!R87IE;BX`3F4@;6]R96T@:7IB<FES871I("<E<R<Z("5S+@!.
M92!M;W)E;2!I>F)R:7-A=&D@)7,L(&EM96YI:R!N:2!P<F%Z96XN`$YE(&UO
M<F5M(&EZ8G)I<V%T:2!I;65N:6MA+@!.92!M;W)E;2!I>F)R:7-A=&D@:6UE
M;FEK82X`3F4@;6]R96T@:7IB<FES871I(%9&4R!I;65N:6MA.B`E<R``3F4@
M;6]R96T@:7IB<FES871I(&1A=&]T96ME+B(E<R(N`$YE(&UO<F5M(&EZ8G)I
M<V%T:2!61E,@9&%T;W1E:V4N`$YE(&UO<F5M(&EZ8G)I<V%T:2!D871O=&5K
M92`B)7,B+@!.92!M;W)E;2!I>F)R:7-A=&D@5D93.B`E<R``3F4@;6]R96T@
M9&]L;\2-:71I('-E9&%N:F5G82!I;65N:6MA+@!.92!M;W)E;2!I>G!I<V%T
M:2!P;W1R:F5N:6@@<&]D<F]B;F]S=&DN`$YE(&UO<F5M('-P<F5M96YI=&D@
M;F$@)7,N`$YE(&UO<F5M('!R96UA:VYI=&D@5D93(&1A=&]T96ME+@!.92!M
M;W)E;2!O9'!R971I(&1A=&]T96ME(B5S(BX`3F4@;6]R96T@;V1P<F5T:2!6
M1E,@9&%T;W1E:V4@;F%M96YJ96YE('!I<V%N:G4N`$YE(&UO<F5M(&]D<')E
M=&D@5D93(&1A=&]T96ME+@!.92!M;W)E;2!O9'!R971I('IG;\6AQ(UE;F5G
M82!A<FAI=F$N`$YE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T;W1E:V4@
M)7,O)7,N`$YE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T;W1E:V4N`$YE
M(&UO<F5M('!R96)R871I(%9&4R!O<VYO=FYE9V$@:6UE;FEK82X`3F4@;6]R
M96T@<')E:6UE;F]V871I("5S('8@)7,Z(&UA<&$@Q;YE(&]S=&%J80!.92!M
M;W)E;2!P<F5I;65N;W9A=&D@5D93(&EM96YI:V$N`$YE(&UO<F5M('!R96EM
M96YO=F%T:2!61E,@:6UE;FEK83H@)7,N`$YE(&UO<F5M('!R96EM96YO=F%T
M:2!61E,@9&%T;W1E:V4@(B5S(BX`3F4@;6]R96T@<')E:6UE;F]V871I(%9&
M4R!D871O=&5K92`E<R\E<RX`3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!D
M871O=&5K92X`3F4@;6]R96T@<W!R96UE;FET:2!N82`E<RX`3F4@;6]R96T@
M<')E=F5S=&D@=&5G82!7;W)D;W9E9V$@9&]K=6UE;G1A+@!.92!M;W)E;2!S
M<')OQ;YI=&D@<')O<W1O+WIA<V5D96YO('!O<V]D;V)I=&4@>F$@)7,`3F4@
M;6]R96T@;F%P:7-A=&D@5D93(&1A=&]T96ME("(E<R(N`$YE(&UO<F5M(&YA
M<&ES871I(%9&4R!P;V1A=&MO=FYI:"!D871O=&5K+@!.92!M;W)E;2!N87!I
M<V%T:2!61E,@<&]D871K;W9N:6@@9&%T;W1E:RX`3F4@;6]R96T@;F%P:7-A
M=&D@5D93(&1A=&]T96ME+"!K=F]T82!B;R!P<F5S9<6^96YA+@!287IV96QJ
M879I('-P<F5M96UB90!.97!R:<2-86MO=F%N(&]D9V]V;W(@<R!S=')EQ;YN
M:6MA('8@<&]V97IO=F%N:G4Z`$YE<')IQ(UA:V]V86X@;F5P<FG$C6%K;W9A
M;B!O9&=O=F]R('-T<F7%OFYI:V$@>F$Z`$YE:7IP;VQN:F5N;P!5;FEK;V0@
M*%541BTX*0!:9')UQ;YE;FD@87)A8G-K:2!E;6ER871I`%ID<G7%OF5N;R!K
M<F%L:F5S='9O`%ID<G7%OF5N92!D<L6^879E`%ID<G7%OF5N92!D<L6^879E
M($]T;VMI($UI;F]R($]U=&QY:6YG`$5N;W1E`$YE<&]Z;F%N;P!.97!O>FYA
M;F$@87!I;7-G:60@*$E$($%022!S<&]R;\2-:6QA*2X`3F5P;WIN86YA(&-L
M:6US9VED("A)1"!U<&]R86)N:<6A:V5G82!S<&]R;\2-:6QA*0!-97-T;R!N
M:2!N87-T879L:F5N;RX`3F5Z;F%N;R!U<&]R86)N:<6A:V\@:6UE(&%L:2!G
M97-L;RX`0G)E>B!I;65N80!.97!O9'!R=&$@<F%ZQ:%I<FET978`4&]S;V1O
M8FD`4&]S;V1O8FD@)7,`4&]S;V1O8FQJ96X@=7!O<F%B;FEK`%!O<V]D;V)L
M:F5N("<E<R<N`$EZ8G)I<V%N82!S:W)I<'1A('IA(&YA9&=R861N:F\N`$YA
M;&%G86T`3F%L;\6^:2!N82!S=')EQ;YN:6L@=G-E(&YA;65S=&ET=F5N92!D
M871O=&5K92!A<&QI:V%C:6HN`%5R=6=V86H`57!O<F%B:2!S961A;FII.B`E
M<P!5<&]R86)I(%-33`!5<&]R86)I+"#$C64@:F4@=7!O<F%B;FG%H6MO(&EM
M92]G97-L;R!D<G5G8<2-;F\@;V0@24U34"!S=')EQ;YN:6MA`%5P;W)A8FYI
M:P!5<&]R86)N:6L@)7,@;FEM82!D;W-T;W!A(&1O("5S`%5P<F%V82!Z82!U
M<&]R86)N:6ME`%5P;W)A8FYIQ:%K92!N87-T879I='9E`%)E9VES=')A8VEJ
M82!U<&]R86)N:6MA`%)E9VES=')I<F%N:F4@=7!O<F%B;FEK;W8@:F4@;F$@
M=&5J('-T<F%N:2!O;F5M;V=OQ(UE;F\N`$YE(&YA:F1E;2!U<&]R86)N:6MO
M=B!R8<2-=6XN`%5P;W)A8FYIQ:%K;R!I;64`57!O<F%B;FG%H6MO(&EM92`B
M)7,B(&IE(,6^92!V('5P;W)A8FDN`%5P;W)A8FYIQ:%K;R!I;64Z(`!5<&]R
M86)N:<6A:V\@:6UE.B``57!O<F%B;FEK:2P@:VD@<V\@=B!S:7-T96UU.@!5
M>F)E:VES=&%N`%9&4R!I;65N:6L@;F4@;V)S=&%J82X`3V1S;W1N;W-T`$YA
M:F1E;F$@=F5L:F%V;F$@;&]K86-I:F$@>F%J96UA.@!696QJ879N;W-T`%9R
M961N;W-T('8@;6EN=71A:"!O9"!S961A:B!D86QJ92X`5G)E9&YO<W0@<')E
M<V5G82!M86MS:6UA;&YO(&1O;,6^:6YO("5S+@!6<F5D;F]S=&D`5G)E9&YO
M<W1I(&]D(&MO9&5R(&EZ8FER871I`%9A;G5A='4`5F%R:6%B:6QN;P!696YE
M>G5E;&$`4')E=F5R:F%N:F4@;F5U<W!EQ:%N;R`M(&UO9V_$C64@:F4@8FEL
M;R!S<&]R;\2-:6QO('-P<F5M96YJ96YO+@!287IL:<2-:6-A`%)A>FQIQ(UI
M8V$`6F5L;R!V:7-O:V\`5FEE=&YA;0!6:65T;F%M<VMI("A625-#24DI`%!O
M9VQE:B`E<P!0;V=L960@;F$@>G5N86YJ;R!S<&QE=&YO('-T<F%N`$1E=FG%
MH6MI(&]T;VMI("AB<FET86YS:VDI`$1E=FG%H6MI(&]T;VMI("A:1$$I`%9I
M9&QJ:79O<W0`5FED;&II=F]S=#H`5F]D869O;B!)=&%L:6IA('!R96MO(%--
M5%``3U!/6D]224Q/`$]03UI/4DE,3R$A(2!23\2-3D\@3T135%)!3DE-(%-+
M4DE05$\@25H@)7,N`%=)3B!P<F5K;R!(5%10`%=A;&QI<R!I;B!&=71U;F$`
M3W!O>F]R:6QO`$UI`%9R96UE;G-K82!N87!O=F5D`%9R96UE;G-K:2!P;V1A
M=&MI(',@<W!L971A`'=E871H97(N8V]M`%-P;&5T`%-P;&5T;F$@<W1R86X`
M5&5D96YS:V\`1&]B<F]D;\6A;&D`1&]B<F]D;\6A;&D@;F$@<W!L971N:6@@
M<W1R86YE:"!P<F]G<F%M82`E<P!$;V)R;V1OQ:%L:2P@)7,`6F%H;V1N:2`H
M25-/+3@X-3DM,2D`6F%H;V1N:2`H25-/+3@X-3DM,34`6F%H;V1N82!386AA
M<F$`2V%T97)O(&%P;&EK86-I:F\@;F%J('!R:6MAQ;YE("5S+"!P;R!P<FEJ
M879I/P!+86O%H65N(&IE(&QOQ(UI;&YI('IN86L_`$MA:\6A96X@:F4@;F%V
M961E;FD@>FYA:S\`6F5M;&IE=FED("!7:&5R96ES($%U<W1R86QI80!287IV
M;VIN82!S=&]P;FIA`$MA=&5R92!D;V1A=&ME(&YA:B!O;6]G;\2-:6T@<')I
M('5R96IA;FIU(&)E<V5D:6PN`,6@:7)I;F$@=B!E;F]T86@@0U-3`,6@:7)I
M;F$@)7,@;65N:6IA(&YA(&QE=FD@*&]D<F%Z:6QA('-E(&)O(&]B(&YA<VQE
M9&YJ:2!P<FEJ879I*3H`5VEK:0!6971E<CH@`$IU=')A;FII('9E=&5R.B``
M2&ET<F]S="!V971R82!V('9O>FQI:`!6971E<CH`5F5T97(Z(`!-;V1R;W-T
M`$QI<W1A(,6^96QJ80!3;'7%OF)A`%-L=<6^8F5N:2!N87-L;W8`4VQUQ;YB
M96YI('1E;&5F;VX`3F%P8<2-;F\@Q:%T979I;&\@<&]L:B!V("5D('9R<W1I
M+B!0<FG$C6%K;W9A;FEH("5D+"!N86ID96YI:"`E9"X`3F%P8<2-;F\@Q:%T
M979I;&\@<&]L:BX@4')IQ(UA:V]V86YI:"`E9"P@;F%J9&5N:6@@)60N`$YA
M<&'$C65N(&]D;6EK("5D(&UE9"!B<F%N:F5M(&1A=&]T96ME(%9&4RX`6"U2
M968`6#4P.78S(&]S;F]V;F$@;VUE:FET978`6#4P.78S(%)A>L6A:7)J96YA
M('5P;W)A8F$@:VQJ=<2-80!8-3`Y=C,@6F%D979A(&%L=&5R;F%T:79N;R!I
M;64`6#4P.78S($MJ=64@>F$@9&]L;V5I=&D@>F%D979O`%@U,#EV,R!R87K%
MH6ER:71E=@!,3`!,3$Q,`%EA:&]O(2!Z96UL:F5V:60`3&5T;F\`2F5M96X`
M1&$N`$1A+"!S92!S=')I;FIA;2X`3FEM871E(&1O=F]L:F5N:F$@=7-T=F%R
M:71I('9EQ(T@:V]T("5D(&)L;VMO=BX`3FES=&4@<')I:F%V;&IE;FD`5B!I
M;65N=2!N92!M;W)E=&4@:6UE=&D@>FYA:V]V("=<)P!.:7-T92!V<W1A=FEL
M:2!V96QJ879N96=A(&5L96MT<F]N<VME9V$@;F%S;&]V82X`365D('-P<F5J
M971I;6D@9&%T;W1E:V%M:2!N:7-T92!O>FYAQ(UI;&D@;F]B96YE9V$@<&]L
M:F$L(&MI('-E('5J96UA(',@<&]L:FD@=B5S+@!":6QI('-T92!O9&IA=FQJ
M96YI+@!6;F5S=&D@;6]R871E('9E;&IA=FYO(&=S;2#%H71E=FEL:V\N1'9O
M;&IE;FD@>FYA:VD@<V\@;&4@Q:%T979I;&ME(&EN("<K)R!K;W0@<')E9'!O
M;F$@;65D;F%R;V1N:6T@Q:%T96EV;&MA;2X`5G-T879I=&D@;6]R871E('9E
M;&IA=FYO('9R961N;W-T+@!/8FQI:V]V871I(&UO<F%T92!3:6=N=7`@8F%C
M:V5N9"P@Q:%E;&4@;F%T;R!S92!L86AK;R!P<FEJ879L:F%T92X`3V)L:6MO
M=F%T:2!M;W)A=&4@5D93(&)A8VME;F0N`$YA:G!R96H@;W!IQ:%I=&4@=&7%
MOF%V92P@Q:%E;&4@;F%T;R!L86AK;R!P;\6A;&IE=&4@<&]R;\2-:6QO(&\@
M=&7%OF%V86@N`$EZ8G)A=&D@;6]R871E('-T<F7%OFYI:RP@:VD@8F\@:7IB
M<FES86XN`$YA=&%NQ(UN96IE(&YA=F5D:71E('5P;W)A8FYIQ:%K;R!I;64L
M(&MI(&=A(,6^96QI=&4@:7IB<FEA=&DN`$YA=&%NQ(UN96IE(&YA=F5D:71E
M('5P;W)A8FYIQ:%K;R!I;64L(&MI(&=A(,6^96QI=&4@;V1S=')A;FET:2X`
M3F%T86[$C6YE:F4@;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@
MQ;YE;&ET92!D;V1A=&DN`$YA=&%NQ(UN96IE(&YA=F5D:71E('5P;W)A8FYI
MQ:%K;R!I;64L(&MI(&=A(,6^96QI=&4@<&]S;V1O8FET:2X`3F%T86[$C6YE
M:F4@;F%V961I=&4@:V%J(,6^96QI=&4@;F%R961I=&DN`%9T:7!K86IT92!I
M;64@;F]V92!K871E9V]R:6IE+@!6;F5S=&D@;6]R871E(&ET86QI:F%N<VMO
M('1E;&5F;VYS:V\@Q:%T979I;&MO`%9AQ:%A('!R:6IA=FET=F5N82!S96IA
M("5S(&IE('!O=&5K;&$N(%!R;W-I;6\L(&1A('-E('!O;F]V;F\@<')I:F%V
M:71E+@!68<6A(&5L96MT<F]N<VMI(&YA<VQO=CH`5F'%H2!N87-L;W8Z`%9A
MQ:%I('!O9&%T:VD`3V0@>F'$C65T:V$@)7,@<V5J92P@<V4@:F4@=F'%H2!S
M<&QE=&YI(&YA<VQO=B!S<')E;65N:6PN($EZ('9A<FYO<W1N:6AR87IL;V=O
M=BP@<V4@;6]R871E('!O;F]V;F\@<')I:F%V:71I+@!68<6A92!I;64Z`%9A
MQ:%E(&]Z861J92!Z82!O=F5R:F5N92!N92!P;V1P:7)A(&1O9&%J86YJ82!U
M<&]R86)N:6MO=BX@Q(UE(,6^96QI=&4@=7!O<F%B:71I2&]R9&4@>F$@861M
M:6YI<W1R:7)A;FIE('5P;W)A8FYIQ:%K:6@@<F'$C75N;W8L(&UO<F%T92!U
M<&]R86)I=&D@9')U9V\@;WIA9&IE('IA;W9E<FIA;FIE+@!68<6A92!O>F%D
M:F4@>F$@;W9E<FIA;FIE(&YE('!O9'!I<F$@;F%V86IA;FIA('5P;W)A8FYI
M:V]V(&%L:2!P82!J92!B:6QA(&UOQ;YN;W-T(&]N96UO9V_$C65N82!I>B!D
M<G5G:6@@<F%Z;&]G;W8N`$MAQ;YE+"!D82!S92!J92!O9"!Z8<2-971K82`E
M('-E:F4L('9AQ:$@8G)S:V%L;FEK('-P<F5M96YI;"X@27IV87)N;W-T;FEH
M(')A>FQO9V]V+"!S92!M;W)A=&4@<&]N;W9N;R!P<FEJ879I=&DN`%9AQ:$@
M8G)S:V%L;FEK(&YE('!O9'!I<F$@=&4@9G5N:V-I:F4N`%9AQ:$@8G)S:V%L
M;FEK(&YE('!O9'!I<F$@9&]L;\2-96YI:"!M;\6^;F]S=&D@<')I('!R:6YT
M86YJ=2X@6F$@<')I;G1A;FIE('!R:71I<VYI=&4@0V]N=')O;"]-;\6^;F]S
M=&D@*R!0+@!68<6A('1R96YU=&YI(,2-87-O=FYI('!A<SH`5F'%H6$@<')I
M=GIE=&$@:61E;G1I=&5T82!J92!B:6QA('-P<F5M96YJ96YA+@!0<FEV>F5T
M82!I9&5N=&ET971A`%9AQ:%E(&EM93H`5F'%H6$@<')I:F%V82!J92!P;W1E
M:VQA+@!68<6A92!N;W9E(&=E<VQO('IA("5S(&IE.B`E<P!68<6A92!N87-T
M879I='9E('-O(&)I;&4@<&]S;V1O8FQJ96YE('IA(,2-87,@=&4@<V5J92X`
M5F'%H64@;F%S=&%V:71V92!S;R!B:6QE('!O<V]D;V)L:F5N92X`5F'%H64@
M9V5S;&\@:F4@8FEL;R!P;VYA<W1A=FQJ96YO+@!68<6A92!G97-L;R!J92!B
M:6QO('!O;F%S=&%V;&IE;F\N($YA('9AQ:$@92UN87-L;W8@<VUO('9A;2!P
M;W-L86QI(&YO=F]G97-L;R!S(&MA=&5R:6T@<V4@<')I:F%V:71E+@!68<6A
M92!G97-L;R!J92!P;W1E:VQO+@!68<6A:2!P;W-R961N:2!S=')EQ;YN:6MI
M.@!*=6=O<VQA=FEJ80!:86ER`%IA;6)I:F$`6FEM8F%B=F4`6U-K<FEJ(&-I
M=&ER86YO(&)E<V5D:6QO70!;<&]R;\2-:6QO(&\@;F%P86MI70!;4&]K8<6^
M:2!C:71I<F%N;R!B97-E9&EL;R`M`%M0;VMAQ;YI(&-I=&ER86YO(&)E<V5D
M:6QO("T@)7,@=G)S=&EC70!;)7,@=G)S=&EC82!O9"`E<UT`7T-,20!$<F5V
M97-N82``7U-K=7!I;F4`4&]M;\2-`%!R:6IA=F$`3V1J879A`$UOQ;YN;W-T
M:0!$;W9O;&IE;FIA`%].86UE<W1I`%]5<&]R86)N:6MI`$EM96YI:P!.87-L
M;W9N:6L@;F5Z;F%N`$MO;&5D87(`36ER;F\`3F4@;6]R96T@=7-T=F%R:71I
M(&EZ:&]D;F4@9&%T;W1E:V4`3F4@;6]R96T@;V1P<F5T:2!V:&]D80!K;&EK
M;FD@='4`;F%P86MA('8@=7!O<F%B;FD@=6MA>FYE('9R<W1I8V4`3F%P86MA
M('8@:V]N9FEG=7)A8VEJ:0!.92!N86ID96T@>F%H=&5V86YE('-I<W1E;7-K
M92!D871O=&5K90!.87!AQ(UN82!O8FQI:V$@9&%T=6UA`%5R961I`$YE(&YA
M:F1E;2!V;F5S96YI:"!P;V1A=&MO=@!0861A=FEN90!D871O=&5K80!I>B`E
M<R`H)7,I(&L@)7,@)7,`9V]S=&EM`&@Z`&AH`$YE>FYA;F\@:6UE(&=O<W1I
M=&5L:F$`=&%K;VH`365D('9R<W1I8V%M:0!6:&]D;F$O:7IH;V1N82!N87!A
M:V$`26YT97)N82!N87!A:V$@=B!P<F]G<F%M=0!V<G-T:6-E`&UK:7-O9G,@
M;F%P86MA(&MO9&4@)60L(&UE9"!P<FEP<F%V;&IA;FIE;2!)4T\N`&UM`&EM
M90!N:2!D;VMO;L2-86YO`,6A92!N:2!P;V1P<G1A`$)E;&7%OFMA`$1O=F]L
M:F5N:F4@:F4@>F%V<FYJ96YO+@!N87!A:V$@=B!O9&1L:F5N96T@<')O=&]K
M;VQU`'9Z:&%J86IOQ(UE`%-E<G9I<R!N:2!N82!V;VQJ;RX`4&]K8<6^:2!R
M87IL:6ME`'-M<S)E;6%I;"!P<F5K;R!(5%10`'-S`%-T86)I;&YO`%-I<W1E
M;7-K82!N87!A:V$N`%-E>FYA;2!O<')A=FEL+@!Z8<2-87-N82!O9'!O=F5D
M`'IA('!O=')D:71E=B!V=&EP:V%J=&4@9V5S;&\@9'9A:W)A=`!E;F]T96X`
M8G)E>B!I;65N80!)>F)I<F$@=7!O<F%B;FEK82``=B!+87)T:6-A`'<Z`'=E
M871H97(N8V]M````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VQ?4TDO:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P
M`#$P-3$U-#,Q,#8R`#`R,#,R-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D
M2&]R9&4Z(&AO<F1E+VQO8V%L92]S;%]322]H96QP+GAM;"QV(#$N,B`R,#`T
M+S`U+S(W(#(P.C(R.C$S(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y
M(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@
M4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I
M9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I
M;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA
M;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"
M3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O
M;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@
M;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U
M;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO
M;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M
M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K
M+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI
M<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T
M(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@
M:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L
M;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT
M:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@
M/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G
M92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@
M;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML
M>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A
M<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI
M<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N
M8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T
M;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A
M<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L
M;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@
M=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC
M92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-V7U-%+P``````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`V,@`P,38V-C<`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M<W9?4T4O3$-?34534T%'15,O````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R`#`R,#0U-``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]S=E]312],0U]-15-304=%4R]H;W)D92YM;P``
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,3,U-#8`,3`U,34T,S$P-C(`,#(R
M,3(T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````Y`<``!P````\/P``A0H``%Q^````````<*@``$@```!QJ```
M#@```+JH```/````R:@```P```#9J```#0```.:H```(````]*@```L```#]
MJ```#`````FI```$````%JD``!@````;J0``&P```#2I```M````4*D``!T`
M``!^J0``)````)RI```I````P:D``!D```#KJ0``)@````6J```,````+*H`
M`"0````YJ@``#P```%ZJ```+````;JH```X```!ZJ@``!0```(FJ```H````
MCZH```@```"XJ@``"@```,&J```5````S*H``!(```#BJ@``"P```/6J```4
M`````:L``"8````6JP``)P```#VK```F````9:L``(4```",JP``#@```!*L
M```*````(:P```T````LK```)P```#JL```@````8JP```X```"#K```%P``
M`)*L```B````JJP``#4```#-K```$0````.M```-````%:T```P````CK0``
M#0```#"M```&````/JT``)0```!%K0``"@```-JM```/````Y:T``!@```#U
MK0``#`````ZN```.````&ZX```X````JK@``"````#FN```)````0JX``"X`
M``!,K@``&@```'NN```R````EJX``#@```#)K@``5`````*O``!1````5Z\`
M`%H```"IKP``5P````2P```T````7+````D```"1L```#0```)NP```'````
MJ;````H```"QL```#P```+RP```%````S+````8```#2L```$0```-FP```(
M````Z[````D```#TL```"0```/ZP```.````"+$```@````7L0``)0```""Q
M```@````1K$``!,```!GL0``$````'NQ```/````C+$```H```"<L0``!P``
M`*>Q```#````K[$```8```"SL0``#P```+JQ```4````RK$```D```#?L0``
M#0```.FQ```2````][$``!D````*L@``'@```"2R```/````0[(```H```!3
ML@``#P```%ZR```(````;K(``"0```!WL@``%P```)RR```4````M+(``!8`
M``#)L@``"````."R``!.````Z;(``"T````XLP``&0```&:S```'````@+,`
M``P```"(LP``+````)6S```.````PK,```,```#1LP``"P```-6S```'````
MX;,```<```#ILP``!0```/&S```%````][,```H```#]LP```P````BT```7
M````#+0```H````DM```#P```"^T```.````/[0``!@```!.M```(P```&>T
M```.````B[0``!0```":M```%P```*^T```7````Q[0``!<```#?M```$P``
M`/>T```/````"[4```X````;M0``*0```"JU```?````5+4``!T```!TM0``
M!P```)*U```&````FK4```@```"AM0``#P```*JU```&````NK4```H```#!
MM0``$P```,RU```+````X+4``!````#LM0``%0```/VU```5````$[8```<`
M```IM@``$````#&V```%````0K8``!4```!(M@``$0```%ZV```,````<+8`
M`#L```!]M@``.````+FV```)````\K8```<```#\M@``%`````2W```#````
M&;<```4````=MP``$````".W```)````-+<``!,````^MP``.0```%*W```2
M````C+<``#D```"?MP``)P```-FW```L`````;@``"H````NN```)0```%FX
M```)````?[@```H```")N```!@```)2X```)````F[@```<```"EN```+P``
M`*VX```W````W;@``"X````5N0``50```$2Y```M````FKD``"T```#(N0``
M/0```/:Y```_````-+H``"T```!TN@``0````**Z```C````X[H``",````'
MNP``0````"N[```M````;+L``#,```":NP``)0```,Z[```5````]+L``!D`
M```*O```*0```"2\```D````3KP``"@```!SO```$0```)R\```1````KKP`
M``H```#`O```!````,N\```,````T+P```H```#=O```$````.B\```6````
M^;P``!8````0O0``!P```">]```'````+[T``!0````WO0``"@```$R]```(
M````5[T```@```!@O0``"````&F]```&````<KT``"<```!YO0``"````*&]
M```'````JKT```<```"RO0``!@```+J]```%````P;T```<```#'O0``!@``
M`,^]```(````UKT``"D```#?O0``#@````F^```*````&+X```D````CO@``
M#@```"V^```$````/+X```<```!!O@``"0```$F^```&````4[X``!$```!:
MO@``!P```&R^```6````=+X```0```"+O@``"````)"^```&````F;X```T`
M``"@O@``!@```*Z^```>````M;X```4```#4O@``$0```-J^```(````[+X`
M``T```#UO@``#`````._```,````$+\```<````=OP```P```"6_```#````
M*;\``!<````MOP``$P```$6_```=````6;\```@```!WOP``!````("_```(
M````A;\```@```".OP``"@```)>_``!!````HK\``!H```#DOP``*P```/^_
M```@````*\```!4```!,P```!@```&+````&````:<```!4```!PP```&```
M`(;````B````G\```"X```#"P```'0```/'````A````#\$``"D````QP0``
M"@```%O!```'````9L$```<```!NP0``%0```';!```.````C,$```H```";
MP0``#P```*;!```-````ML$```\```#$P0``#0```-3!```)````XL$``!0`
M``#LP0``!@````'"```8````",(``!T````AP@``$P```#_"```1````4\(`
M`!0```!EP@``!````'K"```,````?\(```8```",P@``%````)/"```7````
MJ,(``%0```#`P@``9````!7#```$````>L,```X```!_PP``1````([#```%
M````T\,```4```#9PP``&P```-_#```:````^\,``!,````6Q```$0```"K$
M```1````/,0``!$```!.Q```'````&#$```J````?<0``!````"HQ```(0``
M`+G$```%````V\0``!,```#AQ```"P```/7$```2`````<4```H````4Q0``
M#P```!_%```-````+\4``!$````]Q0``$P```$_%```,````8\4```8```!P
MQ0``#````'?%```&````A,4``!<```"+Q0``$````*/%```1````M,4```@`
M``#&Q0``!0```,_%```,````U<4``!````#BQ0``!0```//%```-````^<4`
M``8````'Q@``!P````[&```-````%L8```<````DQ@``"P```"S&```'````
M.,8```<```!`Q@``"0```$C&```4````4L8```D```!GQ@``"0```''&```*
M````>\8``!D```"&Q@``/0```*#&```=````WL8```P```#\Q@``$`````G'
M```%````&L<``"4````@QP``$@```$;'```3````6<<``"L```!MQP``.P``
M`)G'```@````U<<```@```#VQP``-@```/_'```A````-L@``!````!8R```
M"````&G(```,````<L@```8```!_R```!````(;(```/````B\@```X```";
MR```"@```*K(```'````M<@```H```"]R```#0```,C(```>````UL@``!\`
M``#UR```&P```!7)```<````,<D``"$```!.R0``'@```'#)```9````C\D`
M`!X```"IR0``&P```,C)```A````Y,D``"X````&R@``)@```#7*```;````
M7,H``!P```!XR@``'@```)7*```<````M,H``"8```#1R@``*P```/C*```S
M````),L``"8```!8RP``*P```'_+```X````J\L``!T```#DRP``'0````+,
M```5````(,P``!4````VS```+P```$S,```@````?,P``!(```"=S```(```
M`+#,```I````T<P``!X```#[S```'@```!K-```@````.<T``!(```!:S0``
MH@```&W-```6````$,X``",````GS@``*````$O.```I````=,X``"@```">
MS@``'P```,?.```5````Y\X``!4```#]S@``(````!//```E````-,\``"@`
M``!:SP``+0```(//```P````L<\``)(```#BSP``(0```'70```6````E]``
M`!8```"NT```'````,70```F````XM```"H````)T0``00```#31``!$````
M=M$```P```"[T0``!P```,C1```'````T-$```8```#8T0``#0```-_1```0
M````[=$``!(```#^T0``$P```!'2```2````)=(```<````XT@``!````$#2
M```0````1=(``!````!6T@``#````&?2```.````=-(```T```"#T@``#P``
M`)'2```3````H=(```T```"UT@``*````,/2```#````[-(```T```#PT@``
M!@```/[2```1````!=,``!<````7TP``&P```"_3```.````2],```(```!:
MTP``!0```%W3```0````8],```\```!TTP``!````(33```-````B=,```X`
M``"7TP```P```*;3```.````JM,```@```"YTP``#P```,+3```(````TM,`
M``\```#;TP``!P```.O3```-````\],``!`````!U```#0```!+4```+````
M(-0``!$````LU```"0```#[4```&````2-0```L```!/U```#````%O4```*
M````:-0``!$```!SU```&0```(74```+````G]0```T```"KU```(@```+G4
M```/````W-0``!L```#LU```-`````C5```*````/=4``!@```!(U0``$@``
M`&'5```9````=-4``!8```".U0``$````*75```B````MM4```T```#9U0``
M!P```.?5```,````[]4``"8```#\U0``%````"/6```+````.-8``"(```!$
MU@``+P```&?6```+````E]8```D```"CU@``&0```*W6```+````Q]8``!<`
M``#3U@``%P```.O6```)`````]<``!8````-UP``#P```"37```9````--<`
M`!8```!.UP``#@```&77```'````=-<```@```!\UP``#0```(77```F````
MD]<``$,```"ZUP``$@```/[7```?````$=@```@````QV```"P```#K8```O
M````1M@```X```!VV```!0```(78```&````B]@``$4```"2V````P```-C8
M```'````W-@```0```#DV```"@```.G8```*````]-@```\```#_V```$```
M``_9```7````(-D``!$````XV0``&0```$K9```7````9-D```D```!\V0``
M!0```(;9```+````C-D```H```"8V0```@```*/9```%````IMD```T```"L
MV0``&P```+K9```7````UMD``!0```#NV0``"0````/:```.````#=H```T`
M```<V@``$@```"K:```#````/=H```@```!!V@``#@```$K:```8````6=H`
M`!@```!RV@``!0```(O:```8````D=H``!X```"JV@``&P```,G:```9````
MY=H``!@```#_V@``&P```!C;```3````--L``!,```!(VP``!P```%S;```(
M````9-L```8```!MVP``!@```'3;```0````>]L```\```",VP``$````)S;
M```/````K=L```L```"]VP``#P```,G;```,````V=L```\```#FVP``!P``
M`/;;```&````_ML```X````%W```#````!3<```H````(=P```\```!*W```
M"````%K<```(````8]P``!,```!LW```'@```(#<```A````G]P``"````#!
MW```&0```.+<```7````_-P``"4````4W0``%P```#K=```6````4MT```0`
M``!IW0``&P```&[=```-````BMT```P```"8W0```P```*7=```%````J=T`
M``@```"OW0``"@```+C=```,````P]T```L```#0W0``$````-S=```,````
M[=T```X```#ZW0``"P````G>```$````%=X```0````:W@``$P```!_>```4
M````,]X```P```!(W@``"0```%7>```.````7]X```L```!NW@``&P```'K>
M```'````EMX```<```">W@``"@```*;>```-````L=X``!@```"_W@``"@``
M`-C>```$````X]X``"8```#HW@``#@````_?``!\````'M\``!4```";WP``
M!0```+'?```'````M]\```P```"_WP``"````,S?```*````U=\```8```#@
MWP``"````.??```"````\-\```8```#SWP``!@```/K?```4`````>```!4`
M```6X```#P```"S@```1````/.```!H```!.X```#0```&G@```0````=^``
M`!L```"(X```!````*3@```)````J>```!````"SX```"0```,3@```)````
MSN````4```#8X```&@```-[@```(````^>````8````"X0``&0````GA```.
M````(^$```<````RX0``!P```#KA```%````0N$```D```!(X0``"@```%+A
M```.````7>$```(```!LX0``!@```&_A```+````=N$```T```""X0``"0``
M`)#A```&````FN$```4```"AX0``"0```*?A```'````L>$```0```"YX0``
M%````+[A``!"````T^$``"4````6X@``)0```#SB```&````8N(```0```!I
MX@``"0```&[B```(````>.(``!$```"!X@``#@```)/B```)````HN(```8`
M``"LX@``#0```+/B```&````P>(```0```#(X@``.0```,WB```]````!^,`
M`#H```!%XP``'@```(#C```%````G^,```X```"EXP``!````+3C```&````
MN>,```<```#`XP``(0```,CC```-````ZN,``!4```#XXP``!@````[D```2
M````%>0```0````HY```$0```"WD```&````/^0```H```!&Y```(@```%'D
M```$````=.0```4```!YY```!````'_D```,````A.0```X```"1Y```"@``
M`*#D```(````J^0```D```"TY```!0```+[D```Z````Q.0``#````#_Y```
M-0```##E```I````9N4``$<```"0Y0``.````-CE```I````$>8``#\````[
MY@``+@```'OF```M````JN8``!\```#8Y@``#P```/CF```2````".<```L`
M```;YP``)@```"?G```I````3N<``"0```!XYP``)@```)WG```(````Q.<`
M``H```#-YP``"0```-CG```'````XN<``"````#JYP``(`````OH```F````
M+.@```H```!3Z```&0```%[H```I````>.@``!8```"BZ```$@```+GH```'
M````S.@```H```#4Z```#````-_H```/````[.@``!````#\Z```0`````WI
M``!P````3ND``&8```"_Z0``#@```";J```)````->H```H````_Z@``$@``
M`$KJ```3````7>H```P```!QZ@``!@```'[J```/````A>H``!(```"5Z@``
M$````*CJ```*````N>H``!$```#$Z@``'````-;J```C````\^H``&H````7
MZP``#P```(+K```%````DNL``!````"8ZP``"0```*GK```$````L^L```L`
M``"XZP``(````,3K```4````Y>L```P```#ZZP``#`````?L```/````%.P`
M`!4````D[```*0```#KL```J````9.P``"8```"/[```)P```+;L```I````
MWNP``"H````([0``&0```#/M```1````3>T``!(```!?[0``$P```'+M```4
M````ANT```\```";[0``%@```*OM```7````PNT``!````#:[0``$0```.OM
M```T````_>T``!,````R[@``$@```$;N```U````6>X``!0```"/[@``!P``
M`*3N```,````K.X``"L```"Y[@``(````.7N```0````!N\``!0````7[P``
M$0```"SO```7````/N\``!P```!6[P``$P```'/O```4````A^\``!H```"<
M[P``$0```+?O```:````R>\``!X```#D[P``&@````/P```3````'O```!4`
M```R\```$0```$CP```7````6O```!0```!R\```%P```(?P```5````G_``
M``D```"U\```$````+_P```9````T/````0```#J\```!P```._P```+````
M]_```!$````#\0``!@```!7Q```&````'/$```8````C\0``!0```"KQ```'
M````,/$```<````X\0``!0```$#Q```6````1O$```8```!=\0``!@```&3Q
M```$````:_$```0```!P\0``!P```'7Q```.````??$```P```",\0``#```
M`)GQ```-````IO$```4```"T\0``*````+KQ```,````X_$```\```#P\0``
M"@````#R```(````"_(```D````4\@``*P```![R```$````2O(```@```!/
M\@``!0```%CR```F````7O(``!(```"%\@``#P```)CR```&````J/(```H`
M``"O\@``!P```+KR```(````PO(``"````#+\@``"0```.SR```4````]O(`
M``P````+\P``#0```!CS```.````)O,``!8````U\P``$0```$SS```&````
M7O,```@```!E\P```P```&[S```&````<O,``!D```!Y\P``!P```)/S```$
M````F_,```L```"@\P``"P```*SS```'````N/,```4```#`\P``!P```,;S
M```6````SO,```T```#E\P``"@```//S```-````_O,```H````,]```$```
M`!?T```/````*/0``!$````X]```%P```$KT```*````8O0``!$```!M]```
M"````'_T```$````B/0```\```"-]```.@```)WT```%````V/0```P```#>
M]```'@```.OT```.````"O4``!`````9]0``"P```"KU```,````-O4```D`
M``!#]0``!P```$WU```*````5?4```D```!@]0``#@```&KU```0````>?4`
M`!L```"*]0``&````*;U```:````O_4```H```#:]0``"0```.7U```*````
M[_4```P```#Z]0``#P````?V```(````%_8```8````@]@``!P```"?V```%
M````+_8```L````U]@``1P```$'V```-````B?8```D```"7]@``!````*'V
M```#````IO8``!,```"J]@``$P```+[V```3````TO8```8```#F]@``"P``
M`.WV```*````^?8```(````$]P``!`````?W```E````#/<```,````R]P``
M!0```#;W```J````//<```H```!G]P``!0```'+W```$````>/<```H```!]
M]P``#0```(CW```&````EO<```@```"=]P``"````*;W```$````K_<```4`
M``"T]P``:````+KW```)````(_@```P````M^```$````#KX```%````2_@`
M``8```!1^```&P```%CX```O````=/@``!````"D^```"@```+7X```/````
MP/@```H```#0^```"0```-OX```3````Y?@``!L```#Y^```&````!7Y```7
M````+OD``!\```!&^0``#@```&;Y```#````=?D```<```!Y^0``"````('Y
M```4````BOD``!,```"?^0``$````+/Y```-````Q/D```X```#2^0``%@``
M`.'Y```'````^/D```H`````^@``"P````OZ```'````%_H``%$````?^@``
M$````''Z```,````@OH```T```"/^@``&@```)WZ``!*````N/H``!D````#
M^P``!@```!W[```:````)/L``"4````_^P``!@```&7[```&````;/L``!\`
M``!S^P``!@```)/[```)````FOL``!@```"D^P``%P```+W[```H````U?L`
M``8```#^^P``#0````7\```B````$_P``%<````V_```$P```([\```C````
MHOP``!,```#&_````@```-K\```+````W?P```@```#I_```#0```/+\```*
M`````/T```<````+_0``%````!/]```&````*/T```@````O_0``#@```#C]
M```'````1_T```H```!/_0``"P```%K]```R````9OT```<```"9_0``#```
M`*']```-````KOT```P```"\_0``"0```,G]```)````T_T```H```#=_0``
M!P```.C]```)````\/T```<```#Z_0``"@````+^```'````#?X``!L````5
M_@``#P```#'^```2````0?X```H```!4_@``%@```%_^```)````=OX``!``
M``"`_@``!P```)'^```2````F?X```0```"L_@``!P```+'^```%````N?X`
M``0```"__@``#````,3^```%````T?X```L```#7_@``%````./^```1````
M^/X``!0````*_P``%P```!__```8````-_\``!P```!0_P``&0```&W_```'
M````A_\```4```"/_P``#0```)7_```,````H_\``!$```"P_P``"````,+_
M```7````R_\```L```#C_P``#````.__```?````_/\``!H````<``$`$P``
M`#<``0`$````2P`!``H```!0``$`!````%L``0`-````8``!``P```!N``$`
M!0```'L``0`)````@0`!``4```"+``$`!P```)$``0`%````F0`!``0```"?
M``$``@```*0``0`X````IP`!`"P```#@``$`$@````T!`0`I````(`$!`#(`
M``!*`0$`"@```'T!`0`L````B`$!`"X```"U`0$`,P```.0!`0`S````&`(!
M`#@```!,`@$`#P```(4"`0`4````E0(!`!@```"J`@$`$````,,"`0`/````
MU`(!`!,```#D`@$`%0```/@"`0`4````#@,!`!(````C`P$`%````#8#`0`5
M````2P,!`"T```!A`P$`+0```(\#`0`Q````O0,!`"X```#O`P$`+P```!X$
M`0`L````3@0!`!,```![!`$`#````(\$`0`-````G`0!``@```"J!`$`%P``
M`+,$`0`(````RP0!``P```#4!`$`*P```.$$`0`A````#04!`!H````O!0$`
M"0```$H%`0!%````5`4!`$$```":!0$`#P```-P%`0`$````[`4!`!,```#Q
M!0$`#@````4&`0`3````%`8!`!@````H!@$`!@```$$&`0`)````2`8!``H`
M``!2!@$`#P```%T&`0`0````;08!``<```!^!@$`#@```(8&`0`%````E08!
M`!L```";!@$`!@```+<&`0`(````O@8!``8```#'!@$`%````,X&`0`1````
MXP8!``X```#U!@$`.`````0'`0`"````/0<!``8```!`!P$`#@```$<'`0`%
M````5@<!``<```!<!P$`#@```&0'`0`&````<P<!`"@```!Z!P$`#````*,'
M`0`<````L`<!``0```#-!P$`*0```-('`0`7````_`<!`!\````4"`$`7```
M`#0(`0`4````D0@!`#X```"F"`$`'P```.4(`0`0````!0D!`!0````6"0$`
M!P```"L)`0`.````,PD!``P```!""0$`#````$\)`0`3````7`D!``H```!P
M"0$`'0```'L)`0`9````F0D!``4```"S"0$`$0```+D)`0`1````RPD!`"0`
M``#="0$`$@````(*`0`5````%0H!`!(````K"@$`#@```#X*`0`9````30H!
M``@```!G"@$`"0```'`*`0`-````>@H!``<```"("@$`"@```)`*`0`'````
MFPH!``\```"C"@$`!@```+,*`0`+````N@H!`!H```#&"@$`"@```.$*`0`'
M````[`H!``@```#T"@$`!0```/T*`0`?`````PL!``8````C"P$`$````"H+
M`0`(````.PL!``T```!$"P$`"````%(+`0`>````6PL!`!(```!Z"P$`+```
M`(T+`0`:````N@L!``D```#5"P$`"@```-\+`0`5````Z@L!``4`````#`$`
M%`````8,`0`$````&PP!`!`````@#`$`!@```#$,`0`'````.`P!`!X```!`
M#`$`*````%\,`0`*````B`P!`!P```"3#`$`$0```+`,`0`+````P@P!`!H`
M``#.#`$`%````.D,`0`$````_@P!``0````##0$`"P````@-`0`%````%`T!
M``8````:#0$`"````"$-`0`&````*@T!``H````Q#0$`&P```#P-`0`T````
M6`T!`#0```"-#0$`(````,(-`0`I````XPT!`"`````-#@$`00```"X.`0`:
M````<`X!`"@```"+#@$`*0```+0.`0!1````W@X!`%`````P#P$`5P```($/
M`0`L````V0\!`"(````&$`$`!@```"D0`0`(````,!`!``4````Y$`$`"```
M`#\0`0`9````2!`!`!D```!B$`$`*@```'P0`0`(````IQ`!`",```"P$`$`
M&0```-00`0`N````[A`!`#0````=$0$`"````%(1`0`7````6Q$!``H```!S
M$0$`!P```'X1`0`A````AA$!`!````"H$0$`#@```+D1`0`+````R!$!``<`
M``#4$0$`$P```-P1`0`(````\!$!``L```#Y$0$`"@````42`0`4````$!(!
M``\````E$@$`,@```#42`0`+````:!(!``X```!T$@$`!0```(,2`0`%````
MB1(!``4```"/$@$`%P```)42`0`/````K1(!``0```"]$@$`"@```,(2`0`)
M````S1(!``L```#7$@$`#0```.,2`0`,````\1(!``X```#^$@$`!0````T3
M`0`$````$Q,!``T````8$P$`,@```"83`0!%````61,!`!<```"?$P$`!P``
M`+<3`0`>````OQ,!`!0```#>$P$`!0```/,3`0`4````^1,!``8````.%`$`
M!P```!44`0`C````'10!``X```!!%`$`*@```%`4`0`&````>Q0!``P```""
M%`$`#0```(\4`0`1````G10!`!<```"O%`$`"P```,<4`0`V````TQ0!``H`
M```*%0$`(@```!45`0`+````.!4!``\```!$%0$`"P```%05`0`@````8!4!
M`"<```"!%0$`*P```*D5`0`)````U14!`#(```#?%0$`)0```!(6`0`P````
M.!8!`#$```!I%@$`+0```)L6`0`.````R18!`!0```#8%@$`!0```.T6`0`.
M````\Q8!`!,````"%P$`$@```!87`0`'````*1<!`!$````Q%P$`$P```$,7
M`0`'````5Q<!`!0```!?%P$`&````'07`0`'````C1<!``4```"5%P$`#```
M`)L7`0`,````J!<!`!(```"U%P$`!````,@7`0`'````S1<!``H```#5%P$`
M"P```.`7`0`,````[!<!``X```#Y%P$`#@````@8`0`%````%Q@!``4````=
M&`$`+@```",8`0`F````4A@!`",```!Y&`$``P```)T8`0`2````H1@!``8`
M``"T&`$`'@```+L8`0`8````VA@!`"4```#S&`$`#0```!D9`0`)````)QD!
M`!\````Q&0$``P```%$9`0`'````51D!``H```!=&0$``@```&@9`0`,````
M:QD!`!4```!X&0$`"P```(X9`0`9````FAD!`"````"T&0$`$@```-49`0`%
M````Z!D!``H```#N&0$`%0```/D9`0`2````#QH!``P````B&@$`!````"\:
M`0`)````-!H!``<````^&@$`#````$8:`0!2````4QH!`!<```"F&@$`)```
M`+X:`0`2````XQH!``<```#V&@$`!@```/X:`0`.````!1L!``P````4&P$`
M#0```"$;`0`5````+QL!`!(```!%&P$`#P```%@;`0`4````:!L!``H```!]
M&P$`&P```(@;`0`0````I!L!``L```"U&P$`:0```,$;`0`:````*QP!`!<`
M``!&'`$`)P```%X<`0`:````AAP!`!<```"A'`$`&P```+D<`0`9````U1P!
M`!\```#O'`$`%P````\=`0`3````)QT!``@````['0$`!P```$0=`0`(````
M3!T!``D```!5'0$`%0```%\=`0`-````=1T!`",```"#'0$`#0```*<=`0`3
M````M1T!``@```#)'0$``P```-(=`0!&````UAT!`#\````='@$`-P```%T>
M`0!7````E1X!``4```#M'@$`'P```/,>`0`O````$Q\!``H```!#'P$`"```
M`$X?`0`-````5Q\!`"T```!E'P$`!````),?`0!/````F!\!`"4```#H'P$`
M'`````X@`0`+````*R`!`!\````W(`$`'0```%<@`0`E````=2`!`"````";
M(`$`)````+P@`0`@````X2`!``L````"(0$`!P````XA`0`-````%B$!``P`
M```D(0$`%P```#$A`0`&````22$!`#D```!0(0$`#````(HA`0`'````ER$!
M``D```"?(0$`$P```*DA`0`'````O2$!``D```#%(0$`!````,\A`0`0````
MU"$!``@```#E(0$`"````.XA`0`$````]R$!``L```#\(0$`#`````@B`0`2
M````%2(!`!$````H(@$`#````#HB`0`:````1R(!``\```!B(@$`!P```'(B
M`0`-````>B(!`!0```"((@$`#@```)TB`0`,````K"(!`"P```"Y(@$`$P``
M`.8B`0`<````^B(!`"@````7(P$`!@```$`C`0`'````1R,!`!,```!/(P$`
M!0```&,C`0`$````:2,!`!<```!N(P$`"@```(8C`0`,````D2,!``D```">
M(P$`!@```*@C`0`)````KR,!``@```"Y(P$`"0```,(C`0`%````S",!``H`
M``#2(P$`$0```-TC`0`&````[R,!``X```#V(P$`#@````4D`0`-````%"0!
M``L````B)`$`'0```"XD`0`+````3"0!``(```!8)`$`'````%LD`0`'````
M>"0!``8```"`)`$`9````(<D`0`)````["0!``<```#V)`$`)@```/XD`0`X
M````)24!`!H```!>)0$`*@```'DE`0`[````I"4!`"@```#@)0$`-`````DF
M`0`9````/B8!`!4```!8)@$`!0```&XF`0`'````="8!``@```!\)@$`!P``
M`(4F`0`%````C28!``<```"3)@$`#@```)LF`0`)````JB8!``8```"T)@$`
M"````+LF`0`+````Q"8!``<```#0)@$`"````-@F`0`'````X28!`!8```#I
M)@$`"0`````G`0`&````"B<!``L````1)P$`$````!TG`0`&````+B<!`!P`
M```U)P$`%````%(G`0`'````9R<!`!$```!O)P$`"````($G`0`.````BB<!
M``@```"9)P$`!0```*(G`0`0````J"<!``D```"Y)P$`$````,,G`0`&````
MU"<!`!D```#;)P$`"@```/4G`0`<`````"@!``<````=*`$`!0```"4H`0`$
M````*R@!`!`````P*`$`%````$$H`0`+````5B@!``T```!B*`$`*````'`H
M`0`8````F2@!`!<```"R*`$`&@```,HH`0`4````Y2@!``0```#Z*`$`"0``
M`/\H`0`*````"2D!``<````4*0$``@```!PI`0`.````'RD!``@````N*0$`
M'P```#<I`0`C````5RD!`",```![*0$`'P```)\I`0`X````ORD!`"8```#X
M*0$`,0```!\J`0`G````42H!`&0```!Y*@$`%````-XJ`0`<````\RH!`%4`
M```0*P$`.````&8K`0!*````GRL!`%L```#J*P$`*````$8L`0`X````;RP!
M`"H```"H+`$`*````-,L`0`L````_"P!`"<````I+0$`)@```%$M`0`;````
M>"T!`#X```"4+0$`(P```-,M`0`7````]RT!`!D````/+@$`2````"DN`0"%
M````<BX!`#````#X+@$`)0```"DO`0!!````3R\!`%L```"1+P$`20```.TO
M`0`Q````-S`!`!T```!I,`$`&````(<P`0`K````H#`!`"$```#,,`$`'P``
M`.XP`0`K````#C$!`"8````Z,0$`(0```&$Q`0`I````@S$!`"<```"M,0$`
M.@```-4Q`0`=````$#(!`!$````N,@$`,P```$`R`0`E````=#(!`#@```":
M,@$`)P```-,R`0`@````^S(!`!\````<,P$`,````#PS`0!I````;3,!`#$`
M``#7,P$`00````DT`0`S````2S0!`"4```!_-`$`/0```*4T`0!E````XS0!
M`$T```!)-0$`+P```)<U`0`N````QS4!`"L```#V-0$`,````"(V`0`J````
M4S8!`#X```!^-@$`5````+TV`0!:````$C<!`$@```!M-P$`2@```+8W`0`R
M`````3@!`!T````T.`$`(P```%(X`0`O````=C@!`"P```"F.`$`+0```-,X
M`0!Q`````3D!`&8```!S.0$`;P```-HY`0"S````2CH!`!<```#^.@$`)0``
M`!8[`0`R````/#L!`"D```!O.P$`/@```)D[`0`B````V#L!`%(```#[.P$`
M)0```$X\`0`+````=#P!`$4```"`/`$`(0```,8\`0`P````Z#P!`"4````9
M/0$`'````#\]`0`Q````7#T!``<```"./0$`!P```)8]`0`$````GCT!``T`
M``"C/0$`"P```+$]`0`.````O3T!``L```#,/0$`!0```-@]`0`0````WCT!
M``(```#O/0$`60```/(]`0`%````3#X!`!(```!2/@$`!````&4^`0`'````
M:CX!``@```!R/@$`!0```'L^`0`#````@3X!`!````"%/@$`#````)8^`0`3
M````HSX!``T```"W/@$``@```,4^`0`'````R#X!``8```#0/@$`%````-<^
M`0`,````[#X!`!@```#Y/@$`!@```!(_`0`2````&3\!``P````L/P$``P``
M`#D_`0`J````/3\!``0```!H/P$`!@```&T_`0`'````=#\!`!\```!\/P$`
M-0```)P_`0`N````TC\!`"\````!0`$`%P```#%``0`?````24`!`"(```!I
M0`$`)0```(Q``0`@````LD`!`!L```#30`$`&````.]``0`D````"$$!`!\`
M```M00$`&@```$U!`0`A````:$$!`"````"*00$`&@```*M!`0`R````QD$!
M`!H```#Y00$`+P```!1"`0`K````1$(!`!\```!P0@$`(P```)!"`0`?````
MM$(!`!H```#40@$`(0```.]"`0`E````$4,!`"8````W0P$`)0```%Y#`0`D
M````A$,!`!@```"I0P$`'0```,)#`0`D````X$,!`!@````%1`$`(@```!Y$
M`0`L````040!`"\```!N1`$`%0```)Y$`0`E````M$0!`#P```#:1`$`'P``
M`!=%`0`C````-T4!`!\```!;10$`(````'M%`0`:````G$4!`!@```"W10$`
M)@```-!%`0`>````]T4!`"D````61@$`'@```$!&`0`Q````7T8!``D```"1
M1@$`#````)M&`0`7````J$8!`"\```#`1@$`)````/!&`0`'````%4<!`!\`
M```=1P$`#P```#U'`0`4````34<!``X```!B1P$`#0```'%'`0`D````?T<!
M``4```"D1P$`!P```*I'`0`B````LD<!`"4```#51P$`&@```/M'`0`=````
M%D@!`!H````T2`$`!P```$](`0#'````5T@!``L````?20$`%0```"M)`0`&
M````04D!``D```!(20$`&````%))`0`+````:TD!``T```!W20$`%P```(5)
M`0`&````G4D!`#,```"D20$`$P```-A)`0`3````[$D!``<`````2@$`#P``
M``A*`0`'````&$H!`#(````@2@$`!````%-*`0`A````6$H!`!,```!Z2@$`
M#````(Y*`0`1````FTH!`#(```"M2@$`%@```.!*`0`(````]TH!`!T`````
M2P$`"0```!Y+`0`*````*$L!`!0````S2P$`"@```$A+`0`=````4TL!``@`
M``!Q2P$`'P```'I+`0`(````FDL!`!H```"C2P$`)P```+Y+`0`&````YDL!
M`!4```#M2P$`!P````-,`0`(````"TP!``D````43`$`/P```!Y,`0`'````
M7DP!``\```!F3`$`#@```'9,`0`0````A4P!``D```"63`$`"0```*!,`0`(
M````JDP!`!,```"S3`$`!P```,=,`0`9````STP!``H```#I3`$`"@```/1,
M`0`)````_TP!`!<````)30$`%````"%-`0`*````-DT!``P```!!30$`%P``
M`$Y-`0`$````9DT!`"H```!K30$`#````)9-`0`1````HTT!``<```"U30$`
M`@```+U-`0`0````P$T!`!@```#130$`"P```.I-`0`#````]DT!``@```#Z
M30$`$P````-.`0`7````%TX!``8````O3@$`!P```#9.`0`-````/DX!``L`
M``!,3@$`%````%A.`0`5````;4X!``X```"#3@$`+P```)).`0`@````PDX!
M`!P```#C3@$`%0````!/`0`,````%D\!`#$````C3P$`!0```%5/`0`2````
M6T\!`#\```!N3P$`$@```*Y/`0`*````P4\!``8```#,3P$`!````--/`0`$
M````V$\!``H```#=3P$`$P```.A/`0`%````_$\!``8````"4`$`!@````E0
M`0`(````$%`!``0````94`$`#````!Y0`0`*````*U`!`#D````V4`$`+@``
M`'!0`0`I````GU`!``4```#)4`$`&0```,]0`0`1````Z5`!``(```#[4`$`
M!````/Y0`0`*`````U$!``8````.40$`!0```!51`0`#````&U$!``P````?
M40$`10```"Q1`0`R````<E$!`!H```"E40$`-0```,!1`0`T````]E$!`"@`
M```K4@$`&0```%12`0!R````;E(!`"````#A4@$`-0````)3`0`A````.%,!
M`$4```!:4P$`,````*!3`0`H````T5,!`"D```#Z4P$`)@```"14`0`E````
M2U0!`"@```!Q5`$`*````)I4`0`B````PU0!`"L```#F5`$`,````!)5`0`2
M````0U4!`!,```!650$`$````&I5`0!Y````>U4!``D```#U50$`H0```/]5
M`0!S````H58!`'P````55P$`*P```))7`0!4````OE<!`!<````36`$`)P``
M`"M8`0`6````4U@!``\```!J6`$`%P```'I8`0`?````DE@!`$````"R6`$`
M'P```/-8`0`<````$UD!`%$````P60$`&@```()9`0`4````G5D!``H```"R
M60$`!0```+U9`0`&````PUD!``@```#*60$`!0```--9`0`2````V5D!`!``
M``#L60$`$P```/U9`0`=````$5H!``\````O6@$`#P```#]:`0`$````3UH!
M``D```!46@$`"P```%Y:`0`'````:EH!``4```!R6@$`%````'A:`0`'````
MC5H!``@```"56@$`#P```)Y:`0`(````KEH!``P```"W6@$`#P```,1:`0`&
M````U%H!`!0```#;6@$`!@```/!:`0`,````]UH!`!$````$6P$`"````!9;
M`0`$````'UL!`!D````D6P$`$0```#Y;`0`*````4%L!``4```!;6P$`&```
M`&%;`0`3````>EL!`!P```".6P$`$0```*M;`0`$````O5L!``\```#"6P$`
M!P```-);`0`$````VEL!`!D```#?6P$`!P```/E;`0`"`````5P!``(````$
M7`$`$0````=<`0`)````&5P!``8````C7`$`$@```"I<`0`7````/5P!``8`
M``!57`$`)P```%Q<`0`"````A%P!``0```"'7`$`#P```(Q<`0`3````G%P!
M``<```"P7`$`!P```+A<`0`1````P%P!``8```#27`$`&````-E<`0`&````
M\EP!`!,```#Y7`$`$`````U=`0`2````'ET!``(````Q70$`!@```#1=`0`,
M````.UT!``D```!(70$`$0```%)=`0`B````9%T!``<```"'70$`!P```(]=
M`0`+````EUT!``4```"C70$``@```*E=`0`+````K%T!`&(!``"X70$`3```
M`!M?`0`1````:%\!`!(```!Z7P$`#P```(U?`0`.````G5\!``<```"L7P$`
M"@```+1?`0`'````OU\!``0```#'7P$`&````,Q?`0`=````Y5\!`"P````#
M8`$`'0```#!@`0`@````3F`!`"8```!O8`$`%P```)9@`0`H````KF`!``P`
M``#78`$`*P```.1@`0`.````$&$!`!$````?80$`$@```#%A`0`%````1&$!
M`",```!*80$`"````&YA`0`*````=V$!`!,```""80$`#P```)9A`0`+````
MIF$!`!4```"R80$`0P```,AA`0`B````#&(!`#$````O8@$`;P```&%B`0`(
M````T6(!``H```#:8@$`"@```.5B`0`W````\&(!`"(````H8P$`$````$MC
M`0`;````7&,!`"````!X8P$`,````)EC`0`0````RF,!``\```#;8P$`$P``
M`.MC`0`0````_V,!``8````09`$`B0```!=D`0`+````H60!`!$```"M9`$`
M'0```+]D`0`*````W60!`!````#H9`$`$````/ED`0`)````"F4!``L````4
M90$`+````"!E`0`<````364!`#L```!J90$`10```*9E`0!6````[&4!`%,`
M``!#9@$`60```)=F`0!6````\68!`#X```!(9P$`#@```(=G`0`3````EF<!
M``X```"J9P$`$````+EG`0`8````RF<!``4```#C9P$`!@```.EG`0`*````
M\&<!``4```#[9P$`!@````%H`0`&````"&@!`!$````/:`$`"@```"%H`0`E
M````+&@!`"0```!2:`$`$````'=H`0`2````B&@!``P```";:`$`!@```*AH
M`0`(````KV@!``D```"X:`$`#````,)H`0`4````SV@!`!D```#D:`$`#@``
M`/YH`0`2````#6D!`!<````@:0$`'@```#AI`0`C````5VD!`!H```![:0$`
M$````)9I`0`7````IVD!``T```"_:0$`*@```,UI`0`8````^&D!`!8````1
M:@$`&0```"AJ`0`3````0FH!`$\```!6:@$`,0```*9J`0`D````V&H!``8`
M``#]:@$`"0````1K`0`T````#FL!``X```!#:P$`!@```%)K`0`*````66L!
M``@```!D:P$`"````&UK`0`%````=FL!``<```!\:P$`"@```(1K`0`$````
MCVL!`!P```"4:P$`#````+%K`0`1````OFL!``\```#0:P$`%0```.!K`0`F
M````]FL!``L````=;`$`&@```"EL`0`=````1&P!`"$```!B;`$`&````(1L
M`0`/````G6P!`!````"M;`$`$0```+YL`0`O````T&P!`!L`````;0$`&P``
M`!QM`0`'````.&T!``8```!`;0$`"````$=M`0`,````4&T!``0```!=;0$`
M"0```&)M`0`3````;&T!``L```"`;0$`$0```(QM`0`6````GFT!`!\```"U
M;0$`!P```-5M`0`2````W6T!``4```#P;0$`%@```/9M`0`/````#6X!``P`
M```=;@$`,0```"IN`0!"````7&X!``D```"?;@$`"````*EN`0`4````LFX!
M``4```#';@$`!0```,UN`0`0````TVX!``L```#D;@$`&0```/!N`0`[````
M"F\!`!(```!&;P$`1@```%EO`0`O````H&\!`#0```#0;P$`+@````5P`0`M
M````-'`!``D```!B<`$`"````&QP`0`'````=7`!``H```!]<`$`"0```(AP
M`0`C````DG`!`#0```"V<`$`(@```.MP`0!&````#G$!`"$```!5<0$`(0``
M`'=Q`0!#````F7$!`$(```#=<0$`'P```"!R`0!`````0'(!`"<```"!<@$`
M*@```*ER`0!#````U'(!`"$````8<P$`)P```#IS`0`L````8G,!`!H```"/
M<P$`'@```*IS`0`J````R7,!`"L```#T<P$`*P```"!T`0`2````3'0!``X`
M``!?=`$`"@```&YT`0`'````>70!``T```"!=`$`"````(]T`0`-````F'0!
M`!\```"F=`$`(P```,9T`0`'````ZG0!``<```#R=`$`%0```/IT`0`*````
M$'4!``8````;=0$`!@```")U`0`(````*74!``8````R=0$`*0```#EU`0`(
M````8W4!``L```!L=0$`!P```'AU`0`&````@'4!``4```"'=0$`!P```(UU
M`0`&````E74!``H```"<=0$`)P```*=U`0`2````SW4!``@```#B=0$`"```
M`.MU`0`.````]'4!``,````#=@$`!P````=V`0`)````#W8!``,````9=@$`
M"0```!UV`0`%````)W8!`!<````M=@$`!````$5V`0`(````2G8!``8```!3
M=@$`#0```%IV`0`)````:'8!`"<```!R=@$`!````)IV`0`&````GW8!``D`
M``"F=@$`"@```+!V`0`,````NW8!``P```#(=@$`!P```-5V`0`#````W78!
M``,```#A=@$`%P```.5V`0`6````_78!`"0````4=P$`"````#EW`0`%````
M0G<!``@```!(=P$`!P```%%W`0`*````67<!`$4```!D=P$`'0```*IW`0`X
M````R'<!`"(````!>`$`%P```"1X`0`&````/'@!``8```!#>`$`%0```$IX
M`0`5````8'@!`!\```!V>`$`*P```)9X`0`:````PG@!`",```#=>`$`,0``
M``%Y`0`)````,WD!``8````]>0$`"````$1Y`0`7````37D!``X```!E>0$`
M#````'1Y`0`1````@7D!``X```"3>0$`$0```*)Y`0`.````M'D!``P```##
M>0$`%0```-!Y`0`)````YGD!`!P```#P>0$`'0````UZ`0`2````*WH!``\`
M```^>@$`$@```$YZ`0`%````87H!``H```!G>@$`!0```')Z`0`3````>'H!
M`!<```",>@$`50```*1Z`0!B````^GH!``,```!=>P$`$P```&%[`0`I````
M=7L!``4```"?>P$`!````*5[`0`<````JGL!`!X```#'>P$`$0```.9[`0`-
M````^'L!`!$````&?`$`#````!A\`0`;````)7P!`"0```!!?`$`!0```&9\
M`0`>````;'P!``4```"+?`$`%0```)%\`0`+````IWP!`!,```"S?`$`#P``
M`,=\`0`2````UWP!`!,```#J?`$`&````/Y\`0`3````%WT!``T````K?0$`
M!````#E]`0`+````/GT!``@```!*?0$`%P```%-]`0`5````:WT!`!(```"!
M?0$`"````)1]`0`$````G7T!``T```"B?0$`!P```+!]`0`)````N'T!``\`
M``#"?0$`"P```-)]`0`(````WGT!``\```#G?0$`"0```/=]`0`$`````7X!
M``<````&?@$`!P````Y^`0`(````%GX!`!4````??@$`!P```#5^`0`%````
M/7X!``4```!#?@$`&````$E^`0!0````8GX!`"$```"S?@$`#@```-5^`0`1
M````Y'X!``4```#V?@$`!0```/Q^`0`9`````G\!`!H````<?P$`+````#=_
M`0`T````9'\!`"@```"9?P$`"0```,)_`0`E````S'\!`"(```#R?P$`#P``
M`!6``0`(````)8`!``P````N@`$`!@```#N``0`'````0H`!`!H```!*@`$`
M$0```&6``0`*````=X`!``L```""@`$`"@```(Z``0`/````F8`!`"$```"I
M@`$`(@```,N``0`@````[H`!`"$````/@0$`)````#&!`0`C````5H$!`!\`
M``!Z@0$`)@```)J!`0`A````P8$!`"0```#C@0$`*0````B"`0`E````,H(!
M`!T```!8@@$`'@```':"`0`@````E8(!`!L```"V@@$`)@```-*"`0`M````
M^8(!`"L````G@P$`(@```%.#`0`K````=H,!`#<```"B@P$`'0```-J#`0`=
M````^(,!`!D````6A`$`&0```#"$`0`P````2H0!`"$```![A`$`$@```)V$
M`0`A````L(0!`"@```#2A`$`&@```/N$`0`8````%H4!`!X````OA0$`$0``
M`$Z%`0"V````8(4!`!(````7A@$`'````"J&`0`E````1X8!`"8```!MA@$`
M(````)2&`0`D````M88!`!H```#:A@$`&@```/6&`0`D````$(<!`"0````U
MAP$`*P```%J'`0`L````AH<!`"<```"SAP$`C````-N'`0`?````:(@!`!4`
M``"(B`$`%0```)Z(`0`>````M(@!`"D```#3B`$`*0```/V(`0!$````)XD!
M`$0```!LB0$`"P```+&)`0`$````O8D!``8```#"B0$`!0```,F)`0`*````
MSXD!``@```#:B0$`#P```..)`0`6````\XD!`!$````*B@$`"````!R*`0`$
M````)8H!`!`````JB@$`#P```#N*`0`+````2XH!``X```!7B@$`$````&:*
M`0`.````=XH!`!(```"&B@$`#````)F*`0`V````IHH!``@```#=B@$`"P``
M`.:*`0`&````\HH!`!(```#YB@$`&`````R+`0`;````)8L!``@```!!BP$`
M`@```$J+`0`&````38L!`!(```!4BP$`#@```&>+`0`%````=HL!``X```!\
MBP$`"````(N+`0`#````E(L!``X```"8BP$`"````*>+`0`)````L(L!``8`
M``"ZBP$`#0```,&+`0`'````SXL!``P```#7BP$`$0```.2+`0`,````]HL!
M``P````#C`$`$0```!",`0`)````(HP!``8````LC`$`"P```#.,`0`,````
M/XP!``L```!,C`$`$0```%B,`0`<````:HP!``L```"'C`$`#0```).,`0`?
M````H8P!`!0```#!C`$`&@```-:,`0`Q````\8P!``H````CC0$`%0```"Z-
M`0`2````1(T!`!4```!7C0$`$@```&V-`0`5````@(T!`"0```"6C0$`"P``
M`+N-`0`'````QXT!``T```#/C0$`*P```-V-`0`1````"8X!``L````;C@$`
M(@```">.`0`O````2HX!``H```!ZC@$`"0```(6.`0`>````CXX!``L```"N
MC@$`&P```+J.`0`;````UHX!``<```#RC@$`%P```/J.`0`5````$H\!`!P`
M```HCP$`%P```$6/`0`.````78\!``H```!LCP$`"````'>/`0`+````@(\!
M`"(```",CP$`.0```*^/`0`7````Z8\!`",````!D`$`!0```"60`0`(````
M*Y`!`"T````TD`$`"@```&*0`0`&````;9`!``8```!TD`$`5@```'N0`0`#
M````TI`!``<```#6D`$`!0```-Z0`0`+````Y)`!``L```#PD`$`$````/R0
M`0`2````#9$!`!D````@D0$`&````#J1`0`;````4Y$!`!L```!OD0$`"@``
M`(N1`0`'````EI$!``L```">D0$`"@```*J1`0`"````M9$!``8```"XD0$`
M#````+^1`0`E````S)$!`"````#RD0$`%@```!.2`0`,````*I(!`!`````W
MD@$`#@```$B2`0`0````5Y(!``0```!HD@$`!P```&V2`0`/````=9(!`"$`
M``"%D@$`&````*>2`0`#````P)(!`!T```#$D@$`+````.*2`0`K````#Y,!
M`!P````[DP$`*0```%B3`0`C````@I,!`!<```"FDP$`&@```+Z3`0`'````
MV9,!``@```#ADP$`!@```.J3`0`&````\9,!``X```#XDP$`#@````>4`0`/
M````%I0!``T````FE`$`$````#24`0`/````190!``L```!5E`$`$@```&&4
M`0`#````=)0!``D```!XE`$`$@```(*4`0`.````E90!`"\```"DE`$`#0``
M`-24`0`(````XI0!``T```#KE`$`(````/F4`0`E````&I4!`"8```!`E0$`
M)0```&>5`0`C````C94!`",```"QE0$`*P```-65`0`B`````98!`!H````D
ME@$``P```#^6`0`.````0Y8!``@```!2E@$`"P```%N6`0`#````9Y8!``4`
M``!KE@$`"````'&6`0`)````>I8!``L```"$E@$`#P```)"6`0`2````H)8!
M``H```"SE@$`#@```+Z6`0`.````S98!``0```#<E@$``P```.&6`0`3````
MY98!`!4```#YE@$`#`````^7`0`'````')<!``8````DEP$`#@```"N7`0`:
M````.I<!``8```!5EP$`!P```%R7`0`-````9)<!``X```!REP$`%P```(&7
M`0`(````F9<!``,```"BEP$`)0```*:7`0`-````S)<!`$X```#:EP$`%```
M`"F8`0`(````/I@!``H```!'F`$`$0```%*8`0`*````9)@!``P```!OF`$`
M!0```'R8`0`.````@I@!``(```"1F`$`!0```)28`0`)````FI@!`!,```"D
MF`$`&@```+B8`0`3````TY@!`!@```#GF`$`(`````"9`0`.````(9D!`!(`
M```PF0$`&0```$.9`0`$````79D!``D```!BF0$`%P```&R9`0`(````A)D!
M`!$```"-F0$`!0```)^9`0`8````I9D!``@```"^F0$`!@```,>9`0`=````
MSID!``T```#LF0$`"````/J9`0`(`````YH!``4````,F@$`"0```!*:`0`'
M````')H!`!4````DF@$``@```#J:`0`&````/9H!``P```!$F@$`#0```%&:
M`0`(````7YH!`!0```!HF@$`!````'V:`0`(````@IH!``<```"+F@$``P``
M`).:`0`3````EYH!`#T```"KF@$`)@```.F:`0`I````$)L!``<````ZFP$`
M!````$*;`0`)````1YL!``@```!1FP$`$````%J;`0`3````:YL!``<```!_
MFP$`!@```(>;`0`-````CIL!``8```"<FP$`!````*.;`0`Q````J)L!`#8`
M``#:FP$`,P```!&<`0`:````19P!``4```!@G`$`#````&:<`0`%````<YP!
M``8```!YG`$`"````("<`0`8````B9P!`!(```"BG`$`%P```+6<`0`$````
MS9P!``T```#2G`$`!0```."<`0`1````YIP!``T```#XG`$`"`````:=`0`7
M````#YT!``,````GG0$`!````"N=`0`#````,)T!``L````TG0$`"@```$"=
M`0`,````2YT!``@```!8G0$`"0```&&=`0`%````:YT!`#T```!QG0$`,0``
M`*^=`0`_````X9T!`!T````AG@$`00```#^>`0`W````@9X!`"@```"YG@$`
M.0```.*>`0`N````')\!`#(```!+GP$`(0```'Z?`0`1````H)\!`!4```"R
MGP$`#````,B?`0`O````U9\!`"0````%H`$`)````"J@`0`C````3Z`!``D`
M``!SH`$`"@```'V@`0`*````B*`!``8```"3H`$`)0```)J@`0`F````P*`!
M`#````#GH`$`"0```!BA`0`>````(J$!`"H```!!H0$`&@```&RA`0`0````
MAZ$!``8```"8H0$`#0```)^A`0`-````K:$!``\```"[H0$`$@```,NA`0`[
M````WJ$!`)$````:H@$`9````*RB`0`5````$:,!``H````GHP$`"P```#*C
M`0`1````/J,!`!(```!0HP$`#@```&.C`0`&````<J,!`!(```!YHP$`%```
M`(RC`0`1````H:,!``@```"SHP$`$0```+RC`0`D````SJ,!`"H```#SHP$`
M;@```!ZD`0`*````C:0!``8```"8I`$`%@```)^D`0`*````MJ0!``0```#!
MI`$`"P```,:D`0`G````TJ0!`!0```#ZI`$`"P````^E`0`-````&Z4!``\`
M```II0$`$P```#FE`0`E````3:4!`"0```!SI0$`'````)BE`0`>````M:4!
M`"$```#4I0$`(````/:E`0`6````%Z8!`!$````NI@$`$````$"F`0`3````
M4:8!`!(```!EI@$`$@```'BF`0`5````BZ8!`!0```"AI@$`$````+:F`0`/
M````QZ8!`"D```#7I@$`$0````&G`0`1````$Z<!`#L````EIP$`%````&&G
M`0`&````=J<!``P```!]IP$`)P```(JG`0`A````LJ<!`!8```#4IP$`%0``
M`.NG`0`2`````:@!`!8````4J`$`'````"NH`0`3````2*@!`!4```!<J`$`
M&@```'*H`0`8````C:@!`!T```"FJ`$`(0```,2H`0`A````YJ@!`!4````(
MJ0$`%````!ZI`0`4````,ZD!`!@```!(J0$`&@```&&I`0`8````?*D!`!8`
M``"5J0$`"P```*RI`0`/````N*D!``0```#(J0$`!````,VI`0`&````TJD!
M``L```#9J0$`$0```.6I`0`&````]ZD!``L```#^J0$`!@````JJ`0`'````
M$:H!``<````9J@$`!P```"&J`0`%````*:H!`!4````OJ@$`!@```$6J`0`)
M````3*H!``0```!6J@$`!````%NJ`0`'````8*H!``T```!HJ@$`#````':J
M`0`.````@ZH!``P```"2J@$`!0```)^J`0`I````I:H!``T```#/J@$`"P``
M`-VJ`0`+````Z:H!``D```#UJ@$`$````/^J`0`P````$*L!``0```!!JP$`
M"````$:K`0`%````3ZL!``D```!5JP$`"````%^K`0`1````:*L!``8```!Z
MJP$`"0```(&K`0`'````BZL!``4```"3JP$`!````)FK`0`,````GJL!`!$`
M``"KJP$`#P```+VK`0`2````S:L!`!8```#@JP$`'@```/>K`0`:````%JP!
M``@````QK`$`"````#JL`0`#````0ZP!``8```!'K`$`)0```$ZL`0`'````
M=*P!``<```!\K`$`#0```(2L`0`-````DJP!``<```"@K`$`!````*BL`0`'
M````K:P!``8```"UK`$`#0```+RL`0`'````RJP!``@```#2K`$`"0```-NL
M`0`3````Y:P!`!4```#YK`$`#0````^M`0`2````':T!``@````PK0$`#```
M`#FM`0`(````1JT!``0```!/K0$`$````%2M`0!"````9:T!``8```"HK0$`
M!````*^M`0`?````M*T!``X```#4K0$`#P```..M`0`.````\ZT!``P````"
MK@$`"0````^N`0`'````&:X!``H````AK@$`"0```"RN`0`.````-JX!`!``
M``!%K@$`)0```%:N`0`E````?*X!`"(```"BK@$`"@```,6N`0`'````T*X!
M``D```#8K@$`"P```.*N`0`)````[JX!``4```#XK@$`"````/ZN`0`(````
M!Z\!``4````0KP$`$````!:O`0!.````)Z\!`!@```!VKP$`"0```(^O`0`&
M````F:\!``,```"@KP$`$````*2O`0`0````M:\!`!0```#&KP$`!@```-NO
M`0`*````XJ\!``D```#MKP$``@```/>O`0`$````^J\!`",```#_KP$``P``
M`".P`0`%````)[`!``H````ML`$`"@```#BP`0`&````0[`!``8```!*L`$`
M"P```%&P`0`-````7;`!``8```!KL`$`"````'*P`0`*````>[`!``0```"&
ML`$`!0```(NP`0!V````D;`!``L````(L0$`#@```!2Q`0`7````([$!``0`
M```[L0$`"````$"Q`0`5````2;$!`"\```!?L0$`#0```(^Q`0`*````G;$!
M``X```"HL0$`"P```+>Q`0`)````P[$!`!0```#-L0$`,P```.*Q`0`H````
M%K(!`"<````_L@$`&@```&>R`0`-````@K(!``,```"0L@$`!P```)2R`0`'
M````G+(!``L```"DL@$`$````+"R`0`.````P;(!``D```#0L@$`$````-JR
M`0`;````Z[(!``D````'LP$`"0```!&S`0`/````&[,!``H````KLP$`30``
M`#:S`0`>````A+,!``T```"CLP$`"@```+&S`0`A````O+,!`$P```#>LP$`
M&0```"NT`0`%````1;0!`!\```!+M`$`+@```&NT`0`'````FK0!``8```"B
MM`$`"P```*FT`0`&````M;0!``<```"\M`$`)P```,2T`0`F````[+0!`"H`
M```3M0$`!@```#ZU`0`'````1;4!`"\```!-M0$`50```'VU`0`5````T[4!
M`"<```#IM0$`$P```!&V`0`"````);8!``P````HM@$`"````#6V`0`,````
M/K8!``H```!+M@$`!P```%:V`0`)````7K8!``8```!HM@$`"0```&^V`0`,
M````>;8!``@```"&M@$`"0```(^V`0`(````F;8!`#(```"BM@$`!P```-6V
M`0`/````W;8!`!$```#MM@$`$````/^V`0`*````$+<!``X````;MP$`#```
M`"JW`0`*````-[<!``H```!"MP$`"@```$VW`0`*````6+<!``<```!CMP$`
M#@```&NW`0`<````>K<!``<```"7MP$`"@```)^W`0`4````JK<!``H```"_
MMP$`$````,JW`0`'````V[<!`!@```#CMP$`!````/RW`0`'`````;@!``4`
M```)N`$`!`````^X`0`.````%+@!``4````CN`$`#0```"FX`0`7````-[@!
M``\```!/N`$`%@```%^X`0`9````=K@!`!<```"0N`$`'````*BX`0`6````
MQ;@!``<```#<N`$`!@```.2X`0`.````Z[@!``L```#ZN`$`%P````:Y`0`&
M````'KD!`!P````EN0$`"P```$*Y`0`-````3KD!`"(```!<N0$`&@```'^Y
M`0`5````FKD!``<```"PN0$`#0```+BY`0`%````QKD!`!````#,N0$`$P``
M`-VY`0`&````\;D!``D```#XN0$`!0````*Z`0`'````"+H!``0````0N@$`
M!````!6Z`0`#````&KH!`#L````>N@$`,P```%JZ`0`2````CKH!`"\```"A
MN@$`,@```-&Z`0`.````!+L!`#P````3NP$`+P```%"[`0`T````@+L!`#0`
M``"UNP$`.````.J[`0`2````([P!`!,````VO`$`&````$J\`0`3````8[P!
M`!4```!WO`$`$@```(V\`0`2````H+P!`!L```"SO`$`$P```,^\`0`5````
MX[P!`!H```#YO`$`+@```!2]`0`N````0[T!`#(```!RO0$`+P```*6]`0`P
M````U;T!`"T````&O@$`'0```#2^`0`3````4KX!`!0```!FO@$`"P```'N^
M`0`9````A[X!``H```"AO@$`#P```*R^`0`L````O+X!`"X```#IO@$`(@``
M`!B_`0`+````.[\!`%4```!'OP$`1@```)V_`0`.````Y+\!``4```#SOP$`
M'````/F_`0`,````%L`!`!`````CP`$`$@```#3``0`%````1\`!``H```!-
MP`$`"0```%C``0`/````8L`!`!$```!RP`$`"@```(3``0`+````C\`!``P`
M``";P`$`(````*C``0`#````R<`!``@```#-P`$`!@```-;``0`,````W<`!
M``X```#JP`$`"P```/G``0!"````!<$!``(```!(P0$`!@```$O!`0`-````
M4L$!``4```!@P0$`!P```&;!`0`9````;L$!``8```"(P0$`+@```(_!`0`0
M````OL$!`!T```#/P0$`!````.W!`0`J````\L$!`!P````=P@$`(````#K"
M`0!9````6\(!`!0```"UP@$`1P```,K"`0`9````$L,!``X````LPP$`'```
M`#O#`0`-````6,,!`!0```!FPP$`#@```'O#`0`,````BL,!`!(```"7PP$`
M"@```*K#`0`<````M<,!`!D```#2PP$`!0```.S#`0`3````\L,!`!`````&
MQ`$`)@```!?$`0`3````/L0!`!4```!2Q`$`$@```&C$`0`1````>\0!`!D`
M``"-Q`$`!P```*?$`0`(````K\0!`!,```"XQ`$`#@```,S$`0`2````V\0!
M``\```#NQ`$`&@```/[$`0`/````&<4!`!H````IQ0$`%````$3%`0`)````
M6<4!``H```!CQ0$`"````&[%`0`%````=\4!``D```!]Q0$`!@```(?%`0`0
M````CL4!``@```"?Q0$`#@```*C%`0`(````M\4!`!(```#`Q0$`$@```-/%
M`0`H````YL4!`!@````/Q@$`"0```"C&`0`*````,L8!`!D````]Q@$`"@``
M`%?&`0`B````8L8!``8```"%Q@$`&````(S&`0`)````I<8!``<```"OQ@$`
M&@```+?&`0`K````TL8!``H```#^Q@$`'P````G'`0`-````*<<!``P````W
MQP$`&0```$3'`0`5````7L<!``0```!TQP$`!P```'G'`0`,````@<<!``<`
M``".QP$`!0```);'`0`(````G,<!``8```"EQP$`"````*S'`0`8````M<<!
M`"8```#.QP$`+0```/7'`0`:````(\@!`"`````^R`$`'P```%_(`0!$````
M?\@!`!P```#$R`$`'0```.'(`0`D````_\@!`%L````DR0$`6P```(#)`0!*
M````W,D!`"(````GR@$`%P```$K*`0`%````8LH!``<```!HR@$`#@```'#*
M`0`(````?\H!`!<```"(R@$`&0```*#*`0`N````NLH!``@```#IR@$`(@``
M`/+*`0`8````%<L!`!\````NRP$`.P```$[+`0`%````BLL!`!4```"0RP$`
M"P```*;+`0`/````LLL!`",```#"RP$`&````.;+`0`1````_\L!``X````1
MS`$`!P```"#,`0`2````*,P!``<````[S`$`!````$/,`0`-````2,P!`!4`
M``!6S`$`&````&S,`0`O````A<P!``L```"US`$`$0```,',`0`%````T\P!
M``4```#9S`$`!0```-_,`0`<````Y<P!``L````"S0$`!`````[-`0`+````
M$\T!``D````?S0$`"@```"G-`0`,````-,T!``T```!!S0$`%P```$_-`0`+
M````9\T!``,```!SS0$`#P```'?-`0`Y````A\T!`$H```#!S0$`'`````S.
M`0`)````*<X!`"`````SS@$`$P```%3.`0`%````:,X!`!$```!NS@$`"```
M`(#.`0`+````B<X!`"<```"5S@$`#````+W.`0`C````RLX!``<```#NS@$`
M#0```/;.`0`.````!,\!`!,````3SP$`&0```"?/`0`+````0<\!`#,```!-
MSP$`!P```('/`0`@````B<\!`!$```"JSP$`%0```+S/`0`-````TL\!`!P`
M``#@SP$`00```/W/`0`S````/]`!``@```!ST`$`,````'S0`0`L````K=`!
M`#8```#:T`$`-P```!'1`0`P````2=$!`!,```!ZT0$`%@```([1`0`)````
MI=$!`!(```"OT0$`$@```,+1`0`8````U=$!``@```#NT0$`&P```/?1`0`2
M````$](!``<````FT@$`%P```"[2`0`B````1M(!``4```!IT@$`!0```&_2
M`0`+````==(!``L```"!T@$`%````(W2`0`$````HM(!``@```"GT@$`"@``
M`+#2`0`.````N](!``P```#*T@$`$````-?2`0`0````Z-(!``8```#YT@$`
M!@````#3`0`K````!],!`",````STP$`(````%?3`0`#````>-,!``@```!\
MTP$`!@```(73`0`/````C-,!`!L```"<TP$`)P```+C3`0`/````X-,!``@`
M``#PTP$`(0```/G3`0`#````&]0!``8````?U`$`"0```";4`0`"````,-0!
M``P````SU`$`%0```$#4`0`+````5M0!`!D```!BU`$`'@```'S4`0`1````
MF]0!``4```"MU`$`"@```+/4`0`5````OM0!`!(```#4U`$`#````.?4`0`%
M````]-0!``H```#ZU`$`"`````75`0`3````#M4!`$P````BU0$`'0```&_5
M`0`E````C=4!`!$```"SU0$`"0```,75`0`#````S]4!``H```#3U0$`"@``
M`-[5`0`.````Z=4!`!D```#XU0$`#0```!+6`0`+````(-8!`!T````LU@$`
M"0```$K6`0`6````5-8!``\```!KU@$`"@```'O6`0!@````AM8!`!H```#G
MU@$`$0````+7`0`=````%-<!`!@````RUP$`$````$O7`0`8````7-<!`!4`
M``!UUP$`&0```(O7`0`<````I=<!`!4```#"UP$`"@```-C7`0`'````X]<!
M``@```#KUP$`"0```/37`0`6````_M<!``L````5V`$`,P```"'8`0`6````
M5=@!`!@```!LV`$`"0```(78`0`$````C]@!`$D```"4V`$`/@```-[8`0`Y
M````'=D!`%L```!7V0$`!0```+/9`0`T````N=D!`"4```#NV0$`#````!3:
M`0`&````(=H!``X````HV@$`-@```#?:`0`$````;MH!`$P```!SV@$`*P``
M`,#:`0`I````[-H!``L````6VP$`(0```"+;`0`>````1-L!`!<```!CVP$`
M$P```'O;`0`3````C]L!`"(```"CVP$`$````,;;`0`&````U]L!``T```#>
MVP$`"P```.S;`0`1````^-L!``D````*W`$`+P```!3<`0`,````1-P!``H`
M``!1W`$`"````%S<`0`0````9=P!``<```!VW`$`"0```'[<`0`'````B-P!
M`!````"0W`$`"0```*'<`0`)````J]P!``,```"UW`$`!P```+G<`0`)````
MP=P!`!````#+W`$`#@```-S<`0`)````Z]P!`!H```#UW`$`#````!#=`0`'
M````'=T!`!$````EW0$`%@```#?=`0`*````3MT!``D```!9W0$`(@```&/=
M`0`0````AMT!`",```"7W0$`*P```+O=`0`)````Y]T!``D```#QW0$`%P``
M`/O=`0`'````$]X!``0````;W@$`'0```"#>`0`)````/MX!``L```!(W@$`
M"````%3>`0`'````7=X!``D```!EW@$`"````&_>`0`)````>-X!``4```""
MW@$`!P```(C>`0`1````D-X!``8```"BW@$`#@```*G>`0`*````N-X!``P`
M``##W@$`"P```-#>`0`;````W-X!``H```#XW@$``@````/?`0`A````!M\!
M``8````HWP$`!@```"_?`0!S````-M\!``@```"JWP$`!@```+/?`0`;````
MNM\!`"<```#6WP$`#P```/[?`0`=````#N`!`$@````LX`$`'````'7@`0`?
M````DN`!`!(```"RX`$`"````,7@`0`%````SN`!``\```#4X`$`"@```.3@
M`0`*````[^`!``8```#ZX`$`"@````'A`0`2````#.$!``P````?X0$`"@``
M`"SA`0`,````-^$!``<```!$X0$`!P```$SA`0`(````5.$!``D```!=X0$`
M%@```&?A`0`)````?N$!``<```"(X0$`!P```)#A`0`:````F.$!``8```"S
MX0$`%P```+KA`0`&````TN$!``<```#9X0$`%0```.'A`0`)````]^$!`!``
M```!X@$`!P```!+B`0`&````&N(!`!,````AX@$`$0```#7B`0`3````1^(!
M``8```!;X@$`!@```&+B`0`*````:>(!``@```!TX@$`!````'WB`0`)````
M@N(!``0```",X@$`#0```)'B`0`B````G^(!``H```#"X@$`#````,WB`0`I
M````VN(!`!<````$XP$`%@```!SC`0`;````,^,!`!8```!/XP$`!````&;C
M`0`+````:^,!``T```!WXP$`!P```(7C`0`"````C>,!``X```"0XP$`"```
M`)_C`0`B````J.,!`!\```#+XP$`(P```.OC`0`@````#^0!`#4````PY`$`
M(0```&;D`0`G````B.0!`"L```"PY`$`9````-SD`0`2````0>4!`"$```!4
MY0$`/@```';E`0`C````M>4!`$\```#9Y0$`2````"GF`0`F````<N8!`#\`
M``"9Y@$`(0```-GF`0`O````^^8!`"X````KYP$`)P```%KG`0`G````@N<!
M`"$```"JYP$`-@```,SG`0`;`````^@!`!$````?Z`$`%@```#'H`0!+````
M2.@!`'````"4Z`$`.`````7I`0`J````/ND!`#4```!IZ0$`8@```)_I`0!4
M`````NH!`"L```!7Z@$`'````(/J`0`/````H.H!`"$```"PZ@$`%@```-+J
M`0`5````Z>H!`"T```#_Z@$`'````"WK`0`;````2NL!`"T```!FZP$`'0``
M`)3K`0`]````LNL!`!D```#PZP$`#0````KL`0`N````&.P!`"<```!'[`$`
M-@```&_L`0`I````INP!`!P```#0[`$`(````.WL`0`V````#NT!`%````!%
M[0$`,0```);M`0!#````R.T!`"P````,[@$`(P```#GN`0`W````7>X!`&,`
M``"5[@$`3````/GN`0`S````1N\!`!X```!Z[P$`(````)GO`0`A````NN\!
M`"````#<[P$`-````/WO`0!?````,O`!`%$```"2\`$`/````.3P`0`_````
M(?$!`"H```!A\0$`&@```(SQ`0`H````I_$!`"T```#0\0$`+0```/[Q`0`5
M````+/(!`(,```!"\@$`=P```,;R`0"`````/O,!`,@```"_\P$`&0```(CT
M`0`C````HO0!`"X```#&]`$`)P```/7T`0!'````'?4!`"(```!E]0$`4```
M`(CU`0`D````V?4!``X```#^]0$`00````WV`0`D````3_8!`"X```!T]@$`
M)P```*/V`0`D````R_8!`#H```#P]@$`!````"OW`0`'````,/<!``,````X
M]P$`#P```#SW`0`*````3/<!``<```!7]P$`"````%_W`0`&````:/<!`!$`
M``!O]P$`!````('W`0!;````AO<!``0```#B]P$`#P```.?W`0`$````]_<!
M``<```#\]P$`!P````3X`0`%````#/@!``,````2^`$`$````!;X`0`.````
M)_@!`!,````V^`$`$0```$KX`0`"````7/@!``@```!?^`$`!P```&CX`0`4
M````</@!``P```"%^`$`%@```)+X`0`&````J?@!``\```"P^`$`"@```,#X
M`0`#````R_@!`"@```#/^`$`!````/CX`0`&````_?@!``<````$^0$`%P``
M``SY`0!(````)/D!`"D```!M^0$`+````)?Y`0`7````Q/D!`"4```#<^0$`
M)@````+Z`0`I````*?H!`!T```!3^@$`&@```''Z`0`9````C/H!`!L```"F
M^@$`&````,+Z`0`7````V_H!`!T```#S^@$`&P```!'[`0`8````+?L!`"<`
M``!&^P$`&````&[[`0`G````A_L!`",```"O^P$`&0```-/[`0`=````[?L!
M`!L````+_`$`&````"?\`0`>````0/P!`"(```!?_`$`'0```(+\`0`F````
MH/P!`"(```#'_`$`&````.K\`0`:`````_T!`"4````>_0$`%P```$3]`0`A
M````7/T!`#````!^_0$`,P```*_]`0`3````X_T!`"8```#W_0$`/@```![^
M`0`?````7?X!`",```!]_@$`(0```*'^`0`D````P_X!`!X```#H_@$`&```
M``?_`0`A````(/\!`"````!"_P$`,P```&/_`0`B````E_\!`#<```"Z_P$`
M#````/+_`0`/````__\!`!D````/``(`*0```"D``@`?````4P`"`!````!S
M``(`(@```(0``@`/````IP`"`!4```"W``(`#@```,T``@`0````W``"`!L`
M``#M``(`!P````D!`@`%````$0$"`"D````7`0(`)````$$!`@`7````9@$"
M`"(```!^`0(`)````*$!`@`'````Q@$"`-0```#.`0(`#````*,"`@`4````
ML`("``D```#%`@(`#````,\"`@`<````W`("`!,```#Y`@(`$0````T#`@`;
M````'P,"``D````[`P(`,@```$4#`@`(````>`,"`!````"!`P(`!P```)(#
M`@`2````F@,"``H```"M`P(`-@```+@#`@`)````[P,"`"0```#Y`P(`%@``
M`!X$`@`5````-00"`!0```!+!`(`)@```&`$`@`<````AP0"``P```"D!`(`
M'````+$$`@`-````S@0"``X```#<!`(`%0```.L$`@`*`````04"`!@````,
M!0(`"````"4%`@`I````+@4"``D```!8!0(`#P```&(%`@`J````<@4"``8`
M``"=!0(`%0```*0%`@`'````N@4"``@```#"!0(`"0```,L%`@`[````U04"
M``<````1!@(`$````!D&`@`2````*@8"`!(````]!@(`"0```%`&`@`+````
M6@8"``<```!F!@(`%0```&X&`@`'````A`8"`!<```",!@(`"P```*0&`@`-
M````L`8"``P```"^!@(`%P```,L&`@`9````XP8"``0```#]!@(`!0````('
M`@`9````"`<"``0````B!P(`+````"<'`@`,````5`<"`!$```!A!P(`!P``
M`','`@`"````>P<"``P```!^!P(`#@```(L'`@`+````F@<"``0```"F!P(`
M"0```*L'`@`3````M0<"`!8```#)!P(`"````.`'`@`)````Z0<"`!$```#S
M!P(`#0````4(`@`9````$P@"`!H````M"`(`#0```$@(`@`R````5@@"`!X`
M``")"`(`(P```*@(`@`7````S`@"``L```#D"`(`,P```/`(`@`%````)`D"
M`!$````J"0(`0@```#P)`@`+````?PD"``H```"+"0(`!@```)8)`@`$````
MG0D"``0```"B"0(`"@```*<)`@`4````L@D"``4```#'"0(`!@```,T)`@`&
M````U`D"``H```#;"0(`!@```.8)`@`.````[0D"``\```#\"0(`-`````P*
M`@`J````00H"`"<```!L"@(`!0```)0*`@`>````F@H"``X```"Y"@(``@``
M`,@*`@`$````RPH"``H```#0"@(`!0```-L*`@`%````X0H"``(```#G"@(`
M$0```.H*`@!#````_`H"`"X```!`"P(`&````&\+`@`C````B`L"`",```"L
M"P(`)@```-`+`@`/````]PL"`%X````'#`(`(````&8,`@!'````APP"`"0`
M``#/#`(`00```/0,`@`H````-@T"`"H```!?#0(`,````(H-`@`Q````NPT"
M`#4```#M#0(`-````",.`@`J````6`X"`"0```"##@(`*@```*@.`@`R````
MTPX"`!`````&#P(`$0```!</`@`/````*0\"`&P````Y#P(`"0```*8/`@"I
M````L`\"`%\```!:$`(`=P```+H0`@`N````,A$"`%@```!A$0(`%0```+H1
M`@`C````T!$"`!<```#T$0(`%P````P2`@`;````)!("`!\```!`$@(`.0``
M`&`2`@`C````FA("`",```"^$@(`6````.(2`@`:````.Q,"`!(```!6$P(`
M"P```&D3`@`%````=1,"``8```![$P(`"````((3`@`%````BQ,"`!(```"1
M$P(`#````*03`@`4````L1,"`!X```#&$P(`#@```.43`@`/````]!,"``0`
M```$%`(`"0````D4`@`+````$Q0"``@````?%`(`!@```"@4`@`5````+Q0"
M``D```!%%`(`"0```$\4`@`.````610"``X```!H%`(`#0```'<4`@`0````
MA10"``8```"6%`(`%P```)T4`@`*````M10"``D```#`%`(`#P```,H4`@`(
M````VA0"``4```#C%`(`%````.D4`@`5````_A0"``H````4%0(`!@```!\5
M`@`/````)A4"`!$````V%0(`&````$@5`@`-````814"``4```!O%0(`&```
M`'45`@`(````CA4"``,```"7%0(`&0```)L5`@`)````M14"``(```"_%0(`
M`@```,(5`@`/````Q14"``8```#5%0(`!@```-P5`@`/````XQ4"`!<```#S
M%0(`!@````L6`@`6````$A8"``(````I%@(`!````"P6`@`2````,18"`!(`
M``!$%@(`$````%<6`@`'````:!8"``T```!P%@(`!@```'X6`@`,````A18"
M``@```"2%@(`&@```)L6`@`/````MA8"`!(```#&%@(``@```-D6`@`'````
MW!8"``D```#D%@(`#0```.X6`@`/````_!8"`"L````,%P(`!````#@7`@`'
M````/1<"``L```!%%P(`!0```%$7`@`"````5Q<"``L```!:%P(``0```&T#
M````````$@0```````!H!@``7`,``*T"``!M!P``NP$``&,#``"]````Q`4`
M````````````BP(``/P&``````````````<```"]`0``'`4``,8#``#<`@``
MXP```&X```#V````*@4```$&````````T`,``-`$```F`@``A0```/X"``"E
M`P``U0$```````"T!```1P$``#,&``#/!0``80<``$0$``#4`0```````-H!
M```>````_`$``%("````````T````%`"````````'04``#8#```)````C08`
M``````#"`P```````"@#```4````@0$``#T#`````````````*@%``"N`0``
M%`$``-8$``")!P``X`<`````````````_P$`````````````A`0``*\$``#+
M`0``P@8```````#E!0```````/0"````````@P8````````P!@``>`<``%`'
M```?`@``900```````",!@``9P$```````!O````!P<``-T$``"N!@``````
M`(X'``"K`0``K0<``)T%````````S@,``%L```!K!@``;04``(,!```U````
M`````%8'````````^P0``(@&`````````````%8%````````(@0``.D!````
M````/@8``"H#``#C!````````#<!``#!!````````!,!`````````````'4#
M``"L`0``"`(```````!N!0``?`<``)T!``##!@```````'(`````````O0(`
M`!H'``#N`@``U@8```````#9!```1@4``/`"```N!0``[@```!8"``"*`0``
M<P,``)H```!\!0``JP<`````````````QP8```````#9`@``-0<``%H"``#3
M````2`$```````!C`````````"T'``!P`P``(00`````````````/`4`````
M```&`P``W@8```````"*!```AP4``#`'``#_!@````````````!L`0``\`8`
M``````"Y!P```````#4#``"F`0``Y`4```````!H`0``"P<`````````````
M`````.(&````````$P(``+0%````````@`8``'$'````````*0(```<!```,
M!0````````````#?`@``10<``!(!``"3!P``[0(``.T$``!<`@``60```.L&
M``#3!```;0$````%``#1`0```````-,&````````]@4``,`#````````D@4`
M`#P$```@!@```````#,$``#=!0``L@````````!``P```````)H$``"G!```
M[08``#$"````````&0<``#\#``!A````C0<``)8"``!7`0`````````````*
M!````````-`%``![`P``F0$``/,$````````:````-X$``!R!```7P<``'<`
M``"_!@``4P0``#X"```1!@```````%4"```1````H04```````!B!@``7`4`
M````````````V````%@%```G`@``RP```,,!`````````````!`%````````
MW@```,$&````````1`4```````"#`@``I````/L&``"0!0```````!T&``#:
M!0``104``),&``"A!P``<`4``/D$``#F!```MP<``````````````````%8"
M``!/!P````````````!E`@``20,``",&``!#!0``\08``+P```#A`P``````
M```````'`@``30(``-H#```[`P```````&0'``"`!0```````&<$```O!```
MHP<```````!M`@``>@8``"8!``!'`P```````+@"``"^`P``9@(``'P&``#$
M!```A0$``$($```%`@``E0(``(0```!<!````````((````A````IP<``*H%
M``"``P``U@$``+8&```*`P```````,P"``#[`@``E@$``+@````!`P``G`$`
M`#,!```.!@``&0,``,@!``!'`@``2@4```````#`!0``30<``)('```I!0``
MR`(``````````````````&(#```9`0``\0(``'``````````Y0$``*X#``!+
M````J0(``#L!```N`P``0P,``+\!````````-`$``+$#``!)!0``_0````@#
M``")!@``2`,``/8!``#<`0```````-(!````````F00```````"B!P``S@<`
M````````````.P4``$D$``"3!````````%,'````````AP$``!H!```C!```
M/`$``!T'``#^!```R@<``+$&``"/````'@4``/$%```:`P```````,T```"K
M!0``)0,``(````#\!0```````.$&````````+P4``,4%``"#!0```````"T#
M``!N`0``T@<``,4"``#=````RP0`````````````IP```!X"```K`0``````
M````````````KP```*`&```X!```5@8``&X#``#T!```&`<``,@```"D!P``
MP@`````````%!P``/00``+`&```"!P``C0,``#D&``#F````-`(``$<````0
M`P``L`4```````"H`@``)P4``#<$````````80,``-X'``!I!0```````+`'
M````````EP4```````")`@``W`0``&<&```G!P````<``+4"```]`0``N04`
M```````Y!```"0(``)T'````````N`,```8```#.!@``/````%X!``!=!0``
M@`$``-<#``#0`0``3@````````!I!@``4P8``!L%``!!`@``B0```*\&```?
M``````````````#/!```A`$``,D````;`P``^08```````#$`````````+$!
M````````[P(``%4#````````2`<```````!"!P``F`8``,0#````````$`0`
M`%0'``````````````,'````````PP````````#-!````````)(&``#,`P``
M`````)L&``#N`0``B`(``&`%``!J`@``EP8``",#`````````````+D$```O
M!P``"P4``*@'``#G!```E`$```````#J`0``I@(```L"``#1````!`$``,L#
M````````YP,``#@'``#`````[0$``&@$`````````````!(```!R`0``4P(`
M``````"2````````````````````S@(``*`"````````KP4```4`````````
MX0$````````\!@``3@,``%0$``"U!P```````%,%```D!P``````````````
M````/P<```T$````````6@4````````G`P``F`,``#D"```C!P``$P<``)``
M``!;`0``1@8``-H'``````````````````!Z!````````),```!,!```[@4`
M````````````E`(```````#I!0``Q`(``#@````]!@``<0$``)4#````````
MP0`````````*!@``G@$``$D&``"9!0``O@<````````&`0```````'@"````
M````4`$``+D"``!5!0``BP8``)P%``!9!```UP<``"P"``#,!0````````P'
M``"A`0``U@<````````[`@``3`,``(P"``#`!`````````````#[`P``````
M`$X!``"G`@``5@$``'4!```_!@````````````!:`P``X`4```````!'!0``
MI`4``-L'``"B`0``:@<``$P&``"8`@````````````!K`0``+`<``!@%```.
M`P``J0<``*H$````````FP$``*H"``#T!@```````$(&````````308``)P$
M``#)`0``,P<```````#,`0``R@8``$@%`````````````$X'``#=`P``$`<`
M`((&``#2`P``1`,```````!#!P``,`0`````````````P0$``,@%````````
MLP0```````!Y!```]00``"$'``"C!```.@<``,T!``##!P``T@0```````#M
M````B00`````````````,04``%4'`````````````-@$``!^!```>0<``(T$
M``#H````$@,```````"B````M`8``"L'````````M@,``/\"``!*`0``Z0``
M`&('``!X!@```````(4'````````/P(``$T!``"#!P``L`(````````B`P``
M;P$``-4```!]!0``;08``#4$```&!P``$@(``"(&``"%!0```````#`"``"\
M`@``+`4``%@"```"!0```````+4&```6!P``"@4``((!`````````````*X%
M``!,`@``H`$``&(````,````-@(``&4`````````N@0```````#/````(P``
M``````!L!0````````````"(!````````/T&``!U!````````*,!````````
MOP0``-\#```6!0``>P<```````"\!@``\`$```````#=!P``A`8``.@%``#N
M`P```````%$%``!K`P``J@`````````B!P``Y08``#<#``#4`P``,08`````
M``!-!0``JP````````!G`@```````#$!```#!```6`$``&P&````````````
M`!\%``!``@``AP,```````!I!P``30,`````````````BP4```0%``";!P``
MT04``$(!```5`@``+P8`````````````8`0``'<$``#?````RP8`````````
M````````````````````````````````````X00``"T!``#W`@``/P```*,&
M``!L!P``/@,``)\%``!G!P```````+(#```R!0``/P4`````````````/P0`
M`+`!````````Y`````````!7!P``QP````````!9!@``_04```````!M````
M&`8````````N`0``$@4``%D'``#[````<`0``'\```"(`0``Y00``-(```#H
M!@``?0,``(H&````````-08```````#I!```<P4``(L#``!`!```S`8``!T$
M````````PP0``'T!``#>!0````````````#A````NP8``!,&``!?!0``?P8`
M`%<"``#"!```.@4```P"``!?!````````!`"``!+`@``N08``.\%``#K!```
MA08``.@"``#.!```808``$8#````````7@<``%H````7!@``<@(``.@!``#I
M`P``-P```)T"``".`0```P$``%`#````````@0<```````#``0``E`0``/0#
M`````````````"(%```Z!@```````(L$``#R!@```````+("``":!@``X`,`
M```````/`0``#0<`````````````S@$``+\#``#^!0``Z@4```````!H!0``
M\`0``*(%```0````D@0``'X%```U!0``;``````````M!```004`````````
M````>P```%(&````````M@0```````!H`@``IP8``(`$``!C`@``FP(`````
M```8`0``(`0``%@'``!:!@``;P8``*P'``!D!@``D@,``.`!````````````
M`+@&```J`@``=@(``$X%````````:@8``.8#``!K`````````!\'```I````
M`````#<'````````2`(``!8$`````````````"8#``#3`0``%`(``,4!``#;
M````+@8````````3!````````'<%``#J`P``G@<``"`%```-`@``,`$``+,%
M``"\!0``%P,``+4$```.````G````"<!``#Q!````````#L'``!<````(P$`
M`!T```#H`P``HP,``"4!``!!````!P4``&\#````````N@<``)(!```@!P``
M!P,``#`%```J`0``)@8``+0#``"I!0```````%L&``#4!@``R`<``'4&```(
M````T`<`````````````Q0,``)T````.`@``=`0```````!)!P```````.,%
M``!?!@``,@8``$H&``!O!`````````````"(!P``)@```,H```#Z!```!@4`
M`)L%``#W!0``<08````````````````````````T`P``A`(```````"9`@``
M0P0``````````````````.,#````````C@8``,H!``!@`0``1@$``%$#``#%
M!```YP$``'8$```/!```GP<``'X"``````````````````#W`0``#P4`````
M``!Z`0``0`<``````````````````*0$``!:!P`````````````!!0``Y@(`
M``````"U````_P0`````````````[`,``"P!```4!@```````&8#``"8!P``
MX@4```````!^!P``X@```/P"``"5`0```````+T%``#K`P```````#X$````
M````Q0````````!F!P``F`$``"4$``!J!```-P(``"("``!W`0```````&("
M``#W!```H0(``%T#```J!@``B@,``!4$```^````O@```,<'````````-0$`
M`.`&```[````[@8````````-`````````(`"``"\`P``L`,``-H&``!_`0``
M`````#@!``"E````OP4`````````````XP8``'('``"<`@``B`4``/P$``#Z
M`@``9@4```````!6`P``50```"X'``"#`P``T`(``"8%``"B`@``"0,``-0$
M```%!0``O`<```````#L!@``EP,```````"5!0```````*4"```#`@``````
M`-0%```7`0``#@4``,H#```3`P```````*H#``!@!P``C`0``"8$````````
MA@0`````````````9````&4#``"V!0``&0````````!D`0``M`<`````````
M````!@(``)T$``!=````\P,``-L%``!I`````````"4'````````LP<``/0!
M`````````````,0!``#Q`P``00,``!P!``",`0``X@(``%X$``#Y!0``````
M````````````5`,`````````````\0```#H!``#2!@``N@,``)L```#Y`@``
MU08``+L"``"L!```1@0``!L'``!D!````````)D`````````^`0``($$```Y
M`````````!H&``#Y`P```````.D"``!*````D00`````````````?@,``$`!
M``!:`0``!`8``!4#```V`0``7@````,#``"7!P``000``"<`````````````
M`-,"``#\````1P0``(T%``!S!````````(\%```M!@``OP````````!X`0``
MV@(```````#C`@``A@8``%\#``"M!@``````````````````3`$`````````
M````*`$```<&``#P!0``L@<```````"F!0``````````````````/0(``*H&
M```,`P```````+8!````````0@(``/0%``#9`P``<00``&L'``!6!```WP0`
M``D$``#/`0``MP4``+<$``!S````MP,``&$$````````!P0```````">````
M`````%<```!E!0``E`,``)$````>`0``7@4``-@!``#1`P``A@```/,"``!2
M!0```````#@"``"*!P``#P,```````"4!0``8P0```````!-!````````-L#
M``"6!`````````````"D`0``-@<``,D#```G!@``&P8``'0&``"'!```NP``
M`,T"``#/!@``E08``($&``!B`0``00<``"$!``#Y`0``'`0```````"^`@``
MM`$``/4#``#_`P``J`$`````````````#`$``$8"``!R`P``0@`````````E
M`@``\````",%```>!P``#P8``)X#``!?`@``:0$```````":!0``*08``-,%
M```]!P``"0<````````X!@``)`(``(8"``#O!@``/`,``+@!```Z`P``6P(`
M``````!Q`P``F@,``$\!````````A0,```````!!`0``+````!P"``#C!P``
M`````(P#````````"P```,<$``"V`@``LP(```````!=!@``O@0``$L%``!`
M````X@,````````!`@``'P0```````"F`P``:P4``*0#``!9`@```````*,"
M``!1!P```````#("``#V`P````````````!\`0``G@(``!,%````````U0<`
M`!P#``"U`0``RP4``*`$```R````"`$``#(#``#]`P``````````````````
M`````*4%````````N@$``+(&``!.!@``*P(```$!``!V`0``Q@0``&D"```9
M!0``2@0``.0&```M`@``,@<``+<!``#C`0``)0```-D%``!T`P``2P8`````
M``!_`P``)`,`````````````<`<``"P&`````````````````````0``C0``
M`,@#``"1`0``Y0(```````!D`@``,````(P%```&!@```````)<!```*````
M`````%L'``"S````Q0<``!0$``"K!@``;@(``,4&``#K````4P$``$P%``#$
M!P```````,D'``#1!P``R@0``'X!```8`@``T@(``$\&````````_@8`````
M``"+!P```````*T!``#W!@``&00``"P#`````````````-(%``"!`P``"04`
M`/("```4!0``?0(``)P'````````L0(``"@"`````````````/@```#=`0``
MI@```+$$``"1`P``@`<``(8!```T````V@0``%@&``````````````,&````
M`````````.4`````````K`8``'(%```0!@``"@$```````!1````+P$`````
M`````````````(0%````````I00``(('``#;!```F@(`````````````````
M`!X#``""`P``#04``&(%``">!@``>0```-<$``!?`0``[P$````&``!X!0``
MY`(``)0&```B````)04``-$&``!C`0``U04``````````````````"\"``#9
M!P``Y`0``"D'``"(`P``*`0``"\```!2`0``9`4```````"L`P``(08``#8%
M```X`P``Y0,``.<"``!.!```(0,``#,#````````N@4``"L&``#]`@``#`0`
M`$L#``!1!```008``'0!``"W`@``F@$``.$"``!O`@``Q`8`````````````
M`````*0&``"1!0``J`0``&X&``#8`P``N0$``+(%````````J@<```4&``!`
M!@``:P(``-\&``#"!P``[`$``'`&````````P`8``),%```5!@``_`,``-L!
M```>!````00``%P'````````)`$```````"F!P``#P(``-<"````````1`<`
M`%P!``!%!```Y`,``&$%``"B!```A@4````````;````@@0````````:````
M`````&H#```6!@```````"L$``"3`@``,@0```````#K`@``T0(``.P```!W
M!P````````````!Z`@````````````!T`````````````````````````,H%
M``!N!P```````.0!``"7`````````,T'````````LP$``/4&```!!P``UP8`
M``````"7!```R08```````#^````]````+`$``#(!@```````',&``"C````
M``````\'``#9````9P,``,,"```Q!```B@(``%($``"O`P``W`<```````!"
M!0``^@8``#,"```I`0``W`4``.$%````````500``'T```"/!@``GP8``!$#
M``!U````G08``%(#`````````````,8!``#,!P``C````%`&``"R`0``O@4`
M`*L$````````I08``*L#``!W`P``7@,``&<`````````9@0`````````````
M:0,``.H&````````H`<``)$'```@````0P$``#X!``#^`0```````!('````
M````10$``!<$``!X`P``P0<``.`$```(!```*P,``.P%``!'!P``TP<``%D%
M```1`@``CP,```````!%````;@0``'8%```3`````````&4!```N````B@4`
M``````!/`@``````````````````N0```#(!``!9`0```````&@#``"V!P``
M^`(``'T'``"O!P``?@```"T%``"*`````````.H$``!7`P``R0(`````````
M````>P(``&\%``"!!0``[04```````!T`@``.04```````!S`0``%@```.($
M``#<`P``=@```/T!```W!0```````-4"``#U`0``^`,``*T#``"/!P``````
M`-X!``"F!```P`<``````````````````*<#```"`P````````````#5!```
M:`<``#@%````````JP(``)8%```@`@```````/<#``"&!P````````````!T
M!0``NP4``-4#``!V!@``/`<``-$$``"/!```G@4``-0````G!```V`8`````
M```=`0``I0<``,D%``#.``````````````"5````=P(``/H%````````L0``
M``@%````````C@,``$\$```7````B0,``/`#``!Y!0``5`8``)`!````````
M)`8``"D#``",!P``M````````````````````-`&````````R@(`````````
M````AP(``)`'```(!@``O00``-P&```$`@``U@(``'(&```V````I0$``!`!
M``"]!@``J08``"`!``!C!P``6P,```T#``#8!P``&0(``'<&``#F!@``````
M`,P``````````````,<#``#R!```Z@```,$#``!+!```0P```.L%```+!```
M``````4#``#K`0``4`0``%0```"0`P```````#$#`````@``H`4``)("``"X
M!```[P0``/T$```1`0```````"H'````````SP,``%('````````P0(`````
M``#Z`0``K````%D#``#V`@``\P4``,$%``#=`@``E`<```L!``"6!@``````
M`&P"``"Z!@``7P`````````)`0``*`8``)`$````````3P```+\'```-`0``
M%@$```````#&!P```````(0#```K````1P8```````"A!```.@(``&P$````
M````PP4``(X$``!V`P``C@4`````````````U@4````````"`@``#@0``'L$
M`````````````#`#````````G@0``.P$`````````````-T&````````L0<`
M`&H!````````'`8``(L!```$````O0<```````#+!P``M04``!T"``!K!```
M/P$``+X&``"8````)08``+H```#.!0``.0,``%,#``#?!0``X@<```````!F
M!@````````````!^!@``H@8``/\%``#S!@``````````````````+P,``'P#
M``#R`P```````%4&````````V08``"D$````````:@4``(4"``#Q`0``PP,`
M`.\```!U`@``J0````````"8!```_P````````#?`0```````%@`````````
M`````+X!``!.`@``W@(``-@"``!A`0````````X!``"!````UP$``'4%``!/
M`P``700``'$```"@`P``````````````````J`8``%4!``#6`````````(<&
M``#W````"`<``%T"``"6````>08``+<&``"A`P``K00``+P!````````````
M`$8`````````;`,``(X"````````-P8```````!;!0``>0,``.D&``!*!P``
M3P4``.<```!"`P````````````![!0``UP```!4!``"O`0``\P$```0$``"8
M!0``-`4``#4"``#F!0```````.H"```C`@``J0$``-L"```\`@``;P<``%``
M````````'P$```````!\`````````-0"``#&`@``<P<``+,#````````````
M`.P"````````?P4``$P```"M!0``[P,``$H#```&!```-`<``!X&```7`@``
MQP(``%X"```8````<04``+D#```A`@``\@`````````Z!`````,```````"P
M````Q@4````````/````Z`0``!(&```Q````D`8````````$!P```````$L!
M``""`@``1@<```,```!Y`@```````!@#````````D08``$0````T!```````
M`#$'``#Y````4P```-<%```,!@```````%<&``!(!````````'T$``!X````
M`````+P$````````J0,``/H#```N!```O0,```````!Z!P```````(,```!_
M!```>P$``/@!````````)@<````````S!0``````````````````HP4``"T`
M````````J````&,%``!1`0``*@0``&<%``"R!```K`(``(@````B`0``'```
M`+$%`````````````'$"``#&````"P8``,T#`````````````+@'``!_!P``
M.0<``#X'``";`P```````(\"``"5!P``@P0``/X#```*`@``^@```+4#``!8
M!```J00``/(!```^!0``NP,`````````````8`,``*@#``!$`@``RP(``-X#
M``!E!P``#08``,8&````````V0$``.T#``"M````=@<``+,&``!%!@``````
M`+\"```;!```:00```````"[!P```````$`%``"6`P``,P```*X'````````
M/0```'T&````````W````$P'````````-@8``*X`````````YP8```````#6
M`P```````*``````````````````````````+`0```````"N!```?`(``*X"
M``!F`0``X@$``/@&``#4!P``$0<``&($``".````R00``'4'````````20``
M`"X"``"A!@````````(&````````4`4``'@$``!(!@``F@<```````!<!@``
M^P4``(T"````````FP0``"0$``!=`0``F0<``!0'```1!```J@$``&4&``#"
M!0````````X'``!$!@``5`$``-L&````````X````)\"``"?`P``-`8`````
M````````2````&`&``!$`0``Y@$``"0%```[!```&P(``!H"````````5@``
M`(<'``"D`@``8`(````````[!@``B0$```(!``#,!```M@```&T$````````
MNP0``(L```"<`P``B04``````````````````%<%````````D0(```L#````
M````KP(``+<``````````````'L&``#``@```````!$%`````````````,@$
M``"6!P``10,```````"?!````````!4````%!```IP4````````:!0```@0`
M``````#3`P```````%$"```4`P``)`````````#[`0``]04``$D!``"$!P``
MSP(``%(```#'`0```````!@$```Z````5`(``(<````$`P``V`4````````*
M!P``&P$```````#V!```7@8``)0```!J````?P(``*$````5!0``E00``/4`
M``!P`0``*`4```````"B`P``8````%<$``!\!```6@0`````````````````
M`)`"``#G!0```````&8`````````F0,``!H$``#V!@``'`<````````@`P``
M```````````7!P``80(``)\!``#"`@``X0<``$4"````````%@,``,\'``"7
M`@``DP,````````A!0``!0$``)D&````````0P8``%@#`````````````%L$
M``"<!@``I@8``"H````5!P``C0$``/@%````````N@(``)T#``#U`@``Y`<`
M``````!4!0```````,T%``#-!@``QP4````````Y`0``2@(``((%```7!0``
M>@```',"``#"`0``IP$``&,&```9!@``*`<````````?`P``M`(``&0#``#N
M!```2P<``*P%````!```>0$``$,"```)!@``\P```+@%````````\@4``"@`
M````````@0(``#8$```"`````````'H#```#!0``>@4``#T%``!T!P``A00`
M````````````GP```!\&``"&`P``X`(``$T`````````V@````````#?!P``
M*P4``),!````````20(``%T'`````````````'`"```=`P``408```````"/
M`0``````````````("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*%)E860@;VYL>2D`("AI;B`E
M<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T
M(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R
M96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!H87,@
M8V%N8V5L;&5D("5S+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R
M97%U97-T+@`E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E
M<RX`)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T
M:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I
M<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@<F5Q=65S
M=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(')E<75E<W1S('EO
M=7(@<')E<V5N8V4@870@)7,N`"5S('1O("5S(&]F("5S`"5S('=I<VAE<R!T
M;R!A9&0@=&\@)7,N`"5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E
M<RX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO
M;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E
M<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN
M`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)
M($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C97!T(')E<75E<W0`06-C97!T960`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O
M<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`06-T:6]N<P!!9&0`061D
M("5S`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@
M2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@
M8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O
M("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB
M97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<@!!9&0@=&AI<R!T;R!M>2!C86QE;F1A<@!!9&0@=&\@861D<F5S<R!B
M;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E
M<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!
M9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L
M:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U
M<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E
M<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!
M;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L
M=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!E<G)O<B!O8V-U<G)E
M9"!F;VQL;W=I;F<@=&AI<R!L:6YK.B`E<P!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`
M06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P
M<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`
M07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS
M:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&%C:&5D(&ES(&%N(&E#
M86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T96YD965S`$%T=')I8G5T
M97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`
M075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R
M=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`07=A:71I;F<@4F5S<&]N<V4`07IE<F)A:6IA
M;@!!>G5R`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L
M;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA
M;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97-H`$)A<B!4:6UE`$)A<B!T:6UE`$)A<F)A9&]S`$)A<F)I90!"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`
M0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!"
M:7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O
M=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)L=64@36]O;@!";'5E
M(&%N9"!7:&ET90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D
M97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`
M0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R;W=N`$)R=6YE:2!$87)U
M<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U
M<FYT($]R86YG90!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0
M;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@
M8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A
M;6]U9FQA9V4`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T
M;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N
M(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#
M86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F
M:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`
M0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B
M96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S
M`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`
M0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T
M:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA
M;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E(&1E9F%U;'0@:61E;G1I='D`0VAA
M;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N
M('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG
M('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R
M96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#
M:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@
M86-T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L
M:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@
M27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A
M<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U
M<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,
M871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO
M<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!L971E9`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N
M9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#
M;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N
M97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL
M960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F
M("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@
M9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W)N9FQO=V5R`$-O<W0@240`
M0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E+@!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S
M(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@)R5S)RX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!M
M:V1I<B`G)7,G+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG
M+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@)R5S)R!F;W(@
M=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2`G)7,G+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!R;61I<B`G)7,G
M+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN
M:R`B)7,B+@!#;W5L9"!N;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E
M<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E
M<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E
M<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O
M871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#
M=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R
M96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE
M`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T
M`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A
M=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I
M;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R
M<P!$96-L:6YE9`!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O
M;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N
M<P!$96QE9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E`$1E;&5T92!#
M96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N
M`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E
M(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E
M;&5T92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE
M=&4@<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES(&QI;FL`1&5L971E9"!S
M971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA
M<FL`1&5N>2!R97%U97-T`$1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE
M;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O
M:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES
M<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA
M>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:79I9&5R`$1J:6)O
M=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC86X@
M4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA
M:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`
M161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E
M<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N
M<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S
M:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE
M;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M
M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E
M<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N9`!%;F0@>65A<@!%;FQA<F=E
M($5D:71O<@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE
M='1E<G,@8F5L;W<Z`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<P!%<G)O<B!W<FET:6YG("(E<R(N`$5R<F]R('=R:71I;F<@)R5S)RX`17-T
M;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`
M17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R
M`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E
M87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&
M5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O
M;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E
M<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X
M`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3
M:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#
M05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA
M;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T
M(%%U87)T97(`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`
M1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&
M;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U
M;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&
M<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R964O0G5S
M>2!);F9O<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E
M<W0`1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D
M($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.
M86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G
M;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96X`1W)E96YL86YD`$=R
M96YA9&$`1W)E>0!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E
M<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P
M<P!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'
M=65S="!397)V:6-E<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`
M1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I
M=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)
M<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R
M97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE:6=H="`H:6X@<&EX96QS*0!(
M96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VUE
M`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(
M;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ
M`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@
M9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O=R!!9G1E<@!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@
M26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`
M26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`
M26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L
M90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`
M26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C
M;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A
M9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B
M969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L
M:7-T`$EN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N
M="X`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:
M25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$
M+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E
M(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?
M='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M
M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN
M=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L
M:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L
M:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F
M($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)
M=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R
M+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@
M0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H
M=`!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+
M97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO;&%B`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U
M=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA
M<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%V96YD97(`3&%W`$QA
M>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,
M969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`
M3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($)L
M=64`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`
M3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM
M97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK
M<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU
M86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`
M3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G
M:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W
M87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E
M>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L
M971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3&]Y;VQA`$QO>6]L82!";'5E
M`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA
M:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV
M97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E
M<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I
M;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA
M>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@
M;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE971I;F<@0V%N8V5L;&%T
M:6]N`$UE971I;F<@26YF;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-965T
M:6YG(%)E<&QY`$UE971I;F<@57!D871E`$UE971I;F<@57!D871E(%)E<75E
M<W0`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP
M:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@
M:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T
M:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO
M=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R
M9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U
M<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE
M<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN
M`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`
M36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P
M=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H
M;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I
M;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L
M>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`
M36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U
M<`!-;WIA;6)I<75E`$UO>FEL;&$`375L=&DM;&5V96P@9')O<"!D;W=N(&QI
M<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C
M;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T
M86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M
M:6)I80!.875R=0!.95A4`$YE961S($%C=&EO;@!.97!A;`!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S
M8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`
M3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`
M3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`
M3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK
M*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T
M:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E
M`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N
M9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F
M="X`3F\@9&5S8W)I<'1I;VX@9F]U;F0`3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T
M:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@
M<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF
M:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&5N
M9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970`3F\@<75O=&$@<V5T+@!.;R!R
M=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H
M(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U
M;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A
M;G0`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F9O;&L@27-L86YD`$YO
M<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO
M<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T
M(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`3F]V96UB97(`3G5M
M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU
M;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E
M871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@
M86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S
M=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/<'1I;VYS(&9O<B`E
M<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N
M:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/
M<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T
M:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@
M4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!0
M32!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N
M;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U
M`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A
M($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!0
M87-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R
M96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S
M=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M
M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E
M;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M
M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E
M<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T
M;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M
M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S
M+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R
M(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T
M:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@<F5V:65W('1H92!F
M;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I
M;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('-E;&5C="!A;B!A8W1I
M;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0;W-T;G5K90!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO
M;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S
M<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I
M97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S
M(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0
M<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI
M8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U
M;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`
M4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M96UB97(@
M=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M;W1E(%-E<G9E<G,`4F5M
M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V
M90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN
M9P!296UO=F4@9G)O;2!M>2!C86QE;F1A<@!296UO=F4@<&%I<@!296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297!L>2!396YT+@!2
M97!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G90!297!L>2!W:71H(&9R
M964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T
M960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L>3H@)7,`4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@1FEE;&0`4F5Q=6ER960@4&%R=&EC:7!A;G0`4F5S970`4F5S
M970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@
M475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A
M<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT
M($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I
M9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O
M=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T
M:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N
M9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R
M>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@
M9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!3
M86EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA
M`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E
M<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P
M=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A
M<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E
M`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L
M96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`
M4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@3&%T97-T($EN
M9F]R;6%T:6]N`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A
M;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E
M<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L
M92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS
M`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES
M<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`
M4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W
M97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T
M=7)E($%L9V]R:71H;0!3:6UP;&5X`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I
M;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3
M;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,
M871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3
M;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D
M97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T
M:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C
M97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E
M8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`
M4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K
M`%-T87)T`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T
M;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R
M:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@
M6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T
M`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F
M=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D
M("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`
M4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E
M<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD
M($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@
M;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7
M:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!4
M86)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A
M:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N
M>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E86P`
M5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A
M='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L
M871E($%D;6EN:7-T<F%T:6]N`%1E;G1A=&EV96QY($%C8V5P="!R97%U97-T
M`%1E;G1A=&EV96QY($%C8V5P=&5D`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI
M9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!L:6YK('1O("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO
M<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T
M("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V%L96YD87(@
M9&%T82!I<R!I;G9A;&ED`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H
M92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N
M871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@
M;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C
M:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N="!H87,@8F5E;B!A9&1E9"!T
M;R!Y;W5R(&-A;&5N9&%R+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A
M("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@
M)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QI;FL@:&%S(&)E96X@<F5M;W9E9`!4
M:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N
M('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y
M960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F
M:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@
M<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4
M:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE
M`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@
M86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B
M)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E
M<R!N;W0@97AI<W0N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T
M+@!4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+@!4
M:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P
M('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W
M87,@<W5C97-S9G5L;'D@<W1O<F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F
M;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A
M<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@
M=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@
M`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L
M;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&5V96YT.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE('1A<VLZ("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+@!4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+@!4:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+@!4:&ES(&%C=&EO
M;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L
M;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU4
M4"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O
M(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U
M;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4
M:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA
M(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O
M;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R
M(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@;65S<V%G92!W87,@=W)I
M='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@
M;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H
M:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE
M`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM
M;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G
M;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O
M<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@
M5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES
M:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z
M(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@)7,O)7,`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E
M860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L
M9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN
M90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YH
M86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<P!5;FEC;V1E("A55$8M."D`
M56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T
M871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI
M=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W
M;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N
M<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!R97-P;VYD96YT('-T871U
M<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@
M9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E
M<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!3
M4TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E
M<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I
M<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@
M9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M
M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E
M<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D
M:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T
M:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E
M<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@
M;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!6
M87)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`
M5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I
M;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A6
M25-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W
M(&%S("5S`%9I97<@979E;G0`5FEE=R!T87-K`%9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I
M;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%14
M4`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A
M<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!7
M96(@4VET90!796)B<&QA='-E;B`M(%-O8F5R`%=E8F)P;&%T<V5N("T@4V]B
M97(@3D57`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I
M`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES
M=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O
M9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M
M4F5F`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(&5X=&5N<VEO
M;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)
M($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@8V%N;F]T(&AA=F4@
M=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP
M:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG
M(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@
M8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P
M;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W
M(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA
M;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R
M;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!
M9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y
M;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U
M;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@
M8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M
M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R
M;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R
M871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L
M<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I
M9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK
M+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S
M<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T
M(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H
M97)E`&-L;V-K`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T
M:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F
M;W)M870@97)R;W(`961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE
M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T
M(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E
M<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM
M<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT
M`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O
M=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E
M;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O
M<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE
M8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`S+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,34@,3$Z,C$K,#$P
M,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$V(#`P.C(V*S`Q,#`*3&%S
M="U4<F%N<VQA=&]R.B!*;V%Q=6EM($AO;7)I9VAA=7-E;B`\:F]H;T!W96)B
M<&QA='-E;BYS93X*3&%N9W5A9V4M5&5A;3H@4W=E9&ES:"`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:70*`"`F(S$U,3L@)7,@:V]M;65R(&%T="!U=&;V
M<F$@9&4@=6YD97)HY6QL<V%K=&EV:71E=&5R;F$@<V]M(&UA<FME<F%T<R!N
M961A;BX`("@E<R!D86=A<B!S961A;BD`("AS;F%B8G1A;F=E;G0@)7,I`"`H
M4VMR:79S:WED9&%D*0`@*&]M("5S(&1A9V%R*0`@*&ED86<I`"`H:6UO<F=O
M;BD`("AI9^5R*0`@:VP@`"<E<R<@Y'(@:6YT92!E;B!K871A;&]G+@`G)7,G
M(.1R(&EN=&4@971T(&=O9&OD;G0@=F%L+@`G)7,G(.1R(&EN=&4@:V]N9FEG
M=7)E<F%T(&D@2&]R9&5R96=I<W1R97)T+@!4<N1D:&%N=&5R87)E;B!F]G(@
M)7,@<V%K;F%S+@`G)7,G(&QA9&5S('1I;&P@:2!G<G5P<'-Y<W1E;65T+@`G
M)7,G(&QA9&5S('1I;&P@:2!B96CV<FEG:&5T<W-Y<W1E;65T+@`G)7,G('-K
M87!A9&5S(&EN=&4Z("5S+@`E+C)F34(@86YVY&YT(&%V("4N,F9-0B!T:6QL
MY71E="`H)3)F)24I`"5D("5S(&]C:"`E<P!$:71T(&SV<V5N;W)D('5P<&CV
M<B!A='0@9^1L;&$@;VT@)60@9&%G87(N`"5D+61A9W-P<F]G;F]S`"5S("T@
M1O9R(&OD;FYE9&]M`$9I;F=E<G!R:6YT(&;V<B`E<P`E<R!+0@`E<R!5;F1E
M<FCE;&QS9G5N:W1I;VX@+2!"96MRY&9T96QS90`E<R!3971U<``E<R!A;FWD
M;&%N`%1JY&YS=&5A=G1A;"!F]G(@)7,`)7,@9FEN;G,@<F5D86XN`"5S(&ML
M("5S("5S`"5S(&AA<B!A;FYU;&QE<F%T("5S+@`E<R!H87(@<W9A<F%T('#E
M(&5N(&)E9^1R86X@;VT@:6YF;W)M871I;VX@86YGY65N9&4@;&5D:6<O=7!P
M=&%G96XN`"5S(&AA<B!S=F%R870@<.4@:6YB:G5D86X@=&EL;"`E<RX`)7,@
M:&%R('-K:6-K870@9&EG(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N
M+@`E<R!K;VUM97(@871T('5T9O9R82!D92!U;F1E<FCE;&QS86MT:79I=&5T
M97)N82!S;VT@;6%R:V5R871S(&YE9&%N+B!-87)K97)A(&1E(&%K=&EV:71E
M=&5R('-O;2!D=2!V:6QL('5T9O9R82X`)7,@:W+D=G,`)7,@;6EN=71E<@`E
M<R!S86MN87,N`"5S(&5F=&5R9G+E9V%R(&EN9F]R;6%T:6]N(&]M(&[D<B!D
M=2#D<B!L961I9R]U<'!T86=E;BX`)7,@969T97)F<N5G87(@9&EN(&[D<G9A
M<F\@=FED("5S+@`E<R!T:6QL("5S(&%V("5S`"5S('9I;&P@;.1G9V$@=&EL
M;"!T:6QL("5S+@`E<R!V:6QL(&?V<F$@9&EG(&UE9'9E=&5N(&]M("5S+@`E
M<R!V:6QL(&5R:.5L;&$@9&5N('-E;F%S=&4@:6YF;W)M871I;VYE;B!O;2`E
M<RX`061R97-S8F]K(&;V<B`E<P!+86QE;F1E<B!F]G(@)7,`06YT96-K;FEN
M9V%R(&;V<B`E<P!5<'!G:69T97(@9O9R("5S`"5S.B`E<P`E<SH@365D9&5L
M86YD970@:V%N<VME(&EN=&4@Y'(@9G+E;B!D96X@<V]M(&1E="!V97)K87(N
M(%9A<B!F]G)S:6MT:6<@;65D(&%T="!F]FQJ82!LY&YK87(@96QL97(@<VMI
M8VMA(&%V<^1N9&%R96X@<&5R<V]N;&EG(&EN9F]R;6%T:6]N+@`L('-T;W)M
M8GEA<@`L('-T;W)M8GEA<B`E<R`E<P`L('9A<FEE<F%N9&4@;65L;&%N("5S
M(&]C:"`E<P`M+2!VY&QJ("TM`#$R+71I;6UA<G-F;W)M870`,C0M=&EM;6%R
M<V9O<FUA=``R-"!T:6UM87(`/$;V<F5GY65N9&4`16X@9&%T86)A<VMO<'!L
M:6YG(&MRY'9S(&;V<B!A:W1U96QL="!B;&]C:RX`171T(&9A=&%L="!F96P@
M:&%R(&EN='+D9F9A=`!%;B!P=6)L:6L@4$=0+6YY8VME;"!K<N1V<R!F]G(@
M871T(&MR>7!T97)A(&5T="!M961D96QA;F1E+@!%;B!P=6)L:6L@4$=0+6YY
M8VME;"!K<N1V<R!F]G(@871T('9E<FEF:65R82!E='0@<VEG;F5R870@;65D
M9&5L86YD92X`16X@<'5B;&EK(&]C:"!P<FEV870@4$=0+6YY8VME;"!S86UT
M(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@9&5K<GEP=&5R82!E='0@;65D9&5L
M86YD92X`16X@<'5B;&EK(&]C:"!P<FEV870@4$=0+6YY8VME;"!S86UT(&SV
M<V5N;W)D(&MRY'9S(&;V<B!A='0@<VEG;F5R82!E='0@;65D9&5L86YD92X`
M16X@<'5B;&EK(&]C:"!P<FEV870@4R]-24U%+6YY8VME;"!S86UT(&SV<V5N
M;W)D(&MRY'9S(&;V<B!A='0@9&5K<GEP=&5R82!E='0@;65D9&5L86YD92X`
M16X@<'5B;&EK(&]C:"!P<FEV870@4R]-24U%+6YY8VME;"!S86UT(&SV<V5N
M;W)D(&MRY'9S(&;V<B!A='0@<VEG;F5R82!E='0@;65D9&5L86YD92X`16X@
M<'5B;&EK(%,O34E-12UN>6-K96P@:W+D=G,@9O9R(&%T="!K<GEP=&5R82!E
M='0@;65D9&5L86YD92X`1O9R;6ED9&%G<VUO;&X`3.1T="!F]G)M:61D86=S
M<F5G;@!&]G)M:61D86=S<F5G;@!&]G)M:61D86=S<VMU<F%R`$;V<FUI9&1A
M9W-S:W5R87(@;65D('-N]@!!32]030!!4$D@240`3VT@961I=&]R;@!/;2XN
M+@!";W1T96X`36ET=&5N`$%C8V5P=&5R82!B96?D<F%N`$%C8V5P=&5R860`
M0F5H]G)I9VAE="!S86MN87,@871T('-K87!A(%9&4RUM87!P+@!"96CV<FEG
M:&5T('-A:VYA<R!A='0@<VMA<&$@5D93+69I;"X`2V]N=&]I;F9O<FUA=&EO
M;@!,]G-E;F]R9"!F]G(@:V]N=&\`2V]N=&]T(&9R>7-T`$)U9&=E=`#%=&?D
M<F1E<@!,Y&=G('1I;&P`3.1G9R!T:6QL("5S`$SD9V<@=&EL;"!U;F1E<F=R
M=7!P`&SD9V<@=&EL;"!U;F1E<F)E:/9R:6=H970`3.1G9R!T:6QL(&CD<CH`
M3.1G9R!T:6QL(&YY(&=R=7!P`$SD9V<@=&EL;"!N>2!B96CV<FEG:&5T`$SD
M9V<@=&EL;"!U;F1E<F=R=7!P('1I;&P@)R5S)P!,Y&=G('1I;&P@=6YD97)B
M96CV<FEG:&5T('1I;&P@)R5S)P!,Y&=G('1I;&P@96X@;GD@86YVY&YD87)E
M.@!,Y&=G('1I;&P@:V]L=6UN`$SD9V<@=&EL;"!N>6$@;65D;&5M;6%R`$SD
M9V<@=&EL;"!P87(`3.1G9R!T:6QL(&UE;GEN(&;V<B`E<R!S;VT@36]Z:6QL
M82!3:61E8F%R`$SD9V<@=&EL;"!I(&UI;B!K86QE;F1E<@!,Y&=G('1I;&P@
M:2!A9')E<W-B;VLZ`$SD9V<@=&EL;"!I(&UI;B!A9')E<W-B;VL`3.1G9R!T
M:6QL(&%N=N1N9&%R90!,861E('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+"!M
M96X@:W5N9&4@:6YT92!LY&=G82!T:6QL(&5X=')A("!I;F9O<FUA=&EO;CH@
M)7,N`$QA9&4@=&EL;"`G)7,G('1I;&P@<WES=&5M970N($1U(&MA;B!L;V=G
M82!I;B!N=2X`57!P;.1G9R!A=B!A;G;D;F1A<F4@Y'(@:6YA:W1I=F5R870N
M`$%D<F5S<P!!9')E<W-B;VL`061M:6YI<W1R871I;VX@+2!A;F=E(&)E:/9R
M:6=H970@9O9R(&%N9')A(&%N=N1N9&%R90!!9&UI;FES=')A=&EO;@!296ML
M86T`069G86YI<W1A;@!!;&)A;FEE;@!!;&=E<FEE=`!!;&EA<P!*=7-T97)A
M`$IU<W1E<FEN9SH`06QL80!!;&QA(&%U=&5N=&ES97)A9&4@86YVY&YD87)E
M`$%L;&$@9W)U<'!E<@!!;&QA(&)E:/9R:6=H971E<@!!;&QA(&9Y<F$@<VED
M;W(`5&EL;.5T(&9L97)A(&%D<F5S<V5R`%1I;&SE="!I;G-TY&QL;FEN9R!F
M]G(@<V]R=&5R860@;&ES=&$_`$9I;FYS(')E9&%N`$%L=&5R;F%T:78@24U3
M4"UI;FQO9V=N:6YG`$%L=&5R;F%T:79T(&SV<V5N;W)D(&;V<B!)35-0`$%L
M=&5R;F%T:79T(&%N=N1N9&%R;F%M;B!F]G(@24U34`!!;'1E<FYA=&EV(&4M
M<&]S="!A9')E<W,`06QT97)N871I=B!M86QL`$%L=&5R;F%T:78@=&5X=#H`
M06UE<FEK86YS:V$@4V%M;V$`171T(&9E;"!U<'!S=&]D(&[D<B!LY&YK96X@
M*"5S*2!S:W5L;&4@86YVY&YD87,`171T(&9E;&%K=&EG="!VY')D92!A;F=A
M=G,N`$5T="!O:^1N="!F96P@:&%R(&EN='+D9F9A=`!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N>6T@<')O>'D`4W9A<@!!;G1A<FMT:7,`06YT:6=U
M82!O8V@@0F%R8G5D80!!<'!L:6MA=&EO;@!!<'!L:6MA=&EO;G-L:7-T80!!
M<'!L:6MA=&EO;F5N(.1R(&ML87(N`%9E<FMS=.1L;"!T:6QL('5N9&5R=71D
M96QN:6YG87(`1V]D:^1N;@!5;F=E9N1R;&EG('-T;W)L96L`87!R:6P`07)A
M8FES:R`H5VEN9&]W<RTQ,C4V*0!!<FMI=F9I;'-T;W)L96L`07)K:79F:6QN
M86UN`,1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@=&$@8F]R="!B96?D<F%N
M(&;V<B`E<S\`Q'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!R861E<F$@)R5S
M)R!O8V@@979E;G1U96QL82!U;F1E<F=R=7!P97(_`$%R9V5N=&EN80!!<FUA
M;FEE;@!!<FUE;FES:R`H05)-4T-)22TX*0!+;VYS=`!!<G5B80!!<V-E;G-I
M;VX@27-L86YD`$%S8VEI(&MO;G-T`$%S:65N+U-T:6QL82!H879S<F5G:6]N
M96X`1G+E9V$@969T97(@8F5K<N1F=&5L<V4@:6YN86X@=6YD97)HY6QL<V%K
M=&EV:71E=&5R('5T9O9R<S\`5&EL;&1E;&YI;F=S:V]L=6UN`$)I9F]G860@
MY'(@96X@:4-A;&5N9&5R(&9I;"!M960@971T('-V87(@<.4@96X@8F5GY')A
M;B!S;VT@9'4@<VMI8VMA="P`1O9R<_9K('1I;&P@871T(')A9&5R82!E;B!G
M<G5P<"!S;VT@:6YT92!F:6YN<RX`1O9R<_9K('1I;&P@871T(')A9&5R82!E
M;B!B96CV<FEG:&5T('-O;2!I;G1E(&9I;FYS+@!&]G)S]FL@871T(.1N9')A
M(&5N(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!A='0@Y&YD
M<F$@96X@=71D96QN:6YG('-O;2!I;G1E(&9I;FYS+@!$96QT86=A<F4`071T
M<FEB=70`875G=7-T:0!!=7-T<F%L:65N`-9S=&5R<FEK90!!=71H7V-Y<G-Q
M;#H@24U!4"UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7V-Y<G-Q;#H@2V]P<&QI
M;F=E;B!S86MN87(@9G5N:W1I;VYE<B!S;VT@:W+D=G,N`$%U=&A?8WER=7,Z
M($E-05`M97AT96YS:6]N('-A:VYA<RX`075T:%]F='`Z($944"UT:6QLY&=G
M('-A:VYA<RX@2V]M<&EL97)A(%!(4"!M960@<W=I=&-H96X@+2UE;F%B;&4M
M9G1P+@!!=71H7VEM87`Z($E-05`M97AT96YS:6]N('-A:VYA<RX`075T:%]K
M<F(U.B!K<F(U+65X=&5N<VEO;B!S86MN87,N`$%U=&A?;&1A<#H@1&5T(&?E
M<B!I;G1E(&%T="!LY&=G82!T:6QL(&%N=N1N9&%R92!I($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!$970@9^5R(&EN=&4@871T(')A9&5R82!A;G;D
M;F1A<F4@9G+E;B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@3$1!4"UT
M:6QLY&=G('-A:VYA<RX`075T:%]L9&%P.B!+86X@:6YT92!LY&=G82!T:6QL
M(&%N=N1N9&%R92`G)7,G+B!397)V97)N('-V87)A9&4Z(`!!=71H7VQD87`Z
M($MA;B!I;G1E(')A9&5R82!A;G;D;F1A<F4@)7,`075T:%]L9&%P.B!+86X@
M:6YT92!U<'!D871E<F$@86YVY&YD87)E("5S`$%U=&A?;&1A<#H@1&5T(&?E
M<B!I;G1E(&%T="!U<'!D871E<F$@86YVY&YD87)E(&D@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!-0T%,+65X=&5N<VEO;B!S86MN87,N`$%U=&A?
M<VUB875T:#H@<VUB875T:"UE>'1E;G-I;VX@<V%K;F%S+@!!=71E;G1I<V5R
M:6YG('1I;&P@24U!4"US97)V97(@;6ES<VQY8VMA9&5S+@!!=71E;G1I<V5R
M:6YG(&UI<W-L>6-K861E<P!!=71E;G1I<V5R:6YG(&UI<W-L>6-K861E<RX@
M)7,`075T96YT:7-E<FEN9R!A=G9I<V%D97,@878@4D%$2553+7-E<G9E<FXN
M`$%U=&5N=&ES97)I;F<@=&EL;"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RX`
M075T96YT:7-E<FEN9R!T:6QL(%--0BUS97)V97(@;6ES<VQY8VMA9&5S+@!4
M:6QL9^1N9VQI9V$@9N1L=#H`5N1N=&%R('#E('-V87(`07IE<F)A:6IA;@!!
M>G5R8FSE`$)/1D@M=7)SY&MT97(`0F%K9W)U;F0`0F%K9W)U;F1S9N1R9P!&
M96QA:W1I9W0@;/9S96YO<F0@9O9R($ME<F)E<F]S`$9E;&%K=&EG="!A;G;D
M;F1A<FYA;6X@9O9R($ME<F)E<F]S`$)A:&%M87,`0F%H<F%I;@!"86QT:7-K
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)T:60`4F%D=&ED`$)A<F)A
M9&]S`$)A<F)I90!"87-K871A;&]G("<E<R<@9O9R(&)I;&1E<B!H:71T861E
M<R!I;G1E+@!"87-L:6YJ90!6:71R>7-S;&%N9`!"96QG:65N`$)E;&EZ90!"
M96YI;@!"97)M=61A`$)H=71A;@!&]F1E;'-E9&%G`$)L;V-K("<E<R<@9O9R
M(&%P<&QI:V%T:6]N("<E<R<@<V%K;F%S+@!";&]C:VEN<W3D;&QN:6YG87(`
M0FQO8VMT>7``0FSE(&WE;F4`0FSE='0@;V-H('9I='0`1F5T`$)O;&EV:6$`
M0F]K;>1R:V5N`%)A;0!286UB<F5D9#H`4F%M87(`0F]S;FEE;B!O8V@@2&5R
M>F5G;W9I;F$`0N5D80!";W1S=V%N80!";W1T96X`0F]U=F5T($ES;&%N9`!"
M<F%S:6QI96X`0G)I='1I<VMA('1E<G)I=&]R:65T(&D@26YD:7-K82!O8V5A
M;F5N`$)R=6X`0G)U;F5I`$)U;&=A<FEE;@!0=6YK=&QI<W1A`$)U<FMI;F$@
M1F%S;P!"<N1N9"!/<F%N9V4`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S`$-?96QL(&EN<W3D;&QN:6YG87(N+BX`0V%C:&5I;FET
M:65R:6YG(.1R(&EN=&4@9G5L;'-TY&YD:6<N`$MA;&5N9&5R`$QU9VYT`$MA
M;6)O9&IA`$MA;65R=6X`2V%M;W5F;&%G90!+86X@:6YT92!N;VQL<W3D;&QA
M(&SV<V5N;W)D(&%U=&]M871I<VMT+"!K;VYT86MT82!D:6X@861M:6YI<W1R
M873V<BX`2V%N(&EN=&4@<VMR:79A('1I;&P@9FEL("<E<R<`1&5T(&?E<B!I
M;G1E(&%T="!A9&UI;FES=')E<F$@97AT97)N82!S97-S:6]N<VAA;G1E<F%R
M92X`2V%N(&EN=&4@:V]N=&%K=&$@24U!4"US97)V97)N.B`E<P!+86X@:6YT
M92#V<'!N82!F:6P@)R5S)P!+86YA9&$`079B<GET`$%V8G)Y="!P<F]B;&5M
M<F%P<&]R=`!+86X@:6YT92!R861E<F$@)R5S)RX`2V%N(&EN=&4@:&ET=&$@
M96X@=&5M<'+D<B!M87!P+@!+86X@:6YT92!F;W)T<^1T=&$@=71A;B`G;>5L
M9FEL)RUP87)A;65T97(N`$MA;B!I;G1E(')A9&5R82!M87!P("<E<R<N`$MA
M;B!I;G1E(')A9&5R83L@)60@8F%R;B!E>&ES=&5R87(N`$MA;B!I;G1E(&1I
M<FEG97)A(&UE9&1E;&%N9&4@=&EL;"!A;F=I=F5T(&YU;6UE<BX`2V%P(%9E
M<F1E`%)U8G)I:P!/<&5R873V<@!+871E9V]R:65R(&]C:"!R=6)R:6ME<@!#
M87EM86X@27-L86YD<P!-;V)I;'1E;&5F;VX`0V5L;&EN<W3D;&QN:6YG87(`
M0V5L;'5T9GEL;&YA9#H`0V5L;&EN<W3D;&QN:6YG87(`0V5L;&UE;&QA;G)U
M;3H`36]B:6QT96QE9F]N`$-E;'1I<VL@*$E33RTX.#4Y+3$T*0!#96YT<F5R
M860`0V5N=')A;&%F<FEK86YS:V$@<F5P=6)L:6ME;@!#96YT<F%L975R;W!E
M:7-K("A)4T\M.#@U.2TR*0!#97)T:69I:V%T9&5T86QJ97(`0V5R=&EF:6MA
M=.1G87)E`$-E<G1I9FEK871P;VQI8VEE<P!48VAA9`!/<F1F]G)A;F1E`,1N
M9')A`,1N9')A(&1I='0@;/9S96YO<F0`Q&YD<F$@9O9R=F%L9"!I9&5N=&ET
M970`Q&YD<F$@;F%M;B!O8V@@861R97-S('-O;2!M;W1T86=A<FYA('-E<B!N
MY'(@9&4@;.1S97(@;V-H('-V87)A<B!PY2!D:6YA(&UE9&1E;&%N9&5N+@!!
M='0@8GET82!L]G-E;F]R9"!S=/9D<R!I;G1E(&UE9"!D96X@;G5V87)A;F1E
M(&MO;F9I9W5R871I;VYE;BX@(%9A<B!G;V0@:V]N=&%K=&$@861M:6YI<W1R
M873V<F5N+@!4:VX`2V]N=')O;&QE<F$@;.1N:RXN+@!-87)K97)A(&1E(&%K
M=&EV:71E=&5R(&1U('9I;&P@=71F]G)A(&YU+@!#:&EL90!+:6YA`$MI;F5S
M:7-K="!F]G)E;FML870@*$=",C,Q,BD`2VEN97-I<VMT('1R861I=&EO;F5L
M;'0@*$)I9S4I`%;D;&H@87!P;&EK871I;VXZ`%;D;&H@;/9S96YO<F0`5N1L
M:B!A;G;D;F1A<FYA;6X`5N1L:B#E=&?D<F0Z`%;D;&H@:'5R(&1A='5M('-K
M86QL('9I<V%S.@!6Y&QJ(&QI<W1S=&EL("AF]G(@<V]R=&5R861E(&QI<W1O
M<BD`2G5L]FX`2VQA<W-D969I;FET:6]N(&;V<B`E<R!S86MN87,N`%)E;G-A
M`%)E;G-A($U33V9F:6-E+71A9V=A<@!296YS82!F<N5G80!296YS82!A;G;D
M;F1A<F4Z("5S`%)E;G-A(&%N=N1D;F%R90!296YS82!A;G;D;F1A<F1A=&$`
M4V5N87)E('5P<&ML87)N86YD90!+;&EC:V$@9O9R(&%T="!F;W)T<^1T=&$`
M0VQI8VMA=&5L;"!V:6$@2%144`!3=.1N9R!F]FYS=&5R`$UO;&X`5&ED:6=A
M(&UO;&X`36]L;FEN9W0`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`2V]M<')I
M;65R82!S:61O9N1L=&5T`$MO;7!R:6UE<F%D92!R86UA<@!+;VQO;6)I80!&
MY')G`$;D<F=H86YT97)A<F4`1N1R9W9A;`!+;VQU;6YE<CH`2V]L=6UN(')U
M8G)I:V5R`$QU<W1I9VAE=&5R`$MO;6UA;F1O`$MO;6UA;F1O9O9N<W1E<@!+
M;VUM96YT87(`3F%M;@!#;VUO<F]S`$;V<F5T86<`4VQU=&;V<F0`4VMR:78@
M;65D9&5L86YD92`H)7,I`$1A=&]R97(`5N1D97(`5N1D97(`2V]N9FEG=7)A
M=&EO;G-S:VEL;&YA9&5R`$EN<W3D;&QN:6YG87(@9O9R(&%T="!S>6YK<F]N
M:7-E<F$@;65D(&AA;F1D871O<F5R+"!S;6%R=&$@=&5L969O;F5R(&]C:"!/
M=71L;V]K`$MO;F9I9W5R871I;VX@8F5H]G9E<B!U<'!D871E<F%S+@!+;VYF
M:6=U<F5R82`E<P!"96MRY&9T82!L]G-E;F]R9`!+;VYG;P!+;VYG;P!&]G)B
M:6YD96QS92!M:7-S;'EC:V%D97,N`$;V<F)I;F1E;'-E(&UI<W-L>6-K861E
M<SH@`$;V<F)I;F1E;'-E(&UE9"!P=6)L:6L@;GEC:V5L<V5R=F5R(&YE:V%D
M97,N`$;V<F)I;F1E;'-E(&UE9"!P=6)L:6L@;GEC:V5L<V5R=F5R(&YE:V%D
M97,Z("5S("@E<RD`1O9R8FEN9&5L<V4@;65D($944"US97)V97(@;6ES<VQY
M8VMA9&5S+@!+;VYT86MT97(`2V]N=&%K=&5R(&QA9&5S('1I;&P@:2!D:6X@
M861R97-S8F]K+@!);FYE:.5L;'-T>7`@9O9R(&MO;7!R:6UE<F%D(&9I;#H@
M`$EN;F5HY6QL(&D@)R5S)P!&;W)T<^1T=`!#;V]K($ES;&%N9',`0V]O:VEE
M`$MO<&EE<F$`2V]P:65R:6YG(&UI<W-L>6-K861E<SH@)7,`2V]P:65R82!M
M87)K97)I;F<`36%J<V)L;VUM80!+;W-T;F%D<RU)1`!#;W-T82!2:6-A`$5L
M9F5N8F5N<VMU<W1E;@!+86X@:6YT92!01U`M:W)Y<'1E<F$@;65D9&5L86YD
M92X`2V%N(&EN=&4@4$=0+6MR>7!T97)A(&UE9&1E;&%N9&4Z(`!+86X@:6YT
M92!01U`M<VEG;F5R82!M961D96QA;F1E+@!+86X@:6YT92!01U`M<VEG;F5R
M82!M961D96QA;F1E.B``2V%N(&EN=&4@4R]-24U%+6MR>7!T97)A(&UE9&1E
M;&%N9&4N`$MA;B!I;G1E(%,O34E-12US:6=N97)A(&UE9&1E;&%N9&4N`$MA
M;B!I;G1E(&SD9V=A('1I;&P@:V]N=&%K="X@)7,`36ES<VQY8VMA9&5S(&%T
M="!K;VYT86MT82!,1$%0('-E<G9E<BX`2V%N(&EN=&4@=F5R:69I97)A(&MO
M;G1O<V%L9&\N("5S`$MU;F1E(&EN=&4@86YS;'5T82!T:6QL($Q$05`M<V5R
M=F5R+@!+86X@:6YT92!K;VYT86MT82!S97)V97(@)R5S)R!V:6$@1E10.B`E
M<P!+86X@:6YT92!S:V%P82!D:7-T<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I
M;G1E(&1E:W)Y<'1E<F$@4$=0+61A=&$N`$MA;B!I;G1E(&1E:W)Y<'1E<F$@
M4$=0+61A=&$Z(`!+86X@:6YT92!D96MR>7!T97)A(%,O34E-12UD871A+@!+
M86X@:6YT92!R861E<F$@:V]N=&%K="X@)7,`2V%N(&EN=&4@<F%D97)A(&1I
M<W1R:6)U=&EO;G-L:7-T82X@)7,`2V%N(&EN=&4@<F%D97)A('5P<&=R861E
M<FEN9W-S8W)I<'0@=&EL;#H@)7,N`$MA;B!I;G1E(&)E<W3D;6UA(&UO='1A
M9V%R96YS(&50;W-T+6%D<F5S<RX`2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@
M861R97-S8F]K+@!+86X@:6YT92!HY&UT82!K;VUP;&5T="!D:7-T<FEB=71I
M;VYS;&ES=&$N`$MA;B!I;G1E(&CD;71A(&MO;7!L971T(&QI<W1A(/9V97(@
M9&ES=')I8G5T:6]N<VQI<W1O<BX`2V%N(&EN=&4@;&%D9&$@<W1R871E9VD@
M)R5S)RX`2V%N(&EN=&4@;&%D9&$@<W1R871E9VD@)R5S)RX`2V%N(&EN=&4@
M<VMA<&$@;6%P<"`G)7,G+@!+86X@:6YT92!S:V%P82!M87!P("<E<R<N`$MA
M;B!I;G1E(&CD;71A('!U8FQI:R!N>6-K96P@9G+E;B!N>6-K96QS97)V97)N
M+@!+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S:W)I=FEN9RX`2V%N(&EN=&4@
M]G!P;F$@)7,N`$MA;B!I;G1E(/9P<&YA("<E<R<@9O9R('-K<FEV:6YG+@!+
M86X@:6YT92#V<'!N82!-86EN=&5N86YC95]487-K(&UO9'5L("5S`$MA;B!I
M;G1E(/9P<&YA(&UA<'!E;B`G)7,G`$MA;B!I;G1E(/9P<&YA(&UA<'`@)R5S
M)P!+86X@:6YT92!K;VYT86MT82!,1$%0('-E<G9E<BX`2V%N(&EN=&4@;.1S
M82`E<RX`1&5T(&=I8VL@:6YT92!A='0@Y71E<G-TY&QL82!L]G-E;F]R9&5T
M(&;V<B!D96X@86YG:79N82!A;G;D;F1A<F5N+B!.Y6=O;B!E;&QE<B!NY6=R
M82!A=B!U<'!G:69T97)N82#D<B!I;G1E(&MO<G)E:W1A+B!&]G)S]FL@:6=E
M;B!E;&QE<B!K;VYT86MT82!A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H]G9E
M<B!H:N1L<"X`2V%N(&EN=&4@:.1M=&$@04-,`$MA;B!I;G1E(&CD;71A(&%D
M<F5S<V)O:RX@)7,`2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1A
M+B`E<P!+86X@:6YT92!HY&UT82!D:7-T<FEB=71I;VYS;&ES=&]R+B`E<P!+
M86X@:6YT92!HY&UT82!D<V5R=F5R9G5N:W1I;VYE<@!+86X@:6YT92#E=&5R
M<W3D;&QA(&MO;F9I9W5R871I;VYE;BX`2V%N(&EN=&4@<F%D97)A(&UA<'`@
M)R5S)RX`2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RX`2V%N(&EN=&4@<W!A
M<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU
M<"UK;VYF:6=U<F%T:6]N+@!+86X@:6YT92!S<&%R82!E;B!B86-K=7`M:V]N
M9FEG=7)A=&EO;CH@)7,N`$MA;B!I;G1E('-P87)A('5P<&=R861E<FEN9W-S
M8W)I<'0@=&EL;#H@)7,N`$MA;B!I;G1E('-P87)A(&)A8VMU<"UK;VYF:6=U
M<F%T:6]N("5S+@!+86X@:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N<V9I;&5N
M("5S+B!$=2!K86X@86YT:6YG96X@86YVY&YD82!E;B!A=B!A;'1E<FYA=&EV
M96X@871T('-P87)A(&MO9&5N('1I;&P@)7,@96QL97(@:V]P:65R82!K;V1E
M;B!N961A;B!T:6QL("5S+@!+86X@:6YT92!S]FMA(&D@3$1!4"UK871A;&]G
M96XN`$MA;B!I;G1E(')A9&5R82`G)7,G+@!+86X@:6YT92!R861E<F$@)R5S
M)RX`2V%N(&EN=&4@=7!P9&%T97)A(&MO;G1A:W0N("5S`$MA;B!I;G1E('5P
M<&1A=&5R82!D:7-T<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I;G1A('-P87)A
M(&MO;F9I9W5R871I;VX@9O9R("<E<R<Z("5S`$MA;B!I;G1E(&AI='1A($UO
M>FEL;&%S('-I9&]FY&QT+B!697)I9FEE<F$@871T('-I9&]FY&QT970@Y'(@
M]G!P970N`$MA;B!I;G1E(&=E(&%N=N1N9&%R96X@)R5S)R!A;F=I=FYA('+D
M='1I9VAE=&5R('1I;&P@;6%P<&5N("<E<R<Z("5S`%+D:VYA9"!T97AT`$QA
M;F0`2W5R<V5R`%-K87!A`%-K87!A(&SD;FL`4VMA<&$@;GD`4VMA<&$@=6YD
M97)M87!P`$)E:/9R:6=H971E<B!F]G(@Y&=A<F$`2W)E9&ET:V]R='-N=6UM
M97(`2W)O871I96X`2W5B80!!:W1U96QL82`T(&9A<V5R`$%K='5E;&P@<V5S
M<VEO;@!!:W1U96QL('1I9`!!:W1U96QL(%523"#D<@!!:W1I=F$@86YVY&YD
M87)E`$%K='5E;&QT(';D9&5R`$%K='5E;&QA('9I;&QK;W(Z(`!!:W1U96QL
M('-T:6P`4VMRY&1D87)S>2!A:W1I=FET971E<B!S;VT@:_9R<R!V:60@:6YL
M;V=N:6YG('1I;&P@)7,N`$ML:7!P('5T`$ML:7!P('5R=F%L`$-Y<&5R;@!+
M>7)I;&QI<VL@*$M/23@M4BD`2WER:6QL:7-K("A7:6YD;W=S+3$R-3$I`$MY
M<FEL;&ES:R]5:W)A:6YS:R`H2T])."U5*0!4:F5C:VEE;@!$1`!$86=L:6<`
M1&%T851R964@8FSD9&1R87)E`$1A=&%B87-U<'!S;&%G`$1A='5M`$1A='5M
M(&UO='1A9V5T`$1A='5M=F%L`$1A9P!?4F%D97)A(&MO;'5M;@!D96-E;6)E
M<@!$96-I;6%L97(`079B]FIT`$UI;G-K82!I;F1R86<`1O9R=F%L=`!&]G)V
M86QD(&;D<F<`1O9R=F%L9"!I9&5N=&ET970`1O9R=F%L="!S:V%L`$1E9FEN
M:71I;VYE<@!$96QE9V5R82!P;W-I=&EO;@!$96QE9V5R860`4F%D97)A`%)A
M9&5R82!C96QL`%)A9&5R82!G<G5P<`!2861E<F$@;&]G9P!2861E<F$@8F5H
M]G)I9VAE=`!2861E<F$@;V-H(')E;G-A(&UE9&1E;&%N9&5N`%)A9&5R82!C
M96QL`%)A9&5R82!K;VQU;6X`4F%D97)A(&)E9FEN=&QI9R!A;'1E<FYA=&EV
M;6%L;`!2861E<F%D92!M961D96QA;F1E;@!2861E<F$@8F5H]G)I9VAE="!F
M]G(@)R5S)P!2861E<F$@8F5H]G)I9VAE="!F]G(@)R5S)R!O8V@@=6YD97)B
M96CV<FEG:&5T97(_`%)A9&5R82!R860`4F%D97)A('9A;&0@:61E;G1I=&5T
M`%)A9&5R82!U;F1E<FUA<'!A<@!2861E<F$@86MT=65L;"!K;VQU;6X`4F%D
M97)A(&%K='5E;&P@<F%D`%)A9&5R82!D96X@:.1R(&SD;FME;@!2861E<F%D
M92!U<'!G<F%D97)I;F=S<V-R:7!T970@)R5S)RX`3&5V97)A;G-T:60`1&%N
M;6%R:P!!=G-LY2!B96?D<F%N`$%V<VSE(&)E9^1R86X@;VT@;&5D:6<O=7!P
M=&%G96XM:6YF;W)M871I;VX`0F5S:W)I=B!P<F]B;&5M970`0F5S:W)I=FYI
M;F<`1&5T86QJ97(@*&]C:W/E(&D@2&]R9&5S(&QO9V=F:6PI.@!$971A;&IE
M<B!H87(@;&]G9V%T<R!F]G(@<WES=&5M861M:6YI<W1R873V<F5N+@!5='9E
M8VML:6YG`$1A9V=P=6YK=`!$86=G<'5N:W0@9O9R('-E;F%S=&4@=&EM;65N
M.B``1&%G9W!U;FMT.B``4FEK=&YI;F<@=N1N<W1E<B!T:6QL(&CV9V5R`%)I
M:W1N:6YG(&CV9V5R('1I;&P@=N1N<W1E<@!+871A;&]G`%9I<V$@,C0M=&EM
M;6%R<R!K;&]C:V$_`%9I<VYI;F=S:6YS=.1L;&YI;F=A<@!6:7-A(&1E=&%L
M:F5R860@9O9R=71SY&=E;'-E`%9I<V$@9O9R=71SY&=E;'-E("A4048I`%9I
M<VYI;F=S9F]R;6%T`$%V<VMI;&IA<F4`1&II8F]U=&D`4F%D97)A(&EN=&4`
M06YVY&YD(&EN=&4@;6%I;G1E;F%N8V4N<&AP(&1I<F5K=`!);FYE:.5L;&5R
M(&;V<G-T82!R861E;B!FY&QT;F%M;F5N/R!/;2`G:F$G+"!M87)K97)A(&CD
M<CH`1&]M:6YI:V%N<VMA(')E<'5B;&EK96X`2&%R(&1U(&EN9V5T(&MO;G1O
M/R!296=I<W1R97)A(&1I9RX`2.1M=&$`2.1M=&$@)7,`2.1M=&$@9V5N97)E
M<F%D(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I<'0N`$1R;W!P;&ES=&$`
M1')O9V5R`$4M<&]S=`!$<FEV<G5T:6X@9O9R($4M<&]S="!T:6QL(%--4RUB
M<GEG9V$[(&;V<B!O<&5R873V<F5R('-O;2!T:6QL:&%N9&%HY6QL97(@9&5N
M;F$@=&KD;G-T+@!&14P`16MU861O<@#$;F1R80#$;F1R82!B;&]C:P#$;F1R
M82!G<G5P<`#$;F1R82!B96CV<FEG:&5T`,1N9')A(&)E:/9R:6=H971E<@#$
M;F1R82!B96CV<FEG:&5T97(@9O9R("5S`,1N9')A(&EN<W3D;&QN:6YG87(@
M9O9R.@#$;F1R82!B96CV<FEG:&5T97(@9O9R("<E<R<`Q&YD<F$@8F5H]G)I
M9VAE=&5R(&;V<B`G)7,G`%5T8FEL9&YI;F<`16=Y<'1E;@!%;"!386QV861O
M<@!%;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O<W1A9')E<W,`12UP;W-T861R
M97-S97(@;>5S=&4@<W3D;6UA(/9V97)R96YS+@!%+7!O<W1M961D96QA;F1E
M(&UE9"!B96MRY&9T96QS90!%+7!O<W0@=&EL;"!335,M8G)Y9V=A`$OD;G-L
M;VEK;VYE<@!4;VUT(&UE9&1E;&%N9&4N`%1O;70@<F5S=6QT870N`%1O;70@
M<_9K:W)I=&5R:6$`4VQU=`!3;'5T(.5R`$;V<G-T;W)A(&5D:71O<@!!;F=E
M('/V:W;D9R`H55),*2!T:6QL(&)I;&1E;B!HY'(`4TMR:78@8F]K<W3D=F5R
M;F$@;F5D86XZ`$9E;`!&96P@=FED('-K87!A;F1E(&%V(&)L;V-K.B`E<P!&
M96P@=FED(')A9&5R:6YG(&%V('-Y;FMR;VYI<V5R:6YG<VWD<FME.B`E<P!&
M96P@=FED(')A9&5R:6YG(&%V('-Y;FMR;VYI<V5R:6YG<VQO9V<Z("5S`$9E
M;"!NY'(@:6YN96CE;"!HY&UT861E<SH@)7,`1F5L('5N9&5R('/D;F1N:6YG
M(&%V('-V87)S;65D9&5L86YD93H@)7,`1F5L('9I9"!U<'!D871E<FEN9R!A
M=B!L]G-E;F]R9#H@)7,`1F5L('9I9"!S:W)I=FYI;F<@)R5S)RX`1F5L('9I
M9"!S:W)I=FYI;F<@878@)R5S)RX`17-T;&%N9`!%=&EO<&EE;@!%=&YI<VL`
M175R;W!A`%9A<B`Q-3IE(&UI;G5T`%9A<F%N;F%N(&UI;G5T`%9A<B`S,#IE
M('-E:W5N9`!687(@-3IE(&UI;G5T`%9A<FIE(&EN;&]G9VYI;F<`5F%R:F4@
M:&%L=G1I;6UE`%9A<FIE(&UI;G5T`$5X96UP96P@<.4@=N1R9&5N.@!+]G(`
M17AP86YD97)A`$5X<&%N9&5R82!S:61O9N1L=`!&]G)VY&YT861E("<I)P!&
M]G)VY&YT861E(&5N<VMI;'0@;W)D(&5L;&5R(&-I=&5R870@<_9K8F5G<F5P
M<`!&]G)F86QL;V1A='5M`$5X<&]N96YT`$;V<F=R=6YD<V;D<F<`3&%D9&$@
M=7!P(&MO;F9I9W5R871I;VX@=FEA($944"X`36ES<VQY8VMA9&5S(&%T="!H
MY&UT82!I;G-TY&QL;FEN9V%R+@!-:7-S;'EC:V%D97,@871T(&MO;G1A:W1A
M($Q$05`@<V5R=F5R+@!-:7-S;'EC:V%D97,@871T(&MO;G1A:W1A(%--0B!S
M97)V97(N`$UI<W-L>6-K861E<R!A='0@:V]P:65R82!F<N5N("<E<R<N`$UI
M<W-L>6-K861E<R!A='0@:V]P:65R82!T:6QL("<E<R<N`$UI<W-L>6-K861E
M<R!A='0@<VMA<&$@;GD@4T%33"UF]G)B:6YD96QS92X`36ES<VQY8VMA9&5S
M(&%T="!F;'ET=&$@=&EL;"`G)7,G+@!-:7-S;'EC:V%D97,@871T(&CD;71A
M.B`E<P!"<F$`1F%L:VQA;F1S]F%R;F$`1N1R]F%R;F$`1F%T86QT(&9E;#H`
M1F%X`$9A>&%R`&9E8G)U87)I`$OD;FYS('-O;0!+Y&YN<R!S;VTZ(`!&Y71A
M;&EG82!S:W5R87(`1N5T86QI9V$@<V[V<VMU<F%R`$;D;'1M871R:7,`1FEG
M;&5T($-!4%1#2$$`1FEG;&5T='EP<VYI='0`1FEJ:0!&:6P`06YT86P@9FEL
M97(Z("5S(&9I;`!!;G1A;"!F:6QE<CH@)7,@9FEL97(`1FEL:&%N=&5R87)E
M`$9I;&YA;6X`1FEL=F%L`$9I;'5P<&QA9&1N:6YG`$9I;'5P<&QA9&1N:6YG
M('-T]F1S(&EN=&4N`$9I;'1E<@!&:6YL86YD`$;V<G-T82!H86QV86X`1O9R
M<W1A(&MV87)T96X`36%P<"`E<R!E>&ES=&5R87(@:6YT92X`1F]N=&;D<F<`
M36%T`$;V<B!W96)B;.1S87)E('-O;2!I;G1E('-T]F1E<B!B:6QD97(`4')O
M9VYO<R`H5$%&*0!!;G1A;"!D86=A<B!F]G(@<')O9VYO<R`H=F%R:F4@9&%G
M(&)E='ED97(@96X@<')O9VYO<R!F]G(@9&%G(&]C:"!E;B!F]G(@;F%T="D`
M1VSV;70@9&ET="!L]G-E;F]R9#\`1F]R;75LY'(`5FES:&5T<V]R9`!4>7`@
M878@=FES:&5T<V]R9`!6:7-H971S;W)D`%9I<VAE='-O<F0@,@!&;W)U;0!6
M:61A<F)E9F]R9')A<@!&<@!286UA<@!&<F%N:W)I:V4`1G)A;FMR:6ME+"!-
M971R;W!O;`!,961I9R]5<'!T86=E;B!I;F9O<FUA=&EO;@!,961I9R]5<'!T
M86=E;B!S=F%R`$QE9&EG+W5P<'1A9V5N+6;V<F9RY6=A;@!3=F%R('#E(&QE
M9&EG+W5P<'1A9V5N+6;V<F9RY6=A;@!&<F%N<VMA($=U:6%N80!&<F%N<VMA
M(%!O;'EN97-I96X`1G)A;G-K82!S]F1R82!T97)R:71O<FEE<@!&<N5N`$9R
MY6X@9&5N(`!&=6QL<W3D;F1I9R!B97-K<FEV;FEN9P!&=6QL;>5N90!&=6QL
M<W3D;F1I9W0@;F%M;@!'86)O;@!'86QL97)I(&%T="!T82!B:6QD(&9RY6X`
M1V%L;&5R:3H`1V%M8FEA`$=E;F5R97)A(&MO;F9I9W5R871I;VX@9O9R("5S
M`$=E;F5R97)A9"!K;V0`1V5O<F=I96X`5'ES:VQA;F0`1VAA;F$`1VEB<F%L
M=&%R`$;V<FYA;6X`1VQO8F%L82!I;G-TY&QL;FEN9V%R`$]+`$=O961E;`!'
M;V]G;&5K87)T;W(`1V]O9VQE<_9K;FEN9P!'<N5S:V%L80!'<F5K:7-K("A)
M4T\M.#@U.2TW*0!'<O9N`$=R]FYL86YD`$=R86YA9&$`1W+E`$=R=7!P861M
M:6YI<W1R871I;VX`1W)O=7!?;&1A<#H@2V%N(&EN=&4@;.1G9V$@=&EL;"!G
M<G5P<"`G)7,G+B!397)V97)N('-V87)A9&4Z(`!'<F]U<%]L9&%P.B!+86X@
M:6YT92!R861E<F$@9W)U<'`@)R5S)P!'<F]U<%]L9&%P.B!+86X@:6YT92!U
M<'!D871E<F$@9W)U<'`@)R5S)P!'<G5P<&5R`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`$?D<W1B96CV<FEG:&5T97(`5&KD;G-T97(@9O9R(&?D<W1E<@!'
MY'-T8F]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U:6YE80!(5$U,`$A434Q!
M<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&-E;&QE;B!I(&5N(')A9"X`
M2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@:V]L=6UN96X@:2!E
M;B!T86)E;&PN`$A434Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(')A
M9&5N(&D@96X@=&%B96QL+@!(5%10($%U=&5N=&ES97)I;F<@<V%K;F%S+@!(
M86ET:0!(87-H86QG;W)I=&T`1&EM;6$`4G5B<FEK`%)U8G)I:V5R`$AE87)D
M+2!O8V@@36-$;VYA;&3V87)N80!+<F%F=&EG82#E<VMS:W5R87(`2&5B<F5I
M<VL@*$E33RTX.#4Y+3@M22D`2/9J9`!(]FID("AP:7AL87(I`$AJY&QP`$AJ
MY&QP(&UE9"!E9&ET;W)N`$AJY&QP9G5N:W1I;VX`2&5M:7-FY'(`2.1R(.1R
M(&+V<FIA;B!A=B!F:6QE;CH`2/9G`$AE7VT`2&5M`$%D<F5S<RP@:&5M`$AE
M;6MA=&%L;V<`5&5L969O;BP@:&5M`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@3V=I;'1I9W0@)7,@6$U,+61A=&$@<.5T<N1F9F%D
M97,@:2!M961D96QA;F1E("5S`$AO<F1E+TMO;&%B.B!);F=E="!M961D96QA
M;F1E(&UA=&-H87(@;V)J96MT970@)7,`2&]R9&4O2V]L86XZ($EN9V5T(&]B
M:F5K="!A=B!T>7!E;B`E<R!H:71T861E<R!I(&UE9&1E;&%N9&5T("5S`$AO
M<F1E+TMO;&%B.B!2861E<F%D92`E<R`G)7,G`$AO<F1E+TMO;&%B.B!);G1E
M9W)A=&EO;G-M;W1O<FX@:W+D=F5R("=D;VUX;6PG+71I;&SD9V=E="!F]G(@
M4$A0`$AO<F1E+TMO;&%B.B!+86X@:6YT92!S:V%P82!N>71T(%A-3"UT<N1D
M(&;V<B!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E(')A9&5R82`E
M<R`G)7,G.B`E<P!(;W)D92]+;VQA8CH@2V%N(&EN=&4@:.1M=&$@34E-1$4M
M240@9O9R(&1E;&5N(&UE9"!T>7`@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E
M('-Y;FMR;VYI<V5R82`E<R`G)7,G.B`E<P!(;W)D92]+;VQA8CH@2V%N(&EN
M=&4@<WEN:W)O;FES97)A('5T9&5L;FEN9V%R.B`E<P!(;W)D92]+;VQA8CH@
M3VOD;F0@=71D96QN:6YG("<E<R<`2&]R:7-O;G1E;&P@;&EN:F4`2&]R:7-O
M;G1E;&P@=71F>6QL;F%D`$AO<FES;VYT96QL.@!(=7(@:&%M;F%D92!D=2!H
MY'(_("A687(@9V]D(')A<'!O<G1E<F$@9&5T=&$A*0!(=7(@;>5N9V$@:V]L
M=6UN97(@=FEL;"!D=2!S;.4@:6AO<#\`2'5R(&WE;F=A(&;D;'0@*&MO;'5M
M;F5R*2!F:6YN<R!D970_`$AU<B!MY6YG82!R861E<B!V:6QL(&1U('-LY2!S
M86UM86X_`$9U:W1I9VAE=`!&=6MT:6=H970Z`$AU;6]R:7-T97(`56YG97)N
M`%-K87!A;F1E(&%V($E-05`M;6%P<"!M:7-S;'EC:V%D93H@)7,`4F%D97)I
M;F<@878@24U!4"UM87!P(&UI<W-L>6-K861E<SH@)7,`4VMA<&%N9&4@878@
M<75O=&$@9O9R($E-05`M;6%P<"!M:7-S;'EC:V%D97,Z("5S`$E0+6%D<F5S
M<P!)4"UA9')E<W,@Y'(@:6YT92!T:6QL9^1N9VQI9RX`25`M861R97-S(.1R
M(&EN=&4@:6YO;2!G;V1KY&YT($-)1%(M8FQO8VLN`$;V<G/V:R!A='0@:W)I
M;F=GY2!)4"ULY7,N`$E?;F9O9V$@<F%D(&;V<F4`27-L86YD`$5N8F%R="!I
M:V]N97(`26MO;F5R(&;V<B`E<P!):V]N97(@;65D('1E>'0`261E;G1I=&5T
M96YS(&YA;6XZ`$]M(&1E="!I;G1E('9I<V%S(&MO<G)E:W0L("5S(&;V<B!A
M='0@]G!P;F$@:2!N>71T(&;V;G-T97(N`$]M(&1U(&EN=&4@<V5R(&[E9W)A
M(&EK;VYE<B!NY'(@9'4@86YVY&YD97(@26YT97)N970@17AP;&]R97(L('/E
M(&MA;B!D=2!B96CV=F$@;6%R:V5R82!D96YN82!R=71A(&;V<B!A='0@<W3D
M;F=A(&%V(&=E;F]M<VMI;FQI9V$@4$Y'+6)I;&1F:6QE<BX`3VT@9'4@<V5R
M(&1E;FYA('1E>'0@;65N(&EN9V5N(&)I;&0L('/E(&MA;B!I;G1E(&1I;B!W
M96)B;.1S87)E('9I<V$@9&5N(&)I;&0@9'4@9O9R<_9K97(@;&%D9&$@=7!P
M+@!&]G)H86YD<V=R86YS:V$@8FEL9#H`0FEL9&%D<F5S<P!":6QD861R97-S
M.@!":6QD(&9RY6X@9V%L;&5R:0!":6QD(&9RY6X@9V%L;&5R:3H`3&%D9&$@
M=7!P(&)I;&0`0FEL9&5R`$EM<&]R=&5R82P@<W1E9R`E9`!);7!O<G1E<F%D
M92!FY&QT.B`E<P!);7!O<G1E<F%D92!FY&QT.@!0Y6?E96YD90!);E]F;V=A
M(')A9"!E9G1E<@!&96QA:W1I=B!A:W1I=FET971S:V]D('-P96-I9FEC97)A
M9"X`1F5L86MT:6=T(&%N=N1N9&%R;F%M;B!O8V@O96QL97(@;/9S96YO<F0N
M`$]G:6QT:6=T(&%N=N1N9&%R;F%M;B!E;&QE<B!A;'1E<FYA=&EV(&%D<F5S
M<RX@1O9R<_9K(&EG96X@96QL97(@:V]N=&%K=&$@861M:6YI<W1R873V<F5N
M(&]M(&1U(&)E:/9V97(@:&KD;'`N`-9K82!I;F1R86<`26YD:65N`$EN9&EV
M:61U96QL82!A;G;D;F1A<F4`26YD;VYE<VEE;@!);F9O`$EN9F]R;6%T:6]N
M`$EN9F]R;6%T:6]N(.1R(&EN=&4@=&EL;&?D;F=L:6<@;.1N9W)E+@!);F9O
M9V$@:U]O;'5M;B!E9G1E<@!);F9O9V$@8FEL9`!);F9O9V$@=&%B96QL`$EN
M9F]G82!W96)B;.1N:P!);F9O9V$@7VMO;'5M;B!F]G)E`$EN9F]G82!N>2!K
M;VQU;6X@969T97(@86MT=65L;"!K;VQU;6X`26YF;V=A(&YY(&MO;'5M;B!F
M]G)E(&%K='5E;&P@:V]L=6UN`$EN9F]G82!R860@969T97(@86MT=65L;"!R
M860`26YF;V=A(&YY(')A9"!F]G)E(&5K='5E;&P@<F%D`$EN9F]G82!P87)A
M9W)A9B!E9G1E<B!A:W1U96QL(&YO9`!);F9O9V$@<&%R86=R868@9O9R92!A
M:W1U96QL(&YO9`!);F9O9V$@86QT97)N871I=B!M86QL`$EN9F]G82!C96QL
M(&5F=&5R`$EN9F]G82!C96QL(&;V<F4`26YF;V=A(&MO;'5M;B!E9G1E<@!)
M;F9O9V$@:V]L=6UN(&;V<F4`26YF;V=A(&UE9&1E;&%N9&5N`$EN9F]G82!P
M87)A9W)A9B!E9G1E<@!);F9O9V$@<&%R86=R868@9O9R90!);F9O9V$@<F%D
M(&5F=&5R`$EN9F]G82!R860@9O9R90!!;F=E(&5R9F]R9')A="!S=F%R('1I
M;&P@<^1K97)H971S9G+E9V%N.@!);F9O9V$OQ&YD<F$@8FEL9`!);F9O9V$O
MQ&YD<F$@;.1N:P!/=&EL;'+D8VML:6<@:W)E9&ET(&;V<B!A='0@<VMI8VMA
M('1I;&P@9&ES=')I8G5T:6]N<VQI<W1A+@!/=&EL;'+D8VML:6<@:W)E9&ET
M+@!(96QT86P`2&5L=&%L<VQI<W1A`$]G:6QT:6<@Y71GY')D(&;V<B!D96X@
M:.1R(&MO;7!O;F5N=&5N+@!/9VEL=&EG(%5$2"`H)W5S97(@9&%T82!H96%D
M97(G*2X`3V=I;'1I9W0@6DE0+6%R:VEV9&%T80!&96QA:W1I9R!A<'!L:6MA
M=&EO;BX`1F5L86MT:6=T(&)A=&-H+4E$`$9E;&%K=&EG(&1A=&$@<VMI8VMA
M9"X`1F5L86MT:6<@9&5S=&EN871I;VYS861R97-S+@!&96QA:W1I9W0@9FEL
M9F]R;6%T`$]G:6QT:6<@;&EC96YS;GEC:V5L+@!&96QA:W1I9R!O<G0@<W!E
M8VEF:6-E<F%D+@!&96QA:W1I9R!M961D96QA;F1E7W1Y<"X`1F5L86MT:6<@
M96QL97(@<V%K;F%D(&%P:5]I9"X`1F5L86MT:6=T(&5L;&5R('-A:VYA9"!P
M87)A;65T97(N`$9E;&%K=&EG(/9V97)L:6=G86YD92!B96CV<FEG:&5T+@!&
M96QA:W1I9W0@<&%R=&YE<BUI9"X`1F5L86MT:6<@<')O9'5K=&MO9"X`1F5L
M86MT:6=T('!R;W1O:V]L;"X`1F5L86MT:6<@;6]T=&%G87)E.B`G)7,G`$9E
M;&%K=&EG="!U=&1E;&YI;F=S;V)J96MT`$9E;&%K=&EG(&%V<^1N9&%R861R
M97-S+@!&96QA:W1I9W0@=6YI8V]D92UD871A`$EN=F5N=&%R:65R`$EN=F5R
M=&5R82!U<G9A;`!)<F%N`$ER86L`27)L86YD`$ES;&4@;V8@36%N`$5N<W1A
M:V$@Y7-K<VMU<F%R`$ES<F%E;`!5=&;D<F1A="!A=@!+=7)S:78`271A;&EE
M;@!*86UA:6-A`&IA;G5A<FD`2F%P86X`2F%P86YS:R`H25-/+3(P,C(M2E`I
M`$IE<G-E>0!*;W)D86YI96X`:G5L:0!J=6YI`$IU<W1E<F$`0V5N=&5R:G5S
M=&5R80!*=7-T97)A(&KD;70`5N1N<W1E<FIU<W1E<F$`2/9G97)J=7-T97)A
M`$ME;GEA`$ME<F)E<F]S<V5R=F5R;B!A=G9I<V%D92!A=71E;G1I<V5R:6YG
M96XN`$YY8VME;"!S:V%P860`1FEN9V5R<')I;G0`3GEC:V5L;.1N9V0`3GEC
M:V5L='EP`$YY8VME;&%N=N1N9&%N9&4`3GEC:V5L(&9I;FYS(')E9&%N('#E
M(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E<FXN`$)A<FX`2VER:6)A=&D`2V]L
M86(`3F]R9&MO<F5A`%-Y9&MO<F5A`$MO<F5A;G-K("A%54,M2U(I`$MU=V%I
M=`!+:7)G:7-T86X`3&%?>6]U=`!3<'+E:P!,86]S`%-I<W1A(&AA;'9A;@!,
M]G-E;F]R9"#D;F1R861E<P!3:7-T82!K=F%R=&%L970`4V5N87-T('5P<&1A
M=&5R860Z`%-E;F%S=&4@:6YL;V=G;FEN9SH@)7,`4V5N87-T92!I;FQO9V=N
M:6YG.B`E<R!F<N5N("5S`%-E;F%S=&4@:6YL;V=G;FEN9SH@06QD<FEG`$QE
M='1L86YD`$QA=F5N9&5R`$QA9P!,87EO=70`3.1M;F$@=&]M(&;V<B!A='0@
M<W3D;F=A(&%V(&MA;G1L:6YJ90!,:6)A;F]N`%;D;G-T97(`5N1N<W1E<G)U
M8G)I:P!6Y&YS=&5R=N1R9&5N`$QE<V]T:&\`3FEVY0!,:6)E<FEA`$QI8GEE
M;@!,:65C:'1E;G-T96EN`$QJ=7-B;.4`1'5G9W)E9VX`3.1T="!R96=N`$SD
M='0@9O9R;6ED9&%G<W)E9VX`3.1T="!E9G1E<FUI9&1A9W-R96=N`$SD='0@
M<F5G;G-K=7(`3.1T="!R96=N(&UE9"#E<VMA`$SD='0@<V[V`$SD='0@<V[V
M<VMU<@!,:6UE<FEC:P!,Y&YK`$SD;FME;B!P96MA<B!PY3H`3.1N:V$@92UP
M;W-T861R97-S96X@=&EL;"!F=6YK=&EO;F5N(&;V<B!A='0@<VMA<&$@;GET
M="!M961D96QA;F1E`$SD;FMA<@!+86MA`$QI<W1A("T@86YVY&YD87)E(&MA
M;B!S92!M87!P96X`5FES82!D871A8F%S97(`5FES82!H:N1L<.1M;F5N`$QI
M<W1A('1A8F5L;&5R`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,
M:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B
M<V-R:6)E`$1E="!G:6-K(&EN=&4@871T(&QI<W1A('-E<W-I;VYE<CH@)7,`
M1&5T(&=I8VL@:6YT92!A='0@;&ES=&$@86YVY&YD87)E.B`E<P!,:7-T;FEN
M9R!A=B!A;G;D;F1A<F4@879A:W1I=F5R860N`$QI='1E<F%T=7(`3&ET875E
M;@!,861D87(N+BX`3&]K86P@=&ED.B``4F5G:6]N86QT`%!L871S`$QO9V=A
M(&EN`$QO9V=A('5T`$QO9VEN`$QO9VEN86MT:79I=&5T97(`26YL;V=G;FEN
M9R!M:7-S;'EC:V%D97,N(%1R;VQI9W1V:7,@=F%R(&%N=N1N9&%R;F%M;B!E
M;&QE<B!L]G-E;F]R9"!F96QA:W1I9W0N`$EN;&]G9VYI;F<@;6ES<VQY8VMA
M9&5S+@!,Y6YG('1E>'0`2^1R;&5K`$SE9P!'<F5K:7-K82!G96UE;F5R`$QA
M=&EN<VMA(&=E;65N97(`4VWE(')O;65R<VMA('-I9F9R;W(`3&]Y;VQA`$QO
M>6]L82!";.4`3'5X96UB=7)G`$U-`$U/5$0`35,M5$Y%1B!B:6QA9V$@:6YN
M96CV;&P@:6YG96X@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI96X`36%G86=A
M<VMA<@!-86=I<VL`12UP;W-T`$4M<&]S=&%D;6EN`%-K87!A(&SD;FLN+BX`
M36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5R;F$`36%L:0!-86QT80!5;F1E<FCE
M;&P@;&ES=&%N(&UE9"!K871E9V]R:65R(&1U(&%N=N1N9&5R(&;V<B!A='0@
M:V%T96=O<FES97)A('!O<W1E<B!M960@;V-H(&;D<F=E<FYA('-O;2!T:6QL
M:/9R(&1E<W-A(&MA=&5G;W)I97(N`$UA<#(T+6MA<G1A`$UA<%%U97-T+6MA
M<G1A`-9V97)SY'1T;FEN9V%R('-P87)A9&4N`&UA<G,`36%R9VEN86P`1FQA
M9V=A('-O;2!LY'-T+V]LY'-T`$9L86=G82!M960@86YN86X@<W1A='5S("AT
M(&5X('9I:W1I9W0O8F5S=F%R870I`$UA<G-H86QL]F%R;F$`36%R=&EN:7%U
M90!-871C:&%N9&4@9N1L=`!-875R:71A;FEE;@!-875R:71I=7,`36%X('1I
M;&SE=&5N(&MR961I="X`1W+D;G,@9O9R(&UA>"!A;G1A;"!D96QA<B!I(&UE
M9&1E;&%N9&4@]G9E<G-K<FED96XN`$CV9W-T82!T96UP97)A='5R92!S96YA
M<W1E(#(T('1I;6UA<FYA.B``2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@
M-B!T:6UM87)N83H@`$UA>&EM86QT(&%N=&%L('!O<G1A;&)L;V-K`$UA>&EM
M86P@;.1N9V0`;6%J`$UA>6]T=&4`365D:6-I;@!!=F)O:V$@;?9T90!-]G1E
M<VEN9F]R;6%T:6]N`$WV=&5S9O9R9G+E9V%N`$WV=&5S<W9A<@!-]G1E<W5P
M<&1A=&5R:6YG`%5P<&1A=&5R:6YG<V)E9^1R86X@;VT@;?9T90!-961L96UM
M87(`365N>6SD9V4Z`%-LY2!I:&]P(&-E;&QE<@!-961D96QA;F1E`$UE9&1E
M;&%N9&5T('9E<FEF:65R861E<R!M96X@9&5N('-I9VYE<F%D97,@8V5R=&EF
M:6MA="!K=6YD92!I;G1E('9E<FEF:65R87,N`$UE9&1E;&%N9&4@9^1L;&5R
M(&EN=&4@;.1N9W)E+@!-961D96QA;F1E='EP`$UE=&%R=N1D97(`365T87)B
M;&]C:V5T(.1R(&EN=&4@=&EL;&?D;F=L:70N`$UE=&%R+6)L;V-K(&5J('1I
M;&QGY&YG;&EG="X@1&5T86QJ97(@:&%R(&QO9V=A=',@9O9R('-Y<W1E;6%D
M;6EN:7-T<F%T]G)E;BX`365T87)$0B#D<B!I;G1E(&%N<VQU=&5N+@!-971O
M9`!-971O9&5N("<E<R<@Y'(@:6YT92!D969I;FEE<F%D`$UE=&]D96X@:&%R
M(&EN=&4@9&5F:6YE<F%T<RX@06YR;W!A9"!M971O9#H@)7,`365T<FES:P!-
M97AI:V\`36EK<F]N97-I96X`36ET=&5N`$UI;65T>7``3.1G<W1A('1E;7!E
M<F%T=7(@<V5N87-T92`R-"!T:6UM87)N83H@`$SD9W-T82!T96UP97)A='5R
M('-E;F%S=&4@-B!T:6UM87)N83H@`$UI;G-T82!L]G-E;F]R9'/E;&1E<B!H
M87(@:6YT92!U<'!NY71T<R#D;@!3<&5G;&$`1&EV97)S90!/8FQI9V%T;W)I
M<VMT('!A:V5T('-A:VYA<R`H4$5!4B!(5%107U)E<75E<W0I+@!+;VYF:6=U
M<F%T:6]N('-A:VYA<RX@1'4@;>5S=&4@<VMA<&$@9&5N(&YU(&]M(&1U('9I
M;&P@86YVY&YD82!D96X@:.1R(&%P<&QI:V%T:6]N96XN`%-A:VYA<B!M961D
M96QA;F1E+4E$+@!/8FQI9V%T;W)I<VMT('!A:V5T('-A:VYA<R`H4$5!4B!-
M86EL*2X`4V%K;F%R('-E<W-I;VYS+4E$+@!-Y0!-;V)I;"!E+7!O<W0`36]D
M97)E<F$`Q&YD<F%D(&1A='5M`,1N9')A(&SD;FL`36]D=6QU<P!-;VQD879I
M96X`36]N86-O`$UO;F=O;&EE=`!-Y6YA9"!O8V@@Y7(`3>5N871L:6<`36]T
M<V5R<F%T`$WE;F9A<V5R`$9L97(@9N1L="!H:71T861E<R!PY2!R860@)60@
MY&X@9&5T(&;V<G;D;G1A9&4@)60N`$UA<F]C:V\`365S=&%D96QS(&ML87)T
M`$UE<W1A9&5L<R!M;VQN:6=T`$UE<W1A9&5L<R!S;VQI9W0`1FQY='1A(&YE
M9`!&;'ET=&$@=N1N<W1E<@!&;'ET=&$@:/9G97(`1FQY='1A('5P<`!&;'ET
M=&$@;F5D`$9L>71T82!U<'``36_G86UB:7%U90!-;WII;&QA`$9L97)N:7;E
M<VQI<W1A`$UU;'1I;6%P(%-T;W)B<FET86YN:65N:V%R=&$`1FQE<G9A;`!-
M:71T(&MO;G1O`$UI;B!K;VYT;VEN9F]R;6%T:6]N`$UI;B!P;W)T86P`36EN
M('!O<G1A;&QA>6]U=`!->6%N;6%R`$Y%2BP@2F%G(&%C8V5P=&5R87(@:6YT
M90!.86UN`$YA;6EB:6$`3F%U<G4`3F585`!"96CV=F5R(.5T9^1R9`!.97!A
M;`!.961E<FSD;F1E<FYA`$YE9&5R;.1N9'-K82!!;G1I;&QE<FYA`$YE<V-A
M<&4@8F%S+5523`!.971S8V%P92!F]G)N>65L<V4M55),`$YE='-C87!E(.5T
M97)K86QL96QS92U54DP`3F5T<V-A<&4@4U-,+7-E<G9E<FYA;6X`3F5T<V%P
M92!C97)T:69I:V%T<VMO;6UE;G1A<@!.971S87!E(&-E<G1I9FEK871S='EP
M`$[D='9E<FL`06QD<FEG`$YY82!+86QE9&]N:65N`$YY(&MA=&5G;W)I`$YY
M='0@;65D9&5L86YD92!T:6QL("5S`$YY;>5N90!.>71T(&%N=N1N9&%R;F%M
M;B`H=F%L9G)I='0I`$YY82!:965L86YD`$YY='0@;/9S96YO<F0`3GET="!L
M]G-E;F]R9"!K;VUM97(@871T(&?E('5T("5X+@!,]G-E;F]R9"!MY7-T92!V
M87)A('-A;6UA+@!.>71T(&;V;G-T97(@*%]B;&%N:RD`3GEH971E<@!.>6AE
M='-G<G5P<&5R`$[D<W1A`$MO;6UA;F1E(#0@9F%S97(`3N1S=&$@:6YS=.1L
M;&YI;F=A<@!.Y'-T83X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F%T=`!.
M:75E`$YE:@!$970@9FEN;G,@:6YG970@:V]N9FEG=7)A=&EO;G-D871A(&%T
M="!V:7-A('-K:6QL;F%D97(@9O9R+@!);F=E;B!T:6QL9^1N9VQI9R!S=')A
M=&5G:2!F]G(@871T('-K87!A($E33RUI;6%G92X`26YT92!E;B!B871C:&UA
M;&PN`$1E="!F:6YN<R!I;F=E="!B;&]C:R!PY2!D96X@8F5GY')D82!P;W-I
M=&EO;F5N`$EN9V5T(&MA;&5N9&5R;F%M;B!F]G(@34-!3"!A=71E;G1I<V5R
M:6YG(&%N9VEV970N`$EN9V5N(.1N9')I;F<N`$EN9V$@=6YD97)B96CV<FEG
M:&5T97(@:V%N(&SD9V=A<R!T:6QL(&1E;B!HY'(@8F5H]G)I9VAE=&5N+@!)
M;F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R("5S
M+@!);F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R
M($944"!61E,N`$EN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG
M:79E;B!F]G(@4U%,(%9&4RX`26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA
M=&EO;B!A;F=I=F5N(&;V<B!344PM9FEL(%9&4RX`26YG96X@:W)E9&ET(&MV
M87(N`$)E<VMR:79N:6YG('-A:VYA<RX`26YG96X@;6]T=&%G87)E(&%N9VEV
M96XN`$EN9V5N(&9I;"!U<'!L861D860`26YG82!I:V]N97(@:&ET=&%D97,N
M`$EN9V5N(&]R="!A;F=I=F5N+@!);F=E;B!O<G0@86YG:79E;BX`26YG970@
M;65D9&5L86YD92!B:69O9V%D97,N`$EN9V5T(&YA;6X@86YG:79E="X`26YG
M96X@;G5M;65R(&%N9VEV970N`$EN9V$@;V;V<G-KY&UD82!V:7-H971S;W)D
M`$EN9V5T(&SV<V5N;W)D(&;V<B!(5%10+6%U=&5N=&ES97)I;F<@86YG:79E
M="X`26YG970@;/9S96YO<F0@9O9R($E-05`M875T96YT:7-E<FEN9R!A;F=I
M=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@2V5R8F5R;W,M875T96YT:7-E<FEN
M9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@3&]G:6XM875T96YT:7-E
M<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R9"!F]G(@4$%34U=$+6%U=&5N
M=&ES97)I;F<@86YG:79E="X`26YG970@;/9S96YO<F0@9O9R(%--0BUA=71E
M;G1I<V5R:6YG(&%N9VEV970N`$EN9V$@=N1N=&%N9&4@<F5G:7-T<F5R:6YG
M87(N`$EN9V5N(&MV;W1A(&%N9VEV96X`26YG96X@:W9O=&$@86YG:79E;BX`
M26YG82!R96=L97(`26YG96X@879G<N1N<V%R92!A;F=I=F5N+@!);F=A('-I
M9&]R`$EN9V5N('/E9&%N(&9I;`!);F=E;B!T96UP;W+D<FMA=&%L;V<@=&EL
M;&?D;F=L:6<@9O9R(&-A8VAE+@!);F=E="!A;G;D;F1A<FYA;6X@;V-H+V5L
M;&5R(&SV<V5N;W)D('-K:6-K870N`$EN9V5T(&=I;'1I9R!834PM9&%T82!R
M971U<FYE<F%D97,`26YG82!VY')D96X`26YG96X@=F5R<VEO;B!H:71T861E
M<R!I(&1E;B!U<G-P<G5N9VQI9V$@:V]N9FEG=7)A=&EO;F5N+B#%=&5R<VMA
M<&$@:V]N9FEG=7)A=&EO;F5N+@!);F=E;B!V97)S:6]N(&AI='1A9&5S(&D@
M9&EN(&MO;F9I9W5R871I;VXN(,5T97)S:V%P82!K;VYF:6=U<F%T:6]N96XN
M`$EC:V4M9&5L=&%G87)E`$EN9V5N`$EN9V5N("AA;G;D;F0@=6YD97)F]G)S
M=.5D9"D`3F]R9F]L:_9A<FYA`$YO<G)A(&AE;6ES9N1R96X`3F]R<F$@36%R
M:6%N8?9A<FYA`$YO<F=E`$EN=&4@969T97(`26YT92!F]G)E`$EN=&4@96X@
M:V%T86QO9P!%:B!I;7!L96UE;G1E<F%D+@!%:B!A;F=I=F5N`%-T]F1S(&EN
M=&4N`$%N=&5C:VYI;F=A<@!);F=E;G1I;F<@871T('9I<V$L(&?E('1I;&QB
M86MA+@!/0E,`;F]V96UB97(`3G5M;65R`$%N=&%L('1E8VME;@!!;G1A;"!K
M;VQU;6YE<@!!;G1A;"!R861E<@!.=6UM97(@:6YT92!S<&5C:69I8V5R861E
M(&;V<B!A='0@=7!P9&%T97)A(&D@9&ES=')I8G5T:6]N<VQI<W1A;BX`3TL`
M3V)J96MT`$]B:F5K='-K87!A<F4`3VMT86P`;VMT;V)E<@!&:6QT97(@9O9R
M(&]F]G)S:^1M9&AE=&5R`$MO;G1O<@!'86UM86QT(&]C:"!N>71T(&SV<V5N
M;W)D(&;E<B!I;G1E('9A<F$@<V%M;6$N`$=A;6UA;'0@;/9S96YO<F0`1V%M
M;6%L="!L]G-E;F]R9"#D<B!F96QA:W1I9W0`3VUA;@!$96QA9&4@;6%P<&%R
M('-T]F1S(&5N8F%R="!A=B!)34%0+7-E<G9R87(`16YB87)T(&]F]G)S:^1M
M9&$@=FES:&5T<V]R9`!%;F1A<W0@96X@92UP;W-T861R97-S('1I;&SE=&5N
M+@!%;F1A<W0@Y&=A<F4@96QL97(@<WES=&5M861M:6YI<W1R873V<B!K86X@
MY&YD<F$@Y&=A<F4@96QL97(@8F5H]G)I9VAE=&5R('#E(&5N('5T9&5L;FEN
M9P#6<'!N82!I(&YY='0@9O9N<W1E<@!/<&5N4U-,+69E;#H@1&5T(&=I8VL@
M:6YT92!A='0@97AT<F%H97)A(&1A=&$@9G+E;B!S:6=N97)A9"!3+TU)344M
M9&5L+@#6<'!N82!LY&YK(&D@;GET="!F]FYS=&5R`$]P97)A=&EV<WES=&5M
M`$EC:V4@;V)L:6=A=&]R:7-K82!D96QT86=A<F4`26YS=.1L;&YI;F=A<@!)
M;G-TY&QL;FEN9V%R(&;V<B`E<P!3;W)T97)A9"!L:7-T80!/<F=A;FES871I
M;VX`3W)G86YI<V%T:6]N<V5N:&5T`$]R9V%N:7-E<F$`57)S<')U;F=L:6<@
M87!P;&EK871I;VYS;6%L;`!5<G-P<G5N9VQI9V$@;6%L;&%R(&D@)7,Z`$%N
M;F%N`$%N9')A(&EN<W3D;&QN:6YG87(`Q&=A<F)E:/9R:6=H971E<@!004TM
M075T96YT:7-E<FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG+@!014%2.CI-86EL
M+6MO<'!L:6YG`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D
M($1A=&$`4'5B;&EK(%!'4"UN>6-K96P`4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T80!02%`M:V]D`%!(4"US:V%L`$SD='0@9O9R;6ED9&%G<W)E9VX`1O9R
M;6ED9&%G<W)E9VX`169T97)M:61D86=S<VMU<F%R`$5F=&5R;6ED9&%G<W-N
M]@!%9G1E<FUI9&1A9W-S:W5R87(@;65D('-N]@!%9G1E<FUI9&1A9W-S;VP`
MQ7-K<VMU<F%R('#E(&5F=&5R;6ED9&%G96X`4$]325@M=&EL;.1G9R!S86MN
M87,`4%](4"US:V%L`%5T9GEL;&YA9#H`4&%K:7-T86X`4&%L874`4&%L97-T
M:6YA`%!A;F%M80!087!U82U.>6$@1W5I;F5A`%!A<F%G=6%Y`$1E;'9I<R!M
M;VQN:6=T`$SV<V5N;W)D`$SV<V5N;W)D(.1N9')A9&5S+@!,]G-E;F]R9"!F
M96QA:W1I9W0`3/9S96YO<F0@:W+D=G,@9O9R(%)!1$E54R!A=71E;G1I<V5R
M:6YG+@!,]G-E;F]R9"!M960@8F5K<N1F=&5L<V4`3/9S96YO<F0Z`$SV<V5N
M;W)D.B``3/9S96YO<F0@;>5S=&4@=F%R82!L:6MA+@!+;&ES=')A(&EN`$ML
M:7-T<F$@:6X@9G+E;B!U<FML:7!P<VAA;G1E<F%R96X`4_9K=N1G`%;D;G1A
M;F1E(')E9VES=')E<FEN9V%R.@!-Y&YN:7-K;W(`4')O8V5N=`!5=&;V<B!U
M;F1E<FCE;&QS9G5N:W1I;VYE<@!5=&;V<B!U;F1E<FCE;&QS86MT:79I=&5T
M97(@=FED(&EN;&]G9VYI;F<_`$)E:/9R:6=H970`0F5H]G)I9VAE="`G)7,G
M(')A9&5R861E<R!I;G1E+@#%=&MO;7-T(&YE:V%D`&)E:/9R:6=H971E<@!"
M96CV<FEG:&5T<V%D;6EN:7-T<F%T:6]N`%!E<G-O;FQI9R!I;F9O<FUA=&EO
M;@!097)U`$AU<V1J=7(`1FEL:7!P:6YE<FYA`%1E;&5F;VX`1F]T;VX`4&ET
M8V%I<FX`4&EX;&%R`$ML:6-HZ65R`%9A<B!G;V0@:VQI8VMA(&D@96X@8V5L
M;`!"96MRY&9T82!A='0@9'4@=FEL;"!R861E<F$@=F%L9"!P;W-T/P!"96MR
MY&9T82!A='0@9'4@=FEL;"!R861E<F$@86MT=65L;'0@96QE;65N="X`5F%R
M(&=O9"!A;F=E(&WE;F%D(&]C:"#E<BX`5F%R(&=O9"!A;F=E(&YA;6X@9O9R
M(&MA=&5G;W)I;CH`5F%R(&=O9"!A;F=E(&=O9&OD;F0@25`M861R97-S+@!6
M87(@9V]D(&%N9V4@971T(&=I;'1I9W0@9&%T=6T[(&MO;G1R;VQL97)A(&%N
M=&%L970@9&%G87(@:2!MY6YA9&5N+@!687(@9V]D(&%N9V4@96X@9V]D:^1N
M9"!T:60N`%9A<B!G;V0@<W5M;65R82!D:71T('!R;V)L96TN`$%N9V4@9&ET
M="!A;G;D;F1A<FYA;6X@;V-H(&SV<V5N;W)D+@!687(@9V]D(&SD<R!I9V5N
M;VT@9O9L:F%N9&4@=&5X="X@1'4@3<535$4@<V%M='EC:V$@;65D('9I;&QK
M;W)E;B!F]G(@871T(&%N=N1N9&$@<WES=&5M970N`%9A<B!G;V0@;.1S(&EG
M96YO;2!F]FQJ86YD92!T97AT+B!$=2!-Q5-412!S86UT>6-K82!M960@=FEL
M;&MO<F5N(&;V<B!A='0@86YVY&YD82!S>7-T96UE="X`2V]N=')O;&QE<F$@
M9O9L:F%N9&4@:6YF;W)M871I;VX@;V-H(';D;&H@<V5D86X@96X@:&%N9&QI
M;F<@:2!M96YY;@IN961A;BX`5N1L:B!E;B!H86YD;&EN9R!F<N5N(&UE;GEN
M(&YE9&%N+@!!;F=E(&YY='0@:V%T96=O<FEN86UN.@!0;VQE;@!0;VQI=&EK
M`%5N9&5R<_9K;FEN9V%R`%!O<G1U9V%L`%!O<VET:6]N97)I;F<@878@8FEL
M9&5N`%!O<VET:6]N97)I;F<@878@=&%B96QL96X`4VMR:78@=&EL;"!D96X@
M:.1R(&UA<'!E;B`H96H@='9I;F=A="!A=B!)34%0*0!0;W-T;G5K90!.961E
M<F+V<F0@9&4@<V5N87-T92`E<R!T:6UM87)N83H@`$-H86YS('1I;&P\8G(O
M/FYE9&5R8O9R9`!!=71H7VQD87`Z($Q$05`M=&EL;.1G9R!S86MN87,N`%!R
M969S7W-E<W-I;VXZ($]B;&EG871O<FES:W0@<V5S<VEO;G-T:6QLY&=G(&AI
M='1A9&5S(&EN=&4N`%1R>6-K`$QU9G1T<GEC:R!V:60@:&%V970Z(`!,=69T
M=')Y8VLZ(`!&]G)H86YD<W9I<VYI;F<`1O9R:&%N9'-G<F%N<VMA(&)I;&0@
M:2!N>71T(&;V;G-T97(`1O9R96?E96YD92!I;G-TY&QL;FEN9V%R`%-K<FEV
M('5T(&1O:W5M96YT`%!R:79A=&$@;GEC:V5L`%!R;V)L96T`4')O8FQE;6)E
M<VMR:79N:6YG`%!R;VIE:W0`5&5X=`!0=6)L:6L@;GEC:V5L`%!U8FQI:R!N
M>6-K96QA;&=O<FET;0!0=6)L:6L@;GEC:V5L:6YF;W)M871I;VX`1F5L('9I
M9"!G96YE<F5R:6YG(&%V('!U8FQI:W0O<')I=F%T(&YY8VME;'!A<BX`4'5E
M<G1O(%)I8V\`4F5N<V$@;65D9&5L86YD96X`46%T87(`1G+E9V$`2W9O=&$`
M4'5B;&EK(%)302UN>6-K96P@*"5D(&)I=&%R*0!%;G-K:6QT('9A;`!296=N
M`%1I9&EG="!R96=N`%-E;G0@<F5G;@!296=N<VMU<F%R`%)E9VX@;V-H('-N
M]@!296=N('1I;&P@<V[V`%-L=6UP;>1S<VEG="!V:7-H971S;W)D`$;V<FCE
M;&QA;F1E`$SD<P!,Y',@;65D9&5L86YD96X`4^1K97)T(&%T="!D=2!V:6QL
M(')A9&5R82`E<S\@4F%D97)I;F=E;B!K86X@:6YT92#E;F=R87,N`%/D:V5R
M="!A='0@9'4@=FEL;"!R861E<F$@86YVY&YD87)D871A(&;V<B`E<S\@4F%D
M97)I;F=E;B!K86X@:6YT92#E;F=R87,N`$?V<B!O;2!D:6X@<V5N87-T92!I
M;FUA=&YI;F<`57!P9&%T97)A`%5P<&1A=&5R82!D>6YA;6ES:V$@;65N>65L
M96UE;G0Z`%5P<&1A=&5R82!P;W)T86QV>3H`4F5G97@`5FES82!F]G)HY6QL
M86YD96X`3&%D9&$@;VT`2V]M;65N=&%R97(`2V]M(&EHY6<@:6YF;W)M871I
M;VX@;VT@;&5D:6<O=7!P=&%G96XN`$9JY')R<V5R=G)A<@!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!482!B;W)T`%1A(&)O<G0@8FQO
M8VL`5&$@8F]R="!K;VQU;6X`5&$@8F]R="!F;W)M871E<FEN9P!482!B;W)T
M(&9RY6X@;6EN(&MA;&5N9&5R`%1A(&)O<G0@<&%R`%)A9&5R82!S<&%R870@
M<VMR:7!T(&9RY6X@<V5R=F5R;G,@=&5M<&]RY')K871A;&]G+@!482!B;W)T
M`%)A9&5R82!D96YN82!N;V0@9G+E;B!D;VMU;65N=&5T`%1A(&)O<G0@86YV
MY&YD87)E`%1A(&)O<G0@86YVY&YD87)E.B`E<P!3=F%R('-K:6-K870N`%-V
M87)A(&%T="!B96?D<F%N(&EN=&4@<W3V9',`4W9A<F$@;65D(&EN9F]R;6%T
M:6]N(&]M(&QE9&EG+W5P<'1A9V5N(&;V<B!K;VUM86YD92!T=N4@;>5N861E
M<BX`4W9A<F$@;65D(&1E;B!B96?D<F1A(&QE9&EG+W5P<'1A9V5N+6EN9F]R
M;6%T:6]N96XN`%-V87(Z("5S`$)E9^1R86X@:W5N9&4@:6YT92!B97-V87)A
M<RX@4F5T=7)N97)A9"!F96QK;V0Z(`!$96X@969T97)F<N5G861E('1JY&YS
M=&5N(&MU;F1E(&EN=&4@:&ET=&%S+@!%<F9O9')A9"`G)7,G(.1R(&EN=&4@
M86YG:79E;B!I(&MO;F9I9W5R871I;VYE;B!A=B`E<RX`17)F;V1R860@)R5S
M)R#D<B!I;G1E(&%N9VEV96X@:2!K;VYF:6=U<F5R:6YG96X@878@5D93+@!%
M<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R97)I;F=E
M;BX`3V)L:6=A=&]R:7-K='0@9N1L=`!/8FQI9V%T;W)I<VL@9&5L=&%G87)E
M`,5T97)S=.1L;`#%=&5R<W3D;&P@;/9S96YO<F0`Q71E<G-TY&QL(&SV<V5N
M;W)D`,5S=&5R=.1L;"!S96YA<W1E(&9RY6=A;@!297-U;'1A=`#%=&5R=N1N
M9"!T:6QL(&EN<W3D;&QN:6YG87(`06YG92!N>71T(&SV<V5N;W)D`%+I=6YI
M;VX`Q71E<G-TY&QL(&MO;F9I9W5R871I;VX`26YS=.1L;&YI;F=A<B!F]G(@
M4FEC:"!497AT($5D:71O<@!'Y71O<@!(]F=E<@!(]F=E<G)U8G)I:P!(]F=E
M<G;D<F1E;@!285]D:6YS=.1L;&YI;F=A<BXN+@!2;VQL`%)U;>1N:65N`%)O
M=&5R82`Q.#``4F]T97)A(';D;G-T97(`4F]T97)A(&CV9V5R`%)A9&EN<W3D
M;&QN:6YG87(`4F%D:6YS=.1L;&YI;F=A<@!2861E<CH`3&EN:F5R`$QI;FIE
M<B!V:7-A<R!M96QL86X@86QL82!R861E<B!O8V@@:V]L=6UN97(`3&EN:F5R
M('9I<V%S(&5N8F%R="!M96QL86X@:V]L=6UN97(`3&EN:F5R('9I<V%S(&5N
M8F%R="!M96QL86X@<F%D97(`2_9R`%)Y<W-L86YD`%)W86YD80!3+TU)344@
M<VEG;F%T=7(`4R]-24U%+6MR>7!T97)A="!M961D96QA;F1E`%-!4TPM875T
M96YT:7-E<FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG+@!335,@;65D9&5L86YD
M96X`4U%,+7-K86P`4U%,+7-E:W9E;G,@9O9R('5P<'-L86<@878@=N1R9&5N
M`%-32`!,64-+050`4U]13"US:V%L`$SV`%-A:6YT($AE;&5N80!386EN="!+
M:71T<R!O8V@@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0M4&EE<G)E(&]C:"!-
M:7%U96QO;@!386EN="!6:6YC96YT(&]C:"!'<F5N861I;F5R;F$`4V%M;6$@
M<F%M("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!O8V@@4')I
M;F-I<&4`4V%T=&5L:71L979E<F%N=/9R`%-A=61I87)A8FEE;@!3<&%R80!3
M<&%R82`G)7,G`%-P87)A("5S`%-P87)A(&EN<W3D;&QN:6YG87(`4W!A<F$@
M9V5N97)E<F%D(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I<'0@=&EL;"!D
M:6X@<V5R=F5R<R`@=&5M<"UK871A;&]G+@!3<&%R861E(&MO;F9I9W5R871I
M;VX@9O9R("5S+@!3<&%R861E('5P<&=R861E<FEN9W-S8W)I<'0@=&EL;#H@
M)7,N`%-P<FED9&$@Y7-K<VMU<F%R`%9E=&5N<VMA<`!3]FL`4_9K;6]T;W)E
M<@!6Y&QJ(&9I;&5R`%;D;&H@971T(&1A='5M`%;D;&H@9W)U<'`@871T(&SD
M9V=A('1I;&P`5N1L:B!N>2#D9V%R90!6Y&QJ('-E<G9E<@!6Y&QJ(&%N=N1N
M9&%R92!A='0@;.1G9V$@=&EL;`!6Y&QJ(&%L;&$`5N1L:B!D871U;6MO;7!O
M;F5N=&5R+@!6Y&QJ(&5T="!O8FIE:W0`5N1L:B!I;F=E;@!!;F=E(&1E('1E
M8VME;B!D=2!B96CV=F5R(&D@<G5T;W)N82!N961A;BX@1'4@:V%N('-E9&%N
M(&MO<&EE<F$@;V-H(&ML:7-T<F$@:6X@9&5M(&D@=&5X=&%R=71A;BX`5N1L
M:B!A=F=RY&YS87)E(&;V<B!D871U;3H`5N1L:B!D871U;69O<FUA=#H`5N1L
M:B!I9&5N=&ET970@9'4@=FEL;"#D;F1R83H`5N1L:B!A=F=RY&YS87)E(&;V
M<B!T:60Z`%;D;&H@=&ED<V9O<FUA=#H`5N1L:B!T=N4@;6%T8VAA;F1E(&;D
M;'0Z`%;D;&H@9&ET="!FY')G<V-H96UA+@!!;F=E(&1I='0@9O9R=F%L9&$@
M<W!RY6LZ`%-K:6-K82!S96YA<W1E(&EN9F]R;6%T:6]N96X`4VMI8VMA('!R
M;V)L96UR87!P;W)T`%-K:6-K82!335,`4V5N96=A;`!396YS;W(Z(`!S97!T
M96UB97(`4V5R8FEE;B!O8V@@36]N=&5N96=R;P!397)I96YU;6UE<@!397)V
M97)I;G-TY&QL;FEN9V%R(&9E;&%K=&EG82!E;&QE<B!I;F%K=&EV('-E<G9E
M<BX`4V5S<VEO;G-A9&UI;FES=')A=&EO;@!397-S:6]N<RU)1"!H87(@9^5T
M="!U="X`4V5S<VEO;F5R`%/D='0`2V]N9FEG=7)E<F$@86QT97)N871I=B!S
M;VT@;?9J;&EG9_9R(.5T97)S=.1L;&YI;F<@878@8F]R=&=L]FUT(&SV<V5N
M;W)D+@!+;VYF:6=U<F5R82!F:N1R<G-E<G9R87(@<V]M(&1U('9I;&P@:V]M
M;6$@Y70@9G+E;B!D:6X@<&]R=&%L+@!!;F=E(&1I='0@9O9R=F%L9&$@<W!R
MY6LL('1I9'-Z;VX@8V]H(&1A='5M:6YS=.1L;&YI;F=A<BX`4^1T="!D:71T
M(&EN:71I86QA(&%P<&QI:V%T:6]N+"!FY')G<V-H96UA+"!S:61U<'!D871E
M<FEN9R!O8V@@86YD<F$@=FES;FEN9W-I;G-TY&QL;FEN9V%R+@!3971U<`!+
M;VYF:6=U<F%T:6]N<W5P<&=R861E<FEN9W-S:W)I<'0@9FEN;G,@=&EL;&?D
M;F=L:6=A`$1E="!F:6YN<R!F;&5R82!O<G1E<B!M960@<&%R86UE=&5R;CH`
M4V5Y8VAE;&QE<FYA`$AA;F1E;`!+;W)T('-U;6UE<FEN9P!3:V%L;"!G96YV
MY&=S=&%N9V5N=&5R(&1E9FEN97)A<R!F]G(@9&4@9FQE<W1A(&SD;FMA<C\`
M5FES80!6:7-A('-K:6QL;F%D97(@;65L;&%N(&1E;B!A:W1U96QL82!O8V@@
M9&5N(&YY;&EG96X@<VMA<&%D92!K;VYF:6=U<F%T:6]N96XN`%9I<V$@<V5N
M87-T92!I;FQO9V=N:6YG<W1I9"!V:60@:6YL;V=G;FEN9S\`5FES82!I;G-T
MY&QL;FEN9R!F]G(@871T(&)E:.5L;&$@;W)I9VEN86P`5FES82!P86QE='0`
M5FES82`G=&%B96QL86MT:79I=&5T97(G(&D@;65N>6X_`%9I<V$@;65N>2!F
M]G(@)7,@=&EL;"!VY&YS=&5R/P!486)E;&QC96QL:6YS=.1L;&YI;F=A<@!4
M86)E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;&EN<W3D;&QN:6YG87(`5FES82!D
M:6%L;V=R=71A(&;V<B!B:6QD96=E;G-K87!E<@!6:7-A('5P<&QA9&1N:6YG
M`%-K=7)A<@!4:61I9V$@<VMU<F%R`%-E;F$@<VMU<F%R`%-K=7)A<B!I(&[D
M<FAE=&5N`$;V<FUI;G-K80!+<GEM<"!E;&QE<B!F;'ET=&$@8F]R="!NY')L
M:6=G86YD92!B;&]C:R!F]G)S=`!3:65R<F$@3&5O;F4`4F5G:7-T<F5R80!3
M:6=N871U<@!3:6=N871U<F%L9V]R:71M`%-I;7!L97@`4VEN9V%P;W)E`%-T
M;W)L96L`079B<GET('5N9&5R:.5L;`!3;&]V86MI96X`4VQO=F5N:65N`%-N
M]@!3;O9S:W5R`%-N]G-K=7)A<@!4:61I9V$@<V[V<VMU<F%R`%-E;F$@<V[V
M<VMU<F%R`%-N]F1J=7`Z(`!-;W1S=F%R86YD92!S;O8@:2!V871T96XZ(`!3
M86QO;6]N]F%R;F$`4V]M86QI80!3Y6YG97(@;V-H(&1I:W1E<@!3;W)T97)I
M;F=S:6]R9&YI;F=S=F%L`&OD;&QA9')E<W,`4WED869R:6MA`%/V9')A($=E
M;W)G:6$@;V-H(%-Y<W-A;F1W:6-H]F%R;F$`4^1D<F$@:&5M:7-FY')E;@!5
M=')Y;6UE(&UE;&QA;B!I;G1I;&QI9V=A;F1E(&-E;&QE<@!5=')Y;6UE(&UE
M;&QA;B!I;FYE:.5L;"!O8V@@:V%N=&5N(&D@8V5L;&5N`$UE;&QA;G)U;0!-
M96QL86YR=6T`365L;&%N<G5M(&]C:"!U=&KD;6YI;F<`4W!A;FEE;@!3<&%M
M`$EN;6%T;FEN9R!A=B!S<&5C:65L;&$@=&5C:V5N`$1E;&$@8V5L;`!$96QA
M(&MO;'5M;@!$96QA(')A9`!3<&]R=&5R`%-R:2!,86YK80!3=&%N9&%R9`!3
M=&%R(%1R96L`4W1A<G0`4W1A<G3E<@!3=&%T(&5L;&5R(')E9VEO;@!3=&%T
M=7,`3&%G<FEN9W-F;W)M870`1V%T=6%D<F5S<P!'96YO;7-T<G5K96X`4W1R
MY&YG;&ES=&$`5&$@8F]R="!D;VWD;B!F<N5N(&%D<F5S<V5N`%-T:6P@6T-3
M4UT`4_8`2V%N(&EN=&4@:&ET=&$@=6YD97)K871A;&]G("<E<R<N`,1R96YD
M90!3:VEC:V$`1&EN(&)E9^1R86X@871T(&SD9V=A('1I;&P@(B5S(B!T:6QL
M('-Y<W1E;65T(&AA<B!S:VEC:V%T<RX@1'4@:V%N(&EN=&4@;&]G9V$@:6X@
M:6YN86X@9&EN(&)E9^1R86X@:&%R(&%C8V5P=&5R871S+@!.961SY&YK=`!,
M>6-K870`)R5S)R!L861E<R!T:6QL(&D@<WES=&5M970N`%)A9&5R861E(&EN
M9F]R;6%T:6]N(&]M(&%N=N1N9&%R92`G)7,G+@`G)7,G(')A9&5R861E<RX`
M)R5S)R!T;V=S(&)O<G0@9G+E;B!S>7-T96UE="X`2V]N9FEG=7)A=&EO;F5N
M(&AA<B#E=&5R<W3D;&QT<RX@3&%D9&$@;VT@<VED86X@9O9R(&%T="!S92!F
M]G+D;F1R:6YG87(N`%-P87)A9&4@8F%C:W5P:V]N9FEG=7)A=&EO;BX`4W!A
M<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N("5S+@`G)7,G('5P<&1A=&5R861E
M<RX`4VMR978@)7,`4W5D86X`4V%M;6%N<W3D;&QN:6YG`%-O;'5P<&?E;F<`
M4V]L;F5D9^5N9P!3;VQI9W0`4V]L=7!P9^5N9P!3;VQU<'!GY6YG+VYE9&?E
M;F<`4V]L=7!P9^5N9SH@`%-O;&YE9&?E;F<`4V]L;F5D9^5N9SH@`%5P<&CV
M:F0`4W5P<&]R=`!3=7)I;F%M90!%9G1E<FYA;6X`4W9A;&)A<F0@;V-H($IA
M;B!-87EE;@!3=V%Z:6QA;F0`4W9E<FEG90!38VAW96EZ`%-Y:W)O;FES97)I
M;F=S;&]G9R!R861E<F%D`%-Y;F--3`!3>6YT87AF96P@:2!S]FMK<FET97)I
M80!3>7)I96X`Q7-K<VMU<@#%<VMS:W5R87(@;V-H(&)LY7-I9W0`Q7-K<VMU
M<F%R`%1I9&EG82#E<VMS:W5R87(`5%-6+69I;`!486)E;&P`5&%B96QL:6YS
M=.1L;&YI;F=A<@!486)E;&QU<'!SY'1T;FEN9P!486)E;&QI;G-TY&QL;FEN
M9V%R`%1A:7=A;@!486EW86X`5&%J:6MI<W1A;@!486YZ86YI80!-Y6PZ`%5P
M<&=I9G1E<@!496%L`%1E;&5F;VYN=6UM97(`2/9G<W1A('1E;7!E<F%T=7(@
M<V5N87-T92!T:6UM96XZ(`!496UP97)A='5R`%1E;7!E<F%T=7(Z(`!496UP
M97)A='5R/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<P!+86X@:6YT
M92!H:71T82!M86QL("5S+@!!;G;D;F1A<F%D;6EN:7-T<F%T:6]N`$=O9&OD
M;FX@8F5GY')A;B!P<F5L:6UI;N1R=`!0<F5L:6UI;N1R="!A8V-E<'1E<F%T
M`%1E>'0`16YB87)T('1E>'0`5&5X=&IU<W1E<FEN9P!497AT=&]P`%1O`%1H
M86D@*%1)4RTV,C`I`%1H86EL86YD`%1A8VL@9O9R(&%T="!D=2!A;G;D;F1E
M<B!S>7-T96UE="X`3.1N:V5N("5S('1I;&P@)7,@:&%R(')A9&5R871S+@!&
M5%`M=&EL;.1G9V5T(.1R(&EN=&4@=&EL;&?D;F=L:6=T+@!(:7-T;W)I:W-Y
M<W1E;65T(.1R(&%V86MT:79E<F%T+@!(;W)D92]+;VQA8BUI;G1E9W)A=&EO
M;G-G<N1N<W-N:71T970@<W3V9&5R(&EN=&4@(B5S(@!)35-0+6QO9V=E;B!K
M=6YD92!I;G1E(&EN:71I97)A<RX`2VQA<W-E;B!-86EN=&5N86YC93HZ(&MU
M;F1E(&EN=&4@;&%D9&%S`$EN<W3D;&QN:6YG<V;V;G-T<F5T(&AA<B!S=.1N
M9W1S+B!!=G-L=71A<BX`061M:6YI<W1R873V<F5N(&WE<W1E(&MO;F9I9W5R
M97)A(&5N('!E<FUA;F5N="!"96CV<FEG:&5T<RUK;W!P;&EN9R!O;2!D=2!V
M:6QL(&%N=N1N9&$@0F5H]G)I9VAE=&5R+@!%;F)A<G0@;F5D<F4@<VED86X`
M2V%L96YD97)I;F9O<FUA=&EO;F5N(.1R(&9E;&%K=&EG`$MO;G1A:W1E;G,@
M240@86YG879S(&EN=&4@96QL97(@:W5N9&4@:6YT92!H:71T87,@:2!D871A
M8F%S96XN`$MO;G1A:W1E;B!L861E<R!T:6QL(&D@861R97-S8F]K96XN`$1E
M;B!L]G-G:F]R9&$@4$=0+7-I9VYA='5R96X@:W+D=G,@9O9R(&%T="!V97)I
M9FEE<F$@9&5T('-I9VYE<F%D92!M961D96QA;F1E="X`1&ES=')I8G5T:6]N
M<VQI<W1A;G,@240@86YG879S(&EN=&4@96QL97(@:W5N9&4@:6YT92!H:71T
M87,@:2!D871A8F%S96XN`$1I<W1R:6)U=&EO;G-L:7-T86X@:&%R(&EN=&4@
M86YG:79I=',N`$MR>7!T97)I;F=S9G5N:W1I;VYE<FYA(&MRY'9E<B!E;B!S
MY&ME<B!W96)F]G)B:6YD96QS92`H2%144%,I+@!(Y&YD96QS96X@;&%D97,@
M=&EL;"!I(&MA;&5N9&5R;BX`1FEL96X@)7,@<VMA;&P@:6YN96CE;&QA(&5N
M(&EN<W3D;&QN:6YG(&;V<B`E<RX`1FEL96X@)7,@<VMA;&P@:6YN96CE;&QA
M(&EN<W3D;&QN:6YG87(@9O9R("5S+@!&:6QE;B!K86X@:6YT92!K;W!I97)A
M<R!T:6QL('-I9R!S:N1L=BX`1FEL96X@:V%N(&EN=&4@:V]P:65R87,@=&EL
M;"!S:6<@<VKD;'8N`$9I;&5N(&EN;F5H]FQL(&EN9V5N(&EN9F]R;6%T:6]N
M+@!(=79U9&;D;'0@9O9R(&1E='1A(&UE9&1E;&%N9&4O<F9C.#(R;65D9&5L
M86YD92!F]FQJ97(`261E;G1I=&5T96X@)R5S)R!R861E<F%D97,N`$)A<F$@
M=N1N<W1E<B!S:61A`$SD;FME;B!H87(@=&%G:71S(&)O<G0`4_9K=N1G96X@
M=&EL;"!';G501RUP<F]G<F%M;65T(&WE<W1E('9A<F$@86YG:79E;B!T:6QL
M(&ML87-S96X@0W)Y<'1?<&=P.CHN`$UE9&1E;&%N9&5T('-K:6-K870@)7,@
M=&EL;"`E<R!M960@Y')E;F1E("(E<R(@:&%R('9I<V%T<RX*1&5T=&$@Y'(@
M:6YG96X@9V%R86YT:2!F]G(@871T(&UE9&1E;&%N9&5T(&AA<B!LY'-T<RX`
M3F%M;F5T('-O;2!S:V%L;"!A;G;D;F1A<R!F]G(@871T(&SD;FMA('1I;&P@
M<VMA<&$M<VED86X`06YT86P@9N1L="!MY7-T92!V87)A(&5T="!N=6UE<FES
M:W0@=N1R9&4N`$UO9'5L96X@;W!E;G-S;"!K<N1V<R!A=B!K;&%S<V5N($AO
M<F1E7T-R>7!T7W-M:6UE.CHN`$EN<W3D;&QN:6YG96X@(B5S(B!K=6YD92!I
M;G1E('-P87)A<R!PY2!G<G5N9"!A=B!A='0@9&%T86WD;F=D96X@]G9E<G-K
M<FEV97(@9&5N(&UA>&EM86QT('1I;&SE=&YA`%!R;V=R86UM970@<V]M(&%N
M=N1N9',@9O9R(&%T="!V:7-A(&1E;B!HY'(@;65D9&5L86YD971Y<&5N("@E
M<RD@<V%K;F%S('#E('-Y<W1E;65T+@!496-K;F5T(&;V<B!C:71E<FEN9R!M
MY7-T92!V87)A(&5T="!T96-K96XN`$)A<F$@:/9G97(@;V-H(';D;G-T97(@
M<VED;W(`0F%R82!H]F=E<B!S:61A`%-E<&%R871O<FX@;>5S=&4@=F%R82!E
M='0@=&5C:V5N+@!397)V97(@)R5S)R!R861E<F%D97,N`%-E<G9E<B`G)7,G
M('-P87)A9&5S+@!0<F5N=6UE<F%T:6]N<V)E9^1R86X@9O9R("5S(&AA<B!T
M86=I=',@8F]R="X`06YG:79E;B!R860@*"5D*2!F:6YN<R!I;G1E+@!!;F=I
M=F5N(')A9"!E>&ES=&5R87(@:6YT92X`57!P9VEF=&5N(&AA<B!L86=T<R!T
M:6QL(&D@9&EN('5P<&=I9G1S;&ES=&$N`%1E;7!O<N1R(&9I;"`G)7,G(&9I
M;FYS(&EN=&4N`%1E>'1E;B!D=2!M871A="!I;B!S=.1M;65R(&EN=&4@]G9E
M<F5N<R!M960@=&5X=&5N('#E('-KY')M96X`0F%R82!T;W!P(&]C:"!B;W1T
M96X@<VED80!"87)A('1O<'!S:61A`%5P<&QA9&1A="!D871A(&;V<G-V86YN
M('-E9&%N(&;V<F5GY65N9&4@<W1E9RX`1&5N('5P<&QA9&1A9&4@9FEL96X@
M:W5N9&4@:6YT92!S<&%R87,N`$QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N
M(&;V<B!A;G;D;F1A<F5N(&AA<B!S<&%R871S+@!796%T:&5R+F-O;2UB;&]C
M:V5T(.1R(&EN=&4@=&EL;&?D;F=L:6=T+@!496UA:V%T86QO9R`G)7,G(&9I
M;FYS(&EN=&4N`$EN9V$@:6YS=.1L;&YI;F=A<B!T:6QL9^1N9VQI9V$N`$1E
M="!F:6YN<R!I;F=A(&%L=&5R;F%T:79A(&1E;&%R('-O;2!K86X@=FES87,@
M:6YL:6YE+@!&]G(@;>5N9V$@=&5C:V5N(&D@9N1L=&5T+B!$=2!H87(@86YG
M971T("5S('1E8VME;CL@;6%X:6UA;'0@86YT86P@=&5C:V5N(.1R("5S+@!0
M<F]B;&5M(&UE9"!A='0@;.1G9V$@=&EL;"`G)7,G('1I;&P@<WES=&5M970Z
M("5S`%!R;V)L96T@;65D(&%T="!R96YS82!I;F9O<FUA=&EO;B!O;2!A;G;D
M;F1A<F4@)R5S)R!F<N5N('-Y<W1E;65T.B``4')O8FQE;2!M960@871T('1A
M(&)O<G0@)R5S)R!F<N5N('-Y<W1E;65T.B``4')O8FQE;2!V:60@=7!P9&%T
M97)I;F<@878@)R5S)SH@)7,`4')O8FQE;2!V:60@=7!P;&%D9&YI;F<@878@
M9FEL96XN($EN9V$@)7,@;&%D9&%D97,@=7!P+@!$970@=7!P<W1O9"!P<F]B
M;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;CH@)7,@Y'(@<W3V<G)E(.1N
M(&UA>&EM86QT('1I;&SE=&5N('-T;W)L96L@*"5D(&)Y=&5S*2X`1&5T('5P
M<'-T;V0@<')O8FQE;2!V:60@=7!P;&%D9&YI;F<@878@9FEL96XZ("5S(&QA
M9&1A9&5S(&5N8F%R="!U<'`@9&5L=FES+@!$970@=7!P<W1O9"!E='0@9F5L
M('9I9"!V:7-N:6YG(&%V(&UE9&1E;&%N9&5D96QE;BX`1F5L('9I9"!I;7!O
M<G0@878@:V]N=&%K=&1A=&$N`$9E;"!V:60@:6UP;W)T(&%V(&CD;F1E;'-E
M;CH@)7,N`$9E;"!V:60@:6UP;W)T(&%V(&E#86QE;F1A<B!D871A+@!&96P@
M=FED(&EM<&]R="!A=B!U<'!G:69T96XZ("5S+@!&96P@=FED(&EM<&]R="!A
M=B!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;CH@)7,N`$5T="!F96P@
M<.5T<N1F9F%D97,@:2!F;W)M=6SD<F5T+B!+;VYT<F]L;&5R82!A='0@9'4@
M:6YT92!G;/9M="!F>6QL82!I(&5T="!O8FQI9V%T;W)I<VMT(&;D;'0N`$1E
M="!G:6-K(&EN=&4@871T('5T9O9R82!D96X@8F5GY')D82!A9')E<W-B;VMS
M9G5N:W1I;VYE;BX@5F%R(&=O9"!F]G)S]FL@<V5N87)E+@!&96P@=FED('5P
M<&1A=&5R:6YG(&%V(&MO;G1A:W1U<'!G:69T97(N($;V<G/V:R!I9V5N('-E
M;F%R92X`1F5L('9I9"!U<'!D871E<FEN9R!A=B!D:7-T<FEB=71I;VYS;&ES
M=&%N+B!&]G)S]FL@:6=E;B!S96YA<F4N`$1I;B!)34%0+7-E<G9E<B!S=/9D
M97(@:6YT92!D96QA9&4@;6%P<&%R+@!$96YN82!H86YD;&EN9R!S=/9D<R!I
M;G1E+@!$96YN82!F=6YK=&EO;B#D<B!I;G1E(&EM<&QE;65N=&5R860@Y&XN
M`$9I;&5N('9E<FMA<B!I;G1E('9A<F$@971T(&=I;'1I9W0@4D%2+6%R:VEV
M+@!&:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%I)4"UA<FMI
M=BX`1F5L86MT:6=T(&MO<G1N=6UM97(N`$1E;FYA(&1R:79R=71I;B!G]G(@
M9&5T(&WV:FQI9W0@871T('-K:6-K82!M961D96QA;F1E;B!V:6$@0VQI8VMA
M=&5L;"UB<GEG9V%N("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=E;F]M(&%T
M="!A;G;D;F1A($A45%`@05!).G0N`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T
M(&WV:FQI9W0@871T('-K:6-K82!M961D96QA;F1E;B!V:6$@5TE.+6)R>6=G
M86X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10
M($%023IT`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K
M:6-K82!M961D96QA;F1E;B!V:6$@<VUS,F5M86EL+6)R>6=G86X@*&AT='`Z
M+R]S;7,R96UA:6PN8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT
M`$1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M
M961D96QA;F1E;B!V:6$@4TU44"!G96YO;2!6;V1A9F]N92!)=&%L:65N+6)R
M>6=G86X@*&5N8F%R="!T:6QL(%9O9&%F;VYN=6UM97(I+B!$<FEV<G5T:6YE
M;B!K<N1V97(@971T(&4M<&]S=&MO;G1O(&AO<R!6;V1A9F]N92!)=&%L:65N
M("AH='1P.B\O=W=W+C$Y,"YI="DN`$;D;'1E="!MY7-T92!V87)A(&EF>6QL
M="X`1N1L=&5T(&;E<B!E;F)A<G0@:6YN96CE;&QA(&AE;'1A;"X`1N1L=&5T
M(&;E<B!E;F)A<G0@:6YN96CE;&QA('-I9F9R;W(@;V-H(&MO;&]N+@!&Y&QT
M970@9N5R(&5N8F%R="!I;FYE:.5L;&$@;VMT86QA('1A;"X`1N1L=&5T('-K
M86QL('9A<F$@96X@:V]M;6$M(&5L;&5R(&UE;&QA;G-L86=S<V5P87)A<F%D
M(&QI<W1A(&UE9"!H96QT86P`1N1L=&5T(&WE<W1E('9A<F$@971T(&=O9&OD
M;G0@=&%L+@!$971T82!FY&QT(&WE<W1E(&EN;F5HY6QL82!E;B!21T(M9N1R
M9VMO9"!I(&AE>&%D96-I;6%L="!F;W)M870L('0@97@@)R,Q,C,T868G+@!$
M971T82!F;W)M=6SD<B!H87(@<F5D86X@8F5A<F)E=&%T<RX`1&5T(&CD<B#D
M<B`E<RX`365D9&5L86YD970@<VMR979S(&D@96X@86YN86X@=&5C:V5N=7!P
M<^1T=&YI;F<@*"5S*2#D;B!D:6X@96=E;BX`1&5T(&CD<B!N=6UR970@;>5S
M=&4@=F%R82!M:6YS="!E='0N`%-E<G9E<FX@:V%N(&EN=&4@<&%C:V$@=7!P
M('II<"!O8V@@9WII<"!F:6QE<BX`4WES=&5M970@Y'(@9O9R('1I;&QFY&QL
M970@879A:W1I=F5R870N`$1E="!HY'(@=N1R9&5T(&WE<W1E('9A<F$@;G5M
M97)I<VMT+@!$971T82!F]FYS=&5R(&WE<W1E(&%N<F]P87,@9G+E;B!E='0@
M:V]N9FEG=7)A=&EO;G-F]FYS=&5R`,5S:V$`Q')E;F1E;@!4:60`5&ED<W)E
M9&]V:7-N:6YG`%1I9'-F;W)M870`5&ED<W9A;`#6<W1T:6UO<@!2=6)R:6L`
M4G5B<FEK("AT;V]L=&EP*3H`5&EL;`!&]G(@871T(&UA<FME<F$@9FQE<F$@
M=F%L+"!HY6QL(&YE9"!#=')L("A00RD@96QL97(@0V]M;6%N9"`H36%C*2!T
M86YG96YT96X@;N1R(&1U(&ML:6-K87(N`$ED86<`5FES82!(5$U,+6OD;&QA
M`%1O9V\`5&]K96QA=0!);6]R9V]N`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T
M;W`I`-9V97)SY'1T;FEN9V%R`%1R:6YI9&%D(&]C:"!4;V)A9V\`4V%N="!E
M;&QE<B!F86QS:W0`5&D`5'5N:7-I96X`5'5R:VEE=`!4=7)K:7-K("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,M(&]C:"!#86EC;W/V87)N80!4
M=79A;'4`06YG92!D:71T('9A;#H@`%56+6EN9&5X.B``55),`%523"!F]G(@
M9&ET="!L979E<F%N<W)A<'!O<G1E<FEN9W-S:W)I<'0`55),.@!59V%N9&$`
M56MR86EN80!+86X@:6YT92!LY'-A(%9&4RUM87!P+@!$970@9VEC:R!I;G1E
M(&%T="!LY&=G82!T:6QL('5T]FMA9"!A;G;D;F1A<FEN9F]R;6%T:6]N('9I
M9"!R96=I<W1E<FEN9RX`2V%N(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@
M5D93+69I;"`E<RX`2V%N(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@5D93
M+69I;"`E<R\E<RX`2V%N(&EN=&4@Y&YD<F$@=&EL;"`E<RX`2V%N(&EN=&4@
M:V]N=')O;&QE<F$@9FEL<W1O<FQE:R`E<R\E<P!+86X@:6YT92!K;VYT<F]L
M;&5R82!F:6QS=&]R;&5K('#E("5S+@!+86X@:6YT92!K;VYT<F]L;&5R82!F
M:6QS=&]R;&5K('#E("5S+R5S+@!+86X@:6YT92!K;VYT86MT82!344PM<V5R
M=F5R+@!+86X@:6YT92!K;VYT86MT82!V:6$@4U-,+@!+86X@:6YT92!K;W!I
M97)A(%9&4RUF:6PN`$MA;B!I;G1E('-K87!A(%9&4RUM87!P("5S+@!+86X@
M:6YT92!S:V%P82!61E,M;6%P<"X`2V%N(&EN=&4@<VMA<&$@5D93+69I;"X`
M2V%N(&EN=&4@<VMA<&$@5D93+6UA<'`@)R5S)RX`2V%N(&EN=&4@<VMA<&$@
M=&]M(%9&4RUF:6PN`$MA;B!I;G1E('!A8VMA('5P<"!D871A+@!+86X@:6YT
M92!R861E<F$@)7,L(&UA<'!E;B#D<B!I;G1E('1O;2X`2V%N(&EN=&4@<F%D
M97)A("<E<R<Z("5S`$MA;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN
M=&4@=&]M+@!+86X@:6YT92!R861E<F$@5D93+6UA<'`@<F5K=7)S:79T+@!+
M86X@:6YT92!R861E<F$@5D93+6UA<'`N`$MA;B!I;G1E(')A9&5R82!61E,M
M;6%P<#H@)7,N`$MA;B!I;G1E(')A9&5R82!61E,M9FEL("5S+@!+86X@:6YT
M92!R861E<F$@5D93+69I;"X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P("<E
M<R<N`$MA;B!I;G1E(')A9&5R82!61E,@<F5K=7)S:79T.B`E<RX`2V%N(&EN
M=&4@879G]G)A(&%K='5E;&P@;6%P<"X`2V%N(&EN=&4@97AT<F%H97)A($-E
M<G1I9FEK871S9&5T86QJ97(`2V%N(&EN=&4@;&%D9&$@9&5F:6YI=&EO;F5N
M(&%V("5S+@!+86X@:6YT92!F;'ET=&$@5D93+69I;"X`2V%N(&EN=&4@]G!P
M;F$@5D93+69I;"`E<RX`2V%N(&EN=&4@]G!P;F$@5D93+69I;"!F]G(@<VMR
M:79N:6YG+@!+86X@:6YT92#V<'!N82!61E,M9FEL+@!+86X@:6YT92#V<'!N
M82!K;VUP<FEM97)A="!A<FMI=BX`2V%N(&EN=&4@;.1S82!61E,M9FEL("AF
M:6QE<VEZ92@I(&UI<W-L>6-K861E<RDN`$MA;B!I;G1E(&SD<V$@5D93+69I
M;"`H9V5T1FEL95-I>F4H*2!M:7-S;'EC:V%D97,I+@!+86X@:6YT92!LY'-A
M(&9I;#H@`$MA;B!I;G1E(&SD<V$@:V%T86QO9V5N(&;V<B`G=F9S<F]O="<N
M`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2`E<R!T:6QL("5S.B!D97-T:6YA=&EO
M;G-M87!P(&9I;FYS(')E9&%N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M
M;6%P<"X`2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUM87!P.B`E<RX`2V%N
M(&EN=&4@8GET82!N86UN('#E(%9&4RUF:6P@)7,N`$MA;B!I;G1E(&)Y=&$@
M;F%M;B!PY2!61E,M9FEL("5S+R5S+@!+86X@:6YT92!B>71A(&YA;6X@<.4@
M5D93+69I;"X`2V%N(&EN=&4@:_9R82`G;6MI<V]F<R<N`$MA;B!I;G1E(/9V
M97)SY'1T82!7;W)D9&]K=6UE;G1E=`!+86X@:6YT92!S:W)I=F$@=&EL;"!6
M1E,M9FEL("5S+@!+86X@:6YT92!S:W)I=F$@=&EL;"!61E,M9FEL("AC;W!Y
M*"D@;6ES<VQY8VMA9&5S*2X`2V%N(&EN=&4@<VMR:79A(&1A=&$@=&EL;"!6
M1E,M9FEL+@!+86X@:6YT92!S:W)I=F$@=&EL;"!61E,M9FEL+"!K=F]T82!S
M:W5L;&4@]G9E<G-K<FED87,N`%5N9&5R<W1R=6ME;@#%;F=R82#D;F1R:6YG
M87(`Q6YG<F%R(&1I;B!S96YA<W1E(.5T9^1R9`!/=N1N=&%T('-V87(@9G+E
M;B!S97)V97(@<.4@9O9R8FEN9&5L<V4Z(`!/=N1N=&%T('-V87(@9G+E;B!S
M97)V97(@=&EL;#H@`$5J(&MA=&5G;W)I<V5R860`26-K92!H86YT97)A9"!K
M;VUP;VYE;G0@878@='EP.B`E<P!5;FEC;V1E("A55$8M."D`1O9R96YA9&4@
M07)A8F5M:7)A=&5N`%-T;W)B<FET86YN:65N`$;V<F5N=&$@4W1A=&5R;F$`
M06UE<FEK86YS:V$@4W1I;&QA:&%V<_9A<FYA`$5N:&5T97(`3VOD;F0`3VOD
M;G0@9W+D;G-S;FET='-M961D96QA;F1E:60@*&%P:6US9VED*2X`3VOD;G0@
M:VQI96YT;65D9&5L86YD96ED("AC;&EM<V=I9"DN`$]KY&YD(&]R="!S<&5C
M:69I8V5R860N`$]KY&YT(&%N=N1N9&%R;F%M;B!E;&QE<B!L]G-E;F]R9"X`
M5&$@8F]R="!LY&YK96X@9G+E;B!N=79R86YD92!E;&5M96YT`$YA;6YL]G,`
M26-K92UP<FEV:6QI9V5R861E('-K<FEP="!K86X@:6YT92!K;VUM82#E="!+
M;&EP<"!U="]+;W!I97)A+TML:7-T<F$M9G5N:W1I;VYE<FYA(&%V('/D:V5R
M:&5T<W-KY&PN($ML:6-K82!/2R!F]G(@871T('-E(&5N('1E:VYI<VL@8F5S
M:W)I=FYI;F<@9G+E;B!M;WII;&QA+F]R9R!O;2!H=7(@9'4@:V%N('1I;&SE
M=&$@871T('-K<FEP="!K;VUM97(@Y70@=7)K;&EP<"X`5&$@8F]R="!FY')G
M`%1I;&SD9V=E="!S=/9D<R!I;G1E`%5P<&1A=&5R80!5<'!D871E<F$@)7,`
M57!P9&%T97)A('-T871U<R!PY2!S=F%R86YD90!5<'!D871E<F$@86YVY&YD
M87)E`%5P<&1A=&5R861E("<E<R<N`%5P<&1A=&5R:6YG<W-C<FEP="!R861E
M<F%T+@!,861D82!U<'``3&%D9&%D92!U<'`@86QL82!K;VYF:6=U<F%T:6]N
M<V9I;&5R('1I;&P@<V5R=F5R;BX`5F5R<V%L97(`4F]M97)S:V$@<VEF9G)O
M<@!5<G5G=6%Y`$%N=N1N9"!A:W1U96QL.B`E<P!!;G;D;F0@4U-,`$%N=N1N
M9"!O;2!N86UN+VSV<V5N;W)D(.1R(&%N;F]R;'5N9&$@9O9R($E-4U`M<V5R
M=F5R+@!!;G;D;F1A<F4`06YVY&YD87)E("5S(.1R(&EN=&4@8F5H]G)I9R!F
M]G(@)7,N`$%N=N1N9&%R861M:6YI<W1R871I;VX`06YVY&YD87)I;G-TY&QL
M;FEN9V%R`$%N=N1N9&%R<F5G:7-T<F5R:6YG`$%N=N1N9&%R<F5G:7-T<F5R
M:6YG(&AA<B!A=F%K=&EV97)A=',N`$%N=N1N9&%R:V]N=&]T(&AI='1A9&5S
M(&EN=&4`06YVY&YD87)N86UN`$%N=N1N9&%R;F%M;B`E<R!F:6YN<R!R961A
M;BX`06YVY&YD87)N86UN.@!!;G;D;F1A<FYA;6XZ(`!!;G;D;F1A<F4@:2!S
M>7-T96UE=#H`57IB96MI<W1A;@!61E,M;6%P<"!E>&ES=&5R87(@:6YT92X`
M4V5M97-T97(`1VEL=&EG82!P;&%T<V5R('-O;2!H:71T861E<R!I;FML=61E
M<F%R.B``1VEL=&EG:&5T`$UI;G5T97(@9G+E;B!N=0!6Y')D970@]G9E<G-T
M:6=E<B!D970@:/9G<W1A('1I;&SE=&YA("@E<RD`5N1R9&5N`%;D<F1E;B!A
M='0@=N1L:F$@9G+E;@!686YU=&%U`%9A<FEA8F5L`%9E;F5Z=65L80!697)I
M9FEE<FEN9R!M:7-S;'EC:V%D97,@+2!M961D96QA;F1E="!K86X@:&$@;6%N
M:7!U;&5R871S+@!697)S:6]N`%9E<G-I;VYH86YT97)I;F<`5F5R=&EK86P@
M:G5S=&5R:6YG`%9E<G1I:V%L('5T9GEL;&YA9`!697)T:6MA;#H`5N1L9&EG
M="!H]F<`5FEE=&YA;0!6:65T;F%M97-I<VL@*%9)4T-)22D`5FES82`E<P!6
M:7-A(&5N(&5X=&5R;B!W96)B<VED80!6:7-A('-O;2`E<P!6:7-A(&CD;F1E
M;'-E`%9I<V$@=7!P9VEF=`!*=6YG9G)U]F%R;F$L($)R:71T:7-K80!*=6YG
M9G)U]F%R;F$L($%M97)I:V%N<VMA`%-I:W0`4VEK=#H`5F]D869O;F4@271A
M;&EE;B!V:6$@4TU44`!605).`%9!4DY)3D<A(2$@4D%$15)!(%-+4DE05$54
M($U!3E5%3$Q4($92Q4X@)7,N`%=)3B!V:6$@2%144`!786QL:7,@;V-H($9U
M='5N80!687)N:6YG`$]N`%;D9&5R<')O9VYO<P!6Y&1E<F1A=&$@9G+E;@!W
M96%T:&5R+F-O;0!796)B`%=E8F)P;&%T<P!796)B<&QA='-E;B`M(%-O8F5R
M`%=E8F)P;&%T<V5N("T@4V]B97(@3ED`5F5C:V]V:7,`5N1L:V]M;65N`%;D
M;&MO;6UE;B!T:6QL("5S`%;D;&MO;6UE;BP@)7,`5N1S=&5R;.1N9'-K("A)
M4T\M.#@U.2TQ*0!6Y'-T97)LY&YD<VL@*$E33RTX.#4Y+3$U*0!6Y'-T<F$@
M4V%H87)A`%9I;&ME;B!A<'!L:6MA=&EO;B!S:V%L;"`E<R!V:7-A(&5F=&5R
M(&EN;&]G9VYI;F<_`%9I;&ME;B#D<B!A=F=RY&YS;FEN9W-T96-K;F5T/P!6
M:6QK970@Y'(@=&5C:VYE="!F]G(@8VET97)A9"!T97AT/P!7:&5R96ES($%U
M<W1R86QI96YK87)T80!6:6QK82!F87-E<@!6:6QK82!P;'5G:6X@<VMA;&P@
M86MT:79E<F%S(&;V<B!2:6-H(%1E>'0@961I=&]R;BX`0G)E9&0`0G)E9&0@
M:2!#4U,M=6YI=',`0G)E9&0@<.4@;65N>6X@9O9R("<E<R<@=&EL;"!VY&YS
M=&5R("AGY&QL97(@9G+E;B!NY'-T82!I;FQO9V=N:6YG`%1A8F5L;&)R961D
M`$)R961D96YH970`0G)E9&0Z`%=I:VD`5FEN9`!4:61I9R!V:6YD`%9I;F1H
M87-T:6=H970@:2!K;F]P`%9I;F0Z`%9I;F0Z(`!6:7-D;VT`UFYS:V5L:7-T
M80!!<F)E=&4`061R97-S+"!A<F)E=&4`5&5L969O;BP@87)B971E`$9E;"!A
M;G1A;"!FY&QT('#E(')A9"`E9"X@1O9R=N1N=&%D92`E9"P@:&ET=&%D92`E
M9"X`1F5L(&%N=&%L(&;D;'0N($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N
M`$9E;"!P;W-I=&EO;B`E9"!V:60@;.1S;FEN9R!A=B!61E,M9FEL+@!8+5)E
M9@!8-3`Y5C,@573V:V%D(&YY8VME;&%N=N1N9&YI;F<`6#4P.58S+71I;&SD
M9V<`65D`65E960!986AO;R$@;6%P`,5R;&EG`%EE;65N`$IA`$IA+"!J86<@
M<V%M='EC:V5R`$1U(&AA<B!A:W1I=F5R870@=&5X=&SD9V4N($%N=N1N9"!;
M/#Y=(&;V<B!A='0@Y71E<F?E('1I;&P@5UE325=91RX`1'4@:&%R(&EN=&4@
M8F5H]G)I9VAE="!S:V%P82!F;&5R(.1N("5D(&)L;V-K+@!$=2#D<B!I;G1E
M(&%U=&5N=&ES97)A9"X`1'4@:V%N(&EN=&4@86YVY&YD82`G7"<@:2!D:71T
M(&YA;6X`1'4@:V%N(&EN=&4@86YVY&YD82`G7"<@:2!D:71T(&YA;6X`1'4@
M86YG878@:6YT92!E;B!G;V1KY&YD(&4M<&]S=&%D<F5S<RX`1'4@Y'(@=71L
M;V=G860N`$1U(&WE<W1E(&%N9V4@971T(&=I;'1I9W0@;6]B:6QN=6UM97([
M(&5N8F%R="!S:69F<F]R(&]C:"!E='0@)RLG(&;V<F4@:6YT97)N871I;VYE
M;&QT('!R969I>"X`1'4@86YG878@:6YT92!E='0@9V]D:^1N="!VY')D92X`
M1'4@;>5S=&4@:V]N9FEG=7)E<F$@96X@1&%T851RY&1S+6MO<'!L:6YG(&;V
M<B!A='0@86YVY&YD82!R96=I<W1R97)I;F<`1'4@;>5S=&4@:V]N9FEG=7)E
M<F$@96X@5D93+6MO<'!L:6YG`$1U(&WE<W1E(&)E<VMR:79A('!R;V)L96UE
M;BP@:6YN86X@9'4@:V%N(')A<'!O<G1E<F$@971T('!R;V)L96TN`$1U(&WE
M<W1E(&%N9V4@96X@55),('-O;2!LY&YK96X@<&5K87(@<.4`1'4@;>5S=&4@
M86YG92!E;B!S97)V97(@<V]M('-K86QL(')A9&5R87,N`$1U(&WE<W1E(&%N
M9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@<F5N<V%S+@!$=2!MY7-T
M92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(')A9&5R87,N`$1U
M(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@;.1G9V%S
M('1I;&PN`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA
M;&P@=7!P9&%T97)A<RX`1'4@;>5S=&4@86YG92!E;B#E=&?D<F0@<V]M('-K
M86QL('5T9O9R87,N`$1U(&WE<W1E(&%N9V4@971T(&YY='0@:V%T96=O<FEN
M86UN+@!$=2!MY7-T92!A;F=E(&5T="!I=&%L:65N<VMT('1E;&5F;VYN=6UM
M97(`1&EN("5S('-E<W-I;VX@:&%R('5P<&CV<G0N(%9A<B!G;V0@;&]G9V$@
M:6X@:6=E;BX`1&EN(&4M<&]S=&%D<F5S<P!$:6X@1G+E;CH@861R97-S.@!$
M:6X@:6YF;W)M871I;VX`1&EN(&EN=&5R;F5T861R97-S(&AA<B#D;F1R871S
M(&5F=&5R(&%T="!D=2!L;V=G870@:6X@=&EL;"`G)7,G+B!&]G(@871T('-K
M>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN(&EG96XN`$1I='0@;F%M;@!$
M:6X@875T96YT:7-E<FEN9W-K;W!P;&EN9R!S=/9D97(@:6YT92!U<'!LY&=G
M(&%V(&%N=N1N9&%R92X@3VT@9'4@=FEL;"!A;G;D;F1A($AO<F1E(&;V<B!A
M='0@861M:6YI<W1R97)A(&%N=N1N9&%R92!SY2!MY7-T92!D=2!A;G;D;F1A
M(&5N(&%N;F%N(&%U=&5N=&ES97)I;F=S:V]P<&QI;F<N`$1I='0@875T96YT
M:7-E<FEN9W-K;W!P;&EN9R!S=/9D97(@:6YT92!L:7-T;FEN9R!A=B!A;G;D
M;F1A<F4L(&5L;&5R('/E(.1R(&9U;FMT:6]N96X@879S=.1N9V0N`$1I;B!W
M96)B;.1S87)E+VEN=&5R;F5T861R97-S(&AA<B#D;F1R871S(&5F=&5R(&%T
M="!D=2!L;V=G870@:6X@=&EL;"`G)7,G+B!&]G(@871T('-K>61D82!D:6<L
M(&WE<W1E(&1U(&QO9V=A(&EN(&EG96XN`$1I;B!W96)B;.1S87)E('-T]F1E
M<B!I;G1E(&1E;B!HY'(@9G5N:W1I;VYE;BX`1&EN('=E8F)LY'-A<F4@<W3V
M9&5R(&EN=&4@=71S:W)I9G1S9G5N:W1I;VYE;BX@5')Y8VL@0W1R;"]/<'1I
M;VX@*R!0(&;V<B!A='0@<VMR:79A('5T+@!$:6X@86MT=65L;&$@=&ED<WIO
M;CH`1&EN(&;V<G9A;&1A(&ED96YT:71E="!H87(@Y&YD<F%T<RX`1&EN(&;V
M<G9A;&1A(&ED96YT:71E=#H`1&ET="!F=6QL<W3D;F1I9V$@;F%M;CH`1&EN
M(&EN;&]G9VYI;F<@:&%R(&?E='0@=70N`$1I='0@;GEA(&SV<V5N;W)D(&;V
M<B`E<R#D<CH@)7,`1&EN82!I;G-TY&QL;FEN9V%R(&AA<B!U<'!D871E<F%T
M<R!F]G(@9&5N(&CD<B!S97-S:6]N96XN`$1I;F$@:6YS=.1L;&YI;F=A<B!H
M87(@=7!P9&%T97)A=',N`$1I='0@;/9S96YO<F0@:&%R(&)L:79I="#E=&5R
M<W3D;&QT`$1I='0@;/9S;F]R9"!H87(@Y71E<G-TY&QL=',L(&MO;G1R;VQL
M97)A(&1I;B!E+7!O<W0@;V-H(&QO9V=A(&EN(&UE9"!D:71T(&YY82!L]G-E
M;F]R9"X`1&ET="!L]G-E;F]R9"!H87(@9^5T="!U="X`1&EN82!F:N1R<G-E
M<G9R87(Z`$IU9V]S;&%V:65N`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P
M>0!;1_9M(&-I=&5R860@=&5X=%T`6T9E;')A<'!O<G1=`%M6:7-A(&-I=&5R
M860@=&5X="`M`%M6:7-A(&-I=&5R860@=&5X="`M("5S(')A9&5R70!;<F%D
M("5S(&%V("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851RY&0`7U)A
M9&5R82!R860`7T=R=7!P97(`7TAJY&QP`%]":6QD:6YS=.1L;&YI;F=A<BXN
M+@!?3&]G9V$@:6X`7TQO9V=A('5T`,1?;F1R82!LY&YK+BXN`%]);G-TY&QL
M;FEN9V%R`%]"96CV<FEG:&5T97(`7U1A(&)O<G0@;.1N:RXN+@!?4V5T=7``
M7U1A8F5L;&EN<W3D;&QN:6YG87(N+BX`7T%N=N1N9&%R90!A9')E<W-B;VL`
M;VOD;F0@;6]T=&%G87)E`&MA;&5N9&5R`&QU9VYT`&MA;B!I;G1E('-K87!A
M('5T9FEL`&MA;B!I;G1E(/9P<&YA(&EN9&%T80!K;&EC:V$@:.1R`&ML;V-K
M80!K;VUM86YD;W)A9'-F96P`:V]N9FEG=7)A=&EO;G-F96P`:W)I=&ES:R!S
M>7-T96UF:6P@<V%K;F%S`&1A=&%F;W)M871F96P`Y&YD<F$`<&]S=&5N(&MU
M;F1E(&EN=&4@:&ET=&%S`&9A;&QA;F1E`&9I;`!F<N5N(&1E;B`E<R`H)7,I
M(&ML("5S("5S`'-T;W)M8GEA<@!H.@!H:`!O:^1N9"!VY')D9&%T;W(`9V5N
M87-T`&EN;&EN90!B96%R8F5T;FEN9W-F96P`26YT97)N="!A<'!L:6MA=&EO
M;G-F96P`<F%D97)=`&9E;&MO9"`E9"!F<N5N(&UK:7-O9G,`;6T`;F%M;@!I
M;G1E(&EM<&QE;65N=&5R860`:6YT92!I;7!L96UE;G1E<F%D`&%N=&5C:VYI
M;F=S8FQO8VL`<')O8V5N=`#E=&MO;7-T(&YE:V%D`'!I>&QA<@!P<F]T;VMO
M;&QF96P`<W1I9V%N9&4`5&KD;G-T96X@Y'(@96H@=&EL;&?D;F=L:6<`=FES
M82!S:VEL;&YA9&5R`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&%D:6=T`'-Y
M<W1E;69E;`!U<'!G:69T<VQI<W1A`'1I;&QFY&QL:6=T(&9E;`!A;F=E(&SV
M<V5N;W)D970@=';E(&?E;F=E<B!F]G(@871T(&)E:W+D9G1A`&5N860`;F%M
M;FSV<P!A;G;D;F1A<G9A;`!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M<W9?4T4O:&5L<"YX;6P`````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S,S(P`#$P-3$U-#,Q,#8R`#`R,#,S-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/WAM;"!V97)S:6]N/2(Q
M+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]S=E]312]H96QP+GAM
M;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$R(&IA;B!%>'`@)"`M+3X*/&AE
M;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE
M/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A
M;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I
M;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT
M('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E
M(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N
M9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R
M;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O
M9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C
M=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@
M82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E
M=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N
M=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I
M82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C
M:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P
M86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W
M;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A
M=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"
M87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F
M('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B
M87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B
M87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE
M(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN
M=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L
M:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I
M<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B
M969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U
M;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E
M9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W
M:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W1R7U12
M+P``````````````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,3`V,@`P,38W,#(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O=')?5%(O3$-?34534T%'15,O````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R`#`R,#0V-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]T<E]44B],0U]-15-304=%
M4R]H;W)D92YM;P``````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`S,S8Q,#``,3`U
M,34T,S$P-C(`,#(R,3(U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-X2!)4`````F@8``!P```#L-```VP@``+QI````````
M*(T```X````IC0``#P```#B-```-````2(T```@```!6C0``"P```%^-```,
M````:XT```0```!XC0``#````'V-```/````BHT```L```":C0``#@```*:-
M```%````M8T``"@```"[C0``"````.2-```*````[8T``!4```#XC0``$@``
M``Z.```+````(8X```X````MC@``"@```#R.```-````1XX```X```!5C@``
M$0```&2.```-````=HX```P```"$C@``#0```)&.```&````GXX```\```"F
MC@``&````+:.```,````SXX```X```#<C@``#@```.N.```(````^HX``"X`
M```#CP``&@```#*/```R````38\``#@```"`CP``5````+F/``!1````#I``
M`%H```!@D```5P```+N0```T````$Y$```<```!(D0``"@```%"1```/````
M6Y$```4```!KD0``!@```'&1```1````>)$```@```"*D0``"0```).1```)
M````G9$``"4```"GD0``(````,V1```0````[I$```\```#_D0``"@````^2
M```#````&I(```\````>D@``%````"Z2```)````0Y(```T```!-D@``$@``
M`%N2```/````;I(```H```!^D@``#P```(F2```(````F9(``"0```"BD@``
M%````,>2```6````W)(```@```#SD@``&0```/R2```'````%I,```P````>
MDP``+````"N3```.````6),```,```!GDP``"P```&N3```'````=Y,```<`
M``!_DP``!0```(>3```%````C9,```H```"3DP```P```)Z3```7````HI,`
M``H```"ZDP``#P```,63```.````U9,``!@```#DDP``(P```/V3```.````
M(90``!0````PE```%P```$64```7````790``!<```!UE```$P```(V4```/
M````H90```X```"QE```'P```,"4```'````X)0```8```#HE```"````.^4
M```/````^)0```8````(E0``"@````^5```3````&I4```L````NE0``$```
M`#J5```5````2Y4``!4```!AE0``!P```'>5```0````?Y4```4```"0E0``
M%0```):5```1````K)4```P```"^E0``.P```,N5```)````!Y8```<````1
ME@``%````!F6```#````+I8```4````RE@``$````#B6```)````298``!,`
M``!3E@``.0```&>6```2````H98``"<```"TE@``+````-R6```J````"9<`
M`"4````TEP``"@```%J7```&````99<```D```!LEP``!P```':7```O````
M?I<``#<```"NEP``+@```.:7``!5````%9@``"T```!KF```+0```)F8```M
M````QY@``$````#UF```(P```#:9```C````6ID``"T```!^F0``,P```*R9
M```5````X)D``!D```#VF0``*0```!":```D````.IH``!$```!?F@``"@``
M`'&:```,````?)H```H```")F@``$````)2:```6````I9H``!8```"\F@``
M!P```-.:```'````VYH``!0```#CF@``"@```/B:```(`````YL```@````,
MFP``!P```!6;```'````'9L```8````EFP``!0```"R;```'````,IL```8`
M```ZFP``"````$&;```I````2IL```X```!TFP``"@```(.;```$````CIL`
M``<```"3FP``"0```)N;```&````I9L``!$```"LFP``!P```+Z;```6````
MQIL```0```#=FP``"````.*;```&````ZYL```T```#RFP``!@````"<```>
M````!YP``!$````FG```"````#B<```-````09P```P```!/G```!P```%R<
M```#````9)P```,```!HG```%P```&R<```3````A)P```@```"8G```!```
M`*&<```(````IIP```@```"OG```00```+B<```@````^IP```8````;G0``
M!@```"*=```5````*9T``!@````_G0``(@```%B=```N````>YT``!T```"J
MG0``(0```,B=``!4````ZIT``"D````_G@``"@```&F>```'````=)X``!4`
M``!\G@``#@```)*>```*````H9X```\```"LG@``#0```+R>```/````RIX`
M``T```#:G@``"0```.B>```4````\IX```8````'GP``&`````Z?```=````
M)Y\``!,```!%GP``%````%F?```$````;I\```8```!SGP``5````'J?```$
M````SY\```X```#4GP``!0```..?```%````Z9\``!L```#OGP``&@````N@
M```1````)J```!$````XH```'````$J@```J````9Z```!````"2H```(0``
M`*.@```%````Q:```!,```#+H```$@```-^@```*````\J````\```#]H```
M$0````VA```3````'Z$```P````SH0``!@```$"A```&````1Z$``!<```!.
MH0``$````&:A```1````=Z$```@```")H0``!0```)*A```,````F*$``!``
M``"EH0``!0```+:A```-````O*$```8```#*H0``!P```-&A```-````V:$`
M``<```#GH0``"P```.^A```'````^Z$```<````#H@``"0````NB```*````
M%:(``!D````@H@``#````#JB```0````1Z(```4```!8H@``)0```%ZB```2
M````A*(``!,```"7H@``*P```*NB```[````UZ(``"`````3HP``-@```#2C
M```(````:Z,```P```!THP``!@```(&C```$````B*,```X```"-HP``"@``
M`)RC```-````IZ,``!X```"UHP``&P```-2C```A````\*,``!X````2I```
M&0```#&D```>````2Z0``!L```!JI```)@```(:D```;````K:0``!X```#)
MI```'````.BD```F````!:4``#,````LI0``)@```&"E```K````AZ4``#@`
M``"SI0``+P```.RE```2````'*8``"D````OI@``$@```%FF``"B````;*8`
M`!8````/IP``(P```":G```H````2J<``"D```!SIP``*````)VG```?````
MQJ<``"````#FIP``)0````>H```H````+:@``#````!6J```D@```(>H```A
M````&JD``!P````\J0``)@```%FI``!!````@*D```P```#"J0``!P```,^I
M```'````UZD```8```#?J0``#0```.:I```0````]*D``!(````%J@``$P``
M`!BJ```2````+*H```<````_J@``!````$>J```,````3*H```X```!9J@``
M#P```&BJ```3````>*H```T```",J@``*````)JJ```#````PZH```T```#'
MJ@``!@```-6J```1````W*H``!<```#NJ@``&P````:K```.````(JL```(`
M```QJP``!0```#2K```0````.JL```0```!+JP``#0```%"K```.````7JL`
M``,```!MJP``#@```'&K```(````@*L```\```")JP``#P```)FK```'````
MJ:L```T```"QJP``$````+^K```+````T*L```8```#<JP``#````..K```1
M````\*L``!D````"K```"P```!RL```-````**P``"(````VK```"@```%FL
M```8````9*P``!D```!]K```%@```)>L```-````KJP```<```"\K```%```
M`,2L```+````V:P``"(```#EK```+P````BM```+````.*T```D```!$K0``
M&0```$ZM```+````:*T``!<```!TK0``%P```(RM```)````I*T``!8```"N
MK0``#P```,6M```6````U:T```X```#LK0``&````/NM```(````%*X```T`
M```=K@``)@```"NN``!#````4JX```@```"6K@``$@```)^N```(````LJX`
M``L```"[K@``+P```,>N```.````]ZX```4````&KP``!@````RO```#````
M$Z\```<````7KP``!````!^O```*````)*\```H````OKP``#P```#JO```0
M````2J\``!<```!;KP``$0```'.O```7````A:\```D```"=KP``!0```*>O
M```+````K:\```H```"YKP```@```,2O```%````QZ\```T```#-KP``&P``
M`-NO```7````]Z\```D````/L```#@```!FP```-````*+```!(````VL```
M.````$FP```@````@K````@```"CL```#@```*RP``![````N[```!@````W
ML0``$0```%"Q```'````8K$```4```!JL0``&0```'"Q```'````BK$```@`
M``"2L0``!@```)NQ```&````HK$``!````"IL0``#P```+JQ```0````RK$`
M``\```#;L0``"P```.NQ```/````][$```P````'L@``#P```!2R```'````
M)+(```8````LL@``#@```#.R```,````0K(``"@```!/L@``#P```'BR```(
M````B+(```@```"1L@``$P```)JR```>````KK(``"$```#-L@``(````.^R
M```9````$+,``!<````JLP``)0```$*S```7````:+,```0```"`LP``&P``
M`(6S```-````H;,```P```"OLP```P```+RS```(````P+,```H```#)LP``
M#````-2S```+````X;,``!````#MLP``#````/ZS```$````"[0``!,````0
MM```%````"2T```,````.;0```D```!&M```#@```%"T```+````7[0``!L`
M``!KM```!P```(>T```'````C[0```H```"7M```#0```**T```)````L+0`
M``0```"ZM```!0```+^T```#````Q;0``!@```#)M```"@```.*T```$````
M[;0``"8```#RM```#@```!FU``!\````*+4``!4```"EM0``!0```+NU```'
M````P;4```P```#)M0``"````-:U```*````W[4```8```#JM0``"````/&U
M```"````^K4```8```#]M0``!@````2V```4````"[8```T````@M@``$```
M`"ZV```;````/[8```0```!;M@``"0```&"V```0````:K8```D```![M@``
M"0```(6V```%````C[8``!H```"5M@``"````+"V```&````N;8``!D```#`
MM@``#@```-JV```'````Z;8```<```#QM@``!0```/FV```)````_[8```H`
M```)MP```@```!2W```&````%[<```T````>MP``"0```"RW```&````-K<`
M`!(````]MP``"0```%"W```'````6K<``!0```!BMP``'0```'>W```&````
ME;<```H```"<MP``!````*>W```)````K+<```@```"VMP``$0```+^W```)
M````T;<```8```#;MP``#0```.*W```&````\+<```0```#WMP``.0```/RW
M```]````-K@``#H```!TN```'@```*^X```%````SK@```X```#4N```!```
M`..X```&````Z+@``"$```#ON```%0```!&Y```&````)[D```0````NN0``
M$0```#.Y```&````1;D```H```!,N0``(@```%>Y```$````>KD```4```!_
MN0``'0```(6Y```$````H[D```P```"HN0``"@```+6Y```(````P+D```D`
M``#)N0``!0```-.Y```Z````V;D``#`````4N@``-0```$6Z```I````>[H`
M`$<```"EN@``.````.VZ```I````)KL``#\```!0NP``+@```)"[```M````
MO[L``!\```#MNP``#P````V\```2````';P```L````PO```)@```#R\```I
M````8[P``"0```"-O```)@```+*\```(````V;P```H```#BO```"0```.V\
M```'````][P``"````#_O```(````""]```F````0;T```H```!HO0``&0``
M`'.]```I````C;T``!8```"WO0``$@```,Z]```'````X;T```H```#IO0``
M#````/2]```/`````;X``!`````1O@``0````"*^``!P````8[X``&8```#4
MO@``#@```#N_```)````2K\```H```!4OP``$@```%^_```3````<K\```P`
M``"&OP``!@```)._```/````FK\``!(```"JOP``$````+V_```1````SK\`
M`!P```#@OP``(P```/V_``!J````(<````\```",P```!0```)S````0````
MHL````D```"SP```!````+W````+````PL```!0```#.P```#````./````,
M````\,````\```#]P```%0````W!```I````(\$``"H```!-P0``)@```'C!
M```G````G\$``"D```#'P0``*@```/'!```9````',(``$(````VP@``$0``
M`'G"```2````B\(``!,```">P@``%````++"```/````Q\(``!8```#7P@``
M%P```.["```0````!L,``!$````7PP``-````"G#```3````7L,``!(```!R
MPP``-0```(7#```4````N\,```<```#0PP``#````-C#```@````Y<,``!0`
M```&Q```$0```!O$```7````+<0``!P```!%Q```$P```&+$```1````=L0`
M`!H```"(Q```'@```*/$```:````PL0``!$```#=Q```%````._$```7````
M!,4``!4````<Q0``"0```#+%```9````/,4```0```!6Q0``!P```%O%```+
M````8\4``!$```!OQ0``!@```('%```&````B,4```8```"/Q0``!0```);%
M```'````G,4```<```"DQ0``!0```*S%```6````LL4```8```#)Q0``!@``
M`-#%```$````U\4```0```#<Q0``!P```.'%```.````Z<4```P```#XQ0``
M#`````7&```-````$L8```H````@Q@``#@```"O&```%````.L8``"@```!`
MQ@``#@```&G&```,````>,8```\```"%Q@``"@```)7&```(````H,8```D`
M``"IQ@``*P```+/&```$````W\8```@```#DQ@``)@```.W&```2````%,<`
M``\````GQP``!@```#?'```*````/L<```<```!)QP``"````%''```@````
M6L<```D```![QP``#````(7'```-````DL<```X```"@QP``%@```*_'```1
M````QL<```8```#8QP```P```-_'```&````X\<``!D```#JQP``!P````3(
M```$````#,@```L````1R```"P```!W(```'````*<@```<````QR```%@``
M`#G(```-````4,@```T```!>R```"@```&S(```0````=\@```\```"(R```
M$0```)C(```7````JL@```H```#"R```$0```,W(```(````W\@```0```#H
MR```#P```.W(```Z````_<@```4````XR0``#````#[)```>````2\D```X`
M``!JR0``$````'G)```+````BLD```P```"6R0``"0```*/)```'````K<D`
M``H```"UR0``"0```,#)```.````RLD``!````#9R0``&@```.K)```*````
M!<H```D````0R@``"@```!K*```,````)<H```\````RR@``"````$+*```&
M````2\H```<```!2R@``"P```%K*``!'````9LH```T```"NR@``"0```+S*
M```$````QLH```,```#+R@``$P```,_*```3````X\H``!,```#WR@``"@``
M``O+```"````%LL```0````9RP``)0```![+```#````1,L```4```!(RP``
M*@```$[+```*````><L```4```"$RP``!````(K+```*````C\L```T```":
MRP``!@```*C+```(````K\L```@```"XRP``!````,'+```%````QLL``&@`
M``#,RP``"0```#7,```,````/\P```4```!,S```!@```%+,```;````6<P`
M`"\```!US```$````*7,```*````MLP```\```#!S```"@```-',```)````
MW,P``!,```#FS```&P```/K,```8````%LT``!<````OS0``#@```$?-```#
M````5LT```<```!:S0``"````&+-```'````:\T```H```!SS0``"P```'[-
M```'````BLT``%$```"2S0``$````.3-```,````]<T```T````"S@``&@``
M`!#.``!*````*\X```8```!VS@``!@```'W.```&````A,X``!\```"+S@``
M!@```*O.```)````LLX``!@```"\S@``%P```-7.```&````[<X```T```#T
MS@``(@````+/``!7````)<\``!,```!]SP``(P```)'/```3````M<\```(`
M``#)SP``"P```,S/```(````V,\```T```#ASP``"@```._/```'````^L\`
M`!0````"T```!@```!?0```(````'M````X````GT```!P```#;0```*````
M/M````L```!)T```!P```%70```,````7=````T```!JT```#````'C0```)
M````A=````D```"/T```"@```)G0```'````I-````D```"LT```!P```+;0
M```*````OM```!L```#)T```$@```.70```*````^-````D````#T0``$```
M``W1```'````'M$``!(````FT0``!````#G1```'````/M$```4```!&T0``
M!0```$S1```+````4M$``!0```!>T0``$0```'/1```:````A=$``!8```"@
MT0``%````+?1```7````S-$``!@```#DT0``'````/W1```9````&M(```<`
M```TT@``!0```#S2```-````0M(```P```!0T@``"````%W2```7````9M(`
M``L```!^T@``$P```(K2```$````GM(```H```"CT@``!````*[2```,````
ML](```D```#`T@``!0```,K2```'````T-(```4```#8T@``!````-[2```"
M````X](``#@```#FT@``+````!_3```2````3-,``"D```!?TP``,@```(G3
M```*````O-,``"P```#'TP``+@```/33```S````(]0``#,```!7U```.```
M`(O4```/````Q-0``!@```#4U```$````.W4```/````_M0``!,````.U0``
M%````"+5```2````-]4``!0```!*U0``%0```%_5```M````==4``"T```"C
MU0``,0```-'5```N`````]8``"\````RU@``+````&+6``!B````C]8``!,`
M``#RU@``"`````;7```(````#]<``"L````8UP``(0```$37```:````9M<`
M``D```"!UP``10```(O7``!!````T=<```0````3V```$P```!C8```4````
M+-@```X```!!V```$P```%#8```8````9-@```8```!]V```"0```(38```*
M````CM@```\```"9V```$````*G8```'````NM@```X```#"V```!0```-'8
M```;````U]@```@```#SV```!@```/S8```4`````]D``!$````8V0``#@``
M`"K9```X````.=D```(```!RV0``!@```'79```.````?-D```4```"+V0``
M!P```)'9```.````F=D```8```"HV0``!````*_9```I````M-D``!<```#>
MV0``'P```/;9``!<````%MH``!0```!SV@``/@```(C:```?````Q]H``!``
M``#GV@``!P```/C:```.`````-L```P````/VP``#````!S;```3````*=L`
M``H````]VP``'0```$C;```9````9ML```4```"`VP``$0```(;;```1````
MF-L``"0```"JVP``%0```,_;```2````Y=L```X```#XVP``&0````?<```(
M````(=P```D````JW```#0```#3<```*````0MP```<```!-W```#P```%7<
M```+````9=P```H```!QW```!P```'S<```(````A-P```4```"-W```'P``
M`)/<```&````L]P``!````"ZW```"````,O<```-````U-P```@```#BW```
M$@```.O<```L````_MP``!H````KW0``"0```$;=```*````4-T``!4```!;
MW0``!0```''=```4````=]T```0```",W0``$````)'=```&````HMT```<`
M``"IW0``'@```+'=```H````T-T```H```#YW0``&@````3>```4````']X`
M``0````TW@``!````#G>```+````/MX```4```!*W@``!@```%#>```(````
M5]X```8```!@W@``"@```&?>```;````<MX``#0```".W@``-````,/>```@
M````^-X``"D````9WP``(````$/?``!!````9-\``!H```"FWP``*````,'?
M```I````ZM\``"(````4X```!@```#?@```(````/N````4```!'X```"```
M`$W@```9````5N```!D```!PX```*@```(K@```C````M>```"X```#9X```
M-`````CA```(````/>$``!<```!&X0``"@```%[A```'````:>$``"$```!Q
MX0``$````)/A```.````I.$```L```"SX0``!P```+_A```3````Q^$```@`
M``#;X0``"P```.3A```*````\.$``!0```#[X0``,@```!#B```+````0^(`
M``4```!/X@``!0```%7B```7````6^(```\```!SX@``!````(/B```*````
MB.(```D```"3X@``"P```)WB```-````J>(```P```"WX@``#@```,3B```%
M````T^(```0```#9X@``#0```-[B```R````[.(``$4````?XP``%P```&7C
M```>````?>,``!0```"<XP``!0```+'C```4````M^,```<```#,XP``#@``
M`-3C```J````X^,```8````.Y```#````!7D```-````(N0``!$````PY```
M"P```$+D```V````3N0```H```"%Y```(@```)#D```+````L^0```\```"_
MY```,@```,_D```.`````N4```4````1Y0``#@```!?E```3````)N4```<`
M```ZY0``$0```$+E```'````5.4``!0```!<Y0``&````''E```'````BN4`
M``4```"2Y0``#````)CE```,````I>4``!(```"RY0``!````,7E```'````
MRN4```H```#2Y0``"P```-WE```,````Z>4```X```#VY0``#@````7F```%
M````%.8```4````:Y@``+@```"#F```F````3^8``",```!VY@```P```)KF
M```2````GN8```8```"QY@``'@```+CF```8````U^8``"4```#PY@``#0``
M`!;G```)````).<```,````NYP``!P```#+G```*````.N<```(```!%YP``
M#````$CG```5````5><```L```!KYP``&0```'?G```@````D><``!(```"R
MYP``!0```,7G```*````R^<``!4```#6YP``$@```.SG```,````_^<```0`
M```,Z```!P```!'H```,````&>@``%(````FZ```%P```'GH```'````D>@`
M``8```"9Z```#@```*#H```,````K^@```T```"\Z```%0```,KH```2````
MX.@```\```#SZ```%`````/I```;````&.D``!`````TZ0``:0```$7I```:
M````K^D``!<```#*Z0``)P```.+I```:````"NH``!<````EZ@``&P```#WJ
M```9````6>H``!\```!SZ@``$P```)/J```(````I^H```<```"PZ@``"```
M`+CJ```)````P>H``!4```#+Z@``#0```.'J```3````[^H```,````#ZP``
M1@````?K```_````3NL``#<```".ZP``5P```,;K```%````'NP``!\````D
M[```+P```$3L```*````=.P```@```!_[```#0```(CL```M````ENP```0`
M``#$[```3P```,GL```E````&>T``!P````_[0``"P```%SM```?````:.T`
M`!T```"([0``)0```*;M```@````S.T``"0```#M[0``(````!+N```+````
M,^X```<````_[@``#0```$?N```,````5>X``!<```!B[@``!@```'KN```Y
M````@>X```P```"[[@``!P```,CN```)````T.X``!,```#:[@``"0```.[N
M```$````^.X``!````#][@``"`````[O```(````%^\```0````@[P``"P``
M`"7O```,````,>\``!(````^[P``$0```%'O```,````8^\``!H```!P[P``
M#P```(OO```'````F^\```T```"C[P``%````+'O```.````QN\```P```#5
M[P``&P```.+O```L````_N\``!,````K\```'````#_P```H````7/````8`
M``"%\```!P```(SP```3````E/````4```"H\```!````*[P```7````L_``
M``H```#+\```#````-;P```)````X_````8```#M\```"0```/3P```(````
M_O````D````'\0``"@```!'Q```1````'/$```8````N\0``#@```#7Q```.
M````1/$```T```!3\0``"P```&'Q```=````;?$```L```"+\0```@```)?Q
M```'````FO$```8```"B\0``"0```*GQ```'````L_$``#L```"[\0``*```
M`/?Q```T````(/(``!4```!5\@``!0```&OR```'````<?(```@```!Y\@``
M!P```(+R```%````BO(```<```"0\@``#@```)CR```)````I_(```8```"Q
M\@``"````+CR```+````P?(```<```#-\@``"````-7R```'````WO(``!8`
M``#F\@``"0```/WR```&````!_,```L````.\P``'````!KS```4````-_,`
M``<```!,\P``"````%3S```(````7?,```4```!F\P``$````&SS```0````
M??,```8```".\P``&0```)7S```*````K_,``!P```"Z\P``!P```-?S```%
M````W_,``!````#E\P``%````/;S```+````"_0```T````7]```%P```"7T
M```$````/?0```D```!"]```"@```$ST```'````5_0```(```!?]```#@``
M`&+T```(````<?0``!\```!Z]```(P```)KT```X````OO0``#$```#W]```
M)P```"GU``!D````4?4``!0```"V]0``50```,OU```X````(?8``$H```!:
M]@``6P```*7V```H`````?<``#@````J]P``*````&/W```L````C/<``"<`
M``"Y]P``&P```.'W```^````_?<``*D!```\^```(P```.;Y```7````"OH`
M`$@````B^@``A0```&OZ```P````\?H``$$````B^P``6P```&3[``!)````
MP/L``!T````*_```&````"C\```A````0?P``!\```!C_```*P```(/\```A
M````K_P``"<```#1_```'0```/G\```1````%_T``#,````I_0``)0```%W]
M```G````@_T``!\```"K_0``,````,O]``!I````_/T``#T```!F_@``90``
M`*3^``!-````"O\``"\```!8_P``+@```(C_```P````M_\``%0```#H_P``
M6@```#T``0!(````F``!`$H```#A``$`,@```"P!`0`O````7P$!`"P```"/
M`0$`+0```+P!`0!Q````Z@$!`&\```!<`@$`LP```,P"`0`7````@`,!`"4`
M``"8`P$`,@```+X#`0`I````\0,!`#X````;!`$`(@```%H$`0!2````?00!
M`"4```#0!`$`"P```/8$`0"Q`````@4!`$4```"T!0$`(0```/H%`0`P````
M'`8!`"4```!-!@$`'````',&`0`Q````D`8!``<```#"!@$`!P```,H&`0`$
M````T@8!``T```#7!@$`"P```.4&`0`.````\08!``L`````!P$`!0````P'
M`0`0````$@<!``(````C!P$`60```"8'`0`%````@`<!`!(```"&!P$`!```
M`)D'`0`'````G@<!``@```"F!P$`!0```*\'`0`#````M0<!`!````"Y!P$`
M#````,H'`0`3````UP<!``T```#K!P$``@```/D'`0`'````_`<!``8````$
M"`$`%`````L(`0`,````(`@!`!@````M"`$`!@```$8(`0`2````30@!``P`
M``!@"`$``P```&T(`0`J````<0@!``0```"<"`$`!@```*$(`0`'````J`@!
M`!\```"P"`$`-0```-`(`0`N````!@D!`"\````U"0$`%P```&4)`0`@````
M?0D!`!L```">"0$`&````+H)`0`D````TPD!`!\```#X"0$`&@```!@*`0`@
M````,PH!`!H```!4"@$`,@```&\*`0`O````H@H!`"L```#2"@$`'P```/X*
M`0`C````'@L!`!\```!""P$`&@```&(+`0`E````?0L!`"8```"C"P$`)0``
M`,H+`0`D````\`L!`!@````5#`$`'0```"X,`0`D````3`P!`!@```!Q#`$`
M(@```(H,`0`E````K0P!`#P```#3#`$`'P```!`-`0`C````,`T!`!\```!4
M#0$`(````'0-`0`:````E0T!`!@```"P#0$`)@```,D-`0`>````\`T!`"D`
M```/#@$`'@```#D.`0`)````6`X!``P```!B#@$`%P```&\.`0`O````APX!
M`"0```"W#@$`!P```-P.`0`/````Y`X!`!0```#T#@$`#@````D/`0`-````
M&`\!`"0````F#P$`!0```$L/`0`'````40\!`"(```!9#P$`)0```'P/`0`=
M````H@\!`!H```#`#P$`!P```-L/`0#'````XP\!``L```"K$`$`%0```+<0
M`0`&````S1`!``D```#4$`$`"P```-X0`0`7````ZA`!``8````"$0$`,P``
M``D1`0`3````/1$!`!,```!1$0$`!P```&41`0`/````;1$!``<```!]$0$`
M,@```(41`0`A````N!$!`!,```#:$0$`#````.X1`0`1````^Q$!`#(````-
M$@$`"````$`2`0`)````21(!``H```!3$@$`%````%X2`0`*````<Q(!`!T`
M``!^$@$`"````)P2`0`?````I1(!``@```#%$@$`&@```,X2`0`&````Z1(!
M`!4```#P$@$`!P````83`0`(````#A,!``D````7$P$`/P```"$3`0`'````
M81,!``\```!I$P$`#@```'D3`0`0````B!,!``D```"9$P$`"0```*,3`0`(
M````K1,!`!,```"V$P$`!P```,H3`0`9````TA,!``H```#L$P$`%P```/<3
M`0`4````#Q0!``H````D%`$`#````"\4`0`7````/!0!``0```!4%`$`*@``
M`%D4`0`1````A!0!``<```"6%`$``@```)X4`0`0````H10!`!@```"R%`$`
M"P```,L4`0`#````UQ0!``@```#;%`$`!@```.04`0`'````ZQ0!``T```#S
M%`$`"P````$5`0`4````#14!`!4````B%0$`#@```#@5`0`O````1Q4!`"``
M``!W%0$`'````)@5`0`,````M14!`#$```#"%0$`!0```/05`0`2````^A4!
M`#\````-%@$`$@```$T6`0`*````8!8!``8```!K%@$`!````'(6`0`$````
M=Q8!``H```!\%@$`$P```(<6`0`%````FQ8!``8```"A%@$`!@```*@6`0`$
M````KQ8!``P```"T%@$`"@```,$6`0`%````S!8!`!@```#2%@$`&0```.L6
M`0`?````!1<!`!T````E%P$`$0```$,7`0`"````51<!``0```!8%P$`"@``
M`%T7`0`&````:!<!``4```!O%P$``P```'47`0`,````>1<!`$4```"&%P$`
M&@```,P7`0`U````YQ<!`"@````=&`$`4P```$88`0`9````FA@!`'(```"T
M&`$`(````"<9`0`U````2!D!`"$```!^&0$`10```*`9`0`P````YAD!`"@`
M```7&@$`*0```$`:`0`F````:AH!`"4```"1&@$`*````+<:`0`H````X!H!
M`"(````)&P$`,````"P;`0`2````71L!`!,```!P&P$`$````(0;`0!Y````
ME1L!``D````/'`$`<P```!D<`0!\````C1P!`"L````*'0$`%P```#8=`0`6
M````3AT!``\```!E'0$`'P```'4=`0!`````E1T!`!\```#6'0$`'````/8=
M`0!1````$QX!`!0```!E'@$`"@```'H>`0`%````A1X!``8```"+'@$`"```
M`)(>`0`%````FQX!`!(```"A'@$`$````+0>`0`3````Q1X!`!T```#9'@$`
M#P```/<>`0`/````!Q\!``0````7'P$`"0```!P?`0`+````)A\!``<````R
M'P$`!0```#H?`0`4````0!\!``<```!5'P$`"````%T?`0`/````9A\!``@`
M``!V'P$`#````'\?`0`/````C!\!``8```"<'P$`%````*,?`0`&````N!\!
M``P```"_'P$`"````,P?`0`$````U1\!``H```#:'P$`!P```.4?`0`$````
M[1\!`!D```#R'P$``@````P@`0`)````#R`!``8````9(`$`!@```"`@`0`G
M````)R`!``0```!/(`$`#P```%0@`0`3````9"`!``<```!X(`$`!P```(`@
M`0`&````B"`!``8```"/(`$`$````)8@`0`2````IR`!``8```"Z(`$`"0``
M`,$@`0`B````RR`!``<```#N(`$`!P```/8@`0`+````_B`!``4````*(0$`
M`@```!`A`0`+````$R$!`&L!```?(0$`#@```(LB`0`4````FB(!``L```"O
M(@$`"````+LB`0`(````Q"(!``8```#-(@$`"````-0B`0`+````W2(!`!8`
M``#I(@$`#0`````C`0`-````#B,!``4````<(P$`'0```"(C`0`*````0",!
M``@```!+(P$`%````%0C`0`-````:2,!``L```!W(P$`$0```(,C`0`)````
ME2,!``X```"?(P$`#0```*XC`0`0````O",!``D```#-(P$`#@```-<C`0`0
M````YB,!``8```#W(P$`$0```/XC`0`2````$"0!``D````C)`$`%P```"TD
M`0`7````120!``<```!=)`$`,P```&4D`0`7````F20!`#T```"Q)`$`30``
M`.\D`0!D````/24!`%P```"B)0$`:P```/\E`0!C````:R8!`#\```#/)@$`
M"0````\G`0`)````&2<!``P````C)P$`!0```#`G`0`&````-B<!`!0````]
M)P$`#````%(G`0`%````7R<!``8```!E)P$`*````&PG`0`J````E2<!``X`
M``#`)P$`$0```,\G`0`,````X2<!``0```#N)P$`#0```/,G`0`-`````2@!
M``P````/*`$`#@```!PH`0`.````*R@!`!0````Z*`$`"@```$\H`0`-````
M6B@!``H```!H*`$`+````',H`0`5````H"@!`!0```"V*`$`#@```,LH`0`C
M````VB@!``4```#^*`$`#0````0I`0`R````$BD!``<```!%*0$``P```$TI
M`0`*````42D!``H```!<*0$`!P```&<I`0`(````;RD!``8```!X*0$`"@``
M`'\I`0`$````BBD!`!P```"/*0$`"P```*PI`0`+````N"D!``P```#$*0$`
M&````-$I`0`T````ZBD!``D````?*@$`$0```"DJ`0`3````.RH!`!@```!/
M*@$`'0```&@J`0`/````ABH!``P```"6*@$`#@```*,J`0`:````LBH!``8`
M``#-*@$`!@```-0J`0`(````VRH!``P```#D*@$`!0```/$J`0`)````]RH!
M`!(````!*P$`"````!0K`0`0````'2L!``X````N*P$`%P```#TK`0`&````
M52L!``X```!<*P$`!0```&LK`0`5````<2L!`!4```"'*P$`#````)TK`0`Z
M````JBL!``@```#E*P$`"@```.XK`0`4````^2L!``4````.+`$`!0```!0L
M`0`1````&BP!``P````L+`$`%````#DL`0`O````3BP!``\```!^+`$`)0``
M`(XL`0`D````M"P!`"D```#9+`$`+0````,M`0`,````,2T!``<````^+0$`
M"P```$8M`0`)````4BT!`"\```!<+0$`+````(PM`0`M````N2T!`%\```#G
M+0$`+````$<N`0`L````="X!`"P```"A+@$`+@```,XN`0`D````_2X!`"@`
M```B+P$`+````$LO`0`R````>"\!`!D```"K+P$`'````,4O`0`S````XB\!
M`"@````6,`$`$P```#\P`0`*````4S`!`!$```!>,`$`!P```'`P`0`-````
M>#`!`!<```"&,`$`'````)XP`0`)````NS`!``<```#%,`$`%````,TP`0`)
M````XC`!``@```#L,`$`#0```/4P`0`+`````S$!``<````/,0$`!@```!<Q
M`0`%````'C$!``<````D,0$`!@```"PQ`0`)````,S$!`#$````],0$`#0``
M`&\Q`0`)````?3$!``0```"',0$`!P```(PQ`0`*````E#$!``4```"?,0$`
M$````*4Q`0`(````MC$!``P```"_,0$`"0```,PQ`0`(````UC$!``,```#?
M,0$`#@```.,Q`0`(````\C$!`!X```#[,0$`!@```!HR`0`+````(3(!`!``
M```M,@$`#````#XR`0`'````2S(!``,```!3,@$``P```%<R`0`5````6S(!
M`!4```!Q,@$`!@```(<R`0`&````CC(!``@```"5,@$`!P```)XR`0!,````
MIC(!`!\```#S,@$`!@```!,S`0`%````&C,!`!<````@,P$`&````#@S`0`8
M````43,!`#$```!J,P$`&@```)PS`0`?````MS,!`'<```#7,P$`+````$\T
M`0`*````?#0!``8```"'-`$`&````(XT`0`.````IS0!``P```"V-`$`$0``
M`,,T`0`3````U30!`!$```#I-`$`$0```/LT`0`,````#34!`!0````:-0$`
M!````"\U`0`7````-#4!`!@```!,-0$`&````&4U`0`6````?C4!``,```"5
M-0$`"````)DU`0!K````HC4!``@````.-@$`%@```!<V`0`$````+C8!``,`
M```S-@$`'P```#<V`0`7````5S8!``P```!O-@$`$P```'PV`0`G````D#8!
M`#,```"X-@$`$0```.PV`0`:````_C8!``<````9-P$`'P```"$W`0`7````
M03<!`!$```!9-P$`&````&LW`0`9````A#<!`!<```">-P$`#P```+8W`0`(
M````QC<!``<```#/-P$`#0```-<W`0`5````Y3<!`!0```#[-P$`"0```!`X
M`0`$````&C@!``L````?.`$`"P```"LX`0`)````-S@!`!````!!.`$`!0``
M`%(X`0`%````6#@!``P```!>.`$`"````&LX`0`)````=#@!``<```!^.`$`
M!@```(8X`0`-````C3@!``@```";.`$`%0```*0X`0`-````NC@!`!````#(
M.`$`!0```-DX`0`<````WS@!`!@```#\.`$`&````!4Y`0`L````+CD!`#L`
M``!;.0$`)0```)<Y`0`W````O3D!``4```#U.0$`#````/LY`0`%````"#H!
M``<````..@$`#@```!8Z`0`*````)3H!``T````P.@$`'````#XZ`0`;````
M6SH!`!\```!W.@$`'@```)<Z`0`?````MCH!`!X```#6.@$`&````/4Z`0`@
M````#CL!`"$````O.P$`)````%$[`0`?````=CL!`!X```"6.P$`+P```+4[
M`0`C````Y3L!`"4````)/`$`,0```"\\`0`N````83P!``T```"0/`$`)0``
M`)X\`0`-````Q#P!`)D```#2/`$`$````&P]`0`?````?3T!`"$```"=/0$`
M(P```+\]`0`D````XST!`"$````(/@$`'@```"H^`0`E````23X!`"@```!O
M/@$`+````)@^`0"C````Q3X!`!@```!I/P$`(P```((_`0`B````IC\!`$L`
M``#)/P$`#@```!5``0`$````)$`!``<````I0`$`!0```#%``0`.````-T`!
M``H```!&0`$`#P```%%``0`1````84`!`!,```!S0`$`"P```(=``0`$````
MDT`!``\```"80`$`#0```*A``0`5````MD`!`!(```#,0`$`$@```-]``0`P
M````\D`!``,````C00$`$P```"=!`0`&````.T$!``X```!"00$`%````%%!
M`0`6````9D$!``\```!]00$``@```(U!`0`&````D$$!`!4```"700$`!0``
M`*U!`0`,````LT$!``P```#`00$``P```,U!`0`+````T4$!``8```#=00$`
M#P```.1!`0`/````]$$!``H````$0@$`#P````]"`0`1````'T(!``@````Q
M0@$``P```#I"`0`(````/D(!``@```!'0@$`&````%!"`0`)````:4(!``D`
M``!S0@$`&0```'U"`0`*````ET(!`!0```"B0@$`%````+="`0`4````S$(!
M``T```#A0@$`"0```.]"`0`1````^4(!``@````+0P$`/````!1#`0`R````
M44,!``<```"$0P$`"P```(Q#`0`:````F$,!``T```"S0P$`$0```,%#`0`1
M````TT,!``4```#E0P$`(````.M#`0`7````#$0!`!X````D1`$`$@```$-$
M`0`/````5D0!``8```!F1`$`"````&U$`0`M````=D0!`#X```"D1`$`!P``
M`.-$`0`3````ZT0!``4```#_1`$`"`````5%`0`S````#D4!`!(```!"10$`
M!P```%5%`0`'````744!``,```!E10$`!P```&E%`0`'````<44!``P```!Y
M10$`#````(9%`0`,````DT4!`!````"@10$`&````+%%`0`4````RD4!`!@`
M``#?10$`!@```/A%`0`%````_T4!``L````%1@$`!@```!%&`0`"````&$8!
M`!`````;1@$`%P```"Q&`0`E````1$8!`!<```!J1@$`$````()&`0`*````
MDT8!``H```">1@$`$P```*E&`0!.````O48!`"H````,1P$`"@```#='`0`6
M````0D<!`'(```!91P$`'0```,Q'`0`.````ZD<!``8```#Y1P$`!`````!(
M`0`@````!4@!``<````F2`$`"````"Y(`0`%````-T@!``8````]2`$`#0``
M`$1(`0`,````4D@!``T```!?2`$`#````&U(`0`+````>D@!``X```"&2`$`
M"@```)5(`0`/````H$@!``@```"P2`$`"````+E(`0`7````PD@!``X```#:
M2`$`+P```.E(`0`5````&4D!``,````O20$`#0```#-)`0`:````04D!`"``
M``!<20$`(P```'U)`0`B````H4D!`"0```#$20$`(@```.E)`0`D````#$H!
M`!\````Q2@$`"@```%%*`0`:````7$H!``T```!W2@$`#0```(5*`0`$````
MDTH!``4```"82@$`#````)Y*`0`.````JTH!``T```"Z2@$`$@```,A*`0`,
M````VTH!``0```#H2@$`%@```.U*`0`6````!$L!`!`````;2P$`"0```"Q+
M`0`,````-DL!``T```!#2P$`'0```%%+`0`)````;TL!``H```!Y2P$`"```
M`(1+`0`*````C4L!``T```"82P$`!0```*9+`0`%````K$L!``,```"R2P$`
M#0```+9+`0`*````Q$L!``4```#/2P$`*@```-5+`0`,`````$P!`'L````-
M3`$`%P```(E,`0`'````H4P!``4```"I3`$`"@```*],`0`(````NDP!``H`
M``##3`$`"````,Y,`0`.````UTP!``(```#F3`$`"@```.E,`0`&````]$P!
M`!0```#[3`$`$````!!-`0`3````(4T!`!4````U30$`!@```$M-`0`&````
M4DT!``T```!930$`!P```&=-`0`'````;TT!``4```!W30$`'0```'U-`0`'
M````FTT!``<```"C30$`&P```*M-`0`/````QTT!``D```#730$`!P```.%-
M`0`$````Z4T!``L```#N30$`"@```/I-`0`#````!4X!``8````)3@$`#```
M`!!.`0`+````'4X!``H````I3@$`%````#1.`0`(````24X!``<```!23@$`
M#0```%I.`0`<````:$X!``<```"%3@$`"````(U.`0`$````EDX!``D```";
M3@$`"````*5.`0`.````KDX!``T```"]3@$`!````,M.`0`,````T$X!``8`
M``#=3@$`!````.1.`0`R````Z4X!`#,````<3P$`,P```%!/`0`@````A$\!
M``4```"E3P$`$````*M/`0`)````O$\!``8```#&3P$`'P```,U/`0`7````
M[4\!``D````%4`$`!@````]0`0`;````%E`!``@````R4`$`"````#M0`0`5
M````1%`!``8```!:4`$`"0```&%0`0`'````:U`!``@```!S4`$`"0```'Q0
M`0`+````AE`!``@```"24`$`"0```)M0`0`%````I5`!`$@```"K4`$`-P``
M`/10`0`[````+%$!`"<```!H40$`20```)!1`0`[````VE$!`",````64@$`
M-P```#I2`0`C````<E(!`!H```"64@$`&````+%2`0`+````RE(!`!````#6
M4@$`!@```.=2`0`K````[E(!`"H````:4P$`%0```$53`0`J````6U,!``,`
M``"&4P$`!0```(I3`0`*````D%,!``H```";4P$`)````*93`0`@````RU,!
M`"L```#L4P$`"0```!A4`0`8````(E0!`"\````[5`$`%````&M4`0`7````
M@%0!``<```"85`$`#P```*!4`0`0````L%0!`!L```#!5`$`#0```-U4`0!%
M````ZU0!`&H````Q50$`@0```)Q5`0`0````'E8!``L````O5@$`#````#M6
M`0`0````2%8!`!$```!95@$`$````&M6`0`*````?%8!`!0```"'5@$`&```
M`)Q6`0`8````M58!`!,```#.5@$`&@```.)6`0`D````_58!`&@````B5P$`
M$````(M7`0`)````G%<!`!4```"F5P$`"0```+Q7`0`%````QE<!``4```#,
M5P$`$P```-)7`0`1````YE<!`!$```#X5P$`&`````I8`0`2````(U@!`"X`
M```V6`$`+P```&58`0`P````E5@!`"\```#&6`$`,P```/98`0`R````*ED!
M`!8```!=60$`0P```'19`0`;````N%D!`!H```#460$`&@```.]9`0`9````
M"EH!``D````D6@$`'0```"Y:`0`<````3%H!`!H```!I6@$`&0```(1:`0`:
M````GEH!`!P```"Y6@$`&P```-9:`0`N````\EH!``X````A6P$`!P```#!;
M`0`/````.%L!`"T```!(6P$`$@```'9;`0`7````B5L!`!D```"A6P$`%@``
M`+M;`0`5````TEL!`!$```#H6P$`'0```/I;`0`D````&%P!`!(````]7`$`
M&P```%!<`0`9````;%P!`!<```"&7`$`&````)Y<`0`$````MUP!`!8```"\
M7`$`!````--<`0`'````V%P!``\```#@7`$`(````/!<`0`&````$5T!``<`
M```870$`!@```"!=`0`&````)UT!``<````N70$`!````#9=`0`'````.UT!
M`!4```!#70$`!@```%E=`0`%````8%T!``8```!F70$`!P```&U=`0`%````
M=5T!``P```![70$`#0```(A=`0`*````EET!``H```"A70$`"@```*Q=`0`8
M````MUT!``4```#070$`)0```-9=`0`2````_%T!``T````/7@$`$0```!U>
M`0`0````+UX!``P```!`7@$`$0```$U>`0`K````7UX!``@```"+7@$`"```
M`)1>`0`*````G5X!``H```"H7@$`#P```+->`0`&````PUX!``L```#*7@$`
M#0```-9>`0`#````Y%X!`!\```#H7@$`"@````A?`0`)````$U\!``\````=
M7P$`#0```"U?`0`:````.U\!``\```!67P$`!P```&9?`0`$````;E\!``4`
M``!S7P$`'0```'E?`0`&````EU\!``,```">7P$`$@```*)?`0`0````M5\!
M``<```#&7P$`!P```,Y?`0`%````UE\!``T```#<7P$`"0```.I?`0`,````
M]%\!`!P````!8`$`&@```!Y@`0`5````.6`!`!H```!/8`$`"0```&I@`0`2
M````=&`!``P```"'8`$`"````)1@`0`1````G6`!`$$```"O8`$`"P```/%@
M`0`,````_6`!`"0````*80$`&````"]A`0`9````2&$!`!,```!B80$`#0``
M`'9A`0`.````A&$!``H```"380$`#0```)YA`0`:````K&$!`!4```#'80$`
M'0```-UA`0`F````^V$!``@````B8@$`"````"MB`0`-````-&(!``P```!"
M8@$`#````$]B`0`#````7&(!``4```!@8@$`!0```&9B`0`/````;&(!`$,`
M``!\8@$`%0```,!B`0`*````UF(!``,```#A8@$`!0```.5B`0`4````ZV(!
M`!0`````8P$`%````!5C`0`*````*F,!``(````U8P$`!````#AC`0`@````
M/6,!``,```!>8P$`!0```&)C`0`)````:&,!``H```!R8P$`!````'UC`0`%
M````@F,!`!````"(8P$`$@```)EC`0`&````K&,!``<```"S8P$`"0```+MC
M`0`$````Q6,!``4```#*8P$`8P```-!C`0`.````-&0!`!$```!#9`$`!```
M`%5D`0`-````6F0!`"$```!H9`$`/P```(ID`0`0````RF0!``@```#;9`$`
M#P```.1D`0`)````]&0!``@```#^9`$`'0````=E`0`F````)64!`"0```!,
M90$`(P```'%E`0`1````E64!``4```"G90$`!P```*UE`0`#````M64!``8`
M``"Y90$`"@```,!E`0`3````RV4!``4```#?90$`2````.5E`0`5````+F8!
M``H```!$9@$`"P```$]F`0`G````6V8!`$P```"#9@$`!@```-!F`0`&````
MUV8!``<```#>9@$`"@```.9F`0`$````\68!``D```#V9@$`(P````!G`0`B
M````)&<!``4```!'9P$`"````$UG`0`F````5F<!`&````!]9P$`$@```-YG
M`0`G````\6<!`!@````9:`$``P```#)H`0`,````-F@!``4```!#:`$`#@``
M`$EH`0`,````6&@!``H```!E:`$`"````'!H`0`&````>6@!``H```"`:`$`
M"0```(MH`0`%````E6@!``H```";:`$`"P```*9H`0`#````LF@!``\```"V
M:`$`$@```,9H`0`2````V6@!``H```#L:`$`"0```/=H`0`)`````6D!``L`
M```+:0$`"@```!=I`0`+````(FD!``@````N:0$`(0```#=I`0`+````66D!
M``<```!E:0$`"````&UI`0`.````=FD!``<```"%:0$`#P```(UI`0`"````
MG6D!``<```"@:0$`!0```*AI`0`%````KFD!``@```"T:0$`$@```+UI`0`2
M````T&D!`!4```#C:0$`%0```/EI`0`4````#VH!`!(````D:@$`%P```#=J
M`0`@````3VH!`!H```!P:@$``@```(MJ`0`$````CFH!``X```"3:@$`#0``
M`*)J`0`'````L&H!`!P```"X:@$`#0```-5J`0`3````XVH!``@```#W:@$`
M#@````!K`0`'````#VL!`!(````7:P$`"0```"IK`0`'````-&L!``<````\
M:P$`!````$1K`0`$````26L!``4```!.:P$`0P```%1K`0`Z````F&L!`!(`
M``#3:P$`*P```.9K`0`X````$FP!``X```!+;`$`*0```%IL`0`Q````A&P!
M`#8```"V;`$`-@```.UL`0`[````)&T!``H```!@;0$`)P```&MM`0`8````
MDVT!`!@```"L;0$`&````,5M`0`8````WFT!`!````#W;0$`%`````AN`0`8
M````'6X!`"<````V;@$`)P```%YN`0`K````AFX!`"@```"R;@$`*0```-MN
M`0`F````!6\!`&`````L;P$`'````(UO`0`)````JF\!``<```"T;P$`)@``
M`+QO`0`J````XV\!`"`````.<`$`"0```"]P`0!#````.7`!`$8```!]<`$`
M!P```,1P`0`9````S'`!`!P```#F<`$`#0````-Q`0`/````$7$!`!4````A
M<0$`!@```#=Q`0`0````/G$!``\```!/<0$`"P```%]Q`0`3````:W$!``T`
M``!_<0$`#P```(UQ`0`&````G7$!`"0```"D<0$`!0```,EQ`0`$````SW$!
M``\```#4<0$`#````.1Q`0`,````\7$!`$````#^<0$`!````#]R`0`%````
M1'(!`!````!*<@$`#P```%MR`0`$````:W(!`!0```!P<@$`!````(5R`0`%
M````BG(!`#T```"0<@$`&0```,YR`0`X````Z'(!`%T````A<P$`$0```']S
M`0!%````D7,!`!\```#7<P$`#P```/=S`0`*````!W0!`!(````2=`$`$```
M`"5T`0`'````-G0!``X````^=`$`"0```$UT`0`6````5W0!`!P```!N=`$`
M!0```(MT`0`.````D70!``X```"@=`$`'0```*]T`0`0````S70!`!0```#>
M=`$`$0```/-T`0`C````!74!``@````I=0$`"@```#)U`0`/````/74!``X`
M``!-=0$`!@```%QU`0`2````8W4!`!@```!V=0$`"P```(]U`0`*````FW4!
M``@```"F=0$`!0```*]U`0`>````M74!``8```#4=0$`#P```-MU`0`(````
MZW4!``X```#T=0$`!@````-V`0`-````"G8!`"T````8=@$`#0```$9V`0`'
M````5'8!``<```!<=@$`'@```&1V`0`(````@W8!`!````",=@$``P```)UV
M`0`3````H78!``@```"U=@$`!0```+YV`0`>````Q'8!`"T```#C=@$`!```
M`!%W`0`-````%G<!`!`````D=P$`!````#5W`0`/````.G<!``H```!*=P$`
M!P```%5W`0`+````77<!``@```!I=P$`#````')W`0`-````?W<!`!X```"-
M=P$`,0```*QW`0`V````WG<!`!\````5>`$`)````#5X`0`C````6G@!`#\`
M``!^>`$`'P```+YX`0`A````WG@!`"@`````>0$`(0```"EY`0`'````2WD!
M``@```!3>0$`"0```%QY`0`(````9GD!`!D```!O>0$`&0```(EY`0`S````
MHWD!`"H```#7>0$`+0````)Z`0`R````,'H!``8```!C>@$`&P```&IZ`0`'
M````AGH!``@```".>@$`'P```)=Z`0`1````MWH!``X```#)>@$`#````-AZ
M`0`%````Y7H!`!$```#K>@$`"````/UZ`0`2````!GL!``P````9>P$`&```
M`"9[`0`Q````/WL!``H```!Q>P$`!0```'Q[`0`%````@GL!`!H```"(>P$`
M#````*-[`0`&````L'L!`!8```"W>P$`%````,Y[`0`-````XWL!``T```#Q
M>P$`%0```/][`0`.````%7P!``0````D?`$`!0```"E\`0`-````+WP!`$@`
M```]?`$`8P```(9\`0`3````ZGP!`!\```#^?`$`&0```!Y]`0`-````.'T!
M``\```!&?0$`"P```%9]`0`2````8GT!`"P```!U?0$``P```*)]`0`)````
MIGT!``H```"P?0$`#P```+M]`0`+````RWT!`#(```#7?0$``P````I^`0`:
M````#GX!``T````I?@$`$P```#=^`0`G````2WX!``P```!S?@$`!P```(!^
M`0`0````B'X!`!4```"9?@$`"````*]^`0`1````N'X!``<```#*?@$`&@``
M`-)^`0`F````[7X!``H````4?P$``P```!]_`0`2````(W\!``X````V?P$`
M%0```$5_`0`%````6W\!``<```!A?P$`$0```&E_`0`+````>W\!``L```"'
M?P$`$0```)-_`0`1````I7\!``D```"W?P$`"````,%_`0`T````RG\!`"X`
M``#_?P$`+@```"Z``0`(````78`!`!$```!F@`$`!@```'B``0`7````?X`!
M`!P```"7@`$`'@```+2``0`.````TX`!``H```#B@`$``P```.V``0`(````
M\8`!``L```#Z@`$``P````:!`0`,````"H$!`!0````7@0$`"P```"R!`0`8
M````.($!`!L```!1@0$`%P```&V!`0`%````A8$!``H```"+@0$`%````):!
M`0`.````JX$!``\```"Z@0$`!@```,J!`0`)````T8$!`!(```#;@0$`3@``
M`.Z!`0`=````/8(!``4```!;@@$`!0```&&"`0`/````9X(!``T```!W@@$`
M#P```(6"`0`;````E8(!`!$```"Q@@$`$````,."`0`@````U((!`!\```#U
M@@$`#P```!6#`0!N````)8,!`!P```"4@P$`%0```+&#`0`F````QX,!`!L`
M``#N@P$`%`````J$`0`8````'X0!`!8````XA`$`'````$^$`0`3````;(0!
M``H```"`A`$`!P```(N$`0`+````DX0!``4```"?A`$`%P```*6$`0`-````
MO80!`!\```#+A`$`!@```.N$`0!*````\H0!`#$````]A0$`1````&^%`0!C
M````M(4!``<````8A@$`-````""&`0`H````588!``8```!^A@$`"@```(6&
M`0`)````D(8!`#(```":A@$`!@```,V&`0!;````U(8!`"L````PAP$`)0``
M`%R'`0`/````@H<!`#````"2AP$`'P```,.'`0`G````XX<!`"$````+B`$`
M)P```"V(`0`C````58@!`!````!YB`$`!P```(J(`0`7````DH@!`!4```"J
MB`$`#P```,"(`0`&````T(@!`"\```#7B`$`#`````>)`0`&````%(D!``0`
M```;B0$`$````"")`0`(````,8D!``4````ZB0$`"P```$")`0`(````3(D!
M``@```!5B0$``P```%Z)`0`,````8HD!``\```!OB0$`'P```'^)`0`=````
MGXD!``\```"]B0$`%@```,V)`0`/````Y(D!``8```#TB0$`$@```/N)`0`6
M````#HH!``T````EB@$`#````#.*`0`9````0(H!`"<```!:B@$`#P```(**
M`0`B````DHH!`"L```"UB@$`$0```.&*`0`.````\XH!`!P````"BP$`!P``
M`!^+`0`0````)XL!`!0````XBP$`"P```$V+`0`*````68L!``H```!DBP$`
M!P```&^+`0`)````=XL!``@```"!BP$`"0```(J+`0`.````E(L!``X```"C
MBP$`!0```+*+`0`/````N(L!``P```#(BP$`#````-6+`0`-````XHL!`!H`
M``#PBP$`"P````N,`0`#````%XP!``0````;C`$`!@```"",`0`(````)XP!
M``8````PC`$`5````#>,`0`H````C(P!`#,```"UC`$`%0```.F,`0`%````
M_XP!``0````%C0$`"@````J-`0`*````%8T!``<````@C0$`"@```"B-`0`5
M````,XT!``P```!)C0$`"@```%:-`0`,````88T!``@```!NC0$`!@```'>-
M`0`'````?HT!``8```"&C0$`%0```(V-`0`)````HXT!``4```"MC0$`!P``
M`+.-`0`B````NXT!``8```#>C0$`%0```.6-`0`8````^XT!``L````4C@$`
M!P```"".`0`3````*(X!`!,````\C@$`!@```%".`0`3````5XX!``H```!K
MC@$`"````':.`0`&````?XX!``@```"&C@$`$````(^.`0`8````H(X!``@`
M``"YC@$`"@```,*.`0`/````S8X!``4```#=C@$`#````...`0`0````\(X!
M``L````!CP$``P````V/`0`-````$8\!``<````?CP$`+````">/`0`J````
M5(\!`#D```!_CP$`)````+F/`0`M````WH\!`%\````,D`$`$````&R0`0!7
M````?9`!`#4```#5D`$`6@````N1`0!3````9I$!`!X```"ZD0$`0@```-F1
M`0`@````')(!`",````]D@$`(0```&&2`0`5````@Y(!`#\```"9D@$`T@$`
M`-F2`0`4````K)0!`!````#!E`$`00```-*4`0!Y````%)4!`#$```".E0$`
M/````,"5`0!3````_94!`$\```!1E@$`&@```*&6`0`0````O)8!`!8```#-
ME@$`&0```.26`0`C````_I8!`"$````BEP$`(@```$27`0`:````9Y<!`!``
M``""EP$`,P```).7`0`=````QY<!`"$```#EEP$`'`````>8`0`N````))@!
M`%T```!3F`$`.0```+&8`0!;````ZY@!`$0```!'F0$`,@```(R9`0`^````
MOYD!`#(```#^F0$`4````#&:`0!O````@IH!`%T```#RF@$`40```%";`0`T
M````HIL!`"````#7FP$`(0```/B;`0`C````&IP!`&\````^G`$`:0```*Z<
M`0"_````&)T!`!<```#8G0$`(````/"=`0`\````$9X!`#P```!.G@$`.P``
M`(N>`0`E````QYX!`$4```#MG@$`%@```#.?`0`&````2I\!`,4```!1GP$`
M00```!>@`0`C````6:`!`#````!]H`$`(@```*Z@`0`<````T:`!`#(```#N
MH`$`#0```"&A`0`(````+Z$!``4````XH0$`#````#ZA`0`,````2Z$!``P`
M``!8H0$`"P```&6A`0`&````<:$!`!(```!XH0$`!````(NA`0!.````D*$!
M``4```#?H0$`%````.6A`0`$````^J$!``<```#_H0$`!0````>B`0`%````
M#:(!``,````3H@$`$@```!>B`0`)````*J(!`!(````TH@$`$0```$>B`0`"
M````6:(!``4```!<H@$`!P```&*B`0`3````:J(!``P```!^H@$`%P```(NB
M`0`&````HZ(!`!$```"JH@$`#0```+RB`0`#````RJ(!`#(```#.H@$`!```
M``&C`0`&````!J,!``<````-HP$`'````!6C`0`M````,J,!`"X```!@HP$`
M+P```(^C`0`3````OZ,!`!X```#3HP$`%P```/*C`0`;````"J0!`!X````F
MI`$`&0```$6D`0`:````7Z0!`!X```!ZI`$`%@```)FD`0`I````L*0!`!\`
M``#:I`$`)P```/JD`0`7````(J4!`!L````ZI0$`'0```%:E`0`8````=*4!
M`"0```"-I0$`)@```+*E`0`G````V:4!`!<````!I@$`&````!FF`0`<````
M,J8!`"(```!/I@$`%P```'*F`0`>````BJ8!`!H```"II@$`/@```,2F`0`D
M`````Z<!`"<````HIP$`*@```%"G`0`K````>Z<!`"4```"GIP$`&P```,VG
M`0`@````Z:<!`!T````*J`$`,````"BH`0`=````6:@!``H```!WJ`$`%@``
M`(*H`0`2````F:@!`"@```"LJ`$`'0```-6H`0`-````\Z@!``\````!J0$`
M&0```!&I`0`0````*ZD!`!L````\J0$`,0```%BI`0`(````BJD!``H```"3
MJ0$`(@```)ZI`0`F````P:D!`"4```#HJ0$`&0````ZJ`0`'````**H!`,(`
M```PJ@$`&@```/.J`0`5````#JL!``@````DJP$`#````"VK`0`4````.JL!
M`!H```!/JP$`!0```&JK`0`U````<*L!`!0```"FJP$`%````+NK`0`'````
MT*L!``H```#8JP$`"@```..K`0!`````[JL!`"4````OK`$`$@```%6L`0`5
M````:*P!``\```!^K`$`,@```(ZL`0`-````P:P!``X```#/K`$`#P```-ZL
M`0`8````[JP!``H````'K0$`#P```!*M`0`%````(JT!`!\````HK0$`"@``
M`$BM`0`?````4ZT!``@```!SK0$`%0```'RM`0`'````DJT!``@```":K0$`
M"@```*.M`0`[````KJT!``4```#JK0$`#0```/"M`0`*````_JT!`!`````)
MK@$`!@```!JN`0`*````(:X!``<````LK@$`$@```#2N`0`,````1ZX!`!T`
M``!4K@$`$P```'*N`0`>````AJX!`#(```"EK@$`!0```-BN`0`&````WJX!
M`!P```#EK@$`!`````*O`0`J````!Z\!`!`````RKP$`!0```$.O`0`#````
M2:\!``P```!-KP$`%P```%JO`0`+````<J\!``,```!^KP$`"@```(*O`0`(
M````C:\!``L```"6KP$`#@```**O`0`/````L:\!`!$```#!KP$`$@```-.O
M`0`*````YJ\!`#````#QKP$`&P```"*P`0`8````/K`!``H```!7L`$`2```
M`&*P`0`(````J[`!`!8```"TL`$`0@```,NP`0`4````#K$!``\````CL0$`
M"0```#.Q`0`$````/;$!``8```!"L0$`%@```$FQ`0`:````8+$!``<```![
ML0$`"````(.Q`0`(````C+$!``(```"5L0$`"0```)BQ`0`+````HK$!``4`
M``"NL0$`&@```+2Q`0`F````S[$!`!4```#VL0$`'@````RR`0`1````*[(!
M``(````]L@$`!````$"R`0`/````1;(!``8```!5L@$`!0```%RR`0`$````
M8K(!`!0```!GL@$`20```'RR`0`1````QK(!`"4```#8L@$`+P```/ZR`0!8
M````+K,!`!$```"'LP$`:0```)FS`0`?`````[0!`#P````CM`$`)@```&"T
M`0`Y````A[0!`"X```#!M`$`)P```/"T`0`U````&+4!`#$```!.M0$`,0``
M`("U`0`U````LK4!`"T```#HM0$`'P```!:V`0`V````-K8!`!H```!MM@$`
M#@```(BV`0`,````E[8!`',```"DM@$`!@```!BW`0!U````'[<!`&H```"5
MMP$`*P````"X`0`0````++@!`!8````]N`$`"P```%2X`0`:````8+@!`#4`
M``![N`$`&P```+&X`0`5````S;@!`%<```#CN`$`%P```#NY`0`*````4[D!
M``4```!>N0$`!@```&2Y`0`(````:[D!``4```!TN0$`%````'JY`0`0````
MC[D!`!8```"@N0$`(````+>Y`0`+````V+D!``@```#DN0$`!````.VY`0`*
M````\KD!``L```#]N0$`"`````FZ`0`'````$KH!`!<````:N@$`!@```#*Z
M`0`&````.;H!`!<```!`N@$`"P```%BZ`0`'````9+H!`!(```!LN@$`"```
M`'^Z`0`7````B+H!``T```"@N@$`#0```*ZZ`0`&````O+H!``8```##N@$`
M#P```,JZ`0`'````VKH!``4```#BN@$`%````.BZ`0`"````_;H!``0`````
MNP$`#`````6[`0`)````$KL!`"(````<NP$``@```#^[`0`2````0KL!`!@`
M``!5NP$`"P```&Z[`0`%````>KL!``P```"`NP$`"@```(V[`0`/````F+L!
M`!8```"HNP$`!0```+^[`0`-````Q;L!`"<```#3NP$`#@```/N[`0`/````
M"KP!`!`````:O`$`!0```"N\`0`"````,;P!``L````TO`$``0```.,```"I
M`0``6P```%`!``"X`@``(04``#<&```-`P``4`,``/4%````````/@8``.\%
M``!<``````````````!I`P``(`0``%8%``"[!0``20$``"H!````````````
M`)P"``"F!0```````/<```#6!0``=P0```````#<!```P@4``+`````7`0``
M.00``-L$```U````&@8``)````!%`0``&`$``(H!``!0!0``E00``*,`````
M`````````#(!````````+@(`````````````<P$`````````````8P8`````
M````````````````````````,@```'H%``!2!`````````````!J`0``/`0`
M`"<$````````6P$``'$%````````+@8``.P%``!A!@``]P$``'$!````````
M```````````/`0``=P(``,`!``!K`P``````````````````+@4```````!K
M!```+@```/8$``!3`P``CP```&L%`````````````"0#```6`@```````)$`
M``!#`0``50$``/H!``````````````````!1`@``C04``*4#````````\0``
M`&T"``!9!@``?P(```````!:`P``B`,``#8&``#,`0````````````"+`@``
M`````"<```"(`0``&@,``*`"``!+`0``<````'($``!O`0```````+8#````
M````*`$``/H%```9`0``K`$```````!8`P``60,``%H%``#6!```-04```X`
M``!P!```3`(````````K`0``!04``,,"``!*!@``,P,``$<```#;`0``6@$`
M`/L$``!.````Y@```&8&`````0```````-<"``#"`P``)@4``&,"``!I!```
MB`4`````````````]0(``/P$``##`P``&@(```````!Z!```%@4``!L```!?
M!```+````(4%``#)!```SP$``#(&``"8!@``T`(```````"_````````````
M```I`@```````'D"``"C!````````'$`````````OP(``)<`````````.@``
M`'H&``!D````EP4```````"8!0````````0$``";!0``+P````8#````````
MB@```.`%``#(````30``````````````(0(``+X$`````````````((!``"?
M`0```````+X````/`@``Q`(````````.`@``E@8```$$```"!@```````%P"
M``!$!@```````%0#```%````)0$``#L!````````:`,``-<%````````/@``
M``````!-`0``90,```````#(!0```````*@#````````MP0```L$````````
M``````````!/!```A`(``$L#````````/@$```````!=!```<`$``+$$````
M````?`$``#4#````````^P(``/`"``#W!```R`(``)T````!!@```````"@#
M``"Y````Q`4``,\"``#N`0``W@$``"T#``#`!0``;P````````"K!```4@8`
M`,0$```9````.`4```````#``P``(`(``#4"````````1P(``'$$````````
MG0,```T%``!&!```6@0``*D$````````!0,``*("``!C`P``?0(``&4$``!W
M`P```````'@#```4`P``R@(``+($``!\!@``)@$``-H"```H!0``N@4``%P$
M`````````````,$```">````90$```````#J`@``008``+L"````````NP$`
M`%0````#!```S@$````````G`@``1P4``.D$````````W`$`````````````
M`````$X"````````]````$`$````````-@$``'8"``!]!@```````,8!````
M`````````!@$``!;!0``EP$``-(!``!X`````````!P````[`P``X0$``)T$
M```P!0``````````````````Z`(``$,&````````!00```````!D!@``V`$`
M``````".`P```````!4#`````````````'4$``!]````:P(``*$$``#"````
M$`8``(4$``"*!````````(@&```_`0```````%D!````````@`(``.`!``"%
M`0``]@$```,"``!T`P``K@4``*P#``#G`0``U@````P"``#9!```0P``````
M``")`P``30,``,P"``"``P```@0``!4%```E!0``D00`````````````E@(`
M`-<#``"K`@``W`4``)0&``!@````I`(``,`$``!#`P``J@0````````7`P``
M`````!`!``"K`P``>0````D```":!0````````````"``````````"<%```]
M!0``6P(``*$%``"P`0``1````"L````Z`@``5P(``&4%``#Q!```OP4``&H%
M``#%````;@,```L"``!&!@````````X$```Z!```YP````````#U`P``C`,`
M```````$`0````````$"```W!0```````*D```!8!@``$@4````````M!@``
M8@4```````!J````U````/L%````````A0,``!D&```(`P``````````````
M`````````(D&``#3`0``%````-`$`````````````'\%``!J!```]P,``/L#
M````````AP0``,P%```1`0``/@4```````!_`0```````"P"```A!@``$P``
M`.X$``!2!0``K@0``)H"``"T`0``+P8```````#=!0``(@```"P#``!<`P``
M3@0```````#$`P``'`0````````F````UP0```````",!@```````+T```"2
M!```2P(``"X#````````]@,``'\#``"$!0``H`4``&L&``#@`P``?@,``!D#
M````````]`(``.8%``#+`@```````%,"````````!P4``(($```A`P``%P4`
M`"D&``!4!@```````*<`````````Z0(``+<!``"1`@``D04```````#:````
M80```!0&````!@``:@(```X!``#3`@``X@```/T$``!,````X0```#`"````
M````G0(```````#A`@``<`8``"4"``#;````-00``(X&```1`P``MP4``'L`
M``"P!````````/L!``#D!```Q0(``%0"````````FP$``'P"``#K`@``````
M`.@#``````````````P&````````````````````````M`4``"$$````````
M`````$L`````````^`0```X#`````````````#D%``"B`P``%P0``,X%``#L
M!```W0```,@!````````U00``#(%``"-````5@0``(`!``#(!```@0$``$X!
M``!N`0``^`$``)\%```?`P```````(0```!?````=`$``$T$```Q!@``Z@0`
M```````B!0``\P0````````'`P``?0,``,H#``"S!````````%@"``"S````
MS0$``&8$```V`@``!P(``',&``#V!0``T`,``%(#`````````````(0$````
M````60```%\&````````8`4``````````````````/L````X`0``'P8``#L&
M``!%!0``QP4``*$!```+!@``H@$``#,"```;!0```````*H````Y!@``\`,`
M`"8#``#C`@````````````"<!0``Q@,``-0#``""!0``$P,``/$!``!`!0``
MR@4``)<$````````+`$``$T"```U`0``2P8``#$"`````````````*8$``#Q
M`@``:@,``-D"``!\!0``K@```)L$``"R!0```````!X$``!\`P``H@0``(T$
M````````G`$```````!S`@``[0,``$``````````,`,``-D%``"9`P``````
M`$\```"&`@``#````#T&```S`0```````$P$``"=!0``R@```&X$``!R`0``
MU`(``'L!```$`P``8`(``$@$``#6`P``S`0``"\!````````[`````````!$
M!0``:`8``)4&``#"!```\`0``"T!``#?!0```````&P$````````/`,`````
M```S!0``Y@0``-X```#?`@``404``$($``"8`````````.H#```J`@``]`$`
M``````!]!0``9@(``)X%```H`@``I`4```````!$`@``C`$``(0!``!>`@``
MO`0``!0"```$!@``?00``'`"``#N!0``E@0``(<"````````\@4`````````
M````+`0````````J!@``/00``&`$``!R!0``&@```/X#``#F`0``````````
M``````````````````!5!````````!($``!L`0``A@8``!H%````````U04`
M`+X%`````````````$0$```V!```BP```)\```#$`0````````D&```7````
M"@4```````#>`P``4`(``#<"``"K`0``T00``/T"``##!```"@8``&<&```]
M`0``&P8````````[!```````````````````M0$``!`"`````````@```&$$
M````````_P0``,D%````````CP(``&T&``!"!@``I00``(D``````P``C@$`
M````````````\P```),$``"2!0``8@(`````````````9@4``",&``#_````
M`````+0"```V````.0$``(X$````````1P0`````````````````````````
M````N@0``-X"``".`````````-4!``!%`P``!P``````````````C0,``!T!
M```@`P``+0```)`#````````RP,``'\````_!@``M@0``&`!``":`P``>@,`
M`(8%``"'````B`````````"U`P``D`0``&`&````````.@$`````````````
MD`(``$D#``"3!@``$04`````````````=@```)X"``"4````9`$``/H```#4
M!```"P,```,```#"`@``D`4``+@!```,`P``2@````````!^`@``````````
M``!H!```=`````````![`@``)00```````!;!@``X0,``!T&````````708`
M`!4&``!T!```T@0``,$!```6!@``;@4``.P#``"?`P``V0$```````!D`@``
M90```#$#```>`0``F0$``.X"``#R`@```````#L%````````J0,``'X&```[
M`@``2P4``.@$````````4P8```````!G!```"`$``$\#``!^!```KP(`````
M``!7`0``/@,```T"````````SP4``&8!```Q!0```````/X"``!B!```908`
M``````!5`````````-\$```T````00```%$#`````````````'0"``!'`P``
MZ@```(T!``#X`P```````!`%``````````````````#1````-P$``"0%``"0
M`0``U0```'$#``!I!@``TP0``!4$````````KP4``$(%````````ZP$``!@%
M``"_`0``F08```````!_!@``E04``.L``````````@$``!\$``#G!```=0$`
M`*@$`````````````&0$```%`0``'0(```````!U`P``L@````````"!`@``
M`````%,```#O`0``1`$``(,"``!U!@``2`(``*\$``#.`P``(`$`````````
M````O00``/D$````````)`(``/@%````````XP4``&,!``"+!0``[@```.H!
M``"_!```*04``!("```%!@``MP,```````"-!@``;`8``)D%``"*`@``#`4`
M``````#]`P```````+$```!H!0```````+P```#(`P````````````"Y!0``
M`````-T"``"Q!0``RP0````````K!```9P4``,$$```C!0```````&X````7
M`@````````````!:````Z0````````#R````L@$``$`!```=!```````````
M``"&`P``X````#L```"H`@``P````,0`````````.0`````````3!0``H`,`
M`!X%``#X``````````````"@!````````%X!```N!```R0,``#$!``!B````
M/P4``!(```!B!@```````-8"``!,!@``X`0``%T#````````$0```#P```!*
M!```TP,```````"G!0````````````!W!0``X04```````!Y!@``.0(`````
M``!=````;04```````!M````U@$```````#4`0``Y00`````````````````
M``<!````````Y0```%<%``"%`````````"H#``!7`````````/X%``"5`@``
M^0,`````````````408``"`%``#H````O`(``*0!``"U!0``"@```)X$``#0
M`0```````*P"````````NP,``/0#```W`P````````````!;`P``YP(``-L#
M``!D`P``*0,``#0%``#B`@``M00``/P!```@````,@0``+@%``#V````K```
M`(\!``!P!0````````\%`````````````!D%```3`@```````%````"G`@``
M`````%T%`````````````,$"``![!```[P(```````"C`0``&00``/,!````
M!0``=0```),```"\`0```````)(#```T!```A`8````````;`0``R@0``,,!
M```C`````````*D%``!2`0```````$H%```1!```E`4``'4%````````````
M`%`$```K!@``)08``(,#``"_`P``#00``*,%````````D@8```````#D`@``
MI@$``*T$````````>`8``+0$``"4`@```P4```T```!!`@``-`8`````````
M````)````&4"``":!@```````&D%``".!0``@@(``!\"```3!@```````,H!
M``````````````````"`!@``=0(``%<&``"O`P``S04``'H!``!V!0``````
M`&D"``""`P``@P````````"A`P```````*\`````````O`4``,4#````````
M_P4``)<&```*`@```````$4"````````O@,``&X&``#E`@``!@4```````"2
M`0``Z@4``#`$```+````F`(```````#P````BP,``$8#``"*!0```````+T%
M``!<!@``A`,```,#``#9`P``0`(```@`````````F`,```````"M`@``!`(`
M`+P#``````````````````!G`````````"D!``!H`0``S`,````````Q````
MW0$``$P%```>`````````&T#``"2````508``#@````8`@``5P0```D"``!R
M`@```````````````````````"\$``"J!0``ZP4``(P"`````````````$T%
M``!1!```-P```!L#``!)!@```````"L#``!/!0``&P(``*T#``!#`@``;P0`
M`%T!``!V!@``N@(``'8#```!`0``?`0``````````````````-X$````````
M`````'(&```5``````````````"Q`P``$P$````````(!0``````````````
M````E@4``)$&``";`@``QP(``,X"```J!0``TP4```````#H!0``1@$``'@"
M``"T````RP$``-<!``#'````LP,``%\"``!G`@``_P(``&H&``"/!```*@0`
M`(D%``!@`P```````+8`````````I`,``/,#```J````M0```"`&```E````
M"P$``"0&``!>!0``7@8```````"Z`P```````"L"``#]`0``&P0``,4!````
M````IP0``'@%``"*`P```````#H%```/!@``CP8``+0#`````````````#\$
M````````100````````6`0``?@````````#``@``Y`4``)\$``!S!0``[P``
M`(`%``!G`0``(@$``(P%``!)`````````($$``!V`0``O0$``,8$````````
MJ`````,!``"A`````````!4!````````,P8````````(`@```````#P!````
M``````````````"A`@``GP(``"T%``#"`0``80$```````"3`0``O@(``'D%
M```````````````````&````<P0``!H!````````XP,````````B`P``>P,`
M`+$!```2!@````````````!R````804``(P```#\`@``I@```!\%``#8!0``
M```````````1`@````````````"5````'`,``,D!```/````200``$\&```X
M`P``8@$``(4"``!"`P``;`,``(L!```S````=`4``%X#```_````.@8`````
M``#Z`@``N`,``$L$``!6`P``S0```%$!``!``P```````'P```!V!```W`,`
M````````````"00``+`#``#I!0``RP``````````````H@`````````O!0``
MI0$`````````````F`0``-`%``!S`P``QP$``!0%``"P!0``N0$``.($````
M````;@(``$("`````````````-(````R`@``[04``#@"``!)!0``2`$``$$!
M``!(````F@```%<#```5`@``7P$``,8%``"N`P``DP,```````"S`0``>0$`
M```````"`P``W`(``*T```#E`0``8@,```H#```.!0``H````/P%````````
MM@(``-\````V!0````````````!A`P``$`,``.T!```A`0```````-````"#
M`0``MP(``!T%````````D0$``)D$```D`0``7`4``$@#``!2`@``U0,`````
M``#2`@`````````````U!@``J0(```````!4!```;P,````````D!```[00`
M``````#.````108``$(```#^`0``I@,```````"1`P``YP,``%8&``"4`P``
MT0$``!@`````````7`$``!<&```G`P``"0,``)@!``#?`P``#`0```````"4
M`0``0@$```````!'`0```````#<$``#:`0``'P$``$,$```C`0``M0(`````
M``!C!```XP$``$\"```"!0``S0,```````#_`P```````-0%``")`0``'0,`
M`.8"``#8`P``6`4``)D```!!!```JP4```````"Y`@``3@,``$$%``"]`P``
M3P$``)H!``!(!@``K`4``&<#`````````````/D"``"G`0````````@$``"5
M`P``'P````````")!```_```````````````E@```&$"``#Q`P``_0```$,%
M``!Y`P``:P$``!P&``#!!0``T04````````'!@``F0(``(P$``"/`P``````
M`),"``!W````@P8``'H"``!9`@``,````#H#``"!````NP```'L&``#^!```
M/P,```````!1````\@$``-H$```]````,P0``'`#``#X`@````````````"(
M!```:0```%\%``"W````6`0```````";`P```````)("``!6````>P4``%L$
M````````N`0``"$```#D`0````````````!Q!@``"`8``%T"``!8````\P(`
M``<$``"E!0``SP```$@%``#8`@```````!0!``"D`````````)X#``!Q`@``
M"04``.L$``!F````I0````("``"M`0```````&\&````````/`8``(@"``!0
M!@``@P0````````<!0``S0(``/P#``#3`````````-\!````````Q@```+D#
M`````````````)8!```P`0``2@(``&,%```&`0``A@```%0!``"4!```````
M`$<&``"K````+`8``!P!````````;`````T&``#2!0``(@8```````#I`0``
MZP,```0%``!O!0``4@```.(!``#B`P``````````````````?P0```````!M
M`0```````'X!``!D!0``I@(`````````````\`$```````#&`@``X@4```8$
M````````1@(```````!`!@``LP(``'0&``#/!````````#T"``!4!0``+`4`
M`%,$``"7`P```````",#```B!```)@8``,L%``";`````````*@!``#P!0``
M)P8``.X#``!5!0``G0$```````"<````Y`,``!X&```N`0``308``(<&``"Z
M`0``M@$```````#U`0````(``!8#``````````````````"J`P``L0(``"<!
M``"'`0````````````#U````````````````````J@(````````2`0``-`(`
M````````````&`,``-@`````````;00``$H#``!W`0``M@4``"@&``#M````
M.`8``!X"```-`0``Y04``-P```!.!0```0,````````V`P``PP``````````
M````DP4``"("```M`@```````'@$````````F@0```````"*!@``#@8```0`
M```&`@``R0`````````+!0``>`$``%@!``!?`P``L@(``)8#````````````
M`.@!```)`0``V0```/(#``#O`P``,`8``%,!````````_P$``/H$````````
M`````"T$``#E`P``````````````````O0(``!,$``!L!0``%@````````#^
M````QP0````````:!```.0,`````````````G`0```````#Y`0``T@,``,4$
M```*`0``YP4``)X!````````*`0``(<%``"E`@``O@$``"\"````````````
M`!X#``#W!0``A@0```````#L`@```````#0!``!^!0```````*0$````````
M``0```````"-`@``:`(``%X```!R`P``VP4``!`$``!5`@``$08```\#``#=
M!```@P4``%H"``#F`P``;`(``#(#```F!```HP(`````````````KP$`````
M``#C!```(P(``-H%``````````````4"``"%!@``^04``,,%````````/@0`
M`-4"``"+!@``NP0``,D"````````@04``/$%````````,00``"L%``!:!@``
ML`(`````````````````````````````]P(``/T%`````````````%X$``!6
M`0``*0````````""````3@8```8&``#U!```:P```-$"``!&!0```P8``(X"
M```9`@``/P(```````!I`0``G`,``!8$````````.`0``*<#``"H!0``````
M`!@&`````````````($#``#,````2@$``$0#`````````````(`$```<`@``
M3`$``',`````````E0$``(D"`````````````-$#````````J@$``'<&``!9
M!0``S@0``.`"``#:`P``K`0```````"@`0``@@8```H$``#8!```#P0`````
M``#R!```'0```+@`````````?0$`````````````00,``/0%````````BP0`
M`#0#``!F`P``[P0``!(#``"Y!````````%8"``"7`@``K04`````````````
M`````%4#````````CP4``(8!``!9!```@08``"4#``#!`P``*00``$4```#S
M!0````````````#V`@``]`0``&@```#/`P``W0,``-<```!3!0```````.D#
M````````QP,``-L"````````/`4```````!O`@``^@,``#T#```\`@``)@(`
M`+,%````````X00``'D$``"'`P``>@```!0$```^`@``H@4```P!````````
MW@4``$D"``"R`P```````"@```#-!```$````+H```"0!@```````",$``#Y
M````8P```,4%```O`P``[`$`````````````K@$``.T"``"N`@``Y````$P#
M``!&````HP,```$%````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"!A="``)60@)7,@86YD("5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO
M=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@
M5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E
M<R`E<P`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`
M)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A
M<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G=7-T:6YG
M("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`
M,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A
M8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!286EN`$%-
M(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T
M:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT
M(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#
M:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.
M97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@
M;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A
M9&1R97-S(&)O;VL`061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G
M:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N
M=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL
M(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!
M;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@
M24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA
M=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T
M92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0
M<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P
M<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A
M9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E
M(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL
M92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F=E;G1I;F$`
M07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS
M:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S
M=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!
M3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D
M('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@
M9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B
M86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO
M<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M
M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ
M90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F
M(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E
M<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!"
M;W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`
M0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#
M35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I
M97,N+BX`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@
M9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A=&5G
M;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E
M;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#
M96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#
M96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`
M0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI
M<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)
M<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R
M`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R
M('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K
M871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S
M960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R
M('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD
M`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O
M;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I
M;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO
M;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S
M+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I
M979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A
M(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E
M871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#
M=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H
M97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE
M8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!2
M97!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!2
M96-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C
M96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT
M`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969I;FET:6]N<P!$
M96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A
M;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QI=F5R>2!T:6UE`$1E
M;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$
M97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z
M(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y
M($]P=&EO;G,`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA
M=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E
M;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U
M8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$
M<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L
M96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC
M;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%
M=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O
M;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO
M=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N
M9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP
M;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A
M:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S
M(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL
M960@=&\@;6]V92!T;R`B)7,B+@!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA
M;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A
M<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N
M;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE($-O=6YT.B`E<R!F
M:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA
M;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T
M(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A
M<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U
M<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C
M;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S
M=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R
M='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N
M8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S
M:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@
M`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'
M86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA
M`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L
M`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X
M-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!S`$=U861E;&]U
M<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`
M1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E
M;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I
M=&AM`$AA>F4`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U
M<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B
M)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO
M;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W
M(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y
M.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!
M4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S
M<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO
M;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N
M<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U
M<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K
M('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B
M<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!)
M;6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U
M<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT
M`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M
M871I;VX`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R
M="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E
M`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R
M`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R
M="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R
M87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@
M869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y
M($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE
M;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A
M;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV
M86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J
M96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D
M871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q
M`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L
M`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA
M<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`
M2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,
M969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+
M96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`
M2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!2
M97!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`
M3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8P!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,
M97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E
M;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A
M<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!2
M86EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R
M`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`
M3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B
M;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R
M`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA
M`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO
M=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W
M97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O
M;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C
M87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I
M`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T
M(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@
M86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`
M36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H
M(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG
M+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN
M:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X
M(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`
M36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E
M<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE
M<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-
M971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`
M36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN
M('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF
M:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC
M(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO
M;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S
M=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-
M;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U
M90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T
M:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA
M;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE
M<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E
M($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E
M($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C
M87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y
M`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD
M`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X
M="!O<'1I;VYS`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`
M3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA
M;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG
M92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO
M;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T
M+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.
M;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E
M('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I
M9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A
M=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`3F\@<VED97,`3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I
M="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE
M<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y
M`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP
M;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@
M;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W
M<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`
M3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO
M="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/
M<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I
M;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`
M3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L
M(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`
M4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W
M97)S`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!0
M86QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!0
M87!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O
M<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG
M;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S
M;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`
M4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R
M(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@
M=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU
M;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9`!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0
M;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R
M92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I
M;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R
M:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC
M($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`
M4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO
M=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D
M(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O
M97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP
M($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!"
M;&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P
M86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T
M(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@
M365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BX`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`
M4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@
M861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T
M(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E
M;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I
M;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE
M;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`
M4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)
M1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T
M(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E
M;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H
M;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P
M<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@
M16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H
M<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T
M=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-
M86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S
M($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O
M<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E
M`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C
M:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T
M<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A
M=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!
M9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN
M(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M
M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R
M;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`
M4W=I='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I
M86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FUS`%135B!F:6QE`%1A
M8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@
M3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E
M<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($UA
M:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB
M97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S
M<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S
M(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@
M;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA
M>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M
M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF
M:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E
M<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O
M;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL
M92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@
M8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D
M871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A
M9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A
M:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T
M<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N
M`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I
M<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET
M("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F
M;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@
M*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H
M:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4
M;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R
M86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`
M5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE
M;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y
M;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C
M<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I
M;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O
M)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5
M;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`
M56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@
M=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%
M;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3
M=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R
M('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D
M`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO
M4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@
M17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!G<F%D
M92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A
M=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L
M971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N
M=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E
M<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92X`57-E<FYA;64`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A
M9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E
M("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`
M5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A
M=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N
M:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED
M=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E
M9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S
M`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT
M97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8
M-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE
M;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@
M=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T
M851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A
M9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F
M=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E
M(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!4
M97AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@
M;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E
M(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@
M:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S
M:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S
M+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H
M97)E`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z
M`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@
M>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`<FES:6YG
M`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!T
M87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC
M;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D978S+C`N-`I297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#4M,#8M,C@@,30Z-#@K,#,P,`I,87-T+51R86YS;&%T;W(Z($%U=&]M
M871I8V%L;'D@9V5N97)A=&5D"DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TY"D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STQ.R!P;'5R
M86P],#L*`"`H)7,@9_QN(/9N8V4I`"A%<FG^:6T@06YA:'1A<OT@)7,I`"`H
M)7,@9_QN9&4I`"`H8G5G_&XI`"`H>6%R_6XI`"`H9/QN*0`@9&4H9&$I(``E
M9"`E<R!V92`E<P`E9"UG_&YL_&L@:&%V82!T86AM:6YI`"5S("T@0FEL9&ER
M:6T`)7,@4&%R;6%K(-UZ:0`E<R!+0@`E<R!"86O];2#=_FQE;6QE<FD@+2!/
M;F%Y;&%M80`E<R!!>6%R;&%R`"5S($=I<FG^`"5S($%N;&'^;6$@2V_^=6QL
M87+]`"5S('IA=&5N('9A<BX`)7,@9&4@)7,@)7,`)7,@:7-T96YM96MT961I
M<BX`)7,@9&%K:6MA`"5S(&)U;'5N86UA9/TN`"5S("T@)7,@+R`E<R``)7,@
M061R97,@1&5F=&5R:0`E<R!486MV:6T`)7,@3F]T($1E9G1E<FD`)7,@1_9R
M978@3&ES=&5S:0`E<SH@)7,`+"!F_7)T_6YA;/T@)7,@)7,`+"!D9?!I_FEM
M("5S("T^("5S`"TM(%-EYR`M+0`Q,B!386%T;&EK(%IA;6%N($)IYVEM:0`R
M-"!386%T;&EK(%IA;6%N($)IYVEM:0`R-"!S86%T`$)U(/9B96L@:>=I;B!V
M97)I=&%B86[]('-O;B!U>F%N=/US_2!G97)E:VUE:W1E9&ER+@!/;G5L;6%Z
M(&)I<B!H871A(&]L=?YT=0#=;&5T:7EI(/YI9G)E;&5Y96)I;&UE:R!IYVEN
M(%!'4"!AY_UK(&%N86AT87+](&=E<F5K;65K=&5D:7(N`-UM>F%L86YM_?X@
M:6QE=&EY:2!D;_!R=6QU\'5N=2!S8?!L86UA:R!IYVEN(%!'4"!AY_UK(&%N
M86AT87+](&=E<F5K;65K=&5D:7(N`-UL971I;FEN(/YI9G)E<VEN:2#G]GIM
M96L@:>=I;B!AY_UK(%!'4"!A;F%H=&%R_2SV>F5L(%!'4"!A;F%H=&%R_2!V
M92!G9>=I_B!T_&UC96-I\&D@9V5R96MM96MT961I<BX`W6QE=&EY:2!I;7IA
M;&%M86L@:>=I;B!AY_UK(%!'4"!A;F%H=&%R_2SV>F5L(%!'4"!A;F%H=&%R
M_2!V92!G9>=I_B!T_&UC96-I\&D@9V5R96MM96MT961I<BX`W6QE=&EN:6X@
M_FEF<F5S:6YI(.?V>FUE:R!IYVEN(&'G_6L@4R]-24U%(&%N86AT87+]+"#V
M>F5L(%,O34E-12!A;F%H=&%R_2!V92!G9>=I_B!T_&UC96-I\&D@9V5R96MM
M96MT961I<BX`W6QE=&EY:2!I;7IA;&%M86L@:>=I;B!AY_UK(%,O34E-12!A
M;F%H=&%R_2P@]GIE;"!3+TU)344@86YA:'1A<OT@=F4@9V7G:?X@=/QM8V5C
M:?!I(&=E<F5K;65K=&5D:7(N`-UL971I>6D@_FEF<F5L97EE8FEL;65K(&GG
M:6X@8>?]:R!334E-12!A;F%H=&%R_2!G97)E:VUE:W1E9&ER+@#6UB!98?!M
M=7(`UM8@4V'P;F%K`-;6($AA9FEF($MA<@#6UB_64P!!4$D@240`1/QZ96YL
M97EI8VD@:&%K:_UN9&$`2&%K:_UN9&$N+BXN`$5N86QT`$]R=&%Y80!61E,@
M9&EZ:6YI('EA<F%T_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN`%9&4R!D:7II
M;FD@>6%R873];/UR:V5N(&5R:?YI;2!E;F=E;&QE;F1I+@!(97-A<"!087)A
M;&]S_0!(97-A<"!$;VYD=7)U;&1U+@!(97-A<&QA;OUY;W(`16ML90!!;'0@
M1W)U<"!%2VQE`$%L="#=>FEN($5+;&4`0G5R87EA($5K;&4Z`%EE;FD@1W)U
M<"!%:VQE`%EE;FD@W7II;B!%:VQE`%EE;FD@:W5L;&%N_6/](&5K;&4Z`$MO
M;&]N($5K;&4`665N:2#\>64@96ML90#=:VEL:2!%:VQE`"5S($UE;OQS_&[\
M($UO>FEL;&$@2V5N87(@QW5B=?!U($]L87)A:R!%:VQE`$%D<F5S(&1E9G1E
M<FEN92!E:VQE.@!!9')E<R!D969T97)I;64@96ML90!+=6QL86[]8_T@16ML
M90!+=6QL86[]8_T@96ML96UE('-EYVEL96UE>B!K_6S];F3]+@!!9')E<P!!
M9')E<R!$969T97)I`%GV;F5T:6TM+41I\&5R(&MU;&QA;OUL87(@:>=I;B!I
M>FEN;&5R:2!B96QI<FQE>6EN`%GV;F5T:6T`061S`$%F9V%N:7-T86X`07)N
M879U=&QU:P!#97IA>6ER`-9T96MI(&%D`$AI>F%L80!(:7IA;&%M86LZ`%3\
M;?P`5/QM($1O\')U;&%N;?W^($MU;&QA;OUC_6QA<@!4_&T@1W)U<&QA<@!4
M_&T@W7II;FQE<@!4_&T@9/9R="!Y_'H`QV]K;'4@861R97-L97)E(&EZ:6X@
M=F5R`%/]<F%L86YM_?X@;&ES=&4@=/QR_&[\(&%Y87)L86UA>6$@:7II;B!V
M97)I;'-I;B!M:3\`6F%T96X@=F%R`-9T96MI($E-4U`@1VER:?YI`-9T96MI
M($E-4U`@4&%R;VQA<_T`UG1E:VD@24U34"!+=6QL86[]8_T@063]`-9T96MI
M(&5L96MT<F]N:6L@<&]S=&$@861R97-I`-9T96MI('1A<VQA:VQA<@#6=&5K
M:2!M971I;CH`06UE<FEK86X@4V%M;V$`1V7G97)S:7H@9&7P97(@8F5L:7)T
M:6QD:2X`06YD;W)A`$%N9V]L80!!;F=U:6QL80!!;F]N:6T@4')O>'D`0V5V
M87``06YT87)T:6MA`$%N=&EG=6$@=F4@0F%R8G5D80!5>6=U;&%M80!5>6=U
M;&%M82!,:7-T97-I`%5Y9W5L86UA($AA>OUR`$%L="!P87EL8?[];6QA<F$@
M=7EG=6QA`$]N87EL80!986ML8?[]:R!";WEU=`!.:7-A;@!!<F%PYV$@*%=I
M;F1O=W,M,3(U-BD`0F5L9V5L:6L@1&]S>6$@0G5Y=71U`$)E;&=E;&EK($%D
M_0`E<R!IYVEN(&=I<FG^(&ES=&7P:6YI(&MA;&3]<FUA:R!I<W1E9&GP:6YZ
M92!E;6EN(&UI<VEN:7H_`$%R:F%N=&EN`$5R;65N:7-T86X`17)M96YI8V4@
M*$%235-#24DM."D`4V%N870`07)U8F$`07-C96YS:6]N($%D86QA<OT`07-C
M:6D@4V%N873]`$%S>6$O4&%S:69I:R!"]FQG97-I`$)A:_UM(&G^;&5M;&5R
M:6YD96X@]FYC92!D;_!R=6QA;6$@<V]R=6QS=6X@;74_`$%T86UA($MO;&]N
M;&%R_0!687(@;VQM87EA;B!B:7(@9W)U8G4@<VEL;64@9VER:?YI;6DN`%9A
M<B!O;&UA>6%N(&)I<B!I>FYI('-I;&UE(&=I<FG^:6UI+@!687(@;VQM87EA
M;B!B:7(@9W)U8G4@9/QZ96YL96UE(&=I<FG^:6UI+@!687(@;VQM87EA;B!B
M:7(@<&%Y;&'^_6W](&3\>F5N;&5M92!G:7)I_FEM:2X`UGIN:71E;&EK;&5R
M`$'P=7-T;W,`079U<W1U<F%L>6$`079U<W1U<GEA`$%U=&A?8WER<W%L.B#=
M<W1E;F5N(&EM87`@=7IA=&%T_7/](&)U;'5N86UA9/TN`$%U=&A?8WER=7,Z
M(-US=&5N96X@>65T96YE:VQE<F4@<V%H:7`@9&7P:6PN`$%U=&A?8WER=7,Z
M(-US=&5N96X@:6UA<"!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H7V9T<#H@
MW7-T96YE;B!&5%`@=7IA;G3]<_T@8G5L=6YA;6%D_2X@4$A0)WEI("TM96YA
M8FQE+69T<"!S=VET8V@@9&7P:?YT:7)G97-I>6QE(&1E<FQE>6EN+@!!=71H
M7VEM87`Z(-US=&5N96X@24U!4"!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H
M7VMR8C4Z(-US=&5N96X@:W)B-2!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H
M7VQD87`Z(-US=&5N96X@3$1!4"!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H
M7VEM87`Z("5S(&MU;&QA;OUC_7/](&5K;&5N96UE9&DN(%-U;G5C=3H@`$%U
M=&A?;&1A<#H@)7,@:W5L;&%N_6/]<_T@<VEL:6YE;65D:0!!=71H7VQD87`Z
M("5S(&MU;&QA;OUC_7/](&?\;F-E;&QE;F5M961I`$%U=&A?;6-A;#H@W7-T
M96YE;B!-0T%,('5Z86YT_7/](&)U;'5N86UA9/TN`$%U=&A?<VUB875T:#H@
MW7-T96YE;B!S;6)A=71H('5Z86YT_7/](&)U;'5N86UA9/TN`$1O\')U;&%M
M82!B8?YA<OUS_7H@;VQD=2X`1&_P<G5L86UA(&)A_F%R_7/]>B!O;&1U+B`E
M<P!$;_!R=6QA;6$@4D%$2553('-U;G5C=7-U('1A<F%F_6YD86X@9V5R:2#G
M979R:6QD:2X`1E10('-U;G5C=7-U;F$@9&_P<G5L86UA(&)A_F%R_7/]>B!O
M;&1U+@!+=6QL86[];/UR(&%L86YL87(Z`$%Z97)B87EC86X`0D]&2"!!Y_UK
M;&%M86QA<OT`07)T86QA;@!!<G1A;&%N(%)E;F=I`$OV=/P@:V5R8F5R;W,@
M<&%R;VQA<_TN`$OV=/P@:V5R8F5R;W,@:W5L;&%N_6/](&%D_2X`0F%H86UA
M;&%R`$)A:')E>6X`0F%L=/UK("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&7^`$)A
M<F)A9&]S`%1A8F%N(.=I>F=I<VD`0F5Y87H@4G5S>6$`0F5LYVEK80!"96QI
M>F4`0F5N:6X`0F5R;75D80!":'5T86X`1&_P=6UG_&[\`%5Y9W5L86UA("(E
M<R(@<V%H:7`@;VQD=?!U("(E<R(@]F)E\&D@8G5L=6YA;6%D_2X`UF)E:R!!
M>6%R;&%R_0#68F5K(%3\<OP`2V]Y=0!";VQI=GEA`%EE<B#=;6QE<FD`4_UN
M_7(`4_UN_7(@2V%L_6YL_?#].@!3_6[]<FQA<@!";W-N82!(97)S96L`2&5R
M($EK:7-I`$)O='-V86YA`$%L=`!";W5V970@061A;&%R_0!"<F5Z:6QY80!"
M<FET86YY82!(:6YT($]K>6%N=7-U($+V;&=E<VD`0G)U;F5I`$)U;&=A<FES
M=&%N`$UA9&1E(-UM;&D@3&ES=&4`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3
M`$-24P!#4DP@1&'P_73];2!.;VMT86QA<OT`7TC\8W)E(-9Z96QL:6ML97)I
M+BXN`%1A:W9I;0!$=7)G=6X`2V%M8F_G>6$`2V%M97)U;@!087)O;&$@]GID
M979I;FEM;&D@;VQA<F%K('/]9OUR;&%N86UA;6%K=&%D_7(L(&S\=&9E;B!Y
M]FYE=&EC:6YI>FQE(&?V<OS^_&XN`$E-05`@<W5N=6-U<W5N82!B8?!L86[]
M;&%D_3H@)7,`2V%N861A`-UP=&%L`%-O<G5N(%)A<&]R=6YU(-UP=&%L($5T
M`"(E<R(@9&]S>6%S_2!S:6QI;F5M961I+@!'9>=I8VD@9&EZ:6X@8G5L=6YA
M;6%D_2X`)W1A<F=E=$9I;&4G(&1E\&G^=&ER9V5S:2!O;&UA9&%N(&1E=F%M
M(&5D:6QE;65Z+@`B)7,B(&1I>FEN:2!K86QD_7+];&%M863]+@!+86QD_7+]
M;&%M863]("PE9"!A;'0@>6%P_2!V87(N`%EE;FED96X@9/QZ96YL96UE9&DL
M('EE;FED96X@9/QZ96YL96UE(&GG:6X@<V'P;&%N86X@:V%Y_71L87+];B!S
M87G]<_T@:6QE(&1E<&]L86YM_?X@;VQA;FQA<OUN('-A>?US_2!E_FQE_FUE
M;65K=&5D:7(N`$)E;&ER=&EL;6G^(&YU;6%R87EA(&EL971I('GV;FQE;F1I
M<FEL96UE9&DN`$-A<&4@5F5R9&4`0F'^;/UK`$MA=&5G;W)I;&5R('9E($5T
M:6ME=&QE<@!#87EM86X@061A;&%R_0!#97`@5&5L969O;G4`2/QC<F4@UGIE
M;&QI:VQE<FD`2/QC<F4@>6%S=/UK;&%M87/].@!(_&-R92#6>F5L;&EK;&5R
M:0!(_&-R92!";_YL=6ML87+].@!#97`@5&5L969O;G4`2V5L=&EK("A)4T\M
M.#@U.2TQ-"D`3W)T80!/<G1A($%F<FEK82!#=6UH=7)I>65T:0!/<G1A($%V
M<G5P82`H25-/+3@X-3DM,BD`3VYA>2!"96QG97-I($%Y<OUN=/UL87+]`$]N
M87D@0F5L9V5S:2!+=7)A;&QA<OT`QV%D`$1E\&G^=&ER`-UN<V%N;&%R_6X@
M<VEZ9&5N(&=E;&5N(&5L96MT<F]N:6L@<&]S=&%L87+](&]K=7)K96X@=F4@
M8V5V87!L87)K96X@9_9R9/QK;&5R:2!A9"!V92!A9')E<VEN:7II(&1E\&G^
M=&ER:6XN`$MA<F%K=&5R`$)A\&QA;G3]>?T@1&5?;F5T;&4N+BX`WFEL:0#'
M:6X`0F%S:71L9?YT:7)I;&UI_B#':6YC92`H1T(R,S$R*0!'96QE;F5K<V5L
M(,=I;F-E("A":6<U*0!087)O;&$@<V7G:6X`2W5L;&%N_6/](&%D_2!S9>=I
M;@!487)I:&QE<FEN(&YA<_UL(&?V<W1E<FEL96-E\&EN:2!S9>=I;CH`3&ES
M=&4@0FGG96T@5/QR_&[\(%-EYVEN("AS_7)A;&%N;?W^(&QI<W1E;&5R(&GG
M:6XI`$-H<FES=&UA<R!!9&%L87/]`%/];OUF('1A;OUM_2!B=6QU;F%M863]
M.B5S`%1E;6EZ;&4`35-/9F9I8V4@8FGG:6T@:6UL97)I;FD@=&5M:7IL90!+
M=6QL86[]8_UY_2!T96UI>FQE.B`E<P!+=6QL86[]8_T@=&5M:7IL90!+=6QL
M86[]8_T@=F5R:7-I('1E;6EZ;&4`1&5V86T@971M96L@:>=I;B!T_6ML87G]
M;@!(5%10('EO;'5Y;&$@0VQI8VMA=&5L;`!096YC97)E>6D@2V%P870`0G5L
M=71L87(`0G5L=71L=0!#;V-O<R!!9&%L87+]`$ME;F%R(,=U8G7P=6YU($1A
M<F%L=`!$87)A;'3];&W]_B!3_6[]<FQA<@!+;VQO;6)I>6$`4F5N:P!296YK
M(%-EYVEC:0!296YK(%-EYVEM:0!+;VQO;FQA<CH`2V]L;VX@0F'^;/UK;&%R
M_0!+;VUI:P!+;VUU=`!+;VUU="!+86)U\'4`0>?]:VQA;6$`3W)T86L@063]
M`$-O;6]R;W,`WFER:V5T`$)I;&=I<V%Y87)L87(`2V_^=6QL87(`66%P_6QA
M;F3]<FUA($9A<FML87+]`%EA</UL86YD_7(Z)7,`4&%R86QO>?T@1&_P<G5L
M80!+;VYG;P!$96UO:W)A=&EK($MO;F=O($-U;6AU<FEY971I`$)A\&QA;G3]
M(&)A_F%R_7/]>B!O;&1U+@!"8?!L86YT_2!B8?YA<OUS_7H@;VQD=3H`0>?]
M:R!A;F%H=&%R('-U;G5C=7-U;F$@8F'P;&%N=/T@<F5D9&5D:6QD:2X`0>?]
M:R!A;F%H=&%R('-U;G5C=7-U;F$@8F'P;&%N=/T@<F5D9&5D:6QD:2X@4V5B
M96(Z("5S("@E<RD`1E10('-U;G5C=6YA(&)A\&QA;G3](&)A_F%R_7/]>B!O
M;&1U+@#=;&5T:?YI;2!N;VMT86QA<OT@8F'^87+]>6QA(&%D<F5S(&1E9G1E
M<FEN:7IE(&5K;&5N9&DN`$1E=F%M`$-O;VL@061A;&%R_0#'97)E>@!+;W!Y
M86QA`%-EYVEM:2!+;W!Y86QA`$MO<W1A(%)I:V$`0V]T92!D)TEV;VER90#=
M;&5T:2!01U`@:6QE(/YI9G)E;&5N96UE9&DN`-UL971I(%!'4"!I;&4@:6UZ
M86QA;F%M863]+@#=;&5T:2!3+TU)344@:6QE('-I9G)E;&5N96UE9&DN`-UL
M971I(%,O34E-12!I;&4@:6UZ86QA;F%M863]+@#=;&5T:?YI;2!N;VMT87/]
M(&5K;&5N96UE9&DN("5S`$Q$05`@<W5N=6-U<W5N82!B8?!L86[];&%M863]
M+@!"86MI>64@9&5N971L96YE;65D:2X@)7,`1&'P_73];2!L:7-T97-I('EA
M<F%T_6QA;6%D_2X@)7,`4$=0('9E<FES:6YI;B#^:69R97-I(.?V>OQL96UE
M9&DN`%,O34E-12!V97)I<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+@#=;&5T
M:?YI;2!N;VMT87/]('-I;&EN96UE9&DN("5S`$1A\/UT_6T@;&ES=&5S:2!S
M:6QI;F5M961I+B`E<P!!;/UC_6[];B!E;&5K=')O;FEK('!O<W1A(&%D<F5S
M:2!B96QI<FQE;F5M961I+@!!9')E<R!D969T97)I('1A;6%M96X@9V5T:7)I
M;&5M961I+@!$8?#]=/UM(&QI<W1E<VD@=&%M86UE;B!G971I<FEL96UE9&DN
M`$1A\/UT_6T@;&ES=&5L97)I;FEN(&QI<W1E<VD@=&%M86UE;B!G971I<FQE
M;65D:2X`06YA:'1A<B!S=6YU8W5S=6YD86X@8>?]:R!A;F%H=&%R(&5D:6YI
M;&5M961I+@`E<R!AY_UL86UA9/TN`$UA:6YT96YA;F-E7U1A<VL@8FER:6UI
M("5S(&'G_6QA;6%D_2X`)7,@;VMU;F%M863]+@#=<W1E;F5N(&MU;&QA;F/]
M(&GG:6X@<&%R;VQA('/]9OUR;&%N86UA9/TN($)A>OT@>6%D82!T_&T@87ER
M_6YT_6QA<B!D;_!R=2!D9?!I;"X@665N:61E;B!D96YE>6EN('EA9&$@9&%H
M82!F87IL82!Y87)D_6T@:>=I;B!S:7-T96T@>?9N971I;FEZ;&4@9_9R_/[\
M;BX`04-,(&5R:?YI;&5M961I+@!!9')E<R!D969T97)I;F4@97)I_FEL96UE
M9&DN("5S`$1A\/UT_6T@;&ES=&5S:6YE(&5R:?YI;&5M961I+B`E<P!$8?#]
M=/UM(&QI<W1E;&5R:6YE(&5R:?YI;&5M961I+B`E<P!3=6YU8W5N=6X@>65T
M96YE:VQE<FEN92!E<FG^:6QE;65D:2X`66%P_6QA;F3]<FUA(&=E<FD@9/9N
M9/QR_&QE;65D:2XN`"5S('EA</UL86YD_7)M82!K87ED961I;&5M961I+@!9
M961E:R!B:7(@>6%P_6QA;F3]<FUA(&MA>61E9&EL96UE9&DN`%EE9&5K(&)I
M<B!Y87#];&%N9/UR;6$@:V%Y9&5D:6QE;65D:3H@)7,`665D96L@>6%P_6QA
M;F3]<FUA(&1O<WEA<_T@)7,@:V%Y9&5D:6QE;65D:2X`66%P_6QA;F3]<FUA
M(&1O<WEA<_T@)7,@:V%Y9&5D:6QE;65D:2X@0G4@9'5R=6UD82P@:V]D=2!T
M96MR87(@)7,@:>=I;F4@:V%Y9&5T;65K('EA9&$@=&%K:7`@961E;B!K;V1U
M(&5L(&EL92`E<R!IYVEN92!K;W!Y86QA;6%K+"!S9>=E;F5K;&5R:6YI(&MU
M;&QA;F%B:6QI<G-I;FEZ+@!,1$%0('-U;G5C=7-U(&%R86YA;6%D_2X`W6QE
M=&G^:6T@;F]K=&%S_2!G_&YC96QL96YE;65D:2X@)7,`1&'P_73];2!L:7-T
M97-I(&?\;F-E;&QE;F5M961I+B`E<P!-;WII;&QA(&ME;F%R(.=U8G7P=2!B
M=6QU;F%M863]+B!+96YA<B#G=6)U\'5N=6X@8>?]:R!O;&1U\'5N9&%N(&5M
M:6X@;VQU;BX`4V%Y_6QM_?X@;65T:6X`W&QK90!$97)S;&5R`%EA<F%T`$)A
M\&QA;G3]('EA<F%T`%EE;FD@66%R870`06QT(&1I>FEN('EA<F%T`%EA<F%T
M_6/](-UZ:6YL97)I`$MR961I(&MA<G0@;G5M87)A<_T`2/UR=F%T:7-T86X`
M2_QB80#>=2!!;F1A:VD@6F%M86X`WG4@86YD86MI(%523`#>=2!!;F1A:VD@
M2&%V82!$=7)U;74`WG4@06YD86MI(-YA<G1L87(Z`%G\<OQR;/QK=&5K:2!S
M:71I;``E<R!E(&=I<FG^=&4@YV%L_?YA8V%K(&?V<F5V;&5R:2!K:?YI<V5L
M;&7^=&ER:6X`2V5S`-YEYVEL:2!O;&%N;&%R_2!K97,`2_UB<OUS`$MI<FEL
M("A+3TDX+5(I`$MI<FEL("A7:6YD;W=S+3$R-3$I`$MI<FEL+U5K<F%Y;F$@
M*$M/23@M52D`QV5K($-U;6AU<FEY971I`$='`$?\;FS\:P!697)I($'P86/]
M(%1A<F%Y_6/]<_T`5&%R:6@`1V5L:?X@5&%R:6AI`%1A<FEH(%-EYVEM:0!'
M_&X`2U]O;&]N=2!3:6P`07)A;/UK`$]N9&%L_6L@<V%Y_6QA<@!':7)I;G1I
M>6D@07IA;'0`UFX@=&%N_6UL_0#6;B!486[];6S](%)E;FL`UFX@5&%N_6UL
M_2!+:6UL:6L`5&%N_6UL87(`4VEL`$=R=7`@4VEL`-UZ:6X@4VEL`-UL971I
M;&5R:2!S:6P@=F4@=&5M:7IL90!(_&-R92!3:6P`2V]L;VX@4VEL`%9A<F]L
M86X@]G1E:VD@=&%S;&'P_2!S:6P`4V%T_7+]('-I;`!39>=I;&UI_B!K:6UL
M:?!I('-I;`#>=2!A;F1A:VD@:V]L;VYU('-I;`#>=2!A;F1A:VD@<V%T_7+]
M('-I;`!497-L:6T@>F%M86[]`$1A;FEM87)K80!3;W)U;G4@5&%N_6UL87G]
M;@!!Y_UK;&%M80!!>7+];G3];&%R("A!>6[]('IA;6%N9&$@2&]R9&4G=6X@
M9_QN;/QK(&1O<WEA<_UN_6X@:>=I;F1E*3H`07ER_6YT_6QA<B!Y]FYE=&EC
M:2!IYVEN(&?\;FS\:R!O;&%R86L@:V%Y9&5D:6QD:2X`1V5L:?YI;0!.96T@
M36EK=&%R_0!3;VX@<V%A='1E:VD@;F5M(&UI:W1A<OTZ(`!.96T@;6EK=&%R
M_3H@`%-O;&1A;B!S8?!A('GV;FS\`%-A\&1A;B!S;VQA('GV;FS\`$1I>FEN
M`#(T('-A871L:6L@>F%M86X@;?T@9_9S=&5R:6QS:6X_`$?V<OQN=/QL96UE
M(%-EYV5N96ML97)I`$AA=F$@=&%H;6EN:6YI(&?V<OQN=/QL92`H5$%&*0!'
M]G+\;G3\;&5M92!":>=I;6D`1/QZ96X@0FEL9&ER:6UI`$-I8G5T:0!3:6QM
M97EI;@!M86EN=&5N86YC92YP:'`@9&]S>6%S_6YA(&1O\')U9&%N(&5R:?YM
M97EI;BX`W6QK('-A=/UR(&%L86X@861L87+];OT@:>=E<FEY;W(@;74_($5V
M970@:7-E(&)U(&MU='5Y=2!S9>=I;CH`1&]M:6YI:P!$;VUI;FEK($-U;6AU
M<FEY971I`-UN9&ER`"5S(-UN9&ER`$]L=?YT=7)U;&%N('EA</UL86YD_7)M
M87G](%!(4"!B971I\&D@;VQA<F%K(&EN9&ER+@!!_F'P_2!AY_UL_7(@;&ES
M=&4`W6QAYVQA<@!%+5!O<W1A`$524@!%:W9A=&]R`$3\>F5N;&4`0FQO:R!$
M_'IE;FQE`$=R=7`@1/QZ96YL90#=>FEN($3\>F5N;&4`W7II;FQE<FD@1/QZ
M96YL90`E<R#=YVEN(-UZ:6YL97)I($3\>F5N;&4`4V7G96YE:VQE<FD@9/QZ
M96YL93H`)7,@:>=I;B!I>FEN;&5R:2!D_'IE;FQE`$7P:71I;0!-_7/]<@!%
M;"!386QV861O<@#6\&4N+BX`16T`16QE:W1R;VYI:R!0;W-T80!%;&5K=')O
M;FEK(%!O<W1A($%D<F5S:0!%;&5K=')O;FEK('!O<W1A(&%S<F5S;&5R:2!E
M_FQE_FUE;&DN`$]N87EL_2!E;&5K=')O;FEK('!O<W1A`$1U>6=U('-I;6=E
M<FQE<FD`0F_^(&EL971I+@!";_X@<V]N=><N`$)O_B!A<F%M82!T97)I;6QE
M<FD`1F]T;_!R868@1V%L97)I<VEN9&5N(&UE=&EN;&5R:6X@:>=E<FES:6YE
M(&?V<OQN=/P@96ML96UE(&5T:VEN;&7^=&ER:6QS:6X@;6D_`%-A\"!T_6L@
M:>=E<FEK(&UE;OQS_"!E=&MI;FQE_G1I<FEL<VEN(&UI/P!":71I_B!Y_6S]
M`$3\>F5N;&5Y:6-I>6D@1V5N:?YL970`4&%R;VQA;OUZ_2!S_6;]<FQA;6%K
M(&ES=&5D:?!I;FEZ9&4@<V]R=6QM86L@_'IE<F4@8FER(&?\=F5N;&EK('-O
M<G5S=2!G:7)I;BP@UG(N("=%=F-I;"!H87EV86[];OUZ_6X@863](&YE9&ER
M/R<Z`$?V<OQN=/P@861R97-I;FD@8G5R87EA(&=I<FEN`$5K=F%T;W(@1VEN
M97-I`$5R:71R90!(871A`$5L971R;VYI:R!P;W-T82!D]FYD97)M961E(&AA
M=&$N`$5S=&]N>6$`171I>6]P>6$`171N:6L`079R=7!A`$AE<B`Q-2!D86MI
M:V$`2&5R(#(@9&%K:6MA`$AE<B`S,"!S86YI>64`2&5R(#4@9&%K:6MA`$AE
M<B!':7)I_G1E`$AE<B!Y87+];2!S86%T`$AE<B!D86MI:V$`UG)N96L@9&7P
M97)L97(Z`,=A;/W^=/UR`$=E;FG^;&5T`$ME;F%R(,=U8G7P=6YU($=E;FG^
M;&5T`"<I)R!"96ML96YI>6]R`%-A9&4@:V5L:6UE('9E>6$@86S];G3](&%R
M86UA('1E<FEM:2!B96ML96YI>6]R`$=EYV5R;&EL:6L@4V]N(%1A<FEH:0#<
M<W0`UFX@06QA;B!296YG:0!!>6%R;&%R(&GG:6X@1E10('G\:VQE;65S:0!4
M97)C:6AL97)I;B!G971I;&UE<VD@8F'^87+]<_UZ+@!,1$%0('-U;G5C=7-U
M;F$@8F'P;&%N=/T@8F'^87+]<_UZ+@!334(@<W5N=6-U<W5N82!B8?!L86YT
M_2!B8?YA<OUS_7HN`"(E<R(@:V]N=6UU;F1A;B!K;W!Y86QA;6$@8F'^87+]
M<_UZ+@`B)7,B(&MO;G5M=6YA(&MO<'EA;&%M82!B8?YA<OUS_7HN`%EE;FD@
M4T%33"!B8?!L86YT_7/](&]L=?YT=7)U;&%M863]+@`B)7,B(&MO;G5M=6YA
M('1A_OUM82!B8?YA<OUS_7HN`%5Y9W5N($AA=F$`1F%L:VQA;F0@061A;&%R
M_2`H36%L=FEN82D`1F%R;V4@061A;&%R_0!/;G5L;6%Z($AA=&$Z`$9A:W,`
MWG5B870`2&ES<V5D:6QI>6]R`$AI<W-E9&EL:7EO<CH@`$AA9FEF(%-A\&%N
M86L`2&%F:68@2V%R(%-A\&%N8?#]`$%L86X@;6%T<FES:0!&:6II`$1O<WEA
M(%-A>?US_3H@)7,@9&]S>6$`1&]S>6$@4V%Y_7/].B`E<R!D;W-Y80!$;W-Y
M82!9]FYE=&EC:7-I`$1O<WEA($%D_0!$;W-Y82!S9>=I;6D`1&]S>6$@>?QK
M;&5M90!$;W-Y82!Y_&ML96UE(&1E<W1E:VQE;FUI>6]R+@!3_'IG9>=L97(`
M1FEN;&%N9&EY80#=;&L@66%R_0#=;&L@QV5Y<F5K`$]R86[]('-A8FET;&4`
MQV5V:7(`2V%Y86X`4VES`"5S(&1I>FEN:2!Y;VL`66%Z_2!296YG:0!996UE
M:P!']G+\;G3\;&5R:2!D97-T96ML96UE>65N('1A<F%Y_6/];&%R(&GG:6X`
M5&%H;6EN("A4048I`%1A:&UI;B!'_&YL97)I("A.;W0Z($=E<FD@9/9N_&QE
M8V5K;&5R(&AE;2!G_&X@:&5M(&=E8V4@;VQA<F%K(&3V;OQL96-E:SL@*6+\
M>?QK(&)I<B!S87G](&=E;FG^(&)I<B#V8F5K;&4@<V]N=>=L86YA8V%K=/UR
M*0!087)O;&%N_7K](&W]('5N='1U;G5Z/P!&;W)M;&%R`$1E>6G^`$1E>6G^
M('3\<OP`1&5Y:?YL97(`1&5Y:?YL97(@,@!&;W)U;6QA<@!9]FYL96YD:7)M
M96QE<@!#=0#'97+G979E;&5R`$9R86YS80!&<F%N<V$L($UE<G1O<&]L:71A
M;@!&<F%N<_UZ($=U>6%N87/]`$9R86YS_7H@4&]L:6YE>GEA<_T`1G)A;G/]
M>B!'_&YE>2!"]FQG97-I`$MI;61E;@!+:6UD96X`5&%M($)E=&EM;&5M90!$
M;VQU;F%Y`$'G_6L@060`1V%B;VX`1_9R_&YT_&QE<FEN(&%L_6YA8V'P_2!G
M86QE<FD`1V%L97)I.@!'86UB:7EA`"5S(%EA</UL86YD_7)M87/];OT@3VQU
M_G1U<@!/;'7^='5R=6QA;B!+;V0`1_QR8VES=&%N`$%L;6%N>6$`1V%N80!#
M96)E;&ET87+]:P!697)I;&5N($%D`$=I=`!';V5D96P`1V]O9VQE($%R86UA
M`%-I>6%H($)E>6%Z`%EU;F%N:7-T86X`675N86YC82`H25-/+3@X-3DM-RD`
M1W+V;FQA;F0`1W)E;F%D80!'<G5P(%GV;F5T:6UI`$=R=7`@:7-I;6QE<FD@
M9&]L=2!O;&UA;/UD_7(`1W)U<&QA<@!'=6%D86QU<`!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!+;VYU:R#=>FEN;&5R:0!+;VYU:R!$969T97)I`$=I;F4`
M1W5I;F4@0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A('-A=/UR9&%K:2!S
M;VX@:/QC<F5Y:2!S:6QM97EI(')E9&1E9&EY;W(N`$A434Q!<F5A(.=I>F5L
M9V5D96MI('-O;B!K;VQO;G4@<VEL;65Y:2!R961D961I>6]R+@!(5$U,07)E
M82#G:7IE;&=E9&5K:2!S;VX@<V%T_7+]('-I;&UE>6D@<F5D9&5D:7EO<BX`
M2%144"!+:6UL:6L@1&5N971I;6D@8G5L86YA;6%D_2X`2&%I=&D`2&%S:"!!
M;&=O<FET;6%S_0!(869I9B!3:7,`0F'^;/UK`$AE87)D($%D87/]('9E($UC
M1&]N86QD($%D86QA<OT`W6)R86YI8V4@*$E33RTX.#4Y+3@M22D`6?QK<V5K
M;&EK`%EA<F3];0!$_'IE;FQE>6EC:2!K=6QL87)A:R!Y87)D_6T`66%R9/UM
M8_T`66%R_6O\<F4`1&]S>6%N_6X@8F'^;&%N9_UC_3H@`%G\:W-E:P!?06YA
M<V%Y9F$`5F%T:6MA;@!!;F%S87EF80!%=B!!9')E<VD`178@5&5L969O;G4`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!"=2!M97-A
M:B!IYVEN9&4@9V7G97)S:7H@)7,@6$U,('9E<FES:2!I;&4@:V%R_OUL8?[]
M;&3].B`E<P!(;W)D92]+;VQA8CH@)7,@;F5S;F5S:2!I;&4@:6QG:6QI(&)I
M<B!I;&5T:2!B=6QU;F%M863]`$AO<F1E+TMO;&%B.B`E<R!T_'+\;F1E(&AI
MYR!B:7(@;F5S;F4@)7,@;65S86K](&GG:6YD92!Y;VLN`$AO<F1E+TMO;&%B
M.B`E<R`B)7,B(&)A_F%R_2!I;&4@<VEL:6YD:0!(;W)D92]+;VQA8CH@0OQT
M_&YL96UE(&UO=&]R=2`G9&]M>&UL)R!02%`@=7IA;G3]<_UN82!I:'1I>6'G
M(&1U>6UA:W1A9/UR`$AO<F1E+TMO;&%B.B`E<R!N97-N97-I(&GG:6X@>65N
M:2!834P@8?!A8_T@;VQU_G1U<G5L86W]>6]R`$AO<F1E+TMO;&%B.B!3:6QI
M;F5M961I("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B`E<R!T_'+\;F1E:VD@
M:_US_6T@:>=I;B!-24U%($E$(&)U;'5N86UA9/T`2&]R9&4O2V]L86(Z($7^
M;&5N96UE9&D@)7,@(B5S(CH@)7,`4&%Y;&'^_6UL87(@9?YL96YE;65D:3H@
M)7,`0FEL:6YM97EE;B!P87EL8?[];2`B)7,B`%EA=&%Y(,=I>F=I`%EA=&%Y
M('EA<W3]:VQA;6$`66%T87DZ`$)U<F%Y82!N87/];"!G96QD:6YI>C\@*$S\
M=&9E;B!R87!O<B!E9&EN(2D`2V'G(&%D970@:V]L;VYU(&)I<FQE_G1I<FUE
M:R!I<W1I>6]R<W5N=7H_`$MAYR!A;&%N("AK;VQO;BD@=F%R/P!+8><@861E
M="!S873]<OT@8FER;&7^=&ER;65K(&ES=&EY;W)S=6YU>C\`3F5M`$YE;3H@
M`$UI>F%HY_UL87(`36%C87)I<W1A;@!)34%0('!O<W1A(&MU='5S=2!O;'7^
M='5R=6QA;6%D_3H@)7,`24U!4"!P;W-T82!K=71U<W4@<VEL:6YE;65D:3H@
M)7,`24U!4"!P;W-T82!K=71U<W4@:V]T87/](&]L=?YT=7)U;&%M863].B`E
M<P!)4"!!9')E<VD`25`@861R97-I(&UE=F-U="!D9?!I;"X@`$E0($%D<F5S
M:2!I>FEN('9E<FEL96X@0TE$4B!B;&_P=2!IYVEN9&4@9&7P:6PN`$E0(&MI
M;&ET;&5M92!I:&QA;&DN`-9N7V-E>64@4V%T_7(@665R;&7^=&ER`-UZ;&%N
M9&$`4V%D96-E(%-I;6=E;&5R`"5S(&GG:6X@<VEM9V5L97(`365T:6X@:6QE
M(&)I<FQI:W1E('-I;6=E;&5R`$MI;6QI\&EN(&%D_3H`1?!E<B!D;_!R=2!G
M]G+\;G3\;&5N96UI>6]R<V$L('EE;FD@<&5N8V5R961E(&'G;6%K(&GG:6X@
M=/UK;&%Y_6X@)7,N`$7P97(@26YT97)N970@17AP;&]R97(@:6QE('-I;6=E
M;&5R:2!G]G)E;6EY;W)S86[]>B!B=2!K=71U>74@<V7G97)E:R!03D<@<V%Y
M9&%M;/WP_6[](&MA<&%T;6%N_7H@9V5R96MI<BX`1_9R_&YT_&QE<FD@9_9R
M96UI>6]R(&9A:V%T(&)U(&UE<V%J_2!G]G)E8FEL:7)Y;W)S86[]>BP@>?QK
M;&5M96L@:7-T961I\&EN:7H@9_9R_&YT_"!T87)A>?UC_6[]>B!T87)A9OUN
M9&%N(&?V<W1E<FEL96UE;65K=&5D:7(N`$?V<OQN=/P@UFYI>FQE;64`1_9R
M_&YT_"!54DP`1_9R_&YT_"!54DPZ`%-E<F=I9&5N(&?V<OQN=/P`4V5R9VED
M96X@9_9R_&YT_#H`1_9R_&YT_"!Y_&ML96UE:P!']G+\;G3\;&5R`-WG97)I
M($%K=&%R+"!!9/UM("5D`-WG97)I(&%K=&%R_6QA;B!A;&%N.B`E<P#=YV5R
M:2!A:W1A<OUL86X@86QA;FQA<CH`4V]N7W)A>6$@4V%T_7(@16ML90!986YL
M_?X@97EL96T@:V]D=2!G:7)I;&1I+@!986YL_?X@:W5L;&%N_6/](&%D_2!V
M92]V97EA('!A<F]L82X`66%N;/W^(&MU;&QA;OUC_2!A9/T@=F5Y82#V=&5K
M:2!A9')E<RY996YI9&5N(&1E;F5Y:6X@=F5Y82!D86AA(&9A>FQA('EA<F3]
M;2!IYVEN('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BX`1VER:6YT:7EI($%R='3]
M<@!(:6YD:7-T86X`0FER97ES96P@2W5L;&%N_6/];&%R`$5N9&]N97IY80!"
M:6QG:0!":6QG:0!3;VYR87EA($MO7VQO;B!%:VQE`$?V<OQN=/P@665R;&7^
M=&ER`,=I>F5L9V4@665R;&7^=&ER`%=E8B!"8?!L86YT_7/](%EE<FQE_G1I
M<@#6;F-E>64@2V]L;U]N($5K;&4`665N:2!K;VQO;G4@_G4@86YD86MI(&MO
M;&]N9&%N('-O;G)A('EE<FQE_G1I<@!996YI(&MO;&]N=2#^=2!A;F1A:VD@
M:V]L;VYD86X@]FYC97EE('EE<FQE_G1I<@!996YI('-A=/UR_2#^=2!A;F1A
M:VD@<V%T_7)D86X@<V]N<F%Y82!Y97)L9?YT:7(`665N:2!S873]<OT@_G4@
M86YD86MI('-A=/UR9&%N(/9N8V5Y92!Y97)L9?YT:7(`665N:2!P87)A9W)A
M9OT@_G4@86YD86MI(&3\\/QM9&5N('-O;G)A>6$@>65R;&7^=&ER`%EE;FD@
M<&%R86=R86;](/YU(&%N9&%K:2!D_/#\;61E;B#V;F-E>64@>65R;&7^=&ER
M`-9T96MI('1A<VQA:R!Y97)L9?YT:7(`665N:2!B:7(@<&%R86QO>?T@86QA
M8FEL96-E\&EN:7H@8FER(&5L96MT<F]N:6L@<&]S=&$@861R97-I(&=I<FEN
M.@!(_&-R97EI('-O;G)A<_UN82!Y97)L9?YT:7(`2/QC<F5Y:2#V;F-E<VEN
M92!Y97)L9?YT:7(`2V]L;VYU('-O;G)A<_UN82!Y97)L9?YT:7(`2V]L;VYU
M(/9N8V5S:6YE('EE<FQE_G1I<@!-97-A:B!G:7(`4&%R86=R86;]('-O;G)A
M<_UN82!Y97)L9?YT:7(`4&%R86=R86;](/9N8V5S:6YE('EE<FQE_G1I<@!3
M873]<OT@<V]N<F%S_6YA('EE<FQE_G1I<@!3873]<OT@]FYC97-I;F4@>65R
M;&7^=&ER`$?\=F5N;&EK('-O<G5S=6YU;B!C979A8OTZ`$?V<OQN=/QY_"!9
M97)L9?YT:7(O1&7P:?YT:7(`0F'P;&%N=/T@665R;&7^=&ER+T1E\&G^=&ER
M`$1A\/UT_6T@;&ES=&5S:2!G]FYD97)M96L@:>=I;B!Y971E<G-I>B!K<F5D
M:2X`665T97)S:7H@:W)E9&D`5&%M<V%Y_0!486US87G](&QI<W1E<VD`1V7G
M97)S:7H@541(+B`H2W5L;&%N_6/](%9E<FD@0F'^;/UK($)I;&=I<VDI`$=E
MYV5R<VEZ('5Y9W5L86UA+@!'9>=E<G-I>B!Y_?#];B!K:6UL:?!I+@!'9>=E
M<G-I>B!V97)I(&?V;F1E<FEL9&DN`$=EYV5R<VEZ('1E<VQI;2!A9')E<VD`
M1V7G97)S:7H@9&]S>6$@8FGG:6UI`$=EYV5R<VEZ(&US9U]T>7!E`$=EYV5R
M<VEZ('EA9&$@871L86YM_?X@87!I7VED`$=EYV5R<VEZ('EA9&$@871L86YM
M_?X@9&7P:?YT:7)G96QE<@!'9>=E<G-I>B#\<W0@:7II;BX`1V7G97)S:7H@
M:6QE=&G^:6T@:W5R86QL87+]`$=EYV5R<VEZ('!A>6QA_OUL86X@;F5S;F4`
M1V7G97)S:7H@:V%Y;F%K(&%D<F5S:2X`1V7G97)S:7H@=6YI8V]D92!V97)I
M<VDN`%-T;VL`W7)A;B#=<VQA;2!#=6UH=7)I>65T:0!)<F%K`-UR;&%N9&$`
M36%N($%D82!$979L971I`%EA;/UT_6QM_?X@9_9K(&?\<OQL=/QL_"!F_7)T
M_6YA`-US<F%I;`#'_6MA<F%N`-UT86QI:P#==&%L>6$`2F%M86EK80!/8V%K
M`$IA<&]N>6$`2F%P;VYC82`H25-/+3(P,C(M2E`I`$IE<G-E>0#<<F3\;@!4
M96UM=7H`2&%Z:7)A;@!987-L80!/<G1A>6$@66%S;&$`5&%M86UE;B!987-L
M80!3;VQA(%EA<VQA`%-A\&$@66%S;&$`2V%Z86MI<W1A;@#6>F?\;B!O;&%N
M('-A:VQA;G/];B!M_3\`2V5N>6$`2V5R8F5R;W,@<W5N=6-U(&1O\')U;&%M
M87G](')E9&1E='1I+@#'96MI<F1E:R!!8V5M:6QE<FD`06YA:'1A<B!987)A
M=`!!;F%H=&%R(%!A<FUA:VEZ:0!!;F%H=&%R(%5Z=6YL=?!U`$%N86AT87(@
M5&EP:0!!;F%H=&%R($MU;&QA;OUM_0!!Y_UK(&%N86AT87(@<W5N=6-U<W5N
M9&$@86YA:'1A<B!Z871E;B!V87(N`,=O8W5K;&%R`$MI<FEB871I`$MU>F5Y
M($MO<F4`1_QN97D@2V]R90!+;W)E8V4@*&5U8RU+4BD`2W5V97ET`$O]<F?]
M>FES=&%N`%-A>69A(%]$_'IE;FD`1&EL`$QA;R!$96UO:W)A=&EC($AA;&L@
M0W5M:'5R:7EE=&D`4V]N($3V<F3\;@#>:?YK:6X@07D`4V]N($?\;F-E;&QE
M;64Z`%-O;B!':7)I_CH@)7,`4V]N($=I<FG^.B`E<R#\>F5R:6YD96X@)7,`
M4V]N($=I<FG^.B!!<VQA`$QE=&]N>6$`66%S80!$_'IE;@!(:>=B:7(@<_UN
M_7(@:>=I;B!B;_X@8OUR86MM80!,_&)N86X`4V]L`%-O;"!B8?YL_6L@8FEL
M9VES:0!3;VQD86MI(&1E\&5R;&5R`$QE<V]T:&\`3&EB97)Y80!,:6)Y80!,
M:65C:'1E;G-T96EN`,=I<V5L:7EO<@!(869I9B!98?!M=7(`17)K96X@4V%A
M=&QE<F1E($AA9FEF(%EA\&UU<@!'9><@4V%A=&QE<F1E($AA9FEF(%EA\&UU
M<@!(869I9B!98?!M=7(@4V'P86YA\/T`1_9K(&?\<OQL=/QL_"!H869I9B!Y
M8?!M=7(`2&%F:68@2V%R`$AA9FEF($MA<B!38?!A;F'P_0!._&MT96QI(-YI
M:7(`0F'P;&%N=/T`0F'P;&%N=/T@;F]K=&%S_3H`1_9R_&YT_&QE<FME;B!E
M;&5K=')O;FEK('!O<W1A(&%D<F5S:6YI(&]L=?YT=7)M82!S87EF87/];F$@
M8F'P;&$`0F'P;&%N=/UL87(`3&EN=7@@QV5R97II`$QI<W1E;&4@+2!K=6QL
M86[]8_T@9&EZ:6YI(&?V<F5B:6QI<@!697)I(%1A8F%N;&%R_6[]($QI<W1E
M;&4`66%R9/UM($MO;G5L87+];OT@3&ES=&5L90#':7IE;&=E;&5R:2!,:7-T
M96QE`$QI<W1E;&4M07+^:78`3&ES=&5L92U987)D_6T`3&ES=&5L92U)9`!,
M:7-T96QE+5-A:&EP`$QI<W1E;&4M1_9N9&5R:6QM:?X@UO!E;&5R`$QI<W1E
M;&4M4_QR9/QR_&UC_&QE<@!,:7-T96QE+5/\<F3\<OQM8_P@3VQM87EA;FQA
M<@!+=6QL86[]8_T@;&ES=&5L96UE('-EYVEL96UE>B!K_6S];F3]+@!%9&5B
M:7EA=`!,:71V86YY80!9_&ML96YI>6]R+BXN`%EE<F5L('IA;6%N.@!997(@
M=F4@6F%M86X`665R`$=I<FG^`,?]:_W^`$=I<FG^($?V<F5V;&5R:0!+=6QL
M86[]8_T@863]('9E>6$@<&]R;VQA(&1O\')U(&]L;6%D_?#](&GG:6X@9VER
M:?X@8F'^87+]<_UZ(&]L9'4N`$=I<FG^(&)A_F%R_7/]>B!O;&1U+@!5>G5N
M(&UE=&EN`$'^:P!$_/[\:P!+_.?\:R!Y=6YA;B!H87)F;&5R:0!+_.?\:R!L
M871I;B!H87)F;&5R:0!+_.?\:R!R;VUA(')A:V%M;&%R_0!,_&MS96UB=7)G
M`$%!`$U/5$0`35,M5$Y%1B!%:VD@=F5R:2!IYV5R;65M96MT961I<BX`35-'
M`$UA8V%O`$UA:V5D;VYY80!-861A9V%S:V%R`$+\>?P`4&]S=&$`4&]S=&$@
M6?9N971I8VES:0!"8?!L85]N=/T@66%R870N+BX`36%L879I`$UA;&5Z>6$`
M36%L9&EV;&5R`$UA;&D`36%L=&$`UO!E;&5R:2!E=&EK971L97EE8V7P:6YI
M>B!K871E9V]R:2!L:7-T97-I;FD@=F4@:V%T96=O<FEL97)I(&EL:?YK:6QE
M;F1I<F5C9?!I;FEZ(')E;FML97)I('GV;F5T:6XN`$UA<#(T(&AA<FET87/]
M`$UA<%%U97-T(&AA<FET87/]`$UA<G0`2V5N87(@8F_^;'7P=0!/:W5N;77^
M+T]K=6YM86W]_B!O;&%R86L@:?YA<F5T;&4`1&GP97(@:6QE=&D@:?YA<F5T
M;&5R:7EL92!I_F%R971L92`H]G)N96LZ(-9N96UL:2]#979A<&QA;FW]_BD@
M`$UA<G-H86QL($%D86QA<OT`36%R=&EN:6L`1?YL96QE;B!A;&%N;&%R`$UO
M<FET86YY80!-875R:71U<P#=>FEN('9E<FEL96X@96X@>?QK<V5K(&MR961I
M+@!%;B!Y_&MS96L@;65S86H@<&%RYV%S_2!S87G]<_T@8?[];&3]+@!3;VX@
M,C0@<V%A='1E:VD@96X@>?QK<V5K('/]8V%K;/UK.B``4V]N(#8@<V%A='1E
M:VD@96X@>?QK<V5K('/]8V%K;/UK.B``16X@>?QK<V5K('5Z=6YL=6L`36%Y
M_7,`36%Y;W1T90!4_7``W'EE;&5R`$UE;OP@2VEP:3H`2/QC<F5L97)I(&)I
M<FQE_G1I<@#=;&5T:0#=;&5R:2!B8?YA<OUY;&$@9&_P<G5L86YD_2!A;6$@
M:6UZ86QA>?UC_6[];B!O;F%Y(&)E;&=E<VD@9&_P<G5L86YA;6%D_2X`365S
M86K];B!S_')E<VD@8FET=&DN`$UE<V%J('1I<&D`2&%V82!287!O<G4`2&%V
M82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN`$AA=F$@<F%P
M;W)U(/9B9?!I(&MU;&QA;OUL86)I;&ER(&1E\&EL+B!!>7+];G3];&%R('GV
M;F5T:6-I(&GG:6X@9_QN;/QK;&5N9&D`6?9N=&5M`$UE=')I:P!-96MS:6MA
M`$UI:W)O;F5S>6$`3W)T80!-:6UE(%3\<OP`4V]N(#(T('-A871T96MI(&5N
M(&3\_OQK('/]8V%K;/UK.B``4V]N(#8@<V%A='1E:VD@96X@9/S^_&L@<_UC
M86ML_6LZ(`!986YS_0!-=6AT96QI9@!"=6QU;F%M87EA;B!014%2('!A:V5T
M:3H@2%144%]297%U97-T+@!!=&QA;FW]_B!Y87#];&%N9/UR;6$N($)U('5Y
M9W5L86UA>?T@:W5L;&%N;6%K(&ES=&EY;W)S86[]>B!Y87#];&%N9/UR;6%Y
M_2#\<F5T;65K('IO<G5N9&%S_6[]>BX`071L86YM_?X@;65S86H@240N`$%T
M;&%N;?W^(&]L86X@9V5R96ML:2!014%2('!A:V5T:2!-86EL+@!!=&QA;FW]
M_B!O='5R=6UA(&%I="!)1"X`4'IT`$=E>FEC:2!0;W-T80!386MI;@!$9?!I
M_FEM(%1A<FEH:0!$9?!I_G1I<CI54DP`36]D(%1A8F%N_0!-;VQD;W9Y80!-
M;VYA8V\`36_P;VQI<W1A;@!!>2!V92!Y_6P`07EL_6L`36]N='-E<G)A=`!!
M>2!%=G)E;&5R:0!&87,`1V5N96QL:6ML92!!Y_UK`$=E;F5L;&EK;&4@0G5L
M=71L=0!'96YE;&QI:VQE($?\;F7^;&D`0?YA\/T@5&'^_0!3;VQA(%1A_OT`
M4V'P82!48?[]`%EU:V%R_2!48?[]`$'^8?#]('1A_OT`675K87+]('1A_OT`
M36]Z86UB:6L`QV]K;'4@9/QZ97D@8?YA\/T@8>?];/UR(&QI<W1E;&5R`,=O
M:VQU(%-EYVEM`$AE<V%B_6T`4&]R=&%L_6T`4&]R=&%L($3\>F5N:6T`37EA
M;FUA<@!+86)U;"!%5$U)64]254T`060`3F%M:6)Y80!.875R=0!.97!A;`!(
M;VQL86YD80!(;VQL86YD82!!;G1I;&QE<FD`3F5T<V-A<&4@5&%B86X@55),
M`$YE='-C87!E($-!(-UP=&%L(%523`!.971S8V%P92!#02!K=7)A;"!54DP`
M3F5T<V-A<&4@665N:6QE;64@4DP`3F5T<V-A<&4@W7!T86P@55),`$YE='-C
M87!E(%-33"!S=6YU8W4@863]`$YE='-C87!E(&]N87D@8F5L9V5S:2!AY_UK
M;&%M87/]`$YE='-C87!E(&]N87D@8F5L9V5S:2!T_'+\`$'P`$%S;&$`665N
M:2!+86QE9&]N>6$`665N:2!+871E9V]R:0!996YI($%Y`%EE;FD@2W5L;&%N
M_6/]($%D_2`H4V7G:6UL:2D`665N:2!:96QL86YD80!996YI(%!E;F-E<F4@
M*%]B;_XI`$AA8F5R;&5R`$AA8F5R($=R=7!L87+]`%-O;G)A:VD`4V]N<F%K
M:2!39>=E;F5K;&5R`$YI:V%R86=U80!.:6IE<GEA`$YI:F5R>6$`1V5C90!.
M:75E`$AA>?UR`$9A<FML87+];B!G]G-T97)I;&5B:6QE8V7P:2!K=6QL86[]
M;&%B:6QI<B!Y87#];&%N9/UR;6$@=F5R:7-I('EO:RX`25-/(&EM86IL87+]
M(&]U_G1U<FUA:R!IYVEN(&MU;&QA;OUL86)I;&ER(&)I<B!Y]FYT96T@>6]K
M+@!9_?#];B!T87-L8?#]('EO:RX`W7-T96YE;B!K;VYU;61A(&AIYV)I<B#V
M8F5K(&)U;'5N;6%M86MT863]<@!-0T%,(&1O\')U;&%M87/](&GG:6X@:&GG
M8FER('1A:W9I;2!A9/T@<V'P;&%N;6%M_?YT_7(N(`!$9?!I_FEK;&EK(%EO
M:P!"=2!I>FYE(&AIYV)I<B!A;'0@:7II;B!E:VQE;F5M97EE8V5K=&ER+@`E
M<R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE
M9&DN`$944"!61E,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@
M8F5L:7)T:6QM961I+@!344P@5D93(&GG:6X@:&GG8FER('EA</UL86YD_7)M
M82!B:6QG:7-I(&)E;&ER=&EL;65D:2X`4U%,+49I;&4@5D93(&GG:6X@:&GG
M8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER=&EL;65D:2X`2W)E9&D@
M>6]K+@!(:>=B:7(@=&5S;&EM(&YO:W1A<_T@8F5L:7)T:6QM96UI_G1I<BX`
M2&GG8FER(&1O<WEA('G\:VQE;F5M961I`$AIYV)I<B!S:6UG92!B=6QU;F%M
M863]+@!(:>=B:7(@>65R(&)E;&ER=&EL;65D:2X`2&GG8FER(&UE<V%J('-A
M\&QA;FUA9/TN`$%D(&)E;&ER=&EL;65D:2X`3G5M87)A(&)E;&ER=&EL;65D
M:2X`4V%L9/UR9V%N(&1E>6G^(&MU;&QA;FUA`$A45%`@9&_P<G5L86UA<_T@
M:>=I;B!P87)O;&$@9VER:6QM961I+@!)34%0(&1O\')U;&%M87/](&GG:6X@
M<&%R;VQA(&=I<FEL;65D:2X`2V5R8F5R;W,@9&_P<G5L86UA<_T@:>=I;B!P
M87)O;&$@9VER:6QM961I+@!,;V=I;B!D;_!R=6QA;6%S_2!IYVEN('!A<F]L
M82!G:7)I;&UE9&DN`%!!4U-71"!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G
M:7)I;&UE9&DN`%--0B!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G:7)I;&UE
M9&DN`$]P96Y34TP@:6MI;&ES:6YE(&AIYV)I<B!Y;VP@8G5L=6YA;6%D_2Y/
M<&5N4U-,(&EK:6QI<VD@4$M#4R`Q,B!V97)I<VEY;&4@8V%L_?YM86L@:>=I
M;B!G97)E:VQI+@#<>64@;VQM86L@:>=I;B!B96ML97EE;B!Y;VLN`$MU<F%L
M('EO:P!986X@>6]K`-9N8F5L;&5K(&GG:6X@9V7G:6-I(&1I>FEN(&)U;'5N
M86UA9/TN`$MU;&QA;OUC_2!A9/T@=F4O=F5Y82!P87)O;&$@9_9N9&5R:6QM
M961I+@!'9>=E<FQI(%A-3"!V97)I<VD@9V5R:2!D]FYM961I+@!$9?!E<B!Y
M;VL`UGIG_&X@>6%P_6QA;F3]<FUA9&$@<_QR_&T@8G5L=6YA;6%D_2Y987#]
M;&%N9/UR;6%Y_2!T96MR87(@_')E=&EN+@#6>F?\;B!Y87#];&%N9/UR;6%N
M_7ID82!S_'+\;2!B=6QU;F%M863]+EEA</UL86YD_7)M87G]('1E:W)A<B#\
M<F5T:6XN`$AIYV)I<FD`2&GG8FER:2`HUG)T_&S\(&MU;&QA;OUN*0!+=7IE
M>2!!=G)U<&%L_2`H25-/+3@X-3DM,3`I`$YO<F9O;&L@061A<_T`2W5Z97D@
M66%R_6UK_')E`$MU>F5Y($UA<FEA;F$@061A;&%R_0!.;W)V9><`4V]N<F%S
M_6YD82!$9?!I;`#6;F-E<VEN9&4@1&7P:6P`1&EZ:6X@9&7P:6P`1V5RYV5K
M;&7^=&ER:6QM96UI_@!"96QI<G1I;&UE;6G^`$1E<W1E:VQE;FUI>6]R+@!.
M;W1L87(`1_9Z(&%T_6QA8V%K(&)I<OYE>2!Y;VLL(&=E<FD@9/9N_&XN`$MA
M<_UM`%-A>?T`2V%R86MT97(@<V%Y_7/]`$MO;&]N('-A>?US_0!3873]<B!S
M87G]<_T`1&'P_73];2!L:7-T96QE<FEN:6X@9_QN8V5L;&5N;65S:2!IYVEN
M(&YU;6%R86QA<B!B96QI<G1I;&UE;6G^+@!%=F5T`$YE<VYE`$YE<VYE(%EA
M<F%T_6/]<_T`4V5K:7IL:6L@4VES=&5M`$5K:6T`4V%L9/UR9V%N;/UK('/\
M>F=E8VD`3V9I<P!5;6UA;@!3861E8V4@24U!4"!S=6YU8W5L87+]('!A>6QA
M_OUL86X@9&EZ:6YL97)I(&1E<W1E:VQE;65K=&5D:7(N`%-A9&5C92!S86QD
M_7)G86X@9&5Y:?YL97(`4V%D96-E(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D
M<F5S:6YE(&EZ:6X@=F5R:6QM96MT961I<BX`0FER('!A>6QA_OUM_6X@<V%H
M:7!L:?!I;FD@=F5Y82!S86AI8FEN:2!S861E8V4@<VES>65M('GV;F5T:6-I
M<VD@=F5Y82!S86AI8FD@9&7P:?YT:7)E8FEL:7(N`%EE;FD@<&5N8V5R961E
M(&'G`$]P96Y34TP@:&%T87/].MUM>F%L86YM_?X@4R]-24U%('!A<N=A<_UN
M9&%N('9E<FD@<V7G:7`@Y_UK873];&%M863]+@!"=2!B8?!L86YT_7G]('EE
M;FD@<&5N8V5R961E(&'G`-W^;&5T:6T@4VES=&5M:0!39>=E;F5K;&5R`"5S
M(&GG:6X@<V7G96YE:VQE<@!3_7)A;&%N;?W^($QI<W1E`$MU<G5L=?X`2W5R
M=6US86P@0FER:6T`1/QZ96YL96UE`-9Z9_QN('5Y9W5L86UA('1A<VQA\/T`
M)7,@:>=I;F1E:VD@]GIG_&X@=&%S;&%K;&%R.@!$:?!E<@!$:?!E<B!":6QG
M:6QE<@!386AI<"!I>FEN;&5R:0!004T@9&_P<G5L86UA<_T@;65V8W5T(&1E
M\&EL+@!01U`@4V%Y_7-A;"#=;7IA`%!'4"#>:69R96QE;FUI_B!697)I`%!'
M4"!!Y_UK($%N86AT87+]`%!'4"!I;&4@W6UZ86QA;FW]_B_>:69R96QE;FUI
M_B!697)I`%!(4"!+;V1U`%!(4"!+86)U\'4`UE,@2&%F:68@66'P;75R`-93
M(%-A\&%N86ML87+]`-93($MA<@#64R!+87(@4V'P86YA:VQA<OT`UE,@1_9K
M(&?\<OQL=/QL_"!F_7)T_6YA`%!?2%`@2V%B=?!U`%EA<W3]:VQA;6$`4&%K
M:7-T86X`4&%L874`W?YG86P@161I;&UI_B!&:6QI<W1I;B!"]FQG97-I`%!A
M;F%M80!087!U82!996YI($=I;F4`4&%R86=U87D`2_US;65N($)U;'5T;'4`
M4&%R;VQA`%EA;FS]_B!P87)O;&$`4D%$2553(&1O\')U;&%M87/](&GG:6X@
M<&%R;VQA(&=E<F5K;65K=&5D:7(N`$]N87EL_2!087)O;&$`4&%R;VQA.@!0
M87)O;&$Z`%!A<F]L86QA<B!E_FQE_FUE:R!Z;W)U;F1A9/UR+@!987#]_G3]
M<@!086YO9&%N('EA</W^=/UR`%EO;`!"96ML97EE;B#<>65L:6ML97(Z`-UN
M<V%N;&%R`%G\>F1E`$)A:_UM(-W^;&5M;&5R:6YI($=E<N=E:VQE_G1I<@!"
M86O];2!I_FQE;6QE<FD@9VER:?YT92!G97+G96ML9?YT:7)I;'-I;B!M:3\`
MW7II;@#=>FEN(%GV;F5T:6UI`$MI_FES96P@0FEL9VEL97(`4&5R=0!%=F-I
M;"!(87EV86YL87(`1FEL:7!I;FQE<@!496QE9F]N`$9O=&_P<F%F;&%R`%!I
M=&-A:7)N`%)E<VEM($)I<FEM:0!"97EL:6L@4_9Z;&5R`$S\=&9E;B!B:7)K
M8><@:/QC<F5Y92!T_6ML87G];@!,_'1F96X@8G4@]O!E>6D@Y_UK87)M86L@
M:7-T961I\&EN:7II(&1O\')U;&%Y_6XZ`$S\=&9E;B!B=2#V\&5N:6X@8F'P
M_6[](.?V>FUE:R!I<W1E9&GP:6YI>B!D;_!R=6QA>?UN+@!,_'1F96X@8FER
M(&%Y('9E(&)I<B!Y_6P@9VER:6XN`$S\=&9E;B!Y96YI(&MA=&5G;W)I;FEN
M(&%D_6[](&=I<FEN.@!,_'1F96X@9V7G97)L:2!B:7(@25`@861R97-I(&=I
M<FEN+@!,_'1F96X@9V7G97)L:2!B:7(@9_QN(&=I<FEN+"!A>61A:VD@9_QN
M('-A>?US_6[](&MO;G1R;VP@961I;BX`3/QT9F5N(&=EYV5R;&D@8FER('IA
M;6%N(&=I<FEN+@!,_'1F96X@<V]R=6YU;B!B:7(@]GIE=&EN:2!Y87#];BX`
M3/QT9F5N(&MU;&QA;OUC_2!A9/T@=F4@<&%R;VQA;OUZ_2!G:7)I;@!,_'1F
M96X@>65N:2!K871E9V]R:6YI(&%D_2!G:7)I;CH`4&]L;VYY80!0;VQI=&EK
M80!/>6QA;6%L87(`4&]R=&5K:7H`1_9R_&YT_"!K;VYU;6QA;F3]<OUL_7EO
M<@#':7IE;&=E(&MO;G5M;&%N9/UR_6S]>6]R`$)U(&1I>FEN92!G]FYD97(@
M*$E-05`@=&%R86;];F1A;B!Z;W)L86YM86UA:W1A9/UR*0!3;VX@)7,@<V%A
M='1E(&3\_F5N('EA\&UU<B!V92!K87(@;6EK=&%R_3H`4')E9G-?;&1A<#H@
MW7-T96YE;B!,1$%0('5Z86YT_7/](&)U;'5N86UA9/TN`%!R969S7W-E<W-I
M;VXZ(-US=&5N96X@;W1U<G5M('5Z86YT_7/](&)U;'5N86UA9/TN`$)A<_UN
MYP!$96YI>B!S979I>65S:6YD96MI(&)A<_UNYSH`0F%S_6[G.@#6;FEZ;&5M
M90!']G+\;G3\>?P@>65N:2!P96YC97)E9&4@]FYI>FQE`-9N8V5K:2!S9>=E
M;F5K;&5R`$)E;&=E>6D@>6%Z9/UR`-9Z96P@06YA:'1A<@!3;W)U;@!3;W)U
M;B!486[];6QA;6%S_0!0<F]J96QE<@!-971I;B!B:6QG:2!I<W1E;6D`0>?]
M:R!!;F%H=&%R`$'G_6L@06YA:'1A<B!A;&=O<FET;6%S_0!!Y_UK+]9Z96P@
M86YA:'1A<B!I:VEL:7-I(&)A_F%R_7EL82!Y87)A=/UL86UA9/TN`%!O<G1O
M(%)I:V\`2V%T87(`4V]R9W4`4E-!($'G_6L@06YA:'1A<OT@*"5D(&)I="D`
M4F%D>6\@4V7G:6UI`%EA\&UU<@!%<FME;B!386%T;&5R9&4@66'P;75R`$=E
MYR!386%T;&5R9&4@66'P;75R`%-A\&%N86L@66'P_?X`66'P;75R('9E($MA
M<@!+87)A(&3V;OS^96-E:R!Y8?!M=7(`4F%S=&=E;&4@1&5Y:?X`3W)A;@!/
M:W5M80#=;&5T:6QE<FD@3VMU`%-I;&UE:R!I<W1E9&GP:6YI>F4@9V5RYV5K
M=&5N(&5M:6X@;6ES:6YI>C\H0G4@:?YL96T@9V5R:2#G979R:6QE;65Z*3HE
M<P!+=6QL86[]8_T@)7,@92!A:70@:W5L;&%N_6/]('9E<FEL97)I;FD@<VEL
M;65K(&ES=&5D:?!I;FEZ92!E;6EN(&UI<VEN:7HN($)U(&G^;&5M(&=E<FD@
MYV5V<FEL96UE>BX`4V]N(&5Y;&5M:2!T96MR87)L80!$979I;F=E;B!-96[\
M(-;P96QE<FEN:2!487IE;&4Z`%!O<G1A;"!']G+\;OQM_&[\(%1A>F5L93H`
M1/QZ96YL:2#=9F%D90#=;&G^:VD@5&%R87G]8_T`0>?]:VQA;6%L87(`57IA
M:W1A:VD@4W5N=6-U;&%R`%5Z86MT86MI(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%-I;`#68F7P:2!3:6P`2V]L;VYU(%-I;`!":>=I
M;6QE;65Y:2!3:6P`26MI;&EY:2!3:6P`2V%Y9&5D:6QM:?X@8F5T:?!I('-U
M;G5C=6YU(&=EYVEC:2!D:7II;FEN9&5N('-I;"X`4VEL`$)U('!A<N=A>?T@
M8F5L9V5D96X@Y_UK87)T`$MU;&QA;OUC_2!3:6P`2W5L;&%N_6/]>?T@<VEL
M.B`E<P#=<W1E:R!C979A<&QA;F%M863]+D3V;OQL96X@:&%T82!K;V1U.B``
M1V5R96ME;B!!;&%N`%1E;6EZ;&4`4&%R;VQA>?T@<_UF_7)L80!087)O;&%N
M_7K]('/]9OUR;&%Y_6X`4V]N=>=L87(`4V7G96YE:VQE<F4@1/9N_&X`4F5U
M;FEO;@!987#];&%N9/UR;6%Y_2!'97)I($3V;F3\<@!:96YG:6X@365T:6X@
M1/QZ96YL97EI8VES:2!39>=E;F5K;&5R:0!":6QM96-E;&5R`%-A\`!38?`@
M8F'^;/UK(&)I;&=I<VD`1&_P<G4@9&7P97)L97(`4V%?=/UR(-9Z96QL:6ML
M97)I+BXN`$?V<F5V`%)O;6%N>6$`,3@P(&1E<F5C92!D]FYD_'(`4V]L82!$
M]FYD_'(`4V'P82!$]FYD_'(`4V%T_7(@UGIE;&QI:VQE<FD`4V%T_7(@]GIE
M;&QI:VQE<FD`4V%T_7)L87(Z`,=I>F=I;&5R`,=I>F=I;&5R('3\;2!S873]
M<B!V92!K;VQO;FQA<B!A<F%S_6YD82!B96QI<F5C96MT:7(`QVEZ9VEL97(@
M<V%D96-E(&MO;&]N;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<@#':7IG:6QE
M<B!S861E8V4@<V%T_7)L87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER`,=A;/W^
M=/UR`%)U<WEA($9E9&5R87-Y;VYU`%)U86YD80!3+TU)344@WFEF<F5L96UE
M(-UM>F%S_0!3+TU)344@:6QE(-YI9G)E;&5N;6G^(-UL971I`%-!4TP@9&_P
M<G5L86UA<_T@;65V8W5T(&1E\&EL+@!335,@365S86IL8?YM80!344P@2V%B
M=?!U`%-32`!"0=Y!4DE,20!37U%,($MA8G7P=0!#=',`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S('9E($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!V92!-:7%U96QO;@!386EN="!6:6YC96YT('9E($=R96YA9&EN97,`07EN
M_2#G97+G979E("AK96Y?9&ES:2D`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M
M92!V92!0<FEN8VEP90!5>61U(%-A\&QA>?UC_0!3=75D:2!!<F%B:7-T86X`
M2V%Y9&5T`$MA>61E="`E<P!39>=E;F5K;&5R:2!+87ED970`3VQU_G1U<G5L
M86X@>6%P_6QA;F3]<FUA>?T@4$A0(&)E=&GP:2!O;&%R86L@<W5N=6-U;G5N
M(&=EYVEC:2!D:7II;FEN92!K87ED970N`"5S('EA</UL86YD_7)M87/](&MA
M>61E9&EL9&DN`$)I;&EM`$%R86UA`$%R86UA($UO=&]R;&%R_0!$;W-Y86QA
M<OT@4V7G`$)I<B!T87)I:"!S9>=I;@!%:VQE;65K(&GG:6X@8FER(&=R=7`@
M<V7G:6X`665N:2!S86AI8FD@<V7G:6X`0FER('-U;G5C=2!S9>=I;@!%:VQE
M;65K(&GG:6X@8FER(&MU;&QA;OUC_2!S9>=I;@!"_'3\;B!T87)I:"!B:6QE
M_F5N;&5R:6YI('-EYVEN`$)I<B!N97-N92!S9>=I;@#=<W1E9&GP;FEZ(&MA
M<F%K=&5R;&5R:2!A_F'P_61A:VD@:W5T=6QA<F1A;B!S9>=I;BX@1&%H82!S
M;VYR82!M971I;B!A;&%N_6YD86X@:V]P>6%L87G]<"!Y87#]_G3]<F%B:6QI
M<G-I;FEZ+@!487)I:"!S_6[]<FQA>?UC_7/];OT@<V7G_6XZ`%1A<FEH(&)I
MYVEM:6YI('-EYVEN.@!$9?!I_G1I<FUE:R!I<W1E9&GP:6YI>B!K:6UL:?!I
M('-EYVEN.@!386%T('/];OUR;&%Y_6/]<_UN_2!S9>=I;CH`4V%A="!B:>=I
M;6EN:2!S9>=I;CH`1?YL9?YE;B!I:VD@86QA;OT@<V7G:6XN`%)E;FL@9/QZ
M96YI;FEZ:2!S9>=I;BX`5&5R8VEH(&5T=&GP:6YI>B!D:6QI('-EYVEN.@!3
M;W)U;B!287!O<G4@1_9N9&5R`%--4R!']FYD97(`4V5N96=A;`!!;&?];&%Y
M_6/].@!%>6S\;`!3_7)B:7-T86X@=F4@36]N=&5N96=R;P!397)I($YU;6%R
M87/]`$]T=7)U;2!K:6UL:?!I;FEN('/\<F5S:2!D;VQD=2X`0F5L:7)T`%!A
M<F]L86[]>OUN_2!U;G5T=7)S86[]>B!S_6;]<FQA;6%N_7IA(&EZ:6X@=F5R
M96-E:R!S9>=E;F5K;&5R:2!B96QI<G1I;BX@`%5L8?YM86L@:7-T9?!I;FEZ
M('5Z86MT86MI('-U;G5C=6QA<OT@8F5L:7)L97EI;BX`5&5R8VEH(&5T=&GP
M:6YI>B!D:6PL('-A870@9&EL:6UI('9E('1A<FEH('-EYV5N96ML97)I;FD@
M8F5L:7)L97EI;BX`0F'^;&%N9_WG('5Y9W5L86UA;OUZ_2P@<F5N:R!D_'IE
M;FEN:7II+"!S87EF82!T87IE;&5M92P@=F4@9&GP97(@9_9R_&YT_"!S9>=E
M;F5K;&5R:6YI(&)E;&ER;&5Y:6XN`$%Y87)L87(`2W5R=6QU;2!G_&YC96QL
M96UE(&)E=&EK;&5R:2!K=6QL86[];&%B:6QI<B!D=7)U;61A+@!$9?!I_G1I
M<F=E(&EL92!B:7)D96X@9F%Z;&$@>65R(&W\;6O\;CH@`%-E>?YE;`!!;/W^
M('9E<FG^`$O]<V$@UGIE=`#';_!U(&)A\&QA;G3](&GG:6X@97)I_FEM(&%N
M86AT87+]('1A;OUM;&%N<_UN(&W]/P!']G-T97(`2&%L96X@:V%Y_71L_2!O
M;&%N('EA</UL86YD_7)M82!I;&4@>65N:2!Y87)A=/UL86X@>6%P_6QA;F3]
M<FUA(&%R87/];F1A:VD@9F%R:VQA<OT@9_9S=&5R+@!':7)I_G1E(&5N('-O
M;B!G:7)I_B!T87)I:&D@9_9S=&5R:6QS:6X@;6D_`-9Z9_QN(&]L86[]('-A
M:VQA;6$@<V7G96YE\&EN:2!G]G-T97(`4V7G:6-I>6D@9_9S=&5R`,=I>F5L
M9V4@:?YL96UL97)I(&UE;OP@YW5B=?!U;F1A(&?V<W1E<FEL<VEN(&UI/P`E
M<R!-96[\<_P@<V]L9&$@9_9S=&5R:6QS:6X@;6D_`%1A8FQO($C\8W)E(-9Z
M96QL:6ML97)I($MU='5S=6YU(&?V<W1E<@!486)L;R#6>F5L;&EK;&5R:2!+
M=71U<W5N=2!G]G-T97(`5&%B;&\@4V%T_7(@UGIE;&QI:VQE<FD@2W5T=7-U
M;G4@9_9S=&5R`$?V<OQN=/P@]GIE;&QI:VQE<FD@:W5T=7-U;G4@9_9S=&5R
M`%G\:VQE;65Y:2!G]G-T97(`4V'P86YA:P!%<FME;B!386%T;&5R9&4@4V'P
M86YA:P!'9><@4V%A=&QE<F1E(%-A\&%N86L`QV5V<F5D92!38?!A;F%K`$O\
MY_QL=`#=;&L@;VQA<F%K(&MO;?YU(/;P96QE<B!K_.?\;'1S_&X@>6%D82!T
M8?[];G/];@!3:65R<F$@3&5O;F4`W'EE(&]L`-UM>F$`W6UZ82!!;&=O<FET
M;6%S_0!3:6YG87!U<@!";WEU=`!"86O];?T@071L80!3;&]V86MY80!3;&]V
M96YY80!+87(`2V%R(%-A\&%N8?#]`$MA<B!38?!A;F%K;&%R_0!%<FME;B!3
M86%T;&5R9&4@2V%R(%-A\&%N86ML87+]`$=EYR!386%T;&5R9&4@2V%R(%-A
M\&%N86ML87+]`$MA<B!$97)I;FQI\&DZ(`!98?!A;B!K87+];B!S=2!E_FET
M:3H@`%-O;&]M;VX@061A;&%R_0!3;VUA;&D`WF%R:_UL87(@)B#>:6ER;&5R
M`%/]<F%L86UA(&3\>F5N:2!S9>=I;6D`2V%Y;F%K(&%D<F5S:0!'_&YE>2!!
M9G)I:V$`1_QN97D@079R=7!A("A)4T\M.#@U.2TS*0!'_&YE>2!'96]R9VEA
M('9E($?\;F5Y(%-A;F1W:6-H($%D86QA<OT`1_QN97D@66%R_6UK_')E`$)I
M=&G^:6L@:/QC<F5L97(@87)A<_UN9&%K:2!B;_YL=6L`2/QC<F5D96MI('/]
M;OUR('9E(&GG97)I:R!A<F%S_6YD86MI(&)O_FQU:P!";_YL=6L@07EA<FQA
M>?UC_0!!<F%L_6L@8OUR86MM80!!<F%L_6L@8OUR86MM82!V92!Y87-T_6ML
M86UA`-US<&%N>6$`W7-T96YM97EE;B#=;&5T:0#6>F5L($MA<F%K=&5R($=I
M<FG^:0!(_&-R97EI(&+V;`!+;VQO;G4@8O9L`%-A=/UR_2!B]FP`4W!O<FQA
M<@!3<FD@3&%N:V$`4W1A;F1A<G0`57IA>2!9;VQU`$)A_FQA;F?]YR!Y_6S]
M`$5Y86QE="!V97EA(-UL`$1U<G5M`$1E<&]L86UA(&)IYVEM:0!3;VMA:R!!
M9')E<VD`W'-T_"#G:7IG:6QI`$1I>F=I(&QI<W1E<VD`061R97-T96X@86QA
M;B!A9/UN_2#G_6MA<G0`4VET:6P@6T-34UT`4'IR`$MO;G4`1_9N9&5R`$%L
M='-I;6=E`$)A_F%R_0!987#];&%N9/UR;6$@8F'^87+]>6QA(&=E<FD@9/9N
M9/QR_&QD_"X@1&7P:?YI:VQI:VQE<FD@9_9R;65K(&GG:6X@>65N:61E;B!Y
M_&ML97EI;BX`665D96L@>6%P_6QA;F3]<FUA(&)A_F%R_7EL82!K87ED961I
M;&1I+@!9961E:R!Y87#];&%N9/UR;6$@9&]S>6%S_2`E<R!B8?YA<OUY;&$@
M:V%Y9&5D:6QD:2X`)7,@8F'^87+]>6QA('EA>OUL9/TN`%-U9&%N`-9Z970`
M1_QN($1O\'5M=0!'_&X@8F%T_6W]`$?\;F7^;&D`1_QN(&1O\'5M=0!'_&X@
M9&_P=6UU+T?\;B!B873];?T`1_QN(&1O\'5M=3H@`$?\;B!B873];?T`1_QN
M(&)A=/UM_3H@`-QS='-I;6=E`$1E<W1E:P!3=7)I;F%M`%-O>6%D_0!3=F%L
M8F%R9"!V92!*86X@36%Y96X`4W9A>FEL86YD`-US=F7G`-US=FGG<F4`07)A
M;6$@=&5R:6UL97)I;F1E('/V>F1I>FEM(&AA=&%S_0!3=7)I>64`1_9K(&?\
M<OQL=/QL_"!F_7)T_6YA`$?V:R!G_'+\;'3\;/P@9OUR=/UN86QA<@!44U8@
M9&]S>6%S_0#':7IE;&=E`,=)>F5L9V4@UGIE;&QI:VQE<FD`QVEZ96QG92#V
M>F5L;&EK;&5R:0!487EV86X`5&%Y=F%N+"#':6X@97EA;&5T:0!486-I:VES
M=&%N`%1A;GIA;GEA`$AE9&5F.@!']G)E=FQE<@!496QE9F]N($YU;6%R87/]
M`%-O;B!S86%T(&GG:6X@<_UC86ML_6LZ(`!3_6-A:VS]:P!3_6-A:VS]:SH@
M`%1A<VQA:R!9]FYE=&EM:0!-971I;@!3861E8V4@365T:6X`365T:6X@:&EZ
M86QA;6%S_0!-971N:6X@W'-T_`!0<OX`5&%I("A425,M-C(P*0!487EL86YD
M`%-I<W1E;6D@:W5L;&%N_63]\/UN_7H@:>=I;B!T9?YE:VO\<B!E9&5R:7HN
M`$944"!U>F%N=/US_2!K=6QL86[];&%B:6QI<B!D=7)U;61A(&1E\&EL+@!(
M;W)D92]+;VQA8B!B_'3\;FQE_G1I<FUE(&UO=&]R=2!D97-T96ML96UE;65K
M=&5D:7(Z("(E<R(`0F%K_6TZ.B!S_6[]9B!B8?YA<OUY;&$@>?QK;&5N96UE
M9&DN`-YEYV5N96ML97(@<&5N8V5R97-I(&MA<&%N9/TNQ_UK_?X@>6%P_6S]
M>6]R+@!%\&5R(&EZ:6YL97)I(&MU;&QA;FUA:R!I<W1I>6]R<V%N_7H@>?9N
M971I8VEN:7II;B#=>FEN('-I<W1E;6EN:2!Y87#];&%N9/UR;6%S_2!G97)E
M:VUE:W1E9&ER+@!3861E8V4@86QT('1A<F%F`-UL971I_FEM(&YO:W1A<_UN
M_6X@240G<VD@8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K_6QM_?X@=F5Y82!V
M97)I('1A8F%N_6YD82!B=6QU;F%M863]+@#=;&5T:?YI;2!N;VMT87/](&)A
M_F%R_7EL82!A9')E<R!D969T97)I;FEZ92!E:VQE;F1I+@#'_6MA<G3];&W]
M_B!01U`@:6UZ82#V8F7P:2!I;7IA;&%N;?W^(&EL971I;FEN(&1O\')U;'7P
M=6YU;B!S8?!L86YM87/](&GG:6X@9V5R96MM96MT961I<BX`1&'P_73];2!L
M:7-T97-I($E$)W-I(&)E;&ER;&5N96UE9&DL(&)O_B!B_7)A:_UL;?W^('9E
M>6$@=F5R:2!T86)A;OUN9&$@8G5L=6YA;6%D_2X`1&'P_73];2!L:7-T97-I
M(&)E;&ER;&5N96UE9&DN`-YI9G)E;&5M92#V>F5L;&EK;&5R:2!G_'9E;FQI
M(&)I<B!W96(@8F'P;&%N=/US_2!G97)E:W1I<FUE:W1E9&ER+@`E<R!D;W-Y
M87/]("5S(&%Y87+](&GG97)M96QI9&ER+@`E<R!D;W-Y87/]("5S(&%Y87)L
M87+](&GG97)M96QI9&ER+@!$;W-Y82!K96YD:2#\>F5R:6YE(&MO<'EA;&%N
M86UA>BX`1&]S>6$@=F5R:2!IYV5R;6EY;W(N`%1A:VEP(&5D96YL97(@8G4@
M:6QE=&DO<F9C.#(R(&EL971I<VD@:>=I;B!B8?YL_6L@8FEL9VEL97)I9&ER
M+@!!_F%M863]\/UM_7H@=&%R87G]8_T@:&%T86QA<OT@<V5B96)I>6QE('1A
M;2!E:W)A;B!K:7!I;FEN($EN=&5R;F5T($5X<&QO<F5R)VQA(&)I<FQI:W1E
M('-O<G5N(.?]:V%R9/WP_2!B:6QI;FUE:W1E9&ER+B!!;FQA;7/]>B!G]G+\
M;G3\;&5R;&4L(.=A;/W^;6%Y86X@;65T:6X@9/QZ96YL97EI8VD@:?YL97)I
M>6QE('9E+W9E>6$@=&%R87G]8_UN_6X@<F%S=&=E;&4@Y_9K;65S:7EL92!K
M87+^_6QA_F%B:6QI<G-I;FEZ+B!%\&5R('-I<W1E;6EN:7H@5VEN9&]W<R`Y
M>"!I<V4@>?QK<V5K(&EH=&EM86P@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@:&%T87/](&%L_7`@<VES=&5M:2!Y96YI9&5N(&)A_FQA=&UA;OUZ(&=E
M<F5K96-E:RY<;EQN0G4@8FER('5Y87+]>63]+B!%\&5R(&AA;&$@=&%M(&5K
M<F%N(&UE=&EN(&3\>F5N;&5Y:6-I<VEN:2!D96YE;65K(&ES=&EY;W)S86[]
M>B!%=F5T)VD@=/UK;&%Y_6XN`$MI;6QI:R`B)7,B('-I;&EN9&DN`%-A9&5C
M92!S;VP@=&%R868`0W)Y<'1?<&=P.CH@<_UN_6;];F$@1VYU4$<@:6MI;&ES
M:6YI;B!K;VYU;74@=F5R:6QM96L@>F]R=6YD863]<BX`)7,@=&%R:6AI;F1E
M("5S(&4@9_9N9&5R:6QE;B`B)7,B(&MO;G5L=2!I;&5T:2!G]G+\;G3\;&5N
M9&DN"D)U(&EL971I;FEN(&]K=6YD=?!U('9E>6$@86YL8?[];&3]\/UN_2!G
M87)A;G1I;&5M96UE:W1E9&ER+@!/;'7^='5R('!E;F-E<F5S:6YE(&)A\&QA
M;OUR:V5N(&MU;&QA;OUL86-A:R!I<VEM`$AO<F1E7T-R>7!T7W-I;64Z.B!S
M_6[]9OT@;W!E;G-S;"!B:7)I;6D@:>=I;B!G97)E:VUE:W1E9&ER+@`B)7,B
M('1E<F-I:&D@=F5R:7-I(&EZ:6X@=F5R:6QE;B!E;B!Y_&MS96L@8F]Y=71U
M(&=EYW1I\&D@:>=I;B!K87ED961I;&5M96UE:W1E9&ER+@!"=2!V97)I('EA
M<'/];OTH)7,I(&?V<W1E<FUE:R!IYVEN(&MU;&QA;OUL86X@<')O9W)A;2!S
M:7-T96UD92!B=6QU;FUA;6%K=&%D_7(N`%-A9&5C92!S;VP@=F4@<V'P('1A
M<F%F;&%R`%-A9&5C92!S8?`@=&%R868`(B5S(B!S=6YU8W5S=2!S:6QI;F1I
M+@`B)7,B('-U;G5C=7-U(&MA>61E9&EL9&DN`"5S(&GG:6X@;VQA;B#\>65L
M:6L@:7-T9?!I('-I;&EN9&DN`$)E;&ER=&EL96X@<V%T_7(@8G5L=6YM86UA
M:W1A9/UR+@!'9>=I8VD@9&]S>6$@(B5S(B!B=6QU;FUA;6%K=&%D_7(N`%-A
M9&5C92#\<W0@=F4@86QT('1A<F%F;&%R`%-A9&5C92#\<W0@=&%R868`0FER
M(/9N8V5K:2!A9/UM('/]<F%S_6YD82!Y_&ML96YE;B!V97)I(&MA>6)E9&EL
M9&DN`%G\:VQE;F5N(&1O<WEA(&MA>61E9&EL96UE9&DN`'=E871H97(N8V]M
M(&MU;&QA;OUL86)I;&ER(&1E\&EL+@!(:>=B:7(@<V7G96YE:R!M979C=70@
M9&7P:6PN`$UE=&YE(&?V;?QL_"!O;&%R86L@9_9S=&5R:6QE8FEL96-E:R!K
M_7/];2!Y;VL`0G4@86QA;F1A(.=O:R!F87IL82!K87)A:W1E<B!V87(N)7,@
M=&%N92!K87)A:W1E<B!G:7)D:6YI>CL@)7,@=&%N961E;B!A>B!G:7)M96YI
M>B!G97)E:VER9&DN`$1O<WEA("AK87+^_61A;BD@>?QK;&5N;65S:6YD92!S
M;W)U;B!V87(Z("5S('G\:VQE;F5M961I+@!$;W-Y82!Y_&ML96YI<FME;B!B
M:7(@<V]R=6X@;VQU_G1U.B`E<R!E;B!B_'G\:R!I>FEN('9E<FEL96X@8F]Y
M=71T86X@*"5D(&)Y=&4I(&1A:&$@8OQY_&LN`$1O<WEA('G\:VQE;FER:V5N
M(&)I<B!S;W)U;B!O;'7^='4Z("5S('-A9&5C92!K_7-M:2!O;&%R86L@>?QK
M;&5N9&DN`$EL971I;FEN(&)U(&O]<VW];OT@9_9R_&YT_&QE;FUE<VEN9&4@
M:&%T82!O;'7^='4N`-UL971I_FEM(&YO:W1A<_UN_6X@=F5R:6QE<FD@*&GG
M97)I*2!A:W1A<OUL_7)K96X@:&%T82!O;'7^='4N`&E#86QE;F1A<B!V97)I
M<VD@*&GG97)I*2!A:W1A<OUL_7)K96X@:&%T82!O;'7^='4N`%EA</UL86YD
M_7)M82!F;W)M=6YD82!B:7(@:&%T82!V87(N($=E<F5K;&D@8FER(&%L86[]
M(&1O;&1U<FUA;?W^(&]L86)I;&ER<VEN:7HN`$)E;&ER=&EL96X@861R97,@
M9&5F=&5R:2!I_FQE=FEN:6X@9V5RYV5K;&7^=&ER:6QM97-I('/]<F%S_6YD
M82!S;W)U;B!O;'7^='4N($S\=&9E;B!D86AA('-O;G)A('1E:W)A<B!D96YE
M>6EN+@#=;&5T:?YI;2!N;VMT87/];OUN(&%Y<OUN=/UL87+];OT@9_QN8V5L
M;&5R:V5N(&AA=&$@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@
M9&5N97EI;BX`1&'P_73];2!L:7-T97-I;FD@9_QN8V5L;&5R:V5N(&)I<B!H
M871A(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K<F%R(&1E;F5Y:6XN
M`$)U($E-05`@<W5N=6-U<W4@<&%Y;&'^_6QA;B!D:7II;FQE<FD@9&5S=&5K
M;&5M:7EO<BX`0G4@9V7G97)L:2!B:7(@<F%R(&%R_FEV:2!D9?!I;"X`0G4@
M9V7G97)L:2!B:7(@>FEP(&1O<WEA<_T@9&7P:6PN`$)U(&=EYV5R;&D@8FER
M(&MA<G0@;G5M87)A<_T@9&7P:6PN`$)U('/\<OQC_"!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&'P(&=EYVED:2#\>F5R:6YD96X@2%14
M4"!!4$D@:W5L;&%N87)A:R!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+@!"
M=2!S_'+\8_P@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL*2!A\"!G9>=I
M9&D@_'IE<FEN9&5N($A45%`@05!)(&MU;&QA;F%R86L@;65S86H@871M86[]
M>F$@:7II;B!V97)I<BX`0G4@<_QR_&/\(%--5%`@>6]L=7EL82!6;V1A9F]N
M92!)=&%L>2!A\"!G9>=I9&D@_'IE<FEN9&5N+"!S861E8V4@5F]D969O;F4@
M;G5M87)A;&%R_6YA(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N(%9O9&5F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@96QE:W1R;VYI:R!P;W-T
M82!A9')E<VD@9V5R96MT:7)M96MT961I<BX`0G4@9V5R96ML:2!B:7(@86QA
M;F3]<BX`0G4@86QA;B!S861E8V4@<V%Y_2!IYV5R;65L:61I<BX`0G4@86QA
M;B!S861E8V4@<V%Y_2!V92!I:VD@;F]K=&$@_'-T_'-T92!I_F%R971I(&GG
M97)E8FEL:7(N`$)U(&%L86X@<V%D96-E('-E:VEZ;&EK('-A>?T@<VES=&5M
M:6YD96X@9&7P97)L92!IYV5R96)I;&ER+@!"=2!A;&%N('9I<F?\;"!V97EA
M(&)O_FQU:VQA(&%Y<OUL;?W^('-A>?T@;&ES=&4@;VQM86S]9/UR+@!"=2!A
M;&%N(&=EYV5R;&D@8FER(&YU;6%R82!O;&UA;/UD_7(N`$)U(&%L86X@4D="
M($AE>"!B:>=I;6EN9&4@8FER(')E;FL@:V]D=2!IYV5R;65L:61I<BP@]G)N
M96LZ("<C,3(S-&%F)P!"=2!F;W)M('IA=&5N(&G^;&5N9&DN`$)U("5S+@!"
M=2!B:7(@2V]L86(@1W)O=7!W87)E(&YE<VYE<VED:7(N($)U(&YE<VYE>6D@
M9_9R96)I;&UE:R!IYVEN($MO;&%B($=R;W5P=V%R92!B:>=I;6EN:2!A;FQA
M>6%B:6QE;B!B:7(@96QE:W1R;VYI:R!P;W-T82!I<W1E;6-I<VEN92!G97)E
M:R!V87(N0G4@96QE:W1R;VYI:R!I<W1E;6-I(&QI<W1E<VD@:>=I;B`E<R!A
M9')E<VEN92!U\')A>?UN+@!"=2!I;&5T:2!S:7II;B!K87)A:W1E<B!K_&UE
M;FEZ9&5N(&9A<FML_2!O;&%R86LH)7,I('EA>OUL;?W^=/UR+@!"=2!N=6UA
M<F$@96X@87K];F1A;B!B:7(@;VQM86S]9/UR+@!"=2!S=6YU8W4@>FEP('9E
M(&=Z:7`@9&]S>6%L87+];OT@8>=A;6%M86MT863]<BX`4VES=&5M:6X@971K
M:6YL:?!I(&MA;&3]<OUL;?W^=/UR+@!"=2!D9?!E<B!B:7(@<V%Y_2!O;&UA
M;/UD_7(N`$)U('!E;F-E<F4@4V7G96YE:VQE<B!P96YC97)E<VEN9&5N(.=A
M\'+];&UA;/UD_7(N`$?V:R!G_'+\;'3\<_P`0FEL971L97(`6F%M86X`6F%M
M86X@W7IL96UE`%IA;6%N($)IYVEM:0!:86UA;B!39>=I;6D`5&EM;W(M3&5S
M=&4`0F'^;/UK`$)A_FS]:R`H8>?]:VQA;6$I.@!+:6UE`,=O:VQU(/;P92!S
M9>=I;6D@:>=I;BP@=/UK;&%R:V5N($-O;G1R;VP@*%!#*2!V97EA($-O;6UA
M;F0@*$UA8RD@='7^=6YA(&)A<_UN+@!"=6?\;@!(5$U,($MA>6YA\/UN82!'
M9>=I;@!4;V=O`%1O:V5L874`66%R_6X`5&]N9V$`W'-T`-QS="#'97+G979E
M("C<7W-T*0#'979I<FEL97(`5')I;FED860@=F4@5&]B86=O`$1O\')U('9E
M>6$@66%N;/W^`%-A`%1U;G5S`%3\<FMI>64`5/QR:^=E("A)4T\M.#@U.2TY
M*0!4_')K;65N:7-T86X`5'5R:W,@=F4@0V%I8V]S($%D86QA<OT`5'5V86QU
M`%-EYVEM:6YI>FD@9VER:6XZ`%4N5BX@96YD96MS.B``55),`$)E=&EK;&5R
M:6X@9'5R=6T@<F%P;W)L87+];OUN('1E<VQI;2!E9&EL96-E\&D@55),`%52
M3#H`56=A;F1A`%5K<F%Y;F$`5D93(&1I>FEN:6YE(&5R:?YI;&5M96UI>6]R
M+@#<>64@;VQU<FME;B!E:R!K=6QL86[]8_T@8FEL9VES:2!E:VQE;F5M:7EO
M<BX`(B5S(B!61E,@9&]S>6%S_6[];B!I>FEN;&5R:2!D9?!I_G1I<FEL96UI
M>6]R+@`E<R\E<R!61E,@9&]S>6%S_6[];B!I>FEN;&5R:2!D9?!I_G1I<FEL
M96UI>6]R+@`E<R!D9?!I_G1I<FEL96UE9&DN`%-13"!S=6YU8W5S=6YA(&)A
M\&QA;OUL86W]>6]R+@!34TP@:6QE(&)A\&QA;OUL86W]>6]R+@!61E,@9&]S
M>6%S_2!K;W!Y86QA;F%M_7EO<BX`(B5S(B!61E,@9&EZ:6YI('EA<F%T_6QA
M;?UY;W(N`%9&4R!D:7II;FD@>6%R873];&%M_7EO<BX`5D93(&1O<WEA<_T@
M>6%R873];&%M_7EO<BX`0F_^(%9&4R!D;W-Y87/]('EA<F%T_6QA;?UY;W(N
M`%9E<FD@<_UK_?YT_7+];&%M_7EO<BX`(B5S(B!D:7II;FD@<VEL:6YE;6EY
M;W(L(&1I>FEN(&)O_B!D9?!I;"X`)7,@<VEL:6YE;6EY;W(L(&1I>FEN(&)O
M_B!D9?!I;`!61E,@9&EZ:6YI(/9Z>6EN96QI(&]L87)A:R!S:6QI;F5M:7EO
M<BX`5D93(&1I>FEN:2!S:6QI;F5M:7EO<BX`5D93(&1I>FEN:2!S:6QI;F5M
M:7EO<CH@)7,N`%9&4R!D;W-Y87/]("(E<R(@<VEL:6YE;6EY;W(N`%9&4R!D
M;W-Y87/]('-I;&EN96UI>6]R+@!61E,@]GIY:6YE;&D@;VQA<F%K('-I;&EN
M96UI>6]R.B`E<RX`6?QR_')L_&MT96MI(&1I>FEN92!K87)A<B!V97)I;&5M
M:7EO<BX`3VYA>2!B96QG97-I(&%Y<OUN=/UL87+](.?]:V%R=/UL86W]>6]R
M`%1A;OUM_2!Y_&ML96YE;6EY;W(Z("5S`%9&4R!D;W-Y87/]('1A_OUN86W]
M>6]R+@!61E,@9&]S>6%S_2`B)7,B(&'G_6QA;?UY;W(N`%9&4R!D;W-Y87/]
M('EA;6%K(&GG:6X@8>?];&%M_7EO<BX`5D93(&1O<WEA<_T@8>?];&%M_7EO
M<BX`4_UK_?YT_6S];?W^(&%R_FEV(&'G_6QA;?UY;W(N`%9F<W)O;W0@9&EZ
M:6YI(&]K=6YA;?UY;W(N`"5S+3XE<R!O;&%R86L@>65N:61E;B!A9&QA;F3]
M<OUL86W]>6]R.B!H961E9B!D:7II;B!Z871E;B!V87(N`%9&4R!D:7II;FD@
M>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+@!61E,@9&EZ:6YI('EE;FED96X@
M861L86YD_7+];&%M_7EO<CH@)7,`5D93(&1O<WEA<_T@(B5S(B!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(N`"5S+R5S(%9&4R!D;W-Y87/]('EE;FED96X@
M861L86YD_7+];&%M_7EO<BX`5D93(&1O<WEA<_T@>65N:61E;B!A9&QA;F3]
M<OUL86W]>6]R+@`G;6MI<V]F<R<@YV%L_?YT_7+];&%M_7EO<BX`0G4@5V]R
M9"!B96QG97-I(.=E=FER:6QI;&5M:7EO<BX`5D93(&1O<WEA<_T@(B5S(B!Y
M87K];&%M_7EO<BX`5D93(&1O<WEA<_T@>6%Z_6QA;?UY;W(@*&-O<'DH*2!B
M8?YA<OUS_7H@;VQD=2DN`%9&4R!D;W-Y82!V97)I<VD@>6%Z_6QA;?UY;W(N
M`$%L=/UN_2#G:7H`1&7P:?YI:VQI:VQE<FD@1V5R:2!!;`!3;VX@97EL96UI
M(&=E<FD@86P`0F'P;&%N=/UD82!S=6YU8W5D86X@8F5K;&5N;65Y96X@>6%N
M_70Z(`!3=6YU8W5D86X@8F5K;&5N;65Y96X@>6%N_70Z(`!$;VQD=7)U;&UA
M;?W^`%5N:6-O9&4@*%541BTX*0!":7)L9?YI:R!!<F%P($5M:7)L:6ML97)I
M`$)I<FQE_FEK($MR86QL_6L`06UE<FEK82!":7)L9?YI:R!$979L971L97)I
M`$%M97)I:V$@0FER;&7^:6L@1&5V;&5T;&5R:6YI;B!+_.?\:R!5>F%K($%D
M86QA<OT`0FER:6UL97(`0FEL:6YM97EE;@!":6QI;FUE>65N(&%P:6US9VED
M("A!4$D@365S86H@240I`$)I;&EN;65Y96X@8VQI;7-G:60@*-US=&5M8VD@
M;65S86H@240I`$)I;&EN;65Y96X@:W5L;&%N_6/](&%D_2!V97EA('!A<F]L
M82X`WG4@86YK:2#V\&5N:6X@8F'P_6[](.?V>@#=<VEM<VEZ`$%Y<OUC86S]
M:W/]>B!B971I:VQE<B!P<F]G<F%M<V%L(&]L87)A:R!+97,O2V]P>6%L82]9
M87#]_G3]<B=A(&?\=F5N;&EK(&YE9&5N:7EL92!E<FG^96UE>FQE<BX@0F5T
M:6ML97)I;B!P86YO>6$@;F%S_6P@=6QA_F%C8?#];OT@9_9S=&5R96X@;6]Z
M:6QL82YO<F<@=&5K;FEK(&YO='5N=2!G]G)M96L@:>=I;B!%5D54(&D@=/UK
M;&%Y_6XN`$)E;&ER=&EL;6G^(')E;FMT96X@=F%Z9V7G`$1E<W1E:VQE;FUE
M>65N(%5Z86YT_0!'_&YC96QL90!'_&YC96QL93H@)7,`2W5L;&%N_6/]>?T@
M9_QN8V5L;&4`6?QK<V5L=&UE(&)E=&GP:2!S:6QI;&YD:2X`6?QK;&4`0OQT
M_&X@=7EG=6QA;6%L87+];B!A>6%R(&1O<WEA;&%R_2!S=6YU8W5Y82!Y_&ML
M96YD:2X`0OQY_&L@;&%T:6X@:&%R9FQE<FD`0OQY_&L@<F]M82!R86MA;6QA
M<OT`57)U9W5A>0!+=6QL86XZ("5S`%-33"!K=6QL86X`2W5L;&%N_6/](&%D
M_6[]>B]P87)O;&%N_7H@24U34"!S=6YU8W4@:>=I;B!F87)K;/T@:7-E(&MU
M;&QA;OUN+@`E<R!K=6QL86[]8_US_2`E<R!IYVEN(&1O\')U;&%N86UA9/TN
M`$MU;&QA;OUC_2!9]FYE=&EM:0!+=6QL86[]8_T@4V7G96YE:VQE<FD`2W5L
M;&%N_6/]($MA>?UT`$)U('-I=&4@:>=I;B!K=6QL86[]8_T@:V%Y9/T@<V7G
M:6QM97H@:_UL_6YM_?YT_7(N`$MU;&QA;OUC_2!!9/T`2W5L;&%N_6/]($%D
M_3H`2W5L;&%N_6/](&%D_3H@`%-I<W1E;61E:VD@:W5L;&%N_6/];&%R.@#6
M>F)E:VES=&%N`%9&4R!D:7II;FD@>6]K+@!4871I;`!'9>=E<FQI(&MO;G5M
M;&%R_6X@:>=E<F1I:VQE<FDZ`$=EYV5R;&EL:6L`WG4@86YD86X@:71I8F%R
M96X@9&%K:6MA(&1E\&5R:0!$9?!E<FQE<@!$9?!E<FQE<FEN('-EYVEL96-E
M\&D`5F%N=6%T=0!$9?!I_FME;@!696YE>G5E;&QA`$1O\')U;&%M82!B8?YA
M<OUS_7H@;VQD=2`M(&)U(&EL971I(&MU<F-A;&%N;?W^(&]L86)I;&ER+B`@
M`%/\<OQM`%/\<OQM($MO;G1O;/P`1/S^97D@2&EZ80!$_/YE>2!Y87-T_6ML
M86UA`$3\_F5Y.@#';VL@6?QK<V5K`%9I971N86T`5FEE=&YA;6-A("A625-#
M24DI`$?V<OQN=/QL92`E<P!":7(@9/W^('=E8B!S87EF87/](&?V<OQN=/QL
M90`E<R!O;&%R86L@9_9R_&YT_&QE`$)R:71A;GEA)WEA(&%I="!6:7)G:6X@
M061A;&%R_0!!;65R:6MA($)I<FQE<OYI:R!$979L971L97)I)VYE(&%I="!6
M:7)G:6X@061A;&%R_0!']G+\_@!']G+\_CH`4TU44"!Y;VQU>6QA(%9O9&%F
M;VYE(-UT86QY80!705).`%5905))(2$A)7,@W<?=3D1%3B!"153=T-T@14P@
MW4Q%(,=)2T%25$E.+@!786QL:7,@=F4@1G5T=6YA`%5Y87+]`,=R_@!(879A
M(%1A:&UI;FD`2&%V82!V97)I<VD@<V'P;&%Y_6/]<_T`5V5A=&AE<BYC;VT`
M5V5B`%=E8B!3:71E<VD`2&%F=&%L_6L`2&_^9V5L9&EN:7H`)7,@2&_^9V5L
M9&EN:7H`2&_^9V5L9&EN:7HL("5S`$)A=/T@*$E33RTX.#4Y+3$I`$)A=/T@
M*$E33RTX.#4Y+3$U*0!"873](%-A:')A`"5S(&=I<FG^=&5N('-O;G)A(&AA
M;F=I('5Y9W5L86UA>?T@9_9R_&YT_&QE<VEN/P!3_6[]<FQA>?UC_2!K87)A
M:W1E<B!N961I<C\`06MT87+];2!K87)A:W1E<FD@;F5D:7(_`$AA;F=I($5V
M<F4`6F5N9VEN($UE=&EN(&3\>F5N;&5Y:6-I<VD@:>=I;B!H86YG:2!U>75M
M;'4@96ML97(@<V7G:6QE8FEL:7(@:_UL_6YS_6XN`$=E;FG^;&EK`$-34R!B
M:7)I;6EY;&4@9V5N:?YL:6L`4V]L9&%K:2`E<R!M96[\<_QN_&X@9V5N:?YL
M:?!I("AB:7(@<V]N<F%K:2!G:7)I_G1E(&5T:VEN(&]L86-A:RDZ`,=I>F5L
M9V5N:6X@9V5N:?YL:?!I`$=E;FG^;&EK(&)I<FEM:0!'96YI_FQI:SH`5VEK
M:0!2_'IG87(`17)K96X@4V%A=&QE<F1E(%+\>F=A<@!+;F]T(&)I<FEM:6YD
M92!R_'IG87(@:/UZ_0!2_'IG87(Z`%+\>F=A<CH@`$)I;&=E;&EK`-W^`-W^
M($%D<F5S:0#=_B!496QE9F]N=0!8+5)E9@!8-3`Y=C,@5&5M96P@2_US_71L
M86UA;&%R_0!8-3`Y=C,@1V5N:?YL971I;&UI_B!!;F%H=&%R($MU;&QA;OUM
M_0!8-3`Y=C,@UG1E:VD@2V]N=2!!9/T`6#4P.78S($MO;G4@06YA:'1A<B!4
M86[]=/UC_7/]`%@U,#EV,R!U>F%N=/UL87+]`%E9`%E965D`66%H;V\A(&AA
M<FET87/]`%G];&S]:P!996UE;@!%=F5T`$5V970L($MA8G5L($5D:7EO<G5M
M`$U%5-U.($U/1%5.1$%324Y)6BX@6SP^72!D_/!M96QE<FEN:2!K=6QL86YA
M<F%K(%=94TE764<@9_9R_&[\;?QN92!D]F[\;BX`1&_P<G5L86YA;6%D_6[]
M>BX`)UPG(&MA<F%K=&5R:2!T86T@863];OUZ9&$@8G5L=6YA;6%Z+@!'9>=E
M<FQI(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G:7)M961I;FEZ+@`E
M<R!IYVEN9&4@:V%R_OUL_6L@9V5L96X@86QA;FQA<FQA("AIYV5R:2D@86MT
M87+];&%N(&1O<WEA9&%K:2!A;&%N;&%R_2!E_FQE_G1I<FUE9&EN:7HN`,?]
M:_W^('EA<&UA9/UN_7HN`$=EYV5R;&D@8FER(&-E<"!T96QE9F]N=2!N=6UA
M<F%S_2!G:7)M96QI<VEN:7HL('-A>?UL87(@=F4@<V7G96YE:VQI(&]L87)A
M:R!U;'5S;&%R87)A<_T@87)A;6$@]FYE:VD@)RLG(`!'9>=E<FQI(&)I<B!D
M9?!E<B!G:7)M96QI<VEN:7HN`-QY92!K87ED_2!Y87!A8FEL;65K(&GG:6X@
M8FER(%9E<FE!\&%C_2!Y87#];&%N9/UR;6%L_7/];OUZ+@!61E,@<V]N(&'^
M86UA<_UN_2!Y87#];&%N9/UR;6%L_7/];OUZ+@!0<F]B;&5M(')A<&]R=2!G
M]FYD97)M961E;B#V;F-E('-O<G5N=2!T87)F:2!E=&UE;&ES:6YI>BX`0G4@
M8F'P;&%N=/UN_6X@9_9S=&5R9&GP:2!B:7(@55),(&=I<FUE;&ES:6YI>@!3
M:6QI;FUE<VD@:>=I;B!B:7(@<W5N=6-U('-EYVUE;&ES:6YI>BX`5&5M:7IL
M96YM97-I;B!IYVEN(&)I<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI
M>BX`4VEL:6YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L
M:7-I;FEZ+@!%:VQE;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI
M<G1M96QI<VEN:7HN`$?\;F-E;&QE;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/]
M(&%D_2!B96QI<G1M96QI<VEN:7HN`$=E<N=E:VQE_G1I<FEL96-E:R!B:7(@
M97EL96T@8F5L:7)T;65L:7-I;FEZ+@!996YI(&MA=&5G;W)Y(&%D_2!G:7)M
M96QI<VEN:7HN`"5S(&]T=7)U;75N=6X@<_QR97-I(&1O;&1U+B!,_'1F96X@
M=&5K<F%R(&=I<FG^('EA</UN+@!%;&5K=')O;FEK(%!O<W1A($%D<F5S:6YI
M>@!+:6UD96XZ(&%D<F5S.@!":6QG:6QE<FEN:7H`)7,@;W1U<G5M=6YU>G5N
M(&)A_FQA;F?]8_UN9&$@W6YT97)N970@061R97-I;FEN:7H@9&7P:?YT:2X@
M1_QV96YL:?!I;FEZ:2!K;W)U;6%K(&GG:6XL('EE;FED96X@9VER:?X@>6%P
M;6%L_7/];OUZ+@!!9/UN_7H`2VEM;&EK(&1E;F5T:6UI;FEZ(&MU;&QA;OUC
M_2!L:7-T96QE;65Y:2!D97-T96ML96UE;65K=&5D:7(@=F5Y82!B=2#V>F5L
M;&EK(&)I<B!N961E;B!Y_'K\;F1E;B!S9>=I;&5M97H@:_UL_6YM_?YT_7(N
M`"5S(&]T=7)U;75N=7IU;B!B8?YL86YG_6/];F1A('1A<F%Y_6/];OUZ(&1E
M\&G^=&DN($?\=F5N;&GP:6YI>FD@:V]R=6UA:R!IYVEN+"!Y96YI9&5N(&=I
M<FG^('EA<&UA;/US_6[]>BX`5&%R87G]8_UN_7H@8G4@]GIE;&QI\&D@9&5S
M=&5K;&5M96UE:W1E9&ER+@!:86UA;B!$:6QI;6EN:7HZ`-9N('1A;OUM;/T@
M:VEM;&GP:6YI>CH`5&%M($%D_6[]>CH`)7,@:>=I;B!Y96YI('!A<F]L86[]
M>CH@)7,`4V7G96YE:VQE<FEN:7H@8G4@;W1U<G5M=6X@<_QR97-I(&GG:6YD
M92!G_&YC96QL96YD:2X`4V7G96YE:VQE<FEN:7H@9_QN8V5L;&5N9&DN`%!A
M<F]L86[]>B!S_6;]<FQA;F3]+@!087)O;&%N_7H@<_UF_7)L86YD_2P@96QE
M:W1R;VYI:R!P;W-T86[]>OT@:V]N=&]L(&5D:6X@=F4@>65N:2!P87)O;&%N
M_7IL82!G:7)I_B!Y87#];BX`57IA:W1A:VD@<W5N=6-U;&%R_6[]>CH`675G
M;W-L879Y80!:86ER90!:86UB:6$`6FEM8F%B=F4`2/UZ;/T`6T%L_6YT_2!-
M971N:2!386ML85T`6U!R;V)L96T@4F%P;W)U70!;06S];G3]($UE=&YI($?V
M<W1E<B`M`%M!;/UN=/T@365T;FD@1_9S=&5R("T@)7,@<V%T_7)=`"5S+R5S
M('-A=/UR`%]9]FYE=&EM`%]#3$D`7U9E<FE!\&%C_0!3873]<OT@7U-I;`!?
M1W)U<&QA<@!987)?9/UM`$?V<OQN=/P@UE]Z96QL:6ML97)I+BXN`$=I7W)I
M_@#'_5]K_?X`7T)A\&QA;G3]>?T@1&7P:?YT:7(N+BX`7U-EYV5N96ML97(`
M7TAA:VQA<@!"8?!L85]N=/UY_2!3:6PN+BX`7T%Y87)L87(`QVEZ95]L9V4@
MUGIE;&QI:VQE<FDN+BX`2U]U;&QA;OUC_6QA<@!A9')E<R!D969T97)I`'1A
M:W9I;0#];/UM;/T`8G5R87EA('3]:VQA>?UN`&3\_OQY;W(`9&]S>6$`)7,@
M*"5S*2!D96X@)7,@)7,@9&4`:#H`06-I;`!-971N92!G]FW\;/P`<V%T_7)L
M87)=`&UK:7-O9G,@25-/('EA<&%R:V5N(&AA=&$@:V]D=3HE9"X`860`9V5R
MYV5K;&7^=&ER:6QM961I`&AE;OQZ(&=E<N=E:VQE_G1I<FEL;65D:0!N;W0@
M9&5F=&5R:0!Y_'ID90!R97-I;2!B:7)I;6D`>?QK<V5L:7EO<@!F87)K;&%R
M_2!G]G-T97(`2%144"!Y;VQU>6QA('-M<S)E;6%I;`!S86)I=`!G]G)E=B!L
M:7-T97-I`'!A<F]L87G](&1O\')U;&%M86L@:>=I;B!I:VD@9&5F82!G:7)I
M;@!B:7)L9?YT:7)I;&UI_@!A9&QA;F3]<OUL;6%M_?X`:W5L;&%N_6/]('-E
MYVEM:0!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O=')?5%(O:&5L<"YX;6P`````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-C(P`#$P-3$U-#,Q,#8R`#`R,#,U-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/WAM
M;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TY(C\^"CPA+2T@
M)$AO<F1E.B!H;W)D92]L;V-A;&4O=')?5%(O:&5L<"YX;6PL=B`Q+C$N,BXQ
M(#(P,#4O,3`O,3@@,3$Z,S,Z-#8@:F%N($5X<"`D("TM/@H\:&5L<#X*"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)S=6UM87)Y(CX*/'1I=&QE
M/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A
M;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I
M;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT
M('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E
M(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N
M9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R
M;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O
M9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C
M=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@
M82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E
M=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N
M=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I
M82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C
M:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P
M86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W
M;BX*(#PO<&%R83X*/"]E;G1R>3X*+2T^"CQE;G1R>2!I9#TB<W5M;6%R>2(@
M;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(@<W1A=&4]
M(G5P=&]D871E(CX*/'1I=&QE/D=I<FG^(%-A>69A<_T\+W1I=&QE/@H\<&%R
M83X*1VER:?X@<V%Y9F%S_2!S:7IE(/9N96UL:2!B:6QG:6QE<FEN:7II;B!K
M_7-A(/9Z971I;FD@=F5R:7(N(-9R;F7P:6XL(&=E;&5N(&MU='5N=7ID82!K
M8><@=&%N92!Y96YI(&5L96MT<F]N:6L@<&]S=&$@;VQD=?!U;G4L('1A:W9I
M;6EN:7ID96MI('EA:VQA_F%N(&]L87EL87+]+"!Y87#];&%C86ML87(@;&ES
M=&5S:6YD96MI(&G^;&5R:6YI>FDL('-EYVEL:2!H86)E<B!S97)V:7-I;F1E
M:VD@8F'^;/UK;&%R_2!V<RX@9_9S=&5R:7(N($)U(/9Z971L97)I;B#G;_!U
M(&=E;F5L(&9O;FMS:7EO;FQA<B!IYVEN(&O]<V%Y;VQL87(@:>=E<F5C96MT
M:7(L("!Y96YI('!O<W1A(&]L=?YT=7)M86LL('EE;FD@=&%K=FEM(&]L87G]
M('EA(&1A(&G^:2!O;'7^='5R;6%K(&=I8FDN"CPO<&%R83X*/'!A<F$^"D=I
M<FG^('-A>69A<_UN_6X@:>=E<FGP:2!D_'IE;FQE;64@='7^=2!I;&4@:7-T
M9?!E('5Y87)L86YA8FEL:7(N("+6<FYE\&EN+"!G:7)I_B!S87EF87/];OUN
M(&AA;F=I(/;P96QE<FD@:>=E<F5C9?!I;FEN('EA;OUN9&$@8G4@]O!E;&5R
M:6X@9_9S=&5R:6QM92!S_7)A;&%R_2!D82!S9>=I;&5B:6QI<BX*/"]P87)A
M/@H\+V5N=')Y/@H*"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)N
M879B87(B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R
M/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T
M:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R
M+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R
M('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A
M=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@HM+3X*
M"CQE;G1R>2!I9#TB;F%V8F%R(B!M9#4](F(X8V8P864Q.64U-V1F83!C,F(Y
M-C)E-3$V-S@R9C0W(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^57EG=6QA
M;6$@1&]L8?[];2#'=6)U\'4\+W1I=&QE/@H\<&%R83X*57EG=6QA;6$@9&]L
M8?[];2#G=6)U\'4@=V5B('-A>69A<_UN_6X@<V]L(&ME;F%R_63]<BX@365V
M8W5T('5Y9W5L86UA;&%R(&%R87/];F1A("!H_7IL_2!V92!K;VQA>6-A(&=E
M>FEN96)I;&UE:R!IYVEN('5L8?[];2#G=6)U\'5N9&%K:2!S:6UG96QE<FD@
M=/UK;&%Y_6[]>BX*/"]P87)A/@H\+V5N=')Y/@H*"CPA+2T@16YG;&ES:"!E
M;G1R>3H*/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC
M93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O
M('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE
M8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N=')Y
M(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@;60U/2)D9#DU9&8P-V$P,S`S
M,3(S,F)A96$Y,3DR.#AB,F0P,"(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE
M/E1E<F-I:&QE<CH@0F%K_6TZ($)A:_UM(%EA<&UA/"]T:71L93X*/'!A<F$^
M"E-I<W1E;64@9VER97)K96X@8F%K_6T@:?YL96UL97)I('EA<&UA:R!I<W1E
M<G-E;FEZ(&)U(&MU='5Y=2!I_F%R971L97EI;FEZ+@H\+W!A<F$^"CPO96YT
M<GD^"@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<')E9G,M8V]N
M9FER;5]M86EN=&5N86YC92(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA
M:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I
M;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI
M<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D
M(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO
M9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB<')E
M9G,M8V]N9FER;5]M86EN=&5N86YC92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF
M865A9&(W,CDV,C0P,#,V92(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE/E1E
M<F-I:&QE<CH@0F%K_6TZ($)A:_UM($1O\')U;&%M83PO=&ET;&4^"CQP87)A
M/@I"86O];2!G]G)E=FQE<FEN:2#G86S]_FUA>6$@8F'^;&%M861A;B#V;F-E
M(&1O\')U;&%M86L@:7-T:7EO<G-A;OUZ(&)U(&MU='5Y=2!I_F%R971L97EI
M;FEZ+B!%\&5R(&MU='4@:?YA<F5T;&5N;65M:?X@:7-E(.=A;/W^;6%S_2!G
M97)E:V5N(&+\=/QN(&)A:_UM(&G^;&5M;&5R:6YI>B!S:7-T96UE(&=I<F5R
M:V5N("QI<'1A;"!E=&UE(/YA;G/];OUZ(&]L;6%D86X@;W1O;6%T:6L@;VQA
M<F%K(&=E<N=E:VQE_F5C96MT:7(N"CPO<&%R83X*/"]E;G1R>3X*"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+W5K7U5!+P``````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,38V-30`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O=6M?54$O3$-?34534T%'
M15,O````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#8R`#`R,#0T,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]U:U]502],0U]-15-304=%4R]H;W)D92YM;P``````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3$Q,3``,3`U,34T,S$P-C(`,#(R,#8V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````4````!P`
M``"<`@``:P```!P%````````R`8``"@```#)!@``"````/(&```/````^P8`
M``@````+!P``"````!0'```9````'0<```<````W!P``#@```#\'```%````
M3@<``!$```!4!P``"````&8'```5````;P<```H```"%!P``#````)`'```'
M````G0<``!````"E!P```@```+8'```%````N0<``!````"_!P``!@```-`'
M```4````UP<```4```#L!P``#0```/('```%``````@```L````&"```#P``
M`!((```#````(@@```0````F"```#````"L(```*````.`@```4```!#"```
M$@```$D(```0````7`@``!````!M"```&@```'X(```&````F0@```<```"@
M"````@```*@(```$````JP@```\```"P"```!P```,`(```'````R`@```0`
M``#0"```!0```-4(```(````VP@``!4```#D"```'@```/H(```%````&0D`
M`"@````?"0``*0```$@)```3````<@D```L```"&"0``!0```)()```1````
MF`D```0```"J"0``#````*\)```:````O`D``!<```#7"0``%P```.\)```3
M````!PH``!`````;"@``%P```"P*```'````1`H```4```!,"@```P```%(*
M```,````5@H```@```!C"@``%````&P*```'````@0H```8```")"@``"P``
M`)`*```,````G`H```H```"I"@```@```+0*```&````MPH``$4```"^"@``
M)@````0+```E````*PL``!````!1"P``9P$``&(+```Z````R@P```D````%
M#0``&@````\-```+````*@T``!(````V#0``(@```$D-```&````;`T```\`
M``!S#0``"0```(,-```.````C0T```\```"<#0``'P```*P-```4````S`T`
M``T```#A#0``"````.\-```4````^`T```(````-#@``!P```!`.```0````
M&`X```<````I#@``$````#$.```'````0@X``!,```!*#@``!P```%X.```-
M````9@X``!(```!T#@``!````(<.```(````C`X```X```"5#@``$````*0.
M```%````M0X``!0```"[#@``$0```-`.```9````X@X``"D```#\#@``!@``
M`"8/```%````+0\```(````S#P``"@```#8/```/````00\```0```!1#P``
M"````%8/```$````7P\```<```!D#P``!@```&P/```8````<P\``!\```",
M#P``!P```*P/```I````M`\``"X```#>#P``#0````T0```,````&Q````@`
M```H$```%````#$0```$````1A````X```!+$```&0```%H0```5````=!``
M`!4```"*$```(P```*`0```7````Q!```!D```#<$```!P```/80```%````
M_A````,````$$0``#P````@1```1````&!$``!8````J$0``!0```$$1```'
M````1Q$```T```!/$0``#0```%T1```/````:Q$```(```![$0``!P```'X1
M``!%````AA$``#$```#,$0``,0```/X1```7````,!(```$`````````30``
M`!T```!%````%0````@````B````.0``````````````'````$<`````````
M%````"X`````````.P```#8```!)````)@```#$````````````````````G
M````'@```"T````-`````````"D``````````@````````!/````)0```$(`
M``!,```````````````H````/@```!@````?````%@```!L````C````"0``
M`#`````U````!`````L````%````#`````\````O````0````!H```!&````
M2P```$X````R````0P```#T````&````*P``````````````/P```$@````X
M````"@```````````````````#P`````````#@`````````3````$0```"``
M```0````(0```$H``````````P```%`````2````-```````````````````
M```````7````00```#,````9````*@`````````D``````````<````W````
M1````#H````L`````"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VX`,C0@:&]U<G,`061D(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D
M9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&UI
M;FES=')A=&EO;@!!;&EA<P!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#
M86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`
M0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$1$`$1A:6QY`$1E9F%U;'0@261E
M;G1I='D`1&5L971E`$1E<V-R:6)E('1H92!0<F]B;&5M`$5M86EL`$5M<'1Y
M(')E<W5L="X`17)R;W(`179E<GD@3&]G:6X`17AA;7!L92!V86QU97,Z`$9A
M>`!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]G(&EN`$QO9R!O=70`34T`
M36%I;`!-871C:&EN9R!F:65L9',`365S<V%G90!-;VYT:&QY`$YA;64`3F]T
M97,`4&%S<W=O<F0`4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E
M('!A:7(`4F5S970`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO
M;G,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5N9"!0<F]B;&5M
M(%)E<&]R=`!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-U8V-E<W,`5&ET;&4`55),`%5N9&\@0VAA;F=E<P!5<V5R;F%M90!5
M<V5R<R!I;B!T:&4@<WES=&5M.@!787)N:6YG`%=E96ML>0!796QC;VUE+"`E
M<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"X`6U!R;V)L96T@4F5P;W)T70!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E
M('8R+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO
M<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I0
M3RU2979I<VEO;BU$871E.B`R,#`R+3`Q+3`U(#$V.C$U*S`R,#`*3&%S="U4
M<F%N<VQA=&]R.B!!;F1R:7D@2V]P>7-T>6%N<VMY(#QA;G)I0'!O;'EN970N
M;'9I=BYU83X*3&%N9W5A9V4M5&5A;3H@56MR86EN:6%N(#QW96)M87-T97)`
M<&]L>6YE="YL=FEV+G5A/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]2T])."U5"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#@M8FET"@#OT,72P<.FT2#0TL_&ILS!R]3)WL[/Q\\@
MS\+3S-7'S]?5U\'.SM$@)7,@+2#PIL34U\72Q-;%SL[1`#(T(,?/Q,G.R0#D
MS\3!U,D@SL_7S\?/(,O/TLG3U-77P=[!.@#DS\3!U,D@T,'2U0#DS\3!U,D@
MR\_2R=/4U=?!WL$`Y,_$P=?!SL[1(,O/TLG3U-77P=ZFUR#:P<+/TL_.Q<[%
M+@#AQ-+%T\$`X<3-ILZFT]32U=?!SL[1`/#3Q=?$S\ZFS0#DS]/4U=#.IB#0
MS\S1.@#DQ<[8(,[!TL_$UL7.SM$`]Z;$S:;.R=3)(-#/UZ;$S\W,Q<[.T2#0
MTL_"S,7-R0#SU*;,V,[)R\_7R<H@U,7,Q<;/S@#ZP<O2R=3)(->FR\[/`.O/
MS=#!SJ;1`/"FQ-37Q=+$UL7.SM$@T,'2S\S``.3D`/W/Q,7.SL\`[]/.S]?.
MP2"FT,_3U,'3V`#WR=3%TM3)`._0R=NFU-@@T-+/PLS%S=4`Y2W0S]O4P0#P
MS]+/ULZFRB#2Q=K5S-C4P=0N`/#/S<G,R\$`Z\_6SL_'SR#7R,_$U0#DP<ZF
M(,3,T2#0TLG+S,'$U3H`YL'+TP#DS]#/S<_'P0#DS\W!V\[1(,'$TL73P0#D
MS\W!V\ZFRB#4Q<S%QL_.`$AO<F1E`+;-T,_2U,_7P<[%(-#/S,4Z("5S`+;-
MT,_2U,_7P<ZF(-#/S-$Z`/#%TL7,ILL@TL_:Q*;,IM<@Y,_0S\W/Q\D`\,72
MQ<?,T<0@T]#)T\O5(,O/TLG3U-77P=ZFUR#:P<+/TL_.Q<[)RBX`]]>FRM3)
M`/?)RM3)`.WM`$E-4"W0S]+4P<P`]Z;$T,_7IL3.IB#0S\S1`.S)T]0`_<_-
MIM/1P]$`MLU@T0#NS]3!U,O)`/#!TL_,V`#PP=+/S-@@S=73R=38(-/0IM?0
MP=/4R2X`]\G+S\[!U,D@T-+/QJ;,P<O4R=[.IB#/T,72P<.FIP#TQ<S%QL_.
M`.+5Q-@MS,'3R\$L(,3!RM3%(,O/TL_4R\G*(,_0R=,@T-+/PLS%S<DN`.+5
MQ-@MS,'3R\$L(-?+P=:FU-@@SL':U]4@R\_2R=/4U=?!WL$@IB#0P=+/S-@`
M[]#)TR#0TL_"S,7-R0#WR=3%TM3)(-#!TM4`[][)T]3)U,D`\,_7Q=+.U=3)
MT]$@Q,\@[]##ILH`\L_,V`#ZPL72Q<?4R2#/T,.FIP#WR<+%TJ;4V"#2S]K$
MILS`U\'>(,3!U,DZ`/?)PL72IM38(,;/TLW!U"#$P=3).@#WR<+%TJ;4V"#&
MS]+-P=0@WL'3U3H`]Z;$IM/,P=3)(-#/UZ;$S\W,Q<[.T2#0TL\@T-+/PLS%
MS=4`\-+/T-73U,G4R2#0TL_&ILS!R]3)R]4`]]>FQ"#ST,7#IL',V,[)R"#3
MR<W7S\RFUP#UT]"FV\[/`/3)U-7,`%523`#SR\'3U=?!U,D@VLVFSLD`[L':
MU\$@R\_2R=/4U=?!WL$`Z\_2R=/4U=?!WJ8@UR#3R=/4Q<VF.@#UU\''P0#]
MS]3)UL[1`/>FU,'`(/?!TRP@)7,`\L_"S][!(,'$TL73P0#RS\+/WLG*(-3%
MS,7&S\X`\O(`_<_2IM[.SP#WR2#0S]?)SLZF(,_0R=/!U,D@T-+/PLS%S=4L
M(-#%TML@SJ;6(->FQ-/)S,'4R2#0S]>FQ,_-S,7.SM$@T-+/(,[%IRX`]\'-
M(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1
M+@#WP<T@T\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77P=[!(,3,T2#$S\3!
MU\'.SM$N`%OPS]>FQ,_-S,7.SM$@\-+/PLS%S<E=````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O=6M?54$O:&5L<"YX;6P`````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,Q,#8R`#`R,#,R,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/WAM;"!V
M97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]U:U]5
M02]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$R(&IA;B!%>'`@
M)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W
M(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4
M:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A
M;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L
M(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y
M;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y
M;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A
M9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N
M+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I
M8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C
M;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C
M86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*
M("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M
M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@
M>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES
M('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y
M(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA
M=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V
M:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N
M9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V
M:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V
M:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E
M='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO
M=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC
M92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@
M268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS
M('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA
M=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+WIH7T-.+P``````````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V,@`P,38V-3$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?0TXO3$-?34534T%'15,O````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R
M`#`R,#0S-@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z:%]#3B],
M0U]-15-304=%4R]H;W)D92YM;P``````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q
M-S<U,S$`,3`U,34T,S$P-C(`,#(R,3`W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````>P0``!P```#T(P``^P4`
M`,Q'````````N%\```X```"Y7P``#P```,A?```(````V%\```P```#A7P``
M!````.Y?```/````\U\```L````#8```#@````]@```%````'F```"@````D
M8```"@```$U@```5````6&```!(```!N8```"P```(%@```.````C6````H`
M``"<8```#0```*=@```.````M6````8```#$8```#P```,M@```8````VV``
M``P```#T8```"`````%A```N````"F$``!H````Y80``,@```%1A```X````
MAV$``%0```#`80``40```!5B``!:````9V(``%<```#"8@``-````!IC```%
M````3V,```8```!58P``$0```%QC```(````;F,``"4```!W8P``(````)UC
M```/````OF,```H```#.8P```P```-EC```/````W6,``!0```#M8P``"0``
M``)D```-````#&0``!(````:9```#P```"UD```/````/60```@```!-9```
M)````%9D```(````>V0``!D```"$9```!P```)YD```,````IF0``"P```"S
M9```#@```.!D```#````[V0```L```#S9```!P```/]D```'````!V4```4`
M```/90``%P```!5E```*````+64```\````X90``&````$AE```.````864`
M`!0```!P90``%P```(5E```7````G64``!,```"U90``#@```,EE```?````
MV&4```<```#X90``!@````!F```(````!V8```\````09@``"@```"!F```3
M````*V8```L````_9@``%0```$MF```5````868```<```!W9@``!0```']F
M```5````A68``!$```";9@``#````*UF```[````NF8```D```#V9@``!P``
M``!G```4````"&<```4````=9P``$````"-G```3````-&<``#D```!(9P``
M)P```()G```L````JF<``"H```#79P``)0````)H```*````*&@```8````S
M:```"0```#IH```'````1&@``"\```!,:```-P```'QH```N````M&@``%4`
M``#C:```+0```#EI```M````9VD``"T```"5:0``0````,-I```C````!&H`
M`",````H:@``+0```$QJ```S````>FH``!4```"N:@``&0```,1J```I````
MWFH``"0````(:P``$0```"UK```*````/VL``!````!*:P``%@```%MK```6
M````<FL```<```"):P``!P```)%K```4````F6L```H```"N:P``"````+EK
M```'````PFL```<```#*:P``!@```-)K```%````V6L```<```#?:P``!@``
M`.=K```(````[FL```X```#W:P``"@````9L```$````$6P```<````6;```
M"0```!YL```6````*&P```@````_;```#0```$AL```&````5FP``!X```!=
M;```$0```'QL```(````CFP```T```"7;```#````*5L```'````LFP```,`
M``"Z;````P```+YL```7````PFP```@```#:;```!````.-L```(````Z&P`
M``@```#Q;```(````/IL```&````&VT```8````B;0``%0```"EM```8````
M/VT``!T```!8;0``5````'9M```I````RVT```H```#U;0``#@````!N```*
M````#VX``!0````:;@``&````"]N```=````2&X``!,```!F;@``%````'IN
M```$````CVX```8```"4;@``!0```)MN```%````H6X``!L```"G;@``&@``
M`,-N```1````WFX``!$```#P;@``'`````)O```0````'V\``"$````P;P``
M$0```%)O```,````9&\```8```!Q;P``%P```'AO```(````D&\```4```"9
M;P``#````)]O```&````K&\```<```"S;P``#0```+MO```'````R6\```L`
M``#1;P``!P```-UO```'````Y6\```H```#M;P``#````/AO```0````!7``
M``4````6<```)0```!QP```3````0G```#L```!6<```(````))P```,````
MLW````X```#`<```"@```,]P```-````VG```!X```#H<```&P````=Q```A
M````(W$``!X```!%<0``'@```&1Q```;````@W$``!X```"?<0``,P```+YQ
M```O````\G$``!(````B<@``*0```#5R```2````7W(``!8```!R<@``*```
M`(ER```@````LG(``"$```#3<@``00```/5R```'````-W,```8````_<P``
M$@```$9S```3````67,``!(```!M<P``!P```(!S```$````B',```P```"-
M<P``#P```)IS```3````JG,```T```"^<P``#0```,QS```&````VG,``!$`
M``#A<P``%P```/-S```;````"W0```X````G=````@```#9T```%````.70`
M``0````_=```#0```$1T```.````4G0```,```!A=```"````&5T```/````
M;G0``!````!^=```!@```(]T```,````EG0``!$```"C=```&0```+5T```-
M````SW0```<```#==```%````.5T```+````^G0``"(````&=0``+P```"EU
M```+````674```D```!E=0``&0```&]U```+````B74``!<```"5=0``%P``
M`*UU```)````Q74``!8```#/=0``#P```.9U```.````]G4```@````%=@``
M#0````YV```F````''8``$,```!#=@``"````(=V```2````D'8```@```"C
M=@``"P```*QV```O````N'8```X```#H=@``!@```/=V```#````_G8```<`
M```"=P``!`````IW```*````#W<```H````:=P``#P```"5W```0````-7<`
M`!<```!&=P``$0```%YW```7````<'<```4```"(=P``"P```(YW```%````
MFG<```T```"@=P``&P```*YW```7````RG<```D```#B=P``#@```.QW```-
M````^W<```@````)>```#@```!)X```1````(7@```<````S>```!0```#MX
M```'````07@```@```!)>```!@```%)X```0````67@``!````!J>```#P``
M`'MX```+````BW@```\```"7>```#````*=X```/````M'@```<```#$>```
M!@```,QX```/````TW@```@```#C>```$P```.QX```>`````'D``"$````?
M>0``(````$%Y```9````8GD``!<```!\>0``)0```)1Y```7````NGD``!L`
M``#2>0``#0```.YY```#````_'D```@`````>@``"@````EZ```,````%'H`
M``0````A>@``$P```"9Z```4````.GH```P```!/>@``"0```%QZ```+````
M9GH``!L```!R>@``!P```(YZ```'````EGH```H```">>@``#0```*EZ```)
M````MWH```0```#!>@``&````,9Z```*````WWH``'P```#J>@``!0```&=[
M```'````;7L```P```!U>P``"````()[```&````BWL```@```"2>P```@``
M`)M[```&````GGL```T```"E>P``$````+-[```$````Q'L```D```#)>P``
M$````--[```)````Y'L```D```#N>P``!0```/A[```&````_GL``!D````%
M?```!P```!]\```'````)WP```4````O?```"0```#5\```*````/WP```(`
M``!*?```#0```$U\```)````6WP```8```!E?```$@```&Q\```)````?WP`
M``<```")?```%````)%\```=````IGP```8```#$?```"@```,M\```$````
MUGP```D```#;?```"````.5\```1````[GP```D`````?0``!@````I]```-
M````$7T```8````??0``!````"9]```>````*WT```4```!*?0``#@```%!]
M```&````7WT``"$```!F?0``%0```(A]```$````GGT``!$```"C?0``!@``
M`+5]```B````O'T``!T```#??0``!````/U]```,`````GX```H````/?@``
M"````!I^```)````(WX```4````M?@``#P```#-^```D````0WX```@```!H
M?@``"@```'%^```'````?'X``"````"$?@``(````*5^```F````QGX``!D`
M``#M?@``*0````=_```'````,7\```H````Y?P``#P```$1_```,````5'\`
M``8```!A?P``#P```&A_```2````>'\``!````"+?P``'````)Q_```/````
MN7\```4```#)?P``$````,]_```)````X'\```0```#J?P``"P```.]_```,
M````^W\```\````(@```&0```!B````/````,H```!,```!"@```$@```%:`
M```'````:8````P```!Q@```(````'Z````4````GX```!$```"T@```%P``
M`,:````<````WH```!,```#[@```$0````^!```:````(8$``!X````\@0``
M&@```%N!```1````=H$``!<```"(@0``%0```*"!```9````MH$```0```#0
M@0``!P```-6!```+````W8$```8```#I@0``!@```/"!```&````]X$```4`
M``#^@0``!P````2"```'````#((```4````4@@``%@```!J"```&````,8(`
M``8````X@@``!````#^"```$````1((```X```!)@@``#````%B"```,````
M98(```T```!R@@``"@```(""```.````BX(```4```":@@``*````*""```,
M````R8(```\```#6@@``"@```.:"```(````\8(```D```#Z@@``*P````2#
M```(````,(,``"8````Y@P``$@```&"#```/````<X,```8```"#@P``"@``
M`(J#```(````E8,``"````">@P``"0```+^#```,````R8,```T```#6@P``
M#@```.2#```6````\X,``!$````*A```!@```!R$```&````(X0```<````J
MA```!P```#*$```'````.H0``!8```!"A```#0```%F$```$````9X0```4`
M``!LA```'@```'*$```0````D80```P```"BA```"0```*^$```'````N80`
M``H```#!A```"0```,R$```.````UH0``!````#EA```&@```/:$```*````
M$84```D````<A0``#````":%```/````,X4```@```!#A0``!@```$R%```'
M````4X4```4```!;A0``1P```&&%```-````J84```H```"WA0```@```,*%
M```$````Q84``"4```#*A0```P```/"%```%````](4``"H```#ZA0``"@``
M`"6&```$````,(8```H````UA@``!@```$"&```(````1X8```@```!0A@``
M!````%F&```%````7H8```4```!DA@``&P```&J&```O````AH8``!````"V
MA@``"@```,>&```/````TH8```H```#BA@``"0```.V&```;````]X8``!@`
M```3AP``%P```"R'```.````1(<```,```!3AP``!P```%>'```'````7X<`
M``H```!GAP``!P```'*'``!1````>H<``!````#,AP``#````-V'```:````
MZH<``$H````%B```!@```%"(```&````5X@```8```!>B```'P```&6(```)
M````A8@``!@```"/B```%P```*B(```&````P(@``%<```#'B```$P```!^)
M```3````,XD```(```!'B0``"P```$J)```-````5HD```<```!DB0``%```
M`&R)```&````@8D```@```"(B0``#@```)&)```'````H(D```H```"HB0``
M"P```+.)```'````OXD```D```#'B0``"0```-&)```*````VXD```<```#F
MB0``"0```.Z)```'````^(D```H`````B@``$@````N*```*````'HH```D`
M```IB@``$````#.*```'````1(H``!(```!,B@``!````%^*```'````9(H`
M``4```!LB@``!0```'**```+````>(H``!0```"$B@``$0```)F*```8````
MJXH``!P```#$B@``&0```.&*```'````^XH```4````#BP``#0````F+```(
M````%XL``!<````@BP``"P```#B+```3````1(L```0```!8BP``!````%V+
M```,````8HL```D```!OBP``!0```'F+```'````?XL```4```"'BP``!```
M`(V+```I````DHL``#(```"\BP``+@```.^+```S````'HP``#,```!2C```
M.````(:,```0````OXP``!,```#0C```+0```.2,```M````$HT``#$```!`
MC0``+@```'*-```O````H8T``"P```#1C0``$P```/Z-```K````$HX``!H`
M```^C@``"0```%F.``!%````8XX``$$```"IC@``!````.N.```4````\(X`
M``X````%CP``$P```!2/```8````*(\```8```!!CP``"0```$B/```*````
M4H\```\```!=CP``#@```&V/```%````?(\```@```""CP``!@```(N/```4
M````DH\``!$```"GCP``#@```+F/```"````R(\```X```#+CP``!0```-J/
M```'````X(\```8```#HCP``!````.^/```I````](\``!\````>D```7```
M`#Z0```4````FY````<```"PD```#@```+B0```,````QY````P```#4D```
M$P```.&0```=````]9```!D````3D0``!0```"V1```1````,Y$``!$```!%
MD0``)````%>1```5````?)$``!(```"2D0``#@```*61```9````M)$```@`
M``#.D0``"0```->1```(````X9$```4```#JD0``'P```/"1```&````$)(`
M`!`````7D@``"````"B2```(````,9(``"P````ZD@``&@```&>2```)````
M@I(```H```",D@``%0```)>2```%````K9(``!0```"SD@``!````,B2```0
M````S9(``!X```#>D@``*````/V2```*````)I,``!$````QDP``"P```$.3
M```:````3Y,``!0```!JDP``!````'^3```+````A),```4```"0DP``!@``
M`):3```(````G9,``"````"FDP``00```,>3```:````"90``"@````DE```
M*0```$V4```&````=Y0```4```!^E```"````(24```J````C90``",```"X
ME```+@```-R4```T````"Y4```@```!`E0``%P```$F5```*````894```<`
M``!LE0``$````'25```+````A94``!,```"1E0``"````*65```+````KI4`
M``H```"ZE0``%````,65```R````VI4```L````-E@``!0```!F6```7````
M'Y8```\````WE@``!0```$>6```$````398```T```!2E@``,@```&"6```7
M````DY8``!0```"KE@``!0```,"6```'````QI8```X```#.E@``*@```-V6
M```&````")<```P````/EP``"P```!R7```V````*)<```L```!?EP``#P``
M`&N7```R````>Y<```4```"NEP``!P```+27```1````O)<```<```#.EP``
M!````-:7```'````VY<```H```#CEP``"P```.Z7```,````^I<```,````'
MF```$@````N8```&````'I@``!X````EF```&````$28```E````79@```T`
M``"#F```"0```)&8```#````FY@```<```"?F````@```*>8```,````JI@`
M`!4```"WF```"P```,V8```9````V9@``"````#SF```$@```!29```%````
M)YD```H````MF0``%0```#B9```2````3ID```P```!AF0``!````&Z9```'
M````<YD```P```![F0``4@```(B9```7````VYD```8```#SF0``#0```/J9
M```5````")H``!(````>F@``#P```#&:```4````09H``!L```!6F@``:0``
M`'*:```:````W)H``!<```#WF@``&@````^;```7````*IL``!L```!"FP``
M&0```%Z;```?````>)L``!,```"8FP``!P```*R;```(````M)L```D```"]
MFP``%0```,>;```-````W9L``!,```#KFP```P```/^;```_`````YP``#<`
M``!#G```5P```'N<```O````TYP```H````#G0``"`````Z=```-````%YT`
M`"T````EG0``!````%.=```E````6)T```L```!^G0``'0```(J=```&````
MJ)T```P```"OG0``!P```+R=```)````Q)T``!,```#.G0``"0```.*=```$
M````[)T``!````#QG0``"`````*>```(````"YX```P````4G@``#P```"&>
M```'````,9X``!0````YG@``#@```$Z>```,````79X``!L```!JG@``+```
M`(:>```3````LYX```4```#'G@``!````,V>```7````TIX```D```#JG@``
M"````/2>```*````_9X``!$````(GP``!@```!J?```.````(9\```X````P
MGP``#0```#^?```+````39\```(```!9GP``!P```%R?```&````9)\```D`
M``!KGP``!P```'6?```5````?9\```4```"3GP``!P```)F?```(````H9\`
M``<```"JGP``!P```+*?```.````NI\```D```#)GP``!@```-.?```(````
MVI\```L```#CGP``!P```.^?```(````]Y\```<`````H```%@````B@```)
M````'Z````8````IH```"P```#"@```4````/*````@```!1H```!@```%J@
M```9````8:````H```![H```'````(:@```'````HZ````4```"KH```$```
M`+&@```4````PJ````L```#7H```#0```..@```7````\:````0````)H0``
M"0````ZA```"````&*$```X````;H0``"````"JA```?````,Z$``",```!3
MH0``,0```'>A```G````J:$``$H```#1H0``.````!RB```H````5:(``"P`
M``!^H@``&P```*NB```^````QZ(``$@````&HP``00```$^C``!;````D:,`
M`$D```#MHP``(0```#>D```?````6:0``"L```!YI```(0```*6D```S````
MQZ0``"4```#[I```)P```"&E```P````2:4``&D```!ZI0``/0```.2E``!E
M````(J8``$T```"(I@``+P```-:F```N````!J<``%0````UIP``,@```(JG
M```O````O:<``"P```#MIP``+0```!JH```7````2*@``"4```!@J```,@``
M`(:H```I````N:@``#X```#CJ```(@```"*I``!2````1:D``"4```"8J0``
M"P```+ZI```A````RJD``#````#LJ0``)0```!VJ```<````0ZH``#$```!@
MJ@``!````)*J```-````EZH```L```"EJ@``#@```+&J```+````P*H```4`
M``#,J@```@```-*J``!9````U:H```4````OJP``$@```#6K```$````2*L`
M``<```!-JP``"````%6K```%````7JL``!,```!DJP``#0```'BK```"````
MAJL```<```")JP``!@```)&K```4````F*L```P```"MJP``&````+JK```&
M````TZL``!(```#:JP``#````.VK```#````^JL```0```#^JP``!@````.L
M```'````"JP``!\````2K```-0```#*L```N````:*P``"\```"7K```%P``
M`,>L```@````WZP``!L`````K0``&````!RM```D````-:T``!\```!:K0``
M&@```'JM```:````E:T``"\```"PK0``*P```."M```?````#*X``",````L
MK@``'P```%"N```:````<*X``"4```"+K@``)@```+&N```E````V*X``"0`
M``#^K@``&````".O```=````/*\``"0```!:KP``&````'^O```B````F*\`
M`"4```"[KP``'P```.&O```C`````;```!\````EL```(````$6P```:````
M9K```"8```"!L```'@```*BP```>````Q[````D```#FL```#````/"P```7
M````_;```"\````5L0``)````$6Q```/````:K$``!0```!ZL0``#@```(^Q
M```-````GK$``"0```"LL0``!0```-&Q```'````U[$``!T```#?L0``%0``
M`/VQ```&````$[(```D````:L@``"P```"2R```7````,+(```8```!(L@``
M,P```$^R```'````@[(``"$```"+L@``$P```*VR```,````P;(``!$```#.
ML@``,@```."R```(````$[,```D````<LP``"@```":S```4````,;,```H`
M``!&LP``'0```%&S```(````;[,``!\```!XLP``"````)BS```:````H;,`
M``8```"\LP``!P```,.S```(````R[,```D```#4LP``/P```-ZS```'````
M'K0```\````FM```"````#:T```3````/[0```<```!3M```&0```%NT```*
M````=;0``!<```"`M```%````)BT```*````K;0```P```"XM```%P```,6T
M```$````W;0``"H```#BM```$0````VU```'````'[4```(````GM0``$```
M`"JU```#````.[4```@````_M0``!@```$BU```'````3[4```T```!7M0``
M"P```&6U```4````<;4``!4```"&M0``#@```)RU```O````J[4``"````#;
MM0``'````/RU```3````&;8```4````MM@``!@```#.V```,````.K8```H`
M``!'M@``$0```%*V```"````9+8```0```!GM@``"@```&RV```&````=[8`
M``4```!^M@``#````(2V``!%````D;8``"@```#7M@``4P````"W```9````
M5+<``"````!NMP``-0```(^W``!%````Q;<``#`````+N```*````#RX```F
M````9;@``"4```",N```*````+*X```H````V[@``#`````$N0``$@```#6Y
M```0````2+D``'D```!9N0``"0```-.Y``!S````W;D``'P```!1N@``*P``
M`,ZZ```7````^KH``!\````2NP``%````#*[```*````1[L```4```!2NP``
M!@```%B[```(````7[L``!````!HNP``#P```'F[```$````B;L``!D```".
MNP```@```*B[```)````J[L```0```"UNP``#P```+J[```3````RKL``"(`
M``#>NP``!P````&\```+````";P```4````5O````@```!N\```+````'KP`
M`$\!```JO```"@```'J]```,````A;T```<```"2O0``!P```)J]```"````
MHKT``!(```"EO0``"P```+B]```'````Q+T```4```#,O0``$@```-*]```'
M````Y;T```L```#MO0``"0```/F]```+`````[X```D````/O@``!0```!F^
M```*````'[X```\````JO@``!@```#J^```,````0;X``!(```!.O@``"@``
M`&&^```)````;+X``!T```!VO@``%````)2^```E````J;X``"T```#/O@``
M/````/V^``!`````.K\``$````![OP``1@```+R_```G`````\````4````K
MP```"````#'````.````.L````<```!)P```&P```%'````;````;<````L`
M``")P```!````)7````$````FL````H```"?P```#````*K````*````M\``
M``H```#"P```"````,W````-````UL````T```#DP```!@```/+````?````
M^<````@````9P0``&0```"+!```$````/,$```8```!!P0``'P```$C!```$
M````:,$```@```!MP0``!@```';!```*````?<$```H```"(P0``!````)/!
M```0````F,$```H```"IP0``"````+3!```4````O<$```8```#2P0``#@``
M`-G!```.````Z,$```X```#WP0``"`````;"```*````#\(``!4````:P@``
M!@```##"```&````-\(```8````^P@``"````$7"```&````3L(``!````!5
MP@``"````&;"```.````;\(``!(```!^P@``!````)'"```$````EL(``!<`
M``";P@``#````+/"```,````P,(``!H```#-P@``!@```.C"```(````[\(`
M`!8```#XP@``!@````_#```*````%L,```\````APP``'0```#'#```;````
M3\,``!D```!KPP``&P```(7#```9````H<,```0```"[PP``!````,##```(
M````Q<,```8```#.PP``*@```-7#```C`````,0``"D````DQ```:P```$[$
M```H````NL0``"@```#CQ```*`````S%```G````-<4``!H```!=Q0``&@``
M`'C%```H````D\4``"X```"\Q0``"0```.O%```,````]<4``!`````"Q@``
M#0```!/&```+````(<8```@````MQ@``"````#;&```2````/\8``!0```!2
MQ@``"@```&?&```$````<L8``!@```!WQ@``"````)#&```(````F<8```@`
M``"BQ@``!@```*O&```&````LL8```0```"YQ@``"@```+[&```$````R<8`
M``0```#.Q@``"````-/&```(````W,8```0```#EQ@``"````.K&```$````
M\\8``!0```#XQ@``"`````W'```(````%L<```0````?QP``#@```"3'```$
M````,\<```@````XQP``"````$''```*````2L<```8```!5QP``#````%S'
M```#````:<<```H```!MQP``!````'C'```&````?<<```8```"$QP``!@``
M`(O'```:````DL<```8```"MQP``!````+3'```,````N<<``!(```#&QP``
M$@```-G'```Q````[,<``!D````>R```!@```#C(```(````/\@```@```!(
MR```%@```%'(```*````:,@``!$```!SR```"````(7(```(````CL@```0`
M``"7R```!````)S(```$````H<@```0```"FR```$0```*O(```/````O<@`
M``@```#-R```#@```-;(```-````Y<@```8```#SR```%0```/K(```,````
M$,D```@````=R0``!````";)```*````*\D```@````VR0``!````#_)```&
M````1,D```0```!+R0``!````%#)```(````5<D```0```!>R0``!@```&/)
M```&````:LD```0```!QR0``!````';)```'````>\D```@```"#R0``!```
M`(S)```*````D<D```H```"<R0``*P```*?)```:````T\D```@```#NR0``
M"````/?)```*`````,H```@````+R@``%````!3*```8````*<H``!<```!"
MR@``%P```%K*```4````<LH``!(```"'R@``%0```)K*```=````L,H``!T`
M``#.R@``#````.S*```7````^<H```P````1RP``%P```![+```8````-LL`
M`!,```!/RP``%@```&/+```P````>LL```0```"KRP``!````+#+```,````
MM<L```P```#"RP``"@```,_+```(````VLL```0```#CRP``"````.C+```(
M````\<L```H```#ZRP``"`````7,```(````#LP```@````7S```$0```"#,
M```7````,LP``!H```!*S```"@```&7,```"````<,P```0```!SS```!```
M`'C,```(````?<P```@```"&S```!````(_,```&````E,P```@```";S```
M#````*3,```$````L<P```H```"VS```"````,',```.````RLP```@```#9
MS```!````.+,```(````Y\P```0```#PS```'0```/7,```7````$\T```0`
M```KS0``"````##-```6````.<T```H```!0S0``"````%O-```(````9,T`
M``0```!MS0``$0```'+-```(````A,T```@```"-S0``!@```);-```&````
MG<T``!P```"DS0``*0```,'-```(````Z\T```X```#TS0``!`````/.```'
M````",X``!X````0S@``"````"_.```(````.,X```0```!!S@``"````$;.
M```$````3\X```@```!4S@``"@```%W.```(````:,X```@```!QS@``#@``
M`'K.```(````B<X```X```"2S@``!````*'.```(````ILX```@```"OS@``
M#````+C.```5````Q<X```P```#;S@``"````.C.```)````\<X```D```#[
MS@``!`````7/```*````"L\```H````5SP``"@```"#/```$````*\\```@`
M```PSP``"@```#G/```$````1,\```H```!)SP``"@```%3/```)````7\\`
M``@```!ISP``"@```'+/```)````?<\```<```"'SP``!````(_/```$````
ME,\```8```"9SP``!@```*#/```-````I\\``!````"USP``%0```,;/```4
M````W,\``!````#QSP``$`````+0```;````$]```!`````OT```'0```$#0
M```(````7M````0```!GT```!````&S0```(````<=````H```!ZT```!```
M`(70```3````BM```!$```">T```"@```+#0```(````N]````@```#$T```
M%0```,W0```&````X]````0```#JT```!@```._0```&````]M````@```#]
MT```!`````;1```.````"]$```@````:T0``3@```"/1```$````<M$```0`
M``!WT0``"````'S1```$````A=$```0```"*T0``"````(_1```&````F-$`
M``0```"?T0``"@```*31```.````K]$```8```"^T0```@```,71```(````
MR-$```0```#1T0``!````-;1```$````V]$```8```#@T0``$@```.?1```(
M````^M$```0````#T@``!`````C2```(````#=(```(````6T@``!````!G2
M```+````'M(```0````JT@``!````"_2```3````--(```8```!(T@``"```
M`$_2```*````6-(``!(```!CT@``!@```';2```*````?=(```0```"(T@``
M"````(W2```(````EM(```@```"?T@``"````*C2```&````L=(``!````"X
MT@``!@```,G2```$````T-(``!$```#5T@``!````.?2```)````[-(```0`
M``#VT@``$````/O2```7````#-,```0````DTP``#@```"G3```$````.-,`
M`!$````]TP``!@```$_3```$````5M,```@```!;TP``"````&33```(````
M;=,```@```!VTP``!0```'_3```&````A=,```T```",TP``!````)K3```&
M````G],```8```"FTP``%0```*W3```5````P],``!T```#9TP``$````/?3
M```@````"-0```0````IU```"````"[4```*````-]0```@```!"U```!```
M`$O4```-````4-0```P```!>U```"0```&O4```3````==0```@```")U```
M!````)+4```(````E]0```H```"@U```!````*O4```$````L-0```@```"U
MU```#````+[4```.````R]0```@```#:U```#0```./4```1````\=0```0`
M```#U0``!@````C5```9````#]4```\````IU0``#P```#G5```/````2=4`
M``X```!9U0``$````&C5```0````>=4``!8```"*U0``$P```*'5```/````
MM=4```\```#%U0``#P```-75```1````Y=4``!````#WU0``!@````C6```&
M````#]8```0````6U@``!@```!O6```&````(M8```0````IU@``!@```"[6
M```&````-=8```0````\U@``#````$'6```2````3M8```8```!AU@``!```
M`&C6```$````;=8```0```!RU@``!````'?6```(````?-8```@```"%U@``
M"````([6```*````E]8```H```"BU@``!@```*W6```2````M-8```@```#'
MU@``"````-#6```(````V=8```@```#BU@``"````.O6```H````]-8```X`
M```=UP``!````"S7```$````,=<```T````VUP``!@```$37```*````2]<`
M``0```!6UP``!````%O7```&````8-<```8```!GUP``"0```&[7```.````
M>-<``!0```"'UP``%@```)S7```(````L]<```@```"\UP``!@```,77```&
M````S-<```@```#3UP``!@```-S7```*````X]<```0```#NUP``!````//7
M```=````^-<```P````6V```$0```"/8```/````-=@``!,```!%V```$0``
M`%G8```1````:]@```\```!]V```$P```(W8```4````H=@```0```"VV```
M!@```+O8```*````PM@```H```#-V```!````-C8```$````W=@```0```#B
MV```!````.?8```K````[-@```D````8V0``!@```"+9```"````*=D```@`
M```LV0``&P```#79```#````4=D```@```!5V0``#````%[9```,````:]D`
M``0```!XV0``"````'W9```&````AMD```@```"-V0``"````);9```$````
MG]D```8```"DV0``!````*O9```2````L-D``"0```##V0``"@```.C9```*
M````\]D```P```#^V0``"@````O:```(````%MH``!<````?V@``&````#?:
M```7````4-H```P```!HV@``!````'7:```*````>MH```0```"%V@``"0``
M`(K:```$````E-H``"P```"9V@``"P```,;:```(````TMH``!,```#;V@``
M*P```._:```$````&]L```0````@VP``!@```"7;```2````+-L```D````_
MVP``&````$G;```7````8ML```0```!ZVP``-P```'_;```0````M]L``!``
M``#(VP``!@```-G;```(````X-L```@```#IVP``!````/+;```(````]]L`
M``8`````W```!`````?<```&````#-P```0````3W```"@```!C<```(````
M(]P```8````LW```!````#/<```$````.-P```0````]W```!````$+<```$
M````1]P```0```!,W```"````%'<```$````6MP```@```!?W```"````&C<
M```0````<=P```0```""W```"P```(?<```$````D]P```@```"8W```!```
M`*'<```&````IMP```0```"MW```#````++<```3````O]P``!<```#3W```
M$P```.O<```1````_]P```0````1W0``!````!;=```,````&]T```0````H
MW0``$0```"W=```&````/]T```\```!&W0``!````%;=```&````6]T```H`
M``!BW0``"````&W=```&````=MT```@```!]W0``!````(;=```&````B]T`
M`!H```"2W0``'P```*W=```7````S=T``!P```#EW0``&P````+>```@````
M'MX```H````_W@``$````$K>```;````6]X``!L```!WW@``'P```)/>```<
M````L]X``!T```#0W@``&@```.[>```3````"=\``!,````=WP``&0```#'?
M```&````2]\``"\```!2WP``,0```(+?```"````M-\``!8```"WWP``"```
M`,[?```&````U]\```X```#>WP``!````.W?```&````\M\```8```#YWP``
M#`````#@```(````#>````8````6X```!@```!W@```$````).````8````I
MX```"````##@```$````.>````(````^X```"@```$'@```&````3.````0`
M``!3X```!@```%C@```$````7^```",```!DX```$P```(C@```F````G.``
M``X```##X```!````-+@```)````U^````@```#AX```!````.K@```(````
M[^```!````#XX```%`````GA```$````'N$```@````CX0``"@```"SA```-
M````-^$```P```!%X0``#````%+A```,````7^$``!8```!LX0``#````(/A
M```(````D.$```@```"9X0``!````*+A```0````I^$```8```"XX0``#@``
M`+_A```&````SN$```0```#5X0``'0```-KA```(````^.$```4````!X@``
M!@````?B```-````#N(```0````<X@``!````"'B```$````)N(```H````K
MX@``#````#;B```3````0^(```0```!7X@``"````%SB```$````9>(```@`
M``!JX@``!````'/B```$````>.(```8```!]X@``!````(3B```$````B>(`
M``@```".X@``%0```)?B```F````K>(``!$```#4X@``$0```.;B```6````
M^.(```0````/XP``!````!3C```&````&>,``"L````@XP``%@```$SC```I
M````8^,``"\```"-XP``!````+WC```,````PN,```8```#/XP``!````-;C
M```*````V^,```@```#FXP``"````._C```$````^.,```@```#]XP``"```
M``;D```,````#^0``!H````<Y```"````#?D```&````0.0``!0```!'Y```
M!````%SD```$````8>0```0```!FY```"````&OD```E````=.0```@```":
MY```#0```*/D```*````L>0```0```"\Y```"@```,'D```H````S.0```0`
M``#UY```"````/KD```&`````^4``"<````*Y0``"````#+E```,````.^4`
M`!<```!(Y0``!````&#E```$````9>4```@```!JY0``$@```'/E```$````
MAN4``!(```"+Y0``"P```)[E```(````JN4```@```"SY0``!````+SE```;
M````P>4```\```#=Y0``#P```.WE```6````_>4```X````4Y@``!````"/F
M```*````*.8```H````SY@``!````#[F```&````0^8```H```!*Y@``#@``
M`%7F```*````9.8``!0```!OY@``$@```(3F```2````E^8```8```"JY@``
M"````+'F```0````NN8```H```#+Y@``"@```-;F```$````X>8```<```#F
MY@``"````.[F```Z````]^8```\````RYP``!````$+G```,````1^<``!8`
M``!4YP``$@```&OG```.````?N<``!0```"-YP``$0```*+G``!#````M.<`
M``T```#XYP``$0````;H```-````&.@``!$````FZ```%P```#CH```0````
M4.@```T```!AZ```#````&_H```2````?.@```@```"/Z```!````)CH```L
M````G>@```0```#*Z```#P```,_H```$````W^@``"$```#DZ```(P````;I
M```Z````*ND``!P```!EZ0``$P```(+I```$````END```@```";Z0``(0``
M`*3I```$````QND``"````#+Z0``"@```.SI```3````]^D```0````+Z@``
M%P```!#J```$````*.H```0````MZ@``"````#+J```2````.^H```0```!.
MZ@``"````%/J```3````7.H``!4```!PZ@``"@```(;J```<````D>H``!(`
M``"NZ@``#````,'J```(````SNH``!,```#7Z@``$0```.OJ```L````_>H`
M``8````JZP``#@```#'K```(````0.L```P```!)ZP``%````%;K```$````
M:^L```@```!PZP```@```'GK```$````?.L```@```"!ZP``!````(KK```&
M````C^L```@```"6ZP``!@```)_K```$````INL```0```"KZP``!````+#K
M```$````M>L```T```"ZZP``#````,CK```$````U>L```0```#:ZP``!```
M`-_K```$````Y.L```D```#IZP``!@```//K```$````^NL```8```#_ZP``
M!`````;L```$````"^P``!$````0[```!````"+L```6````)^P``!0````^
M[```#0```%/L```2````8>P``!T```!T[```$````)+L```$````H^P```0`
M``"H[```%0```*WL```G````P^P```4```#K[```"````/'L```(````^NP`
M`!(````#[0``!````!;M```&````&^T```@````B[0``!````"OM```&````
M,.T```8````W[0``#@```#[M```/````3>T``!$```!=[0``&````&_M```<
M````B.T``!8```"E[0``*````+SM```;````Y>T``!T````![@``'0```!_N
M```1````/>X``!D```!/[@``,@```&GN```O````G.X``#$```#,[@``+P``
M`/[N```7````+N\``!<```!&[P``%@```%[O```3````=>\``!\```")[P``
M$P```*GO```9````O>\``!$```#7[P``0@```.GO```D````+/```#D```!1
M\```+P```(OP```7````N_```!L```#3\```.````._P```E````*/$``!X`
M``!.\0``'@```&WQ```;````C/$``!$```"H\0``&0```+KQ```;````U/$`
M`!L```#P\0``)`````SR```/````,?(``#T```!!\@``$P```'_R```(````
MD_(``!,```"<\@``+0```+#R```7````WO(```\```#V\@``)`````;S```$
M````*_,```@````P\P``"````#GS```(````0O,```L```!+\P``!````%?S
M```&````7/,``$\```!C\P``!````+/S```-````N/,```0```#&\P``"@``
M`,OS```$````UO,```0```#;\P``$````.#S```&````\?,```8```#X\P``
M!@```/_S```&````!O0``!4````-]```"@```"/T```2````+O0```8```!!
M]```#@```$CT```,````5_0```0```!D]```!0```&GT```&````;_0```8`
M``!V]```$@```'WT```=````D/0``!X```"N]```'P```,WT```.````[?0`
M`!8```#\]```$@```!/U```2````)O4``!<````Y]0``$@```%'U```2````
M9/4``!$```!W]0``&@```(GU```1````I/4``!(```"V]0``%@```,GU```7
M````X/4``!(```#X]0``%0````OV```3````(?8``!`````U]@``%P```$;V
M```2````7O8``!<```!Q]@``$@```(GV```2````G/8``!$```"O]@``%@``
M`,'V```8````V/8``!8```#Q]@``'@````CW```?````)_<``!@```!']P``
M$@```&#W```7````<_<``!8```"+]P``!@```*+W```(````J?<```0```"R
M]P``'@```+?W```;````UO<```X```#R]P``$`````'X```$````$O@```0`
M```7^```)````!SX```$````0?@```8```!&^```$P```$WX```.````8?@`
M``0```!P^```!P```'7X```(````??@```\```"&^```!````);X```E````
MF_@```8```#!^```'0```,CX```(````YO@```@```#O^```"````/CX```;
M`````?D```8````=^0``!P```"3Y```&````+/D```T````S^0``#````$'Y
M```1````3OD```0```!@^0``$@```&7Y```&````>/D``!@```!_^0```@``
M`)CY```(````F_D```0```"D^0``"````*GY```D````LOD```0```#7^0``
M"````-SY```$````Y?D```\```#J^0``!P```/KY```,`````OH```H````/
M^@``#@```!KZ```,````*?H```8````V^@``"````#WZ```=````1OH```0`
M``!D^@``&P```&GZ```0````A?H```0```"6^@``!@```)OZ```(````HOH`
M``0```"K^@``!````+#Z```$````M?H```0```"Z^@``"0```+_Z```(````
MR?H``!$```#2^@``$@```.3Z```(````]_H``",`````^P``#P```"3[```-
M````-/L```@```!"^P``!0```$O[```&````4?L```H```!8^P``"@```&/[
M```-````;OL```(```!\^P```@```'_[```,````@OL```0```"/^P``!```
M`)3[```+````F?L``#T```"E^P``(0```./[```E````!?P```L````K_```
M%P```#?\```_````3_P``"$```"/_```'````+'\```5````SOP``!,```#D
M_```$P```/C\```3````#/T``!,````@_0``'@```#3]```0````4_T```@`
M``!D_0``40```&W]```(````O_T``"L```#(_0``40```/3]```;````1OX`
M`!,```!B_@``#P```';^```/````AOX```@```"6_@``!@```)_^```&````
MIOX```@```"M_@``"@```+;^```4````P?X```0```#6_@``$P```-O^```#
M````[_X```0```#S_@``!````/C^```)````_?X```D````'_P``&@```!'_
M```&````+/\```@````S_P``!0```#S_```%````0O\``!````!(_P```0``
M`"H#``#X`0``'`,``)@"``#M`P```````'`#``#&`@``"`,```0$``!7`@``
ME`(```````">`0``4@$``%,#``"N`0``L@```#T$```)`@````````````"A
M`0``Y`,``)P#```E`0``E0$``)D#````````K@(```````!2`P``B`$``/@#
M````````%P0`````````````/`$``#L"```W`@``%P,``&(#```/`0``\@$`
M`,0```#`````F0$``$\"``````````````````!<`````````$@#``!C!```
M``````````#J`P``;0,``#D#``#``0``M0```.4#```>!````````&L"```?
M`P````````P"`````````````&<!``#5`P```````(D```"#`@``=`0``%\`
M``#J`````P$```````!5````M0(``````````````````&8"``"M`@``````
M`!P!``!4`@```````.,#``"8`````````(H````*`@``!@```.\```""````
M`````$4#```%`@``W`(`````````````.`(````````6!````````&<$``"J
M````'0(``#`!````````T0,``.,`````````X@```%H```"(`P```````/4`
M```F`P``BP$``.T````3`@```````#,```!R`@``8P(``!@!``!?!```2@(`
M`+(#``"6`P``A`,``$0!``!1!```4````%<$```X`````````&8````"`@``
M`````$<"``"!`0``AP$``/L#``````````````````!9````8`(``!,!````
M````F0```.P#``#_`0``#`,``&H!``!<!```@````"L#``!A!```D0```'H#
M``!X!```[P$``,T```#3````.`,``/P!``#0`@``;@,```H#``"A`P``X0``
M````````````6@$``"$#``"X`@``^@``````````````SP$``+L```!J`P``
MMP(``#\#``!A`0``KP(``"P"````````]````````````````````!P````2
M`0```````*(````\````N@,``!<"``!X````'@(``$4$```?`0```````"(`
M````````"P(``-T`````````K`$``````````````````'D```#Q````````
M``````#8`P````````````!O`P```````#0$``!"`````````&D#```M!```
M^0```-`!```'!```CP$``*,#````````T@(``(X!```^`P``)@$``*0#````
M`````````"````!)`0``-`(``)0````1`@``<0,```T"```F`@``=0(``!<`
M``!U````[@(```````#7`@``G0$```````"K`P``I0(````````C!`````,`
M`!<!``!J`@```````%D"``!Y`P`````````````K!````````#<````^`@``
M)`0``!@```#-`0``S0(```````"F`@``=`(``$X#``#C`0```````",`````
M````;@(``%X$````````+0,``!0$``#+`P``H0````,"```Q`P``,@```$(!
M``!H`````````````````````````.$#`````````````,H#``"J`@``1@(`
M```````$`P``6@0``%@!````````O`(``-$!```T`0``0`(``',$``#H`P``
M-@0``!H"``!.````K0```-L#```G!```KP,``"L```!;!```D`(``/8!```4
M`0``+@$``/D"```U`P``+@(``$P#``!Z````FP````````!+````Q0$``.L`
M``"``@``\`,``*P#``#Z`0``?@,```````#'`@``7P(````````P!```/P0`
M`%($```;`0``2P(``)H`````````EP$```````!A`P``%`,``#,$````````
M6P$````````W`0``_`,```````!+`P````````````!6````<`0``%\#````
M````(0(``'$$``!P`0``^@,``-T#```X!```W`,````````"`0``^`(`````
M```O`@``S`,``%P"```E`@``6P(```$!``!#!```5`````````!O`0``K@``
M`!D```#)`@``\P(````````Q`0``X@,``+0```!`````\P```'``````````
M`````)T"``"1`@``6P```-L"``"?````[@$``-$`````````2`(``,D!````
M````*@0```````"<`@``>@$``.L"```L!```U0(``/X"``"/`@``````````
M``!=`````````"$!```K`@``2P$``+$!```5`P``D`$``%`$``#T`@``````
M`$8```#.`@``?0```',#``!)!```C@(``'L#``#_`P``@@(``$X"``#A`0``
M2`0```````"P`@``.P$``%$!``"@`P``0P(```````"&`0```````*,`````
M````1`,``&8$``#G`P``2@$``*(!``".````10````````!'`````````%\!
M````````$00``+0"```A!```S`(``!D$````````/`(``-T!````````IP(`
M``````!L`P``9`(``$`$``#D`@````````\$``"Y`P``BP```*,"````````
M```````````&`0``=@0``'X"``"W````EP(```````!X`0````$``$@!````
M`````````/L!```.!```8P,``/<````[!````````%$#````````RP(```,$
M````````@P,``'8"``#O`@``B@$```````"T`0``P@```$\!```D````30$`
M```````Y!`````````````")`0``<0$``"@```!^`0``2```````````````
M`````#`````Q````?0$``+$#```I`P``1`0```L!``"<`0``@P$``#X$``!D
M`P``A0,``-X`````````_0(```````#!`0```````#T"``#``@``$`$``!$#
M`````````````$T$``#(`@``(`,```4#``!:`@```````,(!```3`P``0`$`
M`+@#```&`P``*`(``.(!``!8`@``[@,```````"F`P``]@(``$\#``!\````
M0P,``,<```"$`````````)@!``!6`P``Y`$``%8"```(````Y0(````````+
M`P``^0,``,$#``#6`P``1@0`````````````R0```(8```!G````"P0``"8`
M``"-`0``\@,``'\```#\`@``Z0$```````!7`0``#0$``/<#``"]`@``5`,`
M`,L!```Z`P```````'4$```\!```OP(``!@$``"G`P```````/$#``!B!```
M`````#D!```B`@``(@0``&0$``#6`@``^````%4#``"(`@``)00```D#``"E
M`P``30````0"````````^@(``,8!``"=````>`(``#D``````````````%4"
M```W`P``S@``````````````0`,````````:!```&`,```````#O`P``QP,`
M`'0#```&`@``U````%P#````````<0```#`#```````````````````>`0``
M=@,``%@````5`@``B@(```````#_````.0(``*\!`````````````(L"``#J
M`@````````4$``#/`````````&L!```&!```\0(``'D"```(!```'@,``/L`
M````````J`,``-D````.`0``NP(``.P!```]`0``8P$`````````````````
M`*0"``"'````ZP,````````=````5`$```````!\`P``&`(``)`````I`@``
M`````#(#````````+0(``%$````S`@```````,@#``"D`0``?`(``-<#``#%
M`P```````%T"``#$`0``X`````0```!I````?P,``)0!```G`P``WP,`````
M````````9@,``+X#```@`0``'0$``/````!)``````````````#P`0``P@(`
M`-H#``"'`P``&P,``%D$````````J`$``.P"```O!```7@$``!X````O`0``
M`````)4"``````````````````#*````RP``````````````6`,``.L!````
M`````````-X!``"Z````Y@,````````"`P``L@$``````````````````'L"
M````````D@$```````"Y````7`$```````!V````C`$```````!K`P``````
M`,0"``"!`@``O0```$0```#8`0``CP```"D!```6`0``/0```,,!````````
MA@,``)4#``"L`@``D@````````"C`0```````+X!````````S@$````````O
M`P``LP$```````!=`0``#0,``/T#``#7````N@$``-X#````````E@```#8"
M`````````````+T#``!=!```GP(``*0```#\`````````)H!````````:`(`
M`+T!````````%@,``+8`````````+@```"@$````````Q@```'H$```H`0``
MDP```)\#````````Z0````````!L`0``.@$``#L`````````3P```!`$```Q
M`@``8P```!L"``#I`@```````+L!```S`0``#`0``#H$``!>`P``S`$`````
M``"G`0``#````*D"``!!``````````,#``````````````````"B`@``N0(`
M`&P"```U`````````)\!````````\P$`````````````4@```%4!````````
M``````````!_`0```````)(#```-`````````(0!```_```````````````)
M!```=P,```````!/!````````.D#````````4`,``-D!```H`P``/@$``$X!
M````````V@```,4"``"R`@``'`(```````">````$@(``(D"```3````-00`
M`"H!``!!!```U@`````````1``````````````"F````/`,```````!'!```
M`````/L"```=!```Y````"L!``#5`````````%,"``"4`P```````$$!````
M````0@0``/<"````````#`$`````````````M@,``.8```!S````:`,`````
M``"^``````````````````````````````!.!````@0``$8!```2````F@(`
M`&4"``#2`0```````.,"``#]````#P,```H$``"0`P``:@0````````=`P``
M,P,``#(!```"````]P$```<!```A````'P(``*L!````````.P,``&(!``!>
M````3`$``-T"```$`0``D0,```````!E!```H`(``)L!````````"@``````
M``"<````V0,``*L"``",`P``C`(``*@`````````;@`````````B`0``X`$`
M````````````#@```!4`````````.@(``$<!```N`P``U0$```````#0`P``
M0@,``$P"``#,````&@$```````#/`P``8`,``````````````````+\````I
M````K@,``&<"```G````)P$```````!-`@```````!4$``!%`0``VP```-,#
M``".`P``D0$```````!I`0``F`,``(4"````````I@$``,,```"3`P``^0$`
M``````"K````OP,``($`````````DP$``)("```6`@```````'L$``!!`P``
M?`$``+`!``!9`0``WP(``+$"``!2`@``%0$``)T#````````KP```%<#``!=
M`P``````````````````C0```#("```V`0``\@(``($#````````>`,``/(`
M````````;00``.`"````````%`(```````!0`0``+````-$"``"'`@``MP,`
M`-,!``#9`@```````-,"````````)`(``,@````E````9`$``+P````_`0``
M#P```'L```#?`````````%L#``"6`0````````````#H````5@0``-H!``";
M`@```````)8"``#"`P```````$D"```V`````````/8```"J`0``G@,``-L!
M`````@``CP,``,X#``#N`````````!($``!#````]0,``(8"```D`0``(`0`
M``````#2````]@,``'T#``!^````````````````````H0(`````````````
MN0$``.T"``#B`@``(P$````````<!`````````````"X`0``(@,```$#```I
M!````````+8"````````<P$``'(```#^``````````````!U`P``K0,``'4!
M````````O`,````````9`@``L`,``%,```#^`P``P0`````````0`P``M`,`
M`.4!````````;@$``*D#```T````=P0``$0"```T`P``M0,``&D$``#%````
M``````````"G````!P```,$"``!@!````````&@!``!K````500```````"B
M`P``\0$``/T!````````A`(``*4```"5`````````-X"``!Y`0``9P,`````
M``!"`@``K````&\$``!S`@``"`(``$D#````````=`$``%$"``"S`@``<@0`
M`,`#``"^`@``+0$``-P!``!W````/0,```````"*`P``%@```&P$````````
M@`,``%,!```.`@``%````#4"``"U`0``A0$``'D$````````X`,``"T`````
M``````````````"J`P``2@```-``````````4P0```$"``"@````"`$``-0#
M``!@`0```````$P```#?`0``)`,``,H"````````"0$```````!H!```PP,`
M``````!6`0```````/X!``#'`0``-@,``````````````````'L!```9`P``
MT@,``,\"``#U`@``,00``.<````.`P``S0,```$$````````F0(``+P!``"V
M`0``LP```%H#```0````[````"8$```?`````````.8"``````````````D`
M``!8!```8@```!\$``!%`@``;@0```````!M`0``N@(``/0#``!E`0``````
M`,D#````````F@,```````"-`@``(`(``&\"```_`@``;````+L#````````
M`````$<#```;`````````(L#``!T````80(``*@"``#$`P```````.<"````
M````<`(``'8!```-!````````-P````1`0``:@`````````:````7@(``#4!
M````````Q@,```````!Q`@``C0,``&T"```C`@``>@(`````````````3`0`
M``````#M`0``!P(``+````##`@``\P,``-@"````````=P$``"<"````````
M````````````````X0(``.8!``">`@``UP$``$$"``"``0```````.H!``!]
M`@``.`$``!D!````````]0$``%D#``!*`P``$@,````````E`P``2P0```,`
M```N!````````+\!`````````````),"``"(`````````'<"````````"P``
M`/\"``!B`@``:0(```H!``!E`P``V@(``+,#``#*`0``5P```%`"``!4!```
MFP,``-0!``")`P``0P$``*4!``!O`````````&`````P`@``N````&T`````
M````+`,```4```!E````+`$```\"``#8``````````````#4`@``C```````
M``"7`P``&P0``.<!````````&@,````````J`@``9@$```4!``#6`0``@P``
M`*D```"M`0``A0```'(!````!```J0$``$8#```W!```2@0````````^````
M+P```)<````J`````````((!```3!```,@0```<#````````Z`(``*`!````
M````@@,``!`"```C`P``\`(``.4````Z`````````'(#``!-`P``````````
M``!_`@``L0```&0`````````MP$``.@!``#T`0```````,@!``!A````:P0`
M```@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AY
M97-T97)D87DI`"!A="``)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S
M($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE
M;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E<75I
M<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E
M<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER
M96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O
M=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D
M9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D
M9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB
M97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E
M<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A
M;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN
M`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N
M86UE`$%L=&5R;F%T92!T96UP;&%T97,`06UE<FEC86X@4V%M;V$`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N>6UO=7,@4')O>'D`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"
M87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L
M>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O
M=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)
M+3@I`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-I82]086-I9FEC(%)E9VEO
M;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"86-K9W)O
M=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S
M('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S
M`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W-N:6$@86YD
M($AE<GIE9V]V:6YA`$)O='-W86YA`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA
M;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0V%L96YD87(`0V%L
M;0!#86UB;V1I80!#86UE<F]O;@!#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U
M<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R
M960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M`$-A<&4@5F5R9&4`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QT:6,@
M*$E33RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&EL90!#:&EN80!#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`
M0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:')I<W1M87,@27-L86YD
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&EC:R!T;R!#
M;VYT:6YU90!#;&]S92!7:6YD;W<`0VQO=61S`$-O8V]S("A+965L:6YG*2!)
M<VQA;F1S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VUI8W,`0V]M
M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O
M<P!#;VUP86YY`$-O;F1I=&EO;G,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S
M<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F
M('1H90!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;VL@27-L86YD<P!#;W!Y
M('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@;V)T
M86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@
M;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#
M;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U
M;G1R>0!#<F5A=&4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES
M<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT
M(%1I;64`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R
M<F5N="!S='EL90!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])
M."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T90!$871E
M(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$96-E;6)E<@!$96-R96%S
M92!);F1E;G0`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5L971E($=R;W5P
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E
M<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R;6%T`$1J:6)O
M=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$
M;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O
M<"!D;W=N(&QI<W0`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C
M:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS
M`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL
M`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M
M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E
M+@!%;7!T>2!R97-U;'0N`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5Q=6%T
M;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17-T;VYI80!%=&AI;W!I80!%
M=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!I<F%T
M:6]N($1A=&4`17AP;VYE;G0`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@
M(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&
M86EL960@=&\@;6]V92!T;R`B)7,B+@!&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RD`1F%R;V4@27-L86YD<P!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&
M965L<R!L:6ME.B``1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U
M;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!U<&QO
M860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N
M9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]R96-A<W0@1&%Y
M<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O
M=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R
M97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@
M='EP90!&;W)T=6YE<P!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;F-E`$9R96YC
M:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F]M`$9R;VT@=&AE(`!&=6QL
M($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%M8FEA
M`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5O<F=I80!'97)M86YY`$=H
M86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O;V=L92!396%R8V@`1W)A
M>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R
M96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`
M1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'
M=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(96%D97(`2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AO;'D@4V5E("A6871I8V%N($-I
M='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R
M87,`2&]N9R!+;VYG`$AO<F1E`$AO<FEZ;VYT86P@4G5L90!(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2'5M:61I='D`2'5M:61I='DZ
M(`!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,@;F]T(&%V86EL
M86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C
M:RX`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!);6%G92!U
M<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN
M9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!486)L90!);G-E<G0@
M5V5B($QI;FL`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@;65S
M<V%G97,`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`
M26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)
M1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y
M<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES
M<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!)
M;G9A;&ED('!R;W1O8V]L+@!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)
M<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-R865L`$ES<W5E<@!)=&%L:6,`
M271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R
M,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K
M:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y($9I;F=E
M<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VER:6)A=&D`
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L
M(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A
M;@!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I
M;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E
M<@!,871V:6$`3&%Y;W5T`$QE8F%N;VX`3&5S;W1H;P!,:6)E<FEA`$QI8GEA
M;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6YK`$QI;FMS`$QI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($AE;'`@5&]P:6-S
M`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO
M9R!O=70`3&]G:6X`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%I;`!-
M86EL($%D;6EN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A
M`$UA<F-H`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@
M;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L
M;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N
M:6$`36%U<FET:75S`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365M8F5R<P!-96YU(&UO9&4Z
M`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N
M`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE
M=&AO9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@
M=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1I9FEE9"!$
M871E`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O
M;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H
M87-E<P!-;W)O8V-O`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-
M;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&EP;&4@
M<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO
M=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA
M=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE
M='-C87!E($)A<V4@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E
M('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!-;V]N`$YE
M=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@
M*%]B;&%N:RD`3F5W<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG
M97(`3FEG97)I80!.:6=H=`!.:75E`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N(&ES('-E="X`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BX`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;W)D:6,@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H
M97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O
M<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=F5M
M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L
M=6UN<P!.=6UB97(@;V8@<F]W<P!/2P!/8FIE8W0@0W)E871O<@!/8W1A;`!/
M8W1O8F5R`$]F9FEC90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O
M<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L
M(%5N:70`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!4
M97)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A
M<F%G=6%Y`%!A<W-W;W)D`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A
M<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T
M90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!H:6QI<'!I;F5S`%!H
M;VYE`%!H;W1O<P!0:71C86ER;@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@
M;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W
M;W)D`%!O;&%N9`!0;VQL<P!0;W)T=6=A;`!0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S
M:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T
M('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:6]U<R!O<'1I
M;VYS`%!R:79A=&4@2V5Y`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`
M4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+@!0=65R=&\@4FEC;P!1871A<@!24T$@4'5B;&EC($ME>2`H)60@8FET
M*0!2861I;R!S96QE8W1I;VX`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@4&]R=&%L(%9I
M97<Z`%)E9V5X`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@
M0FQO8VL`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!U<V5R`%)E;6]V
M92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z(`!297-E=`!297-U;'1S`%)E='5R;B!T;R!/<'1I
M;VYS`%)E=6YI;VX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE
M9G0`4F]T871E(%)I9VAT`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!380!3
M86EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA
M`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E
M<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-E87)C:`!396QE8W0@82!D871E`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+@!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N
M=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T
M`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H
M;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E
M9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('!I8VME<@!3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/P!3:')I;FL`4VEE<G)A($QE;VYE`%-I9VX@=7``
M4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W(&1E<'1H
M.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]R="!O<F1E<B!S96QE8W1I
M;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86EN`%-P86T`
M4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W)I($QA;FMA`%-T86YD87)D`%-T
M87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R
M;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`
M4W4`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3
M=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T
M.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB
M87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N
M9`!3>7)I86X@07)A8B!297!U8FQI8P!44U8@9FEL90!486EW86X`5&%I=V%N
M+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R
M`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E
M.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&@`
M5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES
M(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`
M5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S
M92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AI<R!)34%0('-E<G9E<B!D
M;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S
M(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE
M;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C
M=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A
M8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E
M<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:6UE`%1I
M;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M
M3&5S=&4`5&ET;&4`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W
M:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`
M5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4<FEN:61A9"!A;F0@5&]B86=O`%1R
M=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X
M-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4
M=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),
M.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N
M('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE
M8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("5S
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92X`56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI
M;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;FEC;V1E("A5
M5$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI
M=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',`56YI=',`56YK;F]W;@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A
M=&4@=7-E<@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D
M960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N
M`%5R=6=U87D`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S
M97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T
M:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S
M(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!6
M86QU97,`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9I970@3F%M`%9I971N
M86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN
M($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O
M;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))
M4%0@34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN
M9P!790!796%T:&5R($9O<F5C87-T`%=E8@!796(@4VET90!7965K;'D`5V5L
M8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX
M.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`
M5VEN9#H@`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S+"!)($%G
M<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S
M;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M0<F]B;&5M(%)E<&]R=%T`
M6VQI;F4@)7,@;V8@)7-=`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<P!H.@!I;6UE9&EA=&4`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I
M;7!L96UE;G1E9`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C`*4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`Q+3`V
M+3$X(#(R.C`U*S`X,#`*3&%S="U4<F%N<VQA=&]R.B!L:6%O8FEN(#QL:6%O
M8FEN0&II=&4N;F5T/@I,86YG=6%G92U496%M.B!#:&EN97-E(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4=",C,Q,@I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X+6)I=`H`("@E<R#,[,>P*0`@*+_LO=V\_"`E<RD`("B]
M\<SL*0`@*-?RS.PI`-/:`-?NO?P@)60@S.S&^,_SU*2QJ``E<R`M(+&XS?S"
MO``E<R#6N,[&`"5S($M"`"5S(,ZLNZ2RV=?W("T@R+?(SP`E<R#7HK+A`"5S
M(,VLTN+/[L2_`"5S(-+1M.;4V@`E<R#4VB`E<R`E<P"QV-#HTJH@)7,`)7,@
MM]8`U=*RN[6]("5S+@`@)7,@M;T@)7,@N;(@)7,`)7,Z("5S`"P@U?.WYR`E
M<R`E<P`LL>2[K\&_M-,@)7,@M;T@)7,`+2T@T:'4\2`M+0`R-"#0H<JQUL8`
MM,O'^+_IL=C0Z]*JUKBVJ,K]OMV_XK?^SO&VRRX`MZ+)^L'+TKNX]M'/UMBU
MQ+3MSO,`T_N\T\/<T\J\_BR[N=#HTJK3T-*[N/8@4$=0(+FKOZK#W-2_+@#3
M^]'IUJ32T<>IP_NUQ-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""YJ[^JP]S4ORX`
MT_N]XL/<T\J\_BR[N=#HTJK3T-*[N/:YJ[^J(%!'4"##W-2_+,N]P]P@4$=0
M(,/<U+\LTM2\L+_:P>XN`-/[UK30T-/*O/['J</[++NYT.C2JM/0TKNX]KFK
MOZH@4$=0(,/<U+\LR[W#W"!01U`@P]S4ORS2U+RPO]K![BX`T_N]XL/<T\J\
M_BR[N=#HTJK3T-*[N/:YJ[^J(%--24U%(,/<U+\LR[W#W"!334E-12##W-2_
M+-+4O+"_VL'N+@#3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J(%,O
M34E-12##W-2_+,N]P]P@4R]-24U%(,/<U+\LTM2\L+_:P>XN`-/[O-/#W-/*
MO/XLN[G0Z-*JT]#2N[CV(%--24U%(+FKOZK#W-2_+@!!32]030!!4$D@L>"Z
MQ0"YV-/:U>*X]K'@O*W&]P"YV-/:+BXN`,BHS]ZRN]?C+,[>MZB]J,&B(%9&
M4R#$O\*\+@#(J,_>LKO7XRS.WK>HO:C!HB!61E,@SL2\_BX`U<NZQ=+1MK.]
MX2X`O>'5R@#0PM3V`-#"U/;/PKRVU^D`T,+4]L_"O+;(J,_>`-3:M,O0PM3V
MH[H`T,+4]M/#NZ?7Z0#0PM3VR*C/W@#0PM3VTKNX]M/#NZ<Z`-#"U/;2N[CV
ML\G4L3H`T,+4]K;4`-#"U/8@)7,@SJH@36]Z:6QL82!3:61E8F%R(+++M:4`
MT,+4]M/#NZ<`T,+4]M/#NZ>UQ+FFQ-RUL<>PL;NYV+'5+@"UV-:W`,VHT;:R
MO@"SR<ZJN=S`[=2Q("T@SJK&Y,O\T\.[I\7DUL/(J,_>`+G<P.T`N>.XYKG<
MP.T`L**XN[JY`+"BMONPS<3AT<<`L**V^[RPP/O1QP"Q\,/[`,OYT]#2T='I
MUJ2UQ-/#NZ<`R_G3T-/#NZ?7Z0#+^=/0R*C/W@#4RM#MMN"X]K7GU]/3RKS^
MM=C6MP#2T;3FU-H`L>2X_"!)35-0(+7'PKP`L>2X_"!)35-0(,/<PNL`L>2X
M_"!)35-0(-/#NZ<`L>2X_,2CL.8`P\#*],CXQ*;1QP#2N[CVLKNZS[>HM<36
MM;&[RKG3PRX`L+*UP+;[`+"RN.?`K0"PLKGGP*T`Q.3#^[3ZP.T`Q,^\J];>
M`+"RS.&YS[RPL,VV^[*\M.\`TZ;3P[/,T/(`TZ;3P[/,T/+2T;[-T/<`TZ;3
MP[6]R_G3T,_"O+:YLL_M`,7ZU[P`R\34P@"PHL"MLJ[.Q"`H5VEN9&]W<RTQ
M,C4V*0#1N<OUSL2\_K3ST*$`T;G+]<[$O/[#^[/&`,3ZR+>VJ-*JR;ZS_2`E
M<R"UQ->BLN'"\"`_`+"BN/G-H@#1Q\/`Q.'1QP#1Q\/`Q.'1Q\[$("A!4DU3
M0TE)+3@I`+"BPK.PS0"PHLFMR\G(NK6Z`-''UMXOS*O&O='SM=C'^`#6M-#0
MSJR[I++9U_?'L,_4RK[(M\C/MM2[L+_R/P#*U,V\R;ZS_=*[N/:RN[3FU-JU
MQ-/#NZ?7Z2X`RM3-O,F^L_W2N[CVLKNTYM3:M<3(J,_>+@#*U,V\L>"\K=*[
MN/:RN[3FU-JUQ-/#NZ?7Z2X`RM3-O+'@O*W2N[CVLKNTYM3:M<2YLL_M+@#*
M]-#4`+#+U,(`L,2T\\#[T<<`L,*UV,#[`$%U=&A?8W)Y<W%L.B#5TK*[M;W+
M^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^+@!!=71H7V-Y<G5S.B"W_L[QMLNRHLZT
MS.&YJ;C#S^[6I[/6+@!!=71H7V-R>75S.B#5TK*[M;W+^=#HTJJUQ"!I;6%P
M(,"IU;G7Z;S^+@!!=71H7V9T<#H@U=*RN[6]R_G0Z-*JM<0@1E10(,"IU;G7
MZ;S^+L?KUMC0PK'@TNL@4$A0(+*BQ]*\T\CK("TM96YA8FQE+69T<"#1H<_N
M+,#]R.<@8V]N9FEG=7)E("TM96YA8FQE+69T<`!!=71H7VEM87`Z(-72LKNU
MO<OYT.C2JK7$($E-05`@P*G5N=?IO/XN`$%U=&A?:W)B-3H@U=*RN[6]R_G0
MZ-*JM<0@:W)B-2#`J=6YU^F\_BX`075T:%]L9&%P.B#5TK*[M;W+^=#HTJJU
MQ"!,1$%0(,"IU;G7Z;S^+@!!=71H7VQD87`Z(,[>MZC0PM3VT\.[IR`E<RX@
MM_[.\<;WN]C3ICH`075T:%]L9&%P.B#.WK>HR;ZS_=/#NZ<@)7,`075T:%]L
M9&%P.B#.WK>HN/S0PM/#NZ<@)7,`075T:%]M8V%L.B#5TK*[M;W+^=#HTJJU
MQ"!-0T%,(,"IU;G7Z;S^+@!!=71H7W-M8F%U=&@Z(-72LKNUO<OYT.C2JK7$
M('-M8F%U=&@@P*G5N=?IO/XN`-'IUJ3*I[#<+@#1Z=:DRJ>PW"X@)7,`4D%$
M2553(-'IUJ2T[<[S+@!&5%`@T>G6I+3MSO,N`+_)T\.UQ-?6MLXZ`+"BR/NP
MW;VN`+&SOK#1U<FK`&ME<F)E<F]S(,/<PNNT[<[S+@!K97)B97)O<R#3P[NG
MP_NT[<[S+@"PS;G^PNW(NK6Z`+#-P=8`LJC"WK7$NJ/.Q"`H25-/+3@X-3DM
M,3,I`,//O-/`K;GZ`+#-L,VVX,NY`+#7MNW"WLNY`+'(P/O*L0"RKL#[U\@`
ML;3$_@"PV<2]M//(NK6Z`+*[M:0`R?K(U0#'^+_IQ>36PP#'^+_IP.#0S0"T
MULSE`+*CP/O.K-''`,KIQZD`LJC+N<3AT<>ZS;K:R/NXY\ZLQ,<`LJFTQ,W?
MQ,D`LJC.K,S8M;H`L,W.]P#3HLKTTZ&VR-'SP>RUV`#.Q,"S`+&CO-/`^]''
M`,_NQ+^W^[K%`+*\O*K$R;>HR_<`LKS"H;7/`,3:R-VYW,#MS[7-LP!#4D,`
M0U),(+?6LKRUXP#(U<#Z`,'CO+:WYP"\[<;2U:\`OZ;"\\*A`,[>MZC!JKOZ
MUL$@24U!4""W_L[QQO<Z("5S`+S3Q,.T\P#(H<_[`,BAS_O.RLSBL:BXY@#.
MWK>HR;ZS_<[$O/X@(B5S(BX`SMZWJ,F^L_W$O\*\("(E<R(N`,[>MZC6V-?I
MH:/+^<SAN:FUQ+S'PKS*_<2_T^O/R,>PR_FQH[3FM<3*_;[=LKNW^RX`SMZW
MJ+2KR\W0Q<^BM;W6N+:HM<2ZQ<+K+@"W\+7#O<<`OZK"_,BZM;H`TL:VK[7G
MN[``R/NV^\S8SL0@*$E33RTX.#4Y+3$T*0#6T+?'N;*ZS;GZ`-;0Q;<@*$E3
M3RTX.#4Y+3(I`,:^UJ3/N+W:`,:^UJ2RW\+4`-6GM<,`N/RXQ`#6Q\#[`-;0
MN?H`O/+,Y=;0SL0@*$=",C,Q,BD`M[',Y=;0SL0@*$)I9S4I`-&AU/'#W,+K
M`-&AU/'2N[CVT\.[I\/[`,C5QMK/U,J^M[W*O3H`RJ6UKK6Z`-72LKNUO2`E
M<R"UQ,#@L?"VJ-+E+@"PM,KSL>J\_+S,T/@`N=BQU;2PO]H`U,;!OP"_QK_&
MR[G(NK6Z`+CGPM>QR-''`-'5R:L`M??)J\7,`+^HS:@`P_S![@##_,'NO<6Q
MO@#&P,+;`,VHT\/#^P"_QL2FPMX`N:O+O@#,];S^`,7DUL,@)7,`R+?(S\/<
MPNL`N-6Y^P"XU;G[N;*ZS;GZ`,&LO=/*I[#<.B``P:R]T];!N:N_JL/<U+^W
M_L[QQO?*L=3BOMR^^"X@U*W2\CH@)7,@*"5S*0#!K+W3UL$@1E10(,[$O/ZW
M_L[QQO?*I[#<+@"_XK_+R+JUN@"XM-;&T:'4\0"XY\NYM._`Z+S3`+_&S-BU
MS\W?`,[>MZC2U"!01U`@O-/#W-/*O/XN`,[>MZC.JB!01U`@UK30T-/*O/['
MJ</[+@#.WK>HTM0@4R]-24U%(+S3P]S3RKS^+@#.WK>HSJH@4R]-24U%(-/*
MO/['J</[+@#.WK>HL/.VJ"!,1$%0(+?^SO'&]P#.WK>HO>+#W"!01U`@ROV^
MW2X`SMZWJ+WBP]P@4R]-24U%(,K]OMTN`,[>MZB^]K:HRM6\_LC+M<2UY]?3
MT\J\_K78UK<N`,[>MZC7U,/<U+^W_L[QQO?(H;7#N:N_JL/<U+\N`,[>MZBT
M\K^J("5S+@#.WK>HM/*_JLZLNZ2YI-?WQ*._Z2`E<P#.WK>HML'(H2`E<RX`
MSMZWJ+;!R*&TYLBAO]C6QK'M*$%#3"D`SMZWJ+;!R*&W_L[QQO>UQ,_@N=C,
MV-#4`,[>MZBQH[3F("5S(+7$Q>36PRX`SMZWJ++IU=(@3$1!4"`@M_[.\<;W
M+@#5TK*[M;T@36]Z:6QL82!3:61E8F%R+B#'Z\BWR,\@<VED96)A<B#*Q[?Q
MM/*_JBX`N?J\T@"]J,&B`+VHP:+7T\[$O/Z\T`"]J,&BU=^UQ,BHS]X`T,73
MP[^HNL7"ZP"_R\+>M=C1QP"YQ;#-`+6QQ[#*L;SD`+6QQ[#,[,;X`+6QQ[#7
MM+_V.B``M;''L+?GN/$`O/3'T-&AU/$`R/O&UL*WR[D`SO?`[[;[SL0@*$M/
M23@M4BD`SO?`[[;[SL0@*%=I;F1O=W,M,3(U,2D`SO?`[[;[SL0OSMJ_R\"\
MSL0@*$M/23@M52D`O=V_R[FRNLVY^@#(U0##O\C5`,C5QMH`RM6UO<C5QMH`
MT:'4\<C5QMH`L-?,[`#*KK;^U,(`O/7)V<OUQ<4`Q*S(S\GMM]W*MK'P`,F^
ML_T`R;ZS_=/#NZ?7Z0#)OK/]R*C/W@#)OK/]H:+'Y;_5T\J\_@"UW<O-RK&\
MY`"UI,+S`,[*S.+#Z,KV`,/HRO8`S[B]VB`HQ^NRSK^\($AO<F1E(+S'PKS.
MQ+S^*3H`S[B]VL?KLLZ_O,^US;.YW,#MM<?"O"X`T="WH@#"MK7CSL*VR`#7
M[KKSTKO0H<JQM<3"MK7CSL*VR#H@`,*VM>/.PK;(.B``M-/7\];!T](`M-/3
MTM;!U_,`Q+_"O`#2U"`R-"#0H<JQUL;/U,J^/P#/U,J^T:'/[@#/U,J^N/'*
MO0"\JK*\S.$`LKO)OK/]`+*[TJK6L;W3M.;(H2!M86EN=&5N86YC92YP:'``
MM=K2N['*O,?"O,K'M_&P_+JLU]:VSL/[L\8_(,CGN?O*Q\?KT:'4\2X`MN##
MU\3AO-,`MN##U\3AO-.YLKK-N?H`S\+4V`#/PM38("5S`,_"U-C)^K/)M<3%
MY-;#SL2\_LZJ(%!(4""SS-#R+@#/PL"MLLNUI0"UY]?3T\J\_@"T[<[S`+;R
MN<^VX+;[`+'@O*T`L>"\K<?XO^D`L>"\K=/#NZ?7Z0"QX+RMR*C/W@"QX+RM
MR*C/W@"QX+RM("5S(+7$R*C/W@"QX+RMT:'/[@"QX+RM("5S(+7$R*C/W@"P
MH[RP`,CXMOO-W[;@`+7GU]/3RKS^`+7GU]/3RKS^M=C6MP"UY]?3T\J\_K78
MUK>QV-#KSL>ZSRX`M>?7T]/*O/[(M\C/`+'MQ^FW^[K%`+_5L-?0Q;S^+@"_
MU;#7O>&Y^RX`Q.JUUP"WQ;3SL>"\K<;W`+/@M<"\N,3:T<<`MO+!HLS8P._1
MQP"T[<[S`+"NR;/$X=''`+"CR/NV[;'(T<<`Q;?6W@##OR`Q-2"WUM;3`,._
M(#,P(,/KUM,`P[\@-2"WUM;3`,._M,ZUQ\*\`,._(#,P(+?6UM,`P[\@,2"W
MUM;3`+>VP/W6M3H`UK30T`#5N;^J`+6]QMK(U0"]XLNUU+$`1E10(,G/M*O%
MY-;#+@"VP<BAQJNZP\7DUL/*I[#<`,[>MZC!K+W3($Q$05`@M_[.\<;W+@#.
MWK>HP:R]TR!334(@M_[.\<;W+@"XM-;&RJ>PW-?4("(E<R(N`+BTUL;*I[#<
MM;T@(B5S(BX`SMZWJ+VHP:+2N[CVT,*UQ"!305-,(,&LO=,N`-+&MJ^UO2`B
M)7,BRJ>PW"X`MZC`O+_+N*/(NK6Z("C"[;;[SJS$R<NYR+JUNBD`MZC"WLBZ
MM;H`M*O5Y@"V_M3"`+C0OO7/\<K'`+C0OO7/\<K'.B``[+.\PP#.Q+S^ROW$
MOSH@)7,@N/;.Q+S^`,[$O/[*_<2_.B`E<R#.Q+S^`,[$O/ZYW,#MQO<`SL2\
M_L/[L\8`SL2\_LG/M*L`SL2\_LG/M*NYIL3<SK2QN]:GL]8N`+G]PLO&]P"W
MTL"\`,G/L.O4P@#)S\_2U,(`N<RVJ+'(P/T`MZW7J@#$O\*\("5S(+*[M.;4
MV@#7UM#-T=7)JP#4I+&HS.S*_2`HU*2QJ,SLROVP_,"HL-?,[-+4O+#2N;SD
MM<3*_;[=.\CGN?O4I+&HS.S*_;W/LZ2]J]6\T\.QR+W/O^VW^;7$L.;#YBD`
MM+#,Y0#+X\/\`,OCP_S`X-#-`,OCP_P`PMO,LP#7U+:OUZK0Q0#0Q\;:SN4`
MMZBY^@"WJ,KTN>?1Q\3'`+>HRO2RH\#[Q.'.]]''`+S$O/[(RP"TTP#-ZM7[
MP^C*]@#"^M3"`,BKP_L`O-/%[@"XU+'(T<<`LOK)^B`E<R"UQ,^US;/%Y-;#
M`+CQPK.\JM''`+7"N?H`Y<C$R0#6L;*\PM[-TP##^P#7JK6]`$=O;V=L92#+
MT<OW`+O2ML@`SZ/`L`#/H\"PSL0@*$E33RTX.#4Y+3<I`+CQP>K`O`"X\<'6
MQ,FT[P#3P[NGU^FYW,#M`-/#NZ?7Z</[L\:RN[7#O]6PUP#3P[NGU^D`N<^U
MPL+>QM6UN@"YV+6Z`,ZCM=C"[<"M`+CQMO?.][6Z`+?#O\W(J,_>`+?#O\W!
M]-'4`+RXQ-K1QP"\N,3:T<>QR,G<N;*ZS;GZ`+GGT<?$QP!(5$U,`-72LKNU
MO2!(5%10(-'IUJ0N`+JCM=@`U-.TU2W+X[>H`+'MS;<`NM6UPKK-PO2UL<#-
MR+JUN@#/H[*NP+3.Q"`H25-/+3@X-3DM."U)*0"P[];Z`+'@O*W&]\JYT\.P
M[];Z`+#OUOH`U>+`[\K'SL2\_K7$OZK*O#H`Z/.UV;C4`,K7TK,`RM?2L[78
MUK<`RM?2L[7GN[``NNFVO,"MR[D`UM"Y^L_CN-L`2&]R9&4`RZ[&O<_?`-?6
MML[*_<2_N;*\QC\`RJJVR`#*JK;(.B``T-G1P,#[`$E-05`@T\K/Y+VHP:+*
MI[#<.B`E<P!)34%0(-/*S^3)OK/]RJ>PW#H@)7,`24U!4"#3RL_DM,7%S,7D
MUL.]J,&BRJ>PW#H@)7,`25`@M=C6M\[>MZC*N=/#+@!)4""UV-:WLJ*RN]3:
M($-)1%(@M<2]T\K<Q_B_Z=;0+@"Q^;6Z`-:[T]#-O+'J`,V\L>J\L,[$U]8`
MR<^TJ\V\QJP`S;S&K`"[X\CK+""RO=;H("5D`+OCR.O7UK;..B`E<P"[X\CK
MU]:VSCH`RN3(Z[*[U?W(M[7$U_?3P\+K+@#4]KS3R_7%Q0#3H;;(`+CVL?#3
MP[NG`-.AMLC$X<[WT<<`T,7/H@#0Q<^B`++ER.NQ[;CQ`++ER.O-^,+GP:R]
MTP"RY<CKO\G,YK3ZQ*.PY@"RY<CKT\J\_@"RY<CK+['DN/S-O,:L`++ER.LO
ML>2X_,WXPN?!K+W3`-7[ROT`U?O*_<'0`,[>T*>UQ"!51$@HT\.[I\K]OMVQ
M[<VW*2X`SM[0I[7$TZ;3P[/,T/(N`,[>T*>UQ,7ZM,ZZQ<+K+@#,X;V[M<3*
M_;[=SM[0IRX`SM[0I[7$Q+^QZM>AUK<`LKNZS[>HM<3.Q+S^N/'*O0#.WM"G
MM<0@;7-G7W1Y<&4N`,[>T*>UQ+ORU=*RN[6](&%P:5]I9"X`SM[0I[7$N_+5
MTK*[M;VRSLK]+@"RN[K/MZBUQ+BXR*C/WBX`SM[0I[7$S:C1MM"MTNDN`,[>
MT*>UQ,"TU+37H=:W+@#.WM"GM<3-\M/#PNO*_;[=+@#2P<#*TL'+N<"\N;*Z
MS;GZ`-+!P*V_RP"PKK;[P+P`PORUN@#2U,FKP=``QZFWHM7?`-"QS.4`TN*T
M\\#[`-'`PO*\TP#2N]3"`$IA<&%N("C(U;&^*0#(U<[$("A)4T\M,C`R,BU*
M4"D`U//.][6Z`-2\M:D`QM_4P@#!^=3"`-;#UM``U_/3TK;4QNL`O[_7\[;4
MQNL`O[_3TK;4QNL`N?[(^+_+R[G,N0"QH\'TU*W1^2`_`+_/Q.'1QP!+97)B
M97)O<R#(S]:DM.W.\RX`P]S4O[VHP:(`P]S4O\S8U?<`P]S4O[.DML@`P]S4
MO\#@T,T`P]S4O]/OMZ@`M;''L+7$N:N_JL/<U+^W_L[QQO?6T"S2T;ZMM.;4
MVL3ZM<3#W-2_+@"[^<#OL,W+N;FRNLVY^@"SK\_*`+JKN?H`NJO.Q"`H155#
M+4M2*0"_QLW^S-@`O*JV^[RJR[G,N0#3[]'4`,#/SLX`S\*PZ]3"`,_"S]+4
MP@#)S[3.N/S0PCH`R<_2N[3.M<?"O#H@)7,`R<_2N[3.M<?"O#H@)7,@U]0@
M)7,`R<_2N[3.M<?"O#H@M=K2N[3.M<?"O`#`K<W1SJS1QP"PYL/FQ>36PP#`
MZ+#-Q-L`P+/+]\W0`,#[L<C`[]''`,#[L<C1QP#!T-:GMMC*O[7'`,&LO=,`
MP:R]TP#!T+/V("T@T\.[I[_)TM2_M+6]U>*X]L[$O/Z\T`#!T+/VR[7#]['J
MS.(`S-;"V]/#NZ?7Z2W.Q+S^N?$`S-;"V]/#NZ?7Z2W'\];Z`,S6PMO3P[NG
MU^DMRK:Q\+K%PNL`S-;"V]/#NZ?7Z2W3M=/0U=\`S-;"V]/#NZ?7Z2V\Q+S^
MR,L`S-;"V]/#NZ?7Z2VVJ=3$`,S6PMO3P[NGU^DMR*'/^[:IU,0`P="S]M/#
MNZ>UQ+FFQ-RQN[G8L=4`SL31IP#!HLS5S?``M;&UV,JQO.0Z(`"UV,?XT^O*
ML;SD`+78Q_@`M<?"O`#7HL_Z`+7'PKP`M<?"O,JGL-PL(,?KO.RRZ<3ZM<33
MP[NGP_NZS</<PNLL(,B[NO/6V,K4+@"UQ\*\RJ>PW"X`PJS)K;&D`-3"`,._
MR-70Q<^B`$U3+51.148@N+V\T\[$O/[6T,.[T]#*_;[=+@!-4T<`UM"Y^K#$
MP\4`PNW&Y+;9N;*ZS;GZ`,+MM.^\T\NYO-.UN@#3RKS^`-/*O/ZYW,#M`,+M
MP*W-_@#"[<"TSO?1QP#"[;;[M/JW\@#"[<#[`,+MMOK+^P#(_=3"`+'JO,>S
MR2"_M+G]+\ZTO[2Y_0"QZKS'L\G&Y,O\M<3*MK'P("C`_<CG+B#6V-*J+]+1
MN]BXM"D`PNW)W+;[R+JUN@#"[<SAQ.&_R[6Z`-7]U-K&I<7DU]:VS@##J\#O
MR_[$X=''`,.KP._'\\NY`+B]O/[*_<2_TM&SK+/VO=/*W,G/S]XN`-?NO?P@
M,C0@T*'*L;7$U^ZXW\["ML@Z(`#7[KW\(#8@T*'*L;7$U^ZXW\["ML@Z(`"]
MT\K<U^ZT\[.DML@`SN74P@#"[=2\S-C(NK6Z`+/)U+$`T:&UI<2CRKTZ`-/*
MO/X`T\J\_M'IUJ32T<WJL\DLM:O*Q]/#NZ>UQ,>IP_O(M,[>MZC-J+G]T>G6
MI"X`T,7/HM+1N?W&VBX`T,7/HL#@T,T`365T87(@Q_B_Z<[>MZC*N=/#+@!-
M971A<B#'^+_ISMZWJ,JYT\,N(,^XO=K'Z[+.O[S/M<VSN=S`[;7'PKPN`+>]
MMZ@`N:O6Q@#$J\[WN.<`P]R_R\+>Q.'.]]''P:JP[KGZ`$UI;64@P.#0S0#7
M[KW\(#(T(-"ARK&UQ-?NM<W.PK;(.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(
M.B``T[/)Y`#%Y-;#SL2\_M+%RJ<N(,CGN?O2JLJYT\/5XKCVTZ;3P[/,T/+$
M^K'8T.O/UM3:OLVR^LGZR_LN`-72LKNUO=#%SZ*UQ"!)1"X`U=*RN[6]N^'&
MVK7$($E$+@#0Q\;:TKL`T-"VK]/*O/X`N/S0PLC5QMH`Q*._Z0#$IK;[MN#-
MWP#$IL3)N.<`P\FYQ0#4PKK-Q.H`P[_4P@##R<S8R/O`K<S8`-3"P<'3K[_W
M`,2FPN6XYP#/PM+&`-?STL8`T]+2Q@#)S]+&`,_"TL8`R<_2Q@#$JLFCL<B_
MRP"XM-&A`,[2M<35R[K%`,[2M<3#Q;NG`,[2M<3#Q;NGTK/#YL7DUL,`P^6U
MZ0"RNRS.TK*[S:S2X@##^[/&`,3)P]>QR-''`.BGPK,`Q.&RM+;[`+K)P+P`
MNLG*]+"RM=C!T,NY`+OYT]I.971S8V%P92"UQ,WXUK<`3F5T<V-A<&4@4U-,
M(+?^SO'&]\/[L\8`3F5T<V-A<&4@R,_6I+7$Q?K7H@!.971S8V%P92#(S]:D
MP.#0S0#-^,+G`+33SK0`T,*_IL#OMN#$X=''`-#"U,(`T,+3P[NGP_L@*+?'
ML=C2JBD`T,+.]\"\`-#"M+"_VB`H7V)L86YK*0#0PL[%`,_"TKNRO0#/PM*[
MN/;1H<_N`,3AO-/`K;G/`,3AR-6V^P#$X<C5P/O1QP#-[<G/`,6FL*.UN@#+
M^=:XMJBUQ,Z[UL/)S\.[T]#'^+_IM.;4V@##N]/0S.&YJ<C5P/K#^[/&TM2Y
MJ2!-0T%,(-'IUJ0N`,.[T]#6N+:HM<0@)7,@Q>36P]#%SZ(N`,.[T]#6N+:H
MM<0@1E10(%9&4R#%Y-;#T,7/HBX`P[O3T-:XMJBUQ"!344P@5D93Q>36P]#%
MSZ(N`,.[T]#6N+:HM<0@4U%,+49I;&4@5D93Q>36P]#%SZ(N`,[$O/[.M,G/
MM*L`SKO6P]#%SZ+)T,ZTQ>36PP##N]/0UKBVJ,/<PNO2U+FI($A45%`@T>G6
MI"X`P[O3T-:XMJC#W,+KTM2YJ2!)34%0(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4
MN:D@2V5R8F5R;W,@T>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!,;V=I;B#1Z=:D
M+@##N]/0UKBVJ,/<PNO2U+FI(%!!4U-71"#1Z=:D+@##N]/0UKBVJ,/<PNO2
MU+FI(%--0B#1Z=:D+@##N]/0M/W)\[7$UZ*RX<GJQ^LN`,[>U-VTYL2_PKR_
MR;FIO^S(H2X`P[O3T+K/MZBUQ"!834P@ROV^W;&[M*N[V`"_U;#7UK4`U*W*
MO,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@UMC0PK+ZR?K%Y-;#SL2\_BX`
MU-K$^K7$Q>36P\[$O/[6T-72LKNUO;#FL;[0Q<^B+B#6V-#"LOK)^L7DUL/.
MQ+S^+@#.W@#(U;;ZPOS.Q"`H25-/+3@X-3DM,3`I`,6UN*._R[6Z`+&QL.O'
M\@"QL<+MP._1Q\3)R+JUN@#%LLW^`+?'UJZZ\P"WQ]:NQ[``LKO*Q]*[N/;$
MO\*\`,ZTL;O6I[/6`+&XS?S"O`#*KM*[U,(`ROW7U@#7UK?[ROT`U]:VSLK]
MQ+\`L<K*_0!/2P"VU,_SO:C!HM7?`+#+O?C.NP#*KM3"`+#LN:O*T@"PHL+\
M`-:[T]`@24U!4""W_L[QQO?6I[/6SL2\_KS0N;+/[;FFQ-PN`-:[O=/*W-*[
MN/;3RKS^M=C6MRX`UKO3T-.UT]#5W]/KS[7-L[G<P.W4L;_)TM2QY+C\N;+/
M[<BHS]X`U-K0PK2PO]K6T+3ROZH`T:'/[@`E<R"UQ-&AS^X`S^[$O['@NL4`
MU^G6KP#7Z=:OM:7.NP#4K<J\TZ;3P[/,T/+$H[#F`-3:("5S.B#6T+7$U*W*
MO,2CL.8N`,;DR_P`QN3+_-#%SZ(`T[73T-7?R*C/W@!004T@T>G6I,[>T*<N
M`%!'4"#*_=?6QZG#^P!01U`@O-/#W-?*P<\`4$=0(+FKOZK#W-2_`%!'4"#2
MT<>IP_LOTM&\T\/<(-?*P<\`4$A0(+/,T/*T^L+K`%!(4""]Q;&^`+#-N_G+
MN<RY`,7!P,T`L,W`U<NYS+FQN]6\P>S'^`"PS<3#PNT`L,VRO-''T,*\N,3:
MT<<`L,W`K;GG`,/<PNL`P[O3T-:XMJC#W,+KTM2YJ2!2041)55,@T>G6I"X`
MP]S"Z\BWR,\`P]S"ZSH`P]S"ZSH@`,/<PNNQV-#KSL>ZSRX`S/G)SP#,^<G/
M`,*WOK8`M/W)\[7'PKRCN@#6M-#0SJR[I++9U_<`M<?"O+KSUK30T,ZLNZ2R
MV=?W/P#(J,_>`+3FR*'4XK[<`,BHS]X`R*C/WKG<P.T`SM*UQ`##V,*S`+?&
MPLFQ]@"UY[NP`-75QJP`QJ3,V+^UM;H`Q^O*Y,CKTKNX]M3"M]V\L,3JM]TN
M`,?KRN3(Z]*[N/:ZS[>HM<3(U<;:.]&AU/&TR]3"M]VUQ,C5QMHN`,?KRN3(
MZ[K/MZBUQ,JQO.0N`,?KS.&YJ<[*S.*UQ-6JTJHN`,?KRN3(Z\3ZM<33P[NG
MP_N\L,/<PNL`LJC`O`#-ML:Q`,;/S-'1P`"UW<O-T\J\_K6]U>*X]L[$O/Z\
MT"`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`-?NO?P@)7,@T*'*L;7$O;73ZL&_
M.B``4')E9G-?;&1A<#H@U=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BX`
M4')E9G-?<V5S<VEO;CH@U=*RN[6]R_G0Z-*JM<0@<V5S<VEO;B#`J=6YU^F\
M_BX`QOC1N0"ZH\:]P^;&^-&Y.B``QOC1N3H@`-2DP,``R<_2N[CVT:'/[@#+
MO</<P]S4OP#.RLSBP^C*]@#7J+"X`,SARK[$VLC=`+FKOZK#W-2_`+FKOZK#
MW-2_T=W+XP"YJ[^J+\N]P]S#W-2_MM2RHLZTL;NR^LGZ+@"RJ+;@P.BX]P"_
MJ,O^MOL`4E-!(+FKOZK#W-2_("@E9"#.NRD`M:71H0"QR,+*`+;!R*$`ML'(
MH=/*O/X`U>:UQ-*JR;ZS_2`E<R#"\#\@U>+/[K+9U_>]J\[>MZB[UKBT+@#(
MH<_[N+34K0#+HM#"P\6[I\K3S;PZ`+GFU/*Q[;3ORKT`QL#"VP#4MK/,M_[.
M\<;W`-2VL\S-^-:W("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
MR;ZS_0#)OK/]Q_B_Z0#)OK/]MM0`U]2W_L[QQO?4W;3FQ+_"O-;0R;ZS_=+1
ML:.TYK7$Q>36P[/,T/(N`,F^L_W3P[NG`,F^L_W3P[NG.B`E<P#0Z,?SSK2Q
MN\_LTZ8Z(+3MSO.ZQ<+K.@#6V,GH`+WAN?L`M[6[V-&AS^X`4F5U;FEO;B`H
MP?3$X<WZM;HI`+W'R:L`4F]M86YI82`HPM["[<3AT<<I`-#]UZH@,3@P(+;(
M`,_RU_/0_=>J`,_RT]+0_=>J`-:TT-``4G5S<VEA;B!&961E<F%T:6]N("BV
M[<+>R[DI`%)W86YD82`HPJRPLK3O*0!3+TU)344@O-/#W,>IP_L`T\J\_M+1
MRKG3PR!3+TU)344@O-/#W`!305-,(-'IUJ3.WM"G+@#0Q<^B`,K]OMV_XKW%
ML;X`O-/#W-;5MLN[^@"SR;FF`-#'QMK!^0#*I;K5P-7$P[6Z`,JEN_FUPKK-
MP=#.K,NY`,JEPJS.]]''M;H`RJ7&I+"CMONZS<+SO\O"U\BZM;H`RJ7.Q,FM
MS-BZS;CQP=;$R;3O`,VLTKNX]K2PO]H@*%]S96QF*0#(^,2FT<<`RJ7"[<&F
MQ;4`RJ6VX,/`NLW&U<'6SO>QR`#.P-#'S.&YJ=7?`,FSS-BPHL"MLJX`L:.T
MY@"QH[3F("5S`+&CM.;1H<_N`+VKLOK)^K7$Q>36P\[$O/[2U"!02%`@T^_1
MU+CQRKVQH[3FM;W$^K7$M_[.\<;WU-VTYL2_PKS6T"X`Q>36PR`E<R#2T;&C
MM.8N`,O1T;``T:'4\=*[N/;(U<;:`-&AU/'2N[CVT\.[I]?IT\/2U-#"U/8`
MT:'4\=*[SKO0PK7$T[73T-7?`-&AU/'2N[*_M_[.\<;W`-&AU/'2N\Z[T\.[
MI]/#TM30PM3V`-&AU/'+^=/0R-7&VM?IO/XN`-/:TM3/PK7$M+"_VM;0T:'(
MH<3ZTJJUQ-?6M_LNTM3*\['JN+36QLOYT:'.Q-?6+,B[NO/,^<G/SL2\_K'@
MO*W'^"X`T:'4\<C5QMJWUKCT.@#1H=3QR-7&VLC5QMJX\<J].@#1H=3QRK&\
MY+?6N/0Z`-&AU/'(U<;:RK&\Y+CQRKTZ`-&AU/'/X+NEQJ7%Y+7$MOZX]M?6
MMLXN`-&AU/'$^K7$T=7)J\7DUL,`T:'4\<:KNL/3[]'4.@"TJ\O-SLK,XK>T
MTZ8`4V5N96=A;"`HR/O$VKS3MOLI`+2KN-#&]SH@`+[%U,(`4V5R8FEA(&%N
M9"!-;VYT96YE9W)O("C(^[;[SJS1Q]/KP\G,V,3AN.?"WBD`T/*ZQ0"[X<;:
M($E$(-+1N?W&VBX`Q>36PP#%Y-;#U+:SS+?^SO'&]\G/RO33VL3ZM<2X]LC+
MU;[,J"X`Q>36P\3ZM<3&J[K#T^_1U"P@RK''^-+4O+#(U<;:N/'*O2X`Q>36
MP\3ZM<3&],J\TZ;3P[/,T/(LT=7)J\7DUL,LTK/#YKC\T,+&M<+*++RPQN3+
M_,_4RK[1H<_N+@#3T+K#O+BX]K78M>.ZS=7BN/:RSLK]T]"YV#H@`%-E>6-H
M96QL97,@*,C[SO2V^RD`N;K.[P"\\K;,U:K2J@#*Q[?QSJJT\[*_M]VUQ,&L
MO=.VJ-+EO^R]W;FFQ-R\_#\`S]3*O@##O[3.M<?"O+KSS]3*OLG/TKNTSK7$
MM<?"O,JQO.0@/P#/U,J^M>/1H<;W`-/:U_.QW\_4RKX@)7,@LLNUI3\`RM7+
M]0!3:65R<F$@3&5O;F4@*,JHU]/)O;GZ*0#7HK+A`,>IP_L`QZG#^]'=R^,`
M4VEN9V%P;W)E("C0PKS3QL(I`+3ST*$`PM2Y_<ZLNZ0`4VQO=F%K:6$@*,NY
MPN6WI;_+*0!3;&]V96YI82`HR[G"Y;>EQ.'1QRD`N_W1J<GNML@Z(`!3;VQO
M;6]N($ES;&%N9',@*,OWPM[#Q<BZM;HI`%-O;6%L:6$@*,OWPNW`^]''*0#%
MQ<'0M[W/\M&AU/$`P+34M+78UK<`4V]U=&@@069R:6-A("C$S[?'*0#$S\6W
M("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<P#$S[#KQ_(`4W!A:6X@*,[WL.#1P"D`P*R[^-/*O/X`
MS-C*XM?6M_O*Y,CK`%-R:2!,86YK82`HR[G`[\"\OZ@I`+'JU[P`QO3*O,3J
MM]T`RJ$`U[3,K`"QH[3FN/'*O0"]UK7``,F^L_W/WP#7UK?[M*[!T`#0Q\;:
MS.P`UO?6O`#,X;V[`,_"L>H`L\FYI@#2T;/)N::XLKC'("5S`%-U9&%N("C+
MU;6D*0#5JM*J`,C5L_8`R-7"Y`#(U;/V`,C5L_8OR-7"Y`#(U;/V.B``R-7"
MY`#(U<+D.B``R<^QZ@#6I[/6`%-U<FEN86UE("C+U<#[Q,\I`+3"NL4`4W9A
M;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0@*,JWS=^\P\"\*0!3=V5D
M96X@*,CPM>0I`%-W:71Z97)L86YD("C(\,J_*0!3>7)I86X@07)A8B!297!U
M8FQI8R`HT/#`^]''*0!404(@M]:X]+CQRKW.Q+S^`,RHS>4`S*C-Y0!486II
M:VES=&%N("C+_KRJR[G,N2D`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B`HS+G)T,3AT<<I`,2_L>HZ`+3]L.S*PL_N`+7GN["ZQ<+K`-?NO?S2N]"A
MRK&UQ,["ML@Z(`#.PK;(`,["ML@Z(`#$H[#FN=S`[0#$VLC=`+2_SL37U@#0
MQ\;:R\0`S*G.Q"`H5$E3+38R,"D`5&AA:6QA;F0@*,RIN?HI`-"[T+O$^LJY
MT\.QOL^US;,N`$944"#1T\GL*&5X=&5N<VEO;BG.WM"G+@!-86EN=&5N86YC
M92#`X+'PLJ+.M+/)N:;4V,CK`-&AS^ZTL+_:TM2YV+'5+L#KOZK6T"X`T>G6
MI-/*O/['J</[T.C2JM/0TKNX]M+1O>*_JK7$(%!'4"#'^+_I+@#0Z-*JTKNX
M]KZMN?V\T\/<M<3-^,+GP:R]TRX`SL2\_B`E<R#3IKC#L/RZK-*[N/8@)7,@
MQ>36PRX`SL2\_B`E<R#3IKC#L/RZK-*[T*D@)7,@Q>36PRX`M,O.Q+S^UM##
MN]/0ROV^W2X`TM3/PLK'(')F8S@R,B#3RKS^M<2Q[<VW+@!';G501R"V_M2J
MSL2\_K7$PK>^MK'8T.NVJ-+EU-H@0W)Y<'1?<&=P.CH@P."Q\-;0+@!(;W)D
M95]#<GEP=%]S;6EM93HZ(,#@L?`LL=C0Z-*JT]`@;W!E;G-S;"#$H[_I+@"T
MR\:KNL,@(B5S(B#*_;[=TO+.JK.LN?W7[K3SO=/*W-:U+,OYTM3.WK>HL;NQ
MH[3F`-/#TM2\[,K3M,O*_;[=P.#0S2`H)7,I(+7$L\S0\K*BLKNTYM3:T]K/
MM<VSR<\N`+3+M_[.\<;W("(E<R(@TM&QN\F^L_TN`+3+M_[.\<;W("(E<R(@
MTM&QN[&CM.8N`"5S(+7$UZ*RX=#HQ_/2T;&[R;ZS_2X`UKBVJ+7$O,?"O+*B
MLKNTYM3:+@"TT\G/TKNX]K*]UNC6KKKSR<^TJ[7$ROV^W=+%RJ<N`,G/M*O.
MQ+S^LJ+.M+&[L:.TYBX`=V5A=&AE<BYC;VT@Q_B_Z<[>MZC*N=/#+@#.WKB]
MO/Z_R=:QO=.T\K^J+@"TR]?6ML[6T+#\NJS,J[;@M<37ULK]+L3ZTM'*Y,CK
M("5S(+CVU];*_3O$^LKDR.NUQ-?6ROVQV-#KT*'3VB`E<RX`R<^TJ\[$O/[*
ML;>BR?K2N[CVSLK,XCH@)7,@SK2QN\G/M*LN`,G/M*O.Q+S^RK&WHLGZTKNX
M]L[*S.(Z("5S(+3ST*&SK+G]O=/*W-?NM//6M2`H)60@8GET97,I+@#)S[2K
MSL2\_LJQMZ+)^M*[N/;.RLSB.B"]]K*_M]:UQ"`E<R#.Q+S^L;O)S[2K+@"\
M[,K3T\J\_LJQMZ+)^M*[N/:T[<[S+@"[X\CKM,O-J-&VLK[*_;[=RK&WHLGZ
MM.W.\RX`U-K%Y-;#M+#,Y=;0MZ+)^L'+TKNX]K3MSO,NT]"_R<3<Q/K2Q<*I
MP<NQV-#KS.[0M+7$U]:VSBX`M,L@24U!4""W_L[QQO>RHLZTUJ>SUL[$O/Z\
MT+?6S^VYIL3<+@#5XLO&NO6RN\K'U?W(M[7$(')A<B#1N<OUSL2\_BX`U>++
MQKKULKO*Q]7]R+>UQ"!Z:7`@T;G+]<[$O/XN`-7BR\:Z];*[RL?5_<BWM<30
MQ=/#OZBZQ<+K+@"TR]?6ML[*Q['8T.C2JK7$+@"TR]?6ML[$VLC=UKN]T\K<
MU?O*_<K]U]8N`+3+U]:VSL3:R-W6N[W3RMS*_=?6O+##L+K%+@"TR]?6ML[$
MVLC=UKN]T\K<L,N]^-;&ROW6M2X`M,O7UK;.Q-K(W;'8T.O.JK:ZNL6[\K_5
ML->WUKCTM<3*_=?6`+'8T.O*Q]*[N/;*_=?6+@"TR]?6ML[$VLC=L=C0Z[#\
MNJS2N]?IRJ[!^;WXUL:UQ"!21T(@T=7)J[3ZPNLLP/W(YR`G(S$R,S1A9B<N
M`-7BN/:TL,SETM&QN[2FP.VY_2X`U>+*QR`E<RX`M,O*_=:UU^[)V;'8T.O*
MQR`Q+@"TR[?^SO'&]\[>MZBVU"!Z:7`@O+`@9WII<""X\<J]SL2\_KWXT-"]
MXM&YR_4`M,O/M<VSM;''L,K'S:/3P[7$U[3,K"X`L=C0Z\K'TKNX]LK]U]8N
M`+3+M+"_VK'8T.O2JM/)T:'/[K2PO]HH3W!T:6]N*<OYNO2]T`#*L;SD`,JQ
MO.37M]?9`,JQO.2X\<J]`,JQQ_C1H=3Q`%1I;6]R+4QE<W1E`+'JS.(`RM6\
M_LC+`,CGN?O2JKBTT:$LQ^O4VK7CT:'*\['JM<3-K,JQL+0@0V]N=')O;+S\
M*+CVR,N\QLOCN_HI(+OR($-O;6UA;F2\_"C&N[G[O,;+X[OZ*2X`O?',[`!(
M5$U,(-2MRKS.Q+S^`+;@N.<`S="_R\#-R+JUN@##]\SL`,S`O-,`S-C!HL3A
MM.^ZS;;@L,VXYP#5YKORO-D`T,?&VK;^`,V[Q.'+N0#-P;;ZQN0`S<&V^L;D
MSL0@*$E33RTX.#4Y+3DI`,W!O^+"_,NYS+D`S-B_R\NYNLV_K;_&R[G(NK6Z
M`,V\S=_"K`#*Y,CKQ/JUQ-&AU/$Z(`#7S\WBS]_6N,K].B``S?C6MP#-^-:W
M.@#.VKC)M.\`SMJ_R\"\`,[>MZBTYLBA(%9&4R#$O\*\+@#7HK+ARK'.WK>H
MU/:\T[;NS>*UQ-/#NZ?0Q<^B+@#.WK>HN,2QY"!61E,@SL2\_B`B)7,B(+7$
MR*C/WBX`SMZWJ+'DN/P@5D93(,[$O/X@)7,O)7,@M<3(J,_>+@#.WK>HL>2X
M_,ZJ("5S+@#.WK>HP:R]T];!(%-13""W_L[QQO<N`,[>MZC*N=/#(%-33"#!
MK+W3+@#.WK>HN+36QB!61E,@SL2\_BX`SMZWJ+VHP:(@5D93(,2_PKP@(B5S
M(BX`SMZWJ+VHP:(@5D93(,2_PKPN`,[>MZB]J,&B(%9&4R#.Q+S^+@#.WK>H
MO:O*_;[=O>+1N<OU+@#.WK>HR;ZS_2`E<RRTR\2_PKRRHK?'O]6PUP#.WK>H
MM=VYZ<F^L_W$O\*\+@#.WK>HR;ZS_2!61E,@Q+_"O"X`SMZWJ,F^L_T@5D93
M(,2_PKPZ("5S+@#.WK>HR;ZS_2!61E,@SL2\_B`B)7,B+@#.WK>HR;ZS_2!6
M1E,@SL2\_BX`SMZWJ+7=N>G)OK/](%9&4SH@)7,N`,[>MZC%T+;/M;''L+7$
MQ+_"O"X`SMZWJ+WBOZK&OM:DS[B]V@#.WK>HO-/4V"`E<R"UQ+:HTN7*_;[=
M+@#.WK>HTL:VKR!61E,@SL2\_BX`SMZWJ+3ROZH@5D93(,[$O/X@(B5S(BX`
MSMZWJ-"TR.L@5D93(,[$O/XN`,[>MZBT\K^J(%9&4R#.Q+S^+@#.WK>HM/*_
MJM&YR_7.Q+S^+@#.WK>HML'(H2!V9G-R;V]T(,2_PKPN`,[>MZBQY+C\(%9&
M4R#$O\*\M<3#^[/&+@#.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N`,[>MZBQY+C\
M(%9&4R#.Q+S^("(E<R(@M<3#^[/&+@#.WK>HL>2X_"!61E,@SL2\_B`E<R\E
M<R"UQ,/[L\8N`,[>MZBQY+C\(%9&4R#.Q+S^M<3#^[/&+@#.WK>HUZJ[NR!7
M;W)D(,[$O/X`SMZWJ-"TR.L@5D93("(E<R(@SL2\_BX`SMZWJ-"TR.L@5D93
M(,[$O/[*_;[=+@#/PKNNS]\`R*'/^[C\N,0`N+34K0"W_L[QQO?!K+W3RK&W
MHLGZSK34I,;:M<2[V-.F.B``MZ+)^LZTU*3&VK7$N]C3IBS3R;?^SO'&]SH@
M`,WRT\/"ZR`H551&+3@I`+"BP*VRKL&JNL_'];.DN?H`TZ*Y^@##P+GZ`%5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P"UI=2J`,ZTUJJU
MQ`#.M-:JM<33P[NGP_N[\L/<PNLN`,ZTUJ>SUK7$P*G5N</[`+'DN/P`N/S0
MPB`E<P"X_-#"T\.[IP"X_-#"L\S0\M+1R;ZS_2X`R<^TJP#2T<G/M*O+^=/0
MTZ;3P[/,T/*UQ,7DUL/.Q+S^M;VW_L[QQO<N`,[:P*VYYP#3P[NG("5S(,ZT
MS:BY_2`E<R"UQ,K:R*C1Z=:D+@#3P[NGN=S`[0#3P[NGT:'/[@#3P[NGUZ*R
MX0"TR]6^S*BUQ-/#NZ?7HK+AS[7-L]+1S:/3PRX`T\.[I\/[`-/#NZ?#^SH`
MT\.[ISH@`,^US;/6T+7$T\.[ISH`SMK7R+'PO\O+N<RY`%9&4R#$O\*\LJ*R
MN[3FU-HN`+S9QMH`TM'5TK6]T]#0I[7$M=BUXSH@`-/0T*?0U`#2U+?6UM/.
MJK6ESKLHM-//UM3:QO#+XRD`UK4`S=_"L["BS;P`L>2[KP#.K\3:R/#`K0#1
MZ=:DRJ>PW"`M(+3+T\J\_K_)Q-S2T=3BR,O)P]?4M-NXQ"X`L.:QO@"PYK&^
MO]C6Q@#4O<3/`-2]Q,_.Q"`H5DE30TE)*0"\[,K3("5S`-3:T,*TL+_:M/*_
MJ@#2U"`E<R"RZ;^T`-.BRO3.K+;[OJG(NK6Z`,/`RO3.K+ZIR+JUN@#$W+S[
MML@`Q-R\^[;(.B``TN*T\\#[M_RUPK?GM>?0Q;FKR[[-N+G](%--5%``OJ^X
MY@"^K[CF(2$A(+33("5S(,K6MJ_)OK/]L\S0\BX`S=_`^\NYNLVXN\V\R+JU
MN@"^K[CF`-#'QMK(_0#,[,;XU*2RX@#-^-6^`,WXU;X`P[_6W`"[MM.M`+NV
MTZVUO2`E<P"[MM.M+"`E<P#.]\6W("A)4T\M.#@U.2TQ*0#.]\6W("A)4T\M
M.#@U.2TQ-2D`SO?(]KG^P*T`M<?"O+KSTZ:XP\_(S]3*OB`E<R#$Q-*[N/;3
MIM/#L\S0\C\`U]:VSK7$M]:X]-?6M_L_`-+]RO:UQ,>PM;RW^S\`M^?+V2B]
MVBD`M^?+V3H`M^?+V3H@`+#LN:O*TK78UK<`L.RYJ\K2M>>[L`!8-3`Y=C,@
MP*G5N</[`,3J`,3J`%EA:&]O("$@M=C-O`##O\3J`-*RP\4`RL>UQ"S.TLVL
MTN(`Q/JUL<>PRKG3P[2_SL37UK'@T+3$H\J]+B#*N=/#(%L\/ET@L+3%I;_)
MQ]"[N\ZJS?C2L['@T+3$H\J]+@#$^K*BSK3*Y,CKTKNX]KK/MZBUQ+7GU]/3
MRKS^M=C6MRX`Q/JRHLZTT\FUO,CKM<3.Q+S^UM"VU-.SR,ZZSM?6MLZUO2`E
M<P#$^M+1OJW7HL_Z+@#$^K'8T.O*Y,CKTKNX]KK/MZBUQ-:U+@#$^K'8T.O/
MR+GFNZZZP\K]OMW*]RA$871A5')E92FW_L[QMLNRQ<3<O,S0^,JYT\/0PM/#
MNZ?7HK+AM_[.\2X`Q^O#Z,KVSLK,XJ.LU-K$^K2KR\W.RLSBL:BXYM:NQ[`N
M`,3ZL=C0Z\KDR.NTR\&LO=/+^=:XS_*UQ,WXUK<`Q^O6N+:HTJK)OK/]M<2W
M_L[QQO<N`,?KUKBVJ-*JR;ZS_;7$T\.[IRX`Q^O6N+:HTJK0PM3VM<33P[NG
M+@#'Z]:XMJC2JKC\T,*UQ-/#NZ<N`,?KUKBVJ-*JUK30T+7$U_?3PRX`Q/JU
MQ"`E<R"[X<;:TM&Y_<JQ+L?KUMC0PK7'PKPN`,3ZM<2UY]?3T\J\_K78UK<`
MQ/JUQ-#%SZ(`U]2TT\3ZM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ-+RS-C-^+78
MUK?2T;'DN/PN(,ZJL:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0PK7'PKPN
M`,3ZM<30U</[`,3ZM<31Z=:DMLNRHLZTUJ>SUL'0L_;3P[NGN_*XP[FFQ-S2
MT;&[N=BQU2X`U]2TT\3ZM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ.2OP,#&]\O&
MNO72T;'DN/PN(,ZJL:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0PK7'PKPN
M`,3ZM<3DK\#`QO>RHLZTUJ>SUM7BN/:YIL3<+@#$^K6QQ[#+^<7DUL.UQ,JQ
MQ_@Z`,3ZM<31H<_NTM&X_-#"+@#$^K7$U+:SS+?^SO'&]SH`Q,_+N<"MM_(`
MU/K2P;;[`-3>L<C1QP"]\K#-LKS.I`!;SLK,XK&HN.9=`%O.N]/:T-`@)7,@
MN;(@)7,@T-!=`,[$O/X`M-,@)7,@*"5S*2#3VB`E<R`E<P#*L3H`P:*\M`##
M^[/&`,G0SK3*M<_6+@#)T,ZTRK7/UBX`U-FTSLKDR.O$^K7$P]S"Z]+4R+?(
MS\[>SO,`SK3#_,/[`-/#NZ?1H=3Q`'9#87)D`-#'QMHZ`'=E871H97(N8V]M
M(,WXU;X`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z:%]#3B]H96QP+GAM;```````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,C``,3`U,34T
M,S$P-C(`,#(P,S$V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@
M:&]R9&4O;&]C86QE+WIH7T-.+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@
M,C`Z,C(Z,3(@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U
M;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T
M:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q
M=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T
M:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@
M92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C
M;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@
M=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E
M<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S
M('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T
M:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L
M(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*
M(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A
M;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N
M+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T
M;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN
M('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H
M92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*
M("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H
M92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@
M:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E
M87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T
M:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O
M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@
M(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I
M<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I
M<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL
M(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E
M('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A
M;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?5%<O````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8R
M`#`Q-C<P,P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z:%]45R],
M0U]-15-304=%4R\`````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S$P-C(`,#(P-#<P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+WIH7U17+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#,T,3`V,P`Q,#4Q-30S,3`V,@`P,C(Q,S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M``!-!P``'````(0Z``#'"0``['0````````(G```#@````F<```/````&)P`
M``T````HG```"````#:<```+````/YP```P```!+G```!````%B<```8````
M79P``!L```!VG```+0```)*<```=````P)P``"0```#>G```*0````.=```9
M````+9T``"8```!'G0``#````&Z=```D````>YT```\```"@G0``"P```+"=
M```.````O)T```4```#+G0``*````-&=```(````^IT```H````#G@``%0``
M``Z>```2````))X```L````WG@``A0```$.>```.````R9X```H```#8G@``
M#0```..>```.````\9X``!$`````GP``#0```!*?```,````()\```T````M
MGP``!@```#N?``"4````0I\```H```#7GP``#P```.*?```8````\I\```P`
M```+H```#@```!B@```.````)Z````@````VH```"0```#^@```N````2:``
M`!H```!XH```,@```).@```X````QJ```%0```#_H```40```%2A``!:````
MIJ$``%<````!H@``-````%FB```)````CJ(```T```"8H@``!P```*:B```*
M````KJ(```\```"YH@``!0```,FB```&````SZ(``!$```#6H@``"````.BB
M```)````\:(```D```#[H@``)0````6C```@````*Z,``!,```!,HP``$```
M`&"C```/````<:,```H```"!HP```P```(RC```/````D*,``!0```"@HP``
M"0```+6C```-````OZ,``!(```#-HP``&0```."C```>````^J,```\````9
MI```"@```"FD```/````-*0```@```!$I```)````$VD```4````<J0``!8`
M``"'I```"````)ZD``!.````IZ0``"T```#VI```&0```"2E```'````/J4`
M``P```!&I0``+````%.E```.````@*4```,```"/I0``"P```).E```'````
MGZ4```<```"GI0``!0```*^E```%````M:4```H```"[I0```P```,:E```7
M````RJ4```H```#BI0``#P```.VE```.````_:4``!@````,I@``(P```"6F
M```.````2:8``!0```!8I@``%P```&VF```7````A:8``!<```"=I@``$P``
M`+6F```/````R:8```X```#9I@``'P```.BF```=````"*<```<````FIP``
M!@```"ZG```(````-:<```\````^IP``!@```$ZG```*````5:<``!,```!@
MIP``"P```'2G```0````@*<``!4```"1IP``%0```*>G```'````O:<``!``
M``#%IP``!0```-:G```5````W*<``!$```#RIP``#`````2H```[````$:@`
M`#@```!-J```"0```(:H```'````D*@``!0```"8J````P```*VH```%````
ML:@``!````"WJ```"0```,BH```3````TJ@``#D```#FJ```$@```""I```G
M````,ZD``"P```!;J0``*@```(BI```E````LZD```H```#9J0``!@```.2I
M```)````ZZD```<```#UJ0``+P```/VI```W````+:H``"X```!EJ@``50``
M`)2J```M````ZJH``"T````8JP``/0```$:K```_````A*L``"T```#$JP``
M0````/*K```C````,ZP``",```!7K```0````'NL```M````O*P``#,```#J
MK```)0```!ZM```5````1*T``!D```!:K0``*0```'2M```D````GJT``"@`
M``##K0``$0```.RM```*````_JT```H````)K@``$````!2N```6````):X`
M`!8````\K@``!P```%.N```'````6ZX``!0```!CK@``"@```'BN```(````
M@ZX``"<```",K@``"````+2N```'````O:X```<```#%K@``!@```,VN```%
M````U*X```<```#:K@``!@```.*N```(````Z:X``"D```#RK@``#@```!RO
M```*````*Z\```0````VKP``!P```#NO```)````0Z\```8```!-KP``$0``
M`%2O```'````9J\``!8```!NKP``!````(6O```(````BJ\```8```"3KP``
M#0```)JO```&````J*\``!X```"OKP``$0```,ZO```(````X*\```T```#I
MKP``#````/>O```'````!+````,````,L````P```!"P```7````%+```!,`
M```LL```'0```$"P```(````7K````0```!GL```"````&RP```(````=;``
M`$$```!^L```&@```,"P```@````V[```!4```#\L```!@```!*Q```&````
M&;$``!4````@L0``&````#:Q```B````3[$``"X```!RL0``'0```*&Q```A
M````O[$``%0```#AL0``*0```#:R```*````8+(```<```!KL@``%0```'.R
M```.````B;(```H```"8L@``#P```*.R```-````L[(```\```#!L@``#0``
M`-&R```)````W[(``!0```#IL@``!@```/ZR```8````!;,``!T````>LP``
M$P```#RS```1````4+,``!0```!BLP``!````'>S```&````?+,``!0```"#
MLP``5````)BS``!D````[;,```0```!2M```#@```%>T```%````9K0```4`
M``!LM```&P```'*T```:````CK0``!,```"IM```$0```+VT```1````S[0`
M`!P```#AM```*@```/ZT```0````*;4``"$````ZM0``!0```%RU```3````
M8K4```L```!VM0``$@```(*U```*````E;4```\```"@M0``#0```+"U```1
M````OK4``!,```#0M0``#````.2U```&````\;4```P```#XM0``!@````6V
M```7````#+8``!`````DM@``$0```#6V```(````1[8```4```!0M@``#```
M`%:V```0````8[8```4```!TM@``#0```'JV```&````B+8```<```"/M@``
M#0```)>V```'````I;8```L```"MM@``!P```+FV```'````P;8```D```#)
MM@``"0```-.V```*````W;8``!D```#HM@``/0````*W```=````0+<```P`
M``!>MP``$````&NW```%````?+<``"4```""MP``$@```*BW```3````N[<`
M`"L```#/MP``.P```/NW```@````-[@```@```!8N```-@```&&X```A````
MF+@``!````"ZN```"````,NX```,````U+@```0```#AN```#P```.:X```.
M````]K@```H````%N0``#0```!"Y```?````'KD``!P````^N0``(0```%NY
M```>````?;D``!D```"<N0``'@```+:Y```=````U;D``!L```#SN0``(```
M``^Z```N````,+H``"8```!?N@``'````(:Z```>````H[H``!P```#"N@``
M)@```-^Z```K````!KL``#,````RNP``)@```&:[```K````C;L``#@```"Y
MNP``'0```/*[```5````$+P``"\````FO```(````%:\```2````=[P``"D`
M``"*O```'@```+2\```@````T[P``!(```#TO```H@````>]```6````JKT`
M`",```#!O0``*````.6]```I````#KX``"@````XO@``'P```&&^```5````
M@;X``"````"7O@``)0```+B^```H````WKX``"T````'OP``,````#6_``"2
M````9K\``"$```#YOP``%@```!O````<````,L```"8```!/P```*@```';`
M``!!````H<```$0```#CP```#````"C!```'````-<$```<````]P0``!@``
M`$7!```-````3,$``!````!:P0``$@```&O!```3````?L$``!(```"2P0``
M!P```*7!```$````K<$``!````"RP0``#````,/!```.````T,$```T```#?
MP0``#P```.W!```3````_<$```T````1P@``*````!_"```#````2,(```T`
M``!,P@``!@```%K"```1````8<(``!<```!SP@``&P```(O"```.````I\(`
M``(```"VP@``20```+G"```%`````\,``!`````)PP``#P```!K#```$````
M*L,```T````OPP``#@```#W#```#````3,,```X```!0PP``"````%_#```/
M````:,,```\```!XPP``!P```(C#```-````D,,``!````">PP``#0```*_#
M```+````O<,```8```#)PP``"P```-##```,````W,,```H```#IPP``$0``
M`/3#```9````!L0```L````@Q```#0```"S$```B````.L0``!L```!=Q```
M-````'G$```*````KL0``!@```"YQ```&0```-+$```6````[,0``"(````#
MQ0``#0```";%```'````-,4``!0````\Q0``"P```%'%```B````7<4``"\`
M``"`Q0``"P```+#%```)````O,4``!D```#&Q0``"P```.#%```7````[,4`
M`!<````$Q@``"0```!S&```6````)L8```\````]Q@``&0```$W&```6````
M9\8```X```!^Q@``&````(W&```(````IL8```T```"OQ@``)@```+W&``!#
M````Y,8```@````HQP``$@```#''```?````1,<```@```!DQP``"P```&W'
M```O````><<```X```"IQP``!0```+C'```&````OL<```,```#%QP``!P``
M`,G'```$````T<<```H```#6QP``"@```.''```/````[,<``!````#\QP``
M%P````W(```1````)<@``!D````WR```%P```%'(```)````:<@```4```!S
MR```"P```'G(```*````A<@```4```"0R```#0```);(```;````I,@``!<`
M``#`R```%````-C(```)````[<@```X```#WR```#0````;)```2````%,D`
M`#@````GR0``(````&#)```(````@<D```X```"*R0``>P```)G)```8````
M%<H``!$````NR@``!P```$#*```%````2,H``!@```!.R@``'@```&?*```;
M````ALH``!D```"BR@``&P```+S*```3````V,H```<```#LR@``"````/3*
M```&````_<H```8````$RP``$`````O+```/````',L``!`````LRP``#P``
M`#W+```+````3<L```\```!9RP``#````&G+```/````=LL```<```"&RP``
M!@```([+```.````E<L```P```"DRP``#P```+'+```(````P<L```@```#*
MRP``$P```-/+```>````Y\L``"$````&S```(````"C,```9````2<P``!<`
M``!CS```)0```'O,```7````H<P``!8```"YS```!````-#,```;````U<P`
M``T```#QS```#````/_,```#````#,T```4````0S0``"````!;-```*````
M'\T```P````JS0``"P```#?-```0````0\T```P```!4S0``!````&'-```3
M````9LT``!0```!ZS0``#````(_-```)````G,T```X```"FS0``"P```+7-
M```;````P<T```<```#=S0``!P```.7-```*````[<T```T```#XS0``"0``
M``;.```$````$,X```4````5S@```P```!O.```8````'\X```H````XS@``
M!````$/.```F````2,X```X```!OS@``?````'[.```5````^\X```4````1
MSP``!P```!?/```,````'\\```@````LSP``"@```#7/```&````0,\```@`
M``!'SP```@```%#/```&````4\\```8```!:SP``%````&'/```-````=L\`
M`!````"$SP``&P```)7/```$````L<\```D```"VSP``$````,#/```)````
MT<\```D```#;SP``!0```.7/```(````Z\\```8```#TSP``&0```/O/```.
M````%=````<````DT```!P```"S0```%````--````D````ZT```"@```$30
M```"````3]````8```!2T```"P```%G0```-````9=````D```!ST```!@``
M`'W0```2````A-````D```"7T```!P```*'0```4````J=```!T```"^T```
M0@```-S0```E````']$``"4```!%T0``!@```&O1```*````<M$```0```!]
MT0``"0```(+1```(````C-$``!$```"5T0``"0```*?1```&````L=$```T`
M``"XT0``!@```,;1```$````S=$``!X```#2T0``!0```/'1```.````]]$`
M``0````&T@``!@````O2```'````$M(``"$````:T@``#0```#S2```5````
M2M(```8```!@T@``!````&?2```1````;-(```8```!^T@``"@```(72```B
M````D-(```0```"ST@``!0```+C2```=````OM(```0```#<T@``#````.'2
M```.````[M(```H```#]T@``"`````C3```)````$=,```4````;TP``.@``
M`"'3```P````7-,``#4```"-TP``*0```,/3``!'````[=,``#@````UU```
M*0```&[4```_````F-0``"X```#8U```+0````?5```?````-=4```\```!5
MU0``$@```&75```+````>-4``"8```"$U0``*0```*O5```D````U=4``"8`
M``#ZU0``"````"'6```*````*M8```D````UU@``!P```#_6```@````1]8`
M`"````!HU@``)@```(G6```*````L-8``!D```"[U@``*0```-76```2````
M_]8```<````2UP``"@```!K7```,````)=<```\````RUP``$````$+7``!`
M````4]<``'````"4UP``9@````78```.````;-@```D```![V```"@```(78
M```2````D-@``!,```"CV```#````+?8```&````Q-@```\```#+V```$@``
M`-O8```0````[M@``!$```#_V```'````!'9```C````+MD``&H```!2V0``
M#P```+W9```%````S=D``!````#3V0``"0```.39```$````[MD```L```#S
MV0``(````/_9```4````(-H```P````UV@``#````$+:```/````3]H``!4`
M``!?V@``*0```'7:```J````G]H``"8```#*V@``)P```/':```I````&=L`
M`"H```!#VP``&0```&[;``!"````B-L``!$```#+VP``$@```-W;```3````
M\-L``!0````$W```#P```!G<```6````*=P``!<```!`W```$````%C<```1
M````:=P``#0```![W```$P```+#<```2````Q-P``#4```#7W```%`````W=
M```'````(MT```P````JW0``(````#?=```0````6-T``!0```!IW0``$0``
M`'[=```7````D-T``!P```"HW0``$P```,7=```4````V=T``!H```#NW0``
M$0````G>```:````&]X``!X````VW@``&@```%7>```3````<-X``!4```"$
MW@``$0```)K>```7````K-X``!0```#$W@``%P```-G>```5````\=X```D`
M```'WP``$````!'?```9````(M\```0````\WP``!P```$'?```+````2=\`
M`!$```!5WP``!@```&??```&````;M\```8```!UWP``!0```'S?```'````
M@M\```<```"*WP``!0```)+?```6````F-\```8```"OWP``!@```+;?```$
M````O=\```0```#"WP``!P```,??```.````S]\```P```#>WP``#````.O?
M```-````^-\```H````&X```#@```!'@```%````(.```"@````FX```#@``
M`$_@```,````7N````\```!KX```"@```'O@```(````AN````D```"/X```
M*P```)G@```$````Q>````@```#*X```)@```-/@```2````^N````\````-
MX0``!@```!WA```*````).$```<````OX0``"````#?A```@````0.$```D`
M``!AX0``%````&OA```,````@.$```T```"-X0``#@```)OA```6````JN$`
M`!$```#!X0``!@```-/A```#````VN$```8```#>X0``!P```.7A```$````
M[>$```L```#RX0``"P```/[A```'````"N(```<````2X@``%@```!KB```-
M````,>(```T````_X@``"@```$WB```0````6.(```\```!IX@``$0```'GB
M```7````B^(```H```"CX@``$0```*[B```(````P.(```0```#)X@``#P``
M`,[B```Z````WN(```4````9XP``'@```!_C```.````/N,``!````!-XP``
M"P```%[C```,````:N,```D```!WXP``!P```('C```*````B>,```D```"4
MXP``#@```)[C```0````K>,``!L```"^XP``&````-KC```:````\^,```H`
M```.Y```"0```!GD```*````(^0```P````NY```#P```#OD```(````2^0`
M``8```!4Y```!P```%OD```%````8^0```L```!IY```1P```'7D```-````
MO>0```D```#+Y```!````-7D```#````VN0``!,```#>Y```$P```/+D```3
M````!N4```H````:Y0```@```"7E```$````*.4``"4````MY0```P```%/E
M```%````5^4``"H```!=Y0``"@```(CE```%````D^4```0```"9Y0``"@``
M`)[E```-````J>4```8```"WY0``"````+[E```(````Q^4```0```#0Y0``
M!0```-7E``!H````V^4```D```!$Y@``#````$[F```%````6^8```8```!A
MY@``&P```&CF```O````A.8``!````"TY@``"@```,7F```/````T.8```H`
M``#@Y@``"0```.OF```3````]>8``!L````)YP``&````"7G```7````/N<`
M`!\```!6YP``#@```';G```#````A><```<```")YP``"````)'G```'````
MFN<```H```"BYP``"P```*WG```'````N><``%$```#!YP``$````!/H```,
M````).@``!H````QZ```2@```$SH```9````E^@```8```"QZ```&@```+CH
M```E````T^@```8```#YZ```!@````#I```?````!^D```8````GZ0``"0``
M`"[I```8````..D``!<```!1Z0``*````&GI```&````DND```T```"9Z0``
M(@```*?I``!7````RND``!,````BZ@``(P```#;J```3````6NH```(```!N
MZ@``"P```''J```(````?>H```T```"&Z@``"@```)3J```'````G^H``!0`
M``"GZ@``!@```+SJ```(````P^H```X```#,Z@``!P```-OJ```*````X^H`
M``L```#NZ@``,@```/KJ```'````+>L```P````UZP``#0```$+K```,````
M4.L```D```!=ZP``"0```&?K```*````<>L```<```!\ZP``"0```(3K```'
M````CNL```H```"6ZP``&P```*'K```2````O>L```H```#0ZP``%@```-OK
M```)````\NL``!````#\ZP``!P````WL```2````%>P```0````H[```!P``
M`"WL```%````->P```4````[[```"P```$'L```4````3>P``!$```!B[```
M&@```'3L```6````C^P``!0```"F[```%P```+OL```8````T^P``!P```#L
M[```&0````GM```'````(^T```4````K[0``#0```#'M```,````/^T``!$`
M``!,[0``"````%[M```7````9^T```L```!_[0``#````(OM```?````F.T`
M`!H```"X[0``$P```-/M```$````Y^T```H```#L[0``!````/?M```,````
M_.T```4````)[@``"0````_N```%````&>X```<````?[@``!0```"?N```$
M````+>X```(````R[@``.````#7N```L````;NX``!(```";[@``*0```*[N
M```R````V.X```H````+[P``+````!;O```N````0^\``#,```!R[P``,P``
M`*;O```X````VN\```\````3\```&````"/P```0````//````\```!-\```
M$P```%WP```5````<?```!0```"'\```$@```)SP```4````K_```"T```#$
M\```+0```/+P```Q````(/$``"X```!2\0``+P```('Q```L````L?$``&(`
M``#>\0``$P```$'R```-````5?(```@```!C\@``%P```&SR```(````A/(`
M``P```"-\@``*P```)KR```A````QO(``!H```#H\@``"0````/S``!%````
M#?,``$$```!3\P``!````)7S```3````FO,``!0```"N\P``#@```,/S```3
M````TO,``!@```#F\P``!@```/_S```)````!O0```H````0]```#P```!OT
M```0````*_0```<````\]```#@```$3T```%````4_0``!L```!9]```"```
M`'7T```&````?O0``!0```"%]```$0```)KT```.````K/0``#@```"[]```
M`@```/3T```&````]_0```X```#^]```!0````WU```'````$_4```8````;
M]0``*````"+U```,````2_4``!P```!8]0``!````'7U```I````>O4``!\`
M``"D]0``7````,3U```4````(?8``#X````V]@``'P```'7V```0````E?8`
M``<```"F]@``#@```*[V```,````O?8```P```#*]@``$P```-?V```*````
MZ_8``!T```#V]@``&0```!3W```%````+O<``!$````T]P``$0```$;W```D
M````6/<``!(```!]]P``%0```)#W```2````IO<```X```"Y]P``&0```,CW
M```(````XO<```D```#K]P``#0```/7W```*`````_@```<````.^```#P``
M`!;X```&````)O@```L````M^```&@```#GX```*````5/@```<```!?^```
M"````&?X```%````</@``!\```!V^```!@```);X```0````G?@```@```"N
M^```#0```+?X```(````Q?@``!X```#.^```$@```.WX```L`````/D``!H`
M```M^0``"0```$CY```*````4OD``!4```!=^0``!0```'/Y```4````>?D`
M``0```".^0``$````)/Y```&````I/D```<```"K^0``'@```+/Y```H````
MTOD```H```#[^0``'`````;Z```1````(_H```L````U^@``&@```$'Z```4
M````7/H```0```!Q^@``!````';Z```+````>_H```4```"'^@``!@```(WZ
M```(````E/H```8```"=^@``&P```*3Z```T````P/H``#0```#U^@``(```
M`"K[```I````2_L``"````!U^P``00```);[```:````V/L``"@```#S^P``
M*0```!S\``!0````1OP``"(```"7_```!@```+K\```(````P?P```4```#*
M_```"````-#\```9````V?P``!D```#S_```*@````W]```C````./T``!D`
M``!<_0``+@```';]```T````I?T```@```#:_0``%P```./]```*````^_T`
M``<````&_@``(0````[^```0````,/X```X```!!_@``"P```%#^```'````
M7/X``!,```!D_@``"````'C^```+````@?X```H```"-_@``%````)C^```/
M````K?X``#(```"]_@``"P```/#^```%````_/X```4````"_P``!0````C_
M```7````#O\```\````F_P``!````#;_```*````._\```D```!&_P``"P``
M`%#_```-````7/\```P```!J_P``#@```'?_```%````AO\```0```",_P``
M#0```)'_```R````G_\``$4```#2_P``%P```!@``0`'````,``!`!X````X
M``$`%````%<``0`%````;``!`!0```!R``$`!@```(<``0`'````C@`!``X`
M``"6``$`*@```*4``0`&````T``!``P```#7``$`#0```.0``0`1````\@`!
M``L````$`0$`-@```!`!`0`*````1P$!`"(```!2`0$`"P```'4!`0`/````
M@0$!`#(```"1`0$`)0```,0!`0`P````Z@$!`#$````;`@$`+0```$T"`0`.
M````>P(!``4```"*`@$`#@```)`"`0`3````GP(!`!(```"S`@$`!P```,8"
M`0`1````S@(!`!,```#@`@$`!P```/0"`0`4````_`(!`!@````1`P$`!P``
M`"H#`0`%````,@,!``P````X`P$`#````$4#`0`2````4@,!``0```!E`P$`
M!P```&H#`0`*````<@,!``L```!]`P$`#````(D#`0`.````E@,!``X```"E
M`P$`!0```+0#`0`%````N@,!`"X```#``P$`)@```.\#`0`C````%@0!``,`
M```Z!`$`$@```#X$`0`&````400!`!X```!8!`$`&````'<$`0`E````D`0!
M``T```"V!`$`"0```,0$`0`#````S@0!``<```#2!`$`"@```-H$`0`"````
MY00!``P```#H!`$`%0```/4$`0`+````"P4!`!D````7!0$`(````#$%`0`2
M````4@4!``4```!E!0$`"@```&L%`0`5````=@4!`!(```",!0$`#````)\%
M`0`$````K`4!``D```"Q!0$`!P```+L%`0`,````PP4!`%(```#0!0$`%P``
M`",&`0`D````.P8!`!(```!@!@$`!P```',&`0`&````>P8!``X```""!@$`
M#````)$&`0`-````G@8!`!4```"L!@$`$@```,(&`0`/````U08!`!0```#E
M!@$`"@```/H&`0`;````!0<!`!`````A!P$`"P```#('`0!I````/@<!`!H`
M``"H!P$`%P```,,'`0`G````VP<!`!H````#"`$`%P```!X(`0`;````-@@!
M`!D```!2"`$`'P```&P(`0`3````C`@!``@```"@"`$`!P```*D(`0`(````
ML0@!``D```"Z"`$`%0```,0(`0`-````V@@!`",```#H"`$`#0````P)`0`3
M````&@D!``@````N"0$``P```#<)`0!&````.PD!`#\```"""0$`-P```,()
M`0!7````^@D!``4```!2"@$`'P```%@*`0`O````>`H!``H```"H"@$`"```
M`+,*`0`-````O`H!`"T```#*"@$`!````/@*`0!/````_0H!`"4```!-"P$`
M"P```',+`0`?````?PL!`!T```"?"P$`)0```+T+`0`@````XPL!`"0````$
M#`$`(````"D,`0`+````2@P!``<```!6#`$`#0```%X,`0`,````;`P!`!<`
M``!Y#`$`!@```)$,`0`,````F`P!``<```"E#`$`"0```*T,`0`3````MPP!
M``D```#+#`$`!````-4,`0`0````V@P!``@```#K#`$`"````/0,`0`$````
M_0P!``L````"#0$`#`````X-`0`2````&PT!`!$````N#0$`#````$`-`0`/
M````30T!``<```!=#0$`#0```&4-`0`4````<PT!``X```"(#0$`#````)<-
M`0`;````I`T!`"P```#`#0$`$P```.T-`0`&`````0X!``<````(#@$`$P``
M`!`.`0`%````)`X!``0````J#@$`%P```"\.`0`*````1PX!``P```!2#@$`
M"0```%\.`0`&````:0X!``D```!P#@$`"````'H.`0`)````@PX!``H```"-
M#@$`$0```)@.`0`&````J@X!``X```"Q#@$`#@```,`.`0`-````SPX!``L`
M``#=#@$`'0```.D.`0`+````!P\!``(````3#P$`'````!8/`0`'````,P\!
M``8````[#P$`9````$(/`0`)````IP\!``<```"Q#P$`)@```+D/`0`X````
MX`\!`!H````9$`$`*@```#00`0`[````7Q`!`"@```";$`$`-````,00`0`9
M````^1`!`!4````3$0$`!0```"D1`0`'````+Q$!``@````W$0$`!P```$`1
M`0`%````2!$!``<```!.$0$`#@```%81`0`)````91$!``8```!O$0$`"```
M`'81`0`+````?Q$!``<```"+$0$`"````),1`0`'````G!$!`!8```"D$0$`
M"0```+L1`0`&````Q1$!``L```#,$0$`$````-@1`0`&````Z1$!`!P```#P
M$0$`%`````T2`0`'````(A(!`!$````J$@$`"````#P2`0`.````11(!``@`
M``!4$@$`!0```%T2`0`0````8Q(!`!````!T$@$`!@```(42`0`9````C!(!
M``H```"F$@$`'````+$2`0`'````SA(!``4```#6$@$`$````-P2`0`4````
M[1(!``L````"$P$`#0````X3`0`H````'!,!`!@```!%$P$`%P```%X3`0`$
M````=A,!``D```![$P$`"@```(43`0`'````D!,!``(```"8$P$`#@```)L3
M`0`(````JA,!`",```"S$P$`.````-<3`0`F````$!0!`#$````W%`$`)P``
M`&D4`0!D````D10!`!0```#V%`$`50````L5`0`X````814!`$H```":%0$`
M6P```.45`0`H````018!`#@```!J%@$`*````*,6`0`L````S!8!`"8```#Y
M%@$`&P```"`7`0`^````/!<!`",```![%P$`%P```)\7`0!(````MQ<!`(4`
M````&`$`,````(88`0`E````MQ@!`$$```#=&`$`6P```!\9`0!)````>QD!
M`#$```#%&0$`'0```/<9`0`8````%1H!`"L````N&@$`(0```%H:`0`?````
M?!H!`"L```"<&@$`(0```,@:`0`G````ZAH!`#H````2&P$`'0```$T;`0`1
M````:QL!`#,```!]&P$`)0```+$;`0`G````UQL!`"````#_&P$`'P```"`<
M`0`P````0!P!`&D```!Q'`$`,0```-L<`0!!````#1T!`#,```!/'0$`)0``
M`(,=`0`]````J1T!`&4```#G'0$`30```$T>`0`O````FQX!`"X```#+'@$`
M,````/H>`0!4````*Q\!`%H```"`'P$`2````-L?`0!*````)"`!`#(```!O
M(`$`+P```*(@`0`L````TB`!`"T```#_(`$`%P```"TA`0`E````12$!`#(`
M``!K(0$`*0```)XA`0`^````R"$!`"(````'(@$`4@```"HB`0`E````?2(!
M``L```"C(@$`L0```*\B`0!%````82,!`"$```"G(P$`,````,DC`0`E````
M^B,!`!P````@)`$`,0```#TD`0`'````;R0!``<```!W)`$`!````'\D`0`-
M````A"0!``L```"2)`$`#@```)XD`0`+````K20!``4```"Y)`$`$````+\D
M`0`"````T"0!`%D```#3)`$`!0```"TE`0`2````,R4!``0```!&)0$`!P``
M`$LE`0`(````4R4!``4```!<)0$``P```&(E`0`0````9B4!`!,```!W)0$`
M#0```(LE`0`"````F24!``<```"<)0$`!@```*0E`0`4````JR4!``P```#`
M)0$`&````,TE`0`&````YB4!`!(```#M)0$`#``````F`0`#````#28!``0`
M```1)@$`!@```!8F`0`'````'28!`!\````E)@$`-0```$4F`0`N````>R8!
M`"\```"J)@$`%P```-HF`0`B````\B8!`"4````5)P$`(````#LG`0`;````
M7"<!`!@```!X)P$`)````)$G`0`?````MB<!`!H```#6)P$`(0```/$G`0`@
M````$R@!`!H````T*`$`,@```$\H`0`:````@B@!`"\```"=*`$`*P```,TH
M`0`?````^2@!`",````9*0$`'P```#TI`0`:````72D!`"$```!X*0$`)0``
M`)HI`0`F````P"D!`"4```#G*0$`)`````TJ`0`8````,BH!`!T```!+*@$`
M)````&DJ`0`8````CBH!`"(```"G*@$`+````,HJ`0`O````]RH!`!4````G
M*P$`)0```#TK`0`\````8RL!`!\```"@*P$`(P```,`K`0`?````Y"L!`"``
M```$+`$`&@```"4L`0`8````0"P!`"8```!9+`$`'@```(`L`0`I````GRP!
M`!X```#)+`$`,0```.@L`0`)````&BT!``P````D+0$`%P```#$M`0`O````
M22T!`"0```!Y+0$`!P```)XM`0`/````IBT!`!0```"V+0$`#@```,LM`0`-
M````VBT!`"0```#H+0$`!0````TN`0`'````$RX!`"(````;+@$`)0```#XN
M`0`:````9"X!`!T```!_+@$`&@```)TN`0`'````N"X!`,<```#`+@$`"P``
M`(@O`0`5````E"\!``8```"J+P$`"0```+$O`0`+````NR\!``T```#'+P$`
M%P```-4O`0`&````[2\!`#,```#T+P$`$P```"@P`0`3````/#`!``<```!0
M,`$`#P```%@P`0`'````:#`!`#(```!P,`$`!````*,P`0`A````J#`!`!,`
M``#*,`$`#````-XP`0`1````ZS`!`#(```#],`$`%@```#`Q`0`(````1S$!
M`!T```!0,0$`"0```&XQ`0`*````>#$!`!0```"#,0$`"@```)@Q`0`=````
MHS$!``@```#!,0$`'P```,HQ`0`(````ZC$!`!H```#S,0$`!@````XR`0`5
M````%3(!``<````K,@$`"````#,R`0`)````/#(!`#\```!&,@$`!P```(8R
M`0`/````CC(!``X```">,@$`$````*TR`0`)````OC(!``D```#(,@$`"```
M`-(R`0`3````VS(!``<```#O,@$`&0```/<R`0`*````$3,!`!<````<,P$`
M%````#0S`0`*````23,!``P```!4,P$`%P```&$S`0`$````>3,!`"H```!^
M,P$`#````*DS`0`1````MC,!``<```#(,P$``@```-`S`0`0````TS,!`!@`
M``#D,P$`"P```/TS`0`#````"30!``@````--`$`!@```!8T`0`'````'30!
M``T````E-`$`"P```#,T`0`4````/S0!`!4```!4-`$`#@```&HT`0`O````
M>30!`"````"I-`$`'````,HT`0`5````YS0!``P```#]-`$`,0````HU`0`%
M````/#4!`!(```!"-0$`/P```%4U`0`2````E34!``H```"H-0$`!@```+,U
M`0`$````NC4!``0```"_-0$`"@```,0U`0`3````SS4!``4```#C-0$`!@``
M`.DU`0`&````\#4!``@```#W-0$`!``````V`0`,````!38!``H````2-@$`
M.0```!TV`0`N````5S8!`!D```"&-@$`'P```*`V`0`=````P#8!`!$```#>
M-@$``@```/`V`0`$````\S8!``H```#X-@$`!@````,W`0`%````"C<!``,`
M```0-P$`#````!0W`0!%````(3<!`#(```!G-P$`&@```)HW`0`T````M3<!
M`"@```#J-P$`4P```!,X`0`9````9S@!`'(```"!.`$`(````/0X`0`U````
M%3D!`"$```!+.0$`10```&TY`0`P````LSD!`"@```#D.0$`*0````TZ`0`F
M````-SH!`"4```!>.@$`*````(0Z`0`H````K3H!`"(```#6.@$`*P```/DZ
M`0`P````)3L!`!(```!6.P$`$P```&D[`0`0````?3L!`'D```"..P$`"0``
M``@\`0"A````$CP!`',```"T/`$`?````"@]`0`K````I3T!`%0```#1/0$`
M%P```"8^`0`G````/CX!`!8```!F/@$`#P```'T^`0`7````C3X!`!\```"E
M/@$`0````,4^`0`?````!C\!`!P````F/P$`40```$,_`0`:````E3\!`!0`
M``"P/P$`"@```,4_`0`%````T#\!``8```#6/P$`"````-T_`0`2````YC\!
M`!````#Y/P$`$P````I``0`=````'D`!``\````\0`$`#P```$Q``0`$````
M7$`!``D```!A0`$`"P```&M``0`'````=T`!``4```!_0`$`%````(5``0`'
M````FD`!``@```"B0`$`#P```*M``0`(````NT`!``P```#$0`$`#P```-%`
M`0`&````X4`!`!0```#H0`$`!@```/U``0`,````!$$!``@````100$`&0``
M`!I!`0`1````-$$!``H```!&00$`&````%%!`0`3````:D$!`!P```!^00$`
M$0```)M!`0`/````K4$!``0```"]00$`&0```,)!`0`'````W$$!``(```#D
M00$``@```.=!`0`1````ZD$!``D```#\00$`!@````9"`0`2````#4(!`!<`
M```@0@$`!@```#A"`0`"````/T(!``0```!"0@$`#P```$="`0`3````5T(!
M``<```!K0@$`!P```'-"`0`1````>T(!``8```"-0@$`&````)1"`0`&````
MK4(!`!,```"T0@$`$````,A"`0`2````V4(!``(```#L0@$`!@```.]"`0`,
M````]D(!``D````#0P$`$0````U#`0`B````'T,!``<```!"0P$`!P```$I#
M`0`+````4D,!``4```!>0P$``@```&1#`0`+````9T,!`&$!``!S0P$`"@``
M`-5$`0`,````X$0!``H```#M1`$`!P```/A$`0`'`````$4!``<````(10$`
M`@```!!%`0`1````$T4!`!@````E10$`*P```#Y%`0`:````:D4!`!T```"%
M10$`$P```*-%`0`1````MT4!`"D```#)10$`#0```/-%`0`;`````48!`!(`
M```=1@$`"P```#!&`0`'````/$8!``4```!$1@$`$@```$I&`0`'````748!
M``<```!E1@$`"P```&U&`0`)````>48!``L```"#1@$`/````(]&`0`)````
MS$8!``4```#61@$`"@```-Q&`0`/````YT8!``H```#W1@$`"@````)'`0`*
M````#4<!``H````81P$`!@```"-'`0!9````*D<!``<```"$1P$`#````(Q'
M`0`2````F4<!``H```"L1P$`"0```+='`0`)````P4<!``D```#+1P$`!@``
M`-5'`0`=````W$<!`!0```#Z1P$`)0````](`0`M````-4@!`$````!C2`$`
M1````*1(`0!$````Z4@!`$H````N20$`)P```'E)`0`(````H4D!``@```"J
M20$`"````+-)`0`(````O$D!``@```#%20$`"0```,Y)`0`(````V$D!``X`
M``#A20$`!P```/!)`0`&````^$D!``8```#_20$`&P````9*`0`;````(DH!
M``@````^2@$`"@```$=*`0`+````4DH!``0```!>2@$`!````&-*`0`*````
M:$H!``H```!S2@$`"0```'Y*`0`(````B$H!``@```"12@$`$0```)I*`0`0
M````K$H!``\```"]2@$`"````,U*`0`-````UDH!``8```#D2@$`&0```.M*
M`0`/````!4L!`!`````52P$`"@```"9+`0`S````,4L!`"L```!E2P$`&P``
M`)%+`0`$````K4L!``8```"R2P$`(0```+E+`0`$````VTL!``0```#@2P$`
M%````.5+`0`4````^DL!`!0````/3`$`"````"1,`0`$````+4P!``D````R
M3`$`!````#Q,`0`2````04P!``@```!43`$`"````%U,`0`&````9DP!`!8`
M``!M3`$`%P```(1,`0`&````G$P!``X```"C3`$`#@```+),`0`0````P4P!
M`!````#23`$`"````.-,`0`(````[$P!`!T```#U3`$`$P```!--`0`5````
M)TT!`!`````]30$`#P```$Y-`0`3````7DT!``P```!R30$`!````']-`0`5
M````A$T!`"H```":30$`"````,5-`0`,````SDT!``X```#;30$`$@```.I-
M`0`$````_4T!``@````"3@$`!`````M.`0`7````$$X!``H````H3@$`"@``
M`#-.`0`:````/DX!`"0```!93@$`$@```'Y.`0`2````D4X!`!8```"D3@$`
M!````+M.`0`0````P$X!`!````#13@$`"````.).`0`/````ZTX!`!L```#[
M3@$`"````!=/`0`9````($\!`!D````Z3P$`&0```%1/`0`9````;D\!``0`
M``"(3P$`!````(U/`0`4````DD\!`!````"G3P$`*@```+A/`0`C````XT\!
M`"D````'4`$`:P```#%0`0`H````G5`!`"@```#&4`$`,0```.]0`0`Q````
M(5$!`"@```!340$`*0```'Q1`0`<````IE$!`!P```##40$`,0```.!1`0`H
M````$E(!`"X````[4@$`%````&I2`0`)````?U(!``P```")4@$`$````)92
M`0`-````IU(!``T```"U4@$`"P```,-2`0`5````SU(!``0```#E4@$`"```
M`.I2`0`2````\U(!`!@````&4P$`$````!]3`0`.````,%,!`!@````_4P$`
M$P```%A3`0`1````;%,!`!0```!^4P$`!````)-3`0`'````F%,!`!````"@
M4P$`#P```+%3`0`,````P5,!`!````#.4P$`#0```-]3`0`$````[5,!`"$`
M``#R4P$`"````!14`0`(````'50!``0````F5`$`$@```"M4`0`$````/E0!
M``0```!#5`$`"````$A4`0`$````450!`"T```!65`$`!````(14`0`1````
MB50!``0```";5`$`#0```*!4`0`-````KE0!`!X```"\5`$`&````-M4`0`3
M````]%0!``@````(50$`&0```!%5`0`0````*U4!``@````\50$``P```$55
M`0`*````254!``\```!450$`$P```&15`0`&````>%4!``8```!_50$`$0``
M`(95`0`1````F%4!`"8```"J50$`$0```-%5`0`:````XU4!`!(```#^50$`
M#P```!%6`0`$````(58!``P````F5@$`$@```#-6`0`/````1E8!`",```!6
M5@$`$@```'I6`0`:````C58!`#$```"H5@$`&0```-I6`0`3````]%8!``@`
M```(5P$`"@```!%7`0`9````'%<!``@````V5P$`"@```#]7`0`+````2E<!
M``H```!65P$`"P```&%7`0`(````;5<!`!8```!V5P$`!````(U7`0`E````
MDE<!`!$```"X5P$`"````,I7`0`*````TU<!``@```#>5P$`"P```.=7`0`$
M````\U<!``P```#X5P$`&P````58`0`M````(5@!``0```!/6`$`#0```%18
M`0`,````8E@!``P```!O6`$`$0```'Q8`0`/````CE@!``T```">6`$`"```
M`*Q8`0`2````M5@!``T```#(6`$`$@```-98`0`9````Z5@!`!4````#60$`
M`@```!E9`0`4````'%D!``@````Q60$`#@```#I9`0`*````25D!`!````!4
M60$`!@```&59`0`.````;%D!`!0```![60$`"````)!9`0`$````F5D!``8`
M``">60$``@```*59`0`7````J%D!``H```#`60$`"````,M9`0`3````U%D!
M``0```#H60$`!@```.U9`0`.````]%D!``,````#6@$`"`````=:`0`$````
M$%H!``0````56@$`"````!I:`0`$````(UH!``0````H6@$`$````"U:`0`$
M````/EH!``0```!#6@$`!````$A:`0`$````35H!``0```!26@$`-````%=:
M`0`-````C%H!``<```":6@$`"````*):`0`,````JUH!`#(```"X6@$`"0``
M`.M:`0`*````]5H!`!L`````6P$`*0```!Q;`0`:````1EL!``8```!A6P$`
M'P```&A;`0`4````B%L!``T```"=6P$`!````*M;`0`7````L%L!``0```#(
M6P$`#````,U;`0`$````VEL!`!<```#?6P$`&````/=;`0`5````$%P!`!D`
M```F7`$`%P```$!<`0`7````6%P!`!(```!P7`$`%````(-<`0`4````F%P!
M`!````"M7`$`%@```+Y<`0`B````U5P!`!0```#X7`$`$P````U=`0`5````
M(5T!`!(````W70$`%````$I=`0`6````7UT!`!T```!V70$`%0```)1=`0`7
M````JET!`!D```#"70$`$@```-Q=`0`2````[UT!`!T````"7@$`%0```"!>
M`0`,````-EX!`!<```!#7@$`$@```%M>`0`6````;EX!``P```"%7@$`2P``
M`))>`0`G````WEX!`!(````&7P$`%````!E?`0`4````+E\!`!@```!#7P$`
M#0```%Q?`0`2````:E\!`!,```!]7P$`$0```)%?`0`5````HU\!`!D```"Y
M7P$`%````--?`0!,````Z%\!`!8````U8`$`#@```$Q@`0`2````6V`!`!0`
M``!N8`$`&0```(-@`0`J````G6`!`"T```#(8`$`!@```/9@`0`$````_6`!
M``0````"80$`!`````=A`0`,````#&$!``P````980$`#````"9A`0`,````
M,V$!``H```!`80$`$@```$MA`0`+````7F$!``@```!J80$`"````'-A`0`(
M````?&$!``P```"%80$`"````))A`0`,````FV$!``H```"H80$`'P```+-A
M`0`$````TV$!``0```#880$`$0```-UA`0`1````[V$!`!<````!8@$`&@``
M`!EB`0`;````-&(!``(```!08@$`50```%-B`0`$````J6(!``P```"N8@$`
M"@```+MB`0`$````QF(!``@```#+8@$`"````-1B`0`$````W6(!``H```#B
M8@$`!@```.UB`0`*````]&(!``@```#_8@$`!`````AC`0`(````#6,!``X`
M```68P$`%0```"5C`0`$````.V,!``0```!`8P$`"@```$5C`0`(````4&,!
M``@```!98P$`"````&)C`0`.````:V,!``H```!Z8P$`"````(5C`0`2````
MCF,!``X```"A8P$`(````+!C`0`&````T6,!`!@```#88P$`#@```/%C`0`,
M`````&0!`!4````-9`$`"````"-D`0`.````+&0!``@````[9`$`!````$1D
M`0`=````260!`!<```!G9`$`!````']D`0`(````A&0!`!8```"-9`$`"@``
M`*1D`0`(````KV0!``@```"X9`$`!````,%D`0`1````QF0!``@```#89`$`
M#@```.%D`0`.````\&0!``@```#_9`$`"`````AE`0`1````$64!``8````C
M90$`'````"IE`0`I````1V4!`!,```!Q90$`(P```(5E`0`3````J64!``0`
M``"]90$`!P```,)E`0`<````RF4!``H```#G90$`!````/)E`0`(````]V4!
M``0`````9@$`$@````5F`0`$````&&8!``@````=9@$`"````"9F`0`(````
M+V8!``@````X9@$`#````$%F`0`(````3F8!``X```!79@$`#````&9F`0`$
M````<V8!``P```!X9@$`%@```(5F`0`'````G&8!``@```"D9@$`#````*UF
M`0`5````NF8!``P```#09@$`$P```-UF`0`(````\68!``D```#Z9@$`"0``
M``1G`0`,````#F<!`"H````;9P$`$P```$9G`0`(````6F<!``H```!C9P$`
M/````&YG`0`2````JV<!`!X```"^9P$`%````-UG`0`$````\F<!`!0```#W
M9P$`&P````QH`0`;````*&@!`!8```!$:`$`%P```%MH`0`5````<V@!`!(`
M``"):`$`$P```)QH`0`$````L&@!``T```"U:`$`"@```,-H`0`)````SF@!
M``H```#8:`$`"0```.-H`0`(````[6@!``H```#V:`$`"0````%I`0`'````
M"VD!``0````3:0$`!````!AI`0`*````'6D!``@````H:0$`!@```#%I`0`&
M````.&D!``@````_:0$`#0```$AI`0`0````5FD!`!<```!G:0$`%@```']I
M`0`0````EFD!`!````"G:0$`&P```+AI`0`0````U&D!``P```#E:0$`!```
M`/)I`0`N````]VD!``T````F:@$`"0```#1J`0`$````/FH!``0```!#:@$`
M!````$AJ`0`$````36H!``8```!2:@$`!@```%EJ`0`(````8&H!``@```!I
M:@$`"P```')J`0`3````?FH!`!$```"2:@$`"````*1J`0`(````K6H!``@`
M``"V:@$`"````+]J`0`5````R&H!``8```#>:@$`#@```.5J`0`&````]&H!
M``0```#[:@$`"`````!K`0`(````"6L!``0````2:P$``@```!=K`0`.````
M&FL!``@````I:P$`!````#)K`0`;````-VL!``X```!3:P$`3@```&)K`0`*
M````L6L!``0```"\:P$`!````,%K`0`(````QFL!``0```#/:P$`!@```-1K
M`0`$````VVL!``@```#@:P$`!@```.EK`0`$````\&L!``T```#U:P$`%```
M``-L`0`:````&&P!`"$````S;`$`&P```%5L`0`&````<6P!``(```!X;`$`
M"````'ML`0`$````A&P!``0```");`$`#````(YL`0`%````FVP!``\```"A
M;`$`$@```+%L`0`0````Q&P!`!8```#5;`$`#@```.QL`0`,````^VP!`!0`
M```(;0$`!````!UM`0`$````(FT!``8````G;0$`"P```"YM`0`+````.FT!
M``0```!&;0$`#0```$MM`0`3````66T!`!0```!M;0$`$@```()M`0`(````
ME6T!`!````">;0$`*0```*]M`0`;````V6T!`!L```#U;0$`!````!%N`0`5
M````%FX!``L````L;@$`%````#AN`0`(````36X!``@```!6;@$`"````%]N
M`0`/````:&X!`"````!X;@$`#P```)EN`0`,````J6X!`!$```"V;@$`#```
M`,AN`0`)````U6X!``(```#?;@$`!````.)N`0`$````YVX!`"$```#L;@$`
M!@````YO`0`7````%6\!``0````M;P$`!````#)O`0`.````-V\!``0```!&
M;P$`!````$MO`0`1````4&\!``(```!B;P$`!````&5O`0`1````:F\!``(`
M``!\;P$`"````']O`0`&````B&\!``@```"/;P$`$P```)AO`0`0````K&\!
M``4```"];P$`,````,-O`0`>````]&\!`"P````3<`$`(0```$!P`0`N````
M8G`!`"8```"1<`$`(0```+AP`0`Q````VG`!`"$````,<0$`'0```"YQ`0`<
M````3'$!``8```!I<0$`"````'!Q`0`%````>7$!`!8```!_<0$`%0```)9Q
M`0`-````K'$!`!$```"Z<0$`!````,QQ`0`&````T7$!``@```#8<0$`$```
M`.%Q`0`5````\G$!`!4````(<@$`'0```!YR`0`'````/'(!`!````!$<@$`
M(````%5R`0`.````=G(!``X```"%<@$`!@```)1R`0`(````FW(!``H```"D
M<@$`#P```*]R`0`P````OW(!`&D```#P<@$`/@```%IS`0`)````F7,!``@`
M``"C<P$`"0```*QS`0`,````MG,!``T```##<P$`"````-%S`0`$````VG,!
M``T```#?<P$`#````.US`0`)````^G,!``X````$=`$`$P```!-T`0`:````
M)W0!`$8```!"=`$`"````(ET`0`,````DG0!``H```"?=`$`$````*IT`0`$
M````NW0!``0```#`=`$`#0```,5T`0`0````TW0!``@```#D=`$`"````.UT
M`0`,````]G0!`!`````#=0$`'````!1U`0`<````,74!`!@```!.=0$`&```
M`&=U`0`:````@'4!`!H```";=0$`#@```+9U`0`;````Q74!`!````#A=0$`
M$````/)U`0`.`````W8!``X````2=@$`"````"%V`0`.````*G8!``X````Y
M=@$`#````$AV`0`,````578!``\```!B=@$`#0```')V`0`1````@'8!`"$`
M``"2=@$`"0```+1V`0`$````OG8!``8```##=@$`&P```,IV`0`0````YG8!
M``\```#W=@$`#P````=W`0`/````%W<!``X````G=P$`#@```#9W`0`-````
M17<!``L```!3=P$`$````%]W`0`6````<'<!`!,```"'=P$`#0```)MW`0`1
M````J7<!``T```"[=P$`#P```,EW`0`1````V7<!``\```#K=P$`#P```/MW
M`0`1````"W@!``0````=>`$`"````")X`0`@````*W@!``T```!,>`$`$```
M`%IX`0`2````:W@!``@```!^>`$`#P```(=X`0`&````EW@!``0```">>`$`
M#@```*-X`0`0````LG@!``0```##>`$`#````,AX`0`2````U7@!``8```#H
M>`$`#0```.]X`0`$````_7@!``0````">0$`!`````=Y`0`$````#'D!``@`
M```1>0$`"````!IY`0`(````(WD!``H````L>0$`"@```#=Y`0`,````0GD!
M`!(```!/>0$`"````&)Y`0`(````:WD!``@```!T>0$`"````'UY`0`(````
MAGD!``@```"/>0$`*````)AY`0`$````P7D!`!,```#&>0$`+0```-IY`0`9
M````"'H!``T````B>@$`#P```#!Z`0`*````0'H!``H```!+>@$`!````%9Z
M`0`G````6WH!``8```"#>@$`$@```(IZ`0`&````G7H!``D```"D>@$`#@``
M`*YZ`0`4````O7H!`!8```#2>@$`$0```.EZ`0`$````^WH!``@`````>P$`
M$`````E[`0`$````&GL!``@````?>P$`!@```"A[`0`0````+WL!`!(```!`
M>P$`'P```%-[`0`:````<WL!``0```".>P$`!````)-[`0`(````F'L!``@`
M``"A>P$`!@```*I[`0`(````L7L!``0```"Z>P$`!@```+][`0`&````QGL!
M``0```#->P$`"0```-)[`0`@````W'L!``0```#]>P$`'P````)\`0`*````
M(GP!``P````M?`$`"````#I\`0`/````0WP!``T```!3?`$`$0```&%\`0`/
M````<WP!``\```"#?`$`#0```)-\`0`1````H7P!`!````"S?`$`$@```,1\
M`0`6````UWP!``0```#N?`$`$@```/-\`0`)````!GT!``H````0?0$`"@``
M`!M]`0`$````)GT!``0````K?0$`!````#!]`0`$````-7T!``@````Z?0$`
M+0```$-]`0`)````<7T!``0```![?0$`!````(!]`0`"````A7T!``P```"(
M?0$`#````)5]`0`,````HGT!`!,```"O?0$``@```,-]`0`(````QGT!`!L`
M``#/?0$``P```.M]`0`,````[WT!`#D```#\?0$`%P```#9^`0`$````3GX!
M``0```!3?@$`"````%A^`0`-````87X!``\```!O?@$`$P```']^`0`3````
MDWX!``L```"G?@$`#@```+-^`0`@````PGX!``H```#C?@$`#0```.Y^`0`$
M````_'X!``0````!?P$`$@````9_`0`D````&7\!`!T````^?P$`%P```%Q_
M`0`*````='\!`!<```!_?P$`%````)=_`0`/````K'\!`!<```"\?P$`&```
M`-1_`0`7````[7\!``P````%@`$`#````!*``0`$````'X`!`!(````D@`$`
M!````#>``0`$````/(`!``D```!!@`$`"@```$N``0`$````5H`!`"X```!;
M@`$`"P```(J``0`(````EH`!`!,```"?@`$`*P```+.``0`1````WX`!``0`
M``#Q@`$`$@```/:``0`:````"8$!``0````D@0$`#P```"F!`0`N````.8$!
M``0```!H@0$`"0```&V!`0`8````=X$!`!<```"0@0$`%````*B!`0`$````
MO8$!``0```#"@0$`'@```,>!`0`U````YH$!`!`````<@@$`'````"V"`0`0
M````2H(!``8```!;@@$`"````&*"`0`$````:X(!``@```!P@@$`"````'F"
M`0`$````@H(!`!\```"'@@$`#P```*>"`0`/````MX(!``8```#'@@$`!```
M`,Z"`0`(````TX(!``0```#<@@$`(P```.&"`0`&````!8,!``@````,@P$`
M"````!6#`0`(````'H,!``0````G@P$`!````"R#`0`$````,8,!``0````V
M@P$`!````#N#`0`$````0(,!`!4```!%@P$`$````%N#`0`$````;(,!``@`
M``!Q@P$`#````'J#`0`(````AX,!`!````"0@P$`#@```*&#`0`+````L(,!
M``0```"\@P$`$@```,&#`0`,````U(,!``X```#A@P$`$@```/"#`0`C````
M`X0!`!4````GA`$`%0```#V$`0`5````4X0!`!$```!IA`$`$0```'N$`0`7
M````C80!`!,```"EA`$`$0```+F$`0`(````RX0!``0```#4A`$`'````-F$
M`0`(````]H0!``D```#_A`$`!`````F%`0`5````#H4!`!0````DA0$`!@``
M`#F%`0`1````0(4!``T```!2A0$`#P```&"%`0`$````<(4!``@```!UA0$`
M!@```'Z%`0`*````A84!``8```"0A0$`%````)>%`0`,````K(4!`!(```"Y
MA0$`!````,R%`0`-````T84!``(```#?A0$`&0```.*%`0`:````_(4!``T`
M```7A@$`&@```"6&`0`A````0(8!``D```!BA@$`&P```&R&`0`7````B(8!
M`!P```"@A@$`&P```+V&`0`@````V88!``L```#ZA@$`"P````:'`0`*````
M$H<!``L````=AP$`$````"F'`0`1````.H<!``L```!,AP$`"P```%B'`0`+
M````9(<!`!L```!PAP$`&P```(R'`0`?````J(<!`!P```#(AP$`'0```.6'
M`0`:`````X@!`$@````>B`$`$P```&>(`0`.````>X@!``8```"*B`$`%0``
M`)&(`0`&````IX@!``@```"NB`$`$P```+>(`0`7````RX@!`!<```#CB`$`
M!@```/N(`0`K`````HD!`"T````NB0$``@```%R)`0`1````7XD!`!8```!Q
MB0$`&0```(B)`0`&````HHD!`!@```"IB0$`#0```,*)`0`&````T(D!``8`
M``#7B0$`#````-Z)`0`-````ZXD!``8```#YB0$`"`````"*`0`&````"8H!
M`!(````0B@$`!@```".*`0`$````*HH!``8````OB@$`"````#:*`0`$````
M/XH!`!D```!$B@$``@```%Z*`0`$````88H!``H```!FB@$`!@```'&*`0`$
M````>(H!``8```!]B@$`%P```(2*`0`&````G(H!``P```"CB@$`"P```+"*
M`0`C````O(H!`!,```#@B@$`)@```/2*`0`.````&XL!`"T````JBP$`$@``
M`%B+`0`(````:XL!``0```!TBP$`!@```'F+`0`(````@(L!``0```")BP$`
M"````(Z+`0`$````EXL!`!````"<BP$`%````*V+`0`$````PHL!``@```#'
MBP$`"@```-"+`0`-````VXL!`!````#IBP$`#````/J+`0`,````!XP!``P`
M```4C`$`%@```"&,`0`*````.(P!``@```!#C`$`"````$R,`0`(````58P!
M``@```!>C`$`"````&>,`0`&````<(P!``@```!WC`$`%````(",`0`*````
ME8P!``0```"@C`$`$P```*6,`0`,````N8P!`#````#&C`$`#P```/>,`0`A
M````!XT!`!$````IC0$`!````#N-`0`$````0(T!``T```!%C0$`"@```%.-
M`0`=````7HT!``@```!\C0$`!0```(6-`0`&````BXT!``T```"2C0$`!```
M`*"-`0`$````I8T!``0```"JC0$`"@```*^-`0`$````NHT!``8```"_C0$`
M#````,:-`0`3````TXT!``0```#GC0$`$P```.R-`0`(`````(X!``0````)
MC@$`"`````Z.`0`$````%XX!``L````<C@$`!````"B.`0`4````+8X!``0`
M``!"C@$`!````$>.`0`(````3(X!``0```!5C@$`$````%J.`0`3````:XX!
M`!L```!_C@$`%0```)N.`0`5````L8X!`!@```#'C@$`)@```.".`0`5````
M!X\!`!$````=CP$`&@```"^/`0`N````2H\!`!,```!YCP$`#0```(V/`0`$
M````FX\!``0```"@CP$`$0```*6/`0`(````MX\!``@```#`CP$`*P```,F/
M`0`6````]8\!``X````,D`$`*0```!N0`0`O````19`!``0```!UD`$`#```
M`'J0`0`&````AY`!``0```".D`$`$@```).0`0`*````II`!``@```"QD`$`
M"````+J0`0`$````PY`!``@```#(D`$`!````-&0`0`(````UI`!``@```#?
MD`$`#````.B0`0`,````]9`!`!H````"D0$`%@```!V1`0`,````-)$!``0`
M``!!D0$`"````$:1`0`6````3Y$!``8```!FD0$``@```&V1`0`&````<)$!
M``8```!WD0$`!````'Z1`0`&````@Y$!``8```"*D0$`"````)&1`0`$````
MFI$!``0```"?D0$`"````*21`0`E````K9$!`#(```#3D0$`"`````:2`0`(
M````#Y(!`!4````8D@$`%0```"Z2`0`*````1)(!``H```!/D@$`!````%J2
M`0`$````7Y(!``H```!DD@$`*````&^2`0`$````F)(!``@```"=D@$`"```
M`*:2`0`(````KY(!``8```"XD@$`)P```+^2`0`$````YY(!`!0```#LD@$`
M"@````&3`0`.````#),!`!<````;DP$`$0```#.3`0`:````19,!`!<```!@
MDP$`%0```'B3`0`(````CI,!``0```"7DP$`"````)R3`0`-````I9,!`!``
M``"SDP$`!````,23`0`(````R9,!``X```#2DP$`$@```.&3`0`(````]),!
M``X```#]DP$`!`````R4`0`$````$90!``@````6E`$`!@```!^4`0`+````
M)I0!``0````RE`$`$@```#>4`0`+````2I0!`!````!6E`$`$````&>4`0`&
M````>)0!``8```!_E`$``@```(:4`0`$````B90!``P```".E`$`"````)N4
M`0`&````I)0!``0```"KE`$`&P```+"4`0`/````S)0!``\```#<E`$`%@``
M`.R4`0`.`````Y4!``0````2E0$`"@```!>5`0`*````(I4!``0````ME0$`
M#````#*5`0`&````/Y4!`!<```!&E0$`+````%Z5`0`6````BY4!`!D```"B
ME0$`,P```+R5`0`2````\)4!`!(````#E@$`%0```!:6`0`H````+)8!``H`
M``!5E@$`&P```&"6`0`$````?)8!``D```"!E@$`!P```(N6`0`(````DY8!
M`#@```"<E@$`#P```-66`0`7````Y98!``@```#]E@$`!`````:7`0`$````
M"Y<!``@````0EP$`"````!F7`0`,````(I<!`!0````OEP$`$@```$27`0`.
M````5Y<!`!8```!FEP$`"````'V7`0`1````AI<!``P```"8EP$`!@```*67
M`0!#````K)<!``T```#PEP$`$0```/Z7`0`5````$)@!``T````FF`$`$0``
M`#28`0`7````1I@!`!````!>F`$`#0```&^8`0`,````?9@!``@```"*F`$`
M$@```).8`0`(````II@!``0```"OF`$`+````+28`0`$````X9@!`!L```#F
MF`$`"`````*9`0`/````"YD!``0````;F0$`"````""9`0`H````*9D!`"$`
M``!2F0$`(P```'29`0`Z````F)D!``0```#3F0$`#````-B9`0`<````Y9D!
M`!,````"F@$`!````!::`0`(````&YH!`"$````DF@$`!````$::`0`?````
M2YH!`"````!KF@$`"@```(R:`0`4````EYH!`!4```"LF@$`%@```,*:`0`4
M````V9H!`!(```#NF@$`%`````&;`0`(````%IL!``@````?FP$`"````"B;
M`0`(````,9L!``H````ZFP$`!````$6;`0`7````2IL!``0```!BFP$`!```
M`&>;`0`(````;)L!`!(```!UFP$`!````(B;`0`(````C9L!`!,```"6FP$`
M%0```*J;`0`"````P)L!``0```##FP$`!````,B;`0`(````S9L!``@```#6
MFP$`"@```-^;`0`<````ZIL!`!(````'G`$`!@```!J<`0`,````(9P!``@`
M```NG`$`$P```#><`0`1````2YP!`"P```!=G`$`!@```(J<`0`&````D9P!
M``0```"8G`$`"@```)V<`0`.````J)P!``@```"WG`$`#````,"<`0`(````
MS9P!``@```#6G`$`!@```-^<`0`$````YIP!`!0```#KG`$`!`````"=`0`*
M````!9T!``@````0G0$``@```!F=`0`$````')T!``@````AG0$`!````"J=
M`0`&````+YT!``8````VG0$`&````#V=`0`*````5IT!``8```!AG0$`$0``
M`&B=`0`$````>IT!``0```!_G0$`/P```(2=`0`$````Q)T!``0```#)G0$`
M&0```,Z=`0`E````Z)T!``\````.G@$`&````!Z>`0`E````-YX!`!4```!=
MG@$`&````'.>`0`/````C)X!``\```"<G@$`#````*R>`0`$````N9X!``0`
M``"^G@$`!````,.>`0`"````R)X!``0```#+G@$`"0```-">`0`&````VIX!
M``0```#AG@$`!@```.:>`0`$````[9X!``0```#RG@$`$0```/>>`0`$````
M"9\!`!8````.GP$`%````"6?`0`-````.I\!`!(```!(GP$`#@```%N?`0`,
M````:I\!`!0```!WGP$`'0```(R?`0`$````JI\!``@```"OGP$`!````+B?
M`0`,````O9\!`!````#*GP$`!````-N?`0`(````X)\!``@```#IGP$`!```
M`/*?`0`$````]Y\!`!4```#\GP$`)P```!*@`0`%````.J`!``@```!`H`$`
M"````$F@`0`2````4J`!``0```!EH`$`!@```&J@`0`A````<:`!`!````"3
MH`$`"````*2@`0`$````K:`!``8```"RH`$`"````+F@`0`,````PJ`!``8`
M``#/H`$`#@```-:@`0`/````Y:`!`!@```#UH`$`(0````ZA`0`4````,*$!
M`!P```!%H0$`%@```&*A`0`[````>:$!``8```"UH0$`)@```+RA`0`?````
MXZ$!`"@````#H@$`.@```"RB`0`/````9Z(!`!L```!WH@$`'0```).B`0`=
M````L:(!`!,```#/H@$`$0```..B`0`9````]:(!`!4````/HP$`!@```"6C
M`0`P````+*,!`&4```!=HP$`'@```,.C`0`/````XJ,!`"\```#RHP$`,0``
M`"*D`0`O````5*0!`!4```"$I`$`"````)JD`0`&````HZ0!`!D```"JI`$`
M%P```,2D`0`7````W*0!`!8```#TI`$`$P````NE`0`3````'Z4!`!T````S
MI0$`"````%&E`0`&````6J4!`!\```!AI0$`$P```(&E`0`9````E:4!`!@`
M``"OI0$`#0```,BE`0`1````UJ4!`$(```#HI0$`)````"NF`0`E````4*8!
M`!\```!VI@$`'````):F`0`D````LZ8!`#D```#8I@$`+P```!*G`0`7````
M0J<!`!L```!:IP$`(@```':G`0`X````F:<!`#$```#2IP$`*P````2H`0`I
M````,*@!`"4```!:J`$`'@```("H`0`>````GZ@!`!L```"^J`$`$0```-JH
M`0`9````[*@!`!L````&J0$`&P```"*I`0`D````/JD!``\```!CJ0$`/0``
M`'.I`0`3````L:D!``@```#%J0$`:@```,ZI`0`S````.:H!`!,```!MJ@$`
M+0```(&J`0`7````KZH!``\```#'J@$`)````->J`0`"````_*H!``@```#_
MJ@$`!`````BK`0`(````#:L!``@````6JP$`"````!^K`0`+````**L!``0`
M```TJP$`#P```#FK`0`&````2:L!`$L```!0JP$`!````)RK`0`+````H:L!
M``L```"MJP$`!P```+FK`0`$````P:L!``P```#&JP$`!````-.K`0`1````
MV*L!``X```#JJP$`!@```/FK`0`&`````*P!`!(````'K`$`#P```!JL`0`5
M````*JP!``P```!`K`$`&````$VL`0`/````9JP!``X```!VK`$`#````(6L
M`0`$````DJP!``4```"7K`$`#P```)VL`0`0````K:P!`!(```"^K`$`'P``
M`-&L`0`>````\:P!`!\````0K0$`#@```#"M`0`6````/ZT!`!D```!6K0$`
M%````'"M`0`2````A:T!`!(```"8K0$`%P```*NM`0`2````PZT!`!(```#6
MK0$`%P```.FM`0`8`````:X!`!$````:K@$`'0```"RN`0`1````2JX!`!H`
M``!<K@$`$0```'>N`0`2````B:X!`!8```"<K@$`%P```+.N`0`2````RZX!
M`!<```#>K@$`%0```/:N`0`3````#*\!`!`````@KP$`$0```#&O`0`2````
M0Z\!`!<```!6KP$`$@```&ZO`0`2````@:\!``\```"4KP$`)@```*2O`0`I
M````RZ\!``X```#UKP$`%@````2P`0`G````&[`!`!@```!#L`$`%@```%RP
M`0`>````<[`!`!\```"2L`$`&````+*P`0`3````R[`!`!(```#?L`$`%P``
M`/*P`0`B````"K$!`!8````ML0$`(````$2Q`0`$````9;$!``@```!JL0$`
M!````'.Q`0`>````>+$!`!L```"7L0$`!@```+.Q`0`.````NK$!`"<```#)
ML0$`%0```/&Q`0`4````![(!`"0````<L@$`!````$&R`0`&````1K(!`"4`
M``!-L@$`)````'.R`0`/````F+(!`!<```"HL@$`$@```,"R`0`&````T[(!
M`(T```#:L@$`"````&BS`0`.````<;,!``0```"`LP$`!P```(6S`0`*````
MC;,!``L```"8LP$`#P```*2S`0`$````M+,!`",```"YLP$`#````-VS`0`,
M````ZK,!`!````#WLP$`#@````BT`0`(````%[0!`#4````@M`$`!@```%:T
M`0`?````7;0!``H```!]M`$`"@```(BT`0`*````D[0!`!T```">M`$`$```
M`+RT`0`*````S;0!`!<```#8M`$`"P```/"T`0`(````_+0!``\````%M0$`
M%0```!6U`0`1````*[4!``0````]M0$`$@```$*U`0`&````5;4!`!@```!<
MM0$``@```'6U`0`(````>+4!`!(```"!M0$`!````)2U`0`4````F;4!`"0`
M``"NM0$`!````-.U`0`(````V+4!``@```#AM0$`"````.JU`0`%````\[4!
M``8```#YM0$`#P````"V`0`/````$+8!``<````@M@$`#````"BV`0`*````
M-;8!`"8```!`M@$`(P```&>V`0`&````B[8!``@```"2M@$`'0```)NV`0`$
M````N;8!`!L```"^M@$`#0```-JV`0`1````Z+8!``0```#ZM@$`!@```/^V
M`0`(````!K<!``P````/MP$`$````!RW`0`$````+;<!``0````RMP$`!```
M`#>W`0`$````/+<!``D```!!MP$`"````$NW`0`1````5+<!`!(```!FMP$`
M&0```'FW`0`C````D[<!``\```"WMP$`#P```,>W`0`6````U[<!``@```#N
MMP$`(@```/>W`0`$````&K@!`!,````?N`$`(P```#.X`0`(````5[@!``@`
M``!@N`$`!0```&FX`0`(````;[@!``(```!XN`$`!@```'NX`0`(````@K@!
M``4```"+N`$`!@```)&X`0`$````F+@!``@```"=N`$`!````*:X`0`*````
MJ[@!``H```"VN`$`.````,&X`0`P````^K@!`!,````KN0$`$P```#^Y`0`5
M````4[D!``T```!IN0$``@```'>Y`0`"````>KD!``P```!]N0$`!````(JY
M`0`,````C[D!``(```"<N0$`"P```)^Y`0`]````J[D!`!D```#IN0$`"P``
M``.Z`0`A````#[H!`"$````QN@$`)0```%.Z`0`+````>;H!`%,```"%N@$`
M%P```-FZ`0!!````\;H!`"@````SNP$`(0```%R[`0`<````?KL!`!4```";
MNP$`%0```+&[`0`5````Q[L!`!4```#=NP$`%0```/.[`0`3````";P!`!<`
M```=O`$`(@```#6\`0`>````6+P!`!````!WO`$`%P```(B\`0`(````H+P!
M`%,```"IO`$`"````/V\`0!6````!KT!`"T```!=O0$`40```(N]`0`;````
MW;T!`#8```#YO0$`$P```#"^`0`9````1+X!`!,```!>O@$`"0```'*^`0`/
M````?+X!`!@```",O@$`&P```*6^`0`/````P;X!`!(```#1O@$`.@```.2^
M`0`/````'[\!``\````OOP$`%0```#^_`0`,````5;\!``\```!BOP$`$0``
M`'*_`0`*````A+\!``H```"/OP$`"P```)J_`0`2````IK\!`!0```"YOP$`
M!@```,Z_`0`(````U;\!``H```#>OP$`"````.F_`0`&````\K\!``8```#Y
MOP$`#0````#``0`&````#L`!``8````5P`$`#0```!S``0`&````*L`!``8`
M```QP`$`#P```#C``0`&````2,`!``T```!/P`$`"````%W``0`&````9L`!
M``8```!MP`$`$````'3``0`,````A<`!``0```"2P`$`#@```)?``0`(````
MIL`!`!(```"OP`$`#````,+``0`*````S\`!``0```#:P`$`$P```-_``0`$
M````\\`!``,```#XP`$``@```/S``0`2````_\`!``0````2P0$`$````!?!
M`0`-````*,$!``P````VP0$``P```$/!`0`"````1\$!``0```!*P0$`"0``
M`$_!`0`)````6<$!``8```!CP0$`!@```&K!`0`(````<<$!``0```!ZP0$`
M$````'_!`0`$````D,$!``P```"5P0$`"````*+!`0`3````J\$!``(```"_
MP0$`!````,+!`0`(````Q\$!``8```#0P0$`#````-?!`0`:````Y,$!``0`
M``#_P0$`!@````3"`0`*````"\(!``4````6P@$`!0```!S"`0`0````(L(!
M``$```!-!0```````/`&``"!!0``300``#L&``#"````E@(``*0$``#(!0``
M-00``)8!````````-@````````````````````````"P`0``?0,``!4$``!C
M`@``FP````````#M`0``KP0``,T```"X!@```````.`!``!O!```\0``````
M``#5``````````````#D`0```````*,%``!<`0``;P8```````!)!P``4P8`
M`/\"````````I`4``!0!````````[P$``$P```"&!0``````````````!P``
M``0``/<$``!T`0``(P8``)L&``""!0```````*8&``!"!```K@,``#\"``!U
M`0```P4``/T&``#'`````````.4$``!'`P``)P,``)0!```_!0``(0<``#X"
M``"Y!@``@@8``'8$``!X!@``3`(```$#``!E````@P```/(#``!S`@``:@(`
M``````#8!@``!@,``(D&````````"P```.0&````````>04```````#[`@``
M(0,``.<&```(````J`,```````!O````7@4``````````````````$@&````
M````H`(````````G!0``M@8``"P$``!,`P``$@(```````#R!````````!X$
M``"O!0``&P<``-4!```O`@``5`4``,P!````````8`(```````#T!@``G`,`
M`&H&``````````````4%`````````````.@%```G!@`````````````8````
M``````````"T`P``Y04``)$"`````````````%$!``"J`0``KP8``'H````0
M!```W00``!P$```'!@``>P,``$0"``"*!```-P0``%D%``"U`@``104``,D`
M````````^@0```('``"-`0``;P,``-`$```U`0``9@```!(&````````OP4`
M`*T&````````E08``,\!``#Y!@``K`$``-P#``!(!P``DP(``/P"``#:!```
MV@,``!8%````````0`(``&\%```W!0``9P8``)````!6`P``R`0``/@%````
M````$@0````````%`@```````*("```T`P``;`````````""`P``_@$`````
M``!9!```A`,```0`````````8P8```````#*`````````),$``!\!0``?```
M``$"``#8!0``,0`````````5!P``(08```````#*!```````````````````
M0@`````````\!```;`4``/\&``"0!0``,`4```````#)`@``804````"``"?
M!@``-P,```````!1!```+04``(P!```P`````````(4%``!#!@``#@4``)$#
M``#&!@``Q@4``&0!``":!0````````````"Q!@``"@0``&(&``#B!```````
M`"8!`````````````/T```#^!0``F@,``.<```!K````H0````````!K!@``
M%08``(0!```B`````````/`#``#L!```;0,``%`#`````````````)0&````
M`````````,(&``#%!@``-0,``*0&```/!0``&`$``"X'`````````@$``.@$
M````````3`$``)(#``!K!```#@0`````````````C00``!D````T`0``ZP,`
M`)<#```)`P``M`$``$@$```'!```5P(```8"``!X!0``Y`(``$D```"T!0``
M908``````````````P```(T"`````````````$0#```E`P``+P4`````````
M````,0<``(\$```#!P``UP```'0$``!5!@```````,0$``!%````]08``&H`
M```*`P``4@,``,`&``#1````-`4```````!A`P``Z@(``.X```!?````5P8`
M``````!'`@``/P<``#`"`````````````"0#``",!0``<````!<%````````
MV`0``!`!```V!@``2P,``!(%``"!`P``7`````````#Y`0``$P8``!\&````
M````````````````````?@,``,@"```^`P```````(,"``#<`0``Q`$``!X#
M``"]````5@```(\"``"F`@``$P,``)<&````````2@<``-D%````````0@,`
M``````"W!0``>`$```````#.`@``1@,``)0````_````+P8``)H!``#1!```
M/`4`````````````W@,```8&``!X````A0,``#8$``#M`P`````````````3
M````OP,````````=`@``````````````````%0$``(0&```+!````````'T$
M``#3!0```````/(%```I!P``;`8``$$$``#[`P``WP,``.H$``!!!0``J0(`
M``T'``#C`0```````"H%``#'`P``&0,``+T%``#?!@``N04````````R`@``
MX@(``#4'``#\!@```````/P!```<`@```````'H!````````>@,``!X"````
M````8@4``&D&````````JP4```````#-!0````````````#)`P``#04`````
M``"<`@```````(P#``!V`P``X@$``*8!````````TP$```````"%`@``````
M`*T%```)!0````````````#^`````````'$!```/````Y08```````#Z`P``
MN`0```````"]!@````````````"O`P``C@8``.8$``"?!```AP(````````@
M!P````````(%``""!`````````````"0`0``U`8``.$&``"2!@``````````
M```:`P``T@0``.`````%````(`$``$D&```Y`P``\@8``+,&````````(@$`
M`&8%```P!P``@08``!0'````````]P4``#8%``!,!0``?P(``)4!``!'!```
M"0```!T`````````=P```!X&````````_0$``*,"````````30$``!0#````
M````3@$``````````````````"`#````````<00``/("```4!0``(P$`````
M``!U!@``*@(```````#C!`````````````#D!0``$`,``)D%````````<04`
M``````#I`0```````)T!````````!P,``%(&```)!```BP(```````"X`@``
M``````````!2````"`(``&4"````````&08``"X"``!?!@```````#`!``"#
M!@``,04```````"+!```````````````````M````(T%```1`0``G`4``)T#
M``"O`0``?@$``"0&```^````<P4``(("``!5`P```````&8#``!<!@``B@8`
M`%$```"@!```H0$```````!V````M00````````=!P```````"P!````````
MIP,`````````````L04``$,!````````'P```,4!```4!```U@0``!``````
M`````````!4%``!"!@```````(8"``#V`````````.8```#S`````````$`$
M```@`@```````,(%``"+!@``WP0```````#,`P``Y@8``*L#```A`@``````
M`&8"````````S08``$4$``#>!```900``'L!```#`0``B0$``/,!````````
M`````+8%````````3`0``+D```#^!```7@8````````]!P`````````````:
M`0``-P````````"X````,`0``+0"````````[P,`````````````K0(`````
M````````>0````````#'!@``R08``#4&``"\`0```````/H&```L`P``Z@4`
M`,@#``#T!```D`0``'4$````````'P,``,8"``#%`P``C@```-<$```M!```
M``````````#/````^`8``"@%```]`@``-`0````````S````\`$``.(`````
M````B00```````#0!0``H@0``)`#``"A!@``NP0``"@'``!.`P``=P8`````
M``"V`@``8`,``/0``````````````,0"``#.`P``!`<``)$$```<!@``+`(`
M`&`%```<!0``P````$L$```>````F````*L`````````M08`````````````
M`````(H!````````RP$````````*````O@$```````#Y`P``J@(``-,&````
M````60```,L```#B!@```````.<!````````7@$``-D```!*`0``L`0``*D&
M````````)@,``````````````````(,#````````@`4``,,`````````````
M`*`%``!?`P``B`0````````\!@``]@$``/4!````````3@0``$H```")!0``
MYP4``!`%````````4`4```````#\!0``/@4``,P`````````00(```````"'
M````6`4``&$```!?`0``:@4```````#]`P``*0$``'L```!2!```````````
M````````^P0``"P&````````KP```'H$``#1`P```````.X!```X!@``%@8`
M`/,&``#/!0``P@0``/<!``#W!@```````.P#```\`````````.@!```7!@``
M@`(```````!4`0``<`8```````!:!```W0(``+`#``"H!@``$`(``+4#``#6
M````*0```&D!``"(`P```````*8#``````````````````"Q!```K@8`````
M```:!```#0```%L#``!*!```S`0``%<#``"%!```[P0``),!``!8`@``G`$`
M`",#````````\`(``%@!````````QP0``#@%``#``P``D08``"8&``#6!0``
MGP4````````J!@``9`4``$$`````````'`,```````"@`0``!P<``"0%````
M``````````````#9`@``8P4``.4"```O`P``\P,``.(#``!#````K`8``'$"
M``!?`@``90,```````#1`0``,@$`````````````PP0``,@!````````4P4`
M``````#<````(@,``"@`````````U`(```````#Z`0``"0<``'<!``!H````
M`````````````````````+<"````````0`8``*L$``"[!@``,@0```,$````
M!0``K@```````````````P(``(T#````````ZP(````````%!@``8P$``"@!
M````````5P0`````````````:`$```````!.````"`,``%4%````````*`8`
M``P$``"P!0```````&8$````````,P,``-D&````````3@(````````[!```
M=`(``)<```!S````60$``.`%``!"`@``40,``$4#``!`````W0````````!N
M`0``?`0```L#```1!```S`(``($$```?`0``4P$``)4%`````````````*D`
M```Q`P``?P0``&X$````````JP$``(X#```K````.P,``$\#``"7`0``10(`
M```````?!0```````-L"``````````````````!-`@``R@8``,$!``">`P``
M?P```)X```"G!@``4@4```````#@`P``6@```$(!```R!0``R@$``)D```#Z
M!0``N`$``(\```!A`0``#`(``*4#```9!P```````/,"```2!P``Z04``&``
M````````(0```&8!````````%@,````````````````````````;`P``<@0`
M`'@"``"M!````````$T&```&!0``/04```````!K`P``Y0```-H&```9`0``
MLP(``/\#``"<!```N`4````````$`P``8@0``"4&````````?0$``"8$```F
M!0``,`,``",'``#!!0``"`<``````````````````!@%```H`@``*@<``$@%
M````````\08``%D#``!5`0``HP$``!L%``"+`0``I04`````````````MP``
M````````````"P4```````!Q!@``N`,``+(%````````T@$``+\!````````
MC`8``-<%````````%````(,$``!*`@``(@8``%0&```M`0``.@8``.$%``!@
M!@``V`$```P%``"6!0``\`````````"3!0```````&X#``"9`0``D`(``(X$
M``````````````0"````````'P<```````"7`@```````$8$``#Y````=04`
M```````/`0``NP```&H!``"\!0``YP,``$$#``"\!@```````&(```#[````
MX0(``&<%```C!```40(``!L"`````````````!<'```!!@``6@(``%P"````
M````E`(```````!;!0``$P(``"H```"Z!```9`(``#D$``!]````#P0``*<"
M```Q`0``$P$`````````````K0````X#````````?P8````````_!@``(`4`
M`#T#``!`!0``*00``*@$``"H`0``3P$``,\&````````4P```(\!````````
M``````````"C!```J@0`````````````0@4```<!``!(`@```````!P```"?
M`@``S@4``!D"``!R`0`````````````O````5@$``!@$```I`P``7@(``"T"
M``"0!@``W`(``,X&``````````````\#````````H@8``%T&``!4`@``*@,`
M``````!V!0``9````-8"````````VP````X&````````;`$``&H$``"]!```
MU`$```````"I`0``>00``#@#``!8!```>@8``/P$``#I````U@8``$8"``#H
M````N00```````#T`@```0<``!8'````````+0`````````D`0``<@```"0`
M``"6````20$```````"=!0``B`(``$\```"(!@``LP,``/@```"Z`0``[P``
M`#,%```5`@``XP4```````!H`P``AP,``-`"``#`!0``;`(```@$```3!0``
M'08``/$"``#=`P``TP(``%L!```H`P``.`$``%X```!+!@``6P8```````"2
M`````````,8```!5!```Z@,``*@"```D`@```````/(!``!.!@```````!@&
M```K!```````````````````J0,``*,```#V!0```````!T$```]!@``"@8`
M`/X#```!!0``M0```.8%``#(!@``0P4``&,$``"$!0``ZP$``.X#``#:````
MB@,``#`&```$!@```````$<'````````#`<``/$$``"_!@``"@4``-H%```W
M!P``A@````````!D!@```````%4```#?`0``!`0`````````````Y0,``#P'
M````````W08```````!L!```N@(``'P&`````````````.<"````````````
M``````!)!0``Q`4``)\!````````>P4``"L%``!#`@``]0(``$$&``!:`P``
M``````````#5!```.`(``"\$``"2!````````'H"``#O`@``Z0,``!L!``#"
M`@``L``````````;!````````.P&````````.`<``/4$``"8!@``#````)L$
M````````J@,``,\"``#>````T@8``!<$``!7!0``(00````````7`P``````
M`'`$````````DP```)("````````V0,````````2`P``LP4``#$&``!=`@``
M+P<``'`"``"G`0``IP4```\&`````````````-@"``"L`P``_P```!L&``#G
M!```_P0``+T!````````@`$``%D&``!K`0``C@4``/H"``!;````5`,``/<#
M``!$````N0$``#L"``"D`P``<`$```````!E!0``&00``.@#````````]`4`
M`,$$```G!```^P$``*\"``#S!0``C@(``)T```!B`@``H0(``.P!```8!P``
M'@<``'(%``#M!```/@8```````!Y!@``70```+L!``!,!@``[P8``!,'````
M````Y@$```````!M!0``,00``&,#```"!@```````#0'```K`P``````````
M``"N`@````````````"^`@``T08``$L!``"+`````````$0$````````20,`
M`)D#``"B````-P8``-(#``"]`P``H@,```<```#;`0```````#(&```E!0``
M``````8`````````T@(``+D#``#;`P``%0```*@%```C`@``#0$```````!'
M!0```````&@$``",!```@`0`````````````"P<``$8````Z!P``+08``%`&
M````````.P4``-`&``#O!0``ZP```+L"```^!```:`4``$4!``!;!```1@8`
M`+0&``!U`P```````*@```#*`@``704````````7````Z@$``%8$``!I!0``
MV@(``(P"``!C```````````````,!@``O0(```````#5`@``^`0```````#L
M!0``-0```&T!````````<P,``,X!```B!```<`,``#H`````````O@``````
M``!S`0``U````$$!````````&@(``&<$``"B!0```@```$H&````````D@$`
M`.L$````````H````*4````+!@```````#\!``!W`P``7P4``,$"````````
M6@8``,H%``"(!0``/`(``!T%``"'!```5P````````";`0``R00``-X"````
M````:@,`````````````<0,``)D&``!A`@``;0(``"````#N!0```````#,'
M````````K0,``.4!```Y!P``-@,```@%``#$````4@(``+8#``#Q`0``S00`
M``````!0`0``-@<````````D!```V0$``,$#``#D`P``(0$``%`$``"3`P``
MU08``%@&``#I!@``S0,``"0'``````````````````!$!P``<0`````````Q
M`@``T@4``#X!``":!```.@4```4'````````U@,``+H&``!$!0``+@8``,P%
M``";!0```````*`#``!W!0```````%D"``!M!``````````````S`0``````
M`,$`````````9P,``((```!5`@``K@0``(,%``"C`P``G````"D%``#I`@``
MI0(``*0"``!-!P``*P$``,`$``"A!0````````````"=`@``#P<``$,'``!(
M````<@,``,@```!G`0``^`,``*8$```I!@```````/$#````````EP0`````
M```'!0``F`4```````#>!@```````$4&```.`0```````)X%``!``0``````
M``````";`P``$0(``#4%``")````!@$``"X#```"`@``1P```)0$```G`0``
M`````,,#``"P!@```````.H&``#8````L0$``"H!````````,@```&0$``"I
M!0``$`<``,H#``!>`P``````````````````H@$````````M`P``.`0``)$`
M`````````````,<!``"R`P``K0$``.T%````````4`(``$D"``"N!0``X`8`
M`(8!``!6`@`````````````C!0``HP8``*0!``!*!0``VP0``*`&``!4!```
MA@,``(<%``"?`P``SP0`````````````-P(``.H`````````G@(``,D%````
M````6@$`````````````RP8``*4&`````````````#\#```B!0``F@```(4&
M``!_`0````````````````````````````!'`0```````'P!``"8`@``````
M`"`$``#D`````````!8$```8`@``%@```!0"```7`@``A0$``-,$``#\`P``
M_@8`````````````[`(``````````````````&X````2`0```````-0#``";
M`@````,```````#?!0``\`4`````````````@0`````````\`0``2P```+<$
M``"&!```O@4``+4!``!<!0``;P(``!P!``#9!`````````8'``#Q!0``:P(`
M`+8!````````T0(```D&```^!P```````(\%````````2`$``+("``"-````
M`````.0$````````Z`(``&0#``#X`@```````*L"``"*`@```````/`$``![
M!@```````+X#`````````00``)T$``"E`0``AP$``-4%``#V`@``8@,``%``
M``"F````]@,``,L"``##`@``MP,``/0!``#<!0``RP,``&T&````````'@4`
M`"L'```N!`````````````!$!@``````````````````7P0``,0&``#@`@``
M`````.P`````````)P```$8'````````X0```"P'```@!@``0@<``$\%``!_
M!0``Q00``)4#````````10<``$P'``"L!0``_@(``*$#``#F`P``?@(``/D$
M``#7`0``5````+`"`````````````,4%```S!@``I````+X&``"J!@``=```
M``T&``!Y`@``"P(``&@"``##!@``408``/P```".`0``4P(``)<%```:!0``
MGP```",````T`@``>@4``#T!``"$!```.````-X!````````;P$``"X`````
M````^P8``%T#````````#`,``+L%``!I````70$`````````````)00``*$$
M``#7`@``NP,``/T$``"Q`@``#0,``/T"``#N`@``W@4````````-!```````
M`)D"````````"`$``%P$````````>0,``(P```````````````H'````````
M`````'P"``"'!@``:00``&X%``#"`0````````````#W`@``;@(``'("``"<
M!@``W`0``$`'````````"@(``$8!`````````````(\#````````````````
M```L````-0(``.L&``"I!```-P$``.$$``!I`@``4P,``)@$````````XP``
M`,$&```B`@``404``!$%``#H!@``$0<``+8```"8`P```````$$'``"T!```
M`````(H```"+!0``S@0``*8%````````808``!$```#$`P``^0(``(0"```F
M````L@``````````````7`,``#8!``##!0```````/4#`````````````.$#
M``":!@``0P0```````!T`P``=`8``#8"````````@`,``%L"````````%0,`
M``````#0`````````!`&``"G````)P(```,&``"Z!0```0$``-$%``">!@``
M"0(``-L&```S!``````````&``"S`0``<P8``&$$````````+@4````````Z
M`P``0P,``&<"``!/!```#@(``.,"``#N!```SP,``"4"```[`0``````````
M``#2`````````-T!``!^!@``W`8``+$````?`@``JP8``,4"``#I!```X@4`
M`!<!``"G!```$@```/4```!>!`````````````"Z`````````'L$````````
M;@8``+\```#U!0``!0$``$H#``"L`````````#T````F!P``QP4``,8$``"(
M````<P0``"\!``#4!0```````)T&`````````````.,#```"`P``$0,`````
M``"Z`P``)P<``+8$````````OP0``"@$``"(`0``=P(```````!+!P``0`,`
M`(8&``!=!```#@<``.T````T`````P,``)H"``#&`0``?P,```````!+!0``
MV@$``'T"``#Z````````````````````)@(``'0%``"!`@``]@0``!P'``#R
M````'P0``'@#``"E!````````#P#``")`P``@0$```````"L`@``[@8``+4%
M```Z`0``K@$```````#_`0```````&`$```````````````````B!P``L@0`
M`#\$``"%````200``)4$``"1!0``_04``(`&``#+!```MP8``+(!``!E`0``
M3@4````````-`@``C08``-0$``!6!0``%`8``'T&``"J!0``G@0``#L'```Z
M!```F`$``&L%```%`P``@P$``&(!```Y`@``MP$``!$&``!V!@``````````
M````````#P(``(0```#7!@``````````````````#@```$<&``"*!0``1`$`
M``````#X`0``[0(``"4'``#'`@``"P$``#D!``"+`P``^04``)8#``!I`P``
MD0$```````"4`P``F00```````"/!@```````'@$```"!```*@0```````!Y
M`0``X0$```````!]!0``S0(``'L"````````.P```.8"```Y``````````P!
M```3!```B0(`````````````;0`````````8`P``N0(``,`!````````````
M``````"\`@``L0,``/,$````````/00``!T!````````!`$``-8!````````
MS0$``-`#````````-`8``)(%``"\!```P@,``'X`````````UP,``%(!```)
M`0``!@0``%<!``!G````K`0```````!U`@``=@$``'`%``#[!0``+`4``,4`
M```M!P``2P(``(````````````````````#5`P``4P0``-`!``!/!@``&@8`
M``0%``"\`P``[08``"4!```````````````````I`@``5@8``#('```=`P``
MQ@,```4$``#``@``!P(``"$%``!8`P``ZP4``-\"```>`0``]P````````"^
M!```X`0``$@#```R`P``3P(`````````````?@0```````!@`0```````-@#
M```S`@````````````"6!@```````,P&````````E@0```````"4!0``````
M`),&````````WP```&@&``!^!0``30```!D%````````XP8``+P````:````
M;`,``,D!````````=@(``"4```!U`````````"X!``#=!0``"@$````````;
M````*P(``)X!``!8````&@<``$T#``#3````.@(```````!&!0````$`````
M``!\`P``]@8````````Y!0``E0````````"R!@``_P4```````##`0``RP4`
M`+,$`````````````)4"```6`0```````!8"``!F!@```````%H%``"J````
M"`8``,X`````````.08```````#3`P``<@8`````````````*P8``+,```""
M`0``=P0``-L%````````]`,``+\"````("@E<R!D87ES(&%G;RD`("A!8V-E
M<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`
M("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E
M<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R
M(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR
M9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT
M:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@
M+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE
M;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H
M:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@
M8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F
M('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R
M;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T
M($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H
M="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO
M4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT
M($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R
M;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@
M;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R
M97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T
M86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL
M`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y
M(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!0
M87-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA
M:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT
M.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC
M80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N
M($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H
M87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7
M:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!
M<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N
M9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`
M07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@
M<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E
M;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO
M;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E
M<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L
M=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L
M87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T
M:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD
M+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K
M;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA
M(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@
M27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`
M0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K
M:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#
M86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I
M;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`
M0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B
M+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO
M;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0
M:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E
M<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U
M.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L
M($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E
M<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA
M;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@
M861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E
M<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES
M(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N
M+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI
M;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I
M`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO
M;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I
M8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@
M=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#
M;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U
M9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD
M<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA
M`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O
M;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM
M96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N
M9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#
M;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N
M97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL
M960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F
M("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O<'D`0V]P>2!F86EL960Z
M("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%-E
M<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S
M97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E
M;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M
M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,
M;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$
M95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A
M<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT
M:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#
M96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N
M`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E
M(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P
M9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C
M<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO
M;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C
M=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$
M:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!
M1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J
M:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC
M80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3
M:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES
M=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T
M:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R
M8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T
M;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R
M90!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T
M:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`
M17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=R
M:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N
M9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U
M<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD
M`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!I<F%T:6]N($1A=&4`
M17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@
M(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&
M86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S
M`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N
M9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME
M`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I
M96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GDZ`$=A;6)I
M80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E
M;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!'
M;V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E
M96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U
M<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A
M9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@
M5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER
M96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N
M9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R
M871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS
M:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E
M92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N
M=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M
M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@
M9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I
M80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N
M`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L
M=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E
M8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O
M<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!)
M;G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@
M<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@
M8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D
M:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E
M<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A
M;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV
M86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`
M26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`
M26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D
M=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT
M.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D
M9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T
M('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E
M;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S
M=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE
M<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T
M:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R
M;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@
M3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B
M;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y
M;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`
M3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F
M<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE
M8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI
M8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI
M9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT
M(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@
M5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K
M`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI
M<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M
M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R
M:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z
M("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO
M9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@
M9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N
M(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC
M`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I
M80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA
M<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T
M8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D
M(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA
M>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C
M96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF
M:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S
M(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE
M;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@
M;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T
M90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!2
M97!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S
M=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W
M;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU
M;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M
M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@
M22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE
M<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),
M`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC
M>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W
M;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S
M86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE
M=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD
M;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS
M`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`
M3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E
M<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@
M25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@
M<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I
M8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P
M<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I
M960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.
M;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L
M:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R
M=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R
M=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@
M:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T
M86P`3V-T;V)E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO
M="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA
M<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`
M3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H
M86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA
M<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@
M;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M
M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A
M=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I
M;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D
M($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S
M`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!0
M3U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`
M4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO
M=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!0
M87-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S
M.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!0
M97)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES
M<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I
M;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T
M>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O
M;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H
M;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V
M:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF
M;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B
M;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A
M<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@
M=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G
M97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI
M<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`
M4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`
M4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E
M<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S
M<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`
M4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D
M`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A
M;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q
M.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O
M=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@
M365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE
M;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN
M="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E
M;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@
M4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`
M4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE
M;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T
M(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W
M;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE
M8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@
M;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C
M:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R
M;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E
M<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`
M4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@
M=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V
M97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T
M=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L
M;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E
M;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`
M4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@
M4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E
M<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VEE<G)A
M($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V
M96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E
M<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-O;&]M
M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S
M96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E
M<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`
M4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F
M;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES
M=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3
M=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET
M`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN
M(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E
M;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U
M;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F
M<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U
M<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L
M;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3
M=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E
M+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T
M`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA
M>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L
M971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I
M86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M
M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R
M;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V
M:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@
M9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M
M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T
M92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X
M=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV
M,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI
M=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT
M('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N
M=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T
M<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I
M;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@
M9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C
M;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&ED96YT
M:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E
M(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@
M9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S
M86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@
M=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N
M;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@
M=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L
M;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N
M(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B
M)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE
M87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T
M96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@
M=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN
M('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T
M(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@
M;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L
M9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N
M=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@
M97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N
M('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@
M1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L
M:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I
M;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M
M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@
M2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4
M;W`@9G)A;64@*%]T;W`I`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F
M86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4
M=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4
M>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DPZ`%5G86YD
M80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@
M(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T
M92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E
M=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A
M9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD
M97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N
M86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE
M`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC
M;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D
M;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R
M;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`
M56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U
M="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P
M<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R
M`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D
M`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@
M<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E
M<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M
M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R
M`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN
M:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E
M<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S
M(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!6
M86QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@
M0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I
M8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6
M:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6
M:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!7
M90!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!7
M96%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M
M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T
M97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A
M=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T
M:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA
M<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7
M:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD
M.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO
M;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"X`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8
M-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T
M($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H
M;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E
M(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H
M(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P
M<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL
M($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N
M`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D
M9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN
M:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@
M8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M
M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R
M(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U
M<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`
M675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6TAI9&4@475O=&5D
M(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'
M<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G
M(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]2
M96UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S
M97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L
M:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E;G1R>2!N
M;W0@9F]U;F0`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I
M;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I
M;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN
M97-=`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT
M960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I
M;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`
M<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU
M<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`V+3`Q+3`U(#$U.C`T*S`X,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,2TQ,BTR,"`Q,CHP,"LP.#`P"DQA<W0M5')A;G-L871O<CH@1&%V:60@0VAA
M;F<@/&1A=FED0'1M=BYG;W8N='<^"DQA;F=U86=E+51E86TZ(%1R861I=&EO
M;F%L($-H:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0DE'
M-0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`("@E<R"DT:ME
M*0`@**?6L;;!Y"`E<RD`("@E<R"DT:2Z*0`@**2UI-$I`"`HJ?JDT2D`("BL
M4:31*0"I\P`B)7,B(*2CK$^D0*W3I=B__0`B)7,B(*2CK$^D0*W3IK.NQ*JZ
MO^^^W"X`(B5S(B"I?*6\IF(@2$]21$4@JKJU^:55P,DH4F5G:7-T<GDII*2S
M7:EW+@"GY*2CJ.P@(B5S(B!T<F5E(')E;F1E<F5R+@`B)7,BI'>FJ*5<JKJE
M6Z1*J.RX<[+5J'2RSJ2D+@`B)7,BI'>E6Z1*Q7:MK:ATLLXN`"(E<R*HPZ6\
MJ]BEWSH@)7,N`*1WJ,^ESB`E+C)F34(@+*YEMG$@)2XR9DU"("RST;YL("@E
M+C)F)24I`"5D("5S(*5(I,X@)7,`L\RJ\:1`IKBQ2[U8Q=RG\ZGS("5D(*31
MJV4N`+/,JO$@)60@I-&N\+9(N7>S^``E<R`M(+/&I]&__0`E<R"K_*^^`"5S
M($M"`"5S(+K[Q4"^WJ=`("T@O52[>P`E<R"S7:EW`"5S(+7YI54`)7,@IE"W
M3K:UI=@`)7,@I'>F<Z9B`"5S(*9B("5S("5S`"5S(*1WM$ZD5:9#J,:VM:JZ
MNOO%0+[>IT"T3KK\+B"]T*GSIKFNR:3$O^^G0;=1K6Z^WJ=`JKJVM:78+@"E
MLKO=K6X@)7,`)7,@I,``I^2DHZCL("5S+@`@)7,@J.P@)7,@ID`@)7,`)7.J
MNK-QL%2__0`E<ZJZIN:HQK[D`"5SJKJSQJ?1O_T`)7.JNJO=O^S#KP`E<SH@
M)7,`)7,Z(+-OJ\JK2*7SI*.D0*EWKW6ET:M(I*2JNK%(I?.D2*G2L4BU;RX@
MO="J8+=.I%6F0ZG2IK.JNKKTN/2S<[6RIK.E::_@K*JZ?*=!JKJMTZ1(N.JN
MQBX`+""P?:VW(``L(+!]K;<@)7,@)7,`+,7<I,:V<;%Q("5S(*CL("5S`"TM
M(+_OOMP@+2T`,3(@I'"NR:CN`#(T(*1PKLFH[@`R-""D<*[)J.X`I%>D0*VV
M`*:YL,^V]*6RMK>M;JO\J7>XZJ[&KG>F^*I!NMTN`+5OI<VD1J1`K=/$6:VK
MJKJ_^;M^`+']I5NQ2[9LI?,LP=F[W:UNIK.D0*W3(%!'4""DO;9]JO?&7RX`
ML?W%Y\/2I'?#L;.YJKJV;*7S+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N
M`+']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'
M4""J]\9?+*5(I,ZS<</VI&:E3RX`L?VP]:;FMFRE\\.QL[DLP=F[W:UNIK.D
M0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'4""J]\9?+*5(I,ZS<</VI&:E3RX`
ML?VXT;%+MFRE\RS!V;O=K6ZFLZ1`K=.DO;9](%--24U%(*KWQE\LJ'"Q2R!3
M34E-12"J]\9?+*5(I,ZS<</VI&:E3RX`L?VP]:;FMFRE\\.QL[DLP=F[W:UN
MIK.D0*W3I+VV?2!3+TU)344@JO?&7RRH<+%+(%,O34E-12"J]\9?+*5(I,ZS
M<</VI&:E3RX`L?VE6[%+MFRE\RS!V;O=K6ZFLZ1`K=,@4TU)344@I+VV?:KW
MQE\N`*3(JV6FL[:S`*3(JV6D<*M"`*3(JV6FLZM"`*3(JV6P?:M"`*3(JV6P
M?;.W`*3(JV4OI,BKX0!!4$D@O7.XN0##]JGSLV^MT[USO^B^N0##]JGS+BXN
M`*6_I%6DZ`"EOZ2DI:$`Q7:MK:2CJ*PLM4RJ:ZO8I=\@5D93(*78O_TN`,5V
MK:VDHZBL++5,JFNKV*7?(%9&4R#`R:[7+@"Q8KBYN.JP5`"Q8KBYNU"Q2[U8
M`+%BN+FD=ZWAM;(N`+6RL6(`MW.\5P"W<[Q7IKBX<[+5`+=SO%>D;,5VK:T`
MIF*FN;=SO%<Z`+=SO%>X<[+5`+=SO%?%=JVM`+=SO%>FN+ASLM6H["`B)7,B
M`+=SO%>FN,5VK:VFW"(E<R(`MW.\5Z1`K=.HSZ7.JLPZ`+=SO%?$YJ;L`+=S
MO%>D0*W3IJBM^SH`MW.\5[GO`+=SO%<@)7,@K+`@36]Z:6QL82"JNJ3`K;8`
MMW.\5ZCLJKJS<;!4O_TZ`+=SO%>H[*?:JKJS<;!4O_T`MW.\5ZC/I<ZJS`"D
M=[=SO%<@(B5S(B"H[*ATLLZDI"X@IOVU3*IKMW.\5\-"I7ZJNK7YI56XZK!4
M.B`E<RX`I'>W<[Q7("(E<R(@J.RH=++.I*0N(*=!LGNF8J5II4BV::;FM6ZD
M2J1&+@"W<[Q7J,^ESJK,JKJE7*_@I=BK9;-1P_:SK"X`IF&G?0"S<;!4O_T`
MIJBLL+K>LGJM^R`M(*RPJ.2E3*C/I<ZJS+-=J7?%=JVM`+K>LGH`O'.G:0!!
M9F=H86YI<W1A;B`HJORT2::]*0!!;&)A;FEA("BJ_+JXI-JEIZC(*0!!;&=E
M<FEA("BJ_+JXI,ZG4:C(*0"V;*7SIT^F5P"Y[[OT`+GON_2DZ*:A.@"ITJ:S
M`*G2IK.D=\7GP]*JNJC/I<ZJS`"ITJ:SN'.RU0"ITJ:SQ7:MK0"E?J[8O74`
MI+FS7*9NM%BMT[EQI&RV;*7SIF&G?0"DN;-<Q=RG\[:UI=B]<[BYJKJKK+I!
M/P"D=Z9SIF(`Q=RG\R!)35-0(+5NI$H`Q=RG\R!)35-0(+%+O5@`Q=RG\R!)
M35-0(*C/I<ZJS`#%W*?SN7&D;+9LI?.F[:=]`,7<I_.\RZI/`+3`I4ZDY:9R
M`$%M97)I8V%N(%-A;6]A("BL_,12L.W"Q+ROJ,@I`*1`K=.U3*[$JKJMR+-1
MJ,^ESBX`M6^ES:1&I$"MTZ6\JKZJNK_YNWXN`$%N9&]R<F$@**9WN42FU2D`
M06YG;VQA("BF=ZWTJ=0I`$%N9W5I;&QA("BF=Z9CJ=2N<2D`L,ZF5Z5.LGJF
M<ZCZ`+6JKM<`06YT87)C=&EC82`HJVZWI:1JL[`I`$%N=&EG=6$@86YD($)A
M<F)U9&$@**9WM*.ERJYQI,ZDVKJXI:RY1JYQ*0#`LZ7.M7NFH0#`LZ7.M7NF
MH;)-L^8`P+.ESK5[IJ&D=[1.NOP`KDVESJCLJ=*FLZJZIKBF0*C)`*?EK>,`
MN7>F]*1JI'``I7RDZP"J_*G4IT*DY2`H5VEN9&]W<RTQ,C4V*0#`H\%9P,FD
M:J1P`,"CP5G`R:97NMD`IT&]5*EWK6ZG4K"C("5S(*JZM?FE5;;<(#\`IT&]
M5*EWK6ZG4K"C("(E<R(@I4BDSJ7TIO.JNJ:XN'.RU2`_`$%R9V5N=&EN82`H
MJORNVJ?**0!!<FUE;FEA("BHR*S\I:>HR"D`J,BL_*6GJ,BDY2`H05)-4T-)
M22TX*0##P+-.`$%R=6)A("BJ_+Y\I-JN<2D`07-C96YS:6]N($ES;&%N9`"D
MY:9RP\"S3@"HR*QW+Z33I:VL=J9AL,\`L/6FYK[>IT"Z^\5`JV7%XZ7<O52[
M>[GON-P_`*3`L'3$YJ;L`,!\N-6G4K"CI$"MTZ2CIG.F8JJZN'.RU2X`P'RX
MU:=2L*.D0*W3I*.F<Z9BJKK%=JVM+@#`?+C5O7._Z*1`K=.DHZ9SIF*JNKAS
MLM4N`,!\N-6]<[_HI$"MTZ2CIG.F8JJZID"HR2X`Q-VIR@"D2Z3K`$%U<W1R
M86QI82`HOT2D:J=1J,@I`$%U<W1R:6$@*+;XIF&G42D`075T:%]C<GES<6PZ
M(*?DI*.H[*G2N]VM;JJZ(&EM87`@J;6F^:Y-I?,N`$%U=&A?8WER=7,Z(*;X
MJD&ZW:C#I;RTHZC1N-.VM:3DM*DN`$%U=&A?8W)Y=7,Z(*?DI*.H[*G2N]VM
M;JJZ(&EM87`@J;6F^:Y-I?,N`$%U=&A?9G1P.B"GY*2CJ.RITKO=K6ZJNB!&
M5%`@J;6F^:Y-I?,NO="MJ[=SO7/$MB!02%`@J,.E0J5;I$H@+2UE;F%B;&4M
M9G1P(+_OMK4LJ-*F<"!C;VYF:6=U<F4@+2UE;F%B;&4M9G1P`$%U=&A?:6UA
M<#H@I^2DHZCLJ=*[W:UNJKH@24U!4""IM:;YKDVE\RX`075T:%]K<F(U.B"G
MY*2CJ.RITKO=K6ZJNB!K<F(U(*FUIOFN3:7S+@!!=71H7VQD87`Z(+=SO%>H
MSZ7.JLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ0;#(`$%U=&A?;&1A<#H@
MIU*PHZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@`075T:%]L
M9&%P.B"GY*2CJ.RITKO=K6ZJNB!,1$%0(*FUIOFN3:7S+@!!=71H7VQD87`Z
M(+5,JFNW<[Q7J,^ESJK,("5S+B"F^*I!OKFF7L"S.@!!=71H7VQD87`Z(+5,
MJFNROK"CJ,^ESJK,("5S`$%U=&A?;&1A<#H@M4RJ:Z?SMW.HSZ7.JLP@)7,`
M075T:%]L9&%P.B"G\[=SJ,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]
MJD&PR`!!=71H7VUC86PZ(*?DI*.H[*G2N]VM;JJZ($U#04P@J;6F^:Y-I?,N
M`$%U=&A?<VUB875T:#H@I^2DHZCLJ=*[W:UNJKH@<VUB875T:""IM:;YKDVE
M\RX`24U!4""F^*I!OKG%Y\/2O_F[?BX`Q>?#TJ6BL=$N`,7GP]*EHK'1+B`E
M<P!2041)55,@Q>?#TK_YNWXN`$944"#%Y\/2O_F[?BX`4TU"(,7GP]*_^;M^
M+@"E::7.JKK$YJ;L.@!!>F5R8F%I:F%N("BHR+;KJ_2U32D`K4FTN@"M2;2Z
MPT.FX@!K97)B97)O<R"Q2[U8O_F[?BX`:V5R8F5R;W,@J,^ESJK,IE>ZV;_Y
MNWXN`$)A:&%M87,@**3:JZ*PJ"D`0F%H<F%I;B`HI-JJ3"D`JFG#N:JZKORD
MY2`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@@**ESI5NIU"D`0F%R8F%D;W,@
M**3:J*FF:"D`I^2DHZCLN<^EW*78O_T@(B5S(BX`L/*]=0!"96QA<G5S`$)E
M;&=I=6T@**3QIU&NR2D`0F5L:7IE("BHJ:B]M+4I`$)E;FEN("BHJ;GG*0!"
M97)M=61A("BFRKQ]N48I`$)H=71A;B`HI*.DIBD`I<VDZ0"GY*2CJ.S`LZ7.
MM7NFH2(E,B1S(JJZL,^V]"(E,21S(BX`L,^V]+-=J7<`L,^V]*NLND$`LLK%
MZ0!";VQI=FEA("BLP:=1NONHR"D`KM'%T@"NV+UU`*[8O76D:J1P`*[8O74`
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82`HJFFD:*6GJ,BDSK;"P<FM]+K[J+HI
M`*7^LZ$`0F]T<W=A;F$@**III;ZHNBD`J;.SH0!";W5V970@27-L86YD`$)R
M87II;"`HI-JFZ"D`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R
M=6YE:2!$87)U<W-A;&%M("BH6K7<*0!"=6QG87)I82`HJT^E6Z=1J,@I`+:U
MI=BRQ;BY`$)U<FMI;F$@1F%S;R`HI:RT6*_'JFNOP2D`0G5R=6YD:2`HNUJV
MJ:9A*0"JJ:VQNMZR>@!#4D,`0U),(*3`LZ'"20#`>*9SKN:DNJYE+BXN7V4`
MI]:H^JKLJ6RDQJE\I;RGN::H+@"FYJC&ON0`N7.OQ:VW`$-A;6)O9&EA("BL
M6JY(N>LI`$-A;65R;V]N("BSV+/!MJDI`+5,JFNFV[#*K:NX;;%+O5@LO=#!
M<+6XIT&JNJATLLZZWK)ZK?LN`+5,JFN\9Z1*P,FNUR`B)7,B`+5,JFNS<[UU
MIMP@24U!4""F^*I!OKDZ("5S`+5,JFNV?;'2P,FNUR`B)7,B+@!#86YA9&$@
M**5;KK.D:BD`J/JN^`"H^J[XL-W#1*9>L_@`M4RJ:Z=2L*/`R:[7("(E<R(N
M`*?DI*.H[+S(IG.EV+_]+@"ORJ36("=T87)G971&:6QE)R"PT;S&M4RJ:\1^
MQ/*S0K)Z+@"U3*IKLKZPHZ78O_T@(B5S(BX`M4RJ:[*^L*,[("5D(*W3I&RV
ML*1WIG.F8BX`M4RJ:ZVKLM6A0ZG2M*.HT:JZL$^__;S&I=B[4*7]JV6ITL!X
MIG.JNKCJKL:DH[+%+@"U3*IKML>P9<*RL%2H[*O\J7>JNKBYO5@N`$-A<&4@
M5F5R9&4@*+K[O'>HI"D`NZ&I^J3EIG(`I,##_KM0O-#%T@!#87EM86X@27-L
M86YD<R`HMGVPTKASKG$I`*;FL,JY<;C<`,!XIG.NYJ2ZKF4`P'BF<Z[FN=2E
M4CH`P'BF<Z[FI+JN90#`>*9SKN:VH;9:.@"FYK#*N7&XW`"VZ[JXKU.DY2`H
M25-/+3@X-3DM,30I`+AMI*0`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC("BD
MI*M$ID"I3;#J*0"DI+S:("A)4T\M.#@U.2TR,`"^S,/2LM.X8`"^S,/2OM:F
MLZK,`+[,P]*L1K6F`$-H860@**QDO'<I`*?SI^\`I_.G[Z=!JKJQ2[U8`*?S
MI^^G0:JZJKJE_J97I4BDSJ9>MFRF8:=]+@"EV*MEJKJS7:EWJ,.EO*3DM*FQ
M2[U8Q=RG\RX@O=#!<+6XIT&JNKK>LGJM^RX`IG*DN`#`RZQDLW.ULBXN+E]K
M`$-H:6QE("BTO*=1*0!#:&EN82`HI*2PZBD`PK+%Z:2DI.4@*$=",C,Q,BD`
MI;_%Z:2DI.4@*$)I9S4I`+_OOMS`LZ7.M7NFH3H`O^^^W+%+O5@`O^^^W*1`
MK=.HSZ7.JLRF5[K9`*3IM,'%XZ7<I.BFH3H`O^^^W+:UI=BKK+I!JKJMMZ[F
M`$-H<FES=&UA<R!)<VQA;F0@*+ATO<^N<2D`I^2DHZCL("5S(*JZP_ZG3ZEW
MN'$N`+2X`+)-L*.W3+-N($]F9FEC92"\T,72`+)-L*.L9+C?`+)-L*.HSZ7.
MJLPZ("5S`+)-L*.HSZ7.JLP`LDVPHZC/I<ZJS*JZN.JNQ@"QW\+@M+@`J_:W
MQKFKP>2E2,1^Q/(`0VQI8VMA=&5L;""S>KE,($A45%``P_:SK+7XM:$`MK.V
M<0"FK:9HMK,`L[$`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`I^G%?+CJKL:G
MJ`"GZ<5\P^2LR0!#;VQO;6)I82`HK?2MVZ3QJ,@I`,-#IN(`O=6FXKU,`#$V
MMFFF[,-#IN*E3KU8`,3F.@#$YJ;LO-##1`"E9+-Q`*E2I4\`I^6FN*E2I4\`
MM?N]UP"ZV:E)`$-O;6]R;W,@**SLO*_#N2D`I+VE<0"Y<;BC`,#TN=(`L?BE
M\P"N=+*G`+M0(%!$02"T>*17JZRY<;BC++2\O'JKK*3BOO>E2*3.($]U=&QO
M;VL@JKJF4*A"LUVI=RX`LUVI=[CJKL:Y3+3!+@"S7:EW("5S`+U4NWNQ2[U8
M`$-O;F=O("BMZ*I'*0!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE("BMZ*I'ID"I3;#J*0"S<[6RI:*QT2X`LW.ULJ6BL=$Z(`"S<[6R
MIMRDO;9]JO?&7Z;XJD&^N:[)OD2IVBX`LW.ULJ;<I+VV?:KWQE^F^*I!OKFN
MR;Y$J=HN(*WLIETZ("5S("@E<RD`LW.ULJ;<($944"#`R:[7IOBJ0;ZYI:*Q
MT2X`LW.UN*1(`+!/O_VD=Z:HI5RF8;=SO%>FW*=!JKJS<;!4O_VDI"X`P*/!
M6<#)KM>JNJ2ZKF6KK+I!.B``(B5S(B#`R:[7I+JN90#$?L3R`$-O;VL@27-L
M86YD<R`HK.RG2KASKG$I`+W&NW,`O<:[<Z6BL=$Z("5S`+W&NW,`0V]S=&$@
M4FEC82`HK?2TM:1JOJ2E6RD`0V]T92!D)TEV;VER92`HMDBD^J[\J:0I`+5,
MJFNE2"!01U`@I5NQ2[9LI?,Z(`"U3*IKI4@@4$=0(+#UIN:V;*7SP[&SN3H@
M`+5,JFNE2"!3+TU)344@I5NQ2[9LI?,N`+5,JFNLL"!3+TU)344@MFRE\\.Q
ML[DN`+5,JFNW<[Q7LW.UN*1(+B`E<P"U3*IKP[2ULB!,1$%0(*;XJD&^N0"U
M3*IKP[2ULB!L9&%P(*;XJD&^N0"U3*IKP,NL9+=LKW$N("5S`+5,JFNS<[6R
MIMP@;&1A<""F^*I!OKD`M4RJ:[-SM;*FW*;XJD&^N2`B)7,B(*C/I<X@1E10
M.B`E<P"U3*IKJ]BEW[!TN&VX<[+5+B`E<P"U3*IKN-&Q2R!01U`@N.JNQCH@
M`+5,JFNXT;%+(%,O34E-12"XZJ[&+@"U3*IKIU*PH[-SM;BD2"X@)7,`M4RJ
M:Z=2L*.P=+AMLDVSYBX@)7,`M4RJ:Z=2L*.G\[=SM7NFH2`B)7,B+@"U3*IK
MJ$VI=Z:LI?.D2*JZN7&D;+9LI?.F[*=]+@"U3*IKP/*H^J>YON.JNK-QL%2_
M_2X`M4RJ:\#RJ/JGN;[CJKJP=+AMLDVSYBX`M4RJ:\#RJ/JP=+AMLDVSYJ2D
MJKJX<[+5+@"U3*IKN/RD2K6FLJ0@(B5S(BX`M4RJ:ZO8I=^EV+_]("(E<R(N
M`+5,JFNFVZKWQE^F^*I!OKFH^K%OI+VV?:KWQE\N`+5,JFNV?;'2("(E<R(@
MI4B\9Z1*+@"U3*IKMGVQTB`E<RX`M4RJ:[9]L=*Z^\5`I'6G0+S2LM4@)7,`
MM4RJ:[9]L=*EV+_]("(E<R(N`+5,JFNS<[&U($Q$05`@(*;XJD&^N2X`M4RJ
M:\6JJ/H@)7,N`+5,JFNMJ[=SLUVI=ZC/I<ZJS*JZL4N]6"X@LZ&DP*JZLM.X
M8*2CI;^]5"X@O=#!<+6XIT&JNJATLLZZWK)ZK?NE2*CSIU6S0K)Z+@"U3*IK
MQ:JH^J9SJ/JQL:CNJNTH06-C97-S($-O;G1R;VP@3&ES="D`M4RJ:\6JJ/JS
M<;!4O_TN("5S`+5,JFO%JJCZL'2X;;)-I54N("5S`+5,JFO%JJCZL'2X;;)-
MI54N("5S`+5,JFO%JJCZIOBJ0;ZYJKJLV\/VKU.IR@"U3*IKIEZT7[-=J7<N
M`+5,JFNG4K"CI=B__2`B)7,B+@"U3*IKP'BF<R`E<R"JNK-=J7<N`+5,JFO`
M>*9SL\:E][-=J7<N`+5,JFO`>*9SL\:E][-=J7<Z("5S+@"U3*IKP'BF<Z?S
MMW.U>Z:AJ.PZ("(E<R(N`+5,JFO`>*9SL\:E][-=J7<@)7,N`+5,JFO`>*9S
MLUVI=\#))7,N(*=!I6FE2*C/I<XE<Z2DJKJHY*5,I5ROX,!XIG.S7:EWJ<ZD
MXK#*O<:[<Z15K;&U>Z:AO5BH["`E<RX`M4RJ:[=JM$T@3$1!4"`@IOBJ0;ZY
M+@"U3*IKIU*PHR`B)7,B+@"U3*IKI_.W<[-SM;BD2"X@)7,`M4RJ:Z?SMW.P
M=+AMLDVE52X@)7,`M4RJ:\+0O&<@(B5S(CH@)7,@JKJS7:EW+@"GY*2CJ.P@
M36]Z:6QL82"JNJ3`K;8N(+W0O52[>Z3`K;:L3Z=?MGVQTBX`M4RJ:[WAI*FH
MSZ7.JLP@(B5S(B"D5:9#Q7:MK:CLJTBE\Z=8("(E<R(Z("5S`*?>LTZE>0"P
MZJYA`+W2JNT`J]BEWP"KV*7?I$"MT[-SM;(`J]BEWZ1`K=.W<ZJZ`*O8I=^F
MN*M(I?.G6`"KV*7?JLRJNL5VK:T`JTBESJ5DN+F]6`!#<F]A=&EA("BG2L.Y
MINBHR"D`0W5B82`HI6JDVBD`I=BK9;=\M,$`I=BK9:[)MJ$`I=BK9;KTIWT`
MI=BK9:JZJ,^ESJK,`*78JV6DT:[P`*78JV6JNJJLJG`Z(`"EV*MEJKJMMZ[F
M`*;;K7&D0*C'M6ZD2B5SJ^&ITJUNL/6FYJJZI'6G0"X`L,6D50"PQ:15`$-Y
M<')U<R`HP<FTMK#'M+4I`*;HJ+VZN*3E("A+3TDX+5(I`*;HJ+VZN*3E("A7
M:6YD;W=S+3$R-3$I`*;HJ+VZN*3E+Z]1ITK$]:3E("A+3TDX+54I`$-Z96-H
M(%)E<'5B;&EC("BQMJ=*ID"I3;#J*0"DZ0"XZJ[&J-.WO:97NMD@*+W0L-&F
MTB!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I`*A#I.D`OO"JK+CJKL;"<\3]`+CJKL:N
M=[=JM$T`I.FTP0"FK*CLI.FTP0"_[[[<I.FTP0"EU:31`*=2L*/$YJ;L7VP`
MI%&D1Z3K`*11MFFF[+S&IG(`M.ZDUL%9L<8`N7>S70"Y=[-=PT.FX@"Y=[-=
MJKJHK:7WP]&G3P"Y=[-=J5*E3[C1JE*^N2A3:&5L;"D`J7>X<0"G4K"C`*=2
ML*/`>*9SKN8`IU*PH[ASLM4`IU*PHZSVO_T`IU*PH\5VK:T`IU*PHZ%"LDVJ
MQ;9LI?,`IU*PH\!XIG.NY@"G4K"CQ.:F[`"G4K"CLGNF<ZJZM,"E3KS+JD\`
MIU*PHR(E<R*JNL5VK:T`O52I=ZUNIU*PHR(E<R*JNL5VK:VE2*3.IKC%=JVM
M(#\`IU*PHZ9#`*=2L*.ITK_OOMRJNJBMI??#T:=/N.JNQ@"G4K"CI=BK9:JZ
MQ.:F[`"G4K"CI=BK9:JZID,`I_.W<[5[IJ$@(B5S(B"D=Z=2L*,N`+N\L&6N
MR;:A`$1E;FUA<FL@**2FL\$I`+#=PT2T>:UZ`+1YK7H`LM.X8"`HO="PT:;2
M($AO<F1E(+!/O_W`R:[7*3H`LM.X8+W0L-&FTJATLLZZWK)ZM6Z__2X`K..U
M;P#%4\))M\6KUP"SS*OAI$"D<*[)JKK%4\))M\6KUSH@`,53PDFWQ:O7.B``
ML7&EJJ;<I6L`L7&E:Z;<I:H`I=B__0"E2"`R-""D<*[)J.[%XZ7</P#%XZ7<
MO^^VM0#%XZ7<N-2RTZJZN7>S^`#%XZ7<N7>S^"`H5$%&*0#%XZ7<KN:FH0"V
MQ[!EIEZQ^`!$:FEB;W5T:2`HIDZEK*9A*0"DHZ=2L*,`I*.M;JJ]L;6F<ZCZ
M(&UA:6YT96YA;F-E+G!H<`"RQ*1`M:>P3[_]K$^G7Z5=IW3$YJ;LIE>ZV3\@
MIG"J1ZQ/O="DQ+_O+@!$;VUI;FEC82`HIFBI^J6GI5LI`$1O;6EN:6-A;B!2
M97!U8FQI8R`HIFBI^J6GI5NF0*E-L.HI`,'9J%.FL[%BN+FVW#\@M?FE52X`
MI%6X_`"D5;C\("5S`*15N/RS7:EWP,FNUZ5TIG.LL"!02%`@M7NFH2X`I%6I
MU*5<K^"J[0##Q*M^`+EQI&RV;*7S`+_YNWX`16-U861O<B`HI,RERJ9HNK@I
M`+USO^@`O7._Z+#/MO0`O7._Z+ASLM4`O7._Z,5VK:T`O7._Z,5VK:T`O7._
MZ"5SJKK%=JVM`+USO^B_[[:U`+USO^@B)7,BJKK%=JVM`+USO^@E<ZJZQ7:M
MK0"QT*A\`$5G>7!T("BN2J3.*0!%;"!386QV861O<B`HPL2ZN*7+IF@I`*2X
MI?,N+BX`N7&D;+9LI?,`N7&D;+9LI?.F[:=]`+EQI&RV;*7SINVG?:6RMK>G
M:Z98+@"Y<:1LMFRE\[U4NWL`16UA:6PM=&\M4TU3(+EHN42^N0"J[;&ALL6X
MN0"JQ:75JTBE\RX`JL6EU;6RJD<N`*K%I=6W:K1-MK6EV`"DN;-<IMO#P+19
MM*&D2K?3I/FH[*M(I?.DI"BZ]*VVO7.\9[S2IJ$I(#\`L=*PRK?&N:NE:\'D
MI5ROX*KM/P"ULJ?TIGZE]P"I\:1JO7._Z+ZY`*9PJD>G0;O=K6ZMJ[-=L4N]
M6"R]T+_II$JD0*W3IG>E_K#=I7DLJ-*F<"`GIT'#9*JKJKJF5[K9(#\G.@"F
M8J:YO^FD2KQVN;.JNKKTIWT`17%U871O<FEA;"!'=6EN96$@**BJN42T6*2Z
MJ,@I`$5R:71R96$@**3,I=^O4ZB]IG<I`+_YNWX`J]BEW[#/MO0E<Z[)M6^E
MS;_YNWX`IU*PHZ90J$+!X\)).B`E<R"NR;5OI<V_^;M^`*=2L*.F4*A"L$^_
M_3H@)7,@KLFU;Z7-O_F[?@#%JJCZI+JN93HE<R"NR;5OI<V_^;M^`*?SMW.Q
M2[U8.B`E<R"NR;5OI<V_^;M^`+QGI$H@(B5S(B"NR;5OI<V_^;M^+@!%<W1O
M;FEA("BW4JA&I:>HR"D`171H:6]P:6$@**;GK\&D\:C(*0"ZV+':`$5U<F]P
M92`HO-JL=RD`J$,@,34@I,#$P0"H0R`R(*3`Q,$`J$,@,S`@K.W$P0"H0R`U
M(*3`Q,$`J$.FN+5NI$H`J$,@,S`@I,#$P0"H0R`Q(*3`Q,$`O62HTJW(.@"P
M]:;F`*YIMGT`KFFV?;CJKL:GJ`"M;JA$("<I)P"H[+3!I.D`N-&[H:W[`*ME
MM+K#0Z;B`$944""D5[;'LUVI=RX`Q:JH^K"^IFZS7:EWI:*QT0"U3*IKLW.]
M=:;<($Q$05`@IOBJ0;ZY+@"U3*IKLW.]=:;<(%--0B"F^*I!OKDN`+W&NW.E
MHK'1IML@(B5S(BX`O<:[<Z6BL=&H["`B)7,B+@"U3*IKJ]BEWZ1`K=.W<ZJZ
M(%-!4TP@LW.QM2X`MVBROJ6BL=&H["`B)7,B+@#"7JCZI:*QT3H@)7,`M+:S
M<0!&86QK;&%N9"!)<VQA;F1S(*IKQ/6G2KK6N'.N<2`HL*BZN+K[K\>TM;AS
MKG$I`$9A<F]E($ES;&%N9',`Q%FMJ[_YNWXZ`+;'KW4`ML>O=0"D1Z3K`+=0
MQ+$`MU#$L3H@`*3RI/*K0@"U=;S(L'VSMP#$YJ;LL'VF0P!&:6II("BTM,#9
M*0#`R:[7O,:EV#H@)7,@K=/`R:[7`,#)KM>\QJ78.B`E<R#`R:[7`,#)KM?!
M8+K>`,#)KM>F5[K9`,#)KM>_[[[<`,#)KM>D5[;'`,#)KM>D5[;'I5ROX*6\
MLU&DY+2I+@"Y3,)OOKD`1FEN;&%N9"`HJN+$]2D`I%>E8J3K`*17J;8`J52I
M=Z3QJ-(`I%>D5<1!K<L`KT*PR@##^@"EV+_]("5S(*2CIG.F8@"F<JNLPT.F
MX@"MN:JK`*9=K+#"<\3]OKFHPZ6\I.2TJ;QVN;.E7*_@+@"N\+9(N7>S^"`H
M5$%&*0"Y=[/XI-&\QB`HN7>S^*31O,:E7:Q!I=6DT:5(I,ZI7;:AJKJXZJ[&
M.Z9PJD>Y=[/XI-&\QKC[JOBQ3J;[I<ZD\;C[O&6T5*JZJJFML2D`I]&P3[%+
MO5@@/P"J[;/F`*1PNWD`I'"[></^JZP`I'"[>0"D<+MY(#(`O=>^P@"FV[#*
MPN"K2`"L4+3!I*T`KMBL6P!&<F%N8V4@**IKL.HI`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R96YC:"!'=6EA;F$@**IKQ-V[7*C(J+HI`$9R96YC:"!0;VQY
M;F5S:6$@**IKQ-VLP:=1I:>FZ*C(*0!&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,`L4BE\Z1(`+%Q`*>YON.T>:UZ`+JAI.L`I?ZF5P!'86)O;B`HI5NT
M7BD`P\"T63H`1V%M8FEA("BES*3QJ,@I`+*CI<T@)7,@K=.H=++.LUVI=P"D
M=[*CI<VJNK-=J7>XZJ[&`$=E;W)G:6$@*+/LJG:HR*9`J4VPZBD`1V5R;6%N
M>2`HO'>PZBD`1VAA;F$@**U[K\<I`$=I8G)A;'1A<B`HJKVEK,.YJOLI`*97
MNMD`JV6IN0"M]+QWNK@`1V]O9VQE(*9AN<\`1V]O9VQE(+=JM$T`IL>VI0!'
M<F5E8V4@**?&P[XI`*?&P[ZDY2`H25-/+3@X-3DM-RD`1W)E96YL86YD("BN
MYK.NQ/6N<2D`9W)E;F%D82`HKN:WYZ_'N48I`+ASLM6ZWK)Z`+ASLM6F5[K9
MI*.Q;ZK%I=4`1W)O=7!?;&1A<#H@M4RJ:[=SO%>X<[+5("5S+B"F^*I!OKFF
M7L"S.B``1W)O=7!?;&1A<#H@M4RJ:Z=2L*.X<[+5("5S`$=R;W5P7VQD87`Z
M(+5,JFNG\[=SN'.RU2`E<P"X<[+5`$=U861E;&]U<&4@**WTO'>LI;2V*0!'
M=6%M("C#]JYQ*0!'=6%T96UA;&$@**7*IF&PJ*G4*0"NYJZFINBN<0"HT[NK
MQ7:MK0"S6*O(KV2HI0!'=6EN96$@*+18I+JHR"D`1W5I;F5A+4)I<W-A=2`H
MM%BDNJC(I/&OP:9`J4VPZBD`1W5Y86YA("B[7*C(J+HI`+97I.6S<[6RNWFH
MI0"GY*2CJ.P@2%144"#%Y\/2+@!(86ET:2`HKORF82D`POBTZBVZ=+KB`,9'
M`*KMP%D`JNW`60!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`
MI&JY<*M"`*?&IT*HTZ3E("A)4T\M.#@U.2TX+4DI`+"JJ]<`NZ&I^@"]<[_H
MOKFHSZ7.NZ&I^@"[H:GZ`*5BLGD`LV^XS*Q/P,FNUZJZMGVI;#H`L*H`KF%?
M;0!(;VQY(%-E92`HL>N_S:FC*0"N80"F[:YAIF&G?0"N8:78O_T`INVN8;EQ
MN-P`2&]N9'5R87,@**>[LZ.IU+2U*0!(;VYG($MO;F<@**V[M.0I`$AO<F1E
M`$AO<F1E+TMO;&%B.B"V;*7S("4R)',@I*2Y2JCLM4RNQ*JZ("4Q)',@6$U,
MN.JNQ@!(;W)D92]+;VQA8CH@M4RV;*7SOD&F6*JKI?,@)7,`2&]R9&4O2V]L
M86(Z(+9LI?,@)3(D<R"DI*?DI*.H[*JKI?.KK+I!("4Q)',`2&]R9&4O2V]L
M86(Z(*1WIJBE7*JZLKZPHR`E<R`B)7,B`$AO<F1E+TMO;&%B.B"^XZ98I'6U
M>[O=K6X@)V1O;7AM;"<@JKH@4$A0(*FUIOD`2&]R9&4O2V]L86(Z(+5,JFNK
MV*7?("5S(*JKI?.JNB!834P@OO``2&]R9&4O2V]L86(Z(+5,JFNROK"C("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B"U3*IKP/*H^K.AI?<@)7,@JZRZ0:JZ
M($U)344@P]&G3[BYO5@`2&]R9&4O2V]L86(Z(+5,JFNF4*A"("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B"U3*IKIE"H0J3`J,DZ("5S`$AO<F1E+TMO;&%B
M.B"EO*J^JKJDP*C)("(E<R(`I/2EK;UU`*3TI:VYU*52`*3TI:TZ`*=!IG"F
M\ZCLIKD@/R`HO="QU*UZ(2D`IT&M;J98J-:F:*36K=/$YJ;LJ4\_`,3FINR\
MQJ78ID"M<#\`IT&M;J98J-:F:*36ID.I3S\`M\.KUP"WPZO7.B``M\:]7:1J
MKG8`2'5N9V%R>2`HIDFD^J=1*0!)34%0(+9LO6.KV*7?I:*QT3H@)7,`24U!
M4""V;+UCIU*PHZ6BL=$Z("5S`$E-05`@MFR]8[K/NM"P=+AMJ]BEWZ6BL=$Z
M("5S`$E0(*;LIWT`25`@INRG?;5,JFNHSZ7.+@!)4""F[*=]J,.DHZ9B($-)
M1%(@JKJDN;-<L,^V]*2D+@"F8JOAK;&TH:1*ID-?;@!)8V5L86YD("BF0JYQ
M*0"OPKG/I=P`)7.JNKG/I=P`N<^EW*3.I.6F<@"HK:7WP]&G3ZJZIE>ZV3H`
MIG"J1[5,JFNEO[U4IF'%XZ7<+"`E<R"E2*5TMGVQTK9LI?.I\[=SM?BUH;?M
MI*0N`*C/I<X@26YT97)N970@17AP;&]R97(@PG/$_;ZYKLFF<*I'J%.FLZS=
MJ.RE]*;SJKJD<+G/I=PL(*=!I6FOX+O=K6ZDQ+_OLV^MT[:UI=BE2,/VLZP@
M4$Y'(+QVN;.JNL'TPL.NQ*I'+@"F<*I'K-VH[+-OJVBH4Z:SO':YLZJZL%2N
MIRRS;ZKMI=RG0:JZPG/$_;ZYM4RJ:\7CI=RD5[;'JKJ\=KFS+@"\=KFSN7?$
M_3H`O':YL[KTIWT`O':YL[KTIWTZ`+QVN;.HTZ;;P\"T60"\=KFSJ-.FV\/`
MM%DZ`*17ML>\=KFS`+QVN;,`MM>D2BP@J$+&2B`E9`"VUZ1*Q.:F[#H@)7,`
MMM>D2L3FINPZ`*9BJ^&ML;2AI$JF0U]S`+_II$JDHZ6_O52JNJ=`I<Z]6"X`
MO=#`RZQDIT&JNJC/I<ZJS*97NMFDSK%+O5@`J,^ESJK,IE>ZV:2CI;^]5*G.
MJLRY<:1LMFRE\Z;MIWVD=\7<I_,NO=#!<+6XIT&JNJATLLZZWK)ZK?NE2*CS
MIU6S0K)Z+@"\5Z5;P5FQQ@!);F1I82`HIDRKURD`K=.G3ZC/I<ZJS`!);F1O
M;F5S:6$@**9,I:<I`+CJL%0`N.JP5`"U3*5II<ZJNKCJL%0N`*9BJ^&ML;2A
MI$K$YJ;L7V\`M*&D2KG/I/D`M*&D2JKMKN8`M*&D2KKTN/2S<[6R`*9BJV6M
ML;2AI$K$YJ;L7T,`IF*EV*MEQ.:F[*OAK;&TH:1*I$"MT[=SQ.:F[`"F8J78
MJV7$YJ;LJV6ML;2AI$JD0*W3MW/$YJ;L`*9BI=BK9:9#J^&ML;2AI$JD0*W3
MMW.F0P"F8J78JV6F0ZMEK;&TH:1*I$"MT[=SID,`IF*EV*MEN&#"2:OAK;&T
MH:1*I$"MTZQQN*@`IF*EV*MEN&#"2:MEK;&TH:1*I$"MTZQQN*@`M*&D2J5I
MM,"E3KS+JD\`MW.Q2[U8L4ZQ2+5OJ.RS;ZW3MFRE\Z9AIWTZ`*9BJ^&ML;2A
MI$K`>*9SKN8`IF*K9:VQM*&D2L!XIG.NY@"F8JOAK;&TH:1*Q.:F[`"F8JME
MK;&TH:1*Q.:F[`"TH:1*MFRE\P"F8JOAK;&TH:1*K'&XJ`"F8JMEK;&TH:1*
MK'&XJ`"F8JOAK;&TH:1*ID,`IF*K9:VQM*&D2J9#`*9WI?ZPW:5YJKJUJJ[7
M.@"TH:1*+\7<I_.\=KFS`+2AI$HOQ=RG\[KTN/2S<[6R`,))O,:DHZBLI4BF
MW*GSM4RJ:[;'L&6UN;!TN&VX<[+5+@#"2;S&I*.HK"X`ON.\Q@"^X[S&ID,`
MM4RNQ*JZ(%5$2"BHSZ7.JLRXZJ[&JNW`62DN`+5,KL2JNB!:25`@N.JNQBX`
MM4RNQ*JZP+.ESK5[IJ$N`+5,KL2JNJ?EIKBXN;U8+@"P9:58JKJXZJ[&M4RN
MQ"X`M4RNQ*JZI=B\T*;MIWT`M4RNQ*JZP,FNUZ[FIJ$`M4RNQ*JZL<+%=KU8
M+@"U3*[$JKJF8;#/+@"U3*[$JKH@;7-G7W1Y<&4N`+5,KL2JNJG.I^2DHZCL
M(&%P:5]I9"X`M4RNQ*JZJ<ZGY*2CJ.RPT;S&+@"U3*[$JKJD]\5VK:TN`+5,
MKL2JNKG9IO'#T:=/O5@N`+5,KL2JNK*CJWZ]6"X`M4RNQ*JZLW&P5*CSJ7<N
M`+5,KL2JNJ:LI?.D2#HB)7,B`+5,KL2JNJ3`J,FJJZ7S+@"U3*[$JKJHT[>]
MINVG?2X`M4RNQ*JZN%6PZKU8N.JNQBX`N.JRHP"F7K1?O^^^W`!)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F("BE[*[4*0!)<F%Q("BE[*G4ITHI`$ER96QA
M;F0@*+=2NKC$]2D`27-L92!O9B!-86X@*+#2KG$I`*>]LZ&Y<*M"`$ES<F%E
M;"`HI4BFXJ9#*0##L;5OJLP`L=?%Z0!)=&%L>2`HN'&D:J=1*0!*86UA:6-A
M("BD^K92I5LI`*1`I.L`2F%P86X@**3II;LI`*3II.4@*$E33RTR,#(R+4I0
M*0"_0:;HKG$`2F]R9&%N("BL^:6Y*0"D0Z3K`*2[I.L`N>^[]`"X;:2D`*6J
MI6NY[[OT`+YAI:JY[[OT`+YAI6NY[[OT`$MA>F%K:'-T86X`JT^O9*WLO,L@
M/P!+96YY82`HJM:HR"D`2V5R8F5R;W,@NWO#TK_YNWXN`*[6I-^W<Z3B`*KW
MQE^KV*7?`*KWQE^O4[QX`*KWQE^J^*O7`*KWQE^KK+I!`*KWQE^[>:IK`*78
MJV6JNJ2]MGVJ]\9?IOBJ0;ZYI*0LI'>X9Z9SIF*G0:JZJO?&7RX`J."UHP!+
M:7)I8F%T:2`HL/*HO:3:M+4I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F("BE7\'Z*0!+;W)E82P@4F5P=6)L:6,@;V8@**MNP?HI
M`,'ZI.4@*$550RU+4BD`2W5W86ET("BL[*O"KU,I`$MY<F=Y>G-T86X`JJFM
ML;!TN&U?>0"[>:BE`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M("B\9+#J*0"D5:5BI.L`L\RJ\:1`IKBQ2[U8Q=RG\ZGS`*15J;:DZP"D5Z:X
MI_.W<SH`I%>D0*:XM6ZD2CH@)7,`I%>D0*:XM6ZD2CH@)7,@IML@)7,`I%>D
M0*:XM6ZD2CH@LL2D0*:XM6ZD2@!,871V:6$@**G4LN:Z^ZC(*0"J:ZO?`*JI
MK;&P=+AM`$QE8F%N;VX@*+ZDI-JYX"D`I:K#Y`"EJL/DJNW`60"EJL/DK<@`
M3&5S;W1H;R`HO^"OP::K*0!,:6)E<FEA("B_X*3QM^>HR"D`3&EB>6%N($%R
M86(@2F%M86AI<FEY82`HIU&D\:C(*0!,:65C:'1E;G-T96EN("BF0Z3DM+"T
MM;5N*0"W3*M"`*1PJT(`IJVFLZ1PJT(`L=^FLZ1PJT(`I'"P?:M"`*1PJT*F
ML[EP`*1PL[<`I'"P?;.W`*6TJF^XU@"S<[6R`+-SM;+"2:CL.@#%XZ7<KLFS
M<[6RMFRE\Z;MIWVH[+USO&>V;*7SK;:ML0"S<[6R`*9#I5@@+2"HSZ7.JLRE
M::5(K-VH[+-OK=.K2*7SIU@`ID.E6+CJKL:N=P"F0Z58NZ&I^KS0PT0`ID.E
M6*KMKN8`L%&]U[ASLM4MP,FNU\)D`+!1O=>X<[+5+:A$IU4`L%&]U[ASLM4M
MP]&G3[BYO5@`L%&]U[ASLM4MOM:FLZK,`+!1O=>X<[+5+;%(I?.D2`"P4;W7
MN'.RU2VM<;Y<`+!1O=>X<[+5+:CZKOBM<;Y<`*9#I5BW?+3!I:*QT3H@)7,`
MID.E6*C/I<ZJS*6BL=$Z("5S`*9#I5BHSZ7.JLRJNJ5<K^"S4</VLZP`I.6^
MQP!,:71H=6%N:6$@**7?L[.I>RD`N/RD2J2D+BXN`+?MIF&NR;:A.B``IF&P
MS[M0KLFVH0"F8;#/`+5NI$H`M6ZE6`"U;J1*`+5NI$JD=:=``+5NI$JEHK'1
M+""]T,#+K&2[U:15JKJESJ3AIE>I3;%+O5@L(+5-J^&MJ[C5+@"U;J1*I:*Q
MT2X`JOBE>0"W4K&A`*=#`*1PO&>GQL.^O,:F<@"D<+QGJ=2D0KS&IG(`I'"\
M9\.YL*B\QJ9R`$QU>&5M8F]U<F<@*+]CM,NS^2D`I.L`J$.DZ;!4KJ<`35,M
M5$Y%1B"J_J5;P,FNUZ2DJ%.FL[CJKL8N`$U31P!-86-A;R`HOT2J^2D`36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F("BPJ*CD
MN7FF0*E-L.HI`$UA9&%G87-C87(@*+"HN4:E6[2UI5LI`,5=LTX`MFRE\P"V
M;*7SNMZR>@"KV*7?LW.ULE]K+BXN`$UA;&%W:2`HL*BIU*O"*0!-86QA>7-I
M82`HL*BHTZ;HJ,@I`$UA;&1I=F5S("BPJ+JXIF&DTBD`36%L:2`HL*BG42D`
M36%L=&$@*+"HNKBE3"D`NMZR>J=!JKJDP,/^+*C#I4*LL*3`P_ZS7:EWPT.F
MXBX`36%P,C0@IF&YSP!-87!1=65S=""F8;G/`*14I.L`P^2LR0"\T+!/IJ@@
MK-VY3"^EO*S=N4P`O-"P3Z:HJ.2E3*JZP]&G3R`HJ-*F<"X@K:NM;B^D=Z9>
MPM`I`$UA<G-H86QL($ES;&%N9',@*+"HKDRZN+ASKG$I`$UA<G1I;FEQ=64@
M*+"HM*.EIZ=*KG$I`*3'L'3$YJ;LI*0`36%U<FET86YI82`HK52G4;;PI:>H
MR"D`36%U<FET:75S("B\KZB]INBTM2D`I+FS7*JZL\RD:L))O,8N`*K^I?.\
MQJ78I'>V5Z58I+FS7*17K:TN`+/,JO$@,C0@I'"NR:JZL\RPJK?%J]<Z(`"S
MS*KQ(#8@I'"NR:JZL\RPJK?%J]<Z(`"PS[;TI%>MK;S&I=@`I+FS7+/,I&JJ
M^*O7`*2MI.L`36%Y;W1T92`HL*BL^:]3KG$I`,+EOL<`IJBM^P"_[[/FO-*F
MH3H`IEBHUL!XIG.NY@"V;*7S`+9LI?/%Y\/2I'>GN::H+*;]K$^HSZ7.JLRJ
MNL.QL[FK;[5,JFNS<;E,Q>?#TBX`PK*P5*1WN4RTP2X`PK*P5*NLND$`365T
M87(@L,^V]+5,JFNHSZ7.+@!-971A<B"PS[;TM4RJ:ZC/I<XN(++3N&"]T+#1
MIM*H=++.NMZR>K5NO_TN`$UE=&%R1$(@J7REO+-SL;4N`*3HJFL`I.BJ:R`B
M)7,B(*6\LU&I=[AQ`*3HJFNEO*EWN'$N(*5(J4FE<Z3HJFLZ("5S`*2]J.X`
M365X:6-O("B^I:;HK?0I`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8@*+%+ITK#N:6GINBHR"D`I*2VH0!-:6UE(*NLND$`L\RJ\2`R-""D<*[)
MJKJSS*=#M\6KUSH@`+/,JO$@-B"D<*[)JKJSS+"JM\6KUSH@`+/,M76Q2[U8
MKL2TP:E\I;RH[+3!`*Q-KF<`POBVM0"GY*2CJ.P@4$5!4B"E7;C+($A45%!?
M4F5Q=65S="X`LUVI=\#)O_*EHBX@IG"J1ZUNJ,^ESK-OK=/`LZ7.M7NFH:=!
MI;*VM[)[IF*T3K*CI<VE3"X`I^2DHZCLPK*P5*JZ($E$+@"GY*2CJ.RELK:W
MJKH@4$5!4B"E7;C+($UA:6PN`*?DI*.H[+=\M,&JNB!)1"X`K%"TP:1``*;F
ML,JV;*7S`+?%J4T`I_.W<Z3IM,$`K=>G[[KTIWT`O-*RU0!-;VQD;W9A+"!2
M97!U8FQI8R!O9B`HO*^ZN*9HI<LI`$UO;F%C;R`HO*^OQZWT*0!-;VYG;VQI
M82`HNUBE:BD`I.NDSJ9^`*A#I.L`NUBVZZG4KU,`I.NLVP"F8K+$)62FYJ?D
MJ.RJNL3FINR\QJ78I'>V5Z58N7>TP25D+@"\KZREK?0`IFBVLZ[)M+@`IFBV
MLZ[)L[$`M+BNR:9HMK,`I%6RO@"EJK*^`*5KLKX`I%>RO@"D5;*^`*17LKX`
M36]Z86UB:7%U92`HLO:D5*3QITHI`+W&O^^FH:15J=2E7*_@JNT`O<:_[P"G
MVJJZL6*XN0"GVJJZL6*XN;CJL%0`K=.D2*^XI7@`K=.D2*^XI7BMMJVQL'2X
M;0!->6%N;6%R("B]<:AL*0"DHRRGVJ2CIE"W3@"F5[K9`$YA;6EB:6$@**BZ
MILRD\:C(*0!.875R=2`HO]6^?"D`3F5P86P@**6GJGFZN"D`3F5T:&5R;&%N
M9',@*++\Q/4I`$YE=&AE<FQA;F1S($%N=&EL;&5S("BR_,3=IG>F8:9#M+4I
M`$YE='-C87!E(*RPL/+"IJJZNO2G?0!.971S8V%P92"^S,/2IT"\;[KTIWT`
M3F5T<V-A<&4@OLS#TJQ&M::Z]*=]`$YE='-C87!E(*?SMW.Z]*=]`$YE='-C
M87!E(*=`O&^Z]*=]`$YE='-C87!E(%-33""F^*I!OKFF5[K9`$YE='-C87!E
M(+[,P]*JNK7YN-$`3F5T<V-A<&4@OLS#TJNLND$`NO2X]*1UJ.,`L7&EO`!.
M97<@0V%L961O;FEA("BW<[/8J+VF:*6GJ,@I`+=SO%>DP,/^`+QGJTBUN2`E
M<P"W<Z3K`+=SJ,^ESJK,IE>ZV2`HJT2ELJUN*0!.97<@6F5A;&%N9"`HK\.F
MZ,3U*0"W<[%+O5@`MW.Q2[U8L4ZI\R5XJ.RTP2X`MW.Q2[U8I*.RQ:98+@"W
M<[7XM:$@*%]B;&%N:RD`MW.[1`"W<[M$N'.RU0"D5:1`J$(`I%6D0*W3O^^V
MM0"D5:1`K;8`3FEC87)A9W5A("BEIZ5;J=2ERBD`3FEG97(@**6GI.DI`$YI
M9V5R:6$@**E@I,ZG4:C(*0"QWZ17`$YI=64@**_#KDJN<2D`IU\`M4RE::C1
MQ>.EW*YTLJ>JNK-=J7>XZJ[&+@"U3*5II<ZJNK6FLJ2KV+-Y($E33R"\=KFS
M+@"H4Z:SI^6FN+S+IJ$N`*G2J_RI=ZJZINRX;:17J%.FL[#/MO2F<Z9B`*A3
MIK.THZC1IN:HQK[DIE>ZV:5(J-$@34-!3"#%Y\/2+@"H4Z:SQ=RG\RX`M4RJ
M:Z9BI=BK9<5VK:VDI+Q7I5NFN,5VK:TN`*A3IK.K_*EWJKH@)7,@LUVI=[CJ
ML%0N`*A3IK.K_*EWJKH@1E10(%9&4R"S7:EWN.JP5"X`J%.FLZO\J7>JNB!3
M44P@5D93LUVI=[CJL%0N`*A3IK.K_*EWJKH@4U%,+49I;&4@5D93LUVI=[CJ
ML%0N`+5,L]&^;,))O,8N`*6\M*.HT:78JKHN`,#)KM>EO*17ML<`I^2DHZCL
MN<^EW"X`INRX;;CJL%2I?*6\LUVI=P"I?*6\M*.HT:;LN&VXZK!4+@"EO+2C
MJ-'"LK!4+@"EO*O\J7>F5[K9+@"EO*O\J7>XN;U8+@"H4Z:SJ_RI=[%+O5BE
M2*C1($A45%`@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!)34%0(,7GP](N`*A3
MIK.K_*EWL4N]6*5(J-$@2V5R8F5R;W,@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BH
MT2!,;V=I;B#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1(%!!4U-71"#%Y\/2+@"H
M4Z:SJ_RI=[%+O5BE2*C1(%--0B#%Y\/2+@"EO+_II$H@3W!E;E-33""D1Z2X
ML/6FYL#)JKJE_KCTKGPN(%!+0U,@,3(@LU>NYJJZI5NQ2[CJKL:[W:UNI<ZH
M[+C3M7NFH2X`J%.FLZO=O&:JNK7YI56ET[W0+@"ZS[K0L'3#0J6\LUVI=P"U
M3*[FO74`J7REO*O\J7?$YJ;LI,"Y:J9RI+@N`+5,KMB]=0"U3*:YP,FNUP"U
M3+S(IG.EV+_]I6FHT:?6J/HN`*6\ML>P9:C/I<ZJS*97NMFISK%+O5@N`+5,
MI6FESJJZ(%A-3""XZJ[&LU&VQZ9>`*K%I=6MR`"M[*ELLUVI=\#)I*2GY*2C
MJ.RJJ:6[N.JP5"X@K:NW<[*CI<VS7:EWP,DN`*9BIT&JNK-=J7?`R:2DI^2D
MHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+@"U3`"U3"`H=7-E(&EM<&QI
M8VET*0"DZ:;5L-*DY2`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD("B_
MU;K6ITJN<2D`I5^E8K)Y`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W
M87D@**Z_J\(I`*M$I*>KX0"K1*2GJV4`I*.L3Z1`K=.EV+_]`+5[IJ&I?*6\
MI[FFJ"X`I*.S7:EW`*6\LU&DY+2I`+/&I]&__0"H4Z:SI6G"<\3]JKHLIEZE
M:"X`I%&D0*3K`+S&IG(`IG*DN+S&`*9RI+B\9:O7`*;FO,8`I_.W<[!TN&VX
M<[+5KLFEO*O\J7>\QJ78+@!/2P"JJZ7S`*JKI?.KV*7?JLP`I$NV::;L`*11
MI.L`O^RDO:O'`+=SL4N]6*6RMK>[4,+"L4N]6*2CIE`N`,+"L4N]6`#"PK%+
MO5BDHZ6_O50`3VUA;B`HJORPTBD`I76FLR!)34%0(*;XJD&^N:3DM*FK2*7S
MIUBDP*C)I5ROX"X`I76DN;-<I$"MT[9LI?.F[:=]+@"E=::SOM:FLZK,NU"H
M=++.NMZR>JW[I6FE2,7<I_.F0*C)Q7:MK0"F8K=SJKJU^+6AMGVQT@!/<&5N
M4U-,(+_YNWXZ(+5,JFNQ<2!3+TU)344@P[&SN:K^I?.XT;9]N.JNQBX`IF*W
M<ZJZM?BUH;9]L=*S<[6R`*=`MWZH=++.`+_OMK4`)7._[[:U`+:UI=B]<[BY
M`++5PK0`LM7"M+/FINP`LM7"M`"M[*ELP+.ESK5[IJ&\RZI/`*9B("5S.B"D
MI*JZK>RI;+S+JD\N`*CDI4P`J.2E3+CJL%0`OM:FLZK,Q7:MK0!004T@Q>?#
MTK5,KL0N`%!%05(Z.K9LI?.F^*I!NMT`4$=0(+S&INS#L;.Y`%!'4""E6[%+
MN.JNQ@!01U`@I+VV?:KWQE\`4$=0(*1WP[&SN2^D=Z5;L4L@N.JNQ@!02%`@
MM7NFH;U8`%!(4""O\[U:`*3(J^&D<*M"`*3(J^&P?:M"`*3(J^&FL[.W`*3(
MJ^&P?;.W`*3(J^&TN`"DR*OAN7"K0@!03U-)6"!E>'1E;G-I;VX@O_*EH@!0
M2%`@K_.]6E](`+G4I5(`4&%K:7-T86X@**3:L/*TM:E:*0!086QA=2`HJ:VO
M6RD`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"`HI-JPQ[2UJ5JF
M^[OBL,\I`%!A;F%M82`HI-JNL["H*0!087!U82!.97<@1W5I;F5A("BDVJ6L
MJ,BW<[18I+JHR"D`4&%R86=U87D@**3:J=2F8RD`IFBVLP"Q2[U8`+%+O5C%
MW*?SI[FFJ"X`L4N]6*2CI;^]5`"H4Z:SJ_RI=[%+O5BE2*C1(%)!1$E54R#%
MY\/2+@"Q2[U8O52[>P"Q2[U8.@"Q2[U8.B``L4N]6*6RMK>G:Z98+@"V2Z17
M`+9+I%<`N/2N?`"KW;QFM6Z__:%'`*:HK?L`ILJDP*3Q`+#UIN:Z^\5`OMZG
M0`"U;J1*J^&P]:;FNOO%0+[>IT`_`,5VK:T`(B5S(JJZQ7:MK:6\LU&G4K"C
M+@"F<ZCZOD2IV@#%=JVM`,5VK:VZWK)Z`*?:JKH`4&5R=2`HK[6^?"D`PV2J
MJP!0:&EL:7!P:6YE<R`HM>&KW[NK*0"Y<;C<`,/`M%D`4&ET8V%I<FX`N;.O
MP`"]T+9II$K`>*9SKN;"2;_O`+W0O52I=ZUNLKZPHZ:YI+BE\SH`O="]5*EW
MIT&M;J2DPE^FN:2XI?.JNK-SM;(N`+W0O^FD2J1`K=.DZZ7WI,ZF?J7W+@"]
MT+_II$JW<[Q7I,##_JJZIE>ZV3H`O="_Z:1*I$"MTZ:SKL2JNB!)4""F[*=]
M`+W0O^FD2J1`K=.FLZ[$JKJDZ;3!.Z3$O^^FN:3KI?>JNJ3IM,$N`+W0O^FD
M2J1`K=.FLZ[$JKJNR;:A+@"]T+2CJ-&PW<-$JKJZ2ZUN+@"]T+_II$JG0:JZ
MJ,^ESJK,IE>ZV:3.L4N]6`"]T+Y<Q:JD5:9#I+JN92ZG0:6RMK>F4+=.LV^H
MQZC&MK6D?J_@J,^ESJATLLXN`+W0O^FD2K=SJKJDP,/^IE>ZV3H`4&]L86YD
M("BJ:<3U*0"L1JIV`*?KLKP`4&]R='5G86P@*+BRM>6D^BD`O':YLZ;LN&T`
MJNVNYJ;LN&T`N[RP9;9LI?.H[+-OK=.K2*7SIU@@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*0"SS*KQ("5S(*1PKLFJNJVPJT*V<3H@`*VPJT(\8G(@+SZ^][)V
M`%!R969S7VQD87`Z(*?DI*.H[*G2N]VM;JJZ($Q$05`@J;6F^:Y-I?,N`%!R
M969S7W-E<W-I;VXZ(*?DI*.H[*G2N]VM;JJZ('-E<W-I;VX@J;6F^:Y-I?,N
M`*[PP*,`KOREK:VQKO#`HSH@`*[PP*,Z(`"Y=\3]`*9BMW.JNK7XM:&Y=\3]
MO':YLP"D5Z1`K=._[[:U`*9#IDRDY:7S`*APL4NJ]\9?`+#=PT0`L-W#1+1Y
MK7H`L4VNUP"THZ7<I+JN90"DO;9]JO?&7P"DO;9]JO?&7[ITNN(`I+VV?:KW
MQE^XZK!4`*2]MGTOJ'"Q2ZKWQE^Y[ZC#I;RS4;*CI<TN`%!U97)T;R!2:6-O
M("BJ::9HOJ2F52D`46%T87(@**5DN48I`*QDN-\`NL^ZT+!TN&T`4E-!(*2]
MMGVJ]\9?("@E9""F[*2X*0"_[[[<MG,`JT(`IJVFLZM"`+'?IK.K0@"P?:M"
M`*M"IK.SMP"K0L+@L[<`P$B^]Z1PNWD`I/&R=@#%JJCZ`,6JJ/JV;*7S`*]U
MJKJM;J=2L*,@)7,@MMP_(+-OMK6^WJ=`L4ZU3*IKJ^RT7RX`KW6JNJUNLDVP
MHZC/I<ZJS"`E<R"JNKCJKL:VW"`_(+-OMK6^WJ=`L4ZU3*IKJ^RT7RX`J/JN
M^+1?K>P`K:NW<[[CLGH`K:NW<[[CLGJPRKI!I=B__:2XI?,Z`*VKMW.^X[)Z
MK=.D2*^XI7BDNJYE.@"Q8+-7JNVEW*:A`,/VP7#"<\3]OKD`K:O%J@"U^[W7
M`+NWNMVF^*I!OKD`N[>ZW;KTIWT@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@"ROK"C`+*^L*.PS[;T`+*^L*/$YJ;L`*5HL*.NYJ:A`+*^L*.Y
M[P"FVZ;XJD&^N;S(IG.EV+_]I*2ROK"CI'?`>*9SJKJS7:EWM7NFH2X`LKZP
MHP"FVZ3EI?.DI+*^L*.FN:1`N&#"20"ROK"CJ,^ESJK,`+*^L*.HSZ7.JLPZ
M("5S`+O=J$2EO+-1IE[`LSH@O_F[?KBYO5@Z`*?DI*.H[*G2N]VJNJI!L,@N
M`"4R)',@JKJS7:EWI;*VMZO\J7<@(B4Q)',B`%9&4R"JNK-=J7>ELK:WJ_RI
M=R`B)7,B`+-=J7>XZJ[&I;*VMZO\J7<@(B5S(@"ELK:WQ.:F[`"MJ[-=`*VK
MLUVQ2[U8`*VKLUVG0:JZL4N]6#H`IEZF<[/,J^&D0*W3K&2XWP"ULJI'`*KP
MIEZ_[[:U`*9!IKB_Z:1*MW.Q2[U8`%)E=6YI;VX@**]DI:>I]*YQ*0"F7K1?
MLUVI=P"Z]*VVO7._Z+ZYO^^VM0#!O+MY`*5KP^0`I6O#Y*KMP%D`I6O#Y*W(
M`*9#I+JN95]W+BXN`*BDIN(`4F]M86YI82`HP[FPJ*6GJ,@I`+';PN`@,3@P
M(*O7`+!FKLFP=R`Y,""KU[';PN``MK:NR;!W(#DP(*O7L=O"X`"F0Z2ZKF4`
MID.DNJYE`*9#`*[FO74`Q.:F[+M0ID.NYKUU`,3FINRNYKUU`*9#KN:]=0"P
M]:;F`%)U<W-I86X@1F5D97)A=&EO;B`HJUC#N;2U*0!2=V%N9&$@*+]CIG>Y
M1BD`4R]-24U%(*5;L4O#L;.Y`+9LI?.D=ZC/I<X@4R]-24U%(*5;L4L`4T%3
M3"#%Y\/2M4RNQ"X`PK*P5`"XZJ[&KG>O\[U:`*5;L4NRU[K=OO<`IJBE7`"X
MZJ[&KG>O\[U:7U$`K%"TP:2[`%-A:6YT($AE;&5N82`HN'2[KK#'K\<I`%-A
M:6YT($MI='1S(&%N9"!.979I<R`HN'2G2JB]M+6F:+K6I,ZEI[K[M+4I`%-A
M:6YT($QU8VEA("BX=,53INBHR"D`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R`HN'2DY;3+I,ZN
MYK?GJ+JD0BD`IE"D0*W3M?BUH2`H7W-E;&8I`%-A;6]A("C"Q+ROJ,BX<ZYQ
M*0!386X@36%R:6YO("BX=+"HIU&_U2D`4V%O(%1O;64@86YD(%!R:6YC:7!E
M("BX=*9HK/RDSK2VJDRFZ*3Q*0"]PZQ0M*.HT:K,`%-A=61I($%R86)I82`H
MJ$:O4:9AJORIU*="*0#`>*9S`,!XIG,@(B5S(@#`>*9S("5S`,!XIG._[[:U
M`+%.LJ.ES:JZLUVI=\#)I4@@4$A0(+MYJ*6NYJ:AP'BF<ZCLIT&JNJ;XJD&^
MN;S(IG.EV+_]I*0N`+-=J7<@)7,@I'?`>*9S+@"G\[=SM7NFH:1WP'BF<ZCL
M.B`B)7,B+@"Y<ZQ0N7"K0@"L[+['`+=JM$T`MVJT3:3>P+H`O^^^W,#)KM<`
MO^^^W*1`K=.DZ;3!`+_OOMRD0*W3N'.RU:7.I4BW<[Q7`+_OOMRD0*;LMW.J
MNK[6IK.JS`"_[[[<I$"SH:;XJD&^N0"_[[[<I$"F[*C/I<ZJS*7.I4BW<[Q7
M`+_OOMRITJ:S`+_OOMRITJ:SI.FTP:2XI?,N`+_OOMRD0*W3JJNE\P"DH[_O
MOMP`J?.E2*15JKJU^+6AI*2_[ZCZIT&M;JJZIG*DN"ZE2+?&N:N]QKMSJ=*_
M[Z3EIG(LM4VKX;9+I%>DY:7SO7._Z+#/+@"_[[[<I.FTP:3`N6HZ`+_OOMRD
MZ;3!I.FTP:[FIJ$Z`+_OOMRQ_<7<I_.JNJBMI??#T:=/.@"_[[[<KLFVH:3`
MN6HZ`+_OOMRDZ;3!KLFVH:[FIJ$Z`+_OOMRLVZ2LI,>P=*JZI$>MT\3FINPN
M`+_OOMRG0:JZPT.FXK!TN&T`O^^^W+"^IFZ[>:BE.@"VQ[!EL-W#1*3/P+,`
MML>P9<*RL%0`4V5N96=A;"`HMNNDNJ5;NK@I`+=0M/J^N3H@`*1%I.L`4V5R
M8FEA(&%N9"!-;VYT96YE9W)O("BVZ[JXNONHR+M0NUBO4Z6GK?3#N2D`I\>X
MN0"F^*I!OKFXZJ[&O_F[?JG.JLRU3*IKJ,^ESBX`MWRTP;K>LGH`MWRTP2!)
M1""D=[E,M,$N`+=\M,$`KM:H^J3HMO0`I+FS7*=!J?.GT;!/L4N]6*JZKLFM
MU"RE::5(IMNFYJVKLUVQ2[U8+@"S7:EWN[>ZW:;XJD&^N:17Q-VI\Z=!JKJM
MTZ1(K[BE>"X`LUVI=Z=!JKJPOJ9NNWFHI2P@KLFPSZ5(I,ZDZ;3!KN:FH2X`
MLUVI=Z=!JKJQTJELP+.ESK5[IJ$LPT.FXK!TN&TLK;:ML:?SMW/`5[)V+*3.
MJ.2E3,7CI=R_[[:U+@"S7:EW`*?SMW.U>Z:AM$ZZ_`"FLZ9NM%BMTZ9APDFI
M3;-OK=.PT;S&IK/#]CH@`%-E>6-H96QL97,@*+;KJ?6ZN"D`P<JJJP#"LK5U
MNDNM;@"L3Z=?K+"D:K.AI?>JNK-SM;*I=[AQI]:QMJ5<K^#!Y#\`Q>.EW`#%
MXZ7<MW.RHZ7-NU"M[,!XIG.S7:EWP,FJNJYTLJ<N`*A#IKBU;J1*J^'%XZ7<
MI%>D0*:XJKJU;J1*KLFVH2`_`,7CI=S"2;_OOKD`Q>.EW*KMKN:^WJ=`I5RO
MX*KM(#\`J?.EJL/DQ>.EW"`E<R"E7*_@JNT_`,7CI=S`>*9SKN:DNJYEN>^X
MW*3HMO0`Q>.EW*KMKN:DNJYEN>^XW*3HMO0`Q>.EW*9#I+JN9;GON-RDZ+;T
M`,7CI=R\=KFSI+JN9;GON-RDZ+;T`,7CI=RD5[;'`*OYQ/*P?:M"`*:MIK.P
M?:M"`+'?IK.P?:M"`+NWI.BFL[!]JT(`IJS!60!3:65R<F$@3&5O;F4@*+?@
MI&RD<[#J*0"U^:55`,.QL[D`P[&SN;ITNN(`4VEN9V%P;W)E("BW<Z5;J5DI
M`*1JI'``LJ2Y3+K[Q4``4VQO=F%K:6$@*+2UK*6E[Z=**0!3;&]V96YI82`H
MM+6LI:7OI:>HR"D`L[<`L'VSMP"P?;.W`*:MIK.P?;.W`+'?IK.P?;.W`+]N
ML[>R8*O7.B``4V]L;VUO;B!)<VQA;F1S("BOP<.YJOFX<ZYQ*0!3;VUA;&EA
M("BOP;"HIU&HR"D`NG&[4+C6`+'&ID.DZ*96O^^^W`"HT[>]IF&G?0!3;W5T
M:"!!9G)I8V$@**MNJT0I`*MNO-H@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G
M:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`*MNI6*R>0"JQ:75
MIN8`MJ&V6@"VH;9:NU"YU*52`%-P86EN("BFZ*]:I/HI`*E5IZ.V;*7S`*]3
MKNVF<J2XO^FD2@"DP+/.P'BF<P"DP+/.Q.:F[`"DP+/.ID,`N4*PR@!3<FD@
M3&%N:V$@*+2UJ+W$]:5D*0"\T+?'`*Q0N]JJI\51OM0`L=*I;*9^I?<`K-D`
MJJRZ00#`>*9SKN:FH0"U\[E$`*=2L*.]=0"F<J;JID,`IMNV;*7SIF&G?:2D
MI6BPH[KTL.RF5[K9`+S+IJ$@6T-34UT`K%"TP:31`*?DI*.H[*:XI=B__2`B
M)7,B`*5$IJX`L&6E6`"\5Z5;("(E<R(@J.RH=++.JKJET[W0I'>P9:58+B"G
M0:6RMK>UI:CLN-.ET[W0LU&NUJWCJ^&D?J_@M6ZD2BX`I%6\T`"FJ*5<`*:H
MI5RJNJ5;I$H@(B5S(B"H[*ATLLZDI"X`IJBE7*JZIMNH=++.I*2R3;"CJ,^E
MSJK,("(E<R(@JKJXZJ[&+@`B)7,BI'>G4K"CI[FFJ"X`IJBE7*JZIMNH=++.
MI*2ROK"C("(E<R(N`*1WIJBE7*JZIEZT7[-=J7<N(+W0K:NW<[C\I$K`R[7X
MKG2RIRX`I'>FJ*5<JKJSQJ7WLUVI=[CJKL8N`*1WIJBE7*JZL\:E][-=J7>X
MZJ[&("5S+@"FJ*5<JKJG\[=S("(E<R(`I'>FJ*5<JKK"T+QG("5S`%-U9&%N
M("C$K*2F*0"Z2ZUN`*3II5@`I.FXJ`"TN`"DZ:58`*3II5@OI.FXJ`"DZ:58
M.B``I.FXJ`"DZ;BH.B``I%>\T`"DY+2I`%-U<FEN86UE("C$K*=1JVXI`+KO
MN+D`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0@**5VI<O`V<3U
M*0!3=V5D96X@*+?GJ.4I`%-W:71Z97)L86YD("BWYZ1H*0"F4*A"L$^__:1W
MIU*PHP"F4*A"IN:PRKC+N&T`MVJT3;:UI=BDI*JZNWFJ:[_YNWX`4WER:6%N
M($%R86(@4F5P=6)L:6,@*+'4IU&HR"D`N7"K0@"Y<*M"IK.MMP"Y<*M"`*:M
MIK.K^<3RN7"K0@!404(@I,"Y:J[FIJ'`R:[7`*KML^8`JNVNYJ2ZKF4`JNVN
MYJ2ZKF4`I7C&5P"E>,97`%1A:FEK:7-T86X@*+;PIDZTM:E:*0!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F("BI6JE\I:>HR"D`I=B\T#H`J]V_[*C&
MMK4`N7&XW+BYO5@`L\RJ\:1`I'"NR:JZM\6KUSH@`+?%J]<`M\6KUSH@`+?%
MJ]<\8G(@+SXH)7.PJB5S+R5SIT,E<RD@)F1E9SLE<P"GY*2CJ.R\RZI/("(E
M<R(N`+S+JD^ZWK)Z`*2ZKF4`K\*DY:9R`+GON_2DY:9R`+GON_2DY:9RL[NZ
MW0"L4+3!I7P`KO6DY2`H5$E3+38R,"D`5&AA:6QA;F0@**[UL.HI`$944""I
MM:;Y*&5X=&5N<VEO;BFU3*[$+@!(;W)D92]+;VQA8B"^XZ98I'6U>ZC#I;RD
MY+2I("(E<R(`24U34""L]K_]M4RJ:[-1JNRI;"X`36%I;G1E;F%N8V4@P_ZG
M3ZC#I;RFJ*5<N/RD2@"_[[:UM?BUH:5(P_:SK"["][9]I*0N`*=!JKJH=++.
MNMZR>JW[I;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&HSZ7.Q7:M
MK:ATLLXN`*FSKMB]=0#!<+6XN+F]6*6\J_RI=RRJQ:75J<ZF8KCJKL:N=Z2D
MI^2DHZCL+@"D=Z:HI5RJNK%.P7"UN*1(MW.\5Z;<LW&P5+_]I*0N`,7GP]*V
M;*7SP[&SN;O=K6ZFLZ1`K=.D=[C1MGVJNB!01U`@L,^V]"X`L'2X;;ASLM6J
MNL/1IT^XN;U8*$E$*:2CK$^EO*O\J7<LM$ZL3ZK%I=6ISJK,I*.F8KCJKL:N
M=Z2D+@"P=+AMN'.RU:6\J_RI=RX`N]VM;J1`K=.X9[E,I5NQ2ZJZNO2X]+-S
MM;(N`,#)KM<@)7,@P+.XTZ5=IW2D0*W3("5S(+-=J7<N`,#)KM<@)7,@P+.X
MTZ5=IW2D0*C'("5S(+-=J7<N`+5,JFN]QKMSJ.RFVZBMP,FNURX`IKG`R:[7
MI*2H4Z:SN.JNQBX`I4BD5:Q/(')F8S@R,B"V;*7SJKJJ[<!9+@"HK:7WP]&G
M3R`E<R"D=[-1IU*PHRX`I:JNV+UU`$=N=5!'(*1'I+C`R:JZN/2N?*6RMK>I
M=[AQIF(@0W)Y<'1?<&=P.CH@P_ZG3Z2D+@"G0;2_J?,@)7,@L4BUN2`E<R"D
M0*O*I42FKJRP("(E<R(@JKJK2*7SI'>S4;9]L=(N"J;]LV^HPZ2CK^"K3\/2
MN-.K2*7SJKJDNJYEI'>GN:7^LU&FK*7SI$BLW:>YJ<ZD1KC1+@"S<[6RJ.R]
M<[QGMFRE\ZVVK;&ITJC/I<ZJNJ97NMD`I;*VMZQ/I$"MT[S&IG(N`$AO<F1E
M7T-R>7!T7W-M:6UE.CH@P_ZG3RRELKO=K6ZFLR!O<&5N<W-L(+S2LM4N`*:Y
ML+ZF;B`B)7,B(+CJKL:F7:RPME>Y3+/,I&JDN;-<K<@LJ=*E2+5,JFNS4<!X
MIG,`I<ZE2,#+M?BFN;CJKL;#_JNL("@E<RD@JKJU>Z:AJ,.DHZ9SIF*I\ZAT
MLLZD5RX`I-ZM>J9RI;*VMZRPL^:D0*9RI+@N`*6JI6NNV+UU`*5KKMB]=0#$
MYJ;LI,"Y:J9RI;*VMZRPL^:D0*9RI+@N`*:YIOBJ0;ZY("(E<R(@I'>S4:=2
ML*,N`*:YIOBJ0;ZY("(E<R(@I'>S4<!XIG,N`"5S(*JZM?FE5;O=J$2D=[-1
MLKZPHRX`J_RI=ZJZL$^__:C#I*.F<Z9B+@"\R*9SP,FNUR(E<R*DHZ9SIF(N
M`*=!J=*_Z:1*JKJXZJ[&NU"U9:VQN.JNQJ2CLL4N`*17I%6NV+UU`*17KMB]
M=0"Q<:17I$"MTZA"QDJDIZOAI%>VQZJZN.JNQK_RI:(N`*17ML?`R:[7J,.E
MO+-1P'BF<RX`=V5A=&AE<BYC;VT@L,^V]+5,JFNHSZ7.+@"GY*2CJ.R\RZ:A
ML'2X;:78O_T@(B5S(BX`M4RE::7.JKJ_[[:U+@"U3*K^I?.E::J]L;6V?;'2
M+@"FN<3FINRDI*5=IW2DTZ9HJKJF<KS&+J=!I'>_Z:1*("5S(*W3IG*\QCNG
M0;_II$JJNJ9RO,:ELK:WI'"I\R`E<RX`MW.\5R`B)7,B(*CLJ'2RSCH@)7,@
MKLFU;Z7-I$"MT[#=PT0N`*;;J'2RSK)-L*,@(B5S(B"JNKCJKL:NR;5OI<VD
M0*W3L-W#1#H`IMNH=++.LKZPHR`B)7,B(*[)M6^ES:1`K=.PW<-$.@"G\[=S
M("(E<R(Z("5S(*[)M6^ES:1`K=.PW<-$`*17ML?`R:[7KLFU;Z7-I$"MT[#=
MPT0Z("5S(*6\LU&D5[;'+@"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E<R"D
M:J1PME>Y3*2YLURSS*1JK<@@*"5D(&)Y=&5S*2X`I%>VQ\#)KM>NR;5OI<VD
M0*W3L-W#1#H@MLBSH:3`JKH@)7,@P,FNU[-1I%>VQRX`P,NU^+9LI?.NR;5O
MI<VD0*W3O_F[?BX`MM>D2J:YLW&P5+_]N.JNQJ[)M6^ES;_YNWXN`+;7I$H@
M:4-A;&5N9&%R(+CJKL:NR;5OI<VD0*W3O_F[?BX`IF*S7:EWJNVSYJ2DM6^E
MS:1&I$"MT[_YNWXNIK.E::_@IT&_\KI\I$:ELK:WMO&\9ZJZQ.:F["X`L/6F
MYK-QL%2__:O\J7>E7*_@KLFU;Z7-I$"MT[_YNWXN(+W0M7FKX:9!N-6D0*:X
M+@"G\[=SP7"UN*1(N.JNQJ[)M6^ES:1&I$"MT[_YNWXN(+W0M7FKX:9!N-4N
M`*?SMW.P=+AMN'.RU:[)M6^ES:1&I$"MT[_YNWXN(+W0M7FKX:9!N-4N`*:Y
M($E-05`@IOBJ0;ZYJ,.EO*3DM*FK2*7SIUBDP*C)I5ROX"X`LV^F_*5'I*.L
M3Z6_O52JNB!R87(@P*/!6<#)KM<N`+-OIORE1Z2CK$^EO[U4JKH@>FEP(,"C
MP5G`R:[7+@"S;Z;\I4>DHZQ/I;^]5*JZJTBESJ5DN+F]6"X`IKG$YJ;LK$^E
MLKO=K6ZJNBX`IKG$YJ;LI+JN9:5UI+FS7+[CO,:\QJ9R+@"FN<3FINRDNJYE
MI76DN;-<O,:F<J3.JU^XN2X`IKG$YJ;LI+JN9:5UI+FS7*1+MFFF[+S&K<@N
M`*:YQ.:F[*2ZKF6ELK:WK+"S<KBYJ<ZJQ:75I,"Y:JJZO,:F<@"ELK:WK$^D
M0*W3O,:F<BX`IKG$YJ;LI+JN9:6RMK>E7:=TI$"RU:11I+NV::;LJKH@4D="
M(,-#IN*E3KU8+*C2IG`@)R,Q,C,T868G+@"S;ZW3JNVSYJ1WLU&S0K)ZN4PN
M`+-OK$\@)7,N`+-OK$\@2V]L86(@N'.RU:JZI$"MTZJKI?,N(+']P,NU^*:Y
MJJNE\[O=K6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZN7&D;+9LI?.S;L7I+KW0
ML-&FTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>D`LV^KRK9LI?.HPZM$I4BG0;I$
MI<ZJNJ9RI+BVL*;3K$^HSZ7.("@E<RD@KM&\9Z;3IJ@N`*:YO,:MR+/,I-:E
MLK:WK$\@,2X`IKFF^*I!OKFU3*IKN>\@>FEP(*3.(&=Z:7`@KN:FH<#)KM>V
M::;FN-'`H\%9`*:YJ'2RSJ78JV6L3["QI<ZJNJJLND$N`*6RMK>L3Z1`K=.\
MQJ9R+@"FN;7XM:&ELK:WK6ZET;_OMK6U^+6A*$]P=&EO;BFITJE)I7,`N7``
ML-W#1+!LPMP`KLFVH0"NR;:AJ_RK;@"NR;:AKN:FH0"NR;#/O^^^W`!4:6UO
M<BU,97-T90"\T,-$`+S0PT0@*'1O;VQT:7`I.@"FK*7SI$@`IG"J1ZUNO<:_
M[RR]T*9BPDF_[[?&N:NJNJ90KLFK]B!#;VYT<F]LP>0HK=.D2+EQN*,I(*G.
M($-O;6UA;F3!Y"C$JZI'N7&XHRDN`*2UI-$`2%1-3""M[*ELP,D`5&]G;R`H
MIFBM]"D`5&]K96QA=0"I^J31`%1O;F=A("BJ1J5;*0"SN[.A`+/,I%>\:*[8
MK%L@*%]T;W`I`*1DJ+VY1J3.IJNHJ:WT`*]UJ<ZPL`"L4+3!I$<`5'5N:7-I
M82`HK/"EIZ;HJ,@I`%1U<FME>2`HI&>FU:CD*0"D9Z;5J.2DY2`H25-/+3@X
M-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4
M=79A;'4@**1GI<N^?"D`O^FD2J=!JKJ_[[[<.B``M;6E?KUUJ_R\QCH@`+KT
MIWT`NO2G?3H`56=A;F1A("BO4:1ZN48I`%5K<F%I;F4@**]1ITK$]2D`M4RJ
M:Z9SJ/H@5D93(*78O_TN`+7YI56NR;5,JFN\5Z5;PT*E?JJZJ,^ESJK,N.JP
M5"X`M4RJ:Z?OQ=P@5D93(,#)KM<@(B5S(B"JNL5VK:TN`+5,JFO%W*?S(%9&
M4R#`R:[7("5S+R5S(*JZQ7:MK2X`M4RJ:\7<I_.LL"`E<RX`M4RJ:\#+K&3`
MR:[7I&JD<"`B)7,B+@"U3*IKP,NL9,#)KM>D:J1P("(E<R\E<R(N`+5,JFNS
M<[6R(%-13""F^*I!OKDN`+5,JFNHSZ7.(%-33""S<[6R+@"U3*IKO<:[<R!6
M1E,@P,FNURX`M4RJ:ZO8I=\@5D93(*78O_T@(B5S(BX`M4RJ:ZO8I=\@5D93
M(*78O_TN`+5,JFNKV*7?(%9&4R#`R:[7+@"U3*IKJ]BEWR!61E,@I=B__2`B
M)7,B+@"U3*IKJ]BEWZK%I=6JNB!61E,@P,FNURX`M4RJ:[%.N.JNQKC1P*/!
M62X`M4RJ:Z=2L*,@(B5S(BRFN:78O_VHPZM$JL6EU2X`M4RJ:Z=2L*,@(B5S
M(CH@)7,`M4RJ:Z=2L*,@)7,LIKFEV+_]J,.K1*K%I=4`M4RJ:[N\L&JG4K"C
MI=B__2X`M4RJ:Z=2L*,@5D93(*78O_TN`+5,JFNG4K"C(%9&4R"EV+_].B`E
M<RX`M4RJ:Z=2L*,@5D93(,#)KM<@(B5S(BX`M4RJ:Z=2L*,@5D93(,#)KM<N
M`+5,JFNG4K"C(%9&4R"EV+_]("(E<R(N`+5,JFN[O+!JIU*PHR!61E,Z("5S
M+@"U3*IKIU#"7Z78JV6JNJ78O_TN`+5,JFNXT;9]OLS#TK+3N&``M4RJ:[C\
MI$HE<ZJZJ7>X<2X`M4RJ:[=HLKX@5D93(,#)KM<N`+5,JFNV?;'2(%9&4R#`
MR:[7("(E<R(N`+5,JFN\9Z1*(%9&4R#`R:[7+@"U3*IKMGVQTB!61E,@P,FN
MURX`M4RJ:[9]L=+`H\%9P,DN`+5,JFO%JJCZ(%9&4R#`R:[7("AF:6QE<VEZ
M92@I(&9A:6QE9"DN`+5,JFO%JJCZ(%9&4R#`R:[7("AG971&:6QE4VEZ92@I
M(&9A:6QE9"DN`+5,JFO%JJCZP,FNUSH@`+5,JFO%JJCZ('9F<W)O;W0@I=B_
M_2X`M4RJ:Z?SIE<@)7,@K+`@)7,Z(*9=K+"EV+S0JTBE\Z=8I'>F<Z9B`+5,
MJFO%W*?S(%9&4R"EV+_]JKJF5[K9+@"U3*IKLKZPHR!61E,@I=B__3H@)7,N
M`+5,JFO%W*?S(%9&4R#`R:[7("(E<R(@JKJF5[K9+@"U3*IKQ=RG\R!61E,@
MP,FNUR`E<R\E<R"JNJ97NMDN`+5,JFO%W*?S(%9&4R#`R:[7JKJF5[K9+@"U
M3*IKL/6FYB`G;6MI<V]F<R<N`+5,JFO"X+2K(%=O<F0@I.6E\P"U3*IKO&>D
M2B!61E,@(B5S(B#`R:[7+@"U3*IKO&>D2B!61E,@P,FNUR`H8V]P>2@I(&9A
M:6QE9"DN`+5,JFN\9Z1*(%9&4R#`R:[7N.JNQBX`M4RJ:[QGI$H@5D93(,#)
MKM<L(+K/NM"P=,-"I'>ZH2X`J;.]=0"H^J[XI_.G[P"T7ZWL`*;XJD&^N;-S
MM;*NR;5OI<VEO+EWM,&JNJ9>P+,Z(`"U;Z7-I;RY=[3!JKJF7L"S+*71IOBJ
M0;ZY.B``I;RDP,/^`+A5L.J]6"`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A
M=&5S("BJ_*G4IT+!<*98I&JDO;#J*0!5;FET960@2VEN9V1O;2`HK5ZPZBD`
M56YI=&5D(%-T871E<R`HK/RPZBD`56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S`+/FINP`I;RJOJJZ`*6\JKZJNB!!4$D@L%2NI[USN+D@
M*$%022!-97-S86=E($E$*2X`I;RJOJJZJ\BDX;!4KJ>]<[BY("A!4$D@365S
M<V%G92!)1"DN`*6\JKZJNJ;LN&VXZK!4+@"EO*J^JKJHSZ7.JLRF5[K9J<ZQ
M2[U8+@"DI,)?I=BK9:2XI?.JNK-SM;(`I;RI4J97`*9=IG>E_L55O'NDHZ2Y
MLUREO+'"Q7:JNK5[IJ&P]:;FL,6D52^]QKMS+[9+I%<N(,))O^^]5*EWI4C`
MR[7X(&UO>FEL;&$N;W)G(*G2M*.HT:JZK-O#]J?>LTZDY:7S+,7]IT&E::5(
MN-&PHZ:YI$"MK:CNJ,.FVZ;FMGVI\;5[IJ&F<ZCZL,6V2\.O+@"H^J[XPT.F
MX@"EO*3DM*FJNK#&P,FF5P#%W*?S`*?SMW,@)7,`I_.W<ZC/I<ZJS``B)7,B
MI'>G\[=S+@"G\[=SM7NFH:1WIU*PHRX`I%>VQP"D=Z17ML>ITJ:SP+.ESK5[
MIJ&JNK-=J7?`R:CLIOBJ0;ZY+@"D:KQGJ=2D0KS&IG(`I&J\9\.YL*B\QJ9R
M`%5R=6=U87D@**]1J=2F8RD`J,^ESJ78JV6JNCH@)7,`J,^ESB!34TP`IG"J
M1Z=!JKJHSZ7.JLRF5[K9+[%+O5B[4"!)35-0(*;XJD&^N:2CIE`LI6FF8J:Y
MLUVI=RX`J,^ESJK,`*C/I<ZJS"`E<R"EO+-QN4P@)7,@JKJQPL5VQ>?#TBX`
MJ,^ESJK,NMZR>@"HSZ7.JLR_[[:U`*C/I<ZJS+7YI54`IKFON*5XJKJHSZ7.
MJLRU^:55J'2RSJ1WL+&ESBX`I^2DHZCLJ,^ESJK,L6*XN0"HSZ7.JLRF5[K9
M`*C/I<ZJS*97NMD@(B5S(B"D=Z9SIF(N`*C/I<ZJS*97NMDZ`*C/I<ZJS#H@
M`*ATLLZDI*JZJ,^ESJK,.@!5>F)E:VES=&%N("BO4:_WIT^G2BD`5D93(*78
MO_VHPZ2CIG.F8BX`L+*TP0"D=Z?DJ.RFLZ[$JKJF8<)).B``IK.NQ*G*`*5(
MI,#$P:RPL^:F["BQ<;)[IF*P7[KB*0"MR`"_[ZCZK<BFVP!686YU871U("BE
MRZ6CJORYSRD`Q=RDQ@!696YE>G5E;&$@**EEI+JWYZG4*0#%Y\/2I:*QT2`M
M(*:YMFRE\Z5IK^"D=[Y$I$B^U:;;OWFG[RX`JJFENP"JJ:6[L;&H[@"KJZJ]
MN>^[]`"KJZJ]N=2E4@"KJZJ].@"K1+%@L*H`5FEE="!.86T@*+96JVXI`+96
MJVZDY2`H5DE30TE)*0#`R[7X("5S`*9BMW.U^+6AMGVQT@"E2"`E<R#`R[7X
M`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H("BM7L3=NONHRKASKG$I`%9I<F=I
M;B!)<VQA;F1S+"!5+E,N("BL_,3=NONHRKASKG$I`*_@J*.KUP"OX*BCJ]<Z
M(`"X<:1JIU&E\;QWK;>Y<:M(I+VE<;-ZN4P@4TU44`#$M:=I`,2UIVDA(2$@
ML7$@)7,@I.*PRK*^L*.U>Z:A+@!724X@N&>ET2!(5%10`%=A;&QI<R!A;F0@
M1G5T=6YA`,2UIVD`K%"TP:14`*31KO"Y=[3Z`*[PMDBXZJ[&M*.HT0!W96%T
M:&5R+F-O;2"Z]*^X`+KTK[@`NO2ON`"H0[9G`,5WJN\`Q7>J[ZCL("5S`,5W
MJN\L("5S`*;HO-H@*$E33RTX.#4Y+3$I`*;HO-H@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R82`HINB\NZNBJ=0I`+5NI$JKX<"SN-.E_<7CI=P@)7,@
MK?ZD0*W3P+.ESK5[IJ$_`,3FINRJNJ3`N6JF<J2X/P"DWJUZJKJK9;AMIG*D
MN#\`5VAE<F5I<R!!=7-T<F%L:6$@IF&YSP"M_JW3I.NLVP"Z]*VVO7._Z+ZY
MJKJTH:7S*'!L=6=I;G,IL=*PRK&QJ.XN`+QEJ]<`I4@@0U-3(*RPL^:F[*JZ
MO&6KUP"EJL/D)7.E7*_@JNVJNKQEJ]<HI%6FN+5NI$JI;*7-KL0I.@"J[:[F
MO&6KUP"\9:O7L^:F[`"\9:O7.@"VL,7IL]"G0`"MMP"FK::SK;<`K;>S="BX
M8"D`K;>S=#H`K;>S=#H@`+2\O'H`M,&KW<*GJJL`I'6G0`"_[*2]J\>F8:=]
M`+_LI+VKQ[EQN-P`LL0E9*;FJKK$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E
M9*W3Q.:F["RE=:?DJ.PE9*W3Q.:F["X`Q.:F[+S&I=BDHZ6_O50N(,"SN-.M
M;J:S)62MT\3FINPLI76GY*CL)62MT\3FINPN`%@U,#EV,R"IM:;YJO?&7[MY
MJFL`6#4P.78S(*5$IJZTP*5.IE>ZV0!8-3`Y=C,@I42FKJKWQE_#T:=/JLP`
M6#4P.78S(+#&P,FF5P"F?@"F?@!986AO;R`A(*9AN<\`J$.F?@!996UE;B`H
MN*VJ^2D`K$\`K$^JNBRGVJ90MTX`IT&EV*MEJ,^ESJ_"I.6F<KUSO&>\TJ:A
M+B"HSZ7.(%L\/ET@J_:V<Z5II,&TJZRPNO2MMKUSO&>\TJ:A+@"DHZ2YLURG
M0:O8I=\E9*5(I%>JNK#/MO0N`*=!I;RS4;'"Q78N`*=!JKJE_J97I*2DHZ5I
MIK,@)UPG(+-OO,NJNJ9RI+@N(`"G0:C#I;R_Z:1*I$"MTZ:SKL2JNKEQI&RV
M;*7SINRG?2X`IT&HPZ6\I=&VUZ1*JKK`R:[7I*2Y[ZQ-I?2F\\3FINRH["`E
M<P"G0:1WN&>U;J58+@"]T+_II$JD0*W3IK.NQ*JZN7&XW+BYO5@LL.J[VKEQ
MN-RXN;U8MLBE=:2YLUR\QJ9RN+F]6"RHP[7XL:&J<*5IJ?.K9:VQID&E6Z1`
MK=,@)RLG+@"G0:6RMK>_Z:1*I$"MTZ:SKL2JNJW(+@"G0:6RMK>E_;-7N;JF
M;K[PJJRXZJ[&*$1A=&%4<F5E*:;XJD&ZW:1^K^#$?L3RJ,^ESK=SI<ZDX;7Y
MI56J0;#(+@"G0:6RMK>E_;-7N;JD0*W3M>K`P,#)KM>H=++.*%9&4RFF^*I!
MNMTN`+W0M'FM>K#=PT2A0:9BIT&VQ[!EL-W#1+/XIVFDIZME+@"G0:6RMK>_
MZ:1*IKFS<[6RJ=*K_*96JKJZ]*=]`+W0J_RI=ZUNIU*PHZJZIOBJ0;ZY+@"]
MT*O\J7>M;K)-L*.JNJC/I<ZJS"X`O="K_*EWK6ZROK"CJKJHSZ7.JLPN`+W0
MJ_RI=ZUNMW.\5ZJZJ,^ESJK,+@"]T*O\J7>M;J?SMW.JNJC/I<ZJS"X`O="K
M_*EWK6ZP]:;FJKJG0*7.+@"G0:6RMK>_Z:1*MW.DP,/^JKJF5[K9+@"G0:6R
MMK>THZC1I$"MT[AQI&JG4;G2I+JJNKEQN-RXN;U8`*=!JKH@)7,@MWRTP:1W
MN4RNR2Z]T*VKMW.U;J1*+@"G0:JZN7&D;+9LI?.F[:=]`*=!JKJQ2*7SI$BY
M<:1LMFRE\Z;MIWTZ`*=!JKJXZK!4`*;;L7&G0:JZ("5S(+=\M,&V?:ELI4BH
MTZ=!JKJZ]+O:NO2X]*;LIWVD=\7<I_,N(*RPJT_%0*=!JKJF=Z7^L%^HHZ%!
MIT&ELK:WK:NW<[5NI$HN`*=!JKJF5[K9`*=!JKK%Y\/2IOBJ0;K=J,.DHZ3D
MM*FW<[Q7J,^ESJK,+B"F<*I'IT&GQK'FNMZR>JC/I<ZJS+%BN+DLIT&ELK:W
MI72_[ZCDI4RJNL7GP]*F^*I!NMTN`*=!JKK%Y\/2NMVHPZ6\I.2TJ:9#I5BH
MSZ7.JLRISKC3I5ROX*1WLU'#]K.L+@"FV[%QIT&JNB`E<R"W?+3!MGVI;*5(
MJ-.G0:JZPG/$_;ZYIORE1Z1WQ=RG\RX@K+"K3\5`IT&JNJ9WI?ZP7ZBCH4&G
M0:6RMK>MJ[=SM6ZD2BX`IT&JNL)SQ/V^N:C#I;RDY+2ILV^MTZ5<K^`N`*=!
MJKK"<\3]OKFHPZ6\I.2TJ:9#IDR_[[:U+KW0J_8@0U123"]#;VUM86YD("L@
M4""F0Z9,+@"G0:78JV6ITK-=J7>JNJ[)L,\Z`+O5I%6Y=[-=JKJHK:7WP]&G
M3Z1WQ=RG\RX`N]6D5;EWLUVJNJBMI??#T:=/.@"G0:JZI?ZF5SH`IT&JNK5N
MI$JD=ZCLM,$N`*=!IF(@)7,@I*2JNK=SL4N]6*Q/.B`E<P"G0:9BM6ZD2K3!
MMJ&JNK_OMK6D=[-1I_.W<RX`IT&JNK_OMK6D=Z?SMW,N`*=!JKJQ2[U8I'>M
MJ[=SLUVI=P"Q2[U8I'>S4:VKMW.S7:EW++=SJKJQ2[U8I'>S>KE,N7&D;+9L
MI?.Q2+5OO="E2+C3L4N]6+5NI$HN`*=!JKJQ2[U8I'>H[+3!+@"G0:JZN[>Z
MW:;XJD&^N3H`675G;W-L879I82`HJVZTM:G4I-(I`%IA:7)E("C"Q*7L*0!:
M86UB:6$@**E\I/&HR"D`6FEM8F%B=V4@**BOI-JKPBD`6\'TPL.DWJUZ70!;
ML-W#1*3/K$U=`%O%XZ7<I-ZM>B`M`%O%XZ7<I-ZM>B`M("5S(*;F70!;INRI
M\Z;F("5S(*9`("5S(*;F70"ZWK)Z7T$`J5*E3Z9#7T,`OO"JK+CJKL9?1`"G
M4K"CID-?1`"X<[+57T<`NZ&I^E](`+QVN;.DNJYE7TDN+BX`M6ZD2E],`+5N
MI5A?3`"MUZ?OLW.ULE]-+BXN`+_OMK5?3P#%=JVM7U``LKZPH[GOLW.ULE]2
M+BXN`+-=J7=?4P"J[:[FI+JN95]4+BXN`*C/I<ZJS%]5`+-QL%2__0"FYJC&
MON0`M4RJ:ZO8I=^_Z:58P,FNUP"U3*IKMGVQTK_II$H`J_:FN0"Q2Z5/ID.[
M>:IKO_F[?@"S7:EWO_F[?@"_\J6BK:NM;JJZJ'2RSL#)KM<`N.JNQJ[FIJ&_
M^;M^`*?DI*.H[+!/O_T`P,FNUP"Q<2`E<R`H)7,I(*GS("5S("5S`+!]K;<`
MKLDZ`*[)`*6\JKZJNK9LI?.E1+[WIE>ZV0"EWZ=9`*J]L;7%XZ7<J?.ENZ3E
ML,\`O^FD2B^_Z:58O_F[?@"DNK.ALV[%Z;_YNWX`IN9=`*3``*97NMD`J7RE
MO+GJIT`N`*E\I;RYZJ=`+@"SQJ?1O_T`ILJDP*3Q`*9SJ/J^1*G:`+FSK\``
MLW&K2*CSJ7>[M[K=O_F[?@"D5Z3)`+5,I6FESJJZJD&PR`#%XZ7<KG2RIP!S
M;7,R96UA:6P@N&>ET2!(5%10`*SM`,.MJ7<`J'2RSK_YNWX`J]V_[,.O`+S(
MKLFIRJJZI:*QT0"F0::XO^FD2J=!JKJQ2[U8I4B]5+M[M4R[?@"^XZ98`*6\
MJ5*F5P"HSZ7.JLR_[[[<`'9#87)D`*Q0M,$Z`'=E871H97(N8V]M(+KTK[@`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z
M:%]45R]H96QP+GAM;```````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(U-#``,3`U,34T,S$P-C(`,#(P,S4S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_>&UL('9E<G-I;VX](C$N
M,"(@96YC;V1I;F<](D))1S4B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L
M92]Z:%]45R]H96QP+GAM;"QV(#$N,RXQ,"XQ(#(P,#8O,#(O,3`@,30Z,#$Z
M,C,@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB
M(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B('-T871E
M/2)U<'1O9&%T92(^"CQT:71L93ZD2J1FK;:ML3PO=&ET;&4^"B`\<&%R83X*
M(""S;ZW3K;:ML;2CJ-&ITJ:SP_:I\Z=!JKJMJ\))NDNM;KCJL%2A0ZC2IG"A
M0:6FI6FE2,7CI=RE6*9BIT&JNJ:LI?.]8Z2DI=BK9::SM%BKRK=SMFRE\Z%#
MIN:HQK[DI*2G6;%.J-.H[*JZJ,:QH:%!I4Z_[,.OI*2JNJ:SK?ZHQZO=O^RH
MQK:UH4&W<[M$JD&PR*JZL\RW<Z[XKJ>UI;6EH4.FT[-OJ,>Z2ZUNIE"NR:1=
MI5VG=*1&I]:QMJ5<K^"A0<2TIG"V;*7SO&>G0*%!J]BEW[=SJKJFYJC&ON2H
MQJ7SM:6UI:%#"B`\+W!A<F$^"B`\<&%R83X*(*;3LV^HQ[I+K6ZJNJ2ZKF6E
M::5(Q?VG0;AGI=&JJ:VQL'2X;:OVMG.FVZ;FIG>QQJ%#J-*F<*%!IT&E::5(
MO^^^W*UNI5ND2JW^I$"HQ[:UI=BH[*1*I&:MMJVQI*2HP['&ID.HY+:VI\>A
M0PH@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B(&UD
M-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E/2)U
M<'1O9&%T92(^"CQT:71L93[`LZ7.M7NFH;[)Q/VF0SPO=&ET;&4^"B`\<&%R
M83X*(""F8JVVK;&SS*6JP^2JNJ1`L<:YSZ[7NMFLL,"SI<ZU>Z:AOLG$_:9#
MH4/"2;_OI%>ML:JZI?2D0*W3I'"YSZ7<L4ZE:;NTJ?:GUK-TJKJDP;2KJ?.D
MHZ90JKK`LZ7.M7NFH:%#"B`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD
M-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B/@H@("`@/'1I
M=&QE/K"^IFZS7:EW.B"Z^\5`.B"P]:;FNOO%0#PO=&ET;&4^"B`@("`\<&%R
M83X*("`@(*3$O^^FN:1`MK6EV*%!IG"J1Z=!I\:QYJ9BM6ZD2JJZIE"NR;#U
MIN:Z^\5`I'6G0*%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@
M:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T
M92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@
M("`\=&ET;&4^L+ZF;K-=J7<Z(+K[Q4`Z(+U4NWNP]:;FNOO%0#PO=&ET;&4^
M"B`@("`\<&%R83X*("`@(*3$O^^FN:1`MK6EV*%!IG"J1Z=!I\:QYJ9BL/6F
MYKK[Q4"D=:=`JV6[W:9!IKB\>*A$IT&JNJ90MTZA0Z=?JVBITJ:SNOO%0*1U
MIT"Q3JGSM6ZD2JOAIMNPRK#UIN:A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^
M"CPO:&5L<#X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+RYH=&%C8V5S<P``````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`Q-@`Q,#4Q-30S,3`V
M,@`P,3<T-#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1&5N>2!F<F]M(&%L;`H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!O+P``````````````````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C,`,#$U,#,P`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O9F%?25(N<&\`````````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,3`P-3,P,P`Q,#4Q
M-30S,3`V,@`P,38S-#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!(;W)D92!097)S:6%N('1R86YS;&%T:6]N<RX*(R!4
M:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS
M92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R`*(R!#;W!Y<FEG:'0@*$,I(#(P
M,#0@2&EG:"!#;VYC:6P@;V8@26YF;W)M871I8W,@*'=W=RYS:&-I+FER*0HC
M(%!R;W9I9&5D(&)Y("!!;6ER:V%B:7(@365T86YE='=O<FMI;F<@3'1D+"`R
M,#`T(#QP97)S:6%N+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*(R!-;VAS
M96X@3F%D97(M0F%D<B`@("`@("`\;F%D97)I0&UE=&%N971W;W)K:6YG+F-O
M;3X*(R!#:&%C:V%M96@@36]R=&5Z86YI82`@("`\;6]R=&5Z86YI84!M971A
M;F5T=V]R:VEN9RYC;VT^"B,@4V%L;6%N($YI:W-E9F%T("`@("`@("`@/&YI
M:W-E9F%T0&UE=&%N971W;W)K:6YG+F-O;3X*(R!(86UE9"!':&5Y8FD@("`@
M("`@("`@("`\9VAE>6)I0&UE=&%N971W;W)K:6YG+F-O;3X*(R!686AI9"!'
M:&%F87)P;W5R("`@("`@("`\9VAA9F%R<&]U<D!M971A;F5T=V]R:VEN9RYC
M;VT^"B,@6F%H<F$@06AM861I("`@("`@("`@("`@/&%H;6%D:4!M971A;F5T
M=V]R:VEN9RYC;VT^"B,@"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)
M9"U697)S:6]N.B!(;W)D92`S(%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#4M,#<M,#@@,34Z,C<K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.D%M:7)K
M86)I<B!-971A;F5T=V]R:VEN9R!L=&0N(#QP97)S:6%N+6AO<F1E0&UE=&%N
M971W;W)K:6YG+B(*(F-O;3Y<;B(*(DQA;F=U86=E+51E86TZ(%!E<G-I86X@
M/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U55$8M.%QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*-BQV8C8LB#9@MBHV80@)7,I
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(H
MVJG9A-N,V*\@V*_8L]BJV+'8L]N,("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D
M87ES*2(*;7-G<W1R("(HV*_8L2`E<R#8L=F(V+(I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B
M("C8I]F%V+'9B-BR*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`HV8'8L=BOV*<I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T
M97)D87DI(@IM<V=S='(@(B`HV*_;C-BQV8C8LBDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM
M<V=I9"`B(&%T("(*;7-G<W1R("(@V*_8L2`B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`BVXS:J2#8M-BG
MV*[9AR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V
M86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@V*?9AMBJV*[8I]BH(-F%V+G8
MJMBHV+';C"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB
M"FUS9W-T<B`B)R5S)R#8K]BQ(-BQV*S;C-BSV*K8L2#9A]F(V+'8KR#9OMN,
MVJG8L=BHV8;8K]N,(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]4
M<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(G)7,G
M(-BGV*S8L=BG(-JIV8;9AMBOV8<@V*_8L=BNV*H@V;[;C-BOV*<@V8;8M-BO
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@V*C9AR#:K]BQV8C9A^*`C-F'V*?;C"#8L]BG
MV878I]F&V8<@V*?8MMBGV8'9AR#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B7"(E<UPB(-BHV8<@V+/8I]F%V*?9AMF'(-F%V*S9B-BRXH",V8?8IR#8
MI]BVV*?9@=F'(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]G<F]U<',N<&AP.C4T
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E
M<UPB(-BGVXS8K-BGV*\@V8;8M-BOV8<@V*C9B-BO.B`E<RXB"@HC(`HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T
M<B`B)2XR9DU"(-BGV+/8JMF!V*?8K]F'(-BTV*_9AR#8I]BR("4N,F9-0B#9
MA=BLV*?8LB`H)2XR9DU"*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM
M<V=S='(@(B5D("5S(-F(("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP
M:7)E<RXB"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8M-F%V*<@)60@V+'9B-BR
M(-BOVXS:K]BQ(-F%V+G8JMBHV+$@V*?8L]BJ+B(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(MF^VXS8M,*MV*C;C-F&VXP@
M)60MV+'9B-BRV8<B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T
M<B`B)7,@+2#8JMF(V*S9AR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R
M:6YT(@IM<V=S='(@(MBGV*O8L2#8I]F&VJ_8M-BJ("5S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!+0B(*;7-G<W1R("+:J=N,V839B-BHV*?;C-BJ("5S(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B)7,@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,("T@V*K8
MH]N,VXS8KR(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M971U<"(*;7-G<W1R("(@V+'8I]F')B-X,C`P8SO8I]F&V*_8I]BRVXP@)7,@
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(-BKV*C8
MJB#9AMBGV84B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT
M(@IM<V=S='(@(MBTV+'9B-BW(-BJV8C8I]F!V8(@)7,B"@HC(`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@V*?8LB#9@MBH
MV80@V879B-BLV8C8KR#8I]BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M="`E<R`E<R(*;7-G<W1R("(E<R#8K]BQ("5S("5S(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB
M"FUS9W-T<B`B(@HB)7,@V*+9A=BGV*_9AR#8I]BLV+'8I]N,(-BYV879A-N,
MV*?8JB#9AMJOV8?8K]BGV+';C"#8I]F&V*K8KMBGV*@@V+38K]F'(-BGV+/8
MJBX@V*S8N=BHV8<@V8?8L2#8N=F%V83;C-BGV*K;C"#8L=BG(-JIV8<@V8?9
MA2#8I]JIV8;9B-F&("(*(MF%VXSB@(S8KMF(V*?9A]N,V*\@V*?8K-BQV*<@
MVJG9AMN,V*\@V+G9A-BGV878JB#8J-BRV8;;C-BO(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I
M<R!R97%U:7)E9"(*;7-G<W1R("(E<R#9A=F(V+'8KR#9AMN,V*?8LB#8I]BS
MV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(-BOV8+;C-F"
MV8<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T
M<B`B)7,@V;[;C-BOV*<@V8;8M-BO(@H*(R`*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R("(E<R#8J-F'("5S(-BGV+(@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("+:J=BJV*?8J-J&V8?9E"#8
MHMBOV+'8LR`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B
MV*K9@MF(VXS9A2`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R("(E<R=S($YO=&5P860B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T
M(@IM<V=S='(@(MF!V8?8L=BSV*H@V8C8N-BGVXS9@2`E<R(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S
M86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W
M87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM
M<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("+8C"#8J-BGV*\B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS
M9W-T<B`BV(P@V*C8I]BO("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S
M('1O("5S(@IM<V=S='(@(MB,(-F%V*K8NMN,VXS8L2#8I]BR("5S(-BHV8<@
M)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B#8I]F&V*K8KMBGV*@@(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA
M="(*;7-G<W1R("+9@MBGV838J"#;L=NR(-BSV*?8N=BJVXPB"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S
M='(@(MF"V*?9A-BH(-NRV[0@V+/8I]BYV*K;C"(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("+;LMNT
M(-BSV*?8N=BJV8<B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y
M"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`BV+79@=BMV8<@
MV8+8J-F$VXPB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B
M02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K
M+B(*;7-G<W1R("+;C-JI(-F^V+38JMN,V*C8I]F&(-BOV*?8K]JOV*?9AB#8
MJ-BQV*?;C"#8I]N,V88@V*C9A-BGVJD@V879B-BQV*\@V8;;C-BGV+(@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@
M(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(MN,VJD@V*[8
MM]BGVXP@V*S8K]N,(-BQV*X@V*_8I]BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("+;C-JI(-JIV83;C-BO(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,(-BQ
MV878LMBHV8;8K]N,(-N,VJD@V;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8
MLB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("+;C-JI(-JIV83;C-BO
M(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,(-BHV*?8LMBHVXS9AMN,(-N,VJD@
MV;[;C-BZV*?9A2#8I]F%V+;8I]BA(-BTV*_9AR#9A=F(V+'8KR#9AMN,V*?8
MLB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@HBVXS:J2#:J=F$VXS8KR#8N=F%V8C9
MA=N,V(P@VXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%!'4"#9B"#;C-JI(-BY
MV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BQV878LMJOV+38I]N,VXP@VXS:
MJ2#9OMN,V+K8I]F%(-F%V8C8L=BO("(*(MF&VXS8I]BR(-BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B+;C-JI(-JIV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;
MC-BO(-BNV+79B-BUVXP@4$=0(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@
MV*C8L=BGVXP@V*?9A=BVV*?8H2#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@
M(@HBV8;;C-BGV+(@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B+;C-JI
M(-JIV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BU
MVXP@4R]-24U%(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@
MV+'9A=BRVJ_8M-BGVXS;C"#9OMN,V+K8I]F%(-F%V8C8L=BO("(*(MF&VXS8
MI]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HBVXS:J2#:J=F$VXS8KR#8
MN=F%V8C9A=N,V(P@VXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%,O34E-12#9
MB"#;C-JI(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BGV878MMBGV*$@
MVXS:J2#9OMN,V+K8I]F%(-F%V8C8L=BO("(*(MF&VXS8I]BR(-BGV+/8JB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED
M(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(MN,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!3
M+TU)344@V*C8L=BGVXP@V+'9A=BRV*C9AMBOVXP@V;[;C-BZV*?9A2#9A=F(
MV+'8KR#9AMN,V*?8LB#8I]BSV*HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B
M"FUS9W-T<B`BV*?8J-BQV8?8IR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S
M='(@(MBHV*?8L=BGV88@V+/8J-JI(-BUV*C8K=JOV*?9A]N,(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-
M(%)A:6XB"FUS9W-T<B`BV*C8I]BQV*?9AB#8M=BHV*W:K]BGV8?;C"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED
M(")!32!3:&]W97)S(@IM<V=S='(@(MBQVJ_8J-BGV+$@V+78J-BMVJ_8I]F'
MVXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(MBJVJ_8L=JO(-BU
MV*C8K=JOV*?9A]N,(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*
M;7-G:60@(D%-+U!-(@IM<V=S='(@(MBUV*C8K2_8N=BUV+$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G
M:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O
M<B(*;7-G<W1R("+8K]BQV*C8I]BQV8<@V*?;C-F&(-F(VXS8L=BGV+/8JMBG
MV+$B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O
M=70N+BXB"FUS9W-T<B`BV*_8L=BHV*?8L=F'+BXN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T
M=&]M(@IM<V=S='(@(MF^V*?;C-N,V88@V878M]F$V8(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`BV8C8L]BW(-F%V+?9A-F"(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+8I]N,V*S8I]BO(-BT
MV*?8KMF'(%9&4R#9A=BLV8C8LB#8K]BSV*K8L=BSVXP@V8;8K]BGV+'8KR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(MBGVXS8
MK-BGV*\@V;[8L=F(V8;8K]F'(%9&4R#9A=BLV8C8LB#8K]BSV*K8L=BSVXP@
MV8;8K]BGV+'8KR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED
M(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ
M(-BMV+/8I]BH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED
M(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*W8
ML]BGV*@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("+8
MK=BSV*?8J"#9A=BSV*_9B-BO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("+8K=BSV*?8J-BO
MV*?8L=N,(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B
MV*?8MMBGV8'9AR#:J=BQV*_9AB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#:K]BQV8C9AR#9@=BQV+G;
MC"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E
M<FUI<W-I;VXB"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BLV8C8
MLB#9@=BQV+G;C.*`C"(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU
M"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`BV*?;C-F&V*S8IR#8I]BVV*?9
M@=F'(-JIV88Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O
M=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`BV*?8
MMMBGV8'9AR#:J=BQV*_9AB#:K]BQV8C9AR#8K-BOVXS8KR(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S
M='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@V878K-F(V+(@V*S8K]N,V*\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<
M(B5S7"(B"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-JOV+'9
MB-F'(-F!V+'8N=N,(-BHV8<@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(MBGV+;8I]F!V8<@
MVJG8L=BOV88@VXS:J2#9A=BLV8C8LB#9@=BQV+G;C"#8J-F'(%PB)7-<(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB
M"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-JIV*?8L=BHV+$@
MV*S8K]N,V*\Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("+8I]BVV*?9
M@=F'(-JIV+'8K]F&(-BSV*K9B-F&(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@V*?8N=BVV*?;C"#8K-BOVXS8KR(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P
M86ER(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@V++9B-BL(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T
M<B`B(-BGV+;8I]F!V8<@VJG8L=BOV88@VJ_8LMN,V8;:K]BGV88@)7,@V*C8
MN=F&V8C8I]F&(-F&V8C8I]BQ(-BLV*?9AMBHVXP@V879B-BRVXS9A-BG(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS
M9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("+8I]BVV*?9@=F'
M(-JIV+'8K]F&(-BHV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,Z(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED
M(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(MBGV+;8I]F!V8<@
MVJG8L=BOV88@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#9A=F&(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@
M(MBGV+;8I]F!V8<@V8/8L=BOV88@VJG8I]BQV*C8L2(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D
M;6EN+W5S97(N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G
M<W1R("(B"B(G)7,G(-BHV8<@V+/8I]F%V*?9AMF'(-BGV+;8I]F!V8<@V+38
MK]B,(-BGV878IR#9AMF%VXSB@(S8JMF(V*?9AB#8I]BWV838I]BYV*?8JB#8
MK]N,VJ_8L2#8I]F!V*K8JMBGV*T@V*W8L]BGV*@@V+'8IR#8I]BVV*?9@=F'
M(-JIV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z('-I9VYU<"YP:'`Z-#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B<E<R<@V*C9AR#8L]BGV878
MI]F&V8<@V*?8MMBGV8'9AR#8M-BO+B#8I]JIV8;9B-F&(-BTV878IR#9A=N,
MXH",V*K9B-BGV8;;C-BO(-F(V*?8L=BO(-BTV8C;C-BO(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#:
MJ=BGV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(MBBV*_8
ML=BS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B
M061D<F5S<R!";V]K(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4(-BBV*_8L=BS
M("(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<R(*;7-G<W1R("+8L]BQV;[8L=BSV*H@V+/8I]F%V*?9
MAMF'+2#8JMBYVXS;C-F&(-F%V*S9B-BRV8?8I]N,(-JIV*?8L=BHV+'8I]F&
M(-BOVXS:K]BQ(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(MBSV+'9OMBQV+/8JMN,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(MBJV*C9A-N,V+K8I]BJ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`BV+/8I]BRV878I]F&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I
M9"`B06QB86YI82(*;7-G<W1R("+9A=BYV*?8K]F$(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC
M+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R("+9A=BYV*?8K]F$(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM
M<V=I9"`B06QI87,B"FUS9W-T<B`BV878N=BGV*_9A"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@
M(D%L:6=N(@IM<V=S='(@(MBJV+'8I]BR(-JIV+'8K]F&(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI
M9VYM96YT.B(*;7-G<W1R("+8JMBQV*?8LCHB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("+9A]F%V8<B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R
M<R(*;7-G<W1R("+8JMF%V*?9A=N,(-JIV*?8L=BHV+'8I]F&(-BJV*/;C-N,
MV*\@V+79A-BGV*W;C-BJ(-BTV*_9AR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS
M9W-T<B`BV8?9A=F'(-JOV+'9B-F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A
M=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(MF'V879AR#9A=BLV8C8LN*`C-F'V*<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U
M<B!S:61E<R(*;7-G<W1R("+9A]F%V8?9E"#:AMF'V*?8L2#8L]F%V*HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M
M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`BV*?8K-BGV++9AR#:AMF&V*\@
MV*+8K]BQV+/;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(MBBVXS8IR#8I]BLV*?8LMF'(-BJV8;8N-N,V84@V8;9B-BY(-F!V8?8
ML=BSV*H@V878L=BJV*@@V*_8I]BOV8<@V+39B-BOV)\B"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A
M9'D@97AI<W1S(@IM<V=S='(@(MBGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8
ML]BJ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT
M97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`BV8C8L=F(V*\@24U34"#8K-BG
MVXS:K]BRVXS9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8
ML=F%V+(@24U34"#8K-BGVXS:K]BRVXS9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM
M<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQVXP@24U34"#8K-BGVXS:K]BRVXS9
MAB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!
M;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#9OMBS
MV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BLV*?;C-JOV++;C-F&(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T
M97,B"FUS9W-T<B`BV*?9A-JOV8CB@(S9A]BGVXP@V*S8I]N,VJ_8LMN,V88B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("+9
MA=BJV88@V*S8I]N,VJ_8LMN,V88Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE
M<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q
M-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G
M<W1R("+;C-JI(-F%V8+8K]BGV+$@V8;8I]BOV+'8L]BJ(-BJV+G;C-N,V88@
MV+38K]F'(-BHV8C8KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N(@IM<V=S='(@(MN,VJD@V*[8M]BGVXP@V*S8K]N,(-BQV*X@V*_8
MI]BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S
M(%!R;WAY(@IM<V=S='(@(MF^VXS8M-JIV*?8L2(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`BV;[8
MI]BSV*XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU
M."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!
M<'!L:6-A=&EO;B(*;7-G<W1R("+8J-BQV8;8I]F%V8?9E.*`C"#:J=BGV+'8
MJ-BQV*_;C"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B
M07!P;&EC871I;VX@3&ES="(*;7-G<W1R("+9@=F'V+'8L]BJ(-BHV+'9AMBG
MV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C"(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*
M;7-G<W1R("+8J-BQV8;8I]F%V8<@V*+9A=BGV*_9AR#8I]BSV*HB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(MBGV+G9A=BGV80@V*C8L2#8L=F(VXP@
MV*?8M-BJV+'8I]JIV8?8I]N,(-F!V+'8N=N,(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`BV*K8M=F(VXS8J"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("+8
MI]F&V*_8I]BRV8<@V*K9@MBQVXS8J-N,(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@
M(MBBV8C8L=N,V80B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I
M9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS
M9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("+8I]F&V*_8I]BRV8<@
MV;[8L=F(V8;8K]F'(-BBV+'8M-N,V8@B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(MF&V*?9
MA2#8HMBQV+3;C-F((@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/R(*;7-G<W1R("+8HMN,V*<@V+39A=BG(-F%V+?9A=BFV8;;C-BO(-JI
MV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BWV838I]BYV*?8JB#8I]F!V*K8
MJMBGV*T@V*W8L]BGV*@@)7,@V+'8IR#9OMBGVJD@VJG9AMN,V*_8GR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S
M='(@(MBBVXS8IR#8M-F%V*<@V878M]F%V*;9AMN,V*\@VJG9AR#9A=N,XH",
MV*[9B-BGV8?;C-BO("<E<R<@V8@@V*K9A=BGV84@V++;C-BQ(-JOV+'9B-F'
MXH",V8?8I]N,V+0@V+'8IR#8K=BPV8$@VJG9AMN,V*_8GR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(MF'V8;8L2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!
M<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/R(*;7-G<W1R("+8HMN,V*<@V8+8J-F$(-BGV+(@V+G9A=F$VXS8I]BJ(-F&
MVJ_9A]BOV*?8L=N,(-BHV+'8I]N,(-BJV*/;C-N,V*\@V*+9AB#8L]BFV8C8
MI]F$(-BTV8C8K]B?("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("+8I]F&V*K8
ML]BGV*@@V+/8JMF(V8;9A]BG(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M(@IM<V=S='(@(MBSV+G;C"#8K]BQ(-BMV+#9@2#:K]BQV8C9A]N,(-BTV*_9
MAR#8I]BSV*H@VJG9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BV+/8N=N,(-BO
MV+$@V*W8L-F!(-F%V*S9B-BRVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8
MK-F(V*\@V8;;C-BSV*HB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(MBSV+G;C"#8K]BQ(-F(VXS8L=BGVXS8M"#9A=BLV8C8
MLMN,(-BTV*_9AR#8I]BSV*H@VJG9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(MBSV+G;
MC"#8K]BQ(-F(VXS8L=BGVXS8M"#8I]BTV*K8L=BGVJG;C"#8M-BOV8<@V*?8
ML]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(N*`
MC-F(VXS:F-JOVXS9A]BG(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("+8HMJOV8C8
ML]BJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B
MV*+:K]F(V+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B#8J-BSV+<@
MV879B-BQV*\@V8;;C-BGV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RXB"FUS9W-T<B`B075T:%]C>7)S<6PZ(-BSV*?9A=BGV8;9AR#9OMBT
MV*K;C-BHV*?9AB#9@MBGV*C9A-N,V*K9A]BGVXP@V879B-BQV*\@V8;;C-BG
MV+(@V+'8IR#9AMBOV*?8L=BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&AI;7`Z(-BHV+/8
MMR#9A=F(V+'8KR#9AMN,V*?8LB!)34%0(-F^VXS8K]BG(-F&V+38KR(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G
M<W1R(")!=71H7V9T<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($944"#9
MOMN,V*_8IR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z(-BHV+/8MR#9A=F(
MV+'8KR#9AMN,V*?8LB!)34%0(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@
M4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VMR8C4Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!K<F(U(-F^VXS8
MK]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@V*C8
ML]BW(-F%V8C8L=BO(-F&VXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO(@H*
M(R`*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B
M"B)!=71H7VQD87`ZV*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQ("5S
M(-F%V87:J=F&(-F&VXS8L]BJ+B#8I]N,V88@VH;;C-BRVXP@V*?8L]BJ(-JI
MV8<@VJG8I]BQV+/8I]BR(-JOV8'8JMF'(-BGV+/8JB(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#K8K=BPV8$@VJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,
MV+/8JB`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`ZV*C8L=F(V++8L=BSV*?9
MAMN,(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*HB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B#8J-BS
MV+<@V879B-BQV*\@V8;;C-BGV+(@34-!3"#9OMN,V*_8IR#9AMBTV*\B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,
MV*?8LB!S;6)A=71H(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T
M:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,
MV9'8JB#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@
M(MBJV+78K]N,V8(@V8?9B-N,V9'8JB#9AMBGV879B-F!V9'9@B#8J-F(V*\N
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BXB"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BGV+(@V+?8L=F!
M(-JIV*?8L=BSV*?8LB!2041)55,@V+'8KR#8M-BOV8<@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+8JMBUV*_;
MC-F"(-F'V8C;C-F1V*H@V*_8L2#:J=BGV+'8L]BGV+(@1E10(-F&V*?9A=F(
MV8'9D=F"(-BHV8C8KR`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8
MJB#8K]BQ(-JIV*?8L=BSV*?8LB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO
M("(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V
M86EL86)L92!F:65L9',Z(@IM<V=S='(@(MF!VXS9A-BOV8?8I]N,(-F"V*?8
MJ-F$(-BOV+/8JMBQV+/;C#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM
M<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A
M8VMG<F]U;F0B"FUS9W-T<B`BV;[8L^*`C-BRV87;C-F&V8<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"
M86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(MBQV8;:KR#9OMBSXH",V++9A=N,
MV8;9AR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G
M:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`BV*?8L]F%(-BQ
MV878LB#9AMBGV*_8L=BSV*H@:V5R8F5R;W,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA
M;64N(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQ(-F&V*?8K]BQV+/8JB!K
M97)B97)O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M("+8K=BGV+3;C-F'(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I8R`H25-/
M+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(MBTV*?8KMF'(-JOV+'8I]F!VXS:J=N,(-F%
MV*C9AMBGVXP@)R5S)R#;C-BGV8'8JB#9AMBTV*\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A
M<V5L:6YE(@IM<V=S='(@(MBNV+<@V878J-F&V*<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E
M;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B
M0F5L:7IE(@IM<V=S='(@(MBNV+<@V878J-F&V*<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L
M(&9U>GIY"FUS9VED(")"96YI;B(*;7-G<W1R("+:K]BQV*_9A]F%V*?;C-N,
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S
M7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
MV*C9A-F(VJD@7"(E<UPB(-BGV+(@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8
ML=BOVXP@7"(E<UPB(-N,V*?9@=BJ(-F&V+38KR(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS
M9W-T<B`BV*K9AMBXVXS9A=BGV*H@V*C9A-F(VJDB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T
M<B`BV8;9B-BY(-BHV839B-JI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(MBSVXS8
MI]F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R
M:W,B"FUS9W-T<B`BVH;9B-BH(-BGV839@2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R("+9A-BHV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R("+9OMF'V8;8I]N,(-F$V*C9ASHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D
M97)S(@IM<V=S='(@(MF$V*C9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("+9A]BQ
M(-BOV8@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("+9OMBGVXS;C-F&(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`BV8;8I]F%
MV8<@V*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@
M(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`BV83;C-BSV*H@V*C9B-F$V*KB@(S8
MK]BGV+$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS
M9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<R(*;7-G<W1R("+9AMF"V*?8MR#8JMF(V++;C-BY($-2
M3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("+8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A"XN+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*(RP@9G5Z>GD*;7-G:60@(D-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(MF!V8?8L=BSV*H@V*K9
MB-BRVXS8N=N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+8JMF"V8C;C-F%(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*
M;7-G<W1R("+8HMBQV*?9A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#86UE
M<F]O;B(*;7-G<W1R("+9A=BOVXS8L2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"B+9AMF%VXSB@(S8JMF(V*?9AB#8I]BSV84@V+'9A=BR(-BQV*<@
MV*C8M]F(V+$@V*[9B-BOVJG8I]BQ(-BOV8C8J-BGV+'9AR#8J-BGV++9AMBT
MV*?9AMBOV(P@V*C8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BNV8C8
MKR#8JMF%V*?8LR`B"B+8J-JOVXS8L=N,V*\B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO
M="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(
MV*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!<(B5S7"(@V8;9B-BTV*HB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@
M97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@V;[8L]BJ(-BGV83:J=BJ
MV+'9B-F&VXS:J2#9A=BJV+79A"#8M-BO.B`E<R(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#9OMBQV8C9AMBOV8<@7"(E<UPB(-BQV*<@V*C8I]BR(-JIV+'8KR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*;7-G<W1R("+8JMF"
MV8C;C-F%(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP
M.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T
M<B`BV*?9AMBUV+'8I]F!(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M("+8I]F&V+78L=BGV8$@V*?8LB#8I]BQV+/8I]F$(-JOV++8I]BQV+0B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@7"(E<UPB(-BQV*<@V*W8
ML-F!(-JIV+'8KR`@(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@VXS:J2#8
MM-BGV*[9AR#9A=F(V8+8JB#9OMN,V*_8IR#:J=BQV*\B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV*_9B-F&(-F^V*?8L=BGV878
MJMBQ("?9OMBQV8C9AMBOV8<@V879@MBUV*\G(-BGV*_8I]F%V8<@V*_8I]BO
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!<(B5S
M7"+8L=BG(-BMV+#9@2#:J=BQV*\@(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(
MV*?9AB#8K=BPV8$@V8;9A=F(V*_8C"`E9"#9@=BQV++9AMBO(-F%V8C8K-F(
MV*\@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HBV8;9A=N,XH",V*K9B-BG
MV88@V*_9B-BHV*?8L=F'(-F%V+'8JMBH(-F&V879B-BOV(P@V*C8L=BNVXP@
MV*?8LB#9B-BQV8C8K]N,V8?8I]N,(-F!V+'8I]F'V84@V+38K]F'(-BHV+'8
MI]N,(-F%V+'8JMBH(-BSV*?8LMN,(-BHV*<@(@HBV+39A=BGV+'9A^*`C-F'
MV*?;C"#8L-BNVXS8L=F'(-BTV*_9A]B,(-BSV*?8LMJOV*?8L2#9AMN,V+/8
MJB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-BZ
MV*?9A2#8L=BG(-BHV8<@V+39A=BGV+'9AR#8JMBYVXS;C-F&(-BTV*_9AR#:
MK]BPV+$@V*_8I]BO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(MBYV8;9
MB-BGV88B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`BV*W8I]F%V80B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@
M86YD($QA8F5L<R(*;7-G<W1R("+:K]BQV8C9A^*`C-F'V*<@V8@@V*C8L=J&
MV+/8J-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("+9A=F(V*C8
MI]N,V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B
MV*[8M=F(V+7;C-BGV*H@V+/9A-F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG
M.B(*;7-G<W1R("+9@=BGV+79A-F'(-BSV839B-F$(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B
M0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BSV839
MB-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`BV8'8I]BUV839
MA^*`C-JOV+#8I]BQVXP@V+/9A-F(V80B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BV879B-BH
MV*?;C-F$(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E
M;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D-E;'1I8R`H25-/+3@X-3DM
M,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(MF%V+':J=BR(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")#96YT<F%L
M($5U<F]P96%N("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS
M(@IM<V=S='(@(MBLV++8IMN,V*?8JB#:K]F(V*?9A]N,("(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"B,L(&9U>GIY"FUS9VED
M(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("+8K-BRV*;;C-BGV*H@VJ_9
MB-BGV8?;C"`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`BV+/;
MC-BGV+/8JMF'V*?;C"#:K]F(V*?9A]N,(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U
M>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(MF&V8C;C-BSV8<B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BV*K8NMN,VXS8
ML2`B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@
MV*[9B-BO(-BQV*<@V*K8NMN,VXS8L2#8K]F'VXS8KR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(MBJV+K;C-N,
MV+'8K]BGV*_9AB#9AMBGV84@V8@@V*+8K]BQV+/;C"#:J=F'(-BGV8'8L=BG
MV*\@V8?9AMJOV*?9A2#8KMF(V*?9AMBOV88@V8@@V;[8I]BSV*X@V*_8I]BO
MV88@V*C9AR#9AMBGV879A]F4(-BTV878IR#8KMF(V*?9A]F&V*\@(@HBV*_;
MC-BO("(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I
M9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D
M('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+8JMBZVXS;C-BQV*_8
MI]BOV88@V*?8L]F%(-BQV878LB#8M-F%V*<@V*_8L2#9OMN,VJG8L=BHV8;8
MK]N,(-F!V+G9A-N,(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",V+39B-BO
M+B#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO("(*(MBJ
MV878I]BS(-BHVJ_;C-BQVXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T
M<B`BV8;9B-N,V+/9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB
M"FUS9W-T<B`BV*C8L=BQV+/;C"#9OMN,V8C9AMBO+BXN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`BXH",(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F
M=7IZ>0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`BV8;9B-N,V+/9AR(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BDB"FUS9W-T<B`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE
M<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BV*?9
MAMBJV*[8I]BH(-N,VJD@V*?8L]F%(-BQV878LB(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N
M86UE(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-F&V*?9A2#:J=BGV+'8
MJ-BQVXPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(MBGV8;8JMBN
MV*?8J"#:AMJOV8C9AMJOVXP@V8;9A=BGVXS8M"#8JMBGV+';C-BN.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*2(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8;9B-BY(-BSV*C:
MJ2#9@=F'V+'8L]BJ("C8J-BQV*?;C"#9@=F'V+'8L]BJV8?8I]N,(-F%V+'8
MJMBH*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BV*K8
MN=BQVXS9@2#:J=F$V*?8LR`E<R#;C-BGV8'8JB#9AMBTV*\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE
M87(B"FUS9W-T<B`BV+78I]F!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G
M<R(*;7-G<W1R("+9OMBGVJD@VJG8L=BOV88@V*K:K]F'V*?;C"!-4T]F9FEC
M92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@
M(D-L96%R(%%U97)Y(@IM<V=S='(@(MF^V*?:J2#:J=BQV*_9AB#:J=BGV+'8
MJ-BQ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(MF^V*?:J2#:J=BQV*_9AB#:J=BGV+'8J-BQ(#H@)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R
M('5S97(B"FUS9W-T<B`BV;[8I]JI(-JIV+'8K]F&(-JIV*?8L=BHV+$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE
M87(@=7-E<B!D871A(@IM<V=S='(@(MF^V*?:J2#:J=BQV*_9AB#8K]BGV*_9
MA]F4(-JIV*?8L=BHV+$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*
M;7-G<W1R("+8J-BGV+'8I]F&(-BOVXS8L=F'V8;:K]BGV84B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B
M0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`BV*C8L=BGVXP@V*?8K]BGV879
MA]B,(-JIV83;C-JI(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL
M('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@V*?8LB#8M]BQVXS9@B!(
M5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T
M<B`BV*C8L]BJV88@V;[9AMBLV+'9AR(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`BV*?8J-BQV8?8IR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U
M>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`BV*?8J-BQVXPB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I
M9"`B0VQO=61Y(@IM<V=S='(@(MBGV*C8L=N,(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@
M4VED96)A<B(*;7-G<W1R("+8K-F%V+D@V+38K]F&(-F&V8C8I]BQ(-JIV8;8
MI]BQVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R
M("+:AMF%V+D@V+38K]F&(-F$V*C9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("+8L=F&VJ\B"@HC.B!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`BV+'9AMJO(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM
M<V=S='(@(MBGV8;8JMBNV*?8J"#:J=F&V8;8K]F'(-BQV8;:KR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE
M8W1I;VXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BQV8;:KR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#
M;VQS.B(*;7-G<W1R("+8L]BJV8C9AMF'V*<Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R
M("+8N=F&V*?9B-N,V88@V+/8JMF(V8;9A]BG(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(MF%V+;8
MK=JI(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(MF!V+'9A=BGV88B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`BV;[9B-BSV*K9AR#9
M@=BQV878I]F&(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(MBJV8C8MMN,V*TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`BV8;8I]F%(-BYV879B-F%VXPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`HC+"!F=7IZ>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("+9@=BQV*_8
MIR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BV+38L=JIV*HB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R
M("+8L=BGVXS8I]F&V8?B@(S9A]BG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(MBTV+'8
MMR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I
M;VYS(@IM<V=S='(@(MBTV+'8I]N,V+<B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G
M<W1R("+8JMF!V*?9B-BJV8?8I]N,(-F^VXS:J=BQV*C9AMBOVXPB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO
M;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*
M(RP@9G5Z>GD*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M(@IM<V=S='(@(MF^VXS:J=BQV*C9AMBOVXP@V*C9AR#8J-BQV8C8LMBQV+/8
MI]F&VXP@V8;;C-BGV+(@V*_8I]BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R
M92`E<R(*;7-G<W1R("+9OMN,VJG8L=BHV8;8K]N,("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!0
M87-S=V]R9"(*;7-G<W1R("+8JMBCVXS;C-BO(-BGV+/9A2#8L=F%V+(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")#;VYG;R(*;7-G<W1R("+8L=F&
MVJ\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D+B(*;7-G<W1R("+8I]BJV+78I]F$(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BV*?8JMBUV*?9
MA"#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BV*?8JMBUV*?9A"#8
MJ-F'(-JIV*?8L=BSV*?8LB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*\@V+38
MKR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("+8I]BJ
MV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR(-JIV83;C-BO(-BYV879B-F%VXP@
MV+'8KR#8M-BO+B#8K]F$VXS9A#H@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("+8I]BJV+78I]F$(-BHV8<@VJG8I]BQ
MV+/8I]BR($944"#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B
MV8;9A=BGV+/9A]BG(@H*(R`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BV*K9
MA=BGV+/9A]BG(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-F'(-JIV*K8I]BH
MVH;9A]F4(-BBV*_8L=BS(-BTV878IR#8I]BVV*?9@=F'(-BTV*_9AR#8J-F(
MV*\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@
M(MF%V*W8JMF(V*?;C"`G)7,G("(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I
M9"`B0V]N=&EN=64B"FUS9W-T<B`BV*?8K]BGV879AR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("+:J=F(VJG;
MC"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R("+8L=F(V8;9B-BTV*HB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(MBG
MV*K8M=BGV80@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`BV+'9B-F&V8C8M-BJ(-BHV+'8K]BGV+38JMF&
M(-BGV+(@V*C8KMBT(-BGV8;8JMBNV*?8J-N,(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(MF&V87;
MC.*`C-BJV8C8I]F&V*\@V;[;C-BZV*?9A2#8L=BG(-BQV878LMBHV8;8K]N,
M(-JIV8;8KR!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V*?9
MA=BVV*?8H2#:J=F&V*\@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP
M="!M97-S86=E+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8
MNMBGV84@V+'8IR#8L=F%V++8J-F&V*_;C"#:J=F&V*\@4R]-24U%(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8I]F%V+;8I]BA(-JIV8;8
MKR!3+TU)344B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-BJV878I]BSV8?8IR#8L=BG(-BGV+;8I]F!V8<@VJG8L=BO("5S(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MV*C9AR#:J=BGV+'8L]BGV+(@3$1!4"#9OMN,V8C8L]BJ("(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M(&QD87`@<V5R=F5R(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV8<@
MVJG8I]BQV+/8I]BR(&QD87`@V;[;C-F(V+/8JB(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@
M)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*C8I]F$V*?9AMBS(-BQ
MV*<@VH;:J2#:J=BQV*\@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!L
M9&%P(-F%V*K8M=F$(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8J-BG(-BGV+/8JMF!V*?8K]F'(-BG
MV+(@1E10(-BHV8<@VJG8I]BQV+/8I]BR("<E<R<@V8C8M=F$(-BTV*\Z("5S
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R
M96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V*?;C-BLV*?8KR#:
MJ=BQV*\N("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(%!'4"#8L=BG
M(-BQV878LMJOV+38I]N,VXP@V8;9A=F(V*\@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MK]BGV*_9AR!3+TU)344@V+'8IR#8L=F%V++:K]BTV*?;C-N,(-F&V879B-BO
M("(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MV*K9A=BGV+,@V+'8IR#8K=BPV8$@V8;9A=F(V*\N("5S(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V8'9
MA]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8K=BPV8$@V8;9A=F(V*\N("5S
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(
MV*?9AB#8I]BSVJG8L=N,V;[8JB#8J-BQV8C8LMBQV+/8I]F&VXP@V+'8I]F'
MXH",V*?9AMBOV*?8LMN,(-BQV*<@V*W8L-F!(-F&V879B-BO("<E<R<N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*+8K]BQV+,@VJ_;C-BQV8;8K]F'
M(-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V+'8IR#8JMBTV*[;
MC-BU(-BOV*?8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#:
MJ=F$(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BQV*<@V8C8I]JIV+3;C"#9
MAMF%V8C8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-JIV80@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#9B-BGVJG8M-N,
M(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@VJG8I]F%V80@V8'9A]BQV+/8
MJB#8JMF(V++;C-BYVXP@V+'8IR#9B-BGVJG8M-N,(-F&V879B-BO(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8I]BSV*K8L=BG
MV*K:F-N,(-BQV*<@V*C8I]BQ(-JIV+'8KR`G)7,G(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'("<E<R?8I]N,V*S8
MI]BO(-JIV+'8KR`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-JI
MV83;C-BO(-BYV879B-F%VXP@V+'8IR#8I]BR(-JIV*?8L=BSV*?8LB#:J=F$
MVXS8KR#8J-BOV+/8JB#8HMF(V+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@)R5S)R#8L=BG(-BHV+'8I]N,(-F&V8C8M-BJV88@V*C8I]BR
M(-JIV+'8KR`B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&("5S
M(-BQV*<@V*C8I]BR(-JIV+'8KR(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S
M='(@(MF&V87;C.*`C-BJV8C8I]F&(-F%V*_9B-F$(-F(V+C8I]N,V8$@V8;:
MK]F'V*_8I]BQVXP@)7,@V+'8IR#8J-BGV+(@V8;9A=F(V*\B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'("<E<R<@V+'8IR#8J-BGV+(@
MV8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-JIV*?8L=BSV*?8LB!,1$%0(-BQV*<@V*S8
ML]BJV*S9B"#:J=BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]/
M8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5A9"`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8
MKMF(V*?9AMBO(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B+9AMF%VXSB@(S8JMF(V*?9AB#8I]BSV84@V+'9A=BR(-BQ
MV*<@V*C8L=BGVXP@VJG8I]BQV*C8L2#9A=F(V+'8KR#9AMBXV+$@V*C8I]BR
MV8;8M-BGV8;8KRX@V*C8N=BVVXP@VXS8IR#9A]F%V8<@V*S8LMBFVXS8I]BJ
M(-F%V+'8J-F(V+<@V*C9AR`B"B+8HMF&(-F&V*?8K]BQV+/8JB#9A=N,XH",
MV*C8I]BTV*\N(-BOV8C8J-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\@VXS8IR#8
MJ-BQV*?;C"#:J=F%VJD@V*C;C-BTV*K8L2#8J-BG(-BSV+'9OMBQV+/8JB#8
ML]BGV878I]F&V8<@V*[9B-BO("(*(MBJV878I]BS(-BHVJ_;C-BQVXS8KR(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@04-,(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+'8IR#8K]F(V*C8I]BQV8<@
MV*C8K]BSV*H@V*+9B-BQV*\N("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJ
MV8C8LMN,V+G;C"#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8
MKRX@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG
M(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9@MBGV*C9A-N,V*K9A]BGVXP@VJG8I]BQV+/8
MI]BR(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@V*C8I]BRVJ_8L=BOV*?9
MAMBO(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR`G)7,G(-BQV*<@V*W8L-F!(-F&
MV879B-BO("XB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8
ML=BHV8;8K]N,("5S(-BQV*<@V*_8KMN,V+'9AR#:J=BQV*\B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-JIV+'8
MJ-F&V*_;C"#9OMBTV*K;C-BHV*?9AB#8L=BG(-BMV8'8N"#:J=BQV*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8
MK]N,(-F^V+38JMN,V*C8I]F&(-BQV*<@V*W9@=BX(-JIV+'8KSH@)7,@(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-BGV+/:J=BQVXS9OMBJ(-BHV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B
M@(S8I]F&V*_8I]BRVXP@V+'8IR#8K=F!V+@@V8;9A=F(V*\Z("<E<R<N(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8
ML=F(V8;8K]F'(-F^V+38JMN,V*C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@
MV+'8IR#8K=F!V+@@VJG8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"B+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBO
MV8<@V;[;C-JIV+'8J-F&V*_;C"`E<R#8L=BG(-BMV8'8N"#9AMF%V8C8KRX@
MV+39A=BG(-F%VXP@V*K9B-BGV8;;C-BO(-BGV+(@VXS:J=N,(-BGV+(@VJ_8
MLMN,V8;9A^*`C-F'V*<@V*C8L=BGVXP@(@HBV*W9@=BX(-JIV*\@V*C8L2#8
ML=F(VXP@)7,@V*?8L]BJV8'8I]BOV8<@V8;9A=BGVXS;C-BO(-F((-N,V*<@
MV*?;C-F&VJG9AR#8I]BR(-JIV*\@V*C9AR#8M=F(V+'8JB#8K]BSV*K;C"#8
MK]BQ)7,@V+'9B-F&V8C8M-BJ("(*(MBJV8?;C-F'(-F&V878I]N,VXS8KR(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BV8;9
MA=N,XH",V*K9B-BGV88@VJG8I]BQV+/8I]BR($Q$05`@V+'8IR#8K-BSV*K8
MK-F((-JIV+'8KR(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS9B-F&V*\@)R5S)R#8L=BG
M(-F"V+?8N2#:J=BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(MF&V87;
MC.*`C-BJV8C8I]F&(-BJV878I]BS("#8L=BG(-BHV+'9B-BRV+'8L]BGV8;;
MC"#:J=BQV*\N("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@
MV+'8IR#8J-BQV8C8LMBQV+/8I]F&VXP@VJG8L=BO+B`E<R(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-JIV+'8
MJ-F&V*_;C"#8L=BG(-BHV+'8I]N,("<E<R<@V8;9B-BTV*HZ("5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`B(@HBV8;9A=N,XH",V*K9B-BGV88@V8;9B-BG
MV+$@V*S8I]F&V*C;C"#9A=F(V++;C-F$V*<@V+'8IR#9OMN,V*_8IR#:J=BQ
MV*\N(-F%V+?9A=BFV88@V+39B-N,V*\@VJG9AR#9AMF(V*?8L2#8K-BGV8;8
MJ-N,(-BHV*?8LB#8I]BSV*HB"@HC(`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN
M9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BHV+$@)R5S)R#8K]BSV*K8
ML=BSVXS9A]BGVXP@V++;C-BQ(-BHV+'8I]N,(-F^V8C8M-F'("<E<R<@V*_8
MI]BO.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G
M:60@(D-O=6YT960@=&5X="(*;7-G<W1R("+9A=BJV88@V+39A=BGV+'8M"#8
MM-BOV8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("+:J=BTV8C8L2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T
M<B`BV*_9B-BQV8?B@(S9A]BG(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`BV*?;C-BLV*?8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@
M;&EN:R(*;7-G<W1R("+8I]N,V*S8I]BO(-N,VJD@V;[;C-F(V8;8KR(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@
M(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BV*?;C-BLV*?8KR#;C-JIVXP@
MV*S8K]N,V*\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(MBG
MVXS8K-BGV*\@V++;C-BQV;[9B-BTV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BV878K-F(V++9A]BGVXP@V*?;C-BLV*?8KR#:J=F&
MV8;8K]F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(MBTV878I]BQV8<@VJG8
MI]BQV*H@V*?8N=BJV*C8I]BQVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0HC+"!F=7IZ>0IM
M<V=I9"`B0W)O871I82(*;7-G<W1R("+8I]N,V*S8I]BO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T
M<B`BV8'8I]BR(-F!V+G9A-N,(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X
M"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(MF%
MV*S9B-BRV8?8I]N,(-BGVXS8K-BGV*\@VJG9AMF&V*_9AR(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B
M0W5R<F5N="!4:6UE(@IM<V=S='(@(MBSV*?8N=BJ(-F!V+G9A-N,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")54DP@V8'8N=F$
MVXP@V8?8L]BJ(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY
M"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(MF!V*?8LB#9@=BYV83;
MC"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@
M5V5A=&AE<B(*;7-G<W1R("+8HMBH(-F((-F'V8C8I]N,(-F!V+G9A-N,(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R
M<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("+8M-BQV*?;C-BW(-F!V+G9A-N,
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(MBSV*C:J2#9@=BY
MV83;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+B(*;7-G<W1R("+8L]F!V*?8L=BTVXP@VJG8L=BOV88@V8C8N-BG
MVXS9@2#9A]F&VJ_8I]F%(-F(V+'9B-BO(-BHV8<@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G
M:60@(D-U="(*;7-G<W1R("+8J-BQVXS8K]F&(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C
M=&EO;B(*;7-G<W1R("+8J-BQVXS8K]F&(-BGV8;8JMBNV*?8J"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T
M<B`B0WER:6QL:6,@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM
M<V=S='(@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*
M;7-G<W1R("+8L=F(V++8I]F&V8<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`BV878L=F(V+':
MK]BQ(-BOV+'8KMBJ(-BOV*?8K]F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G
M<W1R("+8JMBGV+';C-BN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`BV*K8
MI]BQVXS8KB#8K]BQVXS8I]F!V*H@V+38K]F'(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T
M<B`BV*K8I]BQVXS8KB#8I]F&V*K8KMBGV*@B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,C(*;7-G:60@(D1A>2(*;7-G<W1R("+8L=F(V+(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(MBMV+#9@2#8L]BJV8C9AB(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS
M9VED(")$96-E;6)E<B(*;7-G<W1R("+8K]BSV*?9A=BHV+$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`BV*?8N=BOV*?8KR#8
MK]F'V*_9A]N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(MJI
MV84@VJG8L=BOV88@V*K9B-BQV8'8JMJOVXPB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B
M1&5F875L="(*;7-G<W1R("+9OMN,V+0@V8'8L=BV(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U
M;'0@0V]L;W(B"FUS9W-T<B`BV+'9AMJO(-F^VXS8M"#9@=BQV+8B"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A
M=6QT($ED96YT:71Y(@IM<V=S='(@(MF'V8C;C-F1V*H@V;[;C-BT(-F!V+'8
MMB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L
M="!3:&5L;"(*;7-G<W1R("+9OMF(V+/8JMF'V90@V;[;C-BT(-F!V+'8MB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO
M;G,B"FUS9W-T<B`BV*K8N=BGV+';C-F!(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(MBMV+#9@2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB
M"FUS9W-T<B`BV*W8L-F!(-BSV839B-F$(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U
M<"(*;7-G<W1R("+8K=BPV8$@VJ_8L=F(V8<B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B
M"FUS9W-T<B`BV*W8L-F!(-BSV+?8L2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(MBMV+#9@2#9
MA=BLV8C8LB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(MBMV+#9@2#9B"#9OMBGVJG8L]BGV++;C"#9OMN,V+K8I]F%V8?8IR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(MBMV+#9@2#8L]F$
MV8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`BV*W8
ML-F!(-BSV*K9B-F&(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G
M:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`BV*W8L-F!(-BGV83:K]F(VXP@V*S8I]N,VJ_8LMN,V88@V879B-BLV8C8
MKR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(@IM<V=S='(@(MBMV+#9@2#9A=BLV8C8LMF'V*<@V*C8L=BGVXP@
M(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("+8HMN,
MV*<@V878K-F(V++9A]BG(-F((-BRVXS8L=F%V*S9B-BRV8?8IR#8J-BQV*?;
MC"!<(B5S7"(@V*W8L-F!(-BTV8C8K]B?(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M(')O=R(*;7-G<W1R("+8K=BPV8$@V+/8M]BQ(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y(@IM<V=S='(@(MBMV+#9@2#9A]F(VXS9D=BJ(-BGV8;8
MJMBNV*?8J"#8M-BOV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6XB"FUS9W-T<B`BV*W8L-F!(-BSV*K9B-F&(-F!V+G9A-N,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S
M='(@(MBMV+#9@2#8L]BWV+$@V8'8N=F$VXPB"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(MBGV+/:J=BQVXS9OMBJ(-BMV+#9@2#8M-BOV8?9E"#8J-BQV8C8LMBQ
MV+/8I]F&VXP@V*K9AMBXVXS9A=BGV*H@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S
M"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(MBRV878I]F&(-BGV+'8
ML]BGV80B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")$96YM87)K(@IM
M<V=S='(@(MBJV8C8MMN,V*W8I]BJ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM
M<V=S='(@(MBTV+'8K2#9A=BTVJG9A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("+8JMF(
MV+;;C-BM(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G
M:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T
M<B`BV*S8LMF0V*;;C-BGV*HZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B#8K-BRV*;;C-BGV*H@V*C8
ML=BGVXP@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8J]BHV*H@V+38K]F'
M(-BGV+/8JB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(MJOV+/8JMBQV+0B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@
M(MF&V8+8M]F'(-BTV*C9AMF%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B
MV8;9@MBWV8<@V+38J-F&V84@V*C8L=BGVXP@V+/8I]BYV*H@VJ_8L-BTV*K9
MASH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I
M9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`BV8;9@MBWV8<@V+38J-F&V84Z("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*
M;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(MBLV8?8
MJB#8I]BR(-J&V;X@V*C9AR#8L=BGV+/8JB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(MBLV8?8JB#8I]BR(-BQV*?8L]BJ(-BH
MV8<@VH;9OB(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$
M:7)E8W1O<GDB"FUS9W-T<B`BV+38I]BNV8<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM
M<V=S='(@(MBBVXS8IR#8LMF%V*?9AB`R-"#8L]BGV+G8JMF'(-F&V878I]N,
MV+0@V*_8I]BOV8<@V+39B-BOV)\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9
MAMF'XH",V8?8I]N,(-F&V878I]N,V+0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z.38*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0B"FUS9W-T<B`BV8;9A=BGVXS8M"#8K-BRV*;;C-BGV*H@V;[;C-BTPJW8
MJ-N,V8;;C"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I
M<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`BV8;9A=BGVXS8M"#9OMN,
MV+3"K=BHVXS9AMN,(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`BV8;9A=BGVXS8M"#9
M@MBGV838J"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*
M;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("+8K=BG
MV838JB#8JMBPVJG8L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R
M"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(MBMV+#9@2#9AMBTV8C8
MKR(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
MV*_8L]BJV+'8L]N,(-F%V+/8JMF"VXS9A2#8J-F'(&UA:6YT96YA;F-E+G!H
M<"#9A=F%VJG9AB#9AMN,V+/8JB(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED
M(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*(MBBVXS8IR#8
ML]BWV+$@V*?9B-F$(-BTV*?9A=F$(-F!VXS9A-BO(-F&V*?9A2#9A=N,XH",
MV*C8I]BTV*_8GR#8I]JOV+$@VH;9AMN,V88@V*?8L]BJV(P@V*?;C-F&(-BL
MV+G8J-F'(-BQV*<@V+G9A-BGV878JB#8J-BRV8;;C-BO.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T
M<B`BV*?8L]BJV8+8L=BGV+$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@
M)7,B"FUS9W-T<B`BV*?8L]BJV8+8L=BGV+$@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("+8I]BSV*K9@MBQ
MV*?8L2#9OMN,VJG8L=BHV8;8K]N,(-BJV8C9A-N,V*\@V+38K]F'(-BHV+G9
MAMF(V*?9AB#8K]BSV*H@V8;9B-N,V+,@4$A0(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T
M<B`BV8'9A]BQV+/8JB#9OMBGVXS;C-F&XH",V;[8L2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`BV*_8I]BQ
MV8C9A]BG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`BV8;8I]F%V8<@V*?9A-JIV*K8L=F(
MV8;;C-JIVXPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R
M+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R
M(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(MF(VXS8L=BGVXS8
MM"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G
M<W1R("+9B-N,V+'8I]N,V+0@V*C9A-F(VJDB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U
M<"(*;7-G<W1R("+9B-N,V+'8I]N,V+0@VJ_8L=F(V8<B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B
MV8C;C-BQV*?;C-BT(-F%V*S9B-BR(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("+9
MB-N,V+'8I]N,V+0@V878K-F(V++9A]BG(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+9B-N,V+'8I]N,V+0@V878
MK-F(V++9A]BG(-BHV+'8I]N,("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BVJ_8
MLMN,V8;9A^*`C-F'V*?;C"#9B-N,V+'8I]N,V+0Z(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(MF(
MVXS8L=BGVXS8M"#9A=BLV8C8LN*`C-F'V*<@V*C8L=BGVXP@7"(E<UPB(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("+9B-N,V+'8I]N,V+0@V878K-F(V++B@(S9A]BG(-BHV+'8I]N,("5S(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB
M"FUS9W-T<B`BV*K8K=BUVXS9A-BGV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%
M9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H
M96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(MBY
MV8;8M=BQ+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R("+9AMBG
MV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#9
MAMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(MBBV*_8L=BSV8?8I]N,(-F&V*?9A=F'XH",
MV8?8I]N,(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BHV*?;C-BO(-F%V8;8M]BH
MV8(@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y
M"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+9AMBG
MV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BHV*<@V*K8H]N,VXS8KR(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED
M(")%;6]T:6-O;G,B"FUS9W-T<B`BV*?8K=BSV*?8L]BGV*HB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G
M:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(MBNV*?9A-N,(-JIV+'8K]F&
M(-F^VXS8NMBGV84@(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R
M("+8KMBGV83;C"#:J=BQV*_9AB#9AMBJVXS8K-F'(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H
M('1E<FUS(@IM<V=S='(@(MBNV*?9A-N,(-JIV+'8K]F&(-F%V8C8I]BQV*\@
MV*S8L]BJV*S9B"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G
M:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(MBBVXS8IR#8K]BQV*P@V*K8M=BG
MV8C;C-BQ(-BGV+(@VJ_8I]F$V+';C-F'V*?;C"#8N=JIV+,@V*_8L2#9A=BJ
MV88@V8'8N=BGV80@V+39B-BOV)\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/R(*;7-G<W1R("+8HMN,V*<@VJ_8LMN,V8;:K]BGV88@V++9A=N,V8;9AR#8
ML=F(VXP@VJG9A-N,VJD@V+'8I]BSV*H@V8'8N=BGV80@V+39B-BOV)\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(MBGV8;8
MJMF'V*?;C"#8L]BGV80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R
M("+8J-BRV+':KR#:J=BQV*_9AB#9B-N,V+'8I]BSV*K8I]BQ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(MN,VJD@V+/8
MIMF(V*?9A"#8I]F%V8;;C-BJVXP@V*C8L=BGVXP@V;[8L=BSV+0@V*?8LB#8
MM-F%V*<@V*C9AR#9A]F&VJ_8I]F%(-BHV*?8LMF&V+38I]F&V*_9AB#8I]BS
MV84@V+'9A=BR(-F(V*?8L=BO(-JIV8;;C-BOV(P@V878J]F$V*?9DB`B"B(G
MV8;8I]F%(-BMVXS9B-BGV88@V*[8I]F&VJ_;C"#8M-F%V*<@VH;;C-BSV*K8
MGR<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R
M92(*;7-G<W1R(")54DP@V*K8M=F(VXS8L2#8L=BG(-BGVXS9AMBLV*<@V8C8
MI]BQV*\@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO
M=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("+8KMBWV*<B"@HC
M(`HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS
M9W-T<B`BV*C9A-F(VJD@V*?;C-BLV*?8KR#8KMBWV*<Z("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G
M<W1R("+8KMBWV*<@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V*?8L]F%(-BQ
MV878LB`Z("5S(@H*(R`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<R(*;7-G<W1R("+8J-F$V8C:J2#8I]N,V*S8I]BO(-BN
MV+?8ISH@)7,B"@HC(`HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O
M;G1E;G0Z("5S(@IM<V=S='(@(MBNV+?8IR#8K]BQ(-JIV+/8J"#9A=BMV*K9
MB-BG.B5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<R(*;7-G<W1R("+8KMBWV*<@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V*?8
ML]F%(-BQV878LB`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(MBNV+?8IR#8J-BG(-F^VXS8NMBGV84@V8;8
MI]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,@"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("+8KMBWV*?;C"#9AMF(V+38JMF&
M("<E<R<@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R("+8N=BJVXS9@MF'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")%=&AN:6,B"FUS9W-T<B`BV+G8JMN,V8+9AR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@
M(MBGV+'9B-F^V*<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(MF'V+$@V;[8I]F&V++8
MK]F'(-BOV8+;C-F"V8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y
M"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BV8?8L2#8K]F((-BO
MV8+;C-F"V8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`BV8?8L2#8L]N,(-BOV8+;C-F"V8<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("+9A]BQ(-F^V8;8K"#8K]F"
MVXS9@MF'(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BV*_8L2#9A]BQ
M(-F(V+'9B-BO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(MF'V+$@V8;;C-F%(-BSV*?8
MN=BJ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B
MV8?8L2#8K]F"VXS9@MF'(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("+9A=F"V*?8
MK]N,V+$@V878J]BGV80Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D
M;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS
M9VED(")%>&5C=71E(@IM<V=S='(@(MBGV*S8L=BG(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`BV*C8I]BR(-JIV+'8K]F&(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B
MV*C8I]BRVJG8L=BOV88@V8;9B-BGV+$@VJG9AMBGV+';C"(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D
M("<I)R(*;7-G<W1R("+8I]F&V*K8N-BGV+$@V*C8L=BGVXP@)R@G(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("+8JMBGV+';C-BN(-BGV8;9
M@MBVV*?8H2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("+9AMF%V*?;C-F&V*_9AR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(MBQV8;:KR#9OMN,V+3B
M@(S8LMF%VXS9AMF'(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")&5%`@=7!L;V%D
M(&]F('-E='5P(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z
M,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS
M9W-T<B`B(-BHV*?8LMN,V*?8J-N,(-BJV8+8K]F%V*?8JB#9AMBGV879B-F!
MV9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B#8
MI]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR($Q$05`@V8;8I]F%V8C9@=F1
MV8(@V*C9B-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G
M<W1R("(@V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB!334(@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R
M;VT@7"(E<UPB+B(*;7-G<W1R("(@V*K9A]N,V8<@V+'9B-F&V8C8M-BJ(-BG
MV+(@7"(E<UPB(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BV*?;C-BL
MV*?8KR#8L=F(V8;9B-BTV*H@V*_8L2!<(B5S7"(@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM
M<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*
M;7-G<W1R("(@V*?;C-BLV*?8KR#;C-JI(-BGV*K8M=BGV80@V*S8K]N,V*\@
M4T%33"#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S
M7"(N(@IM<V=S='(@(B#8I]F&V*K9@MBGV80@V*C9AR!<(B5S7"(@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R
M971R:65V93H@)7,B"FUS9W-T<B`B(-BGV8;8JMF"V*?9A"#8J-F'(%PB)7-<
M(B#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("+9
MA-BWVXS9@2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O
M92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("+8KMBWV*?;C"#8
MK-BOVXPZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("+9@=JIV+,B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE
M<R(*;7-G<W1R("+9@=JIV+,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`BV8'9
MB-BQVXS9AR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`BV+':K]BHV*?8L2#8KMF!VXS9@2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(MJIV87;C"#8JMJOV+':
MKR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@
M9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("+9OMBQV8C9AMBOV8<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(MBTV878I]BQV+0@V;[8
ML=F(V8;8K]F'.B`E<R#9OMBQV8C9AMBOV8<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE<R(*;7-G<W1R("+8M-F%V*?8L=BT(-F^V+'9B-F&V*_9ASH@
M)7,@V;[8L=F(V8;8K]F'(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(MF%V*_;C-BQ(-F^
MV+'9B-F&V*_9AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS
M9VED(")&:6QE($YA;64B"FUS9W-T<B`BV8;8I]F%(-F^V+'9B-F&V*_9AR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9OMBQV8C9AMBOV8<B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE
M('5P;&]A9"(*;7-G<W1R("+8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(MBGV+'8L]BGV80@
MV;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",V+39B-BO
M+BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I
M;'1E<G,B"FUS9W-T<B`BV8';C-F$V*K8L=F'V*<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L
M(&9U>GIY"FUS9VED(")&:6YL86YD(@IM<V=S='(@(MBOV+'8KMBW(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R("+9AMN,V879AR#8I]F(V80B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R
M(@IM<V=S='(@(MBQV*C8N2#8I]F(V80B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`BV8;8L]BHV*H@V*O8I]BHV*HB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(MBGV+G8M-BGV+';C"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS
M9VED(")&;V<B"FUS9W-T<B`BV879A^*`C-BBV839B-BO(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0B"FUS9W-T<B`BV;[9B-BTV8<@)7,@V879B-BLV8C8KR#9
MAMN,V+/8JB`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(MBQV8;:KR#9
M@MF$V84B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O
M;V0B"FUS9W-T<B`BV+K8L-BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("+8J-BQ
MV*?;C"#9A=BQV8C8L=JOV+'9A]BGVXS;C"#:J=F'(-BJV+78I]F(VXS8L2#8
ML=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMF&V*\B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB
M"FUS9W-T<B`BV;[;C-BTPJW8J-N,V8;;C"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U
M;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V8'8L=BG
MV879B-BT(-JIV+'8K]F'XH",V*?B@(S;C-BOV)\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("+9@=BQ
MV879A]BG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&
M;W)T=6YE(@IM<V=S='(@(MBWV*?9A-BY(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`BV8;9B-BY
M(-BWV*?9A-BY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R("+8M]BGV838N=F'V*<B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
MV+?8I]F$V+G9A]BG(-NR(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(MBGV8;8K-F%V8;9A]BG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`BV*?8L=BLV*?8N=F'V*<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R
M("+8K-F%V+G9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("+:AMBG
MV+':AMF(V*C9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A
M;F-E(@IM<V=S='(@(MJ&V*?8L=J&V8C8J-F'V*<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY
M;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*
M;7-G<W1R("+8I]BR(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*
M;7-G<W1R("+8I]BR("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(MBTV+'8
MK2#:J=BGV879A"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`BV878
MI]F'(-JIV*?9A=F$(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@
M3F%M92(*;7-G<W1R("+9AMBGV84@VJG8I]F%V80B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(MJOV*?9A-BQVXP@V*C8
ML=BGVXP@V*_8L=N,V*?9@=BJ(-BJV+79B-N,V+$@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS
M9VED(")'86QL97)Y.B(*;7-G<W1R("+:K]BGV838L=N,.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R
M871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`BV*K9B-F$VXS8KR#9OMN,
MVJG8L=BHV8;8K]N,("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(MJI
MV*\@V*K9B-F$VXS8KR#8M-BOV8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R
M9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E
M;B!.86UE(@IM<V=S='(@(MF&V*?9A2#8K]BGV*_9AR#8M-BOV8<B"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B
MV*C8L=F((@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")'
M;V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-87!S
M(@IM<V=S='(@(MBLV+/9AMBLV8C;C"#:K]F(VJ_9A"(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T
M<B`BV*S8L]F&V*S9B-N,(-JOV8C:K]F$(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(MBOV+'8K-F'(-BNV*?:J=BSV*K8L=N,(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R
M965K("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("+8L]BQV;[8L=BSV*K;C"#:K]BQV8C9
MAR(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`BV8;8I]F%(-JOV+'9B-F'(-F&
MV*C8I]N,V*\@V*[8I]F$VXP@V*C8I]BTV*\B"@HC(`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T
M:%]L9&%P.MBGV+;8I]F!V8<@VJG8L=BOV88@VJG8I]BQV*C8L2`E<R#9A=F%
MVJG9AB#9AMN,V+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JI
MV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z
MV*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;
MC-BSV*HB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.MBHV+'9B-BRV+'8L]BG
MV8;;C"#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R("+:K]BQV8C9AR8C>#(P,&,[V8?8IR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")'=65R;G-E>2(*;7-G<W1R
M("+8LMN,V+'9OMN,V+'8I]F'V8;;C"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*
M;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(MF%V*S9B-BRV8?8
MI]N,(-F%V8?9A=BGV88B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<P"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`BVJG8JMBGV*C:AMF'V90@
MVXS8I]BOV*C9B-BO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(MJ8V8C8IMF&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(-BMV+#9@2#8HMBNV+';
MC-F&(-BSV839B-F$(-BQV*<@V*_8L2#8L=BOVXS9@2#8L=BO(-F%VXSB@(S:
MJ=F&V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@
M(DA434Q!<F5A(-BMV+#9@2#8HMBNV+';C-F&(-BSV*K9B-F&(-BQV*<@V*_8
ML2#8K-BOV8C9A"#8L=BO(-F%VXSB@(S:J=F&V*\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R
M;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(-BMV+#9@2#8HMBNV+';
MC-F&(-BQV*_;C-F!(-BQV*<@V*_8L2#8K-BOV8C9A"#8L=BO(-F%VXSB@(S:
MJ=F&V*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM
M<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(MBJV+78K]N,V8(@V8?9B-N,V9'8JB!(5%10(-N,V*?9@=BJV8<@V8;8M-BO
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED(")(86ET:2(*;7-G<W1R
M("+9AMBSV*C8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`BV*?9A-JOV8C8
ML=N,V*K9A2!(87-H(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`BV879A^*`C-BBV839
MB-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("+8
ML]BQV*+9A=BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("+8
ML]BQV*+9A=BO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@
M86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@
M(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI
M(@IM<V=S='(@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@
M(DAE:6=H="(*;7-G<W1R("+8J-F$V8;8K]N,(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E
M;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@
M(MBQV*?9A]F&V878IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(MBQV*?9A]F&V878I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V8C;C-BQ
MV*?;C-BTVJ_8L2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*
M;7-G:60@(DAE;'!E<B(*;7-G<W1R("+:J=F%VJD@VJG9AMF&V*_9AR(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G
M<W1R("+9AMN,V87B@(S:J=BQV8<B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M("+8I]N,V8;8K-BG(-BGV*C8JMBOV*?;C"#9OMBQV8C9AMBOV8?B@(P@V87;
MC.*`C-BHV*?8M-BO.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(MBHV*?9A-BG(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI
M;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R("+8
MKMBGV8;9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R("+8KMBGV8;9
MAR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U
M-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-BNV*?9
MAMF'(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE
M($1I<F5C=&]R>2(*;7-G<W1R("+8M-BGV*[9A]F4(-BGV+79A-N,(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I
M9"`B2&]M92!0:&]N92(*;7-G<W1R("+8M-F%V*?8L=F'(-BJV839@=F&(-F%
MV8;8LMF$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E
M(@IM<V=S='(@(MF'V8C8L=BO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@V*C8IR#8K]BGV*_9AR#9AMBGV*_8
ML=BSV*H@6$U,(-BOV+$@V;[;C-BZV*?9A2`E<R#9A=F(V*?8K-F'(-BTV*_9
MAR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(-F'VXS:AB#9OMN,V+K8I]F%VXP@V878M]BGV*C9@MBJ(-BHV*<@V+3;C-BA
M("5S(-F&V*_8I]BQV*\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@V8?;C-J&(-BTVXS8IMN,(-BGV+(@V8;9B-BY("5S(-BO
MV+$@V;[;C-BZV*?9A2`E<R#;C-BGV8'8JB#9AMBTV*\B"@HC(`HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<
M(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ
M("5S(%PB)7-<(B#8K=BPV8$@V+38KR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@V*K9B-F$VXS8KR#;C-JI(-BOV+'8KMBJ(-BLV*_;C-BO
M(%A-3"#8J-BQV*?;C"#8M-N,V*$@)7,@V879@MBOV8C8L2#9AMN,V+/8JB`B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@V*W8L-F!("5S(%PB
M)7-<(CHE<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#8J-BGV++;C-BG
MV*C;C"`@34E-12!)1"#8J-BQV*?;C"#9@MBSV878JMN,(-BGV+(@V8;9B-BY
M("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@V+/9AMJIV+'9B-F&(-JIV+'8K]F&("5S(%PB
M)7-<(CH@)7,@V879@MBOV8C8L2#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(-BSV8;:J=BQV8C9AB#:J=BQV*_9AB#8I]BT
MV*K8L=BGVJG9A]BG(-F%V8+8K]F(V+$@V8;;C-BSV*HZ("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B#8I]BTV*K8L=BGVJD@V8;8I]BTV8;8I]BNV*K9AR!<
M(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BV8+8I]F&
MV8C9AB#8I]F!V8+;C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G
M<W1R("+9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8I]F!V8+;C"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@
M(DAO<FEZ;VYT86PZ(@IM<V=S='(@(CK8I]F!V8+;C"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I
M9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS
M9W-T<B`BVH;:K]F(V8;9AR#8J-BG(-BGVXS9AMBLV*<@V*+8M-F&V*<@V+38
MK]N,V*_8GR`HV838M]F!V*?9BR#:K]BRV*?8L=BT(-BOV8?;C-BO*2$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R(*;7-G<W1R("+:AMF&V*\@V+/8JMF(V88@V+'8IR#9A=N,XH",
MV*[9B-BGV8?;C-BO(-BGV*_8NMBGV84@VJG9AMN,V*_8GR(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`BVH;9AMBO(-F!VXS9
MA-BO("C8L]BJV8C9ABD@V8C8K-F(V*\@V*_8I]BQV*_8GR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G
M:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(MJ&V8;8KR#8L]BWV+$@V+'8IR#9A=N,XH",V*[9B-BGV8?;C-BO
M(-BGV*_8NMBGV84@VJG9AMN,V*_8GR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@
M(DAU;6ED:71Y(@IM<V=S='(@(MBQV+?9B-BHV*HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S
M='(@(MBQV+?9B-BHV*HZ("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+8I]N,V*S8I]BO(-F&V*?9A=F'
MXH",V*_8I]F&($E-05`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO.B`@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+8
MK=BPV8$@V8;8I]F%V8?B@(S8K]BGV88@24U!4"#9AMBGV879B-F!V9'9@B#8
MJ-F(V*\@.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(MBGVXS8K-BGV*\@V878K=BOV8C8K]N,V9'8
MJB#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKR`Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR!)4"(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E
M<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BV*+8K]BQV+,@25`@V8+8I]BH
MV80@V*_8L]BJV+'8L]N,(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`BV*+8K]BQV+,@25`@
MV*_8L2#8K]BGV*[9A"#8J-F$V8C:J2!#2412(-BGV*S8I]BRV8<@V*_8I]BO
MV8<@V8;9A=N,XH",V+39B-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V
M:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2
M;W<@0F5F;W)E(@IM<V=S='(@(MBGV*C8JMBOV*<@V+/8M]BQ(-BQV*<@V8C8
MI]BQV*\@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I
M9"`B26-O;G,@3VYL>2(*;7-G<W1R("+9@=F"V+<@V*+;C-JIV8C9AMF'V*<B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(MBBVXS:J=F(V8;9
MA]BG(-BHV+'8I]N,("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(MBBVXS:J=F(V8;9
MA]BG(-BHV*<@V878JMF&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("+9AMBGV84@V8?9
MB-N,V9'8JCHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+B(*;7-G<W1R("+8I]JOV+$@V*+9AB#8J-F'(-BOV+'8L]BJVXP@V8;9A=BG
MVXS8M"#8K]BGV*_9AR#9AMBTV*_8C"`E<R`@V*C8L=BGVXP@V*C8I]BR(-JI
MV+'8K]F&(-BBV88@V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(MBGVJ_8L2#8M-F%V*<@
MV8?;C-J&(-BBVXS:J=F(V8;;C"#8L=BG(-BOV+$@V878L=F(V+':K]BQ(-F&
MV*C;C-F&VXS8K]B,(-F%V87:J=F&(-BGV+/8JB#9A-BGV++9A2#8J-BGV+38
MKR#:J=F'(%!.1R`B"B)4<F%N<W!A<F5N8WD@V+'8IR#8KMBGV879B-BT(-JI
MV8;;C-BO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T
M(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T
M(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*
M(MBGVJ_8L2#8M-F%V*<@V*?;C-F&(-F^VXS8NMBGV84@V+'8IR#9A=BTV*?9
MA]BOV8<@VJG9AMN,V*\@V*?9A=BG(-BJV+79B-N,V+';C"#8L=BG(-F%V+38
MI]F'V*_9AR#9AMJIV8;;C-BOV(P@V*?;C-F&(-BHV8<@V*?;C-F&(-BYV838
MJB`B"B+8KMF(V*?9A]BO(-BHV8C8KR#:J=F'(-F%V+'9B-BQVJ_8L2#8M-F%
MV*<@V8'8I]BOV+$@V*C9AR#9AMF%V*?;C-BT(-BJV+79B-N,V+$@V8;;C-BS
MV*H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M("+9OMN,V+3B@(S9AMF%V*?;C"#8JMBUV8C;C-BQ.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@
M(DEM86=E(%523"(*;7-G<W1R(")54DP@V*K8M=F(VXS8L2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@V*K8M=F(VXS8L3HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M("+8JMBUV8C;C-BQ(-BGV+(@VJ_8I]F$V+';C"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("+8JMBUV8C;C-BQ(-BG
MV+(@VJ_8I]F$V+';C#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`BV*?8L=BSV*?9A"#8
MJMBUV8C;C-BQ(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@
M(DEM86=E<R(*;7-G<W1R("+8JMBUV*?9B-N,V+$B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("+8K]BQV8C9AN*`C-BHV+'8K]B,
M(-JOV*?9A2`E9"(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E
M<R(*;7-G<W1R("+9@=N,V838KR#8K]BQV8C9AN*`C-BHV+'8KR#8M-BOV8<Z
M("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B
M26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("+9@=N,V838K^*`C-F'V*?;C"#8
MK]BQV8C9AN*`C-BHV+'8KR#8M-BOV8<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R("+8J-BYV*_8I]F+(-BSV+?8L2#8L=BG
M(-F(V*?8L=BO(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(MJIV*\@V+G9A=F$VJG8L=BO(-F&V*?8K]BQ
MV+/8JB#8K]BGV*_9AR#8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R
M<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(B#9AMBG
MV84@VJG8I]BQV*C8L2_8I]BSV84@V+'9A=BR("#9AMBGV*_8L=BSV*H@V*?8
ML]BJ(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@
M(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HBV8;8I]F%(-JI
MV*?8L=BHV+$@VXS8IR#8HMBOV+'8LR#8K-BGVXS:K]BRVXS9AB#9AMBGV*_8
ML=BSV*H@V87;C.*`C-BHV*?8M-BO+B#9A-BWV8'8IR#9A=BLV*_8K]BGV9(@
MV+/8N=N,(-JIV8;;C-BO(-F((-N,V*<@V*_8L2#8M=F(V+'8JB`B"B+9AMN,
MV*?8LB#8J-F'(-JIV87:J2#8J-N,V+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ
M(-BSV*?9A=BGV8;9AR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("))
M;F-R96%S92!);F1E;G0B"FUS9W-T<B`BV*?9@=BRV*?;C-BT(-BJV8C8L=F!
MV*K:K]N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R("+:J=BGV+'8J-BQV*?9AB#8KMBGV+4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(MBGV+?9A-BGV+G8I]BJ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`BV*?8M]F$
MV*?8N=BGV*HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P
M"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G
M<W1R("+8I]BWV838I]BYV*?8JB#8K]N,VJ_8L2#8K]BQ(-BOV+/8JMBQV+,@
MV8;;C-BSV*HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(MBOV+'8K"#8L]BJV8C9AB#8J-BYV*\@V*?8LB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(MBOV+'8K"#8JMBU
MV8C;C-BQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(MBOV+'8K"#8
MK-BOV8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("+8K]BQ
MV*P@V;[;C-F(V8;8KR#9B-BH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O
M;'5M;B!"969O<F4B"FUS9W-T<B`BV*?8J-BJV*_8IR#8L]BJV8C9AB#8L=BG
M(-BOV+'8K"#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BVXS:J2#8
ML]BJV8C9AB#8K-BOVXS8KR#8J-BYV*\@V*?8LB#8L]BJV8C9AB#9@=BYV83;
MC"#8K]BQV*P@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+;C-JI
M(-BSV*K9B-F&(-BLV*_;C-BO(-F"V*C9A"#8I]BR(-BSV*K9B-F&(-F!V+G9
MA-N,(-BOV+'8K"#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BVXS:J2#8
ML]BWV+$@V*S8K]N,V*\@V*C8N=BO(-BGV+(@V+/8M]BQ(-F!V+G9A-N,(-BO
MV+'8K"#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(MN,VJD@V+/8M]BQ
M(-BLV*_;C-BO(-F"V*C9A"#8I]BR(-BSV+?8L2#9@=BYV83;C"#8K]BQV*P@
MVJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(MN,VJD@V;[8I]BQV*?:
MK]BQV*?9@2#8J-BYV*\@V*?8LB#:K]BQV8<@V8'8N=F$VXP@V*_8L=BL(-JI
MV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BVXS:J2#9OMBGV+'8I]JO
MV+'8I]F!(-F"V*C9A"#8I]BR(-JOV+'9AR#9@=BYV83;C"#8K]BQV*P@VJG9
MAMN,V*\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("+8K]BQV*P@V*?9A-JO
MV8C;C"#8K-BGVXS:K]BRVXS9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H
M('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("+;
MC-JI(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V*C8L=BG
MVXP@V*_8L=N,V*?9@=BJ(-BGV+/9A2#8L=F%V+(@(-BLV*_;C-BO(-BOV+'8
MK"#:J=F&VXS8KR`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*
M;7-G<W1R("+8K]BQV*P@V+/9A-F(V80@V*C8N=BO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B
M26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(MBOV+'8K"#8L]F$V8C9A"#9
M@MBHV80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S
M='(@(MBOV+'8K"#8L]BJV8C9AB#8J-BYV*\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("+8K]BQV*P@V+/8JMF(V88@V8+8
MJ-F$(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("+8K]BQV*P@V;[;
MC-BZV*?9A2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E
M<B(*;7-G<W1R("+8K]BQV*P@V;[8I]BQV*?:K]BQV*?9@2#8J-BYV*\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(MBOV+'8K"#9OMBGV+'8I]JOV+'8I]F!(-F"V*C9A"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`BV*_8L=BL(-BSV+?8L2#8J-BY
MV*\@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B
MV*_8L=BL(-BSV+?8L2#9@MBHV80B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T
M:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(MF^V*?8L]BN(-F%V8C8
ML=BO(-F&VXS8I]BR(-BQV*<@V*C8L=BGVXP@V+/8IMF(V*?9A"#8I]F%V8;;
MC-BJVXP@V*_8L=BL(-JIV8;;C-BO.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@
M26UA9V4B"FUS9W-T<B`BV*_8L=BL+]BJV+K;C-N,V+$@V*K8M=F(VXS8L2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*
M;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("+8K]BQV*POV*K8
MNMN,VXS8L2#9OMN,V8C9AMBO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(MBGV+G8JMBHV*?8L2#9AMBGVJG8I]F!VXP@V*C8L=BGVXP@V*?8L=BS
MV*?9A"#8J-F'(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@
M(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(MBGV+G8JMBHV*?8L2#9
MAMBGVJG8I]F!VXPB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(MBYV*_8KR#8M=BMVXS8K2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@
M;&ES="(*;7-G<W1R("+9@=F'V+'8L]BJ(-BYV*_8KR#8M=BMVXS8K2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS
M9W-T<B`B541((-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M6DE0(&1A=&$B"FUS9W-T<B`BV*_8I]BOV8<@VXS9B-F&VXS:J=BO(-F&V*?9
MA=BYV*K8J-BQ("(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G
M:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(MBHV+'9AMBGV879
MA]F4(-JIV*?8L=BHV+'8K]N,(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("+8K]BSV*K9AR!)1"#9AMBG
MV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM
M<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`BV*_8I]BO
MV8?9E"#9AMBGV878N=BJV*C8L2#8I]BQV*?8IMF'(-BTV*_9AR(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM
M<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("+8
MHMBOV+'8LR#9A=F"V+78KR#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL
M92!F;W)M870B"FUS9W-T<B`BV8+8I]F$V*@@V;[8L=F(V8;8K]F'V90@V8;8
MI]F%V+G8JMBHV+$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G
M<W1R("+8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#9AMBGV878N=BJ
MV*C8L2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(MBHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-F&V*?9A=BYV*K8
MJ-BQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("+9
MAMF(V+D@V;[;C-BZV*?9A2#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B87!I7VED(-F&
MV*?9A=BYV*K8J-BQ(-BGV+/8JB#9B"#;C-BG(-BGV+(@V*C;C-F&(-BQV8'8
MJMF'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N(@IM<V=S='(@(MF^V*?8L=BGV878JMBQ(-F&V*?9A=BYV*K8
MJ-BQ(-F((-N,V*<@V*?8LB#8J-N,V88@V+'9@=BJV8<B"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(MF%V*S9B-BR(-F^V*_8L2#9AMBGV878N=BJ
MV*C8L2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`BV878
MK-F(V+(@V;[8K]BQ(-F&V*?9A=BYV*K8J-BQ(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P
M<F]D=6-T(&-O9&4N(@IM<V=S='(@(MF^V+'9B-BJVJG9A"#9AMBGV878N=BJ
MV*C8L2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B
MV;[8L=F(V*K:J=F$(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV
M86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("+:K]N,V+'9AMBOV8?9
ME"#9AMBGV878N=BJV*C8L3H@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V
M,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BV+3;C-BA
M(-BHV8<@V*?8M-BJV+'8I]JI(-JOV+#8I]BTV*K9AR#8M-BOV8?9E"#9AMBG
MV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S
M<RXB"FUS9W-T<B`BV*+8K]BQV+,@V+/8L=J&V+39A=F'(-F&V*?9A=BYV*K8
MJ-BQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T
M<B`BV*_8I]BOV8<@VXS9B-F&VXS:J=BO(-F&V*?9A=BYV*K8J-BQ("(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R
M>2(*;7-G<W1R("+9A=F(V*S9B-BOVXPB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T
M:6]N(@IM<V=S='(@(MBHV+':K]BQV*_8I]F&V*_9AB#8I]F&V*K8KMBGV*@B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L
M92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM
M<V=S='(@(E0M4W1O<FUS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("+9A=F&V*K8M-BQ(-JIV8;9
MAMBOV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("+8K=BQV8C9@2#:J=BL(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R("+8
MK=BQV8C9@2#:J=BL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(MJ8V*?9AMF(VXS9AR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R
M,BU*4"DB"FUS9W-T<B`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R
M:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI
M<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS
M9VED(")*97)S97DB"FUS9W-T<B`BV++;C-BQV;[;C-BQV*?9A]F&VXPB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L
M>2(*;7-G<W1R("+:F-F(V*;;C-F'(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`BVIC9
MB-BFV88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(MF'V87B@(S8
MJMBQV*?8LB#:J=BQV*_9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E
M<B(*;7-G<W1R("+9A]F%XH",V*K8L=BGV++;C"#9B-BSV+<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM
M<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(MF'V87B@(S8JMBQV*?8LMN,
M(-JIV*?9A=F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R
M("+9A]F%XH",V*K8L=BGV++;C"#:AMF^(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I
M9GD@4FEG:'0B"FUS9W-T<B`BV8?9A>*`C-BJV+'8I]BRVXP@V+'8I]BSV*H@
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*
M;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(MBGV+79A-N,(-F&VJ_9
MAR#8K]BGV+38JMF'(-BTV8C8K]B?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M96YY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(MJIV*?8L=BSV*?8LB!K97)B97)O<V4@V*K8
MM=BOVXS9@B#9A]F(VXS9D=BJ(-BQV*<@V+'8KR#:J=BQV*\B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(MBGVXS8K-BGV*\@VJG9
MA-N,V*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*
M;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("+8I]BKV+$@V*?9AMJO
MV+38JB#:J=F$VXS8KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("+8M]F(V80@VJG9
MA-N,V*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*
M;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(MF&V8C8N2#:J=F$VXS8KR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")+
M97D@57-A9V4B"FUS9W-T<B`BVJG8I]BQV*C8L=BO(-JIV83;C-BO(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(MJIV83;C-BO(-F"V*C9A-BGV8L@V*_8L2#:J=BGV+'8L]BGV+(@V+G9
MA=F(V87;C"#:J=F$VXS8KR#9A=F(V*S9B-BO(-BGV+/8JB(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("+B@(S8
MJ-J&V8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A
M=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B2V]R96%N("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("+8K-BGV8;9A=BGVXS;
MC"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(MBRV*C8I]F&(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B
M"FUS9W-T<B`BV8;;C-F%V8?9E"#8HMBNV+$B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S
M='(@(MBJV+K;C-N,V+$@V*+8KMBQVXS9AB#8I]BSV84@V+'9A=BR(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM
M<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(MBQV*C8N2#8HMBNV+$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R("+8HMBNV+';C-F&(-BHV+'9B-BRV+'8L]BGV8;;C#HB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BV*+8KMBQVXS9AB#9B-BQ
MV8C8KSH@)7,B"@HC(`HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*
M;7-G<W1R("+8HMBNV+';C-F&(-F(V+'9B-BO(#H@)7,@V*?8LB`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I
M;CH@3F5V97(B"FUS9W-T<B`BV*+8KMBQVXS9AB#9B-BQV8C8KSH@V8?8L=JO
MV+(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DQA='9I82(*;7-G
M<W1R("+8K]BGV*_9AR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM
M<V=I9"`B3&%W(@IM<V=S='(@(MBMV8+9B-F"(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO
M=70B"FUS9W-T<B`BV*S8I]F&V878I]N,VXPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T
M<B`BVH;9OB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G
M:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(MBSV+'8HMF%V*\@VH;9OB(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*;7-G:60@(DQE9G0@=F%L
M=65S(@IM<V=S='(@(MF%V8+8I]BOVXS8L2#:AMF^(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"B,L(&9U>GIY"FUS9VED("),97-O=&AO(@IM<V=S='(@(MBQV8C8M"(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5V96PB"FUS9W-T<B`BV+G8M-F"(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R
M:7IZ;&4B"FUS9W-T<B`BV8;9A>*`C-F&V84@V*C8I]BQV*?9AB(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),
M:6=H="!286EN(@IM<V=S='(@(MBHV*?8L=F&V*_:K]N,(-BSV*C:J2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED
M("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(MBHV*?8L=F&V*_:K]N,(-BS
MV*C:J2#8LMF(V*_9A]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*
M;7-G<W1R("+8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@V*_;C-BQV8?9AMJOV*?9
MA2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y
M"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("+8J-BGV+'9AMBO
MVJ_;C"#9B"#8L=JOV*C8I]BQ(-BSV*C:J2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I
M=&@@5&AU;F1E<B(*;7-G<W1R("+8J-BGV+'8I]F&(-BSV*C:J2#8J-F'(-F'
MV878L=BGV8<@V+'8N=BO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BV*C8
ML=F!(-BSV*C:J2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("+8
MJ-BQV8$@V8@@V+':K]BHV*?8L2#8L]BHVJDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T
M<B`BV;[;C-F(V8;8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z
M(@IM<V=S='(@(MF&V8+8I]BW(-F^VXS9B-F&V*\@V*C9ASHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M(@IM<V=S='(@(MBBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@
MV+'8IR#8J-F'(-BUV8'8K=F'(-BGVXS8K-BGV*\@V;[;C-BZV*?9A=B,(-BH
MV8<@V8?9AMJOV*?9A2#9A=BTV*?9A]BOV8?8C"#9OMN,V8C9AMBO(-BOV8?;
MC-BO(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E
M>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`BV;[;C-F(V8;8K^*`
MC-F'V*<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI
M;G5X($-O;VMI92(*;7-G<W1R("+:J=F(VJG;C"#9A-N,V8;9B-JIV+,B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I
M9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(MF!
MV8?8L=BSV*H@+2#:J=BGV+'8J-BQ(-F%VXSB@(S8JMF(V*?9AMBO(-F^V8C8
MM-F'(-BQV*<@V*C8J-N,V8;8KR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(MF!V8?8L=BSV*H@
MV*_8I]BOVJ_8I]F&V8?8I^*`C"(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(MF!V8?8
ML=BSV*H@V+G9AMBGV8C;C-F&(-BQV*?9A]F&V878IR(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(MF!
MV8?8L=BSV*H@V*S8K]BGV8C9A"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B
MV8'9A]BQV+/8JB#8HMBQV+3;C-F((@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("+9
M@=F'V+'8L]BJ(-BQV*?9A]F&V878IR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(MF!
MV8?8L=BSV*H@260B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("+9@=F'V+'8L]BJ
M(-F%V*?9A-JI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("+9@=F'V+'8L]BJ(-F^
MV+/8JMN,(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(MF!V8?8L=BSV*H@
MV+G8MMF(VXS9D=BJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`BV8'9
MA]BQV+/8JB#8N=BOV84@V+G8MMF(VXS9D=BJ(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG
M('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`BV8'9A]BQV+/8JB#:J=BG
MV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMF%VXSB@(S8J-BGV+38KR(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(MF!V8?8L=BS
MV*H@VJG8I]BQV*C8L=BGV88@V8'8N=BGV80@V8;9A=N,XH",V*C8I]BTV*\B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@
M(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(MF!V8?8L=BS
MV*H@VJG8I]BQV*C8L=BGV88@V8'8N=BGV80@V8;9A=N,XH",V*C8I]BTV*\B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`BV*?8K]BHVXS8I]BJ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"B,L(&9U
M>GIY"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`BV8C8I]BMV*\@V;[9A]F&
MV*<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(MBHV*?8L=JIV+'8K]F&
M+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I
M9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(MBSV*?8N=BJ(-F%V*W9A-N,.B`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A
M;F0@5&EM92(*;7-G<W1R("+9A=BMV83;C-F1V*H@V8@@V+/8I]BYV*HB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N
M(@IM<V=S='(@(MF%V8C9@MBYVXS8JB(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*
M;7-G<W1R("+9B-BQV8C8KR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(MBNV+'9B-BL(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("+9B-BQ
MV8C8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(MF(V+C8I]N,V8$@V8C8L=F(V*\B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(MF(V+'9B-BO(-F&V*?9A=F(V8'9
MD=F"(-BHV8C8KR#8LMN,V+'8IR#9AMBGV84@VJG8I]BQV*C8L2#9B"#;C-BG
M(-BGV+/9A2#8L=F%V+(@V8C8I]BQV*\@V+38K]F'(-BGV+38JMBHV*?9AR#8
MJ-F(V*\@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED
M("),;V=I;B!F86EL960N(@IM<V=S='(@(MF(V+'9B-BO(-F&V*?9A=F(V8'9
MD=F"(-BHV8C8KRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U
M"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`BV878JMF&(-BHV839AMBO(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S
M='(@(MBYV+39@B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`BV;[8I]N,VXS9AB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`BV*W8
ML=F(V8$@VJG9B-J&VJD@VXS9B-F&V*?9AMN,(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B
M3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("+8K=BQV8C9@2#:J=F(VH;:
MJ2#9A-BGV*K;C-F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R("+8I]BYV*_8I]BO(-JIV8C:AMJI(-N,V8C9AMBGV8;;
MC"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]4
M1"(*;7-G<W1R("+9OMN,V+K8I]F%(-BQV8C8LB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(MF^VXS9B-BS
MV*H@35,M5$Y%1B#8M-BGV879A"#9A]N,VH8@V*_8I]BOV8?B@(S8I^*`C-N,
MVXP@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS
M9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86-A
M;R(*;7-G<W1R("+8JMBYV+?;C-F$V*?8JB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@
M(DUA9VEC(@IM<V=S='(@(MBLV*?8K]F((@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(MF&V*?9A=F'(-BG
MV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("+8L]BQV;[8L=BS
MV*H@V8;8I]F%V8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS
M9W-T<B`BV+/8I]BNV*K9AB#9OMN,V8C9AMBO+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`BV8;8I]F%V8<@V*?9
MA-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y
M<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI
M(@IM<V=S='(@(MF&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R("+9AMBG
MV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T
M<B`BV878K]N,V+';C-BJ(-F((-BJV+G;C-N,V88@V+'9AMJO(-BOV+/8JMF'
MXH",V8?8I]N,VXP@VJG9AR#8M-F%V*<@V879B-BGV+'8KR#8L=BG(-BHV*<@
MV*+9AMF'V*<@V8;8I]F%XH",VJ_8L-BGV+';C"#9A=N,XH",VJG9AMN,V*\B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U
M,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(&UA<"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W0@;6%P(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S
M=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("+9A=BGV+'8
MLR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+8K=BGV+3;C-F'(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("+8N=F$
MV*?9A=BJ(-JOV+#8I]BQVXP@V*C8IR#9OMBQVH;9A2#9A=BTV*?9A]BOV8<@
MV+38K]F'+R#9A=BTV*?9A]BOV8<@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B(-BYV838I]F%V*H@VJ_8L-BGV+';C"#8J-BG(-BYV838I]BFV84@V*_;
MC-JOV+$@*-F%V*?9AMF&V*\@V879A]F%+]F^V*?8L]BN(-BOV*?8K]F'(-BT
MV*_9ARDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-87)T
M:6YI<75E(@IM<V=S='(@(MBMV*?8M-N,V8<B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(MF!VXS9A-BOXH",V8?8I]N,(-BGV8;8M]BHV*?9@B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("+8K=BG
MV+3;C-F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(MBHVXS8M-N,V8;9AR#8I]BYV*K8J-BGV+$@V878K-BGV+(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("+8JMBN
MV+?;C"#8I]BR(-BHVXS8M-N,V8;9AR#9@MBSV878JMF'V*?;C"#9OMN,V+K8
MI]F%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("+8J-N,V+3;C-F&V8<@V*_9
MA=BG(-BOV+$@V[+;M"#8L]BGV+G8JB#:K]BPV+38JMF'.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`BV*C;C-BTVXS9AMF'(-BOV878IR#8K]BQ(-NV(-BS
MV*?8N=BJ(-JOV+#8M-BJV8<Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(MBHVXS8M-N,V8;9
MAR#8M]F(V80B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(MF%VXPB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"B,L(&9U>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(MBLV*?9AMF%
MV*?;C-N,(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-
M961I8VEN92(*;7-G<W1R("+9OMBRV+3:J=N,(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R
M("+8I]BYV+;8I]BA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM
M<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("+9A=BO(-JOV++;C-F&VJ_8I]F&
MVXPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`BV*?8K]BZ
MV*?9A2#8L]F$V8C9A-F'V*<B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G
M<W1R("+9OMN,V+K8I]F%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("+9OMN,V+K8I]F%(-BHV*<@V879
MB-F!V9'9@MN,V9'8JB#8J-BGV++8J-N,V8;;C"#8M-BO(-BGV878IR#:K]F(
MV*?9A]N,(-BGV878MMBGV*$@VJG9AMF&V*_9AR#9AMF%VXSB@(S8JMF(V*?9
MAMBO(-BHV*?8LMBHVXS9AMN,(-BTV8C8KR(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G
M92!E>'!I<F5D+B(*;7-G<W1R("+9OMN,V+K8I]F%(-F%V8;9@MBVVXP@V+38
MKR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R
M("+9AMF(V+D@V;[;C-BZV*?9A2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("+8HMBH(-F((-F'V8C8
MI]N,($UE=&%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BV*C9A-F(VJD@
M365T87(@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("+8J-F$V8C:J2!-971A<B#9@MBGV*C9
MA"#8K]BSV*K8L=BS(-F&VXS8L]BJ+B#8K-BRV*;;C-BGV*H@V*C8L=BGVXP@
MV+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8J]BHV*H@V+38K]F'(-BGV+/8
MJB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*(RP@9G5Z
M>GD*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B
MV*?8L]F%(-BQV878LB`@V8+8K]N,V87;C"#9AMBGV*_8L=BSV*H@V*?8L]BJ
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-
M971H;V0B"FUS9W-T<B`BV+'9B-BT(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`BV+'9B-BT("<E<R<@V*K8N=BQVXS9@2#9
MAMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N
M($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS
M9VED(")-971R:6,B"FUS9W-T<B`BV*?9AMBOV*?8LMF'XH",V*?;C"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B365X:6-O(@IM<V=S='(@(MBG
MV8;8K]BGV++9A^*`C-BGVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G
M:60@(DUI9&1L92(*;7-G<W1R("+9B-BSV+<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM
M<V=S='(@(MF&V8C8N2!-:6UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(@
MVJG9A=N,V8;9AR#8K]F%V*?;C"#;LMNT(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(@VJG9A=N,V8;9AR#8K]F%V*?;
MC"#;MB#8L]BGV+G8JB#:K]BPV+38JMF'.B`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0S.0HC+"!F=7IZ>0IM<V=I9"`B36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("+8I]BS
MV84@V+'9A=BR("#8M-F%V*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`IM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(MBBVXS9AMF'(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@
M(MF%V*K9@=BQV8+9AR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HBV;[;C-JIV+'8
MJ-F&V*_;C"#9A=F(V*S9B-BO(-F&VXS8L]BJ+B#8M-F%V*<@V*?:K]BQ(-F%
MVXSB@(S8KMF(V*?9A]N,V*\@V*?8LB#8I]N,V88@V*C8L=F&V*?9A=F'V90@
MVJG8I]BQV*C8L=BOVXP@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\@(@HBV*C8
MI]N,V*\@V*+9AMBQV*<@V*K9B-F$VXS8KR#:J=F&VXS8KR(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I
M9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("+8I]BR(-BHVXS9AB#8
ML=F!V*K9AB!)1"#9OMN,V+K8I]F%(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM
M<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("+8I]BR(-BHVXS9
MAB#8L=F!V*K9AB!)1"#9AMBTV+/8JB`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("+8
MK]F(V+39AMBHV8<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*
M;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(MF^V+/8JB#8L]F$V8C9A-N,
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(DUO9&5R871E(@IM<V=S='(@(MF%V+G8JMBOV80@VJG8L=BOV88B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I
M960@1&%T92(*;7-G<W1R("+8JMBGV+';C-BN(-BJV+K;C-N,V+$@VXS8I]F!
MV*K9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("+8JMBZ
MVXS;C-BQ(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G
M<W1R("+9A=BGV8<@V8@@V+/8I]F$(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R
M("+9A=BGV8?8I]F&V8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DUO;G1S97)R870B"FUS9W-T<B`BV878N=BJV*_9A"#:J=BQV*_9AB(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM
M<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`BV8'8I]BRV8?8I]N,(-F%V*?9
MAR(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E
M9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`BV*C;C-BT
MV*K8L2#8M=BGV8$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("+8J-N,
MV+38JMBQ(-BGV*C8L=N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("+8
MJ-N,V+38JMBQ(-BBV8'8JMBGV*C;C"(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@
M(MBGV8;8JMF"V*?9A"#8J-F'(-F^V*?;C-N,V88B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*
M;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9AR#8J-BGV838IR(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2
M:6=H="(*;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9AR#8L=BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B
M36]V92!5<"(*;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9AR#8J-BGV838IR(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*
M;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9AR#9
MOMBGVXS;C-F&(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(MBGV8;8JMF"V*?9
MA"#8J-F'(-BHV*?9A-BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I
M<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R
M("+9@=F'V+'8L]BJ(-F^V*?;C-N,V8;B@(S9OMBQ(-J&V8;8KR#8L]BWV*W;
MC"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L
M96-T:6]N(@IM<V=S='(@(MJ&V8;8KR#8I]F&V*K8KMBGV*C;C"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`BV*W8L]BGV*@@V879AB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M("+8I]BWV838I]BYV*?8JB#8K=BSV*?8J"#9A=F&(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@
M(MBOV+':K]BGV8<@V879AB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`BV*S8I]F&
MV878I]N,VXP@V*_8L=JOV*?9AR#9A=F&(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R
M964B"FUS9W-T<B`BV8;9A]B,(-F%V88@V879B-BGV8'9@B#9AMN,V+/8JMF%
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B
M"FUS9W-T<B`BV8;8I]F%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B55),(-F^V*?;C-F'
M($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!
M('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!296YE
M=V%L(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").
M971S8V%P92!2979O8V%T:6]N(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R
M(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0B"FUS9W-T<B`BV*K9B-BVVXS8K2#:K]F(V*?9A]N,($YE='-C87!E(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`BV8;9B-BY(-JO
MV8C8I]F'VXP@3F5T<V-A<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(MBTV*C:J=F'(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM
M<V=I9"`B3F5V97(B"FUS9W-T<B`BV8?8L=JOV+(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`BV*_8L]BJ
MV8<@V*S8K]N,V*\B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@
M(MBOV+/8JMF'(-BLV*_;C-BO(@H*(R`*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BV*?;C-BL
MV*?8KR#9OMN,V+K8I]F%("@E<RDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(MF%V*?9AR#9AMF((@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W
M(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BH
MV+';C"#8K-BOVXS8KR`HV*?8KMBJVXS8I]BQVXPI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G
M<W1R("+8I]BSV84@V+'9A=BR(-BLV*_;C-BO(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(MBGV+/9A2#8
ML=F%V+(@V838NMF((-BNV8C8I]F'V*\@V+38KR#8K]BQ("5X("(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W
M;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`BV*?8L]F%(-BQV878LMF'V*?;
MC"#8K-BOVXS8KR#8JMBWV*?8J-F"(-F&V*_8I]BQV*\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@
M=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(MF^V8;8K-BQV8<@V*S8K]N,V*\@
M*-BNV*?9A-N,*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C@Y"FUS9VED(").97=S(@IM<V=S='(@(MBGV*[8J-BGV+$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S
M(@IM<V=S='(@(MJOV+'9B-F'XH",V8?8I]N,(-BNV*C8L=N,(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS
M9W-T<B`BV*C8N=BOVXPB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@
M9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`BV8'8I]BR(-BH
MV+G8K]N,(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@
M;W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-BHV+G8K]N,
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*
M;7-G:60@(DYE>'0^(@IM<V=S='(@(MBHV+G8K]N,(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L
M(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R("+8M-BH(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(MBT
MV*@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYI=64B"FUS9W-T
M<B`BV+G8K]BO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`BV8;9AR(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BXB"FUS9W-T<B`BV*_8I]BOV8<@V;[;C-JIV+'8J-F&V*_;C"#8K]BQ(-BO
MV+/8JMBQV+/;C"#8J-BQV*?;C"#9AMBTV*?9AB#8K]BGV*_9AB#8JMF!V*?9
MB-BJV8?8IR#9B-BLV8C8KR#9AMBOV*?8L=BO(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@
M(DE33R#9AMN,V+/8JB#8I]BSV*K8L=BGV*K:F-N,(-BOV+$@V*_8L]BJV+'8
ML]N,(-BHV+'8I]N,(-BSV*?8KMBJV88@V*K8M=F(VXS8L2`B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G
M:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("+8I]F$VJ_9B-N,(-BO
MV+/8JMF'XH",V*?;C-N,(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`BV*C9A-BGVJG;C"#8K]BQ(-F%V8C9@MBY
MVXS8JB#8K]BQV*[9B-BGV+/8JB#8M-BOV8<@V879B-BLV8C8KR#9AMN,V+/8
MJB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(MF'VXS:AB#9AMBGV84@V*K9@MF(VXS9A=N,(-BH
MV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!-0T%,(-F!V+'8I]F'V84@
MV8;8M-BOV8<@V*?8L]BJ(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*
M;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`BV*C8K]F(V88@V*K8NMN,VXS8
ML2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED
M(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+B(*;7-G<W1R("+9A]N,VH8@V878K-F(V+(@V8'8L=BYVXSB@(S8I]N,(-F&
MV87;C.*`C-BJV8C8I]F&V*\@V*C9AR#8I]N,V88@V878K-F(V+(@V*?8MMBG
MV8'9AR#8M-F(V*\B"@HC(`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R("+9A]N,VH8@V*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;
MC"#8J-BQV*?;C"`E<R#9A=BTV*[8M2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(MF'
MVXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,
M($944"!61E,@V878M-BNV+4@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("+9A]N,VH8@
MV*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"!344P@
M5D93(-F%V+38KMBU(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(MF'
MVXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,
M(%-13"U&:6QE(%9&4R#9A=BTV*[8M2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO
M(&-R961I="!L969T+B(*;7-G<W1R("+9A]N,VH8@V*?8N=BJV*C8I]BQVXP@
MV*C8I]F"VXP@V8;9A=BGV8;8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`BV8?;C-J&(-F%V8+8M=BOVXP@V8'8L=BG
MV8?9A2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BV8?;C-J&
M(-F^V+'9B-F&V*_9A^*`C-BGVXS;C"#8I]BQV+/8I]F$(-F&V+38KR(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U
M;F0N(@IM<V=S='(@(MF'VXS:AB#8HMN,VJG9B-F&VXSB@(P@V;[;C-BOV*<@
MV8;8M-BO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`BV8?;
MC-J&(-F%VJG8I]F&VXP@V*K9AMBXVXS9A2#9AMBTV*_9AR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO
M(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+9A]N,VH8@V87:J=BGV8;;
MC"#8JMF&V+C;C-F%(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@
M<W5P<&QI960N(@IM<V=S='(@(MF'VXS:AB#9OMN,V+K8I]F%VXP@V8'8L=BG
MV8?9A2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM
M<V=S='(@(MF'VXS:AB#9AMBGV87;C"#9A=BTV*[8M2#9AMBTV*\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM
M<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BV8?;C-J&(-BT
MV878I]BQV8?B@(S8I^*`C-N,VXP@V878M-BNV+4@V8;8M-BO(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`BV*+;C-F&V*_9AR#9AMBGV878M]BHV8C8N=N,(-F&
MVXS8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(MBHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8
MJB!(5%10(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BG
MV+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`BV*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M($E-05`@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("+8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@2V5R8F5R;W,@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BO
MV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW
M-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BV*C8
ML=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F(V+'9B-BO(-BGV+/9A2#8
ML=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(MBHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!005-35T0@V*?8
ML]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("+8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4TU"(-BGV+/9A2#8
ML=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G
M<W1R("+8JMF"V*?8MMBGVXP@V*O8J-BJ(-F&V*?9A=N,(-BOV+$@V*?9AMBJ
MV+C8I]BQ(-BJV*/;C-N,V*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-S4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q
M=6]T82!S970N(@IM<V=S='(@(MBJV8;8N-N,V84@V8;8M-BOV8<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S
M"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("+8J-BOV8C9AB#9@MF(V*?8N=BO
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS9VED(").
M;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("+9A]N,VH8@V*S8K]BG
MVJG9AMF&V*_9A^*`C-BGXH",VXS;C"#9A=BTV*[8M2#9AMBTV*\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+8J-BOV8C9AB#8L]F%V*HB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(MBHV*_9B-F&(-BSV878JB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T
M<B`BV+38I]BNV8<@V879B-F"V*K;C"#8J-BQV*?;C"#:J=BGV+39AR#9A=F(
MV*S9B-BO(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+B(*;7-G<W1R("+9A]N,VH8@V8;8I]F%(-JIV*?8L=BH
MV+';C"#9B"#;C-BG(-BGV+/9A2#8L=F%V++;C"#8I]BQV+/8I]F$(-F&V+38
MKR(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED
M(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("+9A]N,VH8@
MV*_8I]BOV8<@6$U,(-F%V+G8JMBHV+';C"#8J-BGV++:K]BQV*_8I]F&V*_9
MAR#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(MBH
MV*_9B-F&(-F%V8+8K]BGV+$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
MV8;8L]BNV8?B@(P@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-BGV+79A-N,(-F^
MVXS8K]BG(-F&V+38KRX@V;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BOV8C8J-BG
MV+'9AR#8JMF(V83;C-BO(-JIV8;;C-BO(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`BV8;8L]BNV8?B@(P@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-BTV878IR#9
MOMN,V*_8IR#9AMBTV*_9AR#8I]BSV*HN(-F^VXS:J=BQV*C9AMBOVXP@V+'8
MIR#8K]F(V*C8I]BQV8<@V*K9B-F$VXS8KR#:J=F&VXS8KR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS
M9W-T<B`BV8?;C-J&XH",VJG8K]BGV84B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP
M;&EC:70I(@IM<V=S='(@(MF'VXS:AN*`C-JIV*_8I]F%("C8MMF%V8;;C"#8
MI]BSV*K9@=BGV*_9AR#:J=F&VXS8KRDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B
M3F]R9&EC("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO
M<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`BV8;;C-F%(-JIV+'9AR#8M-F%V*?9A-N,(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*
M;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("+9AMF'(-BHV+G8KR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@
M0F5F;W)E(@IM<V=S='(@(MF&V8<@V8+8J-F$(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS
M9W-T<B`BVXS:J2#8M-BGV*[9AR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(MF^
MVXS8I]BOV8?B@(S8L]BGV++;C"#9AMBTV*_9AR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`BV*K9AMBXVXS9A2#9AMBTV*_9AR(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R
M,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("+9OMBTV*K;C-BHV*?9AMN,(-F&V+38K]F'(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3<X"FUS9VED(").;W1E<R(*;7-G<W1R("+;C-BGV*_8K]BGV+38JMF'V*<B
M"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("+:AMN,V++;C"#8
MJ-BQV*?;C"#9A=BQV8C8L2#9AMN,V+/8JMB,(-BHV8<@V+G9@MBH(-BHV+':
MK]BQV*\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BV8;9B-BGV878J-BQ(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R
M(@IM<V=S='(@(MBYV*_8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(MBJ
MV+G8K]BGV*\@V8;9B-N,V+/9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F
M(&-O;'5M;G,B"FUS9W-T<B`BV*K8N=BOV*?8KR#8L]BJV8C9AMF'V*<B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM
M<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`BV*K8N=BOV*?8KR#8L]BW
MV+'9A]BG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(MBGV+G8
MK]BGV*\@V*C8L=BGVXP@V*C8L=F(V++8L=BSV*?9AMN,(-F!V8?8L=BSV*H@
MV*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&V+38K]F&V*\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM
M<V=S='(@(MBJV*/;C-N,V*\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`BV+3;
MC-BA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@
M(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(MBGVXS8K-BGV*\@VJG9AMF&V*_9
MAR#8M-N,V*$B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("+9A]BTV*K8I]N,VXPB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B
M3V-T;V)E<B(*;7-G<W1R("+8I]JIV*K8J-BQ(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("+9
M@=N,V838JMBQ(-BHVXSB@(S8K=BQV878JMN,(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(MBOV8'8
MJMBQ(-JIV*?8L2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-F((-BGV+/9
MA2#8L=F%V+(@V8'8N=F$VXP@V*C8I]N,V*\@V878JMF!V*?9B-BJ(-BHV*?8
MM-F&V*\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G
M:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-F"V*_;
MC-F%VXPB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`BV*?8
ML]F%(-BQV878LB`@V8+8K]N,V87;C"#9AMBGV*_8L=BSV*H@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY
M($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R
M("+8JMF&V8?8IR#:J=BGV+'8L]BGV++9A]BGVXP@24U!4-F^V8C8M-F'XH",
MV8?8I]N,(-F%V+38JMBQVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F%VXSB
M@(S:J=F&V8;8KR`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(MF!V8+8MR#8
MHMN,V8;8K]F'(-F&V*?9A=BWV*C9B-BY(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS
M9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@
M(MBJV8;9A]BG(-N,VJD@V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&
MVXS:J=N,(-F%V*S8I]BR(-BGV+/8JB(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HBV*K9AMF'
MV*<@V878I]F$VJD@VXS8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-F%
MVXSB@(S8JMF(V*?9AMBO(-F%V*?9A-JIVXS8JB#;C-BG(-F%V*S9B-BRV8?8
MI]N,(-F%V*?9A-JI(-BQV*<@V*C8L=BGVXP@VXS:J2#8I]BTV*K8L=BGVJD@
M(@HBV*K8NMN,VXS8L2#8K]F'V*\B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BV*_8
ML2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@V*C8I]BR(-BTV8C8KR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BV*?;C-F&
M(-F^VXS9B-F&V*\@V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@V*C8
MI]BR(-BTV8C8KR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I
M9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("+8L]N,V+/8JMF%(-BYV*?9
MA=F$(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I
M9"`B3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF')B-X,C`P8SO9A]BG(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R
M("5S(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@)7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/
M<F1E<F5D($QI<W0B"FUS9W-T<B`BV83;C-BSV*H@V878L=BJV*@@V+38K]F'
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G
M:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("+8L]BGV++9A=BGV88B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G
M86YI<V%T:6]N86P@56YI="(*;7-G<W1R("+9B-BGV*W8KR#8L]BGV++9A=BG
MV8;;C"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@
M(D]R9V%N:7II;F<B"FUS9W-T<B`BV+/8I]BRV878I]F&V*_9A]N,(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E(@IM<V=S='(@(MBGV83:K]F(VXP@V*?8M=F$VXP@
MV*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXPB"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(MBGV83:K]F(V8?8I]N,
M(-BGV+79A-N,(-BOV+$@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T
M:&5R(@IM<V=S='(@(MBOVXS:K]BQ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`BV*?8
MM]F$V*?8N=BGV*H@V*_;C-JOV+$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("+9
MA=BLV8C8LN*`C-F'V*?;C"#9A=BGV83:J2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8
MJB!004T@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&VXS8L]BJ(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED
M(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@
M4VEG;F%T=7)E(@IM<V=S='(@(MBGV878MMBGV*'B@(P@V*_;C-BLVXS8JMBG
MV83;C"!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`BV;[;C-BZ
MV*?9A2#8L=F%V++8J-F&V*_;C"#8M-BOV8?9E"!01U`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC
M($ME>2(*;7-G<W1R("(@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(MF^VXS8NMBGV84@V+'9
MA=BRV*C9AMBOVXP@V+38K]F'+]BGV878MMBGV*$@V+38K]F'(%!'4"(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T
M<B`BVJG8KR!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@
M(E!(4"!3:&5L;"(*;7-G<W1R("+9OMF(V+/8JMF'(%!(4"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,
M:6=H="!286EN(@IM<V=S='(@(MBHV*?8L=F&V*_:K]N,(-BSV*C:J2#8N=BU
MV+':K]BGV8?;C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(MBQVJ_8J-BG
MV+$@V+G8M=BQVJ_8I]F'VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("+8J-BQ
MV8$@V+G8M=BQVJ_8I]F'VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(MBJVJ_8L=JO(-BYV+78L=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@(E!-
M(%-U;B(*;7-G<W1R("+8J-BQV8$@V+G8M=BQVJ_8I]F'VXPB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@
M5"U3=&]R;7,B"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9R(*;7-G<W1R("+8J-BSV+<@4$]325@@V*?8LB#8J-N,V88@V+'9@=BJV8<@
MXH",V*?8L]BJ(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H
M96QL(@IM<V=S='(@(MF^V8C8L]BJV8<@4$A0(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D
M9&EN9R(*;7-G<W1R("+9@=BGV+79A-F'XH",VJ_8L-BGV+';C"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BVH;8
ML]BHV*?9AMBOV88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S='(@(MF&V*?9A2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R("+9@MBSV878JMN,(-BGV*C8L=N,(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I
M9"`B4&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB`B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BH
MV*<@V879B-F!V9'9@MN,V9'8JB#8JMBZVXS;C-BQ(-N,V*?9@=BJ+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM<V=I9"`B
M4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(-F&
MV*?8K]BQV+/8JB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#8
MJ-F'(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!2041)55,@V8;;C-BGV+(@V*_8
MI]BQV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED
M(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+8I]BSV84@
MV+'9A=BR("#8J-BG(-BJV*/;C-N,V*\B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+8I]BS
MV84@V+'9A=BR(#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ
M,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+8I]BSV84@V+'9A=BR(#H@
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ
M-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(MBGV+/9
MA2#8L=F%V++B@(S9A]BG(-BHV*?;C-BO(-F%V8;8M]BHV8(@V*C8I]BTV8;8
MKR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T
M92(*;7-G<W1R("+:AMBSV*C8I]F&V*_9AB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@
M8VQI<&)O87)D(@IM<V=S='(@(MJ&V+/8J-BGV8;8K]F&(-BGV+(@V*K8KMBJ
MV8<@V+'8L]F%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("+9A=BSVXS8L2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG
M(%-I9VYU<',Z(@IM<V=S='(@(MBKV*C8JB#9AMBGV879A]BGVXP@V8;8I]F%
MV+G9A-F(V84B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@
M(E!E;W!L92(*;7-G<W1R("+9A=BQV*_9A2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM
M<V=S='(@(MBOV+'8M=BO(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R(*;7-G<W1R("+8I]BLV+'8I]N,(-BYV879A-N,V*?8JB#9
MAMJOV8?8K]BGV+';C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*
M;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B"FUS9W-T<B`BV*+;C-BG(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';
MC"#8K]BQ(-F$V*W8N-F'(-F(V+'9B-BO(-BGV*S8L=BG(-BTV8C8K]B?(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E
M<FUI<W-I;VXB"FUS9W-T<B`BV878K-F(V+(B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI
M<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("+9A=BLV8C8LB`@
M7"(E<UPB(-BMV+#9@2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`BV878K-F(V+(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM
M<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`BV878K-F(V++9A]BG(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BV+/8L=F^V+'8L]BJVXP@V878K-F(V++9A]BG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!)
M;F9O<FUA=&EO;B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8M-BNV+7;C"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`BV*W;
MC-F(V*?9AMBGV*H@V*[8I]F&VJ_;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B
MV*K9A-F!V88B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS
M9VED(")0:&]T;W,B"FUS9W-T<B`BV+G:J=BSV8?8IR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B
M"FUS9W-T<B`BV;[;C-JIV+/9A-F'V*<B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM
M<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(MF$
MV+?9@=BGV8L@V*_8I]BNV80@VH;9AMBO(-BSV839B-F$(-JIV83;C-JI(-JI
MV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(MF$V+?9
M@=BGV8L@V*K8H]N,VXS8KR#:J=F&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9
MA]N,V*\@V*?;C-F&(-BYV8;8M=BQ(-BQV*<@V*W8L-F!(-JIV8;;C-BO.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("+9A-BWV8'8I]F+(-BJ
MV*/;C-N,V*\@VJG9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-F^
MVXS9B-F&V*\@V*?;C-F&(-BYV8;8M=BQV8?8IR#8L=BG(-F"V+?8N2#:J=F&
MVXS8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(MF$
MV+?9@=BGV8L@VXS:J2#9A=BGV8<@V8@@VXS:J2#8L]BGV80@V8C8I]BQV*\@
MVJG9AMN,V*\N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(MF$V+?9@=BGV8L@V8;8I]F%VXP@
MV*C8L=BGVXP@V*_8L]BJV8<@V*S8K]N,V*\@V8C8I]BQV*\@VJG9AMN,V*\Z
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`BV838M]F!
MV*?9BR#8HMBOV+'8LR!)4"#9A=BYV*K8J-BQVXP@V8C8I]BQV*\@VJG9AMN,
MV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("+9A-BWV8'8I]F+(-N,VJD@
MV*K8I]BQVXS8KB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BOV(P@V*K8
MN=BOV*?8KR#8L=F(V++9A]BG(-BOV+$@V878I]F'(-BQV*<@VJG9AMBJV+'9
MA"#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(MF$
MV+?9@=BGV8L@VXS:J2#8LMF%V*?9AB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JI
MV8;;C-BO(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM
M<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+B(*;7-G<W1R("+9A-BWV8'8I]F+(-BNV838I]BUV8?B@(S8I^*`C-N,VXP@
MV*?8LB#9A=BTVJG9A"#8L=BG(-BHV8;9B-N,V+/;C-BO(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9"(*;7-G<W1R("+9A-BWV8'8I]F+(-F&V*?9A2#:J=BGV+'8
MJ-BQ(-F((-BGV+/9A2#8L=F%V+(@(-BNV8C8KR#8L=BG(-BBV878I]BOV8<@
MVJG9AMN,V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*(MF$V+?9@=BGV8L@V878JMF&(-BRVXS8L2#8
ML=BG(-BHV*[9B-BGV8;;C-BO+B#8M-F%V*<@V*C8L=BGVXP@V*?8L]BJV8'8
MI]BOV8<@V*?8LB#8L]BGV878I]F&V8<@V*C8I]N,V*\@V+38L=F(V+<@V+'8
MIR#9@MBHV8C9A"#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(MF$V+?9@=BGV8L@V8;8
MI]F%(-BOV+/8JMF'(-BLV*_;C-BO(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T
M<B`BV8'8L=F%V*?9AB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM
M<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`BV+/;C-BGV+/8JMF'V*<B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G
M<W1R("+8HMBQV*?8H2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@
M(E!O<G1U9V%L(@IM<V=S='(@(MBOV+':K]BGV8<@V879AB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("+9
MA=BMV80@V8+8L=BGV+':K]BQV8'8JMF&(-BGVXS9AB#8JMBUV8C;C-BQ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*
M;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BV878
MK=F$(-F"V+'8I]BQVJ_8L=F!V*K9AB#8I]N,V88@V*S8K]F(V80B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM
M<V=S='(@(MF^V+/8JB#8J-F'(-BGVXS9AB#9OMF(V+39AR(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(@IM<V=S='(@(MBOV+'8M=BO(-BQV+?9B-BHV*H@V*_8L2`E
M<R#8L]BGV+G8JB#9@MBHV80Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z
M.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@V*C8L]BW(-F%V8C8
ML=BO(-F&VXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,
MV*?8LB!S97-S:6]N(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("+9@=BTV*?8
ML2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R
M92!A="!S96$@;&5V96PZ("(*;7-G<W1R("+9@=BTV*?8L2#8K]BQ(-BSV+?8
MK2#8K]BQVXS8ISH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("+9@=BTV*?8L3H@(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`BV;[;C-BTXH",V8;9
MA=BGVXS8M"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(MF^VXS8M.*`C-F&V878I]N,V+0@
MV*K8M=F(VXS8L2#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KR`B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N
M<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-F"V*C9A-N,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I
M9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`BVH;8I]F^(-BSV8;8KR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`BVJG9A-N,V*\@V+38KMBUVXPB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M
M(@IM<V=S='(@(MF%V+3:J=F$(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(MBJV8C8
MMMN,V*T@V878M-JIV80B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("+9OMBQV8C:F-F'XH",V8?8
MIR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("+9A=BJV88@V*?8
MN=F$V*?9AB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("+:J=F$VXS8KR#8N=F%V8C9
MA=N,(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*
M;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(MBGV83:K]F(
MV+';C-BJV84@VJG9A-N,V*\@V+G9A=F(V87;C"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L
M:6,@2V5Y($EN9F\B"FUS9W-T<B`BVJG9A-N,V*\@V+G9A=F(V87;C"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`BV*S9@=BJ(-JIV83;C-BO(-BYV879B-F%VXPOV*[8M=F(
MV+7;C"#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*K9B-F$VXS8KR#9AMBTV*\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R
M("+8K]BGV*_9AR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B
M475E<GDB"FUS9W-T<B`BV;[8L=BSXH",V8C8K-F((@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("+8L]F'V87;
MC-F'(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB
M"FUS9W-T<B`B(-JIV83;C-BO(-BYV879B-F%VXP@4E-!("@E9"#8J-N,V*HI
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D
M:6\@<V5L96-T:6]N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8L=BGV*_;C-F(
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*
M;7-G:60@(E)A:6XB"FUS9W-T<B`BV*C8I]BQV*?9AB(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A
M<FQY(@IM<V=S='(@(MBHV*?8L=BGV88@V++9B-BOV8?9AMJOV*?9A2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN($QA=&4B"FUS9W-T<B`BV*C8I]BQV*?9AB#8K]N,V+'9A]F&VJ_8
MI]F%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(MBHV*?8L=BGV88@V8@@
MV+':K]BHV*?8L2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(MBHV*?8
ML=BGV88@V8@@V*C8L=F!(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("+8
MJ-BGV+'8I]F&(-BHV8<@V*C8L=F!(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(MBWV*?9A-BY
M(-BJV+78I]BOV8';C"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`BV8;8L]BHV*HB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*
M;7-G<W1R("+8KMF(V*?9AMBOV88B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G
M<W1R("+8KMF(V*?9AMBOV88@V;[;C-BZV*?9A=F'V*<@(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(MF(V*?9@MBYV*?9DB`E<R#8K=BP
MV8$@V+39B-BOV)\@V*?;C-F&(-BYV879A"#9@MBGV*C9A"#9B-BGVJ_8L=BO
M(-F&VXS8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(MF(V*?9@MBYV*?9BR#8K]BGV*_9A]F4(-JI
MV*?8L=BHV+';C"#8J-BQV*?;C"#:J=BGV+'8J-BQ("5S(-BMV+#9@2#8M-F(
MV*_8GR#8I]N,V88@V+G9A=F$(-F"V*?8J-F$(-F(V*?:K]BQV*\@V8;;C-BS
MV*HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+8
MI]F&V*S8I]F%(-BBV*[8L=N,V88@V+G9A=F$(-BTV878IR#8I]BR(-F&V8@B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SHB"FUS9W-T<B`BV*C8I]BRV*+9B-BQVXP@V+G9AMBG
MV+78L2#:K]BRVXS9AMJOV*?9AB#8K]N,V8;8I]F%VXS:J=N,.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L
M(%9I97<Z(@IM<V=S='(@(MBHV*?8LMBBV8C8L=N,(-F&V878I]N,(-BOV+':
MK]BGV8<Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`BV*C8
MI]BRV8;8M-BGV8;;C"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(MF%V+'9
MB-BQVJ_8L2#8L=BGV*C8M]F'XH",V*?B@(S;C-N,(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(MBNV8C8
MI]F&V*_9AB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")2
M96UA<FMS(@IM<V=S='(@(MBJV8C8MMN,V*W8I]BJ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T
M<B`BVJG8I]BQV+/8I]BRV8?8I]N,(-BQV*?9A^*`C-BOV8C8L2(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E52
M3"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E
M(@IM<V=S='(@(MBMV+#9@2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(MBMV+#9@2#8
MJ-F$V8C:J2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`BV*W8L-F!
M(-BSV*K9B-F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B
MV*W8L-F!(-F"V*?9A-BH(-BHV8;8K]N,(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(MBM
MV+#9@2#8LMF(V*PB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS
M9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`BV*W8L-F!(-BOV+/8JB#B@(S9AMF(
MVXS8L]F'V*?;C"#8K=F!V+@@V+38K]F'(-BOV+$@V+38I]BNV8<@V879B-F"
MV*H@VJG8I]BQV+/8I]BR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM
M<V=S='(@(MBMV+#9@2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("+8K=BPV8$@V*?;C-F&(-JO
MV+'9AR#8I]BR(-BSV8;8KR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(MBMV+#9
M@2#:J=BGV+'8J-BQ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R("+8K=BPV8$@VJG8I]BQV*C8L3H@)7,B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`BV*K9@MBGV+;8IR#9@MBGV*C9A"#9OMBGV+/8KMJOV8C;C-N,(-F&
MVXS8L]BJ+B#:J=BO(-BNV+?8I]N,(-BHV+':K]BQV*_8I]F&V*_9AR#8M-BO
MV8<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PHC+"!F
M=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@V*?8L=BSV*?9A"#8M-BOV8<@
MV8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@V+39B-BO(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B<E<R<@V879B-BQV*\@V8;;C-BGV+(@V*_8L2#9OMN,
MVJG8L=BHV8;8K]N,("5S(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(G)7,G(-F%V8C8L=BO(-F&VXS8I]BR(-BOV+$@V;[;
MC-JIV+'8J-F&V*_;C"!61E,@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G)7,G(-F%V8C8L=BO
M(-F&VXS8I]BR(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#9A=BTV*[8M2#9AMBT
MV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(MF!VXS9
MA-BOV8?8I]N,(-F%V8C8L=BO(-F&VXS8I]BR(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(MBHV*?8LMF&V+38I]F&
MVXPB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B
M4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BV*C8I]BRV8;8M-BGV8;;C"#8I]BS
MV84@V+'9A=BR(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQ
MV878LB#8KMF(V*\@V+'8IR#8J-BGV++9AMBTV*?9AMN,(-JIV8;;C-BO(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S
M=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(MBQV*C8N2#8HMBNV+$B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D
M;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("+9
MAMBJV*?;C-BL(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@
M3W!T:6]N<R(*;7-G<W1R("+8J-BGV++:K]BTV*H@V*C9AR#:K]BRVXS9AMF'
MXH",V8?8IR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM
M<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("+8JMBGVXS9OB#8
MK]F(V*C8I]BQV8<@V*?8L]F%(-BQV878LB`@V*S8K]N,V*\@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("+:K]BQV*_9A]F%V*?;
MC-N,(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R("+8J-BGV++:K]BQV*_8I]F&V*_9AB#9OMN,VJG8L=BH
MV8;8K]N,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8?B
M@(S9A]BGVXP@V8C;C-BQV*?;C-BTVJ_8L2#9A=BJV88B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`BV878
MN=F%V*?9A]BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("+8L=BGV+/8
MJB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I
M9VAT(&AE861E<B(*;7-G<W1R("+8L]BQV*+9A=BO(-BQV*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L
M=65S(@IM<V=S='(@(MF%V8+8I]BOVXS8L2#8L=BGV+/8JB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM
M<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(MBNV+79B-BUVXS8
MI]BJ(-BSV+?8L2XN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`BV8;9@MBT(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED
M(")2;W1A=&4@,3@P(@IM<V=S='(@(MJ&V+'8KMBT(-NQV[C;L"#8K]BQV*S9
MAR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(MJ&V+'8KMBT(-BHV8<@
MVH;9OB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("+:AMBQV*[8M"#8
MJ-F'(-BQV*?8L]BJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS
M9W-T<B`BV*[8M=F(V+7;C-BGV*H@V+/8M]BQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W
M('!R;W!E<G1I97,B"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@V+/8M]BQ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*
M;7-G:60@(E)O=W,Z(@IM<V=S='(@(MBSV+?8L=F'V*<Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I
M9"`B4G5L97,B"FUS9W-T<B`BV8+9B-BGV+G8KR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B
M"FUS9W-T<B`BV8+9B-BGV+G8KR#8J-N,V88@V*K9A=BGV84@V+/8M]BQV8?8
MIR#9B"#8L]BJV8C9AMF'V*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38
MKR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L
M=6UN<R!O;FQY(@IM<V=S='(@(MF"V8C8I]BYV*\@V8'9@MBW(-BHVXS9AB#8
MJMF%V*?9A2#8L]BJV8C9AMF'V*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@
MV+38KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M<F]W<R!O;FQY(@IM<V=S='(@(MF"V8C8I]BYV*\@V8'9@MBW(-BHVXS9AB#8
MJMF%V*?9A2#8L]BWV+'9A]BG(-F&V878I]N,V*?9AB#8KMF(V*?9A]BO(-BT
MV*\B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS
M9W-T<B`BV*?8K-BQV*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(MBNV8C8I]F&V*_9AB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-
M12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("+9OMN,V+K8I]F%(-BQV878
MLMBHV8;8K]N,("#8M-BOV8?9E"!3+TU)344@(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+8JMBUV*_;C-F"(-F'V8C;
MC-F1V*H@4T%33"#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*HB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")335,@365S
M<V%G:6YG(@IM<V=S='(@(MF^VXS8NMBGV84@4TU3(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`BV;[9B-BS
MV*K9AR!344PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS
M9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-3
M2"(*;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#
M15-3(@IM<V=S='(@(MF%V8C9@=F1V8+;C-F1V*HB"@HC.B!L:6(O87!I+G!H
M<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`BV;[9B-BSV*K9AR!3
M44PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Q"FUS9VED(")382(*;7-G<W1R("+8M-F&V*C9AR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S
M='(@(MBHV*?8L=BGV88@V*_;C-BQV8?9AMJOV*?9A2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E
M;&8I(@IM<V=S='(@(MF'V878I]F&(-J&V*?8L=J&V8C8J"`HV*[9B-BOV+0I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B4V%M;V$B"FUS9W-T
M<B`BV8?8L=BRV8;8I]F%V8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS
M9VED(")386X@36%R:6YO(@IM<V=S='(@(MBMV*?8M-N,V8<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0HC+"!F=7IZ
M>0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(MF(V+;8N=N,
MV*H@V*W9B-BRV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U
M9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("+8K=F!V+@@VJG8L=BO
MV88B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*
M;7-G<W1R("+8K=F!V+@@VJG8L=BOV88@)7,B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E("5S(@IM<V=S='(@(MBMV8'8N"#:J=BQV*_9AB`E<R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G
M<W1R("+8K=F!V+@@VJ_8LMN,V8;9A^*`C-F'V*<B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(MF^VXS:J=BQV*C9AMBO
MVXP@V*K9B-F$VXS8KR#8M-BOV8<@V*C8N=F&V8C8I]F&(-BOV+/8JB#B@(S9
MAMF(VXS8LR!02%`@V*_8L2#8M-BGV*[9A]F4(-F%V8C9@MBJ(-JIV*?8L=BS
MV*?8LB#8M-F%V*<@V*W9@=BX(-BTV8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(MF^VXS:J=BQV*C9AMBOVXP@
M)7,@V*W9@=BX(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BV*_8L]BJ
M(.*`C-F&V8C;C-BS(-BHV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B@(S8I]F&
MV*_8I]BRVXP@V*W9@=BX(-BTV*\@V*_8L2`Z)R5S)R`N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G
M:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")4+5-T;W)M<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G
M<W1R("+8N=F$V84B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B
M4V5A<F-H(@IM<V=S='(@(MBLV+/8JN*`C-F(V*S9B"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM
M<V=S='(@(MBLV8C;C-BTVJ_8L=F'V*<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`BV*?9
MAMBJV*[8I]BH(-F^V+'9B-F&V*_9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"FUS9VED(")396QE8W0@
M82!D871E(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-BJV*?8L=N,V*XB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L
M96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI
M(-JOV+'9B-F'(-BHV+'8I]N,(-BGV+;8I]F!V8<@VJG8L=BOV88B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N
M97<@;W=N97(B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@V878I]F$VJD@
MV*S8K]N,V*\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*
M;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@
MVXS:J2#:J=BGV+'8L]BGV+(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B
MV*?9AMBJV*[8I]BH(-N,VJD@VJG8I]BQV*C8L2#8J-BQV*?;C"#8I]BVV*?9
M@=F'(-JIV+'8K]F&(@H*(R`C+2,M(RTC+2,@(&9A7TE2+G!O("A4=7)B82`Q
M+C(N,BD@(",M(RTC+2,M(PHC(&US9VED(")396%R8V@@4F5S=6QT<R(*(R!M
M<V=S='(@(MF&V*K8I]N,V*P@V*S8L]BJV*S9B"(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L
M;"(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8?9A=F'(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8JMF%V*?9A2#9A=BD
MV839@=F'XH",V8?8I]N,(-BJV*?8L=N,V*XB"@HC(",M(RTC+2,M(R`@9F%?
M25(N<&\@*%1U<F)A(#$N,BXR*2`@(RTC+2,M(RTC"B,@;7-G:60@(E-E87)C
M:"!297-U;'1S(@HC(&US9W-T<B`BV8;8JMBGVXS8K"#8K-BSV*K8K-F((@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS
M9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;
MC-JI(-BTV*8B"@HC(",M(RTC+2,M(R`@9F%?25(N<&\@*%1U<F)A(#$N,BXR
M*2`@(RTC+2,M(RTC"B,@;7-G:60@(E-E87)C:"!297-U;'1S(@HC(&US9W-T
M<B`BV8;8JMBGVXS8K"#8K-BSV*K8K-F((@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*
M;7-G<W1R("+8I]F&V*K8KMBGV*@@V8?;C-J&XH",VJG8K]BGV84B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+B(*;7-G<W1R("(B"B+9AMF(VXS8L]F'XH",V8?8I]N,VXP@VJG9
MAR#9A-BGV++9A2#8K]BGV+';C-BO(-BQV*<@V*?8LB#8K-BYV*C9AR#8LMN,
MV+$@V*?9AMBJV*[8I]BH(-JIV8;;C-BO+B#8L]F^V+,@V+39A=BG(-F%VXSB
M@(S8JMF(V*?9AMN,V*\@V*?8LB#8HMF&V8?8IR`B"B+8K]BQ(-F%V8;8M]F"
MV8<@V878JMF&(-F&V+/8KMF'XH",V*C8L=BOV*?8L=N,(-JIV+'8K]F'(-F(
M(-BOV+$@V878K=F$(-BOVXS:K]BQ(-BHVH;8L]BHV*?9AMN,V*\B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F%V*W8K]F(
MV*_9AR#8JMBGV+';C-BN.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+8
MI]F&V*K8KMBGV*@@V8+8I]F$V*@@V*K8I]BQVXS8KCHB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`BV*?9
MAMBJV*[8I]BH(-F'V8C;C-F1V*K;C"#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,
MV*\@V*K8NMN,VXS8L2#8K]F'VXS8KSHB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB
M"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F%V*W8K]F(V*_9A]F4(-BRV878I]F&
M.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE
M8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8+8
MI]F$V*@@V++9A=BGV88Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S
M='(@(MBGV8;8JMBNV*?8J"#8K]F((-F!VXS9A-BO(-F%V8;8M]BHV8(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U
M<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8M]BQV*T@
MV+'9AMJO(-BTV878IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*
M;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T
M<B`BV*?9AMBJV*[8I]BH(-BRV*C8I]F&(-F%V8C8L=BO(-F&V+C8L2#8M-F%
MV*<Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G
M:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BV*?8L=BSV*?9A"#:
MK]BRV*?8L=BT(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(MBGV+'8L]BG
MV80@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R
M.B`B"FUS9W-T<B`BV*W8L]JOV+$Z("(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`BV+/9OMBJV*?9A=BHV+$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(MBGV+G8K]BGV*\@
MV*K8L=BJVXS8J-N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`BV*C9A-F(VJD@365T87(@V8+8I]BHV80@
MV*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("+8L]BQ
MV;[8L=BSV*K;C"#9A=BLV8C8LMF'V*<B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@
M240@97AP:7)E9"XB"FUS9W-T<B`B240@V8;8M-BSV*H@V879AMF"V+;;C"#8
MM-BOV8<@V*?8L]BJ(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS
M9VED(")397-S:6]N<R(*;7-G<W1R("+9A=BLV8C8LMF'V*<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B
MV*K9AMBXVXS9A2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I
M9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B+8JMF&
MV+C;C-F%(-JOV++;C-F&V8?B@(S9A]BG(-BHV+'8I]N,(-BGV*S8I]BRV8<@
MV*_8I]BOV88@V*C9AR#8M-F%V*<@V*C8L=BGVXP@V*C8I]BRV8;8M-BGV8;;
MC"#8I]BSV84@V+'9A=BR(-BHV8<@V8?9AMJOV*?9A2#9@=BQV*?9A=F(V+3;
MC"`B"B+8HMF&("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G
M:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B+8JMF&V+C;C-F%
M(-JIV*?8L=BSV*?8LMF'V*?;C"#8L=BGV8<@V*_9B-BQVXP@VJG9AR#8M-F%
MV*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BR(-BOV+':K]BGV8<@V*[9B-BO
M(-BHV8<@V*+9AB#8K]BSV*K8L=BSVXP@V*_8I]BTV*K9AR`B"B+8J-BGV+3;
MC-BO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8
MKR#9AMBXV+'8C"#8L]BGV+G8JB#9B"#:K]BRVXS9AMF'XH",V8?8I]N,(-BJ
MV*?8L=N,V*XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@
M(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V*C8L=F&V*?9A=F'(-BRV878
MI]F&(-BTV+'9B-BYV(P@V+?8L=BM(-BQV8;:K]B,(-BHV*?8LMBBV8C8L=N,
M(-BUV8'8K=F'(-F((-BHV8+;C-F'(-JOV++;C-F&V8?B@(S9A]BGVXP@V8;9
MA=BGVXS8M"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@
M(E-E='5P(@IM<V=S='(@(MBQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*
M;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T
M<B`BV*_8L]BJ(.*`C-F&V8C;C-BS("#8J-BQV8C8LMBQV+/8I]F&VXP@V+'8
MI]F'XH",V*?9AMBOV*?8LMN,(-BOV+$@V*_8L]BJV+'8LR#8I]BSV*HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*
M;7-G<W1R("+:AMF&V*_;C-F&(-F%V8C9@MBYVXS9D=BJ(-BHV*<@V;[8I]BQ
MV*?9A=BJV+$@V879A=JIV88@V*?8L]BJ.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`BV*[8L=N,
MV*\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I
M9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("+8KMF$V*?8M=F'(-JIV8C8JMBG
MV8<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS
M9W-T<B`BV*+;C-BG(-JIV83;C-BOV8?8I]N,(-BOV+/8JMBQV+/;C"#8J-BG
MVXS8KR#8J-BQV*?;C"#8J-N,V+38JMBQ(-F^VXS9B-F&V*_9A]BG(-BJV+G8
ML=N,V8$@V+39B-F&V*_8GR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(MF&V878I]N,V+0B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B#9
MAMF%V*?;C-BT(-BJV8'8I]F(V*K9A]BGVXP@V87;C-BGV88@V;[;C-JIV+'8
MJ-F&V*_;C"#8K=F!V+@@V+38K]F'(-F!V+G9A-N,(-F((-BJV8C9A-N,V*\@
MV+38K]F'(-BLV*_;C-BO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y
M,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/R(*;7-G<W1R("+8HMN,V*<@V++9A=BGV88@V*+8KMBQVXS9AB#9B-BQV8C8
MKR#8J-F'(-F'V8;:K]BGV84@V8C8L=F(V*\@V8;8M-BGV88@V*_8I]BOV8<@
MV+39B-BOV)\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS
M9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(MF&
MV878I]N,V+0@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L=BGVXP@V8;:K]F'V*_8
MI]BQVXP@V*?8M=F$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F#
MV8;9AMBOV8<@V8;9A=BGVXS8M"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B
M"FUS9W-T<B`BV*+;C-BG(-F%VXS9A-F'(-JOV++;C-F&VJ_8I]F&(-BYV879
MA-N,V*?8JB#8K-BOV8C9A.*`C"#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8
MK]B?(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T
M/R(*;7-G<W1R("+8HMN,V*<@VJ_8LMN,V8;:K]BGV88@)7,@V+/9A=BJ(-BQ
MV*?8L]BJ(-F&V+38I]F&(-BOV*?8K]F'(-BTV8C8K]B?(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS
M9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(MF&V878I]N,V+0@VJ_9@=BJXH",V8C:K]F(VXP@V*[8M=F(V+7;
MC-BGV*H@V+/9A-F(V80@V*S8K]F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(MF&V878I]N,
MV+0@VJ_9@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`BV8;9A=BGVXS8M"#:K]F!V*K:K]F(VXP@V*[8M=F(V+7;
MC-BGV*H@V+/8M]BQ(-BLV*_9B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+9AMF%V*?;C-BT
M(-JOV8'8JMJOV8C;C"#8KMBUV8C8M=N,V*?8JB#8JMBUV8C;C-BQ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO
M860B"FUS9W-T<B`BV8;9A=BGVXS8M"#8I]BQV+/8I]F$(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E
M<G,B"FUS9W-T<B`BV*K:K]BQVJ\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("+8L=JOV*C8I]BQ(-BRV8C8K]F'V8;:K]BGV84B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R
M<R!,871E(@IM<V=S='(@(MBQVJ_8J-BGV+$@V*_;C-BQV8?9AMJOV*?9A2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS
M9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H
M<FEN:R(*;7-G<W1R("+8K-F%V+D@V+38K]F&(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M="(*;7-G<W1R("+8K-F%V+D@V+38K]F&(-N,V*<@V*?9AMBJV8+8I]F$(-BH
MV839B-JIV8?8I]N,(-F%V*S8I]F(V+$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("+8
MJ]BHV*H@V8;8I]F%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+8I]F%V+;8I]BA
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G
M:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`BV*?9A-JOV8C8L=N,
MV*K9A2#8I]F%V+;8I]BA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I
M9"`B4VEN9V%P;W)E(@IM<V=S='(@(MBGV878MMBGV*$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(MBG
MV8;8K]BGV++9AR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@
M(MBUV+'9@=F&V+C8L2#8I]BR(-F&VJ_9A]BOV*?8L=N,(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T
M<B`BV*C8L=F!(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(MBJVJ_8L=JO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*
M;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("+8JMJOV+':KR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3
M;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`BV+':K]BHV*?8L2#8LMF(V*_9
MA]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(MBQ
MVJ_8J-BGV+$@V*_;C-BQV8?9AMJOV*?9A2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`BV+G9A=F"
M(-BHV+'9@3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@
M(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(MF%V+G8I]BO
MV80@V*C8L=F!(-BOV+$@V*+8J#H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G
M:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(MBTV+G8L=F'
MV*<@V8@@V*+9B-BGV++9A]BG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B
MV*?9AMBJV*[8I]BH(-BLV8?8JB#9A=BQV*K8J"#8L]BGV++;C"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-BS
MV+':AMBTV879AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(E-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("+9AMN,V84@VJG8L=F'(-BLV8;9B-BHVXPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("+9@=BGV+79A-F'V90@
MV*C;C-F&(-BSV839B-F$V8?8I]N,(-F%V*S8I]F(V+$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R
M("+9@=BGV+79A-F'V90@V*C;C-F&(-F%V*W8JMF(V*<@V8@@V838J-F'(-BO
MV+$@V+/9A-F(V80B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*
M;7-G:60@(E-P86-E<B(*;7-G<W1R("+9@=BGV+79A-F'XH",VJ_8L-BGV+$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`BV8'8I]BUV839AR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`BV8'8I]BU
MV839A^*`C-JOV+#8I]BQVXP@V8@@V*_8L=BRVJ_8L-BGV+';C"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")3<&%I;B(*;7-G<W1R("+9@=BGV+79
MA-F'(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3
M<&%M(@IM<V=S='(@(MF'V+'8LMF&V*?9A=F'(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R("+:J=BGV+'8I]JIV*K8L2#8KMBGV+4@V8C8I]BQV*\@V+38KR(*
M"B,@(RTC+2,M(RTC("!F85])4BYP;R`H5'5R8F$@,2XR+C(I("`C+2,M(RTC
M+2,*(R!M<V=I9"`B4V5A<F-H(%)E<W5L=',B"B,@;7-G<W1R("+9AMBJV*?;
MC-BL(-BLV+/8JMBLV8@B"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T
M<B`BV*K9@MBSVXS9A2#8L]F$V8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O
M;'5M;B(*;7-G<W1R("+8JMF"V+/;C-F%(-BSV*K9B-F&(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I
M9"`B4W!L:70@<F]W(@IM<V=S='(@(MBJV8+8L]N,V84@V+/8M]BQ(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T
M<B`BV8C8L=BRV+3;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B
M4W)I($QA;FMA(@IM<V=S='(@(MBLV878N2#8M-BOV88B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BV*?8L]BJV*?9AMBOV*?8L=BO
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R
M96LB"FUS9W-T<B`BV+/8JMBGV+'9AR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I
M9"`B4W1A<G0@>65A<B(*;7-G<W1R("+8L]BGV80@V+38L=F(V+DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A
M=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BV8C8MMBYVXS8JB#8K=F(V++9A^*`
MC-F'V*<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ
M,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(MF(V+;8N=N,V*KB@(PB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R("+9@MBGV838J"#8L-BNVXS8L=F'(-BSV*?8LMN,(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@
M(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-BNVXS8I]BHV*?9
MAB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS
M9W-T<B`BV8'9A]BQV+/8JB#8L=BTV*K9AR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM
M<V=S='(@(MBTVXS9B-F'(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`BVXS:
MJ=BTV8;8J-F'(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(-BRVXS8L=BTV*?8KMF'("<E<R<@V;[;C-BO
MV*<@V8;8M-BO+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BV+G9AMF(V*?9
MAB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G
M<W1R("+8I]BQV+/8I]F$(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT
M:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R
M("(B"B+8JMF"V*?8MMBGVXP@V*?8MMBGV8'9AR#8M-BOV88@)R5S)R#8J-F'
M(-BSV*?9A=BGV8;9AR#8I]BQV*?8IMF'(-BTV*\N(-BJV*<@V8?9AMJOV*?9
MA=N,(-JIV8<@V*K9@MBGV+;8I]N,(-BTV878IR#8JMBCVXS;C-BO("(*(MF&
MVJ_8L=BOV*\@V8;9A=N,XH",V*K9B-BGV8;;C-BO(-BHV8<@V+/8I]F%V*?9
MAMF'(-F(V*?8L=BO(-BTV8C;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S
M='(@(MBRVXS8L=F&V8C;C-BS(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(MF%
MV8C9@=F1V8+;C-F1V*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(-BHV*<@V879
MB-F!V9'9@MN,V9'8JB#8J-F'(-BSV*?9A=BGV8;9AR#8I]BVV*?9@=F'(-BT
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(-BOV*?8
MK]F'V90@VJG8I]BQV*C8L2`G)7,GV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BG
MV+(@V+/8I]F%V*?9AMF'(-F^V*?:J2#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO
M9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B7"(E<UPB(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=BPV8$@
MV+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*?8LB#8L]BGV878I]F&V8<@V;[8I]JI(-BTV*\B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+B(*;7-G<W1R("(B"B+9OMN,VJG8L=BHV8;8K]N,(-BHV*<@V879
MB-F!V9'9@MN,V9'8JB#8J-BGV++:K]BQV*_8I]F&V*_9AR#8M-BO+B#8J-BQ
MV*?;C"#9A=BTV*?9A]BOV8<@V*K8NMN,VXS8L=BGV*H@V878K-BOV*_8I]F2
M(-BBV8;8L=BG(-BHV*?8L2#9AMF%V*?;C-N,V*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BV;[;C-JIV+'8J-F&V*_;C"#9OMBTV*K;C-BHV*?9
MAB#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W9@=BX(-BTV*\B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`BV;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8
MI]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ
M(-BMV8'8N"#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E
M9"!<(B5S7"(B"FUS9W-T<B`B)R5S)R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@
MV*C9AR#8L=F(V+(@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V8;9B-BTV*K9AR#8M-BO(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W5D86XB"FUS9W-T<B`BV*+9@=BJ
MV*?8J-N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+8KMF$V*?8
MM=F'(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@
M4FES92(*;7-G<W1R("+8M]F$V8C8N2#8HMF!V*K8I]BH(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(MBZ
MV+'9B-BH(-BBV8'8JMBGV*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`BV*+9@=BJ
MV*?8J-N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM
M<V=I9"`B4W5N<FES92(*;7-G<W1R("+8M]F$V8C8N2(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I
M9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`BV+?9A-F(V+DOV+K8L=F(V*@B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3
M=6YR:7-E.B`B"FUS9W-T<B`BV+?9A-F(V+DZ("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("+8
MNMBQV8C8J"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*
M;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(MBZV+'9B-BH.B`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3
M=7!E<G-C<FEP="(*;7-G<W1R("+8J-BGV838I]F&V8C;C-BS(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I9"`B4W5P<&]R="(*;7-G
M<W1R("+9OMBTV*K;C-BHV*?9AMN,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ
M>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`BV8;8I]F%(-BNV*?9AMF(V*?8
MK]JOVXPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-`IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("+9AMBGV84@V*[8I]F&V8C8I]BO
MVJ_;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@
M36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@
M9G5Z>GD*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`BV*W8L-F!
M(-F&V+39B-BO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I
M9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T
M97)M<R(*;7-G<W1R("+8KMBWV*?;C"#9AMBMV8C;C"#8K]BQ(-F%V8C8I]BQ
MV*\@V*S8L]BJV*S9B"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!
M<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@
M(E0M4W1O<FUS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS
M9VED(")4+5-T;W)M<R(*;7-G<W1R(")4+5-T;W)M<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"B,L(&9U>GIY"FUS9VED
M(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("+8L=JOV*C8I]BQ(-BRV8C8K]F'
MV8;:K]BGV84B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V
M"FUS9VED(")44U8@9FEL92(*;7-G<W1R("+9OMBQV8C9AMBOV8<@5%-6(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE
M(@IM<V=S='(@(MBLV*_9B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8K-BOV8C9A"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*(RP@9G5Z
M>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("+8K-BOV8C9A"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*
M;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`BV*[8M=F(V+7;C-BG
MV*H@V*S8K]F(V80B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"B,L(&9U>GIY"FUS
M9VED(")486EW86XB"FUS9W-T<B`BV*C8I]BQV*?9AB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS
M9VED(")487)G970Z(@IM<V=S='(@(MF'V*_9@3HB"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*
M;7-G:60@(E1A<VMS(@IM<V=S='(@(MF(V+C8I]N,V8$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE
M($YU;6)E<B(*;7-G<W1R("+8M-F%V*?8L=F'(-BJV839@=F&(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(MBOV878I]N,(-BSV*?8N=BJ(-BGV*[;C-BQ.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B
M"FUS9W-T<B`BV*_8L=BLV8<@V*W8L=BGV+'8JB(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS
M9W-T<B`BV*_8L=BLV8<@V*W8L=BGV+'8JCH@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*
M;7-G<W1R("(@*"5S2&DE<R\E<TQO)7,I("9D96<[)7,@V*_9A=BG(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B#8I]F$VJ_9B-N,("<E<R?9OMN,V*_8IR#9AMBTV*\B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`BV*?9A-JOV8C;C"#8L]BQV;[8L=BSV*K;
MC"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("+9A=BJ
MV88B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT
M($]N;'DB"FUS9W-T<B`BV8'9@MBW(-F%V*K9AB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E
M>'0@86QI9VXB"FUS9W-T<B`BV*K8L=BGV+(@V878JMF&(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X
M='1O<"(*;7-G<W1R("+8J-BGV838I]N,(-F%V*K9AB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM
M<V=S='(@(MF^V8;8K-BTV8;8J-F'(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86D@*%1)
M4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(MBGV+(@
MV+39A=BG(-BHV8<@V*[8I]BWV+$@V*?8L]BJV8'8I]BOV8<@V*?8LB#8L]BG
MV878I]F&V8<@V878JMBTVJG8L=N,V84B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`BV*C8L]BW($944"#9@MBGV*C9A"#8K]BS
MV*K8L=BS(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ
M,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@V*?8L=BSV*?9
MA"#8M-BOV8<@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@V+39B-BO(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(MF&VJ_9A]BOV*?8L=N,.CH@VJG9A-BGV+,@V*C8IR#9A=F(V8'9
MD=F"VXS9D=BJ(-BHV*?8L2#9AMBTV*\B"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@
M:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`BV;[9AMBLV+'9A]F4(-JO
MV++;C-F&V8?B@(S9A]BG(-BHV+/8JMF'(-BTV*\N(-BNV+'9B-BL(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N
M<RXB"FUS9W-T<B`B(@HBV+/8L=F^V+'8L]BJ(-BHV*?;C-BO(-N,VJD@V;[8
MM-BJVXS8J-BGV88@V878K-F(V++9A]BG(-BQV*?8C"`@V*_8L2#8M=F(V+'8
MJB#8JMF%V*?;C-F$(-BTV878IR#8J-F'(-BGV+/8JMF!V*?8K]F'(-BGV+(@
MV878K-F(V++9A]BGV(P@(@HBV;[;C-JIV+'8J-F&V*_;C"#:J=F&V*\N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`BV*K9
MAMF'V*<@V+/9A=BJ(-F^V*?;C-N,V88B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R
M("+8M-F%V*?8L=F'($E$(-BJV878I]BS(-F%V+38KMBU(-F&V+38K]F'(-BG
MV+/8JMB,(-BGVXS9AB#8M-F%V*?8L=F'(-BOV+$@V*_8I]BOVJ_8I]F&(-N,
MV*?9@=BJ(-F&V+38KR(*"B,@"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
MV*K9A=BGV+,@("5S(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-F'(-JIV*K8
MI]BHVH;9AR#8HMBOV+'8LR#8M-F%V*<@V*?8MMBGV8'9AR#8M-BO(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`BVXS:J2#8
MJ-F$V8C:J2#8I]F%V+;8I]N,(%!'4"#8J-BQV*?;C"#8J-BGV++8J-N,V8;;
MC"#;C-JI(-F^VXS8NMBGV84@V*?9A=BVV*?8H2#8M-BOV8<@V879B-BQV*\@
MV8;;C-BGV+(@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M240@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8<@
MV*?8L]BJ(-F((-N,V*<@V*_8L2#8K]BGV*_:K]BGV88@V879B-BLV8C8KR#9
MAMN,V+/8JB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N(@IM<V=S='(@(MF!V8?8L=BSV*H@V*K9B-BRVXS8
MN=N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T
M=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R
M("+9A=BTV*[8M=F'XH",XH",V8?8I]N,(-BQV878LMBHV8;8K]N,(-F&VXS8
MI]BRV879AMBO(-N,VJD@V*?8L=BJV+78I]F$(-BGV879AB#9B-BH(-F%VXSB
M@(S8J-BGV+39AMBO(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T
M:6YG+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*_8I]BQ
MV*?;C"#8JMF&V+C;C-F%("5S(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`BV;[8L=F(V8;8K]F'
M("5S(-BHV*?;C-BO(-BMV*?9B-N,(-BJV8;8N-N,V878I]BJ("5S(-BHV*?8
MM-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED
M(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS
M9W-T<B`BV;[8L=F(V8;8K]F'(-BHV+$@V+'9B-N,(-BNV8C8K]BT(-F&V87;
MC.*`C-BJV8C8I]F&V*\@V+'9B-F&V8C8M-BJ(-BTV8C8KR(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR#8K=BGV8C;C"#8
MK]BGV*_9A^*`C-BGXH",VXS;C"#9AMN,V+/8JB`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L
M;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R
M,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@
M=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I
M96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO
M=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T
M('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A
M;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(MF%V*\@V*K9
MA=BGV84@V+79@=BMV8<@V*C8IR!)12#9A=BTVJG9A"#8K]BGV+'8KR#9B"#8
MI]N,V88@V*?8LB#9A=BTVJG9A-BGV*H@V878L=F(V+':K]BQ(-F%VXSB@(S8
MJ-BGV+38KRX@V*?:K]BQ(-F'V8;9B-BR("(*(MF%VXSB@(S8KMF(V*?9A]N,
MV*\@V*W8I]F$V*H@V8C;C-BQV*?;C-BTVJ_8L2#8JMF%V*?9A2#8M=F!V*W9
MAR#8L=BG(-BGV878JMBMV*?9AB#:J=F&VXS8K]B,(-F$V+?9@=BGV8L@VJG9
MA-N,V*\@V*K8H]N,VXS8KR#8L=BG(-F!V+38I]BQ("(*(MBOV8?;C-BO("(*
M"B,@"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(MF'V8C;C-F1V*H@7"(E<UPB(-BMV+#9@2#8M-BOV8<@V*?8L]BJ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`BV*K9AMF'V*<@V+/9A=BJ(-J&V;XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@
M8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS
M9W-T<B`B(@HBV;[;C-BZV*?9A2#9@=BQV+/8JMBGV*_9AR#8M-BOV8<@V+'9
MB-N,("5S(-BHV8<@)7,@V*C8IR#9A=F(V+;9B-BY(%PB)7-<(B#9AMF%V*?;
MC-BT(-BOV*?8K]F'(-BTV*_9AR#8I]BSV*HN7&XB"B+8JMBVV87;C-F&VXP@
MV*C8L=BGVXP@V*[9B-BGV8;8K]F'(-BTV*_9AB#9B"#;C-BG(-BOV+':J2#8
MHMF&(-F(V*S9B-BO(-F&V*_8I]BQV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`BV8;8I]F%VXP@VJG9
MAR#8J-F'(-F'V8;:K]BGV84@V;[;C-F(V8;8K]BOV8?;C"#8J-F'(-BUV8'8
MK=F'(-BGVXS8K-BGV*\@V8;8I]F%V8<@V*?8L]BJV8'8I]BOV8<@V87;C.*`
MC-BTV8C8KR(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0IM
M<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*
M;7-G<W1R("+8JMBYV*_8I]BO(-F!VXS9A-BOXH",V8?8IR#8J-BGVXS8KR#;
MC-JI(-BYV*_8KR#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES
M(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB
M(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D
M('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(MBG
MV8C9A-F(VXS8JB!<(B5S7"(@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@
MVJ_8L=BOV*\@V++;C-BQV*<@V879@MBOV*?8L2#8K]BGV*_9AR#8HMF&(-BG
MV+(@V*W8KR#9A=BLV*?8LB#8J-N,V+38JMBQ(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B(@HBV*C8L=F&V*?9A=F'XH",V*?B@(S;C-N,(-JIV8<@V*C8
ML=BGVXP@V878M-BGV8?8K]F'(-BGVXS9AB#9AMF(V+D@V*_8I]BOV8<@*"5S
M*2#9@MBHV838I]F+(-F%V8C8L=BO(-BGV+/8JMF!V*?8K]F'(-F"V+'8I]BQ
M(-F%VXSB@(S:K]BQV8'8JMB,(-BOV+$@(@HBV+/8I]F%V*?9AMF'(-F%V8C8
MK-F(V*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-30*(RP@9G5Z>GD*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`BV*S8K]BG(-JI
MV8;9AMBOV8<@V*C8I]N,V*\@VXS:J2#9AMF(VXS8L]F'(-BHV*?8M-BO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS
M9W-T<B`BV*K9AMF'V*<@V+/9A=BJ(-BQV*?8L]BJ(-F((-J&V;XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X
M"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`BV*K9
MAMF'V*<@V+/9A=BJ(-BQV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(MBLV*_8IR#:J=F&V8;8K]F'
M(-BHV*?;C-BO(-N,VJD@V8;9B-N,V+/9AR#8J-BGV+38KR(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(MJIV*?8L=BSV*?8LB!<(B5S7"(@V*W8L-F!(-BTV*_9AR#8I]BS
MV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!S879E9"XB"FUS9W-T<B`BVJG8I]BQV+/8I]BR(%PB)7-<(B#8K=F!V+@@
MV+38K]F'(-BGV+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(MBOV+'8KMF(V*?8L]BJ(-BG
MV8'8JMBJV*?8K2#8K=BSV*?8J"#8J-BQV*?;C"`E<R#8K=BPV8$@V+38K]F'
M(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(MBQV*_;C-F!(-F%V+38KMBU(-BTV*_9AR#9B-BLV8C8KR#9
MAMBOV*?8L=BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<
M(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BV;[8L=F(V8;8K]F'(-F%V8C9
M@MBJVXP@(%PB)7-<(MF%V8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT
M97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E
M<R!O;FQY(@IM<V=S='(@(MBJV8;9A]BG(-BSV878JB#8J-BGV838IR#9B"#9
MOMBGVXS;C-F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS
M9W-T<B`BV*K9AMF'V*<@V+/9A=BJ(-BHV*?9A-BG(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`BV*_8
MI]BOV8?9E"#8I]BQV+/8I]F$(-BTV*_9AR#8I]BR(-JOV*?9A2#9@MBHV83;
MC"#8I]BR(-BOV+/8JB#8L=F!V*K9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"XB"FUS9W-T<B`BV;[8L=F(V8;8K]F'(-BGV+'8L]BGV80@V+38
MK]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*W9@=BX(-BTV8C8KR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`BV*C9A-F(VJD@=V5A=&AE<BYC;VT@V8+8I]BHV80@V*_8L]BJV+'8LR#9
MAMN,V+/8JB(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("+8M-BGV*[9AR#8JMF%("<E<R<@VXS8I]F!
MV*H@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS
M9W-T<B`BVJ_8LMN,V8;9A^*`C-BGXH",XH",VXS;C"#8K]BQ(-BOV+/8JMBQ
MV+,@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("+8J-BNV+3;C"#:J=F'(-BH
MV*K9B-BGV8;8KR#8J-BQV*[8MR#9AMF%V*?;C-BT(-BOV*?8K]F'(-BTV8C8
MKR#9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@
M=&AA;B`E<RXB"FUS9W-T<B`B(@HBV8;9B-N,V+/9A^*`C-F'V*?;C"#8LMN,
MV*?8K]N,(-BOV+$@V*?;C-F&(-F!VXS9A-BO(-F"V+'8I]BQ(-BOV*?8L=BO
M+B#8M-F%V*<@)7,@V8;9B-N,V+/9AR#9B-BGV+'8KR#:J=BQV*_9A^*`C-BG
MXH",VXS8KR#8K]BQ(-BMV*?9A-N,(-JIV8<@(@HBV+39A=BG(-BHV*?;C-BO
M(-JIV878JMBQ(-BGV+(@)7,@V8;9B-N,V+/9AR#9B-BGV+'8KR#:J=F&VXS8
MKR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+9
MA=BTVJG9A-N,(-BOV+$@V*?8MMBGV8'9AR#:J=BQV*_9AB`G)7,G(-BHV8<@
MV+/8I]F%V*?9AMF'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<R(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("+9A=BTVJG9
MA-N,(-BOV+$@V;[8I]JI(-JIV+'8K]F&(-BOV*?8K]F'V90@VJG8I]BQV*C8
ML2`G)7,G(-BGV+(@V+/8I]F%V*?9AMF'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ
M.B`B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(MF%V+3:J=F$VXP@
MV*_8L2#8K=BPV8$@)R5S)R#8I]BR(-BSV*?9A=BGV8;9AR#8L=BN(-BOV*?8
MK]F'(-BGV+/8JCH@(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`BV878M-JIV83;C"#8K]BQ
M(-BHV+'9B-BRV+'8L]BGV8;;C"`G)7,G(-BQV*X@V*_8I]BOV8<@V*?8L]BJ
M.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@
M(MF%V+3:J=F$VXP@V*_8L2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#8L=BN
M(-BOV*?8K]F'(-BGV+/8JCH@)7,@V*?8L=BSV*?9A"#9AMBTV*\B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B
M"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HBV878M-JI
MV83;C"#8K]BQ(-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-BQV*X@V*_8I]BO
MV8<@V*?8L]BJ.B#8I]F&V*_8I]BRV8<@)7,@V*C;C-BTV*K8L2#8I]BR(-BM
MV*\@V878K-BGV+(@V*C9B-BOV8<@V*?8L]BJ("@@)60@(@HBV*C8I]N,V*HI
M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R("(B"B+9A=BTVJG9A-N,(-BOV+$@V*?8L=BSV*?9
MA"#9OMBQV8C9AMBOV8<@V8C8K-F(V*\@V*_8I]BTV*K9AR#8I]BSV*HZ("`E
M<R#8J-F'(-BUV8C8L=BJ(-BJVJG9A^*`C-BGXH",VXS;C"#8I]BQV+/8I]F$
M(-BTV*_9AR#8I]BSV*H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`BV*[8M]BGVXS;
MC"#8K]BQ(-F&V878I]N,V+0@V*?;C-F&(-BHV*[8M"#9OMN,V+K8I]F%(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("+8KMBWV*?;C-N,
M(-BOV+$@V*_8L=F(V8;B@(S8J-BQV*\@VJG8L=BOV88@V*_8I]BOV8<@V*K9
MA=BGV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC(`HC.B!F<F%M97=O<FLO
M1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("+8KMBW
MV*?;C-N,(-BOV+$@V*_8L=F(V8;B@(S8J-BQV*\@VJG8L=BOV88@V*_8I]BO
MV8?9E"#8JMF"V8C;C-F%(-BQV*X@V*_8I]BOV8<@V*?8L]BJ(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(MBN
MV+?8I]N,VXP@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-F!V+'9A2#8L=BN(-BO
MV*?8K]F'(-BGV+/8JBX@V+38I]N,V*\@V8';C-F$V*\@V879B-BQV*\@V8;;
MC-BGV++;C"#8L=BG(-BLV*<@V*?9AMBOV*?8KMBJV8?B@(S8I^*`C-N,V*\B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B
M"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(MBNV+?8I]N,VXP@V*_8
ML2#8I]BLV+'8IR#:J=BQV*_9AB#8N=F%V83;C-BGV*H@V878M-BNV+4@V+38
MK]F'V90@VJG8JMBGV*C:AMF'(-BBV*_8L=BS(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#8L]BYVXP@(@HBVJG9AMN,
MV*\B"@HC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#8J-BQV8C8LMBQV+/8I]F&
MVXP@V*S8LMBFVXS8I]BJ(-BJV878I]BS(-BQV*X@V*_8I]BOV8<@V*?8L]BJ
M+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\B"@HC
M(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`BV*[8M]BGVXS;C"#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#9@=F'
MV+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V838
MM]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;C-BO(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R("(@VJG8I]BQV+/8I]BR($E-05#9OMF(V+39A^*`C-F'
MV*?;C"#9A=BTV*K8L=JI(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB
M@(S:J=F&V*\B"@HC(`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(@V*C9AR#9AMBXV+$@V8;9
MA=N,XH",V+'8L]BO(-JIV8<@V*+8L=BTVXS9B"!R87(@V878N=BJV*C8L=N,
M(-BHV*?8M-BO(@H*(R`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(-BHV8<@V8;8N-BQ(-F&V87;
MC.*`C-BQV+/8KR#:J=F'(-F^V+'9B-F&V*_9AR!Z:7`@V878N=BJV*C8L=N,
M(-BHV*?8M-BO(@H*(R`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T
M-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R
M9"!N=6UB97(N(@IM<V=S='(@(MBHV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8
MKR#:J=F'(-BTV878I]BQV8<@VJG8I]BQV*H@V878N=BJV*C8L=N,(-BHV*?8
MM-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U
M-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(MBGVXS9AB#9@=N,V838KR#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(MBG
MVXS9AB#9@=N,V838KR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%V80@V*?8N=BO
MV*?8KR#8M=BMVXS8K2#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(MBGVXS9AB#9@=N,
MV838KR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%V80@V*?8N=BOV*?8KR#9B"#9
MB-N,V+':K]F(V80@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+B(*;7-G<W1R("+8I]N,V88@V8';C-F$V*\@V879A=JI
MV88@V*?8L]BJ(-BTV*?9A=F$(-F%V8+8I]BOVXS8L2#9A]BTV*H@V8?8M-BJ
MVXP@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B+8I]N,V88@
MV8';C-F$V*\@V*C8I]N,V*\@V*W8I]F(VXP@VJG8I]F%V*<@V8@@VXS8IR#9
M@=F'V+'8L]BJVXP@V*?8LB#8I]BYV*_8I]BO(-BUV*W;C-BM(-BLV*_8IR#8
MM-BOV8<@V*C8IR#9AMF(VXS8L]F'(-BNV*?9A-N,(-BHV*?8M-BO(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(MBGVXS9AB#9@=N,
MV838KR#8J-BGVXS8KR#;C-JI(-BYV*_8KR#9A=BYV*K8J-BQ(-BHV*?8M-BO
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB
M5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!2
M1T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@
M(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T
M<B`B(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`BV*?;C-F&
M("5S(-F%VXSB@(S8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M(@IM<V=S='(@(B(*(MBGVXS9AB#9OMN,V+K8I]F%(-BHV*<@V878K-F%V8C8
MN=F'(-JIV*?8L=BGVJG8JMBQ("5S(-F&V8C8M-BJV8<@V+38K]F'(-BGV+/8
MJB#:J=F'(-BHV*<@V878K-F%V8C8N=F'(-JIV*?8L=BGVJG8JMBQ(-BTV878
MIR#9A=BJV8'8I]F(V*H@(@HBV*?8L]BJ(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+B(*;7-G<W1R("+8I]N,V88@V+G8K]BO(-BMV*_8I]F"
MV80@V*C8I]N,V*\@VXS:J2#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@
M(MBGVXS9AB#:J=BGV+'8L]BGV+(@V;[8L=F(V8;8K]F'XH",V8?8I]N,('II
M<"#9B"!G>FEP(-BQV*<@V*C8I]BR(-F&V87;C.*`C-JIV8;8KR(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(MBGVXS9AB#8L]BGV878I]F&V8<@V*_8L2#8K=BGV80@V*W8I]BVV+$@V+K;
MC-BQ(-F!V+G8I]F$(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N(@IM<V=S='(@(MBGVXS9AB#9A=F"V*_8I]BQ(-BHV*?;C-BO(-BYV*_8
MKR#8J-BGV+38KR(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`BV*?;C-F&(-F^V8;8K-BQV8<@
MV*C8I]N,V*\@V*?8LB#9OMF&V*S8L=F'V90@VJ_8LMN,V8;9A^*`C.*`C-F'
MV*<@V8'8L=BGV*[9B-BGV8;;C"#8M-F(V*\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G
M<W1R("+8L=BYV*\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T
M"FUS9VED(")4:6-K971S(@IM<V=S='(@(MBHV83;C-BWV8?8IR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(MBRV878I]F&(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4
M<F%C:VEN9R(*;7-G<W1R("+8L=BOVXS8I]BHVXP@V++9A=BGV88B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S
M='(@(MF"V*?9A-BH(-BRV878I]F&(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(-BG
MV8;8JMBNV*?8J"#8LMF%V*?9AB`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P
M"FUS9VED(")4:71L92(*;7-G<W1R("+8N=F&V8C8I]F&(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET
M;&4@*'1O;VQT:7`I.B(*;7-G<W1R("+8N=F&V8C8I]F&("C8L=BGV8?9AMF%
MV*?;C"#8HMF&VXPI.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(MBHV8<B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L
M:6-K:6YG+B(*;7-G<W1R("(B"B+8J-BQV*?;C"#8I]F&V*K8KMBGV*@@VH;9
MAMBO(-F!VXS9A-BOV(P@V*_:J=F%V8<@0W1R;"#8L=F(VXP@*%!#*2#;C-BG
M($-O;6UA;F0@V+'9B-N,("A-86,I(-BQV*<@V*_8L2#9A=BOV*H@VJG9A-N,
MVJD@(@HBVJG8L=BOV88@V8;:K]F'V*_8I]BQVXS8KR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@
M(MBGV878L=F(V+(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G
M<W1R("+8J-F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS
M9VED(")4;VUO<G)O=R(*;7-G<W1R("+9@=BQV*_8IR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*(RP@9G5Z>GD*;7-G:60@(E1O;F=A(@IM<V=S='(@(MBGV878L=F(V+(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("+8J-BGV838IR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`BVH;8I]BQVH;9B-BH(-BHV*?9A-BG
M("C8J-BGV838IRDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G
M:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("+8JMBQV*S9A=F'XH",V8?8IR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I
M9"`B5')U92!O<B!F86QS92(*;7-G<W1R("+8K]BQV+/8JB#9B"#;C-BG(-F&
MV*?8K]BQV+/8JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(MBSV8<@V+39AMBHV8<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM
M.2DB"FUS9W-T<B`B5'5R:VES:"`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@
M8VAO:6-E.B`B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BNV8C8KR#8L=BG(-BJ
MV*?;C-F^(-JIV8;;C-BO.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("+8M-BGV*[8
MM2!5+E8N(#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),
M(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T
M(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),
M.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5K
M<F%I;F4B"FUS9W-T<B`BV++;C-BQV*[8M^*`C-BOV*?8L2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+8I]F%VJG8I]F&(-BOV+/8
MJMBQV+/;C"#8J-F'(-BTV*?8KMF'(%9&4R#9AMN,V+/8JB(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB
M"FUS9W-T<B`BV*?9A=JIV*?9AB#8I]BVV*?9@=F'(-JIV+'8K]F&(-BGV+?9
MA-BGV+G8I]BJ(-BGV+;8I]F!VXP@VJG8I]BQV*C8L2#8J-F'(-F'V8;:K]BG
MV84@V*O8J-BJ(-F&V*?9A2#9AMN,V+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9A=BLV8C8LMF'V*<@V+'8
MIR#8J-BQV*?;C"#9OMBQV8C9AMBOV8<@7"(E<UPB(-BJV+K;C-N,V+$@V*_8
MI]BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V878K-F(V++9A]BG
M(-BQV*<@V*C8L=BGVXP@V;[8L=F(V8;8K]F'("5S+R5S(%9&4R`@V*K8NMN,
MVXS8L2#8K]BGV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ("5S(-BJ
MV+K;C-N,V+$@V*_8I]BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(%PB)7-<(B#8L=BG(-BH
MV*?8LB#9AMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9
MB-F&V*_9AR!61E,@)7,O)7,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BG
MV*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!344S9A=BJV+79
MA"#8M-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#8J-BG(%-33"#9A=BJV+79A"#8M-BO(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-BGV+(@V;[8L=F(V8;8K]F'(%9&4R#8L=F(V8;9B-BTV*H@V*K9A]N,
MV8<@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MM-BGV*[9AR!61E,@7"(E<UPB(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@
M5D93(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^
MV+'9B-F&V*_9AR!61E,@V+'8IR#8I]N,V*S8I]BO(-F&V879B-BO(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!6
M1E,@7"(E<UPB(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#9OMBQV8C9AMBOV8<@V*[8I]F$VXP@5D93("#8I]N,V*S8I]BO
M(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A
M<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N
M<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR#8L=BG(-BHV*?8LB#:
MJ=BQV*\@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R("+8K=BPV8$@7"(E<UPB(-F%V87:J=F&(-F&
MVXS8L]BJV(P@V+38I]BNV8<@V*[8I]F$VXP@V8;;C-BSV*HB"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S
M7"(Z("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB!<(B5S7"(@V+'8
MIR#8K=BPV8$@VJG8L=BO.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(@IM<V=S='(@(MBMV+#9@2`E<R#9A=F%VJG9AB#9AMN,V+/8JMB,(-BTV*?8
MKMF'(-BNV*?9A-N,(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8
MKMF'(%9&4R#8L=BG(-BHV8<@V+79B-BQV*H@V*K9B"#8K]BQ(-BJV8@@V*W8
ML-F!(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93
M(-BQV*<@V*W8L-F!(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38
MI]BNV8<@5D93(-BQV*<@V*W8L-F!(-F&V879B-BO.B`E<RXB"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R!<(B5S
M7"(@V+'8IR#8K=BPV8$@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*W8L-F!
M(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@7"(E<UPB(-BQV*<@V*W8L-F!(-F&
MV879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT
M,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB!6
M1E,@V+'8IR#8J-F'(-BUV8C8L=BJ(-BJV8@@V*_8L2#8JMF((-BMV+#9@2#9
MAMF%V8C8KSH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'V90@V8'8
MN=F$VXP@V+'8IR#8JMBTV*[;C-BU(-BOV*?8KR(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-BLV++8IMN,V*?8JB#:K]F(V*?9A]N,(-BQV*<@V*?8L]BJV*[8
ML=BGV*P@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP
M:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*K8N=BQ
MVXS9@2`E<R`@V+'8IR#8J-BGV+$@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8I]F&V*K9@MBGV80@V*_8I]BO
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'
M(%9&4R!<(B5S7"(@V+'8IR#8J-BGV+(@V8;9A=F(V*\B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'
M(%9&4R#8L=BG(-BHV+'8I]N,(-F&V8C8M-BJV88@V*C8I]BR(-JIV+'8KR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQ
MV*<@V*C8I]BR(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8HMBQ
MV+3;C-F((-F!V+38L=BOV8<@V+'8IR#8J-BGV+(@VJG8L=BO(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T
M<B`B(-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'(%9&4R#9
MAMF(V+38JBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+B(*;7-G<W1R("(@V8;9A=N,XH",V*K9B-BGV88@V*_8
ML2#9OMBQV8C9AMBOV8<@5D93(-F&V8C8M-BJ+B(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8JMBZVXS;
MC-BQ(-F&V*?9A2#8K]BGV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@
M=F9S<F]O="#8L=BG(-BNV8C8I]F&V*\B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*C9
MAR`E<R`@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO.B#9OMF(V+39AR#9A=F"
MV+78KR#8I]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8
MI]BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M.B`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93
M(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO.B`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@V;[8L=F(V8;8K]F'(%9&4R!<(B5S7"(@V+'8IR#8JMBZVXS;C-BQ(-F&
MV*?9A2#8K]BGV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@
M5D93("5S+R5S(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%
M(-BOV*?8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&("=M:VES;V9S
M)R#8L=BG(-BGV*S8L=BG(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R
M86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V*?;C-F&(-BSV8;8KR!7;W)D(-BQV*<@V*K8L=BLV879AR#9
MAMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!<
M(B5S7"(@5D93("#9AMF(V+38JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(-F&V87;C.*`C-BJV8C8I]F&(-BO
MV+$@V;[8L=F(V8;8K]F'(%9&4R#9AMF(V+38JBXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8?9E"#8
MK]BGV*_9AR!61E,@V8;9B-BTV*HB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#0Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B#9AMF%VXSB
M@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!61E,@V8;9B-BTV*HN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(MBRVXS8L=BNV+?B@(S8K]BGV+$B
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H
M86YG97,B"FUS9W-T<B`BV8C8I]JOV+'8K]BGV8;8K]F&(-BJV+K;C-N,V+'8
MI]BJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
MV8C8I]JOV+'8K]BGV8;8K]F&(-BBV*[8L=N,V88@V+G9A=F$(-BTV878IR(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@(@IM<V=S='(@(MF^V*?8L]BN(-BZVXS8L2#9A=F&V*K8N-BQV8<@
MV*?8LB#:J=BGV+'8L]BGV+(@V*C8L2#8L=F(VXP@V*?8JMBUV*?9A#HB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("+9
MOMBGV+/8KB#8NMN,V+$@V879AMBJV+C8L=F'(-BGV+(@VJG8I]BQV+/8I]BR
M(-BHV8<Z(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BV+K;C-BQ(-BM
MV8C8LMF'(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N
M:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM
M<V=I9"`B56YI=',B"FUS9W-T<B`BV8C8I]BMV*_9A]BG(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("+8K]BG
MV*_9AR#9AMBGV+39AMBGV*[8JMF'(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I
M9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"B,L
M(&9U>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R("+9A]N,VH8@V87:J=BGV8;;C"#8JMF&V+C;C-F%(-F&V+38K]F'(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G
M<W1R("+9AMBGV84@VJG8I]BQV*C8L2#9B"#;C-BG(-BGV+/9A2#8L=F%V+(@
MV8;8I]BTV8;8I]BNV*K9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0B"FUS9W-T<B`BV8+8M]BY(-F^VXS9B-F&V*\@V+G9
MAMBUV+$@V8'8N=F$VXPB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+8J-N,(-F&V*?9
MA2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U
M<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO
M=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T
M<B`B(@HBV*_8L]BJ(.*`C-F&V8C;C-BSV8?8I]N,(-BHV*_9B-F&(-BGV878
MJMN,V*?8LB#8J-F'(-BOV83;C-F$(-BGV879AMN,V*K;C"#9AMF%VXSB@(S8
MJMF(V*?9AMF&V*\@V*?8LB#8M]BQVXS9@B#8J-BQV8;8I]F%V8<@V8;9B-N,
MV+/;C"#8J-BQVXS8K]F'+R(*(MBQV8C9AMF(V+38JB#:K]BQV8'8JMF'+]J&
MV+/8J-N,V*_9AR#8M-F(V8;8KRX@VJG9A-N,V*\@V*K8H]N,VXS8KR#8L=BG
M(-F!V+38I]BQ(-BOV8?;C-BO(-BJV*<@V878JMF&(-F!V8;;C.*`C-BGXH",
MVXS;C"#8L=BG(-BOV+$@(@HB;6]Z:6QL82YO<F<@V*C8IR#8N=F&V8C8I]F&
M(-J&VJ_9B-F&VJ_;C"#8K]BSV*K8L=BSVXP@VXS:J2#8K]BSV*H@XH",V8;9
MB-N,V+,@V*C9AR#8JMBNV*K9A]F4(-BQV+/9A2#8L=BG(-F%V+38I]F'V*_9
MAR#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@
M(MBQV8;:KR#8JMF&V+C;C-F%(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R
M("+8J-BSV+<@V*C8K]F(V88@V;[8M-BJVXS8J-BGV8;;C"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BV*C8L=F(
MV++8L=BSV*?9AMN,(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B
M"FUS9W-T<B`BV*C8L=F(V++8L=BSV*?9AMN,("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`BV*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BHV+$B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(-BH
MV+'9B-BRV+'8L]BGV8;;C"#8M-BO(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S
M='(@(MBOV+/8JN*`C"#9AMF(VXS8LR#8J-F'VXS9AMF'XH",V+/8I]BRVXP@
MV*W8L-F!(-BTV*\B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R("+8I]BQV+/8I]F$(-JIV+'8K]F&(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P
M<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@
M(MBJV878I]F%(-F^V+'9B-F&V*_9A^*`C.*`C-F'V*?;C"#8JMF&V+C;C-F%
M(-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C"#8J-F'(-JI
MV*?8L=BSV*?8LB#8I]BQV+/8I]F$(-BTV*\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5
M<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(MBMV+'9B-F!(-BHV++8L=JO
M(-F$V*?8JMN,V88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(MBGV+G8K]BGV*\@VXS9B-F&V*?9AMN,(-BHV++8L=JO
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T
M<B`B(-BGV+/8JMF!V*?8K]F'(-F!V+G9A-N,.B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5
M<V4@4U-,(@IM<V=S='(@(MBGV+/8JMF!V*?8K]F'(-BGV+(@4U-,(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T
M<B`BV*?:K]BQ(-F&V*?9A2_8I]BSV84@V+'9A=BR(-BHV+'8I]N,(-JIV*?8
ML=BSV*?8LB!)35-0(-F%V*K9@=BGV8C8JB#8I]BSV*K8C"#8I]BSV*K9@=BG
MV*_9AR#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`BVJG8I]BQ
MV*C8L=BGV88B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`BVJG8I]BQV*C8L2`E<R`@V*C8
ML=BGVXP@)7,@V*?8K=BQV*?8LB#9A]F(VXS9D=BJ(-F&V+38K]F'(-BGV+/8
MJB(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("+8L]BQV;[8L=BSV*K;C"#:J=BGV+'8J-BQ(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S
M97(@3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-JIV*?8
ML=BHV+$B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B(*;7-G<W1R("+8J]BHV*H@V8;8I]F%(-JIV*?8L=BHV+$B"@HC.B!S
M:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("+8J]BHV*H@VJG8
MI]BQV*C8L2#8J-BQV*?;C"#8I]N,V88@V;[8I]N,VJ_8I]F'(-BZVXS8L2#9
M@=BYV*?9A"#8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R
M("+8K=BSV*?8J"#:J=BGV+'8J-BQ(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(MF&V*?9
MA2#:J=BGV+'8J-BQ(@H*(R`*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA
M;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("+9AMBGV84@VJG8
MI]BQV*C8L2`G)7,G(-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BHV+$Z(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G
M<W1R("+9AMBGV84@VJG8I]BQV*C8L3H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`BVJG8I]BQV*C8L=BGV88@V+/8I]F%V*?9AMF'.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`BV+38I]BNV8<@5D93(-F(V*S9B-BO(-F&V*_8I]BQ
MV*\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")6
M86-A=&EO;B(*;7-G<W1R("+8JMBYV+?;C-F$V*?8JB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z("(*;7-G<W1R("+9A=F(V8+8N=N,V*K9A]BGVXP@V878
MN=BJV*C8L2#;C-BGV8'8JMF'(-BTV*_9AR#8N=BHV*?8L=BJV8;8KR#8I]BR
M.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS
M9VED(")686QI9&ET>2(*;7-G<W1R("+8I]BYV*K8J-BGV+$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(MF%
MV8+8K]BGV+$@V*C9AR#8K]F"VXS9@MF'(-BGV+(@V*W8I]F$V*<B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`BV879@MBOV*?8
ML2#8I]BR(-BHVXS8M-N,V8;9AR#8M]F(V80@V878K-BGV+(@)7,@V*C;C-BT
MV*K8L2#8I]BSV*HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*
M;7-G:60@(E9A;'5E<R(*;7-G<W1R("+9A=F"V*?8K]N,V+$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R
M("+9A=F"V*?8K]N,V+$@V*C8L=BGVXP@V*?9AMBJV*[8I]BH(-BGV+(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE
M(@IM<V=S='(@(MF%V*K8NMN,VXS8L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(MF&V+/8KMF'(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(MJIV8;8JMBQV80@V8;8L]BNV8<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED
M(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("+8JMBQV*?8LB#8N=F%V8C8K]N,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("+9@=BGV+79A-F'
MXH",VJ_8L-BGV+';C"#8N=F%V8C8K]N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(MBYV879B-BOVXPZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("+8
MKMN,V83;C"#8J-BGV838IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*(RP@9G5Z>GD*;7-G
M:60@(E9I970@3F%M(@IM<V=S='(@(MF&V*?9A2#9OMBQV8C9AMBOV8<B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H
M5DE30TE)*2(*;7-G<W1R(")6:65T;F%M97-E("A625-#24DI(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`BV8;9A=BGVXP@)7,B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E(@IM<V=S='(@(MF&V878I]N,(-N,VJD@V+79@=BMV8<@V8C8
MJ"#8KMBGV+'8K-N,(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS
M9W-T<B`B(-F&V878IR#8J-F'(-BYV8;9B-BGV88@)7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B
M5FES:6)I;&ET>2(*;7-G<W1R("+9@MBGV*C9A-N,V*H@V878M-BGV8?8K]F'
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B
M5FES:6)I;&ET>3H@(@IM<V=S='(@(MF"V*?8J-F$VXS8JB#9A=BTV*?9A]BO
MV8<Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S
M='(@(B(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-
M04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("+8I]BNV+?8I]BQ(2$A(-BOV+/8
MJB#B@(S9AMF(VXS8LR#8L=BG(-BHV+?9B-BQ(-BOV+/8JMN,(-BGV+(@)7,@
MV*W8L-F!(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BV*?8KMBWV*?8L3H@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I
M9"`B5V4B"FUS9W-T<B`BVH;9A]BGV+'8M-F&V*C9AR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S
M="(*;7-G<W1R("+9OMN,V+3B@(S8J-N,V8;;C"#9A]F(V*<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A
M=&$@<')O=FED960@8GDB"FUS9W-T<B`BV*_8I]BOV8<@V*+8J"#9B"#9A]F(
MV*?;C-N,(-F!V+'8I]F'V84@V+38K]F'(-BHV8<@V8C8L]N,V839AR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(MF(V*@B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R
M("+9B-BHXH",VJ_8I]F'(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(MF'V8'8
MJMJOVXPB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I
M9"`B5V5L8V]M92(*;7-G<W1R("+8KMF(V+0@V*+9A=BOVXS8KR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,@(RTC+2,M(RTC("!F85])4BYP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R("+8J-F'("5S(-BNV8C8M"#8HMF%V*_;C-BO
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64L("5S(@IM<V=S='(@(B5SV(P@V*[9B-BT(-BBV878K]N,V*\B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,2DB"FUS9W-T<B`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M
M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_(@IM<V=S='(@(MJ&V8<@V*C8L=F&V*?9A=F'V90@VJG8
MI]BQV*C8L=BOVXP@V+'8IR`E<R#8J-BGVXS8KR#8J-BYV*\@V*?8LB#9B-BQ
MV8C8KR#9AMBTV*?9AB#8K]F'V*_8GR(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA
M<F%C=&5R/R(*;7-G<W1R("+9AMF(VXS8L]F'V93B@(P@V*W8I]BFV80@VH;;
MC-BSV*K8GR(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS
M9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(MF&
MV8C;C-BSV8?B@(S;C"#9AMF"V80@V8+9B-F$(-J&VXS8L]BJV)\B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I
M9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@
M(MJIV*_8I]F%(-F!V*?8LB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BXB"FUS9W-T<B`BVJG8K]BGV84@V*C8L=F&V*?9A=F'
MXH",V8?8I]N,(-F%V*K8M=F$XH",VJG9AMF&V*_9AR#B@(S8J-BQV*?;C"#9
MB-N,V+'8I]N,V+3:K]BQ(-F%V*K9AB#9@=BYV*?9A"#8J-BGV+39AMBO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`BV+G8L=BV(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N
M:71S(@IM<V=S='(@(B#9OMF'V8;8IR#8K]BQ(-F(V*?8K=BO($-34R`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G
M:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("+9OMF'V8;8I]N,(-JO
MV++;C-F&VJ_8I]F&("5S(-BOV+$@V+'8I]BSV*H@*-BOV+$@V8C8L=F(V*\@
MV*C8N=BOVXP@V879B-BKV+$@V87;C.*`C-JOV+'8K]BO*3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B
M5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(MF^V8?9AMBGVXP@V*S8K]F(
MV80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("+9B-BGV*W8KR#9OMF'
MV8;8IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`BV;[9A]F&V*<Z(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G
M<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P
M,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I
M9"`B5VEN9"(*;7-G<W1R("+8J-BGV*\Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS
M9W-T<B`BV*C8I]BO(-BRV8C8K]F'V8;:K]BGV84Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS
M9W-T<B`BV+/8L=BYV*H@V*C8I]BO(-BHV+'8K=BSV*@@V8'9B-BJ(-BHV+$@
MV+/8I]BYV*HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B
M5VEN9#HB"FUS9W-T<B`BV*C8I]BO.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R("+8J-BGV*\Z
M("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M
M(@IM<V=S='(@(MBYV8+9A"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.38*(RP@9G5Z>GD*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(MF$VXS8
ML]BJ(-BBV+'8LMF(V8?8IR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-0IM<V=I9"`B5V]R:R(*;7-G<W1R("+:J=BGV+$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D
M<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#9A=BMV80@VJG8I]BQ(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B
M5V]R:R!0:&]N92(*;7-G<W1R("+8JMF$V8'9AB#9A=BMV80@VJG8I]BQ(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O
M9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN
M9R!A(%9&4R!F:6QE+B(*;7-G<W1R("+8I]N,V*S8I]BO(-F^V+'9B-F&V*_9
MAR!61E,@V878K-F(V+(@V*_8L]BJV+'8L]N,(-F&V*_8I]BQV*\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S
M(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(EE9(@IM<V=S='(@(N*`C%E9(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"FUS9VED(")965E9(@IM<V=S
M='(@(EE965DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`BV+/8I]F$V*?9AMF'(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B665M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@
M(MBBV+';C"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`BV*C9A-F'
MV(P@V879B-BGV8'9@MF%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N(@IM<V=S='(@(MBTV878IR#8K]BQ(-F%V*\@V878JMF&(-F'V+/8JMN,
MV*\N(-BGV+(@V*_:J=F%V8<@(%L\/ET@V*C8L=BGVXP@V*C8L=JOV+38JMF&
M(-BHV8<@5UE325=91R#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KR(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM
M<V=S='(@(MBTV878IR#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V8;8M-BOVXS8
MKR(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS
M9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`BV+39A=BG(-F&V87;C.*`C-BJV8C8
MI]F&VXS8KR#9AMF(VXS8L]F'("=<7"<@V+'8IR#8K]BQ(-F&V*?9A2#:J=BG
MV879A"#8KMF(V*\@V*_8I]BTV*K9AR#8J-BGV+3;C-BO(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N(@IM<V=S='(@(MBTV878IR#8HMBOV+'8LR#9OMBSV*H@V*?9
MA-JIV*K8L=F(V8;;C-JI(-F%V+G8JMBHV+';C"#9B-BGV+'8KR#9AMJIV+'8
MK]F'XH",V*?;C-BO(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(MBTV878IR#9A]N,
MVH8@V8';C-F$V*_;C"#8L=BG(-BOV+$@V;[8L=F(V8;8K]F'(-BOV+'9B-F&
MXH",V*C8L=BO(-BTV*_9AR#8J-F'(-F!VXS9A-BO(-F%V*K9@MBGV*C9A-N,
M(-BOV+$@)7,@V8;:K]BGV+38JB#9AMJIV+'8K]F'XH",V*?;C-BO(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N(@IM<V=S='(@(MBTV878IR#8KMBGV+'8K"#8M-BO
MVXS8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B+8
MM-F%V*<@V878K-BHV8C8L2#9A]BSV*K;C-BO(-N,VJD@V+39A=BGV+'9AR#8
MJMF$V8'9AB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BOV(P@V*?8LB#8
MN=F$V*?9A=BJ("<K)R#8J-BQV*?;C"#8M-F%V*?8L=F'XH",V8?8I]N,("(*
M(MBHVXS9AB#8I]F$V879A-F$VXP@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("+8M-F%V*<@
MV878K-BHV8C8L2#9A]BSV*K;C-BO(-N,VJD@V879@MBOV*?8L2#9A=BYV*K8
MJ-BQ(-F(V*?8L=BO(-JIV8;;C-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#9OMBTV*K;C-BHV*?9AB#8K]BQV*[8
MJB#8K]BGV*_9AR#8J-BQV*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-BKV*C8
MJB#9AMBGV84@V;[;C-JIV+'8J-F&V*_;C"#:J=F&VXS8KR(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`BV+39A=BG(-BH
MV*?;C-BO(-N,VJD@V+/8I]F%V*?9AMF'(-F^V+38JMN,V*C8I]F&(%9&4R#8
ML=BG(-F^VXS:J=BQV*C9AMBOVXP@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N(@IM<V=S='(@(MF"V*C9A"#8I]BR(-BGV+'8L]BGV80@VJ_8
MLMBGV+'8M-B,(-BHV*?;C-BO(-F%V+3:J=F$(-BQV*<@V+38L=BM(-BOV8?;
MC-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR!54DS8
MI]N,(-JIV8<@V*?;C-F&(-F^VXS9B-F&V*\@V*C9AR#8HMF&(-BGV+38I]BQ
MV8<@V87;C.*`C-JIV8;8KR#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BV+39
MA=BG(-BHV*?;C-BO(-N,VJD@VJG8I]BQV+/8I]BRV(P@V*C8L=BGVXP@V*W8
ML-F!(-JIV+'8K]F&(-BGV8;8JMBNV*?8J"#:J=F&VXS8KR(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,
MVJD@V8;8I]F%(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8K=BPV8$@VJG8L=BO
MV88@V878M-BNV+4@VJG9AMN,V*\B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9A2#:J=BGV+'8
MJ-BQV(P@V*C8L=BGVXP@V*W8L-F!(-BTV*_9AB#9A=BTV*[8M2#:J=F&VXS8
MKR(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@861D+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#9
MAMBGV84@VJG8I]BQV*C8L=B,(-BHV+'8I]N,(-BGV+;8I]F!V8<@VJG8L=BO
MV88@V878M-BNV+4@VJG9AMN,V*\B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,VJD@V+39AMBGV+/9AR#:
MJ=BGV+'8J-BQV(P@V*C8L=BGVXP@V*C8L=F(V++8L=BSV*?9AMN,(-BGV8;8
MJMBNV*?8J"#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@
MV878M-BNV+4@VJG9AMN,V*\@VJG9AR#:AMF'(-BYV879A-N,(-BHV*?;C-BO
M(-BGV8;8K-BGV84@VJ_;C-BQV*\B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,
MV*\@V8;8I]F%(-BLV*_;C-BO(-BOV+/8JMF'(-BQV*<@V*K8I]N,V;X@VJG9
MAMN,V*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)
M=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E
M<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(MF&V+38L]BJ("5S(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8
MI]BSV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C;
MC-BO(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G
M:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#8I]F$
MVJG8JMBQV8C9AMN,VJG;C"#8M-F%V*<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(MBBV*_8L=BS(-F!V+'8L]BJV8;8K]F'.B#8M-F%V*<Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(MBGV+?9
MA-BGV+G8I]BJ(-BTV878IR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(MBBV*_8L=BS(-BGVXS9
MAMBJV+'9AMBJVXP@V+39A=BG(-F&V+/8J-BJ(-BHV8<@V*?8J-BJV*_8I]N,
M(-F&V+38L]BJ("5S(-BTV878IR#8JMBZVXS;C-BQ(-JIV+'8K]F'(-BGV+/8
MJB[8J-BQV*?;C"#8L=BYV*?;C-BJ(-F%V+/8I]BFV80@(@HBV*?9A=F&VXS8
MJMN,(-BHV*?;C-BO(-BOV8C8J-BGV+'9AR#9B-BGV+'8KR#8M-F(VXS8KR(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9
M;W5R($YA;64B"FUS9W-T<B`BV8;8I]F%(-BTV878IR(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A
M9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E
M<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B+8
ML]BGV878I]F&V8<@V;[8M-BJVXS8J-BGV88@V*K8M=BOVXS9@B#9A]F(VXS9
MD=BJ(-BTV878IR#8I]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&
M(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*_8C"#;C-BG
M(-BTV*?;C-BO("(*(MBHV8;8IR#8J-F'(-BOV83;C-F$(-BOVXS:K]BQVXP@
MV*?;C-F&(-JIV*?8L2#8I]F&V*S8I]F%(-F&V87;C.*`C-BTV8C8KR(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B+8L]BG
MV878I]F&V8<@V;[8M-BJVXS8J-BGV88@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M(-BTV878IR#9@=F'V+'8L]BJ(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-BQ
MV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*_8C"#;C-BG(-BT
MV*?;C-BO("(*(MBHV8;8IR#8J-F'(-BOV83;C-F$(-BOVXS:K]BQVXP@V*?;
MC-F&(-JIV*?8L2#8I]F&V*S8I]F%(-F&V87;C.*`C-BTV8C8KR(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*(MBXV*?9A]BQ(-F%V+'9B-BQVJ_8L2#8M-F%V*<@V8;8L]BH
MV*H@V*C9AR#8I]BHV*K8K]BGVXP@V8;8M-BSV*H@)7,@V+39A=BG(-BJV+K;
MC-N,V+$@VJG8L=BOV8<@V*?8L]BJ+MBHV+'8I]N,(-BQV+G8I]N,V*H@V878
ML]BGV*;9A"`B"B+8I]F%V8;;C-BJVXP@V*C8I]N,V*\@V*_9B-BHV*?8L=F'
M(-F(V*?8L=BO(-BTV8C;C-BO(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92XB"FUS9W-T<B`BV878L=F(V+':K]BQ(-BTV878IR#8I]N,V88@
MV878M-BNV+79AR#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9
MAMBO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L
M(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HBV878L=F(V+':K]BQ(-BTV878
MIR#8I]N,V88@VJ_8LMN,V8;9A]F4XH",(-J&V*?9OB#8L=BG(-F^V+38JMN,
MV*C8I]F&VXP@V8;9A=N,XH",VJG9AMBO+B!#;VYT<F]L+T]P=&EO;B`K(%`@
MV+'8IR#8J-BQV*?;C"#:AMBGV;X@(@HBV8'8M-BGV+$@V*_9A]N,V*\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.B(*;7-G<W1R("+8LMF%V*?9AB#9@=BYV83;C"#9A=F&
MV+?9@MF'(-BLV+K8L=BGV8';C-BGVXS;C"#8M-F%V*<Z(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`BV8?9B-N,V9'8
MJB#9OMN,V+0@V8'8L=BV(-BTV878ISHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S
M='(@(MF'V8C;C-F1V*H@V;[;C-BT(-F!V+'8MB#8M-F%V*<Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(MF&V*?9A2#:J=BGV879A"#8M-F%V*<Z(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z,3`P,`IM<V=I9"`B66]U<B!L;V=I;B!H87,@
M97AP:7)E9"XB"FUS9W-T<B`BV8C8L=F(V*\@V+39A=BG(-F%V8;9@MBVVXP@
MV+38K]F'(-BGV+/8JB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,B"FUS9W-T<B`BV*?8L]F%(-BQV878LB`@V*S8K]N,V*\@
MV+39A=BG(-BHV+'8I]N,("5S(-F'V+/8JCH@)7,B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S
M:6]N+B(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-BTV878IR#8J-BQ
MV*?;C"#8M]F(V80@V*?;C-F&(-F&V+38L]BJ(-BHV+'9B-BRV+'8L]BGV8;;
MC"#8M-BOV8<@V*?8L]BJ("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@V+39A=BG(-BHV+'9
MB-BRV+'8L]BGV8;;C"#8M-BOV8<@V*?8L]BJ(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`BV*?8L]F%(-BQV878LB`@V+39A=BG(-BHV*?8
MLMF&V+38I]F&VXP@V+38K]F'(-BGV+/8JB(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HBV*?8L]F%(-BQV878
MLB#8M-F%V*<@V*C8I]BRV8;8M-BGV8;;C"#8M-BOV8<@V*?8L]BJV(P@V;[8
ML]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8KMF(V*\@V+'8IR#:AMJI(-JIV8;;
MC-BO(-F((-BHV*<@V*?8L]F%(-BQV878LB#8K-BOVXS8KR`B"B+8KMF(V*\@
MV8C8I]BQV*\@V+39B-N,V*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S
M='(@(MBGV+/9A2#8L=F%V+(@(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8
MI]BSV*HB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(MJIV*?8L=BSV*?8
MLN*`C-F'V*?;C"#8L=BGV8?B@(S8K]F(V+$@V+39A=BG.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I
M9"`B6F%I<F4B"FUS9W-T<B`BV838M]N,V8$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");
M2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6]F^V8;9A]BGV88@VJG8L=BO
MV88@V878JMF&(-F&V8+9A"#9@MF(V80@V+38K]F'72(*"B,Z('-E<G9I8V5S
M+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S
M='(@(EO:K]BRV*?8L=BT(-F%V+3:J=F$72`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2(*;7-G<W1R(");V8;9A=BGVXS8M"#9A=BJV88@V8;9@MF$(-F"
MV8C9A"#8M-BOV8<@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`BV8;9
MA=BGVXS8M"#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8=;("T@)7,@V*[8
MMUTB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B
M6]BNV+<@)7,@V*?8LB`E<R!=("(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED
M(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`BV+/8L=F^V+'8L]BJVXPB"@HC
M.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B0TQ)(@H*
M(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B
MV*_8L=BNV*H@V*_8I]BOV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W
M(@IM<V=S='(@(MBMV+#9@2#8L]BWV+$B"@HC.B!L:6(O87!I+G!H<#HQ,S,*
M;7-G:60@(E]'<F]U<',B"FUS9W-T<B`BVJ_8L=F(V8<F(W@R,#!C.]F'V*<B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED
M(")?2&5L<"(*;7-G<W1R("+8L=BGV8?9AMF%V*<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@
M(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ
M(-BJV+79B-N,V+$N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(MF(V+'9B-BO(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B
M7TQO9R!O=70B"FUS9W-T<B`BV*[8L=F(V*PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-
M;V1I9GD@3&EN:RXN+B(*;7-G<W1R("+8JMBZVXS;C-BQ(-F^VXS9B-F&V*\N
M+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS
M9VED(")?3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8IR(*"B,Z
M(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@
M(MF%V*S9B-BRV8?8IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN
M(@IM<V=S='(@(MBMV+#9@2#9OMN,V8C9AMBO+BXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`BV+'8I]F')B-X,C`P8SO8
MI]F&V*_8I]BRVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BLV*_9B-F$+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`BVJG8I]BQ
MV*C8L=BGV88B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0IM
M<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4(-BB
MV*_8L=BS("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,T"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R
M("+:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR`B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BV*K9
M@MF(VXS9A2(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A
M;&TB"FUS9W-T<B`BV*+8L=BGV84B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U.`HC+"!F=7IZ>0IM<V=I9"`B8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL92(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ
M(-F^V+'9B-F&V*_9AR!<(B5S7"(@V8;9B-BTV*HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@
M:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(MBGVXS9
MAMBLV*<@V+'8IR#9@=BTV*?8L2#8K]F'VXS8KR(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`BV*K9@=BGV8C8JMF'V*?;C"#9OMN,VJG8L=BH
MV8;8K]N,(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*
M;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@V;[;C-BOV*<@V8;8M-BO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*
M;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#4U"FUS9VED(")F:6QE(@IM<V=S='(@(MF^V+'9
MB-F&V*_9AR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`BV*?8LB`E<R`H)7,I(-BOV+$@)7,@)7,B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(MBHV*?8KR(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM
M<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(MF!V8C8
ML=BGV8LB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(MBOV+'8KMBW
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G
M:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@
M<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R
M("+8KMBWV8C8MUTB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B
M;F%M92(*;7-G<W1R("+9AMBGV84B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP
M:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`BV;[;C-BG
MV*_9AR#8L]BGV++;C"#9AMBTV*_9AR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E
M9"(*;7-G<W1R("+9A]F&V8C8LB#9OMN,V*?8K]F'(-BSV*?8LMN,(-F&V+38
MK]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U
M"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(FYO=&5P860B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED
M(")P97)C96YT(@IM<V=S='(@(MBOV+'8M=BO(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI
M<W-I;VX@9&5N:65D(@IM<V=S='(@(MF%V*S9B-BR(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B
M<&EX96QS(@IM<V=S='(@(MF^VXS:J=BSV839A]BG(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@
M(MBWV839B-BY(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS
M9W-T<B`BV*C9A-F(VJD@365T87(@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,
MV+/8JB(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H
M;W<@9&EF9F5R96YC97,B"FUS9W-T<B`BV8;9A=BGVXS8M"#8JMF!V*?9B-BJ
MV8?8IR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X
M-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("+9
MOMN,XH",V*_8L=F^VXPB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("+9@=F'
MV+'8L]BJ(-F(V+C;C-F!V8<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z
M>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("+8K]BQ(-F'V+$@V8C8L=F(
MV*\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V+'8IR#8J-BQ
MV*?;C"#8JMBCVXS;C-BO(-BOV8C8J-BGV+$@V8C8I]BQV*\@VJG9AMN,V*\B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F
M+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("+;C-JOV*?9AMF'(-BT
MV*_9AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G
M:60@(G5N;F%M960B"FUS9W-T<B`BV*C;C"#9AMBGV84B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G
M:60@(G5S97(@<V5L96-T(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#:J=BGV+'8
MJ-BQ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM
M<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O97-?15,N<&\`````````````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<Q-C(W,P`Q
M,#4Q-30S,3`V,@`P,38T,#(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!3<&%N:7-H('1R86YS;&%T:6]N<R!F;W(@:&]R
M9&4@<&%C:V%G90HC(%1R861U8V-I;VYE<R!A;"!E<W!A\6]L('!A<F$@96P@
M<&%Q=65T92!H;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O
M:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M
M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E+@HC($%U=&]M871I8V%L
M;'D@9V5N97)A=&5D+"`R,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#8M,#4M,3@@,#@Z,3<K,#(P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-BTP,BTQ-2`Q-SHR-"LP,3`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($UA;G5E;"!0+B!!>6%L82`\;6%Y86QA0'5N97@N97,^7&XB"B),
M86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH
M;B`A/2`Q*3M<;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H:&%C
M92`E<R!D[6%S*2(*"B,Z(&QI8B](;W)D92YP:'`Z,3,X,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A!8V-E9&EE
M;F1O(&$@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&5N("5S
M(&3M87,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H
M=&]D87DI(@IM<V=S='(@(B`H:&]Y*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&UA\6%N82DB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D
M87DI(@IM<V=S='(@(B`H87EE<BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T
M("(*;7-G<W1R(")E;B`B"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM
M<V=S='(@(EPB)7-<(B!N;R!E<R!U;B!D:7)E8W1O<FEO+B(*"B,Z(&QI8B](
M;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@;F\@97,@
M=6YA(&5L96-C:?-N(';A;&ED82XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN
M<&AP.C<Q,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(
M;W)D92!296=I<W1R>2XB"FUS9W-T<B`B3F\@<V4@:&$@8V]N9FEG=7)A9&\@
M7"(E<UPB(&5N(&5L(')E9VES=')O(&1E($AO<F1E+B(*"B,Z(&QI8B](;W)D
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R
M\R!E;"!G96YE<F%D;W(@9&4@X7)B;VQE<R!D92!<(B5S7"(N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")392!H
M82!A\6%D:61O(%PB)7-<(B!A;"!S:7-T96UA(&1E(&=R=7!O<RXB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")392!H82!A\6%D:61O(%PB)7-<(B!A;"!S:7-T96UA(&1E
M('!R:79I;&5G:6]S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(").;R!S92!H82!C
M<F5A9&\@7"(E<UPB.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B57-A9&]S("4N,F9-0B!D92`E
M+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S('D@)7,B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3DT(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@
M97AP:7)E<RXB"FUS9W-T<B`B475E9&%N("5D(&3M87,@:&%S=&$@<75E(&5X
M<&ER92!L82!C;VYT<F%S9?%A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C
M87-T(@IM<V=S='(@(B5D('!R;V[S<W1I8V]S(&1I87)I;W,B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!!=FES;R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($9I;F=E<G!R:6YT(@IM<V=S='(@(DAU96QL82!D:6=I=&%L(&1E("5S(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@;W!E<F%C:6]N
M97,@9&4@;6%N=&5N:6UI96YT;R`M($-O;F9I<FUA8VGS;B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R(")#;VYF
M:6=U<F%C:?-N(&1E("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R
M(")&:7)M82!D92`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B06-U97)D;W,@9&4@;&EC96YC:6$@9&4@)7,B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-CDP(&QI8B]61E,O9G1P+G!H<#HW-C,@;&EB+U9&4R]S
M;6(N<&AP.C0T,0HC.B!L:6(O5D93+W-M8BYP:'`Z-3`W"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")982!E>&ES
M=&4@)7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#8*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@
M82!L87,@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!E<W3A
M('!R97!A<F%D;R!P87)A(')E86QI>F%R(&QA<R!O<&5R86-I;VYE<R!D92!M
M86YT96YI;6EE;G1O("(*(G-E;&5C8VEO;F%D87,N06-T:79E(&QA<R!C87-I
M;&QA<R!D92!L87,@;W!E<F%C:6]N97,@<75E(&1E<V5A(&5J96-U=&%R(&5N
M("(*(F5S=&$@;V-A<VGS;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R
M(")(86-E(&9A;'1A("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M
M:6YU=&]S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$S
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(DYO('-E(&AA(&5N8V]N=')A9&\@)7,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R("(E<R!A;"`E<R!D92`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D
M<F5S<R!";V]K(@IM<V=S='(@(D1I<F5C8VEO;F5S(&1E("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$@9&4@)7,B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO
M=&5P860B"FUS9W-T<B`B3&EB<F5T82!D92!N;W1A<R!D92`E<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@5&%S:VQI<W0B"FUS9W-T<B`B5&%R96%S(&1E("5S(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M
M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*
M(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W
M:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z
M($5S=&4@;65N<V%J92!P=65D92!Q=64@;F\@<')O8V5D82!D92!Q=6EE;B!P
M87)E8V4@<V5R+B!%=FET92!S96=U:7(@(@HB8W5A;'%U:65R(';M;F-U;&\@
M:6YC;'7M9&\@;R!S=6UI;FES=')A<B!C=6%L<75I97(@:6YF;W)M86-I\VX@
M<&5R<V]N86P@86P@(@HB<F5M:71E;G1E+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L('9E;G1O<V\@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(BP@=F5N=&]S;R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E
M<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA8FQE(&1E("5S(&$@)7,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`V.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$R
M.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0X(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@<V5L
M96-C:6]N87(@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@
M(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@,3(@:&]R87,B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R
M;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@,C0@:&]R87,B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B
M,C0@:&]R87,B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`B/$%N=&5R:6]R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B4&%R82!E<W1E(&)L
M;W%U92!H86-E(&9A;'1A('5N(&UO=&]R(&1E(&)A<V4@9&4@9&%T;W,N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-S$*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D(@IM<V=S='(@(E-E(&AA('!R;V1U8VED;R!U;B!E<G)O<B!I
M<G)E<&%R86)L92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B2&%C92!F86QT82!U;F$@8VQA=F4@4$=0
M('#Z8FQI8V$@<&%R82!C:69R87(@=6X@;65N<V%J92XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R(")(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-O
M;7!R;V)A<B!U;B!M96YS86IE(&9I<FUA9&\N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DAA8V5N(&9A
M;'1A('5N82!C;&%V92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV
M861A('D@=6YA(&9R87-E(&-L879E("(*(G!A<F$@9&5S8VEF<F%R('5N(&UE
M;G-A:F4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N
M(@IM<V=S='(@(B(*(DAA8V5N(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC
M82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R87-E(&-L879E("(*
M(G!A<F$@9FER;6%R('5N(&UE;G-A:F4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)(86-E
M;B!F86QT82!U;F$@8VQA=F4@4R]-24U%('#Z8FQI8V$L('5N82!C;&%V92!3
M+TU)344@<')I=F%D82!Y('5N82!F<F%S92`B"B)C;&%V92!P87)A(&1E<V-I
M9G)A<B!U;B!M96YS86IE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB2&%C96X@9F%L=&$@=6YA
M(&-L879E(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=F4@4R]-24U%('!R:79A
M9&$@>2!U;F$@9G)A<V4@(@HB8VQA=F4@<&%R82!F:7)M87(@=6X@;65N<V%J
M92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R(")(86-E(&9A;'1A('5N82!C;&%V92!334E-12!P
M^F)L:6-A('!A<F$@8VEF<F%R('5N(&UE;G-A:F4N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S
M(@IM<V=S='(@(DYU8F5S(&UA=&EN86QE<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(DQI9V5R82!L;'5V:6$@;6%T:6YA;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN
M(@IM<V=S='(@(DQL=79I82!M871I;F%L(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS
M9W-T<B`B06=U86-E<F]S(&UA=&EN86QE<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B06=U86-E<F\@;6%T:6YA;"!D92!N:65V92(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B240@9&4@05!)(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B
M06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B06-E<F-A(&1E;"!E9&ET;W(B
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N
M+BXB"FUS9W-T<B`B06-E<F-A(&1E+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM
M<V=S='(@(DEN9F5R:6]R($%B<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T
M<B`B16X@;65D:6\@06)S+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(X,@IM
M<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(")392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@
M9&ER96-T;W)I;R!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R
M(")392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@87)C:&EV
M;R!61E,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B261E;G1I9&%D(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S
M<W=O<F0B"FUS9W-T<B`B0V]N=')A<V7Q82!D92!A8V-E<V\B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(DED96YT:61A9"!B;&]Q=65A9&$N(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O
M=6YT:6YG(@IM<V=S='(@(D-O;G1A8FEL:61A9"(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I
M9"`B061D(@IM<V=S='(@(D'Q861I<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O
M=7`B"FUS9W-T<B`B0?%A9&ER(&=R=7!O(&1E<V-E;F1I96YT92(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B0?%A
M9&ER('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!\6%D
M:7(@87%U[3HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U
M<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")!\6%D
M:7(@9W)U<&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO
M;B(*;7-G<W1R(")!\6%D:7(@<')I=FEL96=I;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D'Q861I
M<B!A(%PB)7-<(B!U;B!G<G5P;R!D97-C96YD:65N=&4B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")!\6%D:7(@
M82!<(B5S7"(@=6X@<')I=FEL96=I;R!D97-C96YD:65N=&4B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@
M(D'Q861I<B!U;B!U<W5A<FEO.B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M0?%A9&ER(&-O;'5M;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B0?%A
M9&ER(&UI96UB<F]S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY
M-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B0?%A9&ER('!A<B(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS
M9W-T<B`B0?%A9&ER(&5L(&UE;OH@)7,@8V]M;R!P86YE;"!L871E<F%L(&1E
M($UO>FEL;&$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")!\6%D
M:7(@82!L87,@9&ER96-C:6]N97,Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O
M:R(*;7-G<W1R(")!\6%D:7(@82!L87,@9&ER96-C:6]N97,Z(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D'Q861I
M<B!U<W5A<FEO(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B
M"B(E<RXB"FUS9W-T<B`B(@HB4V4@:&$@8?%A9&ED;R!<(B5S7"(@86P@<VES
M=&5M82P@<&5R;R!N;R!S92!P=65D92!A\6%D:7(@;&$@:6YF;W)M86-I\VX@
M(@HB861I8VEO;F%L(&1E(&%L=&$Z("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B4V4@:&$@8?%A9&ED
M;R!<(B5S7"(@86P@<VES=&5M82X@66$@<'5E9&4@:6YI8VEA<B!L82!S97-I
M\VXN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&$@861I
M8VGS;B!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A9&$N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T-#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R
M97-S($)O;VLB"FUS9W-T<B`B1&ER96-C:6]N97,B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S0S,30N<&AP.C4V"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')A9&]R("T@
M9&5F:6YE('!R:79I;&5G:6]S(&1E(&]T<F]S('5S=6%R:6]S(@H*(SH@861M
M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M,3<*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C
M:?-N(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS
M9VED(")!9',B"FUS9W-T<B`B06YU;F-I;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X"FUS9VED(")!9F=H86YI<W1A
M;B(*;7-G<W1R(")!9F=A;FES=.%N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,0IM<V=I9"`B06QB86YI82(*;7-G<W1R
M(")!;&)A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!<F=E;&EA(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@
M(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS
M9W-T<B`B06QI;F5A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B06QI
M;F5A8VGS;CHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@
M(D%L;"(*;7-G<W1R(")4;V1O<R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L
M;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E1O9&]S(&QO<R!U<W5A
M<FEO<R!A=71E;G1I9FEC861O<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@
M861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T
M<B`B5&]D;W,@;&]S(&=R=7!O<R(*"B,Z(&QI8B](;W)D92]097)M<R]D871A
M=')E92YP:'`Z-S4@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY,0IM<V=I9"`B
M06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1O9&]S(&QO<R!P<FEV:6QE9VEO
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E1O9&]S
M(&QO<R!L861O<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<Q"FUS9VED
M(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B4&5R;6ET:7(@
M=F%R:6%S(&1I<F5C8VEO;F5S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/R(*;7-G<W1R("*_4&5R;6ET:7(@8V]N9FEG=7)A8VGS;B!D92!T
M:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_(@H*(SH@;&EB+TAO<F1E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R
M(")982!E>&ES=&4B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ
M,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%C8V5S
M;R!)35-0(&%L=&5R;F%T:79O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G
M<W1R(")#;&%V92!)35-0(&%L=&5R;F%T:79A(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R(")5<W5A<FEO($E-4%,@86QT97)N871I=F\B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N(&5L96-T<O-N:6-A
M(&%L=&5R;F%T:79A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B4&QA;G1I;&QA<R!A
M;'1E<FYA=&EV87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*;7-G:60@(D%L=&5R;F%T92!T97AT
M.B(*;7-G<W1R(")497AT;R!A;'1E<FYA=&EV;R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<*;7-G:60@(D%M97)I8V%N
M(%-A;6]A(@IM<V=S='(@(E-A;6]A($%M97)I8V%N82(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*
M;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T
M<B`B4V4@:&$@:6YD:6-A9&\@=6X@=F%L;W(@:6QE9V%L+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(E-E(&AA('!R;V1U8VED;R!U
M;B!E<G)O<B!D97-C;VYO8VED;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!;F1O<G)A(@IM<V=S='(@
M(D%N9&]R<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,`IM<V=I
M9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S
M='(@(E!R;WAY(&%N\VYI;6\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E)E<W!U97-T82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4*;7-G
M:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YTX7)T:61A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.0IM<V=I9"`B06YT
M:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A('D@0F%R8F%D;W,B
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,S8@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM
M<V=S='(@(D%P;&EC86-I\VXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@
M87!L:6-A8VEO;F5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S.0IM
M<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(DQA(&%P;&EC
M86-I\VX@97-TX2!L:7-T82XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(D%P;&EC87(@82!R96-U<G-O<R!C;VUP87)T:61O<R!D97-C96YD:65N=&5S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G
M:60@(D%P<')O=F4B"FUS9W-T<B`B07!R;V)A<B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B5&%M8?%O(&%P<F]X:6UA9&\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B06)R:6PB
M"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!<F%B
M:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07+A8FEG;R`H5VEN9&]W<RTQ
M,C4V*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8V"FUS9VED(")!<F-H:79E($9I;&4@4VEZ
M92(*;7-G<W1R(")486UA\6\@9&5L(&%R8VAI=F\B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HW-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-0IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DYO;6)R92!D96P@87)C
M:&EV;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS
M9W-T<B`BOT5S=&$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!L82!S
M;VQI8VET=60@9&4@86QT82!D92`E<S\B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U
M8BUG<F]U<',_(@IM<V=S='(@(K]%<W3A('-E9W5R;R!D92!Q=64@9&5S96$@
M96QI;6EN87(@7"(E<UPB('D@=&]D;W,@<W5S('-U8F=R=7!O<S\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V"FUS9VED
M(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,@IM<V=I9"`B07)M96YI
M82(*;7-G<W1R(")!<FUE;FEA(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD
M:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M07)M96YI;R`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(D%R=&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P"FUS9VED(")!<G5B82(*
M;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM
M<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("))<VQA($%S8V5N<VGS
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(D=RX69I8V]S($%S8VEI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`B4F5G:?-N(&1E($%S:6$O4&%C[69I8V\B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G
M<W1R("(B"B*_4V]L:6-I=&%R(&-O;F9I<FUA8VGS;B!A;G1E<R!D92!R96%L
M:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O/R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,#DU"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B0V]L=6UN87,@9&4@87-I9VYA8VGS;B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+B(*;7-G<W1R("));G1E;G1A(&5L:6UI;F%R('5N(&=R
M=7!O(&EN97AI<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(DEN=&5N=&$@96QI;6EN87(@=6X@<')I=FEL
M96=I;R!I;F5X:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX
M-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(DEN=&5N=&$@;6]D:69I8V%R('5N('!R:79I;&5G
M:6\@:6YE>&ES=&5N=&4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N(@IM<V=S='(@(DEN=&5N=&$@;6]D:69I8V%R('5N(')E8W5R<V\@8V]M
M<&%R=&ED;R!I;F5X:7-T96YT92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0IM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T;W,B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%G
M;W-T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,CD*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X"FUS
M9VED(")!=7-T<FEA(@IM<V=S='(@(D%U<W1R:6$B"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C
M>7)S<6PZ($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE8V5S
M87)I82XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED
M(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($5L(&UO=&]R(&-A
M<F5C92!D92!L87,@8V%P86-I9&%D97,@;F5C97-A<FEA<RXB"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?8WER=7,Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE
M8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED
M("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET
M8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!.;R!S92!E;F-O;G1R\R!L82!E
M>'1E;G-I\VX@1E10(&YE8V5S87)I82X@0V]M<&EL92!02%`@8V]N(&QA("(*
M(F]P8VGS;B`M+65N86)L92UF='`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($YO('-E(&5N
M8V]N='+S(&QA(&5X=&5N<VGS;B!)34%0(&YE8V5S87)I82XB"@HC.B!L:6(O
M2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U
M:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M:W)B-3H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&MR8C4@;F5C97-A
M<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z($YO(&5S
M=.$@<V]P;W)T861A(&QA(&%D:6-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E
M($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,U-PIM
M<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A
M<#H@3F\@97-TX2!S;W!O<G1A9&$@;&$@96QI;6EN86-I\VX@9&4@=7-U87)I
M;W,@9&4@06-T:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!.;R!S92!E
M;F-O;G1R\R!L82!E>'1E;G-I\VX@3$1!4"!N96-E<V%R:6$N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P.B!.
M;R!S92!P=65D92!A\6%D:7(@96P@=7-U87)I;R`E<RX@R7-T;R!E<R!L;R!Q
M=64@9&EJ;R!E;"`B"B)S97)V:61O<CH@(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@
M56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@
M26YC87!A>B!D92!E;&EM:6YA<B!E;"!U<W5A<FEO("5S(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U
M=&A?;&1A<#H@26YC87!A>B!D92!A8W1U86QI>F%R(&5L('5S=6%R:6\@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?
M;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!.;R!E<W3A
M('-O<&]R=&%D82!L82!A8W1U86QI>F%C:?-N(&1E('5S=6%R:6]S(&1E($%C
M=&EV92!$:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT
M-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@3F\@<V4@96YC;VYT<O,@
M;&$@97AT96YS:?-N($U#04P@;F5C97-A<FEA+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M
M8F%U=&@Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!S;6)A=71H(&YE
M8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O24U!4"]!9&UI;BYP:'`Z,3`V"FUS
M9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(D9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED
M;W(@24U!4"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D9A
M;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960N("5S(@IM<V=S='(@(D9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;BX@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B16P@<V5R=FED;W(@4D%$2553(&AA(')E8VAA>F%D;R!L82!A=71E
M;G1I9FEC86-I\VXN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@Y-0IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED;W(@1E10
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&86QL\R!L
M82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R(%--0BXB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@
M9FEE;&1S.B(*;7-G<W1R(")#86UP;W,@9&ES<&]N:6)L97,Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,0IM<V=I9"`B
M07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I:F%N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B
M17AC=7-A<R!"3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R
M(")&;VYD;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0V]L
M;W(@9&4@9F]N9&\B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM
M<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")#;VYT<F%S
M9?%A(&ME<F)E<F]S(&EN8V]R<F5C=&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS
M9W-T<B`B3F]M8G)E(&1E('5S=6%R:6\@:V5R8F5R;W,@:6YC;W)R96-T;RXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U
M"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M87,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X"FUS9VED(")"86AR
M86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R
M(")"X6QT:6-O("A)4T\M.#@U.2TQ,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T"FUS9VED(")"86YG;&%D97-H(@IM
M<V=S='(@(D)A;F=L861E<V@B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,S"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"
M87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!D:7)E8W1O
M<FEO(&)A<V4@9&4@:6WA9V5N97,@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0IM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B3.UN96$@8F%S92(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`B0F5L87)U<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S4*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0NEL9VEC
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3`*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P"FUS9VED(")"96YI
M;B(*;7-G<W1R(")"96YI;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#$*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R
M;75D87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0V"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H
M9&%Y(@IM<V=S='(@(D-U;7!L96'Q;W,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K
M(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(").;R!S92!E;F-O;G1R\R!E;"!B;&]Q=64@7"(E<UPB(&1E(&QA(&%P
M;&EC86-I\VX@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B3W!C:6]N
M97,@9&4@8FQO<75E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1I<&\@9&4@8FQO<75E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"FUS9VED(")";VQD(@IM<V=S='(@(DYE9W)I=&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S"FUS9VED(")";VQI=FEA
M(@IM<V=S='(@(D)O;&EV:6$B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP
M:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")-87)C861O
M<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(D)O<F1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B1W)O<V]R(&1E;"!B;W)D
M93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(D)O<F1E<R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;FEA($AE
M<GIE9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(D%M8F]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*;7-G<W1R("));F9E
M<FEO<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#<*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B27-L82!D92!"
M;W5V970B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0T"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3<*;7-G:60@
M(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")497)R
M:71O<FEO(&]C9>%N:6-O(&1E(&QA($EN9&EA(&)R:73A;FEC82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(*;7-G:60@
M(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M-PIM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(DQI<W1A(&1E<V]R9&5N861A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-@IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD*;7-G:60@
M(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R\N8F%K+W)E
M9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#
M4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@
M(E!U;G1O<R!D92!D:7-T<FEB=6-I\VX@0U)#(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#
M7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!I961A9&5S(&1E(%]C
M96QD82XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(DYO('-E(&AA(&9I;F%L:7IA9&\@96P@:6YI8VEO(&1E(&QA(&-A8VCI+B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$V(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+RYB86LO:&]O:W,N<&AP
M+F1I<W0Z,3`T,"!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*
M;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D%G96YD82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B
M0V%L;6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R.`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B0V%M8F]Y82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`*;7-G
M:60@(D-A;65R;V]N(@IM<V=S='(@(D-A;65R^FXB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C(S,B!L:6(O5D93+V9T<"YP:'`Z-C<V(&QI8B]61E,O<VUB+G!H
M<#HT,S4*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`S"FUS9VED(")#86X@
M;F]T(&-O<'D@9FEL92AS*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E
M('1H92!S86UE+B(*;7-G<W1R("(B"B).;R!S92!P=65D92AN*2!C;W!I87(@
M96PO;&]S(&%R8VAI=F\H<RD@+2!O<FEG96X@>2!D97-T:6YO('-O;B!E;"!M
M:7-M;RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,B!L:6(O5D93+V9T<"YP
M:'`Z-S4R(&QI8B]61E,O<VUB+G!H<#HU,#$*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,38X"FUS9VED(")#86X@;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I
M;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N(@IM<V=S='(@(B(*(DYO('-E('!U
M961E*&XI('1R87-L861A<B!E;"]L;W,@87)C:&EV;RAS*2`M(&5L(&1E<W1I
M;F\@97-TX2!D96YT<F\@9&5L("(*(F]R:6=E;BXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4@<F5A:G5S=&%R(&QA(&-L879E
M(&%U=&]MX71I8V%M96YT92P@</-N9V%S92!E;B!C;VYT86-T;R!C;VX@96P@
M(@HB861M:6YI<W1R861O<B!D96P@<VES=&5M82XB"@HC.B!L:6(O1FEL92]#
M4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E
M('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(DYO('-E('!U961E(&5S8W)I8FER
M(&5N(&5L(&%R8VAI=F\@7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@
M:&%N9&QE<G,N(@IM<V=S='(@(DYO('-E('!U961E;B!A9&UI;FES=')A<B!M
M86YE:F%D;W)E<R!D92!S97-I\VX@97AT97)N;W,N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER<W%L+G!H<#HS,3D@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R(").;R!S92!P=65D92!C;VYE8W1A<B!A
M;"!S97)V:61O<B!)34%0.B`E<R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#0V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DYO('-E('!U961E(&%B<FER(&5L(&%R8VAI=F\@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3$*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9.$B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-2!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ,B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3$*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")#86YC96QA<B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B0V%N8V5L87(@:6YF;W)M92!D92!P<F]B
M;&5M87,B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYO
M('-E('!U961E(&5L:6UI;F%R(&5L(&%R8VAI=F\@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU
M,@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R(").;R!S92!E;F-U96YT<F$@=6X@9&ER96-T;W)I;R!T
M96UP;W)A;"XB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@
M(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@8V]N=&EN=6%R('-I;B!E;"!P87+A
M;65T<F\@)W1A<F=E=$9I;&4G+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R(").;R!S92!P=65D92!E;&EM:6YA<B!E;"!D:7)E
M8W1O<FEO(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R
M."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM
M<V=S='(@(DYO('-E('!U961E(&5L:6UI;F%R+"!T:65N92`E9"!D97-C96YD
M:65N=&5S+B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8P.`IM
M<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U
M<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S
M=&]R960N(@IM<V=S='(@(B(*(DYO('-E('!U961E(')E;W)D96YA<BP@96P@
M;OIM97)O(&1E(&5N=')A9&%S('%U92!S92!D97-E82!O<F1E;F%R(&YO("(*
M(F-O:6YC:61E(&-O;B!L87,@86QM86-E;F%D87,N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DYO('-E
M('!U961E(&1I<FEG:7(@96P@;65N<V%J92!A;"!N^FUE<F\@97-P96-I9FEC
M861O+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C4*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B0V%B;R!697)D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B4W5B=.UT=6QO(@H*(SH@
M;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I
M97(B"FUS9W-T<B`B4')O=F5E9&]R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R(")#871E9V]R[6%S('D@971I<75E=&%S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4*;7-G:60@(D-A>6UA;B!)
M<VQA;F1S(@IM<V=S='(@(DES;&%S($-A:6WA;B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM
M<V=S='(@(E1E;.EF;VYO(&WS=FEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P
M97)T:65S(@IM<V=S='(@(E!R;W!I961A9&5S(&1E(&-E;&1A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@
M(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B36%R9V5N(&1E(&-E;&1A.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P:65D861E
M<R!D92!C96QD82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(D5S
M<&%C:6%D;R!D92!C96QD83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(W
M-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E;.EF;VYO(&WS=FEL(@H*
M(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC
M("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0^EL=&EC;R`H25-/+3@X-3DM,30I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D-E;G1R87(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T"FUS9VED
M(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A
M($-E;G1R;V%F<FEC86YA(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS
M9W-T<B`B175R;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E
M=&%I;',B"FUS9W-T<B`B1&5T86QL97,@9&5L(&-E<G1I9FEC861O(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC
M871E($]W;F5R(@IM<V=S='(@(E!R;W!I971A<FEO(&1E;"!C97)T:69I8V%D
M;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#
M97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")0;VSM=&EC87,@9&5L(&-E
M<G1I9FEC861O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(Q"FUS9VED(")#:&%D(@IM<V=S='(@(D-H860B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B0V%M8FEA
M<B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B
M0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B0V%M8FEE(&QA(&-O;G1R
M87-E\6$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*(D-A;6)I82!E;"!N;VUB<F4@>2!L82!D:7)E8V-I
M\VX@96QE8W1R\VYI8V$@=FES:6)L97,@86P@;&5E<B!O(')E<W!O;F1E<B!A
M("(*(G-U<R!M96YS86IE<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
M3&$@8V]N9FEG=7)A8VGS;B!A8W1U86P@;F\@<V]P;W)T82!E;"!C86UB:6\@
M9&4@8V]N=')A<V7Q87,N(%#S;F=A<V4@96X@(@HB8V]N=&%C=&\@8V]N(&5L
M(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R(")'<N%F:6-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN
M:RXN+B(*;7-G<W1R(")697)I9FEC87(@7W;M;F-U;&\N+BXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y"FUS9VED(")#
M:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C$*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-H
M:6YA(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(D-H:6YO('-I
M;7!L:69I8V%D;R`H1T(R,S$R*2(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N
M9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM
M<V=S='(@(D-H:6YO('1R861I8VEO;F%L("A":6<U*2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB
M"FUS9W-T<B`B07!L:6-A8VGS;CHB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B
M16QI:F$@=6YA(&-O;G1R87-E\6$B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B
M16QI:F$@=6X@;F]M8G)E(&1E('5S=6%R:6\B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SHB"FUS9W-T<B`B16QI:F$@8_-M;R!M;W-T<F%R(&QA<R!F96-H
M87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E-E;&5C8VEO;F%R('1I<&\@
M9&4@97-T:6QO(&1E(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D87,I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-@IM
M<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("))<VQA(&1E(%!A<V-U
M82(*"B,Z(&QI8B]61E,N<&AP.CDQ-"!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!L82!D969I;FEC:?-N
M(&1E(&-L87-E(&1E("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R("),:6UP:6%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(")%;&EM:6YA
M<B!E=&EQ=65T87,@35-/9F9I8V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")";W)R87(@8V]N<W5L
M=&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B
M0F]R<F%R('5S=6%R:6\Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D)O<G)A
M<B!U<W5A<FEO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")";W)R87(@9&%T
M;W,@9&5L('5S=6%R:6\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")$
M97-P96IA9&\@=&%R9.UO(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM
M<V=S='(@(DAA9V$@8VQI8VL@<&%R82!S96=U:7(B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V
M:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('!O<B!(5%10(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B0V5R<F%R('9E
M;G1A;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO
M=61S(@IM<V=S='(@(DYU8F5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R
M(").=6)E<R!T96UP<F%N87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(FYU8F]S
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3(*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DES
M;&%S(&1E(&-O8V]S("A+965L:6YG*2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T
M<B`B3V-U;'1A<B!B87)R82!L871E<F%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P
M<V5D(&)O<F1E<G,B"FUS9W-T<B`B0V]L87!S87(@8F]R9&5S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,@IM<V=I9"`B
M0V]L;VUB:6$B"FUS9W-T<B`B0V]L;VUB:6$B"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B
M0V]L;W(B"FUS9W-T<B`B0V]L;W(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3`S(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,S@*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S
M.2!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#
M;VQO<B!0:6-K97(B"FUS9W-T<B`B4V5L96-T;W(@9&4@8V]L;W(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@R.`IM<V=I9"`B0V]L;W5R('-E;&5C=&EO
M;B(*;7-G<W1R(")396QE8V-I\VX@9&4@8V]L;W(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB
M"FUS9W-T<B`B0V]L=6UN87,Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B5.UT=6QO<R!D92!L
M87,@8V]L=6UN87,B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES
M=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")#\VUI8W,B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M
M86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N
M9"!3:&5L;"(*;7-G<W1R("));G3I<G!R+B!C;VUA;F1O<R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R
M(")#;VUE;G1A<FEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(DYO;6)R92!C;VWZ;B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P
M"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R;W,B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R(")#;VUP8?'M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(D]R9&5N861O<F5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(D-O;F1I8VGS;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D-O;F1I8VEO;F5S
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1&EF97)E;F-I87,@9&4@;&$@
M8V]N9FEG=7)A8VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$
M07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B)#;VYF
M:6=U<F%C:?-N('!A<F$@<VEN8W)O;FEZ86-I\VX@8V]N(%!$07,L($WS=FEL
M97,@8V]N(&%G96YD82!Y($]U=&QO;VLN(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92XB"FUS9W-T<B`B3&$@8V]N9FEG=7)A8VGS;B!E<W3A(&1E<V%C='5A;&EZ
M861A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(D-O;F9I9W5R87(@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS
M9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D-O;F9I<FUA<B!C;VYT
M<F%S9?%A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B0V]N9V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(D-O;F=O+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&5L(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB
M"FUS9W-T<B`B1F%L;/,@;&$@8V]N97AI\VXN(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S
M='(@(D9A;&SS(&QA(&-O;F5X:?-N.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B4V4@:&$@<F5C:&%Z861O(&QA
M(&-O;F5X:?-N(&%L('-E<G9I9&]R(&1E(&-L879E<R!P^F)L:6-O+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B"B)392!H82!R96-H87IA
M9&\@;&$@8V]N97AI\VX@86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N
M($UO=&EV;SH@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX.#D*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(DAA(&9A;&QA9&\@;&$@8V]N97AI\VX@86P@<V5R=FED;W(@1E10+B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(T(&-O;F9I9R\N8F%K+VAO;VMS+G!H
M<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(D-O;G1A8W1O
M<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G
M:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+B(*;7-G<W1R(")392!H86X@8?%A9&ED;R!C;W)R96-T
M86UE;G1E(&QO<R!C;VYT86-T;W,@82!S=7,@9&ER96-C:6]N97,B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(E1I<&\@9&4@
M8V]N=&5N:61O(&1E;"!A<F-H:79O(&-O;7!R:6UI9&\Z("(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C<U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<
M(B(*;7-G<W1R(")#;VYT96YI9&\@9&4@7"(E<UPB(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,S('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT:6YU87(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X"FUS
M9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B27-L87,@0V]O:R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@
M(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!I87(B
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")&86QL\R!L82!C;W!I83H@)7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V
M"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")#;W!I87(@<V5L96-C
M:?-N(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$W,"!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@
M(DE$(&1E(&-O<W1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV,PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T
M82!2:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-PIM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")#;W-T82!D
M92!-87)F:6PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G
M:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B
M3F\@<V4@<'5E9&4@8VEF<F%R(&5L(&UE;G-A:F4@;65D:6%N=&4@4$=0.B`B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(DYO('-E('!U961E
M(&9I<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").;R!S92!P=65D92!C:69R
M87(@96P@;65N<V%J92!M961I86YT92!3+TU)344B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYO('-E('!U961E(&9I<FUA<B!E;"!M
M96YS86IE(&UE9&EA;G1E("!3+TU)344B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@8?%A
M9&ER(&5L(&-O;G1A8W1O+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT.#(@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.CDV"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DYO('-E('!U961E(&5N;&%Z87(@86P@
M<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$W,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E
M+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!C;VUP<F]B87(@96P@<V%L9&\N
M("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V-@IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYO('-E
M('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($Q$05`N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*
M;7-G<W1R(").;R!S92!P=65D92!C;VYE8W1A<B!A;"!S97)V:61O<B!<(B5S
M7"(@;65D:6%N=&4@1E10.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F\@<V4@
M<'5E9&4@8W)E87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&1E
M<V-I9G)A<B!L;W,@9&%T;W,@4$=0.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N(@IM<V=S='(@(DYO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A
M=&]S(%,O34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@96QI;6EN87(@96P@
M8V]N=&%C=&\N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!E
M;&EM:6YA<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN("5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(B(*(DYO('-E('!U961E(&5L:6UI;F%R(&5L(&=U:?-N(&1E
M(&%C='5A;&EZ86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!<(B5S7"(N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34S(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S@Q"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@9&5T97)M:6YA<F$@;&$@9&ER96-C:?-N(&1E(&-O<G)E;R!D96P@9&5S
M=&EN871A<FEO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(DYO('-E('!U961E('1R865R(&QA(&QI8G)E=&$@
M9&4@9&ER96-C:6]N97,@8V]M<&QE=&$N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").;R!S92!P=65D
M92!T<F%E<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VX@8V]M<&QE=&$N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@=')A97(@;&$@;&ES
M=&$@8V]M<&QE=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U8VGS;BXB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<
M(B5S7"(N(@IM<V=S='(@(DYO('-E('!U961E(&-A<F=A<B!L82!E<W1R871E
M9VEA(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO9&ER96-T+G!H<#HS,`HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@
M<'5E9&4@8W)E87(@96P@9&ER96-T;W)I;R!<(B5S7"(N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN
M('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(").;R!S
M92!P=65D92!O8G1E;F5R(&QA(&-L879E('#Z8FQI8V$@9&5L('-E<G9I9&]R
M(&1E(&-L879E<RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").;R!S
M92!P=65D92!A8G)I<B!<(B5S7"(@<&%R82!E<V-R:6)I<BXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-2!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(DYO('-E('!U961E(&%B<FER("5S+B(*"B,Z(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM
M<V=S='(@(DYO('-E('!U961E(&%B<FER(&5L(&WS9'5L;R!D92!T87)E87,@
M9&4@;6%N=&5N:6UI96YT;R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(DYO('-E('!U961E(&%B<FER(&5L(&1I<F5C=&]R:6\@7"(E<UPB+B(*"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C,W
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C$R
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@;&]C86QI>F%R(&5L
M('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`B3F\@<V4@<'5E9&4@;&5E<B`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P
M87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O
M9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYO('-E('!U961E(')E<W1A8FQE
M8V5R(&QA(&-O;G1R87-E\6$@9&5L('5S=6%R:6\@<V]L:6-I=&%D;RX@4&%R
M=&4@9&4@;&]S("(*(F1E=&%L;&5S(&\@=&]D;W,L('-O;B!I;F-O<G)E8W1O
M<RX@4')U96)E(&]T<F$@=F5Z(&\@</-N9V%S92!E;B!C;VYT86-T;R!C;VX@
M(@HB96P@861M:6YI<W1R861O<B!D96P@<VES=&5M82!P87)A(&WA<R!I;F9O
M<FUA8VGS;BXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-2!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB
M"FUS9W-T<B`B3F\@<V4@<'5E9&4@;V)T96YE<B!L82!!0TPN(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*
M;7-G<W1R(").;R!S92!P=65D92!O8G1E;F5R(&QA(&QI8G)E=&$@9&4@9&ER
M96-C:6]N97,N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO('-E('!U961E
M(&]B=&5N97(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&QI<W1A
M<R!D92!D:7-T<FEB=6-I\VXN("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I
M97,B"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&-A<&%C:61A
M9&5S(&1E;"!S97)V:61O<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@<F5S=&%U<F%R(&QA(&-O;F9I9W5R86-I\VXN
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9&ER
M96-T;W)I;R!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C
M;VYF:6=U<F%C:?-N(&1E("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").;R!S
M92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF:6=U<F%C:?-N
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(DYO('-E('!U961E(&=U87)D87(@=6YA(&-O<&EA(&1E
M(&QA(&-O;F9I9W5R86-I\VXZ("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@HB
M3F\@<V4@<'5E9&4@9W5A<F1A<B!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N
M(&1E(&QA(&-O;F9I9W5R86-I\VX@96XZ(%PB)7-<(BXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(").;R!S92!P=65D92!G=6%R9&%R(&QA(&-O<&EA("5S(&1E(&QA
M(&-O;F9I9W5R86-I\VXN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"B).;R!S92!P=65D92!G=6%R9&%R(&5L(&%R8VAI=F\@)7,@9&4@
M8V]N9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ87(@=6YA(&1E("(*(FQA<R!O
M<&-I;VYE<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I9V\@9&4@)7,@;R!C;W!I
M87(@;6%N=6%L;65N=&4@82`E<R!E;"`B"B)C\V1I9V\@<VEG=6EE;G1E+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYO('-E('!U
M961E(&)U<V-A<B!E;B!E;"!S97)V:61O<B!,1$%0+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G
M<W1R(").;R!S92!P=65D92!D97-V:6YC=6QA<B!<(B5S7"(N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(DYO('-E('!U961E(&%C='5A;&EZ87(@96P@8V]N=&%C=&\N("5S(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!A8W1U86QI>F%R(&QA(&QI<W1A
M(&1E(&1I<W1R:6)U8VGS;BX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@97-C<FEB:7(@;&$@8V]N9FEG=7)A8VGS;B!D92!<(B5S7"(Z("5S(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).;R!S92!P=65D92!L;V-A
M;&EZ87(@96P@<&%N96P@;&%T97)A;"!D92!-;WII;&QA+B!#;VUP<G5E8F4@
M<75E(&5S=.D@(@HB86)I97)T;RXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B).;R!S92!P=65D
M96X@;W1O<F=A<B!A;"!U<W5A<FEO(%PB)7-<(B!L;W,@<VEG=6EE;G1E<R!D
M97)E8VAO<R!P87)A(&QA("(*(F-A<G!E=&$@7"(E<UPB.B`E<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS
M9W-T<B`B5&5X=&\@8V]N=&%D;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(E!A[7,B"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B0W5R<V]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`B0W)E87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB
M"FUS9W-T<B`B0W)E82!U;B!V[6YC=6QO(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N
M92(*;7-G<W1R(")#<F5A<B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*
M;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")#<F5A<B!S=6)C
M87)P971A<R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED
M(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!R:79I;&5G:6]S(&1E
M(&-R96%D;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q,@IM<V=I9"`B
M0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!T87)J971A
M(&1E(&-RZ61I=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")#<F]A8VEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M-`IM<V=I9"`B0W5B82(*;7-G<W1R(")#=6)A(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(C0@
M1F%S97,@86-T=6%L97,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G
M:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B4V5S:6]N97,@86-T=6%L
M97,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP
M:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")(;W)A(&%C='5A
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B55),
M(&%C='5A;"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R
M<F5N="!5<V5R<R(*;7-G<W1R(")5<W5A<FEO<R!A8W1U86QE<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*
M;7-G<W1R(")4:65M<&\@86-T=6%L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G
M<W1R(")#;VYD:6-I\VX@86-T=6%L.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE
M(@IM<V=S='(@(D5S=&EL;R!A8W1U86PB"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")097)S
M;VYA;&EZ82!L87,@=&%R96%S(&$@96IE8W5T87(@86P@:6YI8VEA<B!S97-I
M\VX@96X@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B0V]R=&%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")#;W)T87(@<V5L96-C
M:?-N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV-PIM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-H:7!R92(*"B,Z(&-O;F9I
M9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX
M+5(I(@IM<V=S='(@(D-I<NUL:6-O("A+3TDX+5(I(@H*(SH@8V]N9FEG+RYB
M86LO;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2DB"FUS9W-T<B`B0VER[6QI8V\@*%=I;F1O=W,M,3(U,2DB"@HC.B!C
M;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0VER[6QI8V\O56-R86YI86YO
M("A+3TDX+54I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV.`IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B4F5P
M^F)L:6-A($-H96-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W,@IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"B)$4TX@*'9E82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E<R]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@;&EB+TAO<F1E
M+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&EA
M<FEA;65N=&4B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A
M=&%4<F5E($)R;W=S97(B"FUS9W-T<B`BP7)?8F]L(&1A=&]S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,R-S`*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*
M;7-G<W1R(")#;VYS=6QT82!D92!L82!B87-E(&1E(&1A=&]S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S.3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`B1F5C:&$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")392!H82!R96-I8FED;R!L82!F96-H82(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-S@Y"FUS9VED(")$871E('-E;&5C
M=&EO;B(*;7-G<W1R(")396QE8V-I\VX@9&4@9F5C:&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")$[6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*
M;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(D5?;&EM:6YA<B!C;VQU
M;6YA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@
M(D1E8V5M8F5R(@IM<V=S='(@(D1I8VEE;6)R92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@
M(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(&1E8VEM86QE<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*
M;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")2961U8VER('-A;F=R
M861O(@H*(SH@;&EB+W!R969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4&]R(&]M:7-I\VXB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW
M-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")#;VQO<B!P;W(@;VUI
M<VGS;B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E
M9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I9&%D('!O<B!O;6ES:?-N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<U"FUS9VED(")$969A=6QT
M(%-H96QL(@IM<V=S='(@(E-H96QL('!O<B!O;6ES:?-N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R
M(")$969I;FEC:6]N97,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&QI8B](
M;W)D92]097)M<RYP:'`Z,S(V(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#,Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW
M,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3@@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"FUS9VED
M(")$96QE=&4B"FUS9W-T<B`B)FYB<W`[16QI;6EN87(F;F)S<#LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(D5L:6UI;F%R(&-E;&1A
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR
M,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")%;&EM:6YA<B!G<G5P
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B
M1&5L971E($QO9R(*;7-G<W1R(")%;&EM:6YA<B!R96=I<W1R;R(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(D5L:6UI
M;F%R('!R:79I;&5G:6\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B16QI;6EN87(@>2!V86-I87(@;65N<V%J97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED
M(")$96QE=&4@8V5L;"(*;7-G<W1R(")%;&EM:6YA<B!C96QD82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B16QI;6EN87(@8V]L=6UN
M82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(D5L:6UI;F%R
M('!L86YT:6QL87,@86QT97)N871I=F%S(&5X:7-T96YT97,B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M
M97-S86=E<R(*;7-G<W1R(")%;&EM:6YA<B!M96YS86IE<R(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5L:6UI;F%R
M('!R:79I;&5G:6]S(&1E(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G
M<W1R("*_16QI;6EN87(@<')I=FEL96=I;W,@<&%R82!<(B5S7"(@>2!C=6%L
M<75I97(@<')I=FEL96=I;R!D97-C96YD:65N=&4_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E(')O=R(*;7-G<W1R(")%;&EM:6YA<B!F:6QA(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(D5L:6UI;F%R(&ED96YT:61A
M9"!S96QE8V-I;VYA9&$B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")%
M;&EM:6YA<B!S=6)C87)P971A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")%;&EM:6YA(&QA(&-O;'5M;F$@
M86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M(@IM<V=S='(@(D5L:6UI;F$@;&$@9FEL82!A8W1U86PB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B4V4@
M:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@
M8V]N9FEG=7)A8VGS;B!<(B5S7"(N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-3,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"FUS9VED(")$
M96QI=F5R>2!T:6UE(@IM<V=S='(@(DAO<F$@9&4@96YT<F5G83HB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q"FUS9VED
M(")$96YM87)K(@IM<V=S='(@(D1I;F%M87)C82(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R(")$97-C<FEB82!E;"!P<F]B;&5M82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B1&5S8W)I<&-I\VXB"@HC.B!L:6(O2&]R9&4N<&AP.C(P-@IM<V=I9"`B
M1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$
M971A;&QE<R`H=&%M8FGI;B!E;B!E;"!A<F-H:79O(&1E(')E9VES=')O(&1E
M($AO<F1E*3HB"@HC.B!L:6(O2&]R9&4N<&AP.C(Q,`IM<V=I9"`B1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B4V4@:&%N(')E9VES=')A9&\@;&]S(&1E=&%L;&5S('!A<F$@96P@
M861M:6YI<W1R861O<BXB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N
M9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D1E<V%R<F]L
M;&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W(%!O
M:6YT(@IM<V=S='(@(E!U;G1O(&1E(&-O;F1E;G-A8VGS;B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@(@IM<V=S='(@(E!U;G1O(&1E(&-O;F1E;G-A8VGS;B!D92!L82#Z
M;'1I;6$@:&]R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B4'5N=&\@9&4@8V]N
M9&5N<V%C:?-N.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*
M;7-G<W1R(")$92!I>G%U:65R9&$@82!D97)E8VAA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B1&4@9&5R96-H82!A(&EZ<75I
M97)D82(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E
M8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)I;R(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S
M/R(*;7-G<W1R("*_36]S=')A<B!E;B!F;W)M871O(&1E(#(T+6AO<F%S/R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES
M<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(&1E(%9I<W5A;&EZ86-I
M\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@
M(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B36]S=')A<B!P
M<F]N\W-T:6-O(&1E=&%L;&%D;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B36]S
M=')A<B!P<F]N\W-T:6-O("A4048I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(W.3D*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@
M9&4@=FES=7IA;&EZ86-I\VXB"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP
M.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@
M(DYO=&EF:6-A8VGS;B!D92!C;VYS=6QT82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(D1J:6)O=71I(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT
M,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F\@96QI;6EN87(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DYO
M(&%C8V5D97(@9&ER96-T86UE;G1E(&$@;6%I;G1E;F%N8V4N<&AP(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB
M"FUS9W-T<B`B(@HBOT-O;G1I96YE(&QA('!R:6UE<F$@9FEL82!L;W,@;F]M
M8G)E<R!D92!L;W,@8V%M<&]S/R!3:2!E<R!A<^TL('-E;&5C8VEO;F4@(@HB
M97-T82!C87-I;&QA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S(*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN
M:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW,PIM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB
M;&EC82!$;VUI;FEC86YA(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*
M;7-G<W1R("*_3F\@9&ES<&]N92!D92!C=65N=&$_(%-O;&EC[71E;&$N(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,PIM<V=I9"`B1&]W
M;FQO860B"FUS9W-T<B`B1&5S8V%R9V%R(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R(")$97-C87)G87(@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,38Q"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")$97-C87)G87(@;&$@
M8V]N9FEG=7)A8VGS;B!G96YE<F%D82!C;VUO('5N(&=U:?-N(%!(4"XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI
M<W0B"FUS9W-T<B`B3&ES=&$@9&5S<&QE9V%B;&4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=A<R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL
M(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G
M<W1R("(B"B)#;VYT<F]L861O<B!D92!P87-A<F5L82!#;W)R96\M82U335,@
M<&%R82!P<F]V965D;W)E<R!Q=64@<')O<&]R8VEO;F5N(&5S=&4@(@HB<V5R
M=FEC:6\N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-0IM<V=I9"`B
M16-U861O<B(*;7-G<W1R(")%8W5A9&]R(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R
M"FUS9VED(")%9&ET(@IM<V=S='(@(B9N8G-P.TUO9&EF:6-A<B9N8G-P.R(*
M"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO
M8VLB"FUS9W-T<B`B36]D:69I8V%R(&)L;W%U92(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R
M;W5P(@IM<V=S='(@(DUO9&EF:6-A<B!G<G5P;R(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#`*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")-;V1I9FEC87(@<')I=FEL
M96=I;R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B36]D:69I8V%R('!R:79I;&5G
M:6]S(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M(")-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,B"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G
M<W1R(")-;V1I9FEC87(@;W!C:6]N97,@9&4Z(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(DUO9&EF:6-A<B!P<FEV:6QE
M9VEO<R!D92!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(DUO9&EF:6-A<B!P<FEV:6QE9VEO<R!D92`E<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM
M<V=S='(@(D5D=6-A8VGS;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S<*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G:7!T
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N=&\N
M+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@V.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B0V]R<F5O(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHV.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$P"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS;B!D
M92!C;W)R96\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV,PIM<V=I9"`B
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DQA<R!D:7)E
M8V-I;VYE<R!D92!C;W)R96\@=&EE;F5N('%U92!C;VEN8VED:7(N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N
M9FER;6%T:6]N(@IM<V=S='(@(D-O<G)E;R!C;VX@8V]N9FER;6%C:?-N(@H*
M(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA
M:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B4&%S87)E;&$@0V]R<F5O+6$M
M4TU3(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y
M.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D5M;W1I8V]N97,B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP
M='D@;65S<V%G92XB"FUS9W-T<B`B365N<V%J92!E;B!B;&%N8V\B"@HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8V,B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")2
M97-U;'1A9&\@96X@8FQA;F-O+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R
M9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(DQI;7!I87(@=.ER;6EN;W,@9&4@8OIS<75E9&$B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S
M='(@(K]097)M:71I<B!I;G-E<F-I\VX@9&4@:6WA9V5N97,@9&4@;&%S($=A
M;&5R[6%S(&1E(&9O=&]S/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`BOU!E<FUI=&ER(&UE;OH@9&4@8V]N=&5X=&\@9&5L(&)O
M=/-N(&1E<F5C:&\@9&5L(')A=/-N/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-3@X(&QI8B](;W)D92]&;W)M+G!H<#HR-SDS"FUS9VED(")%;F0@>65A
M<B(*;7-G<W1R(")!\6\@9&4@=&5R;6EN86-I\VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E
M($5D:71O<B(*;7-G<W1R(")!9W)A;F1A<B!E9&ET;W(B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C
M=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U
M(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I
M<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B));G1R;V1U
M>F-A('5N82!P<F5G=6YT82!D92!S96=U<FED860@<75E('-E(&QE(&9O<FUU
M;&%RX2!S:2!P<F5C:7-A("(*(G)E86IU<W1A<B!L82!C;VYT<F%S9?%A+"!P
M+F4N(">_0W7A;"!E<R!E;"!N;VUB<F4@9&4@<W4@;6%S8V]T83\G.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.0IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S
M='(@(DEN=')O9'5Z8V$@87%U[2!L82!54DP@9&4@;&$@:6UA9V5N(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I9"`B
M16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(DEN=')O9'5Z8V$@
M;&%S(&QE=')A<R!D92!D96)A:F\Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY.0IM<V=I9"`B17%U871O<FEA;"!'=6EN
M96$B"FUS9W-T<B`B1W5I;F5A($5C=6%T;W)I86PB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y"FUS9VED(")%<FET<F5A
M(@IM<V=S='(@(D5R:71R96$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-`IM<V=I9"`B17)R;W(B"FUS
M9W-T<B`B17)R;W(B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B
M"FUS9W-T<B`B17)R;W(@86P@8W)E87(@96P@8FQO<75E.B`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")%
M<G)O<B!A;"!E;&EM:6YA<B!A;F-L82!D92!S:6YC<F]N:7IA8VGS;CH@)7,B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T
M<B`B17)R;W(@86P@96QI;6EN87(@96P@<F5G:7-T<F\@9&4@<VEN8W)O;FEZ
M86-I\VXZ("5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R(")%<G)O<B!A;"!O8G1E;F5R(&-O;G1E;FED;W,Z("5S(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")%
M<G)O<B!A;"!A8W1U86QI>F%R(&QA(&-O;G1R87-E\6$Z("5S(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R
M('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B17)R;W(@8V]N(&5L(&UE
M;G-A:F4@9&4@8V]R<F5O+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B17)R;W(@86P@97-C
M<FEB:7(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S8*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T;VYI
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]P[6$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("+)
M=&YI8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R
M(")#861A(#$U(&UI;G5T;W,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")#861A
M(#(@;6EN=71O<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,T
M,"!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=U;F1O<R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R
M(")#861A(#4@;6EN=71O<R(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D-A9&$@:6YI8VEO
M(&1E('-E<VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,T
M-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D-A9&$@;65D:6$@
M:&]R82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R(")#861A(&UI;G5T;R(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B
M5F%L;W)E<R!D92!E:F5M<&QO.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HU
M,2!A9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")%:F5C=71A<B(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B17AP86YD:7(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I
M9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")-
M;W-T<F%R(&)A<G)A(&QA=&5R86PB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O
M<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")S92!E
M<W!E<F%B82`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ
M-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B4V4@97-P97)A8F$@=6YA(/IN:6-A('!A;&%B<F$@
M;R!U;B!TZ7)M:6YO(&1E(&+Z<W%U961A(&5N=')E8V]M:6QL861O(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N
M($1A=&4B"FUS9W-T<B`B1F5C:&$@9&4@=F5N8VEM:65N=&\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`B17AP;VYE;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T
M<B`B0V]L;W(@9&4@;&5T<F$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<V"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D-A<F=A
M<B!L82!C;VYF:6=U<F%C:?-N('!O<B!&5%`B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O<W%L+G!H<#HR,C`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+B(*;7-G<W1R(")&86QL;R!A;"!T<F%E<B!L87,@<')E9F5R96YC
M:6%S+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DEN8V%P87H@9&4@8V]N96-T87)S
M92!A;"!S97)V:61O<B!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP
M:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M(@IM<V=S='(@(DEN8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!3
M34(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<R-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B1F%L
M;&\@86P@8V]P:6%R(&1E(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M-S,P"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB
M)7-<(BXB"FUS9W-T<B`B1F%L;&\@86P@8V]P:6%R(&$@7"(E<UPB+B(*"B,Z
M(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(D9A;&QO(&%L
M(&-R96%R('5N82!C;VYE>&GS;B!305-,(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C<V."!L:6(O5D93+W-M8BYP:'`Z-3$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B1F%L;&\@86P@
M=')A<VQA9&%R(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<T"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS
M9W-T<B`B1F%L;&\@86P@<F5C=7!E<F%R.B`E<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S
M='(@(D1E<W!E:F%D;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I
M;F%S*2(*;7-G<W1R("))<VQA<R!-86QV:6YA<R`H1F%L:VQA;F0I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-@IM<V=I
M9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("))<VQA<R!&87)O92(*"B,Z(&QI
M8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(D5R<F]R(&ER<F5C=7!E<F%B;&4Z(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B
M"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@
M(D9A>&5S(@IM<V=S='(@(D9A>&5S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)E<F\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK
M92(*;7-G<W1R(")392!S:65N=&4@8V]M;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R
M(")392!S:65N=&4@8V]M;SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(E!O8V%S(&QL=79I87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M(")%<V-A<V\@86=U86-E<F\@9&4@;FEE=F4B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(DUA=')I
M>B!D92!C86UP;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-0IM<V=I
M9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B0T%05$-(02!D92!&:6=L970B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R.0IM<V=I9"`B1FEG;&5T(&9O
M;G0B"FUS9W-T<B`B3&5T<F$@9&4@1FEG;&5T(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,PIM<V=I9"`B1FEJ:2(*;7-G
M<W1R(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")&:6QE(@IM<V=S='(@(D%R8VAI=F\B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HW.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(DZZ(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL
M97,B"FUS9W-T<B`B3KH@9&4@87)C:&EV;W,Z("5S(&%R8VAI=F]S(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B07)C:&EV;W,B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,`IM
M<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;6)R92!D92!A<F-H:79O(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S<*;7-G:60@(D9I;&4@<V5L96-T
M:6]N(@IM<V=S='(@(E-E;&5C8VGS;B!D92!A<F-H:79O(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@
M(D-A<F=A<B!A<F-H:79O(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP
M,`IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(DQA(&-A<F=A(&1E(&%R8VAI=F]S(&YO(&5S=.$@<V]P;W)T861A+B(*"B,Z
M(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT
M97)S(@IM<V=S='(@(D9I;'1R;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@R"FUS9VED(")&:6YL86YD(@IM<V=S='(@
M(D9I;FQA;F1I82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B0W5A<G1O(&-R96-I96YT92(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G
M:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B0W5A<G1O(&-R96-I96YT92(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-3<*;7-G
M:60@(D9I>"!R871I;R(*;7-G<W1R(")287KS;B!F:6IA(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*
M;7-G<W1R(")6;VQT96%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B
M1&ES<&]S:6-I\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(DYI96)L82(*"B,Z(&QI
M8B]61E,O;75S<6PN<&AP.C$P-R!L:6(O5D93+W-Q;"YP:'`Z,C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G
M<W1R("),82!C87)P971A("5S(&YO(&5X:7-T92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O
M;&]R(@IM<V=S='(@(D-O;&]R(&1E(&QE=')A(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(D-O;6ED82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,PIM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R
M="!I;6%G97,B"FUS9W-T<B`B4&%R82!N879E9V%D;W)E<R!Q=64@;F\@861M
M:71A;B!I;>%G96YE<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS
M9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<F]N\W-T:6-O("A4048I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B
M"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S
M='(@(B(*(D3M87,@9&5L('!R;V[S<W1I8V\@*'1E;F=A(&5N(&-U96YT82!Q
M=64@96P@<')O;O-S=&EC;R!F86-I;&ET861O(&EN8VQU>64@(@HB=&%N=&\@
M96P@9.UA(&-O;6\@;&$@;F]C:&4[('5N(&[Z;65R;R!G<F%N9&4@<V4@=')A
M9'5C:7+A(&5N('5N(&)L;W%U92!M=7D@(@HB86YC:&\I(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R("*_2&$@;VQV:61A9&\@;&$@8V]N=')A<V7Q83\B
M"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(D9O<FUU;&%R:6]S(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D9O<G1U;F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@
M='EP92(*;7-G<W1R(")4:7!O(&1E(&9O<G1U;F$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D9O<G1U
M;F%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T
M=6YE<R`R(@IM<V=S='(@(D9O<G1U;F%S(#(B"@HC.B!C;VYF:6<O+F)A:R]R
M96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&
M;W)O<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM
M<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4F5E;G;M;W,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*
M;7-G<W1R(")6:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B1G)A
M;65S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX-PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O
M;&ET86XB"FUS9W-T<B`B1G)A;F-I82P@365T<F]P;VQI=&%N82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1W5A>6%N82!F<F%N8V5S82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T"FUS
M9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O;&EN97-I82!F<F%N
M8V5S82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R,@IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM
M<V=S='(@(E1E<G)I=&]R:6]S(&9R86YC97-E<R!D96P@<W5R(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B1&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM
M<V=S='(@(D1E;"`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP
M8VGS;B!C;VUP;&5T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B
M3'5N82!L;&5N82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-2!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA
M;64B"FUS9W-T<B`B3F]M8G)E(&-O;7!L971O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.`IM<V=I9"`B1V%B;VXB"FUS
M9W-T<B`B1V%B\VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&5R[6$@9&4@;&$@<75E(&]B=&5N
M97(@;&$@:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R(")'86QE<NUA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.38*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*
M;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N
M97)A<B!C;VYF:6=U<F%C:?-N(&1E("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM
M<V=S='(@(D/S9&EG;R!G96YE<F%D;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`*;7-G:60@(D=E;W)G:6$B"FUS9W-T
M<B`B1V5O<F=I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B06QE;6%N:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS
M"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30*;7-G:60@(D=I8G)A;'1A
M<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(").;VUB<F4@
M:6YD:6-A9&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<Y
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")/
M<&-I;VYE<R!G;&]B86QE<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$W"FUS9VED(")';R(*;7-G<W1R("))<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED
M(")';V]G;&4@36%P<R(*;7-G<W1R(")-87!A<R!D92!';V]G;&4B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H
M(@IM<V=S='(@(D+Z<W%U961A(&5N($=O;V=L92(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES8V%L92(*
M;7-G<W1R(")%<V-A;&$@9&4@9W)I<V5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#`*;7-G:60@(D=R965C92(*;7-G
M<W1R(")'<F5C:6$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@X
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)I96=O("A)
M4T\M.#@U.2TW*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F]E;FQA
M;F1I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#D*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)A;F%D82(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!9&UI;FES=')A8VGS;B!D92!G<G5P;W,B"@HC.B!L:6(O
M2&]R9&4O1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ
M-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S
M='(@(DQO<R!N;VUB<F5S(&1E(&=R=7!O(&YO('!U961E;B!D96IA<G-E(&5N
M(&)L86YC;R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*(D=R;W5P7VQD87`Z($YO('-E('!U961E(&'Q861I<B!E;"!G<G5P
M;R`E<RX@R7-T;R!E<R!L;R!Q=64@9&EJ;R!E;"!S97)V:61O<CH@(@H*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E
M;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!);F-A<&%Z(&1E
M(&5L:6UI;F%R(&5L(&=R=7!O("5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@26YC87!A>B!D92!A8W1U
M86QI>F%R(&5L(&=R=7!O("5S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,30*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P
M;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDX"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861A;'5P92(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S"FUS
M9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,@IM<V=I9"`B1W5A=&5M86QA(@IM
M<V=S='(@(D=U871E;6%L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYE<V5Y(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4')I
M=FEL96=I;W,@9&4@:6YV:71A9&\B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("),+B!I
M;G9I=&%D;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDW"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U":7-S874B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4*
M;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=6%Y86YA(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434P@<V4@;FEE9V$@
M8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&-E;&1A(&1E(&QA
M(&9I;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M("(B"B)(5$U,07)E82!S92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA
M<B!L82#Z;'1I;6$@8V]L=6UN82!D92!L82!T86)L82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434P@<V4@;FEE9V$@8V]B87)D
M96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&9I;&$@9&4@;&$@=&%B;&$N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC
M;VYT<O,@;&$@875T96YT:69I8V%C:?-N($A45%`N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P"FUS9VED(")(86ET
M:2(*;7-G<W1R(")(86ET[2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I;6\@
M2&%S:"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DYE8FQI;F$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3$Y(&QI8B](;W)D92]&;W)M+G!H<#HR.3$T"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B0V%B96-E<F$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M(")#86)E8V5R87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#<*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<R(*;7-G<W1R("))<VQA($AE87)D(&4@27-L87,@36-$;VYA
M;&0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")4;W)M96YT82!T<F]P
M:6-A;"!I;G1E;G-A(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E
M;R`H25-/+3@X-3DM."U)*2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")!;'1U<F$B"@HC.B!L:6(O2&]R
M9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B07EU9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP
M('5S:6YG(&5D:71O<B(*;7-G<W1R(")!>75D82!D96P@961I=&]R(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R
M(")!>75D86YT92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B
M2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V9E<FEO(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB"FUS9W-T<B`B07%U[2!T:65N92!E;"!C;VUI96YZ;R!D96P@87)C:&EV
M;SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,0IM<V=I9"`B2&EG:"(*;7-G<W1R(")!;'1A(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R
M+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")?26YI8VEO(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,PIM<V=I
M9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B4V%N
M=&$@4V5D92`H0VEU9&%D+45S=&%D;R!D96P@5F%T:6-A;F\I(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM<V=S='(@(DEN:6-I;R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D
M9')E<W,B"FUS9W-T<B`B1&]M:6-I;&EO(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E
M8W1O<FEO('!E<G-O;F%L(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5LZ69O
M;F\@<&%R=&EC=6QA<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P.`IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N
M9'5R87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#8*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B
M"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*(DAO<F1E+TMO;&%B.B!392!H86X@96YC;VYT<F%D;R!D871O<R!8
M34P@)7,@;F\@=N%L:61O<R!E;B!E;"!M96YS86IE("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!.:6YG^FX@;65N<V%J92!C;W)R97-P;VYD
M92!A;"!O8FIE=&\@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0T-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@3F\@<V4@96YC;VYT<O,@=6X@;V)J971O(&1E('1I<&\@)7,@96X@
M96P@;65N<V%J92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!392!H
M82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`E<R!<(B5S7"(B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VXB"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($5L(&UO=&]R(&1E
M(&EN=&5G<F%C:?-N('!R96-I<V$@9&4@;&$@97AT96YS:?-N(%!(4"`G9&]M
M>&UL)R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!8
M34P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!)
M;F-A<&%Z(&1E(&-R96%R(&YU979O(.%R8F]L(%A-3"!D96P@;V)J971O("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@96QI;6EN
M87(@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@S
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YC87!A>B!D92!O8G1E;F5R($E$($U)344@
M9&4@;&$@<&%R=&4@9&4@=&EP;R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ87(@)7,@7"(E<UPB.B`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H
M87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN
M8W)O;FEZ87(@96QE;65N=&]S(&-O;7!A<G1I9&]S.B`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@16QE;65N=&\@8V]M<&%R=&ED;R!D97-C;VYO8VED;R!<(B5S7"(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T
M"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B3.UN96$@:&]R:7IO
M;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")-87)G
M96X@:&]R:7IO;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO
M<FEZ;VYT86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R
M93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("*_0_-M;R!L;&5G\R!H87-T
M82!A<77M/R`HH4-O;75N[7%U96QO+"!P;W(@9F%V;W(A*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G
M:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(K]#=6%N=&%S(&-O;'5M;F%S(&1E<V5A(&-O;6)I;F%R/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`BOT-U
MX6YT;W,@8V%M<&]S("AC;VQU;6YA<RD@:&%Y/R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(K]#=6%N=&%S(&9I;&%S(&1E<V5A(&-O;6)I;F%R/R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#D*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DAU;65D860B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@
M(@IM<V=S='(@(DAU;65D860Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T87,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3$*
M;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B2'5N9W+M82(*"B,Z(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H
M<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B2&$@9F%L;&%D;R!L82!C<F5A8VGS
M;B!D96P@8G5Z\VX@24U!4#H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S
M<6PN<&AP.C(Y-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C$T"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(DAA(&9A;&QA9&\@;&$@96QI;6EN86-I\VX@9&5L(&)U
M>O-N($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR
M-#(@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R(")(82!F86QL861O(&QA(&-R96%C:?-N(&1E(&5S<&%C:6\@
M87-I9VYA9&\@9&5L(&)U>O-N($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B1&ER96-C
M:?-N($E0(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G
M:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3&$@9&ER
M96-C:?-N($E0(&YO(&5S=.$@9&ES<&]N:6)L92XB"@HC.B!L:6(O2&]R9&4O
M075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B3&$@9&ER96-C:?-N
M($E0(&YO(&5S=.$@96YT<F4@8FQO<75E<R!#2412('!E<FUI=&ED;W,N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@
M(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B5FEO;&%C:?-N(&QO
M8VMD;W=N($E0+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E
M(@IM<V=S='(@(DE?;G-E<G1A<B!F:6QA(&5N8VEM82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,`IM<V=I9"`B26-E
M;&%N9"(*;7-G<W1R("))<VQA;F1I82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")3\VQO
M(&EC;VYO<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26-O;F]S(&1E
M("5S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED
M("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26-O;F]S(&-O;B!T97AT;R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E
M;G1I='DG<R!N86UE.B(*;7-G<W1R(").;VUB<F4@9&4@;&$@:61E;G1I9&%D
M.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HV,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")3
M:2!N;R!S92!M=65S=')A(&-O<G)E8W1A;65N=&4L("5S('!A<F$@86)R:7)L
M;R!E;B!U;F$@=F5N=&%N82!N=65V82XB"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2XB"FUS9W-T<B`B(@HB4VD@;F\@=F4@;FEN9_IN(&EC;VYO(&UE9&EA
M;G1E($EN=&5R;F5T($5X<&QO<F5R+"!P=65D92!T96YE<B!Q=64@86-T:79A
M<B`B"B)E<W1A(&-A<VEL;&$@<&%R82!D97-A8W1I=F%R(&QA('1R86YS<&%R
M96YC:6$@4$Y'+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B
M"B)3:2!V92!E<W1E(&UE;G-A:F4@<VEN(&YI;F=U;F$@:6UA9V5N+"!L82!I
M;6%G96X@<75E('%U:65R92!C87)G87(@;F\@<V4@(@HB<'5E9&4@;6]S=')A
M<B!E;B!S=2!N879E9V%D;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"FUS9VED("));6%G92!0
M<F5V:65W.B(*;7-G<W1R(")6:7-T82!P<F5V:6$Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B
M26UA9V4@55),(@IM<V=S='(@(E523"!D92!L82!I;6%G96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3@*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B55),(&1E(&QA(&EM86=E
M;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G
M<W1R("));6%G96X@9&4@;&$@9V%L97+M82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B
M26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("));6%G96X@9&4@;&$@9V%L
M97+M83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA
M9V4@=7!L;V%D(@IM<V=S='(@(E-E(&AA(&-A<F=A9&\@;&$@:6UA9V5N(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R("));>%G96YE<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-`HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHW('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(DEM<&]R=&%R+"!P87-O("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE
M;&0Z("5S(@IM<V=S='(@(D-A;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L
M9',Z(@IM<V=S='(@(D-A;7!O<R!I;7!O<G1A9&]S.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I
M9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B26Y?<V5R=&%R(&9I;&$@
M9&5B86IO(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(E-E
M(&AA(&EN9&EC861O('5N(&/S9&EG;R!D92!A8V-I\VX@:6YC;W)R96-T;RXB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED
M("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R
M(").;VUB<F4@9&4@=7-U87)I;R!Y+V\@8V]N=')A<V7Q82!I;F-O<G)E8W1O
M<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B
M(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).;VUB<F4@9&4@
M=7-U87)I;R!O(&1I<F5C8VGS;B!A;'1E<FYA=&EV82!I;F-O<G)E8W1O<RX@
M5G5E;'9A(&$@:6YT96YT87)L;R!O("(*(G#S;F=A<V4@96X@8V]N=&%C=&\@
M8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<&%R82!MX7,@:6YF
M;W)M86-I\VXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(D%U
M;65N=&%R('-A;F=R861O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I82(*;7-G<W1R("));F1I
M82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM
M<V=S='(@(E5S=6%R:6]S(&EN9&EV:61U86QE<R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE
M<VEA(@IM<V=S='(@(DEN9&]N97-I82(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R
M;6%C:?-N(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y
M"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DQA(&EN9F]R
M;6%C:?-N('EA(&YO(&5S=.$@9&ES<&]N:6)L92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@
M(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN<V5R=&%R(&-?;VQU
M;6YA(&1E='+A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PIM<V=I9"`B26YS97)T($EM86=E(@IM
M<V=S='(@(DEN<V5R=&%R(&EM86=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*
M;7-G<W1R("));G-E<G1A<B!T86)L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN
M:R(*;7-G<W1R("));G-E<G1A<B!V[6YC=6QO(%=E8B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I
M9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DEN<V5R=&%R(%]C
M;VQU;6YA(&1E;&%N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R=&$@
M=6YA(&YU979A(&-O;'5M;F$@9&5T<N%S(&1E(&QA(&%C='5A;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(DEN<V5R=&$@=6YA(&YU979A(&-O;'5M;F$@9&5L
M86YT92!D92!L82!A8W1U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R=&$@
M=6YA(&9I;&$@;G5E=F$@9&5B86IO(&1E(&QA(&%C='5A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(DEN<V5R=&$@=6YA(&9I;&$@;G5E=F$@96YC:6UA(&1E(&QA
M(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS97)T82!U;B!PX7)R
M869O('1R87,@96P@;F]D;R!A8W1U86PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M("));G-E<G1A('5N('#A<G)A9F\@86YT97,@9&5L(&YO9&\@86-T=6%L(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B26YS97)T87(@<&QA;G1I;&QA(&%L
M=&5R;F%T:79A(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C0R
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B26YS97)T
M87(@=6YA(&1I<F5C8VGS;B!D92!C;W)R96\@96X@;&$@<75E(')E8VEB:7(@
M;&$@8V]N=')A<V7Q83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E
M<B(*;7-G<W1R("));G-E<G1A<B!C96QD82!D971RX7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED
M("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B26YS97)T87(@8V5L9&$@
M86YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S
M='(@(DEN<V5R=&%R(&-O;'5M;F$@9&5T<N%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YS97)T87(@8V]L=6UN82!A
M;G1E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,"!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("));G-E<G1A<B!M96YS86IE<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("));G-E
M<G1A<B!PX7)R869O(&1E='+A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B26YS97)T87(@<.%R<F%F;R!A;G1E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YS
M97)T87(@9FEL82!D96)A:F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E
M9F]R92(*;7-G<W1R("));G-E<G1A<B!F:6QA(&5N8VEM82(*"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G
M<W1R("));G-E<G1A<B!L82!R97-P=65S=&$@;F5C97-A<FEA(&$@;&$@<')E
M9W5N=&$@9&4@<V5G=7)I9&%D.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA
M9V4B"FUS9W-T<B`B26YS97)T87(O36]D:69I8V%R(&EM86=E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@
M(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("));G-E<G1A<B]-;V1I9FEC
M87(@=NUN8W5L;R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(E-A;&1O(&EN<W5F:6-I
M96YT92!P87)A(&5N=FEA<B!A(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BXB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")386QD;R!I;G-U9FEC
M:65N=&4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN
M=&5G97(B"FUS9W-T<B`B16YT97)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("),:7-T82!D92!E
M;G1E<F]S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM
M<V=S='(@(E5$2"`H0V%B96-E<F$@9&4@1&%T;W,@9&4@57-U87)I;RD@;F\@
M=N%L:61A+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$V-R!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@;&EB+TAO<F1E+T-O
M;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM
M<V=S='(@(D1A=&]S(%I)4"!N;R!VX6QI9&]S(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B07!L:6-A8VGS;B!N;R!VX6QI9&$N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(DE$(&1E(&QO=&4@;F\@=N%L:61O+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#@W(&QI8B](;W)D92]&;W)M+G!H<#HR,34X(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C,R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,CDY(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED
M("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")392!H86X@96YV
M:6%D;R!D871O<R!N;R!VX6QI9&]S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N(@IM<V=S='(@(D1I<F5C8VGS;B!D92!C;W)R96\@;F\@=N%L
M:61A+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$P.2!L:6(O
M2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM
M<V=S='(@(D9O<FUA=&\@9&4@87)C:&EV;R!N;R!VX6QI9&\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI
M8V5N<V4@:V5Y+B(*;7-G<W1R(")#;&%V92!D92!L:6-E;F-I82!N;R!VX6QI
M9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I
M9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B4V4@:&$@
M:6YD:6-A9&\@=6YA('5B:6-A8VGS;B!N;R!VX6QI9&$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@
M;7-G7W1Y<&4N(@IM<V=S='(@(FUS9U]T>7!E(&YO(';A;&ED;RXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B87!I7VED(&YO(';A
M;&ED;R!O(&1E<V%P87)E8VED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N(@IM<V=S='(@(E!A<N%M971R;W,@;F\@=N%L:61O<R!O(&1E
M<V%P87)E8VED;W,N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W
M"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0
M<FEV:6QE9VEO(&1E;"!P861R92!N;R!VX6QI9&]S+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE
M<B!I9"XB"FUS9W-T<B`B240@9&4@87-O8VEA9&\@;F\@=N%L:61O+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L
M:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")#\V1I9V\@9&4@<')O9'5C=&\@
M;F\@=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")0<F]T
M;V-O;&\@;F\@=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B1&5S=&EN871A
M<FEO(&YO(';A;&ED;SH@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,#@P(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI
M9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3V)J971O(&-O;7!A<G1I9&\@;F\@
M=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")$
M:7)E8V-I\VX@9&5L(')E;6ET96YT92!N;R!VX6QI9&$B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U
M;FEC;V1E(&1A=&$N(@IM<V=S='(@(D1A=&]S('5N:6-O9&4@;F\@=N%L:61O
M<RXB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1A<FEO(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T
M('-E;&5C=&EO;B(*;7-G<W1R("));G9E<G1I<B!S96QE8V-I\VXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D*;7-G
M:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27+A;BP@
M4F5P^F)L:6-A($ES;.%M:6-A(&1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X"FUS9VED("))<F%Q(@IM<V=S='(@
M(DER87$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3,*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B27)L86YD82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N
M(@IM<V=S='(@(DES;&$@9&4@36%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS
M(@IM<V=S='(@(D)O<G)A<V-A<R!A:7-L861A<R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-`IM<V=I9"`B27-R865L
M(@IM<V=S='(@(DES<F%E;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C(V"FUS9VED("))<W-U97(B"FUS9W-T<B`B16UI<V]R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))
M=&%L:6,B"FUS9W-T<B`B0W5R<VEV82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,0IM<V=I9"`B271A;'DB"FUS9W-T
M<B`B271A;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(S"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N
M=6%R>2(*;7-G<W1R(")%;F5R;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R-0IM<V=I9"`B2F%P86XB"FUS9W-T<B`B
M2F%P\VXB"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED
M(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]NZ7,@*$E3
M3RTR,#(R+4I0*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G
M:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C0*;7-G:60@(DIO<F1A;B(*
M;7-G<W1R(")*;W)DX6XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI;R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU
M;FEO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-T:69I8V%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(D%L:6YE
M87(@86P@8V5N=')O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G
M<W1R(")*=7-T:69I8V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*
M;7-G<W1R(")!;&EN96%R(&$@;&$@:7IQ=6EE<F1A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@
M(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B06QI;F5A<B!A(&QA(&1E<F5C:&$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86MH<W1A;B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*;7-G:60@
M(DME97`@;W)I9VEN86P_(@IM<V=S='(@(K]#;VYS97)V87(@96P@;W)I9VEN
M86P_(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(V"FUS9VED(")+96YY82(*;7-G<W1R(")+96YY82(*"B,Z(&QI8B](
M;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D5L('-E<G9I9&]R
M($ME<F)E<F]S(&AA(')E8VAA>F%D;R!L82!A=71E;G1I9FEC86-I\VXN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W
M8FEE<R(*;7-G<W1R(").;W9A=&]S(&1E;"!+97)N96PB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G
M<W1R(")#<F5A8VGS;B!D92!C;&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(DAU
M96QL82!D:6=I=&%L(&1E(&QA(&-L879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(E1A;6'Q
M;R!D92!C;&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM
M<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5&EP;R!D92!C;&%V92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B
M"FUS9W-T<B`B57-O(&1E(&QA(&-L879E.B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("),82!C;&%V92!Y82!E>&ES
M=&4@96X@96P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(DYI
M\6]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(Y"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,@IM
M<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B0V]R96$L(%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A
M(&1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,S"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]R
M96$L(%)E</IB;&EC82!D92(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")#;W)E86YO
M("A%54,M2U(I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,T"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5W86ET(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W
M"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMY<F=Y>G-T86XB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS
M9W-T<B`B7T1I<W1R:6)U8VGS;B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DED:6]M82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-PIM
M<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T
M<B`B3&%O+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@4&]P=6QA<B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R
M(")#=6%R=&\@;65N9W5A;G1E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C@X"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("+:;'1I
M;6\@8V%M8FEO(&1E(&-O;G1R87-E\6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T
M97(B"FUS9W-T<B`B0W5A<G1O(&UE;F=U86YT92(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(MIL
M=&EM82!A8W1U86QI>F%C:?-N.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T
M<B`BVFQT:6UA('-E<VGS;CH@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`BVFQT:6UA('-E<VGS;CH@)7,@9&5S9&4@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E
M<B(*;7-G<W1R("+:;'1I;6$@<V5S:?-N.B!.=6YC82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-@IM<V=I9"`B3&%T
M=FEA(@IM<V=S='(@(DQA='9I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DQE>65S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"FUS9VED("),
M87EO=70B"FUS9W-T<B`B1&ES=')I8G5C:?-N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP
M='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R(")$96IA<B!E;B!B;&%N8V\@<&%R
M82!E;&EM:6YA<B!E;"!B;W)D92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S.`IM<V=I9"`B3&5B86YO;B(*;7-G<W1R
M("),96)A;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0P"FUS9VED("),969T(@IM<V=S='(@(DEZ<75I97)D
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`Q"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R(")#86)E8V5R82!I>G%U:65R9&$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S`Y-PIM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B
M5F%L;W)E<R!D92!L82!I>G%U:65R9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#,*;7-G:60@(DQE<V]T:&\B"FUS
M9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B3FEV96PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(*;7-G:60@(DQI
M8F5R:6$B"FUS9W-T<B`B3&EB97)I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-PIM<V=I9"`B3&EB>6%N($%R86(@
M2F%M86AI<FEY82(*;7-G<W1R("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P
M"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM
M<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("),:6=E<F$@;&QO=FEZ;F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM
M<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),;'5V:6$@;&EG97)A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B3&QU=FEA(&QI9V5R82!M871U
M=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B3&QU=FEA(&QI
M9V5R82!V97-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(D%G=6%C97)O(&QI9V5R;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU
M;F1E<B(*;7-G<W1R("),;'5V:6%S('D@=')U96YO<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3
M;F]W(@IM<V=S='(@(DYE=F%D82!S=6%V92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H
M;W=E<B(*;7-G<W1R("),:6=E<F\@86=U86-E<F\@9&4@;FEE=F4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(D-H87-C87)R:6QL;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$T
M"FUS9VED("),:6YK(@IM<V=S='(@(E;M;F-U;&\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@
M(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R(")%;"!V[6YC=6QO(&%P=6YT82!A
M.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H
M92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P
M;&%Y:6YG(@IM<V=S='(@(E9I;F-U;&%R(&1I<F5C8VGS;B!D92!C;W)R96\@
M82!L82!PX6=I;F$@9&4@8V]M<&]S:6-I\VX@86P@;6]S=')A<B(*"B,Z(&QI
M8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B
M3&EN:W,B"FUS9W-T<B`B5NUN8W5L;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R(")#;V]K:64@
M3&EN=7@B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&%R("T@
M96P@=7-U87)I;R!P=65D92!E>&%M:6YA<B!L82!C87)P971A(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS
M9W-T<B`B3&ES=&%R(&)A<V5S(&1E(&1A=&]S(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T
M<B`B3&ES=&%R('1E;6%S(&1E(&%Y=61A(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&ES=&%R('1A
M8FQA<R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8P,0IM<V=I
M9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W0M07)C:&EV92(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U(96QP
M(@IM<V=S='(@(DQI<W0M2&5L<"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E
M<G,N<&AP.C8P,PIM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T+4ED(@H*
M(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DY"FUS9VED("),:7-T
M+4]W;F5R(@IM<V=S='(@(DQI<W0M3W=N97(B"@HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HV,#`*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),
M:7-T+5!O<W0B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3@*
M;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M4W5B<V-R:6)E
M(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DW"FUS9VED("),
M:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M56YS=6)S8W)I8F4B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(DAA(&9A;&QA
M9&\@96P@;&ES=&%D;R!D92!L87,@<V5S:6]N97,Z("5S(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")(82!F86QL861O(&5L(&QI<W1A
M9&\@9&4@=7-U87)I;W,Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+B(*;7-G<W1R(")%;"!L:7-T861O(&1E('5S=6%R:6]S(&5S=.$@9&5S:&%B
M:6QI=&%D;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@
M(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A='5R82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-`IM<V=I9"`B3&ET
M:'5A;FEA(@IM<V=S='(@(DQI='5A;FEA(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T
M<B`B3&5Y96YD;RXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")(;W)A(&QO8V%L
M.B`B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B
M3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DED:6]M82!Y(&AO<F$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<R(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR
M,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@
M(E5B:6-A8VGS;B(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C(P-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,34*;7-G:60@(DQO9R!I;B(*;7-G<W1R("));FEC
M:6%R('-E<VGS;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R
M(")296=I<W1R;R!D92!L87,@<V5S:6]N97,@9&4@<VEN8W)O;FEZ86-I\VX@
M86YT97)I;W)E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M.3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B4V%L:7(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C$*;7-G:60@(DQO9VEN(@IM<V=S='(@(DEN:6-I
M87(@<V5S:?-N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$P
M"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")487)E87,@9&4@:6YI8VEO
M(&1E('-E<VGS;B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.34*;7-G:60@
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(D9A;&SS
M(&5L(&EN:6-I;R!D92!S97-I\VX@<&]R<75E(&EN=')O9'5J;R!I;F-O<G)E
M8W1A;65N=&4@<W4@;F]M8G)E(&1E("(*(G5S=6%R:6\@;R!C;VYT<F%S9?%A
M+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A
M:6QE9"XB"FUS9W-T<B`B1F%L;/,@96P@:6YI8VEO(&1E('-E<VGS;BXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM
M<V=S='(@(E1E>'1O(&-O;7!L971O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(D%M;W(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B3&]W(@IM
M<V=S='(@(D)A:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T
M97)S(@IM<V=S='(@(D%L9F%B971O(&=R:65G;R!E;B!M:6[Z<V,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")!;&9A
M8F5T;R!L871I;F\@96X@;6EN^G-C+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!R;VUA;F]S(&5N(&UI
M;OIS8RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#4*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G
M;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B
M"FUS9W-T<B`B34]41"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R(")%;"!A9&IU;G1O($U3+51.148@;F\@8V]N=&5N
M[6$@9&%T;W,N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W"FUS
M9VED(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,PIM<V=I9"`B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA
M8V5D;VYI82P@06YT:6=U82!297#Z8FQI8V$@675G;W-L879A(&1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q"FUS
M9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-C87(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA
M9VEA(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G
M:60@(DUA:6PB"FUS9W-T<B`B0V]R<F5O(@H*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@
M(D%D;2X@8V]R<F5O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(D-R96%R(%]V[6YC=6QO+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U"FUS9VED(")-86QA=VDB"FUS
M9W-T<B`B36%L87=I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38W"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA
M<VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38T"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD:79A<R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-`IM
M<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R"FUS9VED(")-86QT82(*;7-G
M<W1R(")-86QT82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.CDT
M"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@
M:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)'97-T
M:6]N82!L82!L:7-T82!D92!C871E9V]R[6%S(&-O;B!L82!Q=64@971I<75E
M=&%R(&5L96UE;G1O<R!Y(&QO<R!C;VQO<F5S("(*(F%S;V-I861O<R!A(&1I
M8VAA<R!C871E9V]R[6%S+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P
M82!M87`R-"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#@W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P82!M87!Q=65S
M="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B
M36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")#;W)R97-P;VYD96YC:6%S(&%L
M;6%C96YA9&%S+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)Z;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA
M<F=I;B(*;7-G<W1R(")-87)G96XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP
M.C0X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T
M<B`B36%R8V%R(&-O;B!L87,@8F%N9&5R87,@9&4@3&7M9&\O4VEN(&QE97(B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"FUS9VED(")-87)K('=I=&@@
M;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R
M(")-87)C87(@8V]N(&]T<F%R(&)A;F1E<F%S("AP+F4N($EM<&]R=&%N=&4O
M4F5S<&]N9&ED;RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3(*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T
M<B`B27-L87,@36%R<VAA;&PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3D*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T
M<B`B36%R=&EN:6-A(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")#86UP;W,@8V]I
M;F-I9&5N=&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38P"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I
M=&%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C,*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:6-I;R(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(E-A;&1O(&WA>&EM;R!P
M97)M:71I9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G
M<W1R(")392!H82!S;V)R97!A<V%D;R!E;"!N^FUE<F\@;>%X:6UO(&1E('!A
M<G1E<R!D92!M96YS86IE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S
M"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M
M<"X@;>%X:6UA(/IL=&EM87,@,C0@:&]R87,Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")496UP+B!MX7AI;6$@^FQT:6UA<R`V(&AO<F%S.B`B"@HC.B!L
M:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L
M($)L;V-K<R(*;7-G<W1R(").^FUE<F\@;>%X:6UO(&1E(&)L;W%U97,@9&5L
M('!O<G1A;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@
M(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DQO;F=I='5D(&WA>&EM82(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS
M9W-T<B`B36%Y;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-3,*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`B365D:6-I;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUI96UB
M<F]S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED
M(")-96YU(&UO9&4Z(@IM<V=S='(@(D9O<FUA=&\@9&5L(&UE;OHZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B0V]M8FEN87(@8V5L9&%S
M(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I
M9"`B365S<V%G92(*;7-G<W1R(")-96YS86IE(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)392!H82!C;VUP
M<F]B861O(&-O<G)E8W1A;65N=&4@96P@;65N<V%J92!P97)O(&YO('-E('!U
M961E('9E<FEF:6-A<B!E;"`B"B)C97)T:69I8V%D;R!D96P@9FER;6%N=&4N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G
M:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365N<V%J92!C861U8V%D
M;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,#(*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R
M(")4:7!O(&1E(&UE;G-A:F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*
M;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B5&EE;7!O(&1E($UE=&%R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B0FQO<75E($UE=&%R(&YO(&1I
M<W!O;FEB;&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@
M(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M(D)L;W%U92!-971A<B!N;R!D:7-P;VYI8FQE+B!392!H86X@<F5G:7-T<F%D
M;R!L;W,@9&5T86QL97,@<&%R82!E;"`B"B)A9&UI;FES=')A9&]R+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B3F\@97-TX2!C;VYE8W1A
M9&$@;&$@365T87)$0B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED
M(")-971H;V0B"FUS9W-T<B`B3>ET;V1O(@H*(SH@;&EB+TAO<F1E+U)00R]S
M;V%P+G!H<#HQ,3<@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B
M"FUS9W-T<B`B16P@;>ET;V1O(%PB)7-<(B!N;R!E<W3A(&1E9FEN:61O(@H*
M(SH@;&EB+TAO<F1E+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM
M<V=S='(@(DWI=&]D;R!N;R!D969I;FED;RX@3>ET;V1O(&QL86UA9&\Z("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C<*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-Z71R:6-O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38V"FUS9VED(")-97AI8V\B"FUS9W-T<B`B3>EJ:6-O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4*;7-G:60@(DUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EC<F]N
M97-I82P@17-T861O<R!&961E<F%D;W,@9&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*;7-G:60@(DUI9&1L
M92(*;7-G<W1R(")%;B!M961I;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(E1I<&\@
M36EM92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M<"X@;>UN+B!L87,@
M^FQT:6UA<R`R-"!H;W)A<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#D*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E
M;7`N(&WM;BX@;&%S(/IL=&EM87,@-B!H;W)A<SH@(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(E1O9&%V[6$@;F\@:&$@
M97AP:7)A9&\@;&$@86YT:6?\961A9"!M[6YI;6$@9&4@;&$@8V]N=')A<V7Q
M82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S4*
M;7-G:60@(DUI<G)O<B(*;7-G<W1R(")2969L96IA<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R
M(")-:7-C96SA;F5A(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#`@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!A<75E=&4@
M4$5!4B!(5%107U)E<75E<W0@9&5S87!A<F5C:61O+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)&86QT
M82!L82!C;VYF:6=U<F%C:?-N+B!4:65N92!Q=64@9V5N97)A<FQA(&%H;W)A
M('-I(&1E<V5A('5T:6QI>F%R(&5S=&$@(@HB87!L:6-A8VGS;BXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES
M<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("))1"!D92!M96YS86IE(&1E<V%P
M87)E8VED;RXB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-
M86EL+B(*;7-G<W1R(")087%U971E(%!%05(@36%I;"!D97-A<&%R96-I9&\N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B240@9&4@<V5S:?-N
M(&1E<V%P87)E8VED;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("),=6XB"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B0V]R<F5O(&WS=FEL(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO9&5R871E(@IM
M<V=S='(@(DUO9&5R861O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*;7-G:60@(DUO9&EF
M:65D($1A=&4B"FUS9W-T<B`B4V4@:&$@;6]D:69I8V%D;R!L82!F96-H82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")-;V1I9FEC87(@
M55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@
M(DUO9'5L=7,B"FUS9W-T<B`B3?-D=6QO(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P"FUS9VED(")-;VQD;W9A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R(")-;VQD879I82P@4F5P^F)L:6-A(&1E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y
M"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B3?-N86-O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V"FUS9VED(")-;VYG
M;VQI82(*;7-G<W1R(")-;VYG;VQI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-3@T"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-97,@>2!A
M\6\B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-
M;VYT:&QY(@IM<V=S='(@(DUE;G-U86QM96YT92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,0IM<V=I9"`B36]N='-E
M<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E
M<R(*;7-G<W1R(")&87-E<R!D92!L82!L=6YA(@H*(SH@;&EB+T9I;&4O0U-6
M+G!H<#HQ.38@;&EB+T9I;&4O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"XB"FUS9W-T<B`B4V4@:&%N(&5N8V]N=')A9&\@;>%S(&-A
M;7!O<R!E;B!L82!L[6YE82`E9"!Q=64@;&]S("5D(&5S<&5R861O<RXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R<G5E8V]S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L
M>2!#;&5A<B(*;7-G<W1R(")&=6YD86UE;G1A;&UE;G1E(&1E<W!E:F%D;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS
M9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(D9U;F1A;65N=&%L;65N=&4@
M;G5B;W-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@
M(D9U;F1A;65N=&%L;65N=&4@;G5B;W-O('D@=F5N=&]S;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T
M;'D@4W5N;GDB"FUS9W-T<B`B1G5N9&%M96YT86QM96YT92!S;VQE861O(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G
M:60@(DUO=F4@1&]W;B(*;7-G<W1R(")$97-P;&%Z87(@:&%C:6$@86)A:F\B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM
M<V=I9"`B36]V92!,969T(@IM<V=S='(@(D1E<W!L87IA<B!A(&QA(&EZ<75I
M97)D82(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(D1E<W!L87IA<B!A(&QA
M(&1E<F5C:&$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")$97-P;&%Z87(@:&%C
M:6$@87)R:6)A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(D1E<W!L87IA<B!H
M86-I82!A8F%J;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")$97-P;&%Z87(@:&%C:6$@87)R
M:6)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38X"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEQ=64B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(DQI<W1A<R!D97-P;&5G86)L
M97,@;75L=&DM;FEV96PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@
M(DUA<&$@54L@;?IL=&EP;&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T
M,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS
M;B!M^FQT:7!L92(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("))9&5N=&ED860B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B36D@:61E;G1I9&%D(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HT-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S
M='(@(DUI('!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT
M,@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")$:7-T<FEB=6-I
M\VX@9&4@;6D@<&]R=&%L(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34U"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY
M86YM87(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY/
M+"!.3R!E<W1O>2!D92!A8W5E<F1O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1N968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`R"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M3F%M92(*;7-G<W1R(").;VUB<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-CD*;7-G:60@(DYA;6EB:6$B"FUS9W-T
M<B`B3F%M:6)I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W.`IM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<*
M;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U"FUS9VED(").971H97)L
M86YD<R(*;7-G<W1R(")(;VQA;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,*;7-G:60@(DYE=&AE<FQA;F1S($%N
M=&EL;&5S(@IM<V=S='(@(D%N=&EL;&%S($AO;&%N9&5S87,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B55),(&)A<V4@9&4@3F5T<V-A<&4B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E(&%N=6QA8VGS;B!D92!#
M02!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(E52
M3"!D92!P;VSM=&EC87,@9&4@0T$@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A
M;"!54DPB"FUS9W-T<B`B55),(&1E(')E;F]V86-I\VX@9&4@3F5T<V-A<&4B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E(&%N=6QA8VGS
M;B!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M3F]M8G)E(&1E('-E<G9I9&]R(%-33"!D92!.971S8V%P92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T
M:69I8V%T92!C;VUM96YT(@IM<V=S='(@(D-O;65N=&%R:6\@9&5L(&-E<G1I
M9FEC861O(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS
M9W-T<B`B5&EP;R!D92!C97)T:69I8V%D;R!D92!.971S8V%P92(*"B,Z(&-O
M;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R
M:R(*;7-G<W1R(")2960B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,C4@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B
M3G5N8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S`*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3G5E=F$@
M0V%L961O;FEA(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").=65V82!C
M871E9V]R[6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE
M=R!-;V]N(@IM<V=S='(@(DQU;F$@;G5E=F$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P
M=&EO;F%L*2(*;7-G<W1R(").=65V;R!N;VUB<F4@9&4@=7-U87)I;R`H;W!C
M:6]N86PI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@P"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").=65V82!:
M96QA;F1A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS
M9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B0V]N=')A<V7Q82!N=65V82(*
M"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T
M<B`B3&$@;G5E=F$@8V]N=')A<V7Q82!E>'!I<F%RX2!E;"`E>"XB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S
M=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DQA<R!C;VYT<F%S9?%A<R!N
M;R!C;VEN8VED96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G
M<W1R(").=65V82!V96YT86YA("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4R(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G
M<W1R(").;W1I8VEA<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD
M:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'+B!D92!N;W1I
M8VEA<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C0Q('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U"FUS
M9VED(").97AT(@IM<V=S='(@(E-I9W5I96YT92(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(")0<O-X
M:6UA<R`T(&9A<V5S(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N
M<R(*;7-G<W1R(")/<&-I;VYE<R!S:6=U:65N=&5S(@H*(SH@;&EB+TAO<F1E
M+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(E-I9W5I
M96YT93XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S0*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S$*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S"FUS9VED(").:6=E
M<FEA(@IM<V=S='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(").;V-H92(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.0IM
M<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F\B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(DYO(&AA>2!D871O<R!D92!C;VYF:6=U
M<F%C:?-N('!A<F$@;6]S=')A<B!D:69E<F5N8VEA<RXB"@HC.B!L:6(O5D93
M+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").;R!S92!D:7-P
M;VYE(&1E(&5S=')A=&5G:6$@9&4@96QA8F]R86-I\VX@9&4@:6WA9V5N97,@
M25-/+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S
M"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B3F\@:&%Y('!L
M86YT:6QL82!D92!L;W1E<R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3`Q"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,S@U"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;B(*;7-G<W1R(").;R!H87D@8FQO<75E<R!E;B!L82!P
M;W-I8VGS;B!I;F1I8V%D82(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP
M.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED
M;R!U;B!N;VUB<F4@9&4@86=E;F1A('!A<F$@;&$@875T96YT:69I8V%C:?-N
M($U#04PN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO
M(&-H86YG92XB"FUS9W-T<B`B4VEN(&-A;6)I;W,N(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(DYO('-E('!U961E
M;B!A\6%D:7(@9&5S8V5N9&EE;G1E<R!A(&5S=&4@<')I=FEL96=I;RXB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$W."!L:6(O2&]R9&4N<&AP.C4Q-R!L:6(O2&]R
M9&4O571I;"YP:'`Z-S@R"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T
M<B`B3F\@<V4@:&$@97-P96-I9FEC861O(&EN9F]R;6%C:?-N(&1E(&-O;F9I
M9W5R86-I\VX@<&%R82`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#8X"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O(&EN
M9F]R;6%C:?-N(&1E(&-O;F9I9W5R86-I\VX@<&%R82!61E,@<&]R($944"XB
M"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-C@T"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T
M<B`B3F\@<V4@:&$@97-P96-I9FEC861O(&EN9F]R;6%C:?-N(&1E(&-O;F9I
M9W5R86-I\VX@<&%R82!61E,@<&]R(%-13"XB"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW-3,*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*(DYO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@5D93('!O<B!A<F-H:79O(%-13"XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE
M9G0N(@IM<V=S='(@(DYO('%U961A('-A;&1O+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!E;"!D
M97-T:6YO+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,3@*;7-G:60@
M(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B3F\@<V4@:&$@8V%R9V%D;R!N
M:6YG^FX@87)C:&EV;R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM
M<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DYO('-E(&AA;B!E;F-O
M;G1R861O(&EC;VYO<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,"!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G
M<W1R(").;R!S92!H82!D969I;FED;R!L82!U8FEC86-I\VXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(DYO('-E(&AA(&1E9FEN:61O(&QA('5B
M:6-A8VGS;BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(").;R!S
M92!H82!I;G1R;V1U8VED;R!U;B!M96YS86IE+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF
M:65D+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@=6X@;F]M8G)E
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G
M:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYO('-E(&AA(&5S
M<&5C:69I8V%D;R!U;B!N^FUE<F\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
M3F\@;V9E;G-I=F%S(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N
M=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO
M('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T
M96YT:69I8V%C:?-N($E-05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I
M9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@2V5R
M8F5R;W,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T(&QI8B](
M;W)D92]!=71H+W!A;2YP:'`Z-S4*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP
M:'`Z-S<*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@
M=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@9&4@:6YI
M8VEO+B(*"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A
M<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!005-35T0N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<V4@
M:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I
M9FEC86-I\VX@4TU"+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F\@<V4@
M:&$@:6YD:6-A9&\@=NUA(&1E(&%C8V5S;R!A(&QO<R!B:6YA<FEO<R!/<&5N
M4U-,+B!087)A('1R86)A:F%R(&-O;B`B"B)D871O<R!02T-3(#$R(&AA8V5N
M(&9A;'1A(&QO<R!B:6YA<FEO<R!/<&5N4U-,+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG
M;G5P<RXB"FUS9W-T<B`B4VEN(&%L=&%S('!E;F1I96YT97,N(@H*(SH@;&EB
M+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(D-A
M<F5C92!D92!Q=6]T82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R
M(")3:6X@<F%Y87,B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B
M3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B3F\@<V4@:&$@97-P
M96-I9FEC861O('5N('-E<&%R861O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E
M<R(*;7-G<W1R(").:6YG=6YO(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C8P,`IM
M<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(DYO(&5X:7-T92!E;"!A<F-H
M:79O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I
M9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE
M+B(*;7-G<W1R(").;R!S92!D:7-P;VYE(&1E('5N(&1I<F5C=&]R:6\@9&4@
M86QM86-E;F%M:65N=&\@=&5M<&]R86PN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB
M"FUS9W-T<B`B3F\@<V4@:&$@96YV:6%D;R!E;"!N;VUB<F4@9&4@=7-U87)I
M;R!Y+V\@;&$@8V]N=')A<V7Q82XB"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P
M8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*
M;7-G<W1R(").;R!S92!H86X@9&5V=65L=&\@9&%T;W,@6$U,(';A;&ED;W,B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.#0*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S
M(@IM<V=S='(@(E-I;B!V86QO<F5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Q.0IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(DYO('-E(&5N8V]N='+S(&QA('9E<G-I\VX@96X@;&$@8V]N9FEG
M=7)A8VGS;B!O<FEG:6YA;"X@4F5G96YE<F%R(&QA("(*(F-O;F9I9W5R86-I
M\VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R-PIM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F\@<V4@96YC;VYT<O,@
M;&$@=F5R<VGS;B!E;B!L82!C;VYF:6=U<F%C:?-N+B!296=E;F5R87(@;&$@
M8V]N9FEG=7)A8VGS;BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,C<@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U
M"FUS9VED(").;VYE(@IM<V=S='(@(DYI;F=U;F$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU
M<V4@:6UP;&EC:70I(@IM<V=S='(@(DYI;F=U;F\@*'5S;R!I;7!L[6-I=&\I
M(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B3F]R
M9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3O-R9&EC;R`H25-/+3@X-3DM
M,3`I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3<R"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("))<VQA(&1E
M($YO<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(DAE;6ES9F5R:6\@;F]R=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3@*;7-G:60@(DYO<G1H97)N($UA<FEA
M;F$@27-L86YD<R(*;7-G<W1R("))<VQA<R!-87)I86YA<R!D96P@3F]R=&4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S8*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)U96=A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G
M<W1R(").;R!D97-P=>ES(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B3F\@86YT97,B"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C0R,0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y
M(@IM<V=S='(@(DYO(&5S('5N(&1I<F5C=&]R:6\B"@HC.B!L:6(O5D93+TE3
M3U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HU.0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.34*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`B4VEN(&1E<V%R<F]L;&%R+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T
M<B`B4VEN(&5S=&%B;&5C97(B"@HC.B!L:6(O5D93+G!H<#HQ.3,@;&EB+U9&
M4RYP:'`Z,C`X(&QI8B]61E,N<&AP.C(S-"!L:6(O5D93+G!H<#HR-3(*(SH@
M;&EB+U9&4RYP:'`Z,C8Y(&QI8B]61E,N<&AP.C(X-2!L:6(O5D93+G!H<#HS
M,#$@;&EB+U9&4RYP:'`Z,S$V"B,Z(&QI8B]61E,N<&AP.C,S,R!L:6(O5D93
M+G!H<#HS-C8@;&EB+U9&4RYP:'`Z-#(V(&QI8B]61E,N<&AP.C4P-0HC.B!L
M:6(O5D93+G!H<#HU-S0@;&EB+U9&4RYP:'`Z-3DQ(&QI8B]61E,N<&AP.C8V
M.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T-2!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C$W-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C$X.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C(S-@IM<V=I
M9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F\@97-TX2!S;W!O<G1A9&\N
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#@@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@8V]N9FEG+RYB86LO:&]O:W,N<&AP
M+F1I<W0Z,3`U."!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*
M;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&%S(@H*(SH@<V5R=FEC97,O;V)R
M;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RXB"FUS9W-T<B`B3F\@:&%Y(&YA9&$@=FES=6%L:7IA8FQE+"!R
M971R;V-E9&$N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*
M;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=FEE;6)R92(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`B3OIM
M97)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E
M<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(D[Z;65R;R!D92!C87)A8W1E<F5S
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E
M<B!O9B!C;VQU;6YS(@IM<V=S='(@(D[Z;65R;R!D92!C;VQU;6YA<R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8W(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#(Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@
M<F]W<R(*;7-G<W1R(").^FUE<F\@9&4@9FEL87,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"B).;R!S92!H86X@97-P96-I9FEC861O(&[Z;65R;W,@82!A
M8W1U86QI>F%R(&5N(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@
M(D]+(@IM<V=S='(@(D%C97!T87(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J
M971O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@
M(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D-R96%D;W(@9&4@;V)J971O<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G
M<W1R(")/8W1A;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]C='5B<F4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S
M='(@(D9I;'1R87(@;V9E;G-A<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y
M+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(D]F:6-I;F$B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L
M9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T
M<B`B3&$@8V]N=')A<V7Q82!A;G1I9W5A('D@;&$@;G5E=F$@9&5B96X@<V5R
M(&1I<W1I;G1A<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")#;VYT<F%S9?%A(&%N
M=&EG=6$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B3&$@
M8V]N=')A<V7Q82!A;G1I9W5A(&YO(&5S(&-O<G)E8W1A+B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,0IM<V=I9"`B
M3VUA;B(*;7-G<W1R(")/;>%N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")3\VQO(&QO<R!S97)V:61O<F5S
M($E-05`@<V]P;W)T86X@;&%S(&-A<G!E=&%S(&-O;7!A<G1I9&%S+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B4_-L;R!O9F5N<VEV87,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@U,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW,0IM
M<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R
M(")3\VQO('-E('!E<FUI=&4@=6YA(&1I<F5C8VGS;B!D92!C;W)R96\N(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY
M('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E
M(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R
M92(*;7-G<W1R("(B"B)3\VQO(&5L('!R;W!I971A<FEO(&\@=6X@861M:6YI
M<W1R861O<B!D92!S:7-T96UA<R!P=65D92!C86UB:6%R(&QA("(*(G!R;W!I
M961A9"!O(&QO<R!P<FEV:6QE9VEO<R!D92!P<F]P:65T87)I;R!D92!U;B!R
M96-U<G-O(&-O;7!A<G1I9&\B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT
M,2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B06)R:7(@96X@=6YA(&YU979A('9E;G1A;F$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="XB"FUS9W-T<B`B17)R;W(@3W!E;E-33#H@3F\@<V4@
M<'5E9&5N(&5X=')A97(@9&%T;W,@9&4@;&$@<&%R=&4@4R]-24U%(&9I<FUA
M9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(D%B<FER(&5S=&4@=NUN8W5L;R!E;B!U;F$@=F5N
M=&%N82!N=65V82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I
M9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")3:7-T96UA(&]P97)A=&EV
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-34*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N97,B"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3W!C:6]N97,@
M9&4@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B3&ES=&$@;W)D
M96YA9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I
M9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IA8VGS;B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I
M;VYA;"!5;FET(@IM<V=S='(@(E5N:61A9"!O<F=A;FEZ871I=F$B"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N
M:7II;F<B"FUS9W-T<B`B3W)G86YI>F%C:?-N(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E(@IM<V=S='(@(E!L86YT:6QL82!D92!A<&QI8V%C:?-N(&]R:6=I;F%L
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")0;&%N
M=&EL;&%S(&]R:6=I;F%L97,@96X@)7,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B
M3W1H97(B"FUS9W-T<B`B3W1R;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.CDY(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$S-"!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]T<F$@:6YF;W)M86-I\VXB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!0
M97)M:7-S:6]N<R(*;7-G<W1R(")0<FEV:6QE9VEO<R!D96P@<')O<&EE=&%R
M:6\B"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3&$@
M875T96YT:69I8V%C:?-N(%!!32!N;R!E<W3A(&1I<W!O;FEB;&4N(@H*(SH@
M;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z
M.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.CI-;W1O<B!D92!C;W)R96\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@
M1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B1FER;6$@9&EG:71A;"!01U`B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@
M16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%T;W,@8VEF<F%D;W,@8V]N(%!'
M4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D-L879E(%!'4"!P^F)L:6-A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")$871O<R!F:7)M861O<R]C:69R
M861O<R!C;VX@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED
M(")02%`@0V]D92(*;7-G<W1R(")#\V1I9V\@4$A0(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B26YTZ7)P
M<BX@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B3&QO=FEZ;F$@
M=F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,Y"FUS9VED(")032!286EN(@IM<V=S='(@(DQL=79I82!V97-P
M97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B0VAA<&%R<F]N97,@
M=F5S<&5R=&EN;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(").:65V92!V97-P
M97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")!9W5A8V5R
M;R!D92!N:65V92!V97-P97)T:6YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")3
M;VP@=F5S<&5R=&EN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")";W)R
M87-C87,@=F5S<&5R=&EN87,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,C@V"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R
M(").;R!S92!E;F-U96YT<F$@;&$@97AT96YS:?-N(%!/4TE8(@H*(SH@;&EB
M+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(DEN=.ER
M<'(N(%!?2%`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(DUA<F=E
M;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X-PIM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-TX6XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT"FUS
M9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(*;7-G:60@(E!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T:6YO<RP@
M5&5R<FET;W)I;W,@3V-U<&%D;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#(*;7-G:60@(E!A;F%M82(*;7-G<W1R
M(")086YA;>$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#4*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B
M4&%P^F$@3G5E=F$@1W5I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-0IM<V=I9"`B4&%R86=U87DB"FUS9W-T
M<B`B4&%R86=U87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-PIM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")087)C
M:6%L;65N=&4@;G5B;W-O(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,W"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B
M"FUS9W-T<B`B0V]N=')A<V7Q82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(DQA(&-O;G1R87-E\6$@<V4@8V%M8FEA9&\@8V]R<F5C
M=&%M96YT92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C,*
M;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")#;VYT<F%S9?%A
M(&EN8V]R<F5C=&$B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$U
M,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B2&%Y('%U92!I;G1R;V1U8VER('5N82!C;VYT
M<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N(%)!1$E54RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VXB"FUS9W-T<B`B0V]N=')A<V7Q82!C;VX@8V]N9FER;6%C
M:?-N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED
M(")087-S=V]R9#HB"FUS9W-T<B`B0V]N=')A<V7Q83HB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G
M<W1R(")#;VYT<F%S9?%A.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(DQA<R!C;VYT<F%S9?%A<R!T:65N96X@<75E(&-O:6YC:61I<BXB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B
M"FUS9W-T<B`B4&5G87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*
M;7-G<W1R(")096=A<B!D96P@<&]R=&%P87!E;&5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*
M;7-G<W1R(")6[6$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")!;'1A<R!P96YD
M:65N=&5S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(D=E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T
M<B`B4&]R8V5N=&%J92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,B"FUS9W-T<B`B4F5A;&EZ87(@;W!E<F%C:6]N97,@9&4@;6%N
M=&5N:6UI96YT;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C0Q
M,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/R(*;7-G<W1R("*_4F5A;&EZ87(@;W!E<F%C:6]N97,@9&4@;6%N=&5N
M:6UI96YT;R!A;"!I;FEC:6%R('-E<VGS;C\B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")0<FEV
M:6QE9VEO(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB
M"FUS9W-T<B`B3F\@<V4@:&$@96QI;6EN861O(&5L('!R:79I;&5G:6\@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HV,#,*;7-G:60@(E!E<FUI<W-I
M;VX@1&5N:65D(@IM<V=S='(@(E!R:79I;&5G:6\@9&5N96=A9&\B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4')I=FEL96=I
M;W,B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU.`HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@
M861M:6XO<&5R;7,O:6YD97@N<&AP.C(R"FUS9VED(")097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VGS;B!D92!P<FEV
M:6QE9VEO<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C8X"FUS
M9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS
M;B!P97)S;VYA;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R=2(*;7-G<W1R(")097+Z(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@
M(DUA<V-O=&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@V"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI
M<&EN87,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\B"@HC.B!C;VYF:6<O
M+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G
M<W1R(")&;W1O9W)A9NUA<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@
M(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0[7AE;&5S(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S
M(@IM<V=S='(@(E3S<&EC;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B4'5L<V4@96X@=6YA(&-E;&1A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(D-O;F9I<FUE('%U92!D
M97-E82!E;&EM:6YA<B!E<W1E(&5L96UE;G1O.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+B(*;7-G<W1R(")#;VYF:7)M92!Q=64@9&5S96$@96QI;6EN87(@
M96P@=NUN8W5L;R!A(&5S=&4@96QE;65N=&\N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U-C(*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N(@IM<V=S='(@(DEN=')O9'5Z8V$@=6X@;65S('D@=6X@8?%O+B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R
M"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.B(*;7-G<W1R("));G1R;V1U>F-A(&5L(&YO;6)R92!D92!L82!N=65V
M82!C871E9V]R[6$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#$*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@
M(DEN=')O9'5Z8V$@=6YA(&1I<F5C8VGS;B!)4"!VX6QI9&$N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-#`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N(@IM<V=S='(@(DEN=')O9'5Z8V$@=6YA(&9E8VAA(';A;&ED82P@8V]M
M<')U96)E(&5L(&[Z;65R;R!D92!D[6%S(&1E;"!M97,N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N(@IM<V=S='(@(DEN=')O9'5Z8V$@=6YA(&AO<F$@=N%L:61A+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T
M<B`B4')O<&]R8VEO;F4@=6X@<F5S=6UE;B!D96P@<')O8FQE;6$N(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("));G1R;V1U>F-A('-U(&YO;6)R
M92!D92!U<W5A<FEO('D@8V]N=')A<V7Q82XB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL
M;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@
M=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DQE82!E;"!T97AT;R!S
M:6=U:65N=&4N($1%0D4@86-E<'1A<B!L;W,@=.ER;6EN;W,@<VD@<75I97)E
M('5S87(@96P@<VES=&5M82XB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.B(*;7-G<W1R("));G1R;V1U>F-A(&5L(&YU979O(&YO
M;6)R92!D92!C871E9V]R[6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B
M4&]L;VYI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B
M4&]L:71I8W,B"FUS9W-T<B`B4&]L[71I8V$B"@HC.B!C;VYF:6<O+F)A:R]R
M96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(D5N
M8W5E<W1A<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3,*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(T"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E
M(@IM<V=S='(@(E!O<VEC:?-N(&1E(&QA(&EM86=E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VEC:?-N(&1E(&QA
M('1A8FQA(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0IM<V=I9"`B4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S
M='(@(D5N=FEA<B!A(&5S=&$@8V%R<&5T82`H;F\@;V)L:6=A9&\@<&]R($E-
M05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4')E8VEP:71A8VEO
M;F5S(&1E(&QA*',I(/IL=&EM82AS*2`E<R!H;W)A*',I.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(E!R;V)A8FEL:61A9#QB<B`O/F1E
M('!R96-I<&ET86-I\VXB"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z
M.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@;F\@<V4@96YC;VYT
M<O,@;&$@97AT96YS:?-N($Q$05`@<F5Q=65R:61A+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]S97-S:6]N.B!N;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@
M9&4@<V5S:?-N(')E<75E<FED82XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B4')E<VGS;B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@
M;&5V96PZ("(*;7-G<W1R(")0<F5S:?-N(&%L(&YI=F5L(&1E;"!M87(Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B4')E<VGS;CH@(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B5FES=&$@<')E=FEA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"FUS9VED
M(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M5FES=&$@<')E=FEA(&1E(&QA(&EM86=E;B!E;B!U;F$@;G5E=F$@=F5N=&%N
M82(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S
M='(@(D]P8VEO;F5S(&%N=&5R:6]R97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N
M="(*;7-G<W1R("));7!R:6UI<B!D;V-U;65N=&\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@
M(D-L879E('!R:79A9&$B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS
M9VED(")0<F]B;&5M(@IM<V=S='(@(K]0<F]B;&5M87,_(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N
M(@IM<V=S='(@(D1E<V-R:7!C:?-N(&1E;"!P<F]B;&5M82(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B
M"FUS9W-T<B`B4')O>65C=&]S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M,3$@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#@@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R-S8*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E1E>'1O(&1E;"!I
M;F1U8W1O<B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4'5B;&EC($ME>2(*;7-G<W1R(")#;&%V92!01U`@</IB;&EC82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;6\@9&4@8VQA=F4@</IB
M;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B26YF;W)M86-I\VX@9&4@8VQA
M=F4@</IB;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM
M<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B3F\@<V4@9V5N97)A<F]N(&-O<G)E8W1A
M;65N=&4@;&%S(&-L879E<R!0^F)L:6-A+U!R:79A9&$N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,0IM<V=I9"`B
M4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I8V\B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A
M9V5S(@IM<V=S='(@(DQI;7!I87(@;65N<V%J97,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV"FUS9VED(")1871A
M<B(*;7-G<W1R(")1871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM
M<V=I9"`B475E<GDB"FUS9W-T<B`B0V]N<W5L=&$B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z.#`*;7-G:60@(E%U;W1A(@IM<V=S='(@(E%U;W1A(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B0VQA
M=F4@4E-!('#Z8FQI8V$@*"5D(&)I="DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(D)O=/-N
M(&1E(&]P8VGS;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0U"FUS9VED(")286EN(@IM<V=S='(@(DQL=79I82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")2
M86EN($5A<FQY(@IM<V=S='(@(DQL=79I82!M871U=&EN82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN
M($QA=&4B"FUS9W-T<B`B3&QU=FEA('9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!3
M:&]W97(B"FUS9W-T<B`B06=U86-E<F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*
M;7-G<W1R("),;'5V:6$@>2!.:65V92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O(%-N;W<B"FUS
M9W-T<B`B3&QU=FEA(&$@3FEE=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B4G5E9&$@9&4@
M;&$@9F]R='5N82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2
M871I;R(*;7-G<W1R(")287KS;B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(B9N8G-P.TQE97(F;F)S
M<#LB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0W"FUS9VED(")296%D(&UE
M<W-A9V5S(@IM<V=S='(@(DQE97(@;65N<V%J97,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92XB"FUS9W-T<B`BOT5L:6UI;F%R(')E86QM96YT92`E<S\@17-T82!O
M<&5R86-I\VX@;F\@<V4@<'5E9&4@9&5S:&%C97(N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(K]%;&EM:6YA
M<B!R96%L;65N=&4@;&]S(&1A=&]S(&1E;"!U<W5A<FEO("5S/R!%<W1A(&]P
M97)A8VGS;B!N;R!S92!P=65D92`B"B)D97-H86-E<BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O
M97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")6=65L=F4@82!R96%L:7IA
M<B!L82#Z;'1I;6$@86-C:?-N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B
M"FUS9W-T<B`B06-T=6%L:7IA<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N
M=',Z(@IM<V=S='(@(D%C='5A;&EZ87(@96QE;65N=&]S(&1E(&UE;OH@9&EN
MX6UI8V]S.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,T-0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B06-T=6%L:7IA
M<B!V:7-T82!D96P@<&]R=&%L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(S,0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B
M"FUS9W-T<B`B3F%V96=A9&]R(&1E(')E;&%C:6]N97,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B4F5F<F5S8V%R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS
M9W-T<B`B3V)S97)V86-I;VYE<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B4V5R
M=FED;W)E<R!R96UO=&]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),(')E;6]T82`H:'1T<#HO+W=W=RYE
M:F5M<&QO+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,R!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(R"FUS9VED(")296UO=F4B"FUS9W-T<B`B475I=&%R(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB
M"FUS9W-T<B`B475I=&%R(&)L;W%U92(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS
M9W-T<B`B475I=&%R(&-O;'5M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN
M9R(*;7-G<W1R(")%;&EM:6YA<B!F;W)M871O(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@
M(E%U:71A<B!P87(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`Q"FUS
M9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B16QI;6EN87(@9W5I\VX@9W5A<F1A
M9&\@9&5L(&1I<F5C=&]R:6\@=&5M<&]R86P@9&5L('-E<G9I9&]R+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")%;&EM:6YA<B`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE
M;G0B"FUS9W-T<B`B16QI;6EN87(@97-T92!N;V1O(&1E;"!D;V-U;65N=&\B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED
M(")296UO=F4@=7-E<B(*;7-G<W1R(")%;&EM:6YA<B!U<W5A<FEO(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")%;&EM:6YA<B!U
M<W5A<FEO.B`E<R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*
M;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@(@IM<V=S='(@(DYO('-E('!U961E(')E<W!O;F1E<B!A
M(&QA('-O;&EC:71U9"X@0_-D:6=O(&1E(&5R<F]R(&1E=G5E;'1O.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(DYO
M('-E(&5N8V]N='+S(&5L('-E<G9I8VEO('-O;&EC:71A9&\N(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ.#4@;&EB+TAO<F1E+G!H<#HU,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O
M(&5L(%PB)7-<(B!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;B!D92`E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<T(&QI8B]61E,O<W%L+G!H<#HV
M.3`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@96P@
M7"(E<UPB(')E<75E<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N(&1E(%9&4RXB
M"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-SDP"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!E;"!<(B5S
M7"(@<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VXN(@H*(SH@;&EB+TAO
M<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-@IM<V=I9"`B4F5Q=6ER960@1FEE
M;&0B"FUS9W-T<B`B0V%M<&\@;F5C97-A<FEO(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,S.0HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P(&QI8B](;W)D92]&;W)M+U)E;F1E
M<F5R+G!H<#HS,C$*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")2
M97-E="(*;7-G<W1R("),:6UP:6%R(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(DQI
M;7!I87(@8V]N=')A<V7Q82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(DQI
M;7!I87(@8V]N=')A<V7Q82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*
M;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")297-T875R87(@
M^FQT:6UA(&-O;G-U;'1A(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(Y(&%D
M;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G
M:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT861O<R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4F5G<F5S
M87(@82!O<&-I;VYE<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")2965S
M8W)I8FER(&-O;G1R87-E\6$@;G5E=F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DW"FUS9VED(")2975N:6]N(@IM
M<V=S='(@(E)E=6YI\VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(E)E<W1A=7)A<B!C;VYF:6=U<F%C:?-N(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N97,@9&4@961I
M8VGS;B!D92!T97AT;R!E;G)I<75E8VED;R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")#<FEB87,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*;7-G:60@(E)I9VAT(@IM<V=S='(@(D1E<F5C:&$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S$P,PIM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@
M(D-A8F5C97)A(&1E<F5C:&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y
M.0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E9A;&]R97,@9&4@;&$@
M9&5R96-H82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E!R;W!I961A9&5S(&1E(%]F:6QA+BXN(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T
M<B`B1G5N8VGS;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4G5M86[M
M82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C8*
M;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B1VER87(@,3@P(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T
M871E($QE9G0B"FUS9W-T<B`B1VER87(@82!L82!I>G%U:65R9&$B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED(")2
M;W1A=&4@4FEG:'0B"FUS9W-T<B`B1VER87(@82!L82!D97)E8VAA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE9&%D97,@
M9&4@9FEL82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!I961A9&5S(&1E(&9I;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B
M1FEL87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B4F%Y87,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS(@IM<V=S='(@(D%P87)E8V5RX6X@<F%Y87,@96YT<F4@
M=&]D87,@;&%S(&9I;&%S('D@8V]L=6UN87,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R(")!
M<&%R96-E<N%N(')A>6%S('/S;&\@96YT<F4@;&%S(&-O;'5M;F%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B07!A<F5C97+A;B!R87EA<R!S\VQO(&5N=')E(&QA<R!F:6QA
M<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G
M<W1R(")%:F5C=71A<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3D*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R(")&961E<F%C:?-N(%)U<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P"FUS9VED(")2=V%N9&$B"FUS
M9W-T<B`B4G5A;F1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR
M.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G
M<W1R(")&:7)M82!C<FEP=&]G<N%F:6-A(%,O34E-12(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4B"FUS9W-T<B`B365N<V%J92!C:69R861O(&5N(%,O34E-12(*
M"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYO(&5S
M=.$@9&ES<&]N:6)L92!L82!A=71E;G1I9FEC86-I\VX@4T%33"XB"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-
M97-S86=I;F<B"FUS9W-T<B`B365N<RX@4TU3(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B26YTZ7)P<BX@
M4U%,(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G:60@(E-13"!S
M=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4V5N=&5N8VEA
M(%-13"!P87)A(&-O;G-U;'1A<R!D92!V86QO<F5S(@H*(SH@8V]N9FEG+RYB
M86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B
M4U-((@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(LE8251/(@H*(SH@
M;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(DEN
M=.ER<'(N(%-?44PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")386(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W"FUS9VED
M(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%N=&$@2&5L96YA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q"FUS9VED
M(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I;G0@2VET=',@
M>2!.979I<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S.0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%N=&$@
M3'5C[6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@Y"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM
M<V=S='(@(E-A:6YT(%!I97)R92!Y($UI<75E;&]N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-`IM<V=I9"`B4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%N(%9I
M8V5N=&4@>2!'<F%N861I;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I
M(@IM<V=S='(@(DUI<VUO(&9R86UE("A?<V5L9BDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q"FUS9VED(")386UO
M82(*;7-G<W1R(")386UO82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3(*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T
M<B`B4V%N($UA<FEN;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,38*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP
M92(*;7-G<W1R(")386YT;R!4;VWA<R!Y(%!R[6YC:7!E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED
M97(B"FUS9W-T<B`B4')O=F5E9&]R(&1E('-A=.EL:71E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,0IM<V=I9"`B
M4V%U9&D@07)A8FEA(@IM<V=S='(@(D%R86)I82!3875D:71A(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S
M='(@(D=U87)D87(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S
M='(@(D=U87)D87(@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R
M(")'=6%R9&%R("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM
M<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(D=U87)D87(@;W!C:6]N97,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38V"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(D=U87)D87(@;&$@8V]N9FEG=7)A8VGS;B!G96YE<F%D82!C;VUO('5N
M(&=U:?-N(%!(4"!E;B!E;"!D:7)E8W1O<FEO("(*(G1E;7!O<F%L(&1E('-U
M('-E<G9I9&]R+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(E-E(&AA(&=U87)D861O(&QA(&-O;F9I9W5R86-I\VX@9&4@)7,N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B1W5A<F1A<B!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E
M(&QA(&-O;F9I9W5R86-I\VX@96XZ(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(D)O<G)A<V-A<R!A:7-L861A<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R
M(")#:65N8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E
M87)C:"(*;7-G<W1R(")"=7-C87(B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@
M(DTN(&+Z<W%U961A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-34*;7-G
M:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")396QE8V-I;VYA<B!A<F-H:79O
M<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4*
M;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L96-C:6]N92!U;F$@
M9F5C:&$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I
M9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E-E;&5C8VEO;F4@
M96P@9W)U<&\@82!A\6%D:7(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4V5L
M96-C:6]N92!U;B!N=65V;R!P<F]P:65T87)I;R(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM
M<V=S='(@(E-E;&5C8VEO;F4@=6X@<V5R=FED;W(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A
M9&0B"FUS9W-T<B`B4V5L96-C:6]N92!E;"!U<W5A<FEO(&$@8?%A9&ER(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R(")396QE8V-I;VYA<B!T;V1O(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#,*;7-G:60@(E-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+B(*;7-G<W1R(")396QE8V-I;VYE('1O9&]S(&QO<R!C
M;VUP;VYE;G1E<R!D92!L82!F96-H82XB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T
M(@IM<V=S='(@(E-E;&5C8VEO;F%R('5N(&]B:F5T;R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N
M;VYE(@IM<V=S='(@(E-I;B!S96QE8V-I\VXB"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y
M;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O
M<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G
M<W1R("(B"B)396QE8V-I;VYE(&QO<R!C87+A8W1E<F5S('%U92!N96-E<VET
M92!D92!L87,@8V%S:6QL87,@9&4@86)A:F\N(%!U961E("(*(F-O<&EA<FQO
M<R!Y('!E9V%R;&]S(&1E;"#A<F5A(&1E('1E>'1O+B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&1E;&EM:71A9&]R(&1E
M(&9E8VAA<SHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N
M92!E;"!F;W)M871O(&1E(&9E8VAA<SHB"@HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B4V5L96-C:6]N92!L
M82!I9&5N=&ED860@<75E('%U:65R82!C86UB:6%R.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&1E;&EM:71A9&]R(&1E
M(&AO<F%S.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED
M(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE
M(&5L(&9O<FUA=&\@9&4@:&]R87,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M(@IM<V=S='(@(E-E;&5C8VEO;F4@9&]S(&-A;7!O<R!C;VEN8VED96YT97,N
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E-E;&5C8VEO;F4@
M<W4@8V]M8FEN86-I\VX@9&4@8V]L;W)E<RXB"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93HB"FUS9W-T<B`B4V5L96-C:6]N92!S=2!I9&EO;6$@<')E
M9F5R:61O.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X
M"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D5N=FEA<B!I
M;F9O<FUE(&1E('!R;V)L96UA<R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R(")%
M;G9I87(@4TU3(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")397!T:65M8G)E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B
M4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I82!Y($UO;G1E
M;F5G<F\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I
M9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@<V5R:64B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")$871O
M<R!D96P@<V5R=FED;W(@97)R\VYE;W,@;R!N;R!D:7-P;VYI8FQE<RXB"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB
M"FUS9W-T<B`B061M:6YI<W1R86-I\VX@9&4@<V5S:?-N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@
M240@97AP:7)E9"XB"FUS9W-T<B`B2&$@8V%D=6-A9&\@96P@240@9&4@<V5S
M:?-N+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS
M9W-T<B`B4V5S:6]N97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-`IM
M<V=I9"`B4V5T(@IM<V=S='(@(D5S=&%B;&5C97(B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+B(*;7-G<W1R("(B"B)%<W1A8FQE8V4@;W!C:6]N97,@<75E(&QE
M('!E<FUI=&5N(')E86IU<W1A<B!S=2!C;VYT<F%S9?%A('-I(&QL96=A<F$@
M82`B"B)O;'9I9&%R;&$N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B0V]N
M9FEG=7)A('-E<G9I9&]R97,@<F5M;W1O<R!A(&QO<R!Q=64@9&5S964@86-C
M961E<B!D97-D92!E;"!P;W)T86PN(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B1&5F:6YE
M(&QA<R!O<&-I;VYE<R!P<F5F97)I9&%S(&1E(&ED:6]M82P@>F]N82!H;W)A
M<FEA('D@9F5C:&%S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D1E9FEN92!L82!A<&QI8V%C
M:?-N(&1E(&EN:6-I;RP@;&$@8V]M8FEN86-I\VX@9&4@8V]L;W)E<RP@;&$@
M86-T=6%L:7IA8VGS;B`B"B)D92!PX6=I;F$@>2!O=')A<R!O<&-I;VYE<R!D
M92!V:7-U86QI>F%C:?-N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(D-O;F9I9W5R86-I\VXB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")(87D@9W5I
M;VYE<R!D92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*
M;7-G<W1R(")687)I87,@=6)I8V%C:6]N97,@9&ES<&]N:6)L97,@8V]N(&5L
M('!A<N%M971R;SH@(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,PIM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")3
M97EC:&5L;&5S(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")#;VUP<F%S(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U
M;6UA<GDB"FUS9W-T<B`B4F5S=6UE;B!C;W)T;R(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(K]$969I;FER
M(&-L879E<R!D92!A8V-E<V\@<&%R82!L82!M87EO<NUA(&1E(&QO<R!V[6YC
M=6QO<S\B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I
M9"`B4VAO=R(*;7-G<W1R("(F;F)S<#M-;W-T<F%R)FYB<W`[(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$U-`IM<V=I9"`B(@HB4VAO=R!D:69F97)E
M;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E
M;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")-=65S=')A(&QA
M<R!D:69E<F5N8VEA<R!E;G1R92!L82!N=65V82!C;VYF:6=U<F%C:?-N('D@
M;&$@86QM86-E;F%D82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG
M(&EN/R(*;7-G<W1R("*_36]S=')A<B!H;W)A(&1E(&QA(/IL=&EM82!S97-I
M\VX@86P@:6YI8VEA<C\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-0IM
M<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")-
M;W-T<F%R(&]P8VGS;B!D92!C;VYS97)V87(@96P@;W)I9VEN86PB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS
M9W-T<B`B36]S=')A<B!S96QE8W1O<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/R(*;7-G<W1R("*_36]S=')A<B!L82!B87)R82!D92!M96[Z(&1E
M(&]P97)A8VEO;F5S(&1E('1A8FQA/R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("*_36]S=')A<B!E;"!M96[Z
M("5S(&$@;&$@:7IQ=6EE<F1A/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")-=65S=')A
M(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@8V5L9&$@9&4@=&%B;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(DUU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E
M<R!D92!T86)L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUU97-T<F$@96P@9&GA;&]G
M;R!D92!P<F]P:65D861E<R!D92!F:6QA(&1E('1A8FQA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M(")-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@:6UA9V5N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L
M;V%D(@IM<V=S='(@(DUO<W1R87(@8V%R9V$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R(*;7-G
M<W1R(")!9W5A8V5R;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("),
M;'5V:6%S(&UA='5T:6YA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
M3&QU=FEA<R!V97-P97)T:6YA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I
M;FET>2(*;7-G<W1R(")!9W5A8V5R;W,@96X@;&$@=F5C:6YD860B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B
M4VAR:6YK(@IM<V=S='(@(E)E9'5C:7(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$P-3@*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,3(P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3$X,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R,C,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,C4R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E!R:6UE<F\@
M<F5D=7IC82!O('%U:71E(&1E(&5N;65D:6\@;&]S(&)L;W%U97,@8V5R8V%N
M;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$Q"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE
M;VYA(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@
M(E-I9VX@=7`B"FUS9W-T<B`B06QT82(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B1FER;6$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG
M;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;6\@9&4@9FER;6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`V"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P=7(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.#DV(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C0V(&QI8B](;W)D92]&;W)M+G!H<#HR.3$R(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3`U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8U
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"FUS9VED(")3:7IE(@IM<V=S='(@
M(E1A;6'Q;R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(D]M
M:71I<B!M86YT96YI;6EE;G1O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,`IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T
M<B`B17-L;W9A<75I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(D5S
M;&]V96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4V"FUS9VED(")3;F]W(@IM<V=S='(@(DYI979E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@
M4VAO=V5R(@IM<V=S='(@(D%G=6%C97)O(&1E(&YI979E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")!9W5A8V5R;R!D92!N:65V92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W
M(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B06=U86-E<F\@9&4@;FEE=F4@;6%T
M=71I;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B06=U86-E
M<F\@9&4@;FEE=F4@=F5S<&5R=&EN;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@U"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B17-P97-O<B!D
M92!L82!N:65V93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*;7-G
M:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(D5Q=6EV
M86QE;G1E(&1E(&QA(&YI979E(&5N(&%G=6$Z("(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R("))<VQA<R!386QO;?-N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-`IM<V=I9"`B
M4V]M86QI82(*;7-G<W1R(")3;VUA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(D-A;F-I
M;VYE<R`F(%!O96UA<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3`X"FUS
M9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")396QE8V-I\VX@
M9&5L('-E;G1I9&\@9&4@;&$@8VQA<VEF:6-A8VGS;B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X
M.0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,38V(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S
M='(@(E)E;6ET96YT92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-34*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R
M(")3=63A9G)I8V$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3DS
M"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B
M175R;W!A(&1E;"!S=7(@*$E33RTX.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q"FUS9VED(")3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R
M(")'96]R9VEA(&1E;"!3=7(@92!)<VQA<R!386YD=VEC:"!D96P@4W5R(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V9E
M<FEO('-U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M(@IM<V=S='(@(D5S<&%C:6%D;R!E;G1R92!C96QD87,@861Y86-E;G1E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U
M"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C
M96QL(@IM<V=S='(@(D5S<&%C:6%D;R!E;G1R92!E;"!C;VYT96YI9&\@>2!E
M;"!B;W)D92!D92!U;F$@8V5L9&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B4V5P87)A9&]R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"FUS
M9VED(")3<&%C:6YG(@IM<V=S='(@(D5S<&%C:6%D;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B17-P86-I861O('D@;6%R
M9V5N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#`*;7-G:60@(E-P86EN(@IM<V=S='(@(D5S<&'Q82(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G
M<W1R(")3<&%M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED
M(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")%<V-R:71U<F$@
M9&4@8V%R86-T97)E<R!E<W!E8VEA;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@
M8V5L;"(*;7-G<W1R(")$:79I9&ER(&-E;&1A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L
M:70@8V]L=6UN(@IM<V=S='(@(D1I=FED:7(@8V]L=6UN82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G
M:60@(E-P;&ET(')O=R(*;7-G<W1R(")$:79I9&ER(&9I;&$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")$
M97!O<G1E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#$@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")%<W3A
M;F1A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A
M<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-3@V(&QI8B](;W)D92]&;W)M+G!H<#HR-SDQ"FUS9VED(")3=&%R
M="!Y96%R(@IM<V=S='(@(D'Q;R!D92!I;FEC:6\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B
M"FUS9W-T<B`B17-T861O(&\@<')O=FEN8VEA(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R
M(")%<W1A9&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B
M4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92!A;&UA8V5N86UI
M96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED
M(")3=')E970@061D<F5S<R(*;7-G<W1R(")$:7)E8V-I\VX@9&4@;&$@8V%L
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(E1A8VAA9&$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B
M"FUS9W-T<B`B3&ES=&$@9&4@8V%D96YA<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<R(*;7-G<W1R(")%;&EM:6YA<B!D;VUI;FEO(&1E(&QA(&1I<F5C8VGS;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(D5S=&EL;R!;0U-3
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C(*;7-G:60@(E-U(@IM<V=S='(@(D1O;2(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@96P@
M<W5B9&ER96-T;W)I;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B07-U
M;G1O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,B!L:6(O2&]R9&4O1F]R
M;2]296YD97)E<BYP:'`Z,S$X"FUS9VED(")3=6)M:70B"FUS9W-T<B`B16YV
M:6%R(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB4V4@:&$@96YV:6%D;R!U
M;F$@<V]L:6-I='5D(&1E(&%L=&$@9&4@7"(E<UPB(&5N(&5L('-I<W1E;6$N
M($YO('!O9'+A("(*(FEN:6-I87(@<V5S:?-N(&AA<W1A('%U92!S92!H87EA
M(&%P<F]B861O(&QA('-O;&EC:71U9"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS
M9W-T<B`B4W5B[6YD:6-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-2!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*
M;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BR7AI=&\B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(E-E(&AA(&'Q861I
M9&\@8V]R<F5C=&%M96YT92!<(B5S7"(@86P@<VES=&5M82XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"B)392!H86X@96QI;6EN861O(&-O<G)E8W1A;65N
M=&4@;&]S(&1A=&]S(&1E;"!U<W5A<FEO(%PB)7-<(B!D96P@<VES=&5M82XB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T
M960@7"(E<UPB+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M
M96YT92!<(B5S7"(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E(%PB)7-<(B!D96P@<VES=&5M82XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N
M9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B
M"B)392!H82!R97-T875R861O(&-O<G)E8W1A;65N=&4@;&$@8V]N9FEG=7)A
M8VGS;BX@4F5F<F5S<75E('!A<F$@=F5R(&QO<R`B"B)C86UB:6]S+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")392!H82!G=6%R9&%D;R!C;W)R96-T86UE
M;G1A(&QA(&-O<&EA(&1E(&QA(&-O;F9I9W5R86-I\VXN(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(E-E(&AA(&=U87)D861O(&-O<G)E8W1A;65N=&4@;&$@
M8V]P:6$@)7,@9&4@;&$@8V]N9FEG=7)A8VGS;BXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(E-E(&AA(&%C='5A;&EZ861O(&-O<G)E
M8W1A;65N=&4@7"(E<UPB(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(E-E(&AA(&5S8W)I
M=&\@8V]R<F5C=&%M96YT92`G)7,G(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-`IM<V=I9"`B4W5D86XB"FUS9W-T
M<B`B4W5DX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E)E<W5M
M96XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2
M:7-E(@IM<V=S='(@(D%M86YE8V5R(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(D%T87)D96-E<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED
M(")3=6YN>2(*;7-G<W1R(")3;VQE861O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")!;6%N
M96-E<B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B
M06UA;F5C97(O071A<F1E8V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(D%M86YE8V5R
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED
M(")3=6YS970B"FUS9W-T<B`B071A<F1E8V5R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B
M071A<F1E8V5R.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")3=7!E
M<NUN9&EC92(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,X
M,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")3;W!O<G1E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-0IM<V=I9"`B
M4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(D%P96QL
M:61O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P.0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M(")3=F%L8F%R9"!Y($IA;B!-87EE;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R(")3=V%Z:6QA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#4*;7-G:60@(E-W961E;B(*;7-G<W1R
M(")3=65C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4W5I>F$B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R(")296=I<W1R;R!D92!S:6YC<F]N:7IA
M8VGS;B!E;&EM:6YA9&\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!L:6(O
M2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R
M(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")%<G)O<B!D92!S:6YT87AI<R!E
M;B!L;W,@=.ER;6EN;W,@9&4@8OIS<75E9&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X"FUS9VED(")3>7)I86X@
M07)A8B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@P7)A8F4@9&4@4VER
M:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")#:'5B87-C;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T
M;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")";W)R87-C;W-O('D@=F5N=&]S;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS
M9VED(")4+5-T;W)M<R(*;7-G<W1R(")";W)R87-C87,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R
M;7,@16%R;'DB"FUS9W-T<B`B0F]R<F%S8V%S(&UA='5T:6YA<R(*"B,Z(&QI
M8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G
M<W1R(")!<F-H:79O(%135B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`B4')O<&EE9&%D97,@9&4@=&%B;&$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T
M(@IM<V=S='(@(E1A8FQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R(")0<F]P:65D861E<R!D92!T86)L82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T
M"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=^%N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN82(*;7-G<W1R(")486EWX6XL(%!R;W9I;F-I82!D92!#:&EN
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,C4*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%Y:6MI<W3A;B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S4*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B5&%N>F%N:6$L(%)E</IB;&EC82!5;FED82!D92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E
M=#HB"FUS9W-T<B`B1&5S=&EN;SHB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDS,B!C;VYF:6<O+F)A:R]H;V]K<RYP:'`N9&ES=#HQ,#0Y"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS
M9W-T<B`B5&%R96%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E
M('1E;.EF;VYO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3<*;7-G:60@
M(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&1U
M<F%N=&4@;&$@^FQT:6UA(&AO<F$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")496UP97)A='5R
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@
M(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R871U<F$Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<R(*;7-G<W1R(")496UP97)A='5R83QB<B`O/B@E<TWA>"5S+R5S3>UN)7,I
M("9D96<[)7,B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(").;R!S92!E;F-O;G1R\R!L82!P;&%N=&EL;&$@7"(E<UPB+B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VGS;B!D92!P;&%N
M=&EL;&%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,S,C<*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X=&\B"@HC
M.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@
M3VYL>2(*;7-G<W1R(")3\VQO('1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R(")!;&EN96%C:?-N(&1E('1E>'1O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X
M='1O<"(*;7-G<W1R(")";W)D92!S=7!E<FEO<B!D96P@=&5X=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R(")*=64B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I
M<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")486EL86YD
MZ7,@*%1)4RTV,C`I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R-`IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&%I
M;&%N9&EA(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@V-`IM<V=I9"`B5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F\@97-T
MX2!D:7-P;VYI8FQE(&QA(&5X=&5N<VGS;B!&5%`N(@H*(SH@;&EB+TAO<F1E
M+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N(@IM<V=S='(@(D5L('-I<W1E;6$@:&ES=/-R:6-O(&5S=.$@
M9&5S:&%B:6QI=&%D;RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(D5L
M(&UO=&]R(&1E(&EN=&5G<F%C:?-N($AO<F1E+TMO;&%B(&YO('-O<&]R=&$@
M7"(E<UPB(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@
M(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S
M='(@(DYO('-E('!U961E(&EN:6-I87(@96P@<F5G:7-T<F\@9&4@24U34"XB
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB
M"FUS9W-T<B`B3F\@<V4@:&$@8V%R9V%D;R!C;W)R96-T86UE;G1E(&QA(&-L
M87-E($UA:6YT96YA;F-E.CHB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L
M;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B4V4@:&$@8V5R<F%D;R!L82!V96YT
M86YA(&1E(&]P8VEO;F5S+B!386QI96YD;RXB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,"!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R,R!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(U,@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N
M9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U
M("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)3:2!D
M97-E82!U=&EL:7IA<B!P97)M:7-O<RP@96P@861M:6YI<W1R861O<B!T:65N
M92!Q=64@8V]N9FEG=7)A<B!U;B!S;W!O<G1E("(*(F1E('!E<FUI<V]S('!E
M<FUA;F5N=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB
M"FUS9W-T<B`B4_-L;R!E;"!B;W)D92!I;F9E<FEO<B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B
M(@HB16P@240@9&5L(&-O;G1A8W1O(&YO('-E(&5S<&5C:69I8_,L('-E(&1E
M:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC;VYT<O,@96X@(@HB;&$@8F%S92!D
M92!D871O<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")392!H82!A\6%D:61O
M(&-O<G)E8W1A;65N=&4@96P@8V]N=&%C=&\@82!S=7,@9&ER96-C:6]N97,N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB4&%R
M82!C;VUP<F]B87(@96P@;65N<V%J92!F:7)M861O(&AA8V4@9F%L=&$@96P@
M8FQO<75E(&1E(&9I<FUA('-E<&%R861O+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M(@HB16P@240@9&4@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N(&YO('-E(&5S
M<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@;F\@(@HB<V4@96YC;VYT
M<O,@96X@;&$@8F%S92!D92!D871O<RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DYO('-E(&5S<&5C:69I
M8_,@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("),87,@
M8V%R86-T97+M<W1I8V%S(&1E(&-I9G)A9&\@;F5C97-I=&%N('5N82!C;VYE
M>&GS;B!W96(@<V5G=7)A+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3@V(&QI8B](
M;W)D92YP:'`Z-3(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B16P@87)C
M:&EV;R`E<R!T96YD<NUA('%U92!C;VYT96YE<B!U;F$@;W!C:?-N("5S+B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3<Y(&QI8B](;W)D92YP:'`Z-3$X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O
M;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(D5L(&%R8VAI=F\@)7,@=&5N9'+M
M82!Q=64@8V]N=&5N97(@86QG=6YA<R!O<&-I;VYE<R`E<RXB"@HC.B!L:6(O
M2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B16P@87)C:&EV;R!N;R!C;VYT:65N92!D871O
M<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM
M<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B02!C;VYT:6YU86-I
M\VX@=&EE;F4@;&%S(&-A8F5C97)A<R!D92!E<W1E(&UE;G-A:F4@;65S<V%G
M92]R9F,X,C(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L
M92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R
M8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R
M(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I
M<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*
M(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)392!S86)E('%U92!E;"!M;V1O
M(&1E('!A;G1A;&QA(&-O;7!L971A(&1A('!R;V)L96UA<R!C;VX@26YT97)N
M970@17AP;&]R97(@(@HB9&5B:61O(&$@9F%L;&]S(&1E;"!N879E9V%D;W(@
M<75E(&YO(&AE;6]S('!O9&ED;R!S;W-L87EA<BX@4'5E9&4@<W5F<FER("(*
M(G9I<W5A;&EZ86-I\VX@9&4@8F%S=7)A+"!PZ7)D:61A(&1E(&9U;F-I;VYE
M<R!D96P@961I=&]R('DO;R!C=65L9W5E<R`B"B)A;&5A=&]R:6]S(&1E;"!N
M879E9V%D;W(N(%-I('-U('-I<W1E;6$@;W!E<F%T:79O(&5S(%=I;F1O=W,@
M.7@L(&5S(&UU>2`B"B)P<F]B86)L92!Q=64@<W5F<F$@=6X@9F%L;&\@9&4@
M<')O=&5C8VGS;B!G96YE<F%L('D@=&5N9V$@<75E(')E:6YI8VEA<B!E;"`B
M"B)E<75I<&\N7%QN7%QN66$@97-TX2!A=FES861O+B!0=6QS92!!8V5P=&%R
M('-I(&'Z;B!D97-E82!P<F]B87(@96P@961I=&]R(&5N("(*(FUO9&\@9&4@
M<&%N=&%L;&$@8V]M<&QE=&$N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!L82!I
M9&5N=&ED860@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(E/S;&\@96P@8F]R9&4@:7IQ=6EE<F1O(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB2&%Y('%U92!I
M;F1I8V%R;&4@82!L82!C;&%S92!#<GEP=%]P9W`Z.B!L82!U8FEC86-I\VX@
M9&4@;&]S(&)I;F%R:6]S($=N=5!'+B(*"B,Z(&QI8B](;W)D92]-24U%+TU$
M3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E
M;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T
M<B`B(@HB4V4@:&$@;6]S=')A9&\@96P@;65N<V%J92!E;G9I861O(&5L("5S
M(&$@)7,@8V]N(&5L(&%S=6YT;R!<(B5S7"(N7&XB"B+)<W1O(&YO(&=A<F%N
M=&EZ82!Q=64@96P@;65N<V%J92!H87EA('-I9&\@;&5I9&\@;R!C;VUP<F5N
M9&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M(@IM<V=S='(@(DYO;6)R92!U=&EL:7IA9&\@86P@=FEN8W5L87(@82!L82!P
MX6=I;F$@9&4@8V]M<&]S:6-I\VXB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W
M-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC
M+B(*;7-G<W1R(")%;"!N^FUE<F\@9&4@8V%M<&]S('1I96YE('%U92!S97(@
M=6X@;OIM97)O+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S
M,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&%C92!F
M86QT82!E;"!M\V1U;&\@;W!E;G-S;"!P87)A(&QA(&-L87-E($AO<F1E7T-R
M>7!T7W-M:6UE.CHN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(DYO('-E
M('!U961E(&=U87)D87(@;&$@<')E9F5R96YC:6$@7"(E<UPB('!O<G%U92!S
M=7,@9&%T;W,@<V]B<F5P87-A;B!E;"`B"B)T86UA\6\@;>%X:6UO('!E<FUI
M=&ED;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(DYO('-E(&5N
M8V]N='+S(&5N(&5L('-I<W1E;6$@96P@<')O9W)A;6$@<&%R82!V97(@97-T
M92!T:7!O(&1E(&1A=&]S("@E<RDN(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT
M.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B16P@8V%RX6-T97(@9&4@8VET82!D
M96)E('-E<B!S97(@<_-L;R!U;F\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B4_-L;R!L;W,@;&%D;W,@
M:7IQ=6EE<F1O('D@9&5R96-H;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R(")3\VQO(&5L(&QA9&\@9&5R96-H;R(*
M"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D5L('-E
M<&%R861O<B!D96)E('-E<B!S\VQO('5N;RXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")392!H82!E
M;&EM:6YA9&\@96P@<V5R=FED;W(@7"(E<UPB+B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")392!H82!G
M=6%R9&%D;R!E;"!S97)V:61O<B!<(B5S7"(N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B4V4@:&$@96QI
M;6EN861O(&QA('-O;&EC:71U9"!D92!A;'1A(&1E("5S+B(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(DQA(&9I;&$@97-P96-I9FEC861A("@E9"D@;F\@97AI
M<W1E+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B16P@87)C:&EV;R!T96UP;W)A;"!<(B5S7"(@;F\@97AI
M<W1E+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`R"FUS9VED(")4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN(@IM<V=S='(@(D5L('1E>'1O('%U92!H82!I;G1R;V1U8VED
M;R!N;R!C;VEN8VED92!C;VX@96P@9&4@;&$@<&%N=&%L;&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM
M<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B
M4_-L;R!L;W,@;&%D;W,@<W5P97)I;W(@92!I;F9E<FEO<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G
M:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E/S;&\@96P@;&%D;R!S
M=7!E<FEO<B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H
M92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S
M=&5P+B(*;7-G<W1R(")392!P97)D:65R;VX@;&]S(&1A=&]S(&-A<F=A9&]S
M(&1E<V1E(&5L('!A<V\@86YT97)I;W(N(@H*(SH@;&EB+TAO<F1E+T1A=&$O
M8W-V+G!H<#HR-C(@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@
M(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T
M<B`B3F\@<V4@<'5D;R!G=6%R9&%R(&5L(&%R8VAI=F\@8V%R9V%D;RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L
M;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYO(&5S=.$@9&ES<&]N
M:6)L92!E;"!B;&]Q=64@9&4@=V5A=&AE<BYC;VTN(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC
M;VYT<O,@96P@9&ER96-T;W)I;R!D92!496UA<R!<(B5S7"(N(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3F\@<V4@9&ES<&]N92!D92!O
M<&-I;VYE<RXB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S4P
M"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92XB"FUS9W-T<B`B3F\@:&%Y('!A<G1E<R!Q=64@<V4@<'5E
M9&%N(&UO<W1R87(@96X@;.UN96$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@
M)7,N(@IM<V=S='(@(B(*(D5N(&5S=&4@8V%M<&\@:&%Y(&1E;6%S:6%D;W,@
M8V%R86-T97)E<RX@2&$@:6YT<F]D=6-I9&\@)7,@8V%R86-T97)E<R!Y("(*
M(G1I96YE('%U92!I;G1R;V1U8VER(&UE;F]S(&1E("5S+B(*"B,Z('-I9VYU
M<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S
M>7-T96TZ("5S(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@
M8?%A9&ER(&$@7"(E<UPB(&%L('-I<W1E;6$Z("5S(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B(@HB4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A
M;"!B;W)R87(@;&]S(&1A=&]S(&1E;"!U<W5A<FEO(%PB)7-<(B!D96P@<VES
M=&5M83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@<')O8FQE
M;6$@86P@96QI;6EN87(@82!<(B5S7"(@9&5L('-I<W1E;6$Z("(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B4V4@
M<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A8W1U86QI>F%R(%PB)7-<(CH@)7,B
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B4V4@<')O9'5J;R!U
M;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\Z($YO('-E(&-A
M<F?S("5S+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB
M4V4@<')O9'5J;R!U;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI
M=F\N($5L("5S(&5R82!MX7,@9W)A;F1E('%U92!E;"`B"B)T86UA\6\@;>%X
M:6UO('!E<FUI=&ED;R`H)60@8GET97,I+B(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB4V4@<')O9'5J
M;R!U;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N(%/S;&\@
M<V4@8V%R9_,@<&%R8VEA;&UE;G1E("(*(F5L("5S+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R
M(")392!P<F]D=6IO('5N(&5R<F]R(&%L(&UO<W1R87(@97-T82!P87)T92!D
M96P@;65N<V%J92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,SD@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+B(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R<F]R(&%L(&EM<&]R=&%R
M(&QO<R!D871O<R!D96P@8V]N=&%C=&\N(@H*(SH@;&EB+TAO<F1E+T1A=&$O
M:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@
M97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S(&E#86QE;F1A<BXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB
M4V4@<')O9'5J;R!U;B!E<G)O<B!E;B!E;"!F;W)M=6QA<FEO(&1E(&-O;F9I
M9W5R86-I\VXN(%!U961E('%U92!H87EA("(*(F]L=FED861O(')E;&QE;F%R
M('5N(&-A;7!O(&YE8V5S87)I;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB4V4@
M<')O9'5J;R!U;B!E<G)O<B!A;"!E:F5C=71A<B!L82!F=6YC:?-N(&5S<&5C
M:69I8V%D82!D92!L82!L:6)R971A(&1E("(*(F1I<F5C8VEO;F5S+B!6=65L
M=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&%C='5A;&EZ87(@;&]S(&1E=&%L;&5S(&1E;"!C;VYT86-T;RX@5G5E
M;'9A(&$@<')O8F%R("(*(FWA<R!A9&5L86YT92XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L
M:7IA<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN(%9U96QV82!A('!R;V)A
M<B`B"B)MX7,@861E;&%N=&4N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B17-T92!S97)V
M:61O<B!)34%0(&YO('-O<&]R=&$@;&%S(&-A<G!E=&%S(&-O;7!A<G1I9&%S
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(*;7-G<W1R("+)<W1E(&YO('!A<F5C92!S97(@=6X@87)C:&EV;R!R
M87(@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+B(*;7-G<W1R("+)<W1E(&YO('!A<F5C92!S97(@=6X@87)C
M:&EV;R!Z:7`@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3(W
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`BR7-T92!N;R!P87)E8V4@<V5R('5N(&[Z;65R
M;R!D92!T87)J971A(';A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@HB17-T92!C;VYT<F]L861O<B!P97)M:71E
M(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!#;&EC
M:V%T96QL("(*(BAH='1P.B\O8VQI8VMA=&5L;"YC;VTI+"!M961I86YT92!L
M82!!4$D@2%144"(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%<W1E(&-O
M;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S(&$@=')A=NES(&1E
M(&QA('!A<V%R96QA(%=)3B`H:'1T<#HO+R(*(G=I;G!L8RYC;VTI+"!M961I
M86YT92!L82!!4$D@2%144"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R
M(&UE;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA('-M<S)E;6%I;"`B
M"B(H:'1T<#HO+W-M<S)E;6%I;"YC;VTI+"!M961I86YT92!L82!!4$D@2%14
M4"(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(D5S=&4@8V]N=')O;&%D;W(@
M<&5R;6ET92!E;G9I87(@;65N<V%J97,@=FEA(%--5%`@82!T<F%VZ7,@9&4@
M;&$@<&%S87)E;&$@9&4@(@HB5F]D869O;F4@9&4@271A;&EA+"!S\VQO(&$@
M;OIM97)O<R!6;V1A9F]N92X@2&%C92!F86QT82!U;F$@8W5E;G1A(&1E(&-O
M<G)E;R`B"B)D92!6;V1A9F]N92!D92!)=&%L:6$@*&AT='`Z+R]W=W<N,3DP
M+FET*2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3<X(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#4W(&QI8B](;W)D92]&;W)M+G!H<#HQ,#@V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@R(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C4V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S`U(&QI8B](;W)D92]&;W)M+G!H<#HQ,SDX(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-34W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#,Y(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.34X(&QI8B](;W)D92]&;W)M+G!H<#HR,#`U"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#(Y(&QI8B](;W)D92]&;W)M+G!H<#HR,#<X(&QI
M8B](;W)D92]&;W)M+G!H<#HR,30Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HR-#`X(&QI8B](;W)D92]&;W)M+G!H
M<#HR-#4P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C,W(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#$P(&QI8B](;W)D92]&;W)M+G!H<#HS,3$Y"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,CDW(&QI8B](;W)D92]&;W)M+G!H<#HS.#`U(&QI
M8B](;W)D92]&;W)M+G!H<#HS.#$S"FUS9VED(")4:&ES(&9I96QD(&ES(')E
M<75I<F5D+B(*;7-G<W1R(")(86-E(&9A;'1A(&5S=&4@8V%M<&\N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B17-T92!C86UP;R!S
M\VQO('!U961E(&-O;G1E;F5R(&5N=&5R;W,N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(T,38*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D5S=&4@8V%M<&\@
M<_-L;R!P=65D92!C;VYT96YE<B!N^FUE<F]S('D@;&]S(&1O<R!P=6YT;W,N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D5S
M=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE<B!V86QO<F5S(&]C=&%L97,N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@=&EE;F4@<75E('-E
M<B!U;F$@;&ES=&$@9&4@96YT97)O<R!S97!A<F%D;W,@<&]R(&-O;6%S(&\@
M97-P86-I;W,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDX.0IM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")%
M<W1E(&-A;7!O('1I96YE('%U92!S97(@=6X@;OIM97)O(';A;&ED;RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q.`IM<V=I9"`B(@HB5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)%
M<W1E(&-A;7!O('1I96YE('%U92!C;VYT96YE<B!U;B!C\V1I9F\@9&4@8V]L
M;W(@96X@9F]R;6%T;R!21T(@2&5X861E8VEM86PL("(*(G!O<B!E:F5M<&QO
M("<C,3(S-&%F)RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38Q"FUS9VED
M(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S
M='(@(EEA('-E(&AA('!R;V-E<V%D;R!E<W1E(&9O<FUU;&%R:6\N(@H*(SH@
M=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B17-T;R!E<R`E<RXB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,B"FUS9W-T<B`B(@HBR7-T;R!E<R!U;B!O8FIE=&\@9&4@2V]L86(@1W)O
M=7!W87)E+B!087)A('9E<FQO(&YE8V5S:71A('5N(&-L:65N=&4@9&4@(@HB
M8V]R<F5O("!Q=64@96YT:65N9&$@96P@9F]R;6%T;R!+;VQA8B!'<F]U<'=A
M<F4N(%!A<F$@=F5R('5N82!L:7-T82!D92`B"B)D:6-H;W,@8VQI96YT97,@
M=FES:71E("5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BXB"FUS9W-T<B`B(@HB17-T92!M96YS86IE('-E(&5S8W)I8FGS(&-O;B!U
M;B!J=65G;R!D92!C87)A8W1E<F5S("@E<RD@9&ES=&EN=&\@86P@<W5Y;RXB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N
M=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D5S=&4@;OIM
M97)O(&1E8F4@<V5R('!O<B!L;R!M96YO<R!U;B!U;F\N(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B
M17-T92!S97)V:61O<B!N;R!P=65D92!D97-C;VUP<FEM:7(@87)C:&EV;W,@
M>FEP('D@9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM
M<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*
M;7-G<W1R(")%<W1E('-I<W1E;6$@86-T=6%L;65N=&4@97-TX2!D97-A8W1I
M=F%D;RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")%<W1E('9A
M;&]R('1I96YE('%U92!S97(@=6X@;OIM97)O+B(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B
M17-T82!V96YT86YA('/S;&\@<'5E9&4@86)R:7)S92!D97-D92!U;F$@=F5N
M=&%N82!D92!O<&-I;VYE<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E1R=65N
M;R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I
M9"`B5&EC:V5T<R(*;7-G<W1R("));F-I9&5N8VEA<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#(U('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B5&EM92(*;7-G<W1R(")(;W)A(@H*(SH@8V]N9FEG+RYB86LO
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM
M<V=S='(@(D,N('1I96UP;W,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*
M;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@:&]R87)I;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,Q"FUS9VED(")4:6UE('-E;&5C
M=&EO;B(*;7-G<W1R(")396QE8V-I\VX@9&4@:&]R82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,CD*;7-G:60@(E1I=&QE(@IM<V=S='(@(E3M='5L;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I
M=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B5.UT=6QO("AC;VYS96IO*3HB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B
M5&\B"FUS9W-T<B`B4&%R82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(E!A<F$@
M<V5L96-C:6]N87(@=F%R:6]S(&-A;7!O<RP@;6%N=&5N9V$@<'5L<V%D82!L
M82!T96-L82!#;VYT<F]L("A00RD@;R`B"B)#;VUA;F1O("A-86,I(&%L(&AA
M8V5R(&-L:6-K+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DAO>2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(
M5$U,(%-O=7)C92(*;7-G<W1R(")#;VYM=71A<B!O<FEG96X@2%1-3"(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,*
M;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8*;7-G:60@(E1O:V5L874B
M"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DUA\6%N82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,CD*
M;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV86QI9"!L;V=I
M;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@(D1E;6%S:6%D
M;W,@:6YT96YT;W,@9F%L;&ED;W,@96X@;&]S(/IL=&EM;W,@;6EN=71O<RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#$*;7-G:60@(E1O<"(*;7-G<W1R(")3=7!E<FEO<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B1G)A;64@<W5P97)I;W(@*%]T;W`I
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA
M=&EO;G,B"FUS9W-T<B`B5')A9'5C8VEO;F5S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,@IM<V=I9"`B5')I;FED
M860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!Y(%1O8F%G;R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(E9E<F1A9&5R;R!O(&9A;'-O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B36%R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R.`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4^FYE>B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$*
M;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)Q=>UA(@H*(SH@8V]N9FEG+RYB
M86LO;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM
M.2DB"FUS9W-T<B`B5'5R8V\@*$E33RTX.#4Y+3DI(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-PIM<V=I9"`B5'5R
M:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI<W3A;B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`*;7-G:60@(E1U
M<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("))<VQA<R!4=7)K<R!Y
M($-A:6-O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S,*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC
M.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I
M8V4Z("(*;7-G<W1R(")%<V-R:6)A('-U(&5L96-C:?-N.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X
M.B`B"FUS9W-T<B`BS6YD:6-E(%4N5BXZ("(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y
M"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP
M="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(E523"!D92!S=2!I
M;F9O<FUE(&1E(&5S=&%D;R!D92!E;G;M;R!D96P@9W5I\VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")5
M4DPZ(@IM<V=S='(@(E523#HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W"FUS9VED(")59V%N9&$B"FUS9W-T<B`B
M56=A;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S-@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")58W)A;FEA(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HT,C4*;7-G:60@(E5N86)L92!T;R!A8V-E
M<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26YC87!A>B!D92!A8V-E9&5R
M(&%L(&1I<F5C=&]R:6\@5D93+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*(DEN8V%P87H@
M9&4@8?%A9&ER(&EN9F]R;6%C:?-N(&1E('5S=6%R:6\@861I8VEO;F%L(&%L
M(')E86QI>F%R(&5L(&%L=&$N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!C
M86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!61E,@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,SDX(&QI8B]61E,O;75S<6PN<&AP
M.C0X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("));F-A<&%Z
M(&1E(&-A;6)I87(@;&]S('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&4R`E
M<R\E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-SDY"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DEN8V%P
M87H@9&4@8V%M8FEA<B!A("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@8V]M<')O8F%R(&5L
M('1A;6'Q;R!D92!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HW,#<@
M;&EB+U9&4R]S<6PN<&AP.C$P-#`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#<X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&-O;7!R;V)A
M<B!E;"!T86UA\6\@9&4@7"(E<R\E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R("));F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R
M=FED;W(@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX.#,*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("));F-A<&%Z(&1E
M(&-O;F5C=&%R(&-O;B!34TPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,S@@
M;&EB+U9&4R]F:6QE+G!H<#HR-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$T
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q.2!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HR,C<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G
M<W1R("));F-A<&%Z(&1E(&-O<&EA<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEN
M8V%P87H@9&4@8W)E87(@96P@9&ER96-T;W)I;R!61E,@7"(E<UPB+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,S8W(&QI8B]61E,O;75S<6PN<&AP.C(W,"!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR-S0*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26YC87!A>B!D92!C<F5A<B!E
M;"!D:7)E8W1O<FEO(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DEN
M8V%P87H@9&4@8W)E87(@96P@87)C:&EV;R!61E,N(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&-R
M96%R(&QA(&-A<G!E=&$@5D93(%PB)7-<(B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C<X"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE
M+B(*;7-G<W1R("));F-A<&%Z(&1E(&-R96%R('5N(&%R8VAI=F\@5D93('9A
M8^UO+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.2!L:6(O
M2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&1E
M8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B26YC87!A>B!D92!D97-C;VUP<FEM
M:7(@;&]S(&1A=&]S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,#,@;&EB+U9&
M4R]S;6(N<&AP.C(R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM
M<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@7"(E<UPB+"!E;"!D:7)E8W1O
M<FEO(&YO(&5S=.$@=F%C[6\N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B26YC87!A
M>B!D92!E;&EM:6YA<B!<(B5S7"(Z("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,S0T(&QI8B]61E,O;75S<6PN<&AP.C,R,R!L:6(O5D93+W-Q;"YP:'`Z
M-#`W"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R("5S+"!E
M;"!D:7)E8W1O<FEO(&YO(&5S=.$@=F%C[6\B"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS.#0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S@X"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,@
M9&4@9F]R;6$@<F5C=7)S:79A+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S4P
M(&QI8B]61E,O;75S<6PN<&AP.C,S-"!L:6(O5D93+VUU<W%L+G!H<#HS-#<*
M(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S4U(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,X,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,S(@;&EB+U9&4R]S<6PN<&AP.C0T
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R(&5L
M(&1I<F5C=&]R:6\@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&%R
M8VAI=F\@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,Q-B!L
M:6(O5D93+VUU<W%L+G!H<#HQ-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z
M(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93+W-Q;"YP:'`Z,CDQ(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C0Q.0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HT,C<*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S
M='(@(DEN8V%P87H@9&4@96QI;6EN87(@96P@87)C:&EV;R!61E,N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("));F-A
M<&%Z(&1E(&5L:6UI;F%R(&QA(&-A<G!E=&$@5D93(%PB)7-<(BXB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B26YC
M87!A>B!D92!E;&EM:6YA<B!E;"!61E,@9&4@9F]R;6$@<F5C=7)S:79A.B`E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#0W"FUS9VED(")5;F%B;&4@=&\@
M9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("));F-A<&%Z
M(&1E(&1E=&5R;6EN87(@96P@9&ER96-T;W)I;R!A8W1U86PN(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B26YC87!A>B!D
M92!E>'1R865R(&QO<R!D971A;&QE<R!D96P@8V5R=&EF:6-A9&\N(@H*(SH@
M;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B26YC87!A>B!D92!C87)G87(@;&$@
M9&5F:6YI8VGS;B!D92`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P."!L
M:6(O5D93+V9I;&4N<&AP.C(Q,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3@T"FUS9VED(")5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92XB"FUS9W-T<B`B26YC87!A>B!D92!T<F%S;&%D87(@
M96P@87)C:&EV;R!61E,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.CDX(&QI8B]6
M1E,O<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`V"B,Z(&QI8B]61E,O
M<VUB+G!H<#HV-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&%B<FER
M(&5L(&%R8VAI=F\@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C(Y,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O
M(%9&4R!P87)A(&5S8W)I8FER+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z.#,@
M;&EB+U9&4R]F:6QE+G!H<#HQ,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S8*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("));F-A
M<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DEN8V%P87H@9&4@86)R:7(@
M96P@87)C:&EV;R!C;VUP<FEM:61O+B(*"B,Z(&QI8B]61E,N<&AP.C@U-@IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B26YC87!A>B!D92!L965R('5N(&%R8VAI=F\@5D93
M("AH82!F86QL861O(&9I;&5S:7IE*"DI+B(*"B,Z(&QI8B]61E,N<&AP.C@X
M-PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B26YC87!A>B!D92!L965R('5N(&%R8VAI
M=F\@5D93("AH82!F86QL861O(&=E=$9I;&53:7IE*"DI+B(*"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE
M('1O(')E860@9FEL93H@(@IM<V=S='(@(DEN8V%P87H@9&4@;&5E<B!U;B!A
M<F-H:79O.B`B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8X.`IM<V=I9"`B56YA
M8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("))
M;F-A<&%Z(&1E(&QE97(@96P@9&ER96-T;W)I;R!V9G-R;V]T+B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`B26YC87!A>B!D92!R96YO;6)R87(@
M)7,@8V]M;R`E<SH@;&$@8V%R<&5T82!D97-T:6YO('EA(&5X:7-T92(*"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,R,PIM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("));F-A<&%Z(&1E(')E;F]M
M8G)A<B!E;"!D:7)E8W1O<FEO(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,S0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DEN8V%P87H@9&4@<F5N;VUB<F%R
M(&5L(&1I<F5C=&]R:6\@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M,S4Q(&QI8B]61E,O<VUB+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEN
M8V%P87H@9&4@<F5N;VUB<F%R(&5L(&%R8VAI=F\@5D93(%PB)7-<(B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z-C(Y(&QI8B]61E,O;75S<6PN<&AP.C(T,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R("));F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H
M:79O(%9&4R`E<R\E<RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB
M+U9&4R]M=7-Q;"YP:'`Z-#8T(&QI8B]61E,O<W%L+G!H<#HS,S@*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S$U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,S
M-PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B
M26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV;R!61E,N(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T
M;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("));F-A<&%Z(&1E(&5J96-U=&%R
M("=M:VES;V9S)RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$X,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y
M('5P9&%T92!F;W(@)7,B"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4@86-T:79A
M<B!L82!A8W1U86QI>F%C:?-N(&1E(&EN9F]R;6%C:?-N(&1E('1I96UP;R!D
M:7-P;VYI8FQE(&1E("4B"B)S(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L
M:6(O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@
M9&4@97-C<FEB:7(@96P@87)C:&EV;R!61E,@7"(E<UPB+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("));F-A<&%Z(&1E(&5S8W)I
M8FER('5N(&%R8VAI=F\@5D93("AH82!F86QL861O(&-O<'DH*2DN(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HR.30@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30V
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DEN8V%P87H@9&4@97-C<FEB
M:7(@;&]S(&1A=&]S(&1E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O5D93+G!H
M<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B26YC87!A>B!D92!E<V-R:6)I
M<B!U;B!A<F-H:79O(%9&4RP@<V4@<W5P97)A<N$@;&$@<75O=&$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I
M9"`B56YD97)L:6YE(@IM<V=S='(@(E-U8G)A>6%D82(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R
M(")$97-H86-E<B!C86UB:6]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A
M8W1I;VXB"FUS9W-T<B`B1&5S:&%C92!L82#Z;'1I;6$@86-C:?-N(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,2!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")2
M97-P=65S=&$@:6YE<W!E<F%D82!D96P@<V5R=FED;W(@96X@;&$@8V]N97AI
M\VXZ("(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.0HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")297-P=65S=&$@:6YE<W!E<F%D
M82!D96P@<V5R=FED;W(@83H@(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B4VEN
M(&-A=&5G;W+M82(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M
M."DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-PIM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B16UI
M<F%T;W,@P7)A8F5S(%5N:61O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S.`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`B26YG;&%T97)R82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#`*;7-G:60@(E5N:71E9"!3=&%T97,B
M"FUS9W-T<B`B17-T861O<R!5;FED;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y"FUS9VED(")5;FET960@4W1A
M=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B17-T861O<R!5
M;FED;W,@;65N;W,@;&%S(&ES;&%S('!E<FEFZ7)I8V%S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-C(*;7-G:60@(E5N:71S(@IM<V=S='(@(E5N:61A9&5S(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#(Y"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0S,`IM<V=I
M9"`B56YK;F]W;B(*;7-G<W1R(")$97-C;VYO8VED;R(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(D%P:6US9VED(&1E
M<V-O;F]C:61O("A)1"!D92!M96YS86IE(&1E(&QA($%022DN(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B0VQI
M;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@9&5L(&-L:65N=&4I
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(E-E(&AA(&1E
M9FEN:61O('5N82!U8FEC86-I\VX@9&5S8V]N;V-I9&$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@
M=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5S=6%R:6\@;R!C;VYT
M<F%S9?%A(&1E<V-O;F]C:61O<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(D5L:6UI;F%R(';M;F-U;&\@
M9&5L(&5L96UE;G1O(&%C='5A;"(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP
M:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-I;B!N;VUB<F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS
M9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U
M="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*
M(DQO<R!G=6EO;F5S('-I;B!P<FEV:6QE9VEO<R!N;R!P=65D96X@86-C961E
M<B!D92!F;W)M82!P<F]G<F%MX71I8V$@82!#;W)T87(O(@HB0V]P:6%R+U!E
M9V%R('!O<B!R87IO;F5S(&1E('-E9W5R:61A9"X@4'5L<V4@06-E<'1A<B!P
M87)A('9E<B!E;B!M;WII;&QA+F]R9R`B"B)U;F$@;F]T82!TZ6-N:6-A('%U
M92!L92!M=65S=')E(&/S;6\@<&5R;6ET:7(@<75E('5N(&=U:?-N(&%C8V5D
M82!A;"`B"B)P;W)T87!A<&5L97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L
M;W(B"FUS9W-T<B`B06YU;&%R(&-O;&]R(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C<*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P
M<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")%>'1E;G-I\VX@;F\@<V]P;W)T
M861A(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R
M(")!8W1U86QI>F%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T
M<B`B06-T=6%L:7IA<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D%C='5A
M;&EZ87(@=7-U87)I;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G
M<W1R(")392!H82!A8W1U86QI>F%D;R!<(B5S7"(N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!E;"!G=6GS;B!D92!A8W1U
M86QI>F%C:?-N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L
M;V%D(@IM<V=S='(@(D-A<F=A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#4*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"B)392!H86X@8V%R9V%D
M;R!E;B!E;"!S97)V:61O<B!T;V1O<R!L;W,@87)C:&EV;W,@9&4@8V]N9FEG
M=7)A8VGS;B!D92`B"B)A<&QI8V%C:6]N97,N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")!;&9A8F5T;R!L871I;F\@
M96X@;6%Y^G-C+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B3OIM97)O<R!R;VUA;F]S(&5N(&UA>?IS8RXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q"FUS
M9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B57-A<B!A8W1U86PZ("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I
M9"`B57-E(%-33"(*;7-G<W1R(")5<V%R(%-33"(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B4V4@
M=7-A('-I(&5L('5S=6%R:6\O8V]N=')A<V7Q82!S;VX@9&ES=&EN=&]S(&5N
M(&5L('-E<G9I9&]R($E-4U`N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")5<W5A<FEO(@H*
M(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S
M='(@(D5L('5S=6%R:6\@)7,@8V%R96-E(&1E(&%U=&]R:7IA8VGS;B!P87)A
M("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VGS;B!D92!U<W5A<FEO
M<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N97,@9&4@=7-U87)I;R(*"B,Z('-I
M9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(E)E9VES=')O(&1E('5S=6%R:6]S(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92XB"FUS9W-T<B`B17-T82!S961E('1I96YE(&1E<V%C=&EV861O
M(&5L(')E9VES=')O(&1E('5S=6%R:6]S+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS
M9W-T<B`B3F\@<V4@:&$@96YC;VYT<F%D;R!L82!I9&5N=&ED860B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HY."!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(E5S
M=6%R:6\B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES
M=',N(@IM<V=S='(@(EEA(&5X:7-T92!E;"!N;VUB<F4@9&4@=7-U87)I;R!<
M(B5S7"(N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`B57-U87)I;SHB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S
M='(@(E5S=6%R:6\Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5S
M=6%R:6]S(&5N(&5L('-I<W1E;6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,@IM<V=I9"`B57IB96MI<W1A;B(*
M;7-G<W1R(")5>F)E:VES=.%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@
M;&EB+U9&4R]F:6QE+G!H<#HR-C@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(DYO(&5X:7-T92!E;"!D:7)E8W1O<FEO
M(%9&4RXB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*
M;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%U<V5N8VEA(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD
M(&EN8VQU9&4Z("(*;7-G<W1R("),87,@=6)I8V%C:6]N97,@=N%L:61A<R!E
M;F-O;G1R861A<R!I;F-L=7EE;CH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E9A;&ED97HB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-2!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"FUS9VED(")686QU92!I
M;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")686QO<B!E;B!M:6YU=&]S
M(&$@<&%R=&ER(&1E(&%H;W)A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M-38@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM
M<V=S='(@(D5L('9A;&]R(&5X8V5D92!E;"!T86UA\6\@;>%X:6UO(&1E("5S
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0T(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C8V(&QI8B](;W)D92]&;W)M+G!H<#HR,S$V"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.3$P(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B5F%L;W)E<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3`Y(&QI8B](;W)D92]&;W)M+G!H<#HR,3@V
M"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L;W)E
M<R!A('-E;&5C8VEO;F%R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T.0IM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")6
M86YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM
M<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B;&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0U"FUS9VED(")6
M96YE>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*
M;7-G<W1R(")(82!F86QL861O(&QA(&-O;7!R;V)A8VGS;B`M(&5S=&4@;65N
M<V%J92!P=65D92!H86)E<G-E(&9O<GIA9&\N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R
M<VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM
M<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(D,N('9E<G-I;VYE<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D%L:6YE86-I
M\VX@=F5R=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@
M(DUA<F=E;B!V97)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")6
M97)T:6-A;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(DUU>2!A;'1A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I
M9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)
M4T-)22DB"FUS9W-T<B`B5FEE=&YA;6ET82`H5DE30TE)*2(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(")697(@)7,B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM
M<V=S='(@(E9E<B!U;F$@<.%G:6YA('=E8B!E>'1E<FYA(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W(&%S("5S(@IM<V=S='(@(E9E<B!C;VUO("5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B27-L87,@5NUR9V5N
M97,L($)R:73A;FEC87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0W"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3
M+B(*;7-G<W1R("))<VQA<R!6[7)G96YE<RP@52Y3+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I
M<VEB:6QI9&%D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E9I<VEB:6QI9&%D.B`B
M"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N
M92!D92!)=&%L:6$@;65D:6%N=&4@4TU44"(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*
M;7-G<W1R(")!5DE33R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("*AH:%!1%9%4E1%3D-)02$A
M(2!%3$E-24Y%($U!3E5!3$U%3E1%($5,($=52=-.($1%("5S+B(*"B,Z(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%14
M4"(*;7-G<W1R(")724X@<&]R($A45%`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P"FUS9VED(")786QL:7,@86YD
M($9U='5N82(*;7-G<W1R(")786QL:7,@>2!&=71U;F$B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.34@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,C<*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B061V97)T96YC
M:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4X"FUS9VED(")792(*;7-G<W1R(")-:64B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS
M9W-T<B`B4')E=FES:?-N(&1E;"!T:65M<&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB"FUS9W-T<B`B1&%T;W,@9&5L('1I96UP;R!S=6UI;FES=')A9&]S
M('!O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H
M97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF
M:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E
M(@IM<V=S='(@(E-E9&4@5V5B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E-E;6%N86QM96YT92(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC
M;VUE(@IM<V=S='(@(D)I96YV96YI9&\B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C4W('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")":65N
M=F5N:61O<R!A("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)I96YV96YI9&\L("5S(@H*
M(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3V5S=&4@*$E33RTX.#4Y+3$I(@H*
M(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(D]E<W1E("A)4T\M.#@U.2TQ-2DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M.`IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B4^%H87)A($]C8VED
M96YT86PB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BOU%UZ2!A<&QI8V%C:?-N
M(&1E8F5R[6$@;6]S=')A<B`E<R!A;"!I;FEC:6%R(&QA('-E<VGS;C\B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`BOT-UX6P@97,@
M96P@8V%RX6-T97(@9&5L:6UI=&%D;W(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`BOT-UX6P@97,@96P@8V%RX6-T97(@9&4@8VET861O
M/R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U
M"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B36%P82!D
M92!L;V-A;&EZ86-I\VX@9&4@075S=')A;&EA(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B477I(&9A
M<V5S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(E!L=6=I;G,@:&%B:6QI=&%D;W,@9&5L(&5D:71O
M<B!D92!T97AT;R!E;G)I<75E8VED;RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*
M;7-G<W1R(")!;F-H=7)A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#<*
M;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R(")!;F-H=7)A(&5N
M('5N:61A9&5S($-34R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B06YC:'5R82!D96P@;65N^B`E<R!I>G%U:65R9&\@*&1I<W!O
M;FEB;&4@96X@;&$@<'+S>&EM82!S97-I\VXI.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O
M9B!T:&4@=&%B;&4B"FUS9W-T<B`B06YC:'5R82!D92!L82!T86)L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS
M9VED(")7:61T:"!U;FET(@IM<V=S='(@(E5N:61A9&5S(&1E(&%N8VAU<F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(D%N8VAU<F$Z(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S
M='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED
M(")7:6YD(@IM<V=S='(@(E9I96YT;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM<V=S
M='(@(E9I96YT;R!M871U=&EN82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#<*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5F5L;V-I
M9&%D(&1E;"!V:65N=&\@96X@;G5D;W,B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$V,PIM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5FEE;G1O.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*
M;7-G<W1R(")6:65N=&\Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E-A8FED=7+M82(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B
M"FUS9W-T<B`B1&5S96]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U
M"FUS9VED(")7;W)K(@IM<V=S='(@(D5M<&QE;R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B
M1&ER96-C:?-N(&1E;"!T<F%B86IO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
M5&5LZ69O;F\@9&5L('1R86)A:F\B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y
M,R!L:6(O1FEL92]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B3OIM97)O(&5R<O-N96\@9&4@8V%M<&]S
M(&5N(&QA(&SM;F5A("5D+B!392!E<W!E<F%B86X@)60@>2!H87D@)60N(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R(").^FUE<F\@97)R\VYE;R!D92!C86UP;W,N(%-E(&5S<&5R
M86)A;B`E9"!Y(&AA>2`E9"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")/9F9S970@)60@97)R\VYE;R!A
M;"!L965R('5N(&%R8VAI=F\@5D93+B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(DQI;6ET86-I;VYE<R!B
MX7-I8V%S(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@
M(E5S;R!D92!C;&%V92!E>'1E;F1I9&$@6#4P.78S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L
M=&5R;F%T:79E($YA;64B"FUS9W-T<B`B3F]M8G)E(&%L=&5R;F%T:79O(&1E
M(&%S=6YT;R!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS
M9W-T<B`B261E;G1I9FEC861O<B!D92!C;&%V92!D92!A<W5N=&\@6#4P.78S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U
M,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(D5X=&5N<VEO;F5S(%@U,#EV,R(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!
M02(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,30@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B
M65E962(*;7-G<W1R(")!04%!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B
MH4UA<&$@9&4@66%H;V\A(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(D%N=6%L;65N=&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R"FUS
M9VED(")996UE;B(*;7-G<W1R(")996UE;B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")3
M[2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B4^TL(&QO(&%C97!T
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B
M"B)%<W3A(&5N($U/1$\@5$585$\N(%5T:6QI8V4@96P@8F]T\VX@6SP^72!P
M87)A(')E9W)E<V%R(&%L(&UO9&\@5UE325=91RXB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@8FQO8VMS+B(*;7-G<W1R(").;R!D:7-P;VYE(&1E('!R:79I;&5G:6]S
M('!A<F$@8W)E87(@;>%S(&1E("5D(&)L;W%U97,N(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-#(T"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R(").;R!E<W3A(&%U=&5N=&EF:6-A9&\N(@H*(SH@;&EB+TAO<F1E
M+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(DYO
M('!U961E(&EN8VQU:7(@96P@8V%RX6-T97(@7")<7%PB(&5N(&5L(&YO;6)R
M92!C;VUP;&5T;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").;R!I;G1R;V1U:F\@
M=6YA(&1I<F5C8VGS;B!D92!C;W)R96\@=N%L:61A+B(*"B,Z(&QI8B](;W)D
M92]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B
M(@HB3F\@87-O8VGS(&YI;F=U;F\@9&4@;&]S(&-A;7!O<R!D96P@87)C:&EV
M;R!I;7!O<G1A9&\@82!L;W,@8V%M<&]S("(*(F-O<G)E<W!O;F1I96YT97,@
M9&4@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")(82!S86QI9&\@9&4@
M;&$@<V5S:?-N+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8Q"FUS9VED
M("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB
M5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@;OIM97)O(&1E('1E;.EF;VYO(&WS
M=FEL(';A;&ED;RP@<_-L;R!D[6=I=&]S(&-O;B!U;B`B"B(G*R<@;W!C:6]N
M86P@<&%R82!E;"!P<F5F:6IO(&1E(&QL86UA9&$@:6YT97)N86-I;VYA;"XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B5&EE;F4@<75E(&EN
M=')O9'5C:7(@=6X@=F%L;W(@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(E!A<F$@
M=7-A<B!!;'1A<R!T:65N92!Q=64@8V]N9FEG=7)A<B!U;B!M;W1O<B!D92!$
M871A5')E92XB"@HC.B!L:6(O2&]R9&4N<&AP.C0W,0IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E1I96YE('%U
M92!C;VYF:6=U<F%R('5N(&UO=&]R(%9&4RXB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(D1E8F4@9&5S8W)I8FER(&5L('!R;V)L96UA(&%N
M=&5S(&1E(&5N=FEA<B!E;"!I;F9O<FUE+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R
M(")4:65N92!Q=64@:6YT<F]D=6-I<B!L82!54DP@82!L82!Q=64@87!U;G1A
M(&5S=&4@=NUN8W5L;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(E1I96YE('%U92!S96QE8V-I;VYA<B!U;B!S97)V
M:61O<B!A(&5L:6UI;F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`B5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E
M;&EM:6YA<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(E1I
M96YE('%U92!E<W!E8VEF:6-A<B!U;B!U<W5A<FEO(&$@96QI;6EN87(N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!A9&0N(@IM<V=S='(@(E1I96YE('%U92!E<W!E8VEF:6-A<B!E;"!U
M<W5A<FEO(&$@8?%A9&ER+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*
M;7-G<W1R(")4:65N92!Q=64@97-P96-I9FEC87(@96P@=7-U87)I;R!A(&%C
M='5A;&EZ87(N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(E1I96YE('%U92!E<W!E8VEF:6-A<B!Q=>D@86-C:?-N
M('-E(&5J96-U=&%RX2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E
M9V]R>2!N86UE+B(*;7-G<W1R(")4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N
M=65V;R!N;VUB<F4@9&4@8V%T96=O<NUA+B(*"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R
M;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B5&EE;F4@
M<75E(&EN=')O9'5C:7(@=6X@;OIM97)O(&1E('1E;.EF;VYO(&ET86QI86YO
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B2&$@97AP:7)A9&\@<W4@<V5S:?-N("5S+B!6
M=65L=F$@82!I;FEC:6%R('-E<VGS;BXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(E-U(&1I<F5C8VGS;B!D92!C;W)R96\B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S
M<SHB"FUS9W-T<B`B1&ER96-C:?-N($1E.B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C8W(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C<W
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C@U(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM
M<V=S='(@(E-U(&EN9F]R;6%C:?-N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(DAA(&-A;6)I861O('-U
M(&1I<F5C8VGS;B!D92!);G1E<FYE="!D97-D92!E;"!C;VUI96YZ;R!D92!S
M=2!S97-I\VX@)7,N(%!O<B`B"B)R87IO;F5S(&1E('-E9W5R:61A9"!T:65N
M92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S97-I\VXN(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*
M;7-G<W1R(")3=2!N;VUB<F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S
M+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@
M8F%C:V5N9"XB"FUS9W-T<B`B(@HB4W4@;6]T;W(@9&4@875T96YT:69I8V%C
M:?-N(&YO('!E<FUI=&4@8?%A9&ER('5S=6%R:6]S+B!3:2!Q=6ES:65R82!U
M<V%R("(*(DAO<F1E('!A<F$@861M:6YI<W1R87(@8W5E;G1A<R!D92!U<W5A
M<FEO+"!T96YD<N$@<75E('5T:6QI>F%R('5N(&UO=&]R(&1E("(*(F%U=&5N
M=&EF:6-A8VGS;B!D:7-T:6YT;RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BXB"FUS9W-T<B`B(@HB4W4@;6]T;W(@9&4@875T96YT:69I8V%C
M:?-N(&YO('!E<FUI=&4@;&ES=&%R('5S=6%R:6]S+"!O('-E(&AA("(*(F1E
M<VAA8FEL:71A9&\@;&$@8V%R86-T97+M<W1I8V$@<&]R(&%L9_IN(&UO=&EV
M;RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@HB4&%R96-E('%U92!H82!C86UB:6%D;R!S=2!N879E
M9V%D;W(@9&5S9&4@96P@8V]M:65N>F\@9&4@<W4@<V5S:?-N("5S+B!0;W(@
M(@HB<F%Z;VYE<R!D92!S96=U<FED860@=&EE;F4@<75E('9O;'9E<B!A(&EN
M:6-I87(@;&$@<V5S:?-N+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4W
M"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N(@IM<V=S='(@(E-U(&YA=F5G861O<B!N;R!A9&UI=&4@97-T82!C
M87)A8W1E<NUS=&EC82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN
M="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(D5L(&YA=F5G861O<B!N;R!A
M9&UI=&4@97-T82!O<&-I\VX@9&4@:6UP<F5S:?-N+B!0<F5S:6]N92!#;VYT
M<F]L+T-O;6%N9&\@*R`B"B)0('!A<F$@:6UP<FEM:7(N(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R("):;VYA(&AO<F%R:6$@86-T=6%L.B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")392!H82!C86UB
M:6%D;R!S=2!I9&5N=&ED860@<&]R(&]M:7-I\VXN(@H*(SH@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ(@IM<V=S='(@(DED96YT:61A9"!P;W(@;VUI<VGS;CHB"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L
M;"!N86UE.B(*;7-G<W1R(").;VUB<F4@8V]M<&QE=&\Z(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B4V4@:&$@86=O=&%D;R!S=2!T:65M<&\@9&4@8V]N97AI
M\VXN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<R(*;7-G<W1R("),82!N=65V82!C;VYT<F%S9?%A('!A<F$@)7,@97,Z("5S
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B4V4@:&%N(&%C='5A;&EZ861O('-U
M<R!O<&-I;VYE<R!S\VQO('!O<B!L82!D=7)A8VGS;B!D92!L82!S97-I\VXN
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B4V4@:&%N(&%C
M='5A;&EZ861O('-U<R!O<&-I;VYE<RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="(*;7-G<W1R(")392!H82!R96%J=7-T861O('-U(&-O;G1R87-E\6$B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S
M='(@(B(*(E-E(&AA(')E86IU<W1A9&\@<W4@8V]N=')A<V7Q82P@8V]M<')U
M96)E(&5L(&-O<G)E;R!E(&EN:6-I92!S97-I\VX@8V]N('-U("(*(FYU979A
M(&-O;G1R87-E\6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<S,PIM<V=I
M9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B3&$@8V]N
M=')A<V7Q82!H82!E>'!I<F%D;RXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S
M='(@(E-E<G9I9&]R97,@<F5M;W1O<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-`IM<V=I9"`B
M675G;W-L879I82(*;7-G<W1R(")9=6=O<VQA=FEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER
M92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-38*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W"FUS9VED
M(")::6UB86)W92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*
M;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");3V-U;'1A<B!T
M97AT;R!C:71A9&]=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G
M:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6TEN9F]R;64@9&4@<')O
M8FQE;6%=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6TUO
M<W1R87(@=&5X=&\@8VET861O("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6TUO
M<W1R87(@=&5X=&\@8VET861O("T@)7,@;.UN96%S72(*"B,Z(&QI8B](;W)D
M92YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R(");;.UN96$@)7,@9&4@)7-=(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-34T('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R86-I\VXB"@HC.B!L
M:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*"B,Z
M(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(L%R
M7V)O;"!D871O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T
M<B`B15]L:6UI;F%R(&9I;&$B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@
M(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!O<R(*"B,Z(&QI8B](;W)D92]-96YU
M+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(D%?>75D82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<&EE
M9&%D97,@9&4@7VEM86=E;BXN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ
M.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7TEN:6-I87(@<V5S:?-N(@H*
M(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS
M9W-T<B`B7U-A;&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`B36]D:69I8V%R(%]V[6YC=6QO+BXN(@H*(SH@;&EB+TAO<F1E
M+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]P8VEO
M;F5S(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B7U!R:79I;&5G:6]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E
M($QI;FLN+BXB"FUS9W-T<B`B7T5L:6UI;F%R(';M;F-U;&\N+BXB"@HC.B!L
M:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")#;VY?9FEG
M=7)A8RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E!R;W!I961A9&5S(&1E(%]T86)L82XN+B(*"B,Z(&QI8B]A<&DN
M<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]5<W5A<FEO<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B9&ER96-C:6]N97,B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@
M(F1E<W1I;F%T87)I;R!D97-C;VYO8VED;R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.3$W"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")A9V5N9&$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(F-A;&UA
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(FYO('-E('!U961E
M(&-R96%R(&5L(&%R8VAI=F\@9&4@9&5S=&EN;R(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B;F\@<V4@<'5E9&4@86)R:7(@96P@;W)I9V5N(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P,`IM<V=I9"`B8VQI8VL@:&5R
M92(*;7-G<W1R(")P=6QS92!A<77M(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B
M"FUS9W-T<B`B97)R;W(@9&4@;.UN96$@9&4@8V]M86YD;R(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO
M;B!E<G)O<B(*;7-G<W1R(")E<G)O<B!D92!C;VYF:6=U<F%C:?-N(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A
M;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(F9A;'1A('5N(&%R8VAI
M=F\@8W+M=&EC;R!D96P@<VES=&5M82(*"B,Z(&QI8B](;W)D92]-24U%+TUE
M<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T
M<B`B97)R;W(@9&4@9F]R;6%T;R!D92!D871O<R(*"B,Z('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B;6]D:69I
M8V%R(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B96YT<F%D82!N;R!E;F-O;G1R
M861A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B9&5S8V5N<V\B"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.#DV"FUS9VED(")F:6QE(@IM<V=S='(@(F%R
M8VAI=F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S
M='(@(F1E;"`E<R`H)7,I(&$@;&%S("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")V
M96YT;W-O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R(")H
M:"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B
M:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B;F]M8G)E(&1E(&%N9FET<FGS
M;B!D97-C;VYO8VED;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*
M;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")I;FUE9&EA=&%M96YT92(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B96X@;.UN96$B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U
M="!E<G)O<B(*;7-G<W1R(")E<G)O<B!D92!E;G1R861A+W-A;&ED82(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B97)R;W(@9&4@<V]F='=A<F4@
M:6YT97)N;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B;.UN96%S72(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R(")C\V1I9V\@9&4@97)R;W(@;6MI<V]F<R`E9"!A;"!R96%L
M:7IA<B!)4T\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3<T"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#,*;7-G:60@
M(FYA;64B"FUS9W-T<B`B;F]M8G)E(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z
M,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B<VEN(&1E<V%R
M<F]L;&%R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(F'Z;B!N;R!S92!H
M82!D97-A<G)O;&QA9&\B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP.0IM
M<V=I9"`B;F]T97!A9"(*;7-G<W1R(")N;W1A<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E
M<F-E;G0B"FUS9W-T<B`B<&]R8V5N=&%J92(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`B<')I=FEL96=I;R!D96YE9V%D;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L
M<R(*;7-G<W1R(")P[7AE;&5S(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS
M9W-T<B`B97)R;W(@<F5M;W1O(&1E('!R;W1O8V]L;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B
M"FUS9W-T<B`B96X@875M96YT;R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R
M(")S97)V:6-I;R!N;R!D:7-P;VYI8FQE+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@
M(FUO<W1R87(@9&EF97)E;F-I87,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS
M9W-T<B`B<VUS,F5M86EL('!O<B!(5%10(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B<W,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM
M<V=I9"`B<W1E861Y(@IM<V=S='(@(F5S=&%B;&4B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G
M<W1R(")E<G)O<B!D96P@<VES=&5M82(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B=&%R96%S(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A
M<GD@9F%I;'5R92(*;7-G<W1R(")F86QL;R!T96UP;W)A;"(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS
M9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S
M='(@(F5S8W)I8F$@9&]S('9E8V5S(&QA(&-O;G1R87-E\6$@<&%R82!C;VYF
M:7)M87)L82(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I
M8V%D;R(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(G-I;B!N;VUB<F4B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")U<W5A
M<FEO('-E;&5C8VEO;F%D;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B
M=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+WIH7T-.
M+G!O````````````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`V-3$V-S$`,3`U,34T,S$P-C(`,#$V-#`U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@2&]R9&4@4VEM<&QI9FEE
M9"!#:&EN97-E(%1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`Q(%=A
M;F=(96YG5V5N+@HC(%=A;F=(96YG5V5N(#QW:'=`;7DQ-CDN8V]M/BP@,C`P
M,2X*(R!$879I9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SXL(#(P,#$N"B,@
M;&EA;V)I;B`\;&EA;V)I;D!J:71E+FYE=#XL,C`P-"X*(R`*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#(N,%QN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,#8M,3@@,C(Z,#4K,#@P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!L:6%O8FEN(#QL:6%O8FEN0&II=&4N;F5T/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@0VAI;F5S92`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/4=",C,Q,EQN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB
M"FUS9W-T<B`B("@E<R#,[,>P*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B("B_[+W=O/P@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,W-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B("AI
M;B`E<R!D87ES*2(*;7-G<W1R("(@*"5S(,SLQ[`I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B
M("B]\<SL*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*(RP@
M9G5Z>GD*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(L/WS.PB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A
M>2DB"FUS9W-T<B`B("C7\LSL*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@
M(@IM<V=S='(@(M/:(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!D:7)E8W1O<GDN(@IM<V=S='(@(K*[RL?2N[CVQ+_"O"(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E
M<R<@LKO*Q]*[N/;3T-"GM<31H=3Q+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2XB"FUS9W-T<B`B)R5S)R#)T,ZTU-H@2$]21$4@M<37HK+ASL2\_BA2
M96=I<W1R>2G6T,7DUL,N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z
M,3<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2`E<RXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G
M<W1R("(G)7,G(-+1L\FYIKS3R.NUO=/#NZ?7Z<^US;/6T"XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y
M<W1E;2XB"FUS9W-T<B`B)R5S)R#2T;S3R.O(J,_>S[7-LRXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(B<E<R<@LJ+.M+VHP:(Z("5S+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B
M)7,@TM'(H<_[("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S
M='(@(M?NO?P@)60@S.S&^,_SU*2QJ"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*
M;7-G<W1R("(E<R`M(+&XS?S"O"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E
M<G!R:6YT(@IM<V=S='(@(B5S(-:XSL8B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S
M='(@(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@SJR[I++9U_<@+2#(M\C/(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R#7
MHK+A(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E
M<R#-K-+BS^[$OR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R("(E<R#2T;3FU-HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*
M;7-G<W1R("(E<R#4VB`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@
M<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C
M:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T
M:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G
M<W1R("+1H=3QQ/K/Z]*JLMG7][7$S/7$ORXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E
M<75I<F5D(@IM<V=S='(@(K'8T.C2JB`E<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS
M9W-T<B`B)7,@M]8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`BU=*RN[6]("5S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@
M;V8@)7,B"FUS9W-T<B`B("5S(+6]("5S(+FR("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(LVHT;:ROB(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(LC5P/HB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S("T@L;C-_,*\
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R
M("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*(RP@9G5Z
M>GD*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"#5\[?G("5S("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(BP@U?.WYR`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<R(*;7-G<W1R("(LL>2[K\&_M-,@)7,@M;T@)7,B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T
M("TM(@IM<V=S='(@(BTM(-&AU/$@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@
M(L3ZM<30Q<^B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY
M"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("+$^K7$T,7/HB(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*
M;7-G<W1R("(R-"#0H<JQUL8B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N
M<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`BR<_2
MN]*S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS
M9W-T<B`BM,O'^+_IL=C0Z]*JUKBVJ,K]OMV_XK?^SO&VRRXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960B"FUS9W-T<B`BMZ+)^L'+TKNX]M'/UMBUQ+3MSO,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(M/[O-/#W-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""Y
MJ[^JP]S4ORXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("+3^]'IUJ32T<>IP_NU
MQ-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""YJ[^JP]S4ORXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
MT_N]XL/<T\J\_BR[N=#HTJK3T-*[N/:YJ[^J(%!'4"##W-2_+,N]P]P@4$=0
M(,/<U+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(M/[UK30T-/*O/['J</[++NYT.C2
MJM/0TKNX]KFKOZH@4$=0(,/<U+\LR[W#W"!01U`@P]S4ORS2U+RPO]K![BXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I
M9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(M/[O>+#W-/*O/XLN[G0Z-*JT]#2N[CVN:N_
MJB!334E-12##W-2_+,N]P]P@4TU)344@P]S4ORS2U+RPO]K![BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N
M(@IM<V=S='(@(M/[UK30T-/*O/['J</[++NYT.C2JM/0TKNX]KFKOZH@4R]-
M24U%(,/<U+\LR[W#W"!3+TU)344@P]S4ORS2U+RPO]K![BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("+3^[S3P]S3RKS^++NYT.C2JM/0TKNX]B!334E-12"YJ[^J
MP]S4ORXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`BU,;!OR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS
M9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS
M9VED(")!4$D@240B"FUS9W-T<B`B05!)(+'@NL4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T
M:&ES(&5D:71O<B(*;7-G<W1R("*YV-/:U>*X]K'@O*W&]R(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R
M("*YV-/:+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@
M(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(LBHS]ZRN]?C+,[>MZB]J,&B(%9&4R#$
MO\*\+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(LBHS]ZRN]?C+,[>MZB]J,&B(%9&4R#.Q+S^+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(L3ZM<30Q<^B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S
M='(@(LBWR,_#W,+K(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS
M9W-T<B`BU<NZQ=+1MK.]X2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(KWAU<HB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("+0PM3V(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@
M(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("+0PM3VS\*\MM?I(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*
M;7-G<W1R("+0PM3VS\*\MLBHS]XB"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(M3:M,O0PM3VH[HB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q
M.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("+0PM3VT\.[I]?I(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I
M;VXB"FUS9W-T<B`BT,+4]LBHS]XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`BT,+4]L_"
MO+;3P[NGU^D@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("+0PM3VS\*\MLBHS][6
MP2`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE
M=R!U<V5R.B(*;7-G<W1R("+0PM3VTKNX]M/#NZ<Z(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BT,+4
M]M*[N/:SR=2Q.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*
M;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(M#"U/:VU"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(M#"U/8@
M)7,@SJH@36]Z:6QL82!3:61E8F%R(+++M:4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(M#"U/:UO<[2M<3-J-&VLKXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`BT,+4]K6]SM*UQ,VHT;:ROB(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS
M9VED(")!9&0@=7-E<B(*;7-G<W1R("+0PM3VT\.[IR(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("+2
MT=#"U/8@)R5S)R"UO<^US;/6T"X@M:O.WK>HT,+4]K;NS>*UQ->BLN'0Q<^B
M.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+B(*;7-G<W1R("+2T=#"U/8@)R5S)R"UO<^US;/6T"X@Q/K/
MUM3:O\G2U+WXT-"UQ\*\P<LN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`BT,+4]M/#NZ>UQ+FFQ-RUL<>PL;NYV+'5+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(K78
MUK<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`BS:C1MK*^(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(K/)
MSJJYW,#MU+$@+2#.JL;DR_S3P[NGQ>36P\BHS]XB"@HC.B!A9&UI;B]I;F1E
M>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I
M9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BN=S`[2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(D%D<R(*;7-G<W1R("*YX[CF
MN=S`[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@
M(K"BN+NZN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
ML**V^[#-Q.'1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T
M<B`BL**V^[RPP/O1QR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(K'PP_LB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R("*Q\,/[(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PHC+"!F
M=7IZ>0IM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("*_S;NGMLLB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E
M9"!5<V5R<R(*;7-G<W1R("++^=/0TM'1Z=:DM<33P[NG(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL
M($=R;W5P<R(*;7-G<W1R("++^=/0T\.[I]?I(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T
M871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
MR_G3T,BHS]XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!
M;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`BU,K0[;;@N/:UY]?3
MT\J\_K78UK<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED
M(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU
M,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(M+1M.;4VB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)
M35-0($QO9VEN(@IM<V=S='(@(K'DN/P@24U34""UQ\*\(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S
M<W=O<F0B"FUS9W-T<B`BL>2X_"!)35-0(,/<PNLB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M
M92(*;7-G<W1R("*QY+C\($E-4U`@T\.[IR(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA
M:6P@861D<F5S<R(*;7-G<W1R("*QY+C\Q*.PYB(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S
M='(@(K'DN/S$H[#F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")!;'1E
M<FYA=&4@=&5X=#HB"FUS9W-T<B`BL>2X_,2CL.8B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("+#P,KTR/C$IM''(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+B(*;7-G<W1R("+2N[CVLKNZS[>HM<36M;&[RKG3PRXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY
M"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R
M("*WHLGZP<O2N[CVM.W.\SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A
M(@IM<V=S='(@(K"RM<"V^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*
M;7-G<W1R("*PLKCGP*TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R("*PLKGGP*TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`BQ.3#^[3Z
MP.TB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B
M06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I
M8V$B"FUS9W-T<B`BQ,^\J];>(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U
M82!A;F0@0F%R8G5D82(*;7-G<W1R("*PLLSAN<^\L+#-MONRO+3O(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*
M;7-G<W1R("+3IM/#L\S0\B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT
M,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("+3
MIM/#L\S0\B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@
M(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("+3IM/#L\S0\M+1OLW0
M]R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!
M<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`BTZ;3P[6]R_G3T,_"O+:Y
MLL_M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*
M;7-G:60@(D%P<')O=F4B"FUS9W-T<B`BQ?K7O"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@
M4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`BR\34PB(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`BL*+`K;*NSL0@*%=I;F1O=W,M,3(U-BDB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`BT;G+]<[$O/ZT\]"A(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R
M("+1N<OUSL2\_L/[L\8B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_(@IM<V=S='(@(L3ZR+>VJ-*JR;ZS_2`E<R"UQ->BLN'"\"`_(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B
MQ/K(M[:HTJK)OK/]("<E<R<@TM2\L,C.NL[7T]/#NZ?7Z2`_(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(K"BN/G-HB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`BT<?#P,3AT<<B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#
M24DM."DB"FUS9W-T<B`BT<?#P,3AT<?.Q"`H05)-4T-)22TX*2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(K"BPK.PS2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO
M;B!)<VQA;F0B"FUS9W-T<B`BL*+)K<O)R+JUNB(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]0
M86-I9FEC(%)E9VEO;B(*;7-G<W1R("+1Q];>+\RKQKW1\[78Q_@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B
M"FUS9W-T<B`BUK30T,ZLNZ2RV=?WQ[#/U,J^R+?(S[;4N["_\C\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M(@IM<V=S='(@(LK4S;S)OK/]TKNX]K*[M.;4VK7$T\.[I]?I+B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(LK4S;S)
MOK/]TKNX]K*[M.;4VK7$R*C/WBXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(LK4S;RQX+RMTKNX]K*[M.;4VK7$T\.[I]?I
M+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("+*
MU,V\L>"\K=*[N/:RN[3FU-JUQ+FRS^TN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`BRO30U"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS
M9VED(")!=6=U<W0B"FUS9W-T<B`BL,O4PB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R86QI82(*;7-G<W1R("*PQ+3SP/O1QR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%U<W1R:6$B"FUS9W-T<B`BL,*UV,#[(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]C<GES<6PZ(-72LKNUO<OYT.C2JK7$(&EM87`@P*G5N=?IO/XN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z(+?^SO&VR[*BSK3,X;FIN,//
M[M:GL]8N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R
M"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8W)Y=7,Z(-72LKNUO<OYT.C2JK7$
M(&EM87`@P*G5N=?IO/XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N
M<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B#5TK*[M;W+
M^=#HTJJUQ"!&5%`@P*G5N=?IO/XNQ^O6V-#"L>#2ZR!02%`@LJ+'TKS3R.L@
M+2UE;F%B;&4M9G1P(-&A(@HBS^XLP/W(YR!C;VYF:6=U<F4@+2UE;F%B;&4M
M9G1P(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I
M9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@U=*RN[6]R_G0Z-*JM<0@24U!4"#`
MJ=6YU^F\_BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q
M"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B#5TK*[M;W+^=#HTJJUQ"!K
M<F(U(,"IU;G7Z;S^+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@
MU=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@SMZWJ-#"
MU/;3P[NG("5S+B"W_L[QQO>[V-.F.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A
M<#H@SMZWJ,F^L_W3P[NG("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.
MWK>HN/S0PM/#NZ<@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]M8V%L.B#5TK*[M;W+^=#HTJJUQ"!-0T%,(,"IU;G7
MZ;S^+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@U=*RN[6]R_G0Z-*J
MM<0@<VUB875T:"#`J=6YU^F\_BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R("+1Z=:DRJ>PW"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S
M='(@(M'IUJ3*I[#<+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N(@IM<V=S='(@(E)!1$E54R#1Z=:DM.W.\RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D944"#1
MZ=:DM.W.\RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L
M(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(D944"#1Z=:DM.W.\RXB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S
M.B(*;7-G<W1R("*_R=/#M<37UK;..B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z
M97)B86EJ86XB"FUS9W-T<B`BL*+(^[#=O:XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$X"B,L(&9U>GIY"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(K&SOK#1
MU<FK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("*QL[ZPT=7)
MJR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@
M(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B:V5R8F5R;W,@P]S"
MZ[3MSO,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM
M<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")K97)B97)O
M<R#3P[NGP_NT[<[S+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS
M9W-T<B`BL,VY_L+MR+JUNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB
M"FUS9W-T<B`BL,W!UB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS
M9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("*RJ,+>M<2ZH\[$
M("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H
M(@IM<V=S='(@(L//O-/`K;GZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`BL,VPS;;@R[DB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI
M8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNU
MO2`E<R"UQ,#@L?"VJ-+E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B0F%S96QI
M;F4B"FUS9W-T<B`BLJ[`^]?((@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U
M<R(*;7-G<W1R("*PU[;MPM[+N2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I
M=6TB"FUS9W-T<B`BL<C`^\JQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(K*NP/O7R"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM
M<V=S='(@(K&TQ/XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(K#9Q+VT\\BZM;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS
M9W-T<B`BLKNUI"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(LGZR-4B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P
M;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BU=*RN[6]("5S
M(+7$P."Q\+:HTN4N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("+'^+_IQ>36PR(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO
M8VL@5'EP92(*;7-G<W1R("+'^+_IP.#0S2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R
M("*TULSE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("*R
MH\#[SJS1QR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R("+*Z<>I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM
M<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H
M:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R
M9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`BLJC+N<3AT<>ZS;K:R/NXY\ZL
MQ,<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*(RP@9G5Z>GD*;7-G
M:60@(D)O=&@B"FUS9W-T<B`BU,(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S
M=V%N82(*;7-G<W1R("*RJ;3$S=_$R2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS
M9W-T<B`BLJC.K,S8M;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS
M9W-T<B`BL,W.]R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`BTZ+*]-.AMLC1\\'LM=@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("+.
MQ,"S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`BL:.\
MT\#[T<<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(L_NQ+^W^[K%
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(K*\
MO*K$R;>HR_<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@
M(K*\PJ&USR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G
M:60@(D--4R(*;7-G<W1R("+$VLC=N=S`[<^US;,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T
M<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-2
M3""WUK*\M>,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(LC5
MP/HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED
M(")#86QM(@IM<V=S='(@(L'CO+:WYR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#
M86UB;V1I82(*;7-G<W1R("*\[<;2U:\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M86UE<F]O;B(*;7-G<W1R("*_IL+SPJ$B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A
M=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I
M;&4@7"(E<UPB(@IM<V=S='(@(L[>MZC)OK/]SL2\_B!<(B5S7"(N(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R
M(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(L[>MZC!
MJKOZUL$@24U!4""W_L[QQO<Z("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.WK>HR;ZS_<[$O/X@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("*\T\3#
MM/,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("+(
MH<_[(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G
M:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+(H<_[SLK,XK&H
MN.8B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("+.WK>HR;ZS_<[$O/X@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,L(&9U>GIY"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(L[>
MMZC)OK/]Q+_"O"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(L[>MZC)OK/]Q+_"O"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`BSMZWJ,F^
ML_T[T]#/PKRVM.;4VB`H)7,I(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`BSMZWJ-;8U^FA
MH\OYS.&YJ;7$O,?"O,K]Q+_3Z\_(Q[#+^;&CM.:UQ,K]OMVRN[?[+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BXB"FUS9W-T<B`BSMZWJ+2KR\W0Q<^BM;W6N+:HM<2ZQ<+K+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`BM_"UP[W'(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+1H<_N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T
M"B,L(&9U>GIY"FUS9VED(")#87)R:65R(@IM<V=S='(@(K?;NNS)JR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A
M;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM
M86X@27-L86YD<R(*;7-G<W1R("*_JL+\R+JUNB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO
M;F4B"FUS9W-T<B`BTL:VK[7GN[`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#
M96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BTL:VK[7GN[`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L
M;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(M+&MJ^UY[NP(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM
M,30I(@IM<V=S='(@(LC[MOO,V,[$("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"B,L
M(&9U>GIY"FUS9VED(")#96YT97(B"FUS9W-T<B`BO:C!HB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("+6
MT+?'N;*ZS;GZ(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@
M(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(M;0Q;<@
M*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
MQK[6I,^XO=HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8Q,0HC+"!F=7IZ>0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T
M<B`BQK[6I,^XO=HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B
MQK[6I++?PM0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B
MU:>UPR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G
M<W1R("*X_+C$(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q
M"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R
M("+(M\C/P]S"ZR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*
M(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W
M"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(M6GM<,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-H:6QE(@IM<V=S='(@(M;'P/LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EN82(*;7-G<W1R("+6T+GZ(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G
M<W1R("*\\LSEUM#.Q"`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G
M<W1R("*WL<SEUM#.Q"`H0FEG-2DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G
M<W1R("+1H=3QP]S"ZR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(M&A
MU/'2N[CVT\.[I\/[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM
M<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("+(
MU<;:S]3*OK>]RKTZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`BRJ6UKK6Z
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BU=*RN[6]("5S
M(+7$P."Q\+:HTN4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(LC5
MP/HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(LK]OMV_XK+IT:\B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(LF^L_W3P[NG.B`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B
M0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B!D871A
M(@IM<V=S='(@(M&AU/'2N\Z[T\.[I]/#TM30PM3V(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG
M($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM
M<V=S='(@(K"TRO.QZKS\O,S0^"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V
M:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E
M(%=I;F1O=R(*;7-G<W1R("*YV+'5M+"_VB(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`BU,;!OR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U>GIY
M"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`BU,;!OR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"B,L(&9U>GIY"FUS
M9VED(")#;&]U9'DB"FUS9W-T<B`BU,;!OR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(K_&O\;+N<BZM;HB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#
M;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA
M<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M;&]M8FEA(@IM<V=S='(@(KCGPM>QR-''(@H*(SH@;&EB+T)L;V-K+V-O;&]R
M+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O
M;&]R(@IM<V=S='(@(M'5R:LB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`BM??)J\7,(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@HC+"!F=7IZ>0IM<V=I
M9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("*\],?0T:'4\2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"B,L(&9U
M>GIY"FUS9VED(")#;VQS.B(*;7-G<W1R("+-ML:Q(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED
M(")#;VUI8W,B"FUS9W-T<B`BOZC-J"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("+#_,'N(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@
M(L/\P>Z]Q;&^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(L;`PMLB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`BS:C3P\/[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R
M;W,B"FUS9W-T<B`BO\;$IL+>(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("*Y
MJ\N^(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"B,L(&9U>GIY"FUS
M9VED(")#;VUP=71E<G,B"FUS9W-T<B`BTM'-ZK/)(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(LSUO/XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T
M.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("+,];S^(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,B"FUS9W-T<B`BQ>36PR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I
M;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0HC+"!F=7IZ>0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B
MQ>36PR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(L7DUL,@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#
M;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(LBWR,_#W,+K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`BN-6Y^R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G
M:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS
M9W-T<B`BN-6Y^[FRNLVY^B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D+B(*;7-G<W1R("+!K+W3RJ>PW#H@(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960Z("(*;7-G<W1R("+!K+W3RJ>PW#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-SDP"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(L&L
MO=/6P;FKOZK#W-2_M_[.\<;WRK'4XK[<OO@N(-2MTO(Z("5S("@E<RDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`BP:R]T];!N:N_
MJL/<U+^W_L[QQO?*L=3BOMR^^"X@U*W2\CH@)7,@*"5S*2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+!K+W3UL$@1E10(,[$O/ZW
M_L[QQO?*I[#<+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS
M9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+B(*;7-G<W1R("+-J-&VROV^W=+1L\FYIK7$U/:\T[6]Q/JUQ,VHT;:R
MOM;0+M/#RO.QZK"TS\+!T,_NQ+_2U+SLRM,Z(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(G)7,G(,[$O/[$VLC=(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#;VYT:6YU92(*;7-G
M<W1R("+,];S^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM
M<V=S='(@(K_BO\O(NK6Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R
M"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS
M9VED(")#;W!Y(@IM<V=S='(@(KFKR[XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P
M>2!F86EL960Z("5S(@IM<V=S='(@(L&LO=/*I[#<.B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y
M('-E;&5C=&EO;B(*;7-G<W1R("*XM-;&T:'4\2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B
MN.?+N;3OP.B\TR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B
M"FUS9W-T<B`BO\;,V+7/S=\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R("+.WK>HTM0@4$=0(+S3P]S3RKS^+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("+.WK>HSJH@4$=0(-:TT-#3
MRKS^QZG#^RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(L[>MZC2U"!3+TU)344@O-/#W-/*O/XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("+.WK>HSJH@4R]-24U%
M(-/*O/['J</[+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(L[>MZBT\K^J("5S
M+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(L[>MZBP\[:H($Q$05`@
MM_[.\<;W(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T
M<B`BSMZWJ+#SMJ@@3$1!4""W_L[QQO<B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*
M;7-G<W1R("+.WK>HML'(H2`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L
M9&%P('-E<G9E<B(*;7-G<W1R("+.WK>HP:R]TR!334(@M_[.\<;W+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U
M<VEN9R!&5%`Z("5S(@IM<V=S='(@(L[>MZC!K+W3UL&W_L[QQO<@)R5S)R#*
MN=/#($944#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BSMZWJ+VHP:*QOK78T^_1U"`E<R#+^=#HTJJUQ,2_PKPZ(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(L[>MZB]XL/<(%!'4"#*
M_;[=+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T
M<B`BSMZWJ+WBP]P@4R]-24U%(,K]OMTN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`BSMZWJ,F^L_VX_-#"L\S0\B`G)7,G+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("+.WK>HR;ZS_;C\T,*SS-#R("<E<R<N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB+B(*;7-G<W1R("+.WK>HR;ZS_;C\T,*SS-#R("<E<R<N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB
M"FUS9W-T<B`BSMZWJ+[VMJC*U;S^R,NUQ+7GU]/3RKS^M=C6MRXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`BSMZWJ+[VMJC*U;S^R,NUQ+7GU]/3RKS^M=C6
MMRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+.WK>HL/RZK-?6S.6V
MJ-+ESL2\_BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP
M;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E
M<UPB+B(*;7-G<W1R("+.WK>HML'(H2`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T
M<B`BSMZWJ+;!R*$@)7,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("+.WK>HU]3#W-2_M_[.\<;W
MR*&UP[FKOZK#W-2_+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F
M;W(@=W)I=&EN9RXB"FUS9W-T<B`BSMZWJ+3ROZH@)7,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("+.
MWK>HM/*_JB`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("+.WK>H
MM/*_JLZLNZ2YI-?WQ*._Z2`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_W$O\*\(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(L[>MZBRZ=72
M($Q$05`@(+?^SO'&]RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N
M<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E
M<RXB"FUS9W-T<B`BSMZWJ+;!R*$@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M(@IM<V=S='(@(L[>MZBVP<BAM.;(H;_8UL:Q[2A!0TPI(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S(@IM<V=S='(@(L[>MZBVP<BAM_[.\<;WM<3/X+G8S-C0
MU"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L[>MZBV
MP<BAM_[.\<;WM<3/X+G8S-C0U"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<R(*;7-G<W1R("+.WK>HML'(H;?^SO'&][7$S^"YV,S8T-0B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M("+.WK>HML'(H;?^SO'&][7$S^"YV,S8T-0B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L[>MZBQH[3F("5S(+7$Q>36PRXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(L[>MZBV
MP<BA("5S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(L[>MZBQH[3F("5S(+7$Q>36PRXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;BXB"FUS9W-T<B`BSMZWJ+&CM.8@)7,@M<3%Y-;#+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R("+.WK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(L[>MZBQH[3FN/S0PK/,T/*UO3H@)R5S)RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`BSMZWJ+&CM.8@)7,@M<3%Y-;#+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P
M=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N
M=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(L[>MZC0M,CK
M+B#$^K_)TM3*N=/#R,ZZSK7$R?V\MK/,T/*[\LK6MJ^XM-;&S\+#YK/,T/*T
M^L+KM;T@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("+.WK>HLNG5TB!,1$%0(""W_L[QQO<N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+3ROZH@)7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,B"FUS9W-T<B`BSMZWJ+3ROZH@)7,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L[>MZBP_+JLU];,Y;:HTN7.Q+S^
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`BSMZWJ+BRN,<@)R5S)SH@)7,@M<3%
MY-;#+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(M72LKNUO2!-;WII;&QA(%-I
M9&5B87(N(,?KR+?(SR!S:61E8F%R(,K'M_&T\K^J+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(L[>MZBXL]/HT\.[IR`G)7,G(,_"P=#(J,_>M;W.Q+S^O-`@
M)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"B,L
M(&9U>GIY"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`BS.'*OL3:R-TB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I
M9"`B0V]U;G1R>2(*;7-G<W1R("*Y^KS2(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(W,PHC+"!F=7IZ>0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R
M("+0H<JQ(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BO:C!
MHB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G
M<W1R("*]J,&B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G
M<W1R("+1H=3QTKO.N]#"M<33M=/0U=\B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD
M97)S(@IM<V=S='(@(KVHP:+7T\[$O/Z\T"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(KVHP:+5W[7$R*C/WB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M("+0Q=/#OZBZQ<+K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS
M9W-T<B`BO\O"WK78T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S
M='(@(KG%L,TB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`BM;''L,_@SKLB"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E
M;G0@4V5S<VEO;G,B"FUS9W-T<B`BO:C!HM7?M<3(J,_>(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#
M=7)R96YT(%1I;64B"FUS9W-T<B`BM;''L,JQO.0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(K6QQ[#*L;SD(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R
M96YT(%5S97)S(@IM<V=S='(@(K6QQ[#/X,Z[(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(K6Q
MQ[#,[,;X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM
M<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("*UL<>PU[2_]CH@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("*UL<>PM^>X\2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D-U="(*;7-G<W1R
M("*Y^KS2(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("*\],?0T:'4
M\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("+(^\;6PK?+
MN2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI
M8R`H2T])."U2*2(*;7-G<W1R("+.]\#OMOO.Q"`H2T])."U2*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*2(*;7-G<W1R("+.]\#OMOO.Q"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52DB"FUS9W-T<B`BSO?`[[;[SL0OSMJ_R\"\SL0@*$M/
M23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G
M<W1R("*]W;_+N;*ZS;GZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`BR-4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(L._R-4B"@HC.B!A
M9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM
M<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R("+(U<;:(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`BRM6UO<C5QMHB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R("+1H=3QR-7&VB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@IM<V=I
M9"`B1&%Y(@IM<V=S='(@(K#7S.PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@
M(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(LF^L_W3P[NGU^DB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C
M96UB97(B"FUS9W-T<B`BRJZV_M3"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(M#RNL4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R
M96%S92!);F1E;G0B"FUS9W-T<B`BO/7)V<OUQ<4B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R("+)OK/](@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`BU];0S='5R:LB"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A
M=6QT($ED96YT:71Y(@IM<V=S='(@(L2LR,_)[;?=RK:Q\"(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3
M:&5L;"(*;7-G<W1R("+$K,C/R>VWW<JVL?`B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S
M='(@(LSUO/XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`BR;ZS_2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`BR;ZS_2(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`BR;ZS_=/#NZ?7Z2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E($QO9R(*;7-G<W1R("+)OK/](@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`BR;ZS_<BH
MS]XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("+)
MOK/]H:+'Y;_5T\J\_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C
M96QL(@IM<V=S='(@(LF^L_TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@8V]L=6UN(@IM<V=S='(@(LF^L_W3P[NGU^DB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("*RY<CKO\G,YK3ZQ*.PYB(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B(*;7-G<W1R("+)OK/]("<E<R>UQ,BHS]XB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(LBWMJC2JLF^L_T@)R5S)[7$R*C/
MWM+4O+#/PKRVR*C/WB`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(')O=R(*;7-G<W1R("+)OK/]T\.[I]?I(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(M&AU/'(U<;:(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="!<(B5S7"(N(@IM<V=S='(@(KC\T,*SS-#R("<E<R<@TM')OK/]+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BM=W+
MS<JQO.0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(K6D
MPO,B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I
M9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`BSLK,XL/HRO8B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`BP^C*]B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ(@IM<V=S='(@(L^XO=H@*,?KLLZ_O"!(;W)D92"\Q\*\SL2\_BDZ
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(L^XO=K'Z[+.O[S/M<VSN=S`[;7'PKPN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS
M9W-T<B`BT="WHB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED
M(")$97<@4&]I;G0B"FUS9W-T<B`BPK:UX\["ML@B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R("+7[KKSTKO0H<JQM<3"MK7CSL*VR#H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B
M"FUS9W-T<B`BPK:UX\["ML@Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O
M(')I9VAT(@IM<V=S='(@(K33U_/6P=/2(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`BM-/3TM;!U_,B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(L2_PKPB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(M+4(#(T(-"ARK'6QL_4RKX_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P
M=&EO;G,B"FUS9W-T<B`BS]3*OM&AS^XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0B"FUS9W-T<B`BS]3*OKCQRKTB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T
M("A4048I(@IM<V=S='(@(L_4RKZX\<J](@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B
MS]3*OKCQRKTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP
M"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`BO*JRO,SA(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O
M(&YO="!D96QE=&4B"FUS9W-T<B`BLKO)OK/](@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("*RN]*JUK&]T[3FR*$@;6%I;G1E
M;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`BM=K2N['*O,?"O,K'M_&P_+JLU]:V
MSL/[L\8_(,CGN?O*Q\?KT:'4\2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI
M;FEC82(*;7-G<W1R("*VX,/7Q.&\TR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O
M;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("*VX,/7Q.&\T[FRNLVY^B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA
M=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R("+/PM38(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S
M(@IM<V=S='(@(L_"U-@@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+B(*;7-G<W1R("+/PM38R?JSR;7$Q>36P\[$O/[.JB!0
M2%`@L\S0\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("+/PL"MLLNUI2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")%+4UA:6PB"FUS9W-T<B`BM>?7T]/*O/XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M
M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED
M92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*
M;7-G:60@(D524B(*;7-G<W1R("*T[<[S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16-U861O<B(*;7-G<W1R("*V\KG/MN"V^R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET(@IM<V=S='(@(K'@O*TB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G
M:60@(D5D:70@0FQO8VLB"FUS9W-T<B`BL>"\K<?XO^DB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I
M="!'<F]U<"(*;7-G<W1R("*QX+RMT\.[I]?I(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(K'@O*W(
MJ,_>(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B
M161I="!097)M:7-S:6]N<R(*;7-G<W1R("*QX+RMR*C/WB(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BL>"\K2`E<R"UQ,BH
MS]XB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET
M(&]P=&EO;G,@9F]R.B(*;7-G<W1R("*QX+RMT:'/[B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B
ML>"\K2`E<R"UQ,BHS]XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(K'@O*T@)7,@M<3(J,_>(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")%9'5C871I;VXB"FUS9W-T
M<B`BM=C'^"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(K"C
MO+`B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U
M<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`BR/BV^\W?
MMN`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G
M:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`BM>?7T]/*O/XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BM>?7
MT]/*O/ZUV-:W(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM
M<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(K7G
MU]/3RKS^M=C6M['8T.O.Q[K/+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(K7GU]/3RKS^R+?(SR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BL>W'Z;?[
MNL4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(K_5L-?0
MQ;S^+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BO]6PU[WA
MN?LN(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM
M<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`BQ.JUUR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*
M;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(K?%M/.QX+RMQO<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S
M='(@(K/@M<"\N,3:T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(K;RP:+,V,#OT<<B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("*T
M[<[S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<R(*;7-G<W1R("*TJ\O-N]BXM,JQMZ+)^K3MSO,Z("5S+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S(@IM<V=S='(@(K2KR\V[V+BTRK&WHLGZM.W.\SH@)7,N(@H*(SH@9G)A
M;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS
M9W-T<B`BM*O+S;O8N+3*L;>BR?JT[<[S.B`E<RXB"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("*TJ\O-
MN]BXM,JQMZ+)^K3MSO,Z("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG
M(%PB)7-<(BXB"FUS9W-T<B`BM*O+S;O8N+3*L;>BR?JT[<[S.B`E<RXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(K"NR;/$X=''(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`BL*/(^[;ML<C1
MQR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@HC+"!F=7IZ>0IM<V=I
M9"`B171H;FEC(@IM<V=S='(@(K"NR;/$X=''(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`BQ;?6
MWB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y
M(#$U(&UI;G5T97,B"FUS9W-T<B`BP[\@,34@M];6TR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN
M=71E<R(*;7-G<W1R("+#OR`U(+?6UM,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BP[\@,S`@P^O6TR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(L._(#4@M];6TR(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*
M;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(L._M,ZUQ\*\(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(L._(#,P(+?6UM,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y
M(&UI;G5T92(*;7-G<W1R("+#OR`Q(+?6UM,B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S
M='(@(K>VP/W6M3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO
M8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@
M(D5X96-U=&4B"FUS9W-T<B`BUK30T"(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(M6Y
MOZHB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"B,L(&9U
M>GIY"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("+$ZK77(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`HC+"!F=7IZ>0IM
M<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(M:TT-`B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP
M:7)A=&EO;B!$871E(@IM<V=S='(@(K6]QMK(U2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G
M<W1R("*]XLNUU+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED(")&1R!#;VQO<B(*
M;7-G<W1R("+7UM#-T=7)JR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B1E10(,G/
MM*O%Y-;#+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q
M-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S
M='(@(K;!R*'&J[K#Q>36P\JGL-PB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY
M.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(L[>MZC!K+W3($Q$05`@M_[.\<;W+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`BSMZWJ,&LO=,@4TU"(+?^SO'&]RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T
M<B`BN+36QLJGL-S7U"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R("*XM-;&RJ>PW+6](%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(L[>
MMZB]J,&BTKNX]M#"M<0@4T%33"#!K+W3+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<
M(BXB"FUS9W-T<B`BTL:VK[6](%PB)7-<(LJGL-PN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`BTL:VK[6](%PB
M)7-<(LJGL-PN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3@*(RP@9G5Z>GD*;7-G:60@(D9A:7(B"FUS9W-T<B`BU/K2P;;[
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I(@IM<V=S='(@(K>HP+R_R[BCR+JUNB`HPNVV^\ZLQ,G+N<BZM;HI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("*WJ,+>
MR+JUNB(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*(RP@9G5Z>GD*
M;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("+1S];8M.W.\R$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED
M(")&87@B"FUS9W-T<B`BM*O5YB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(K2KU>8B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM
M<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`BMO[4PB(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(KC0OO7/
M\<K'(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(KC0OO7/\<K'.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I
M9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*(RP@9G5Z>GD*
M;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(M72LKNUO<[$O/XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(NRSO,,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B
M"FUS9W-T<B`BSL2\_B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS
M9W-T<B`BSL2\_LK]Q+\Z("5S(+CVSL2\_B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&5S(@IM<V=S='(@(L[$O/[*_<2_.B`E<R#.Q+S^(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R
M(@IM<V=S='(@(L[$O/ZYW,#MQO<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(L[$O/[#^[/&(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0HC+"!F=7IZ>0IM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`BRK''^-&AU/$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*
M;7-G<W1R("+.Q+S^R<^TJR(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(L[$O/[)S[2KN:;$W,ZTL;O6I[/6+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("*Y
M_<++QO<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(K?2
MP+PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(
M86QF(@IM<V=S='(@(LG/L.O4PB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW
M-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B
M"FUS9W-T<B`BR<_/TM3"(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(KG,
MMJBQR,#](@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("*WK=>J(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I
M9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E
M<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("+$O\*\("5S(+*[M.;4VB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`BU];0S='5R:LB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(V"B,L(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("+$^K7$Y*_`P,;WLJ+.M-:GL];5
MXKCVN:;$W"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B
M1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(M2DL:C,[,K]("C4I+&H
MS.S*_;#\P*BPU\SLTM2\L-*YO.2UQ,K]OMT[R.>Y^]2DL:C,[,K]O<^SI+VK
MU;S3P['(O<^_[;?YM<2PYB(*(L/F*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3`R"B,L(&9U>GIY"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`BT:'4\</<PNLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("*TL,SE(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S
M='(@(LOCP_PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@
M(D9O<G1U;F4@='EP92(*;7-G<W1R("++X\/\P.#0S2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BR^/#
M_"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I
M9"`B1F]R='5N97,@,B(*;7-G<W1R("++X\/\(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(L+;S+,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W
M87)D<R(*;7-G<W1R("+7U+:OUZK0Q2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(M#'
MQMK.Y2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R("*T
ML,SE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(K>HN?HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`BMZC*]+GGT<?$QR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(K>HRO2R
MH\#[Q.'.]]''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE
M<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R
M("*\Q+S^R,LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S
M='(@(K33(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BS>K5^\/HRO8B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(L+ZU,(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(LBKP_LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("*\T\7N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P
M"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("*XU+'(T<<B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`BLOK)^B`E<R"UQ,^U
MS;/%Y-;#(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL
M.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`BN/'"L[RJT<<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(K7"N?HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")':&%N82(*;7-G<W1R("+ER,3)(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VEB<F%L=&%R(@IM<V=S='(@(M:QLKS"WLW3(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B
M"FUS9W-T<B`BP_LB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM
M<V=I9"`B1V\B"FUS9W-T<B`BUZJUO2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS
M9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@R]'+]R(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B
M"FUS9W-T<B`B1V]O9VQE(,O1R_<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T
M<B`BN]*VR"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
MSZ/`L"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E
M:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`BSZ/`L,[$("A)4T\M.#@U.2TW*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("*X\<'JP+PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(KCQP=;$R;3O
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(M/#NZ?7Z;G<P.TB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M(@IM<V=S='(@(M/#NZ?7Z</[L\:RN[7#O]6PUR(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD
M87`Z(,[>MZC0PM3VT\.[IR`E<RX@M_[.\<;WN]C3ICHB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")!=71H
M7VQD87`Z(,[>MZBX_-#"T\.[IR`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,W.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD
M87`Z(,[>MZBX_-#"T\.[IR`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T
M<B`BT\.[I]?I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G
M<W1R("*YS[7"PM[&U;6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS
M9W-T<B`BN=BUNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS
M9W-T<B`BSJ.UV,+MP*TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("*X\;;WSO>UNB(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(K?#O\W(J,_>(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W
M,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(K?#O\W!]-'4(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(KRXQ-K1QR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("*\N,3:T<>QR,G<
MN;*ZS;GZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
MN>?1Q\3'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED
M(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`BU=*R
MN[6]($A45%`@T>G6I"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM
M<V=S='(@(KJCM=@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(M33M-4MR^.W
MJ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R
M"B,L(&9U>GIY"FUS9VED(")(87IE(@IM<V=S='(@(K'MS;<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(K'MS;<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY
M"FUS9VED(")(96%D97)S(@IM<V=S='(@(K'MS;<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G
M<W1R("*ZU;7"NLW"]+6QP,W(NK6Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE
M8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("+/H[*NP+3.Q"`H25-/+3@X
M-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(DAE:6=H="(*;7-G<W1R
M("+-[<G/(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W
M.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN
M8SHS"FUS9VED(")(96QP(@IM<V=S='(@(K#OUOHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S
M:6YG(&5D:71O<B(*;7-G<W1R("*QX+RMQO?*N=/#L._6^B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R
M("*P[];Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"B,L(&9U>GIY"FUS
M9VED(")(96UI<W!H97)E(@IM<V=S='(@(K&QL.O'\B(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z(@IM<V=S='(@(M7BP._*Q\[$O/ZUQ+^JRKPZ(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@
M(DAI9V@B"FUS9W-T<B`BS>W)SR(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC
M+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`BRM?2LR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM
M<V=S='(@(NCSM=FXU"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R("+*U]*S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D
M9')E<W,B"FUS9W-T<B`BRM?2L[78UK<B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S
M='(@(L2_PKPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(LK7TK.UY[NP
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("*ZZ;:\
MP*W+N2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@
M(M;0N?K/X[C;(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS
M9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A
M9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*
M;7-G<W1R("+2T;/)N::XLKC'("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(,[>MZC)OK/]
MT\.[IR`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G
M<W1R("++KL:]S]\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@R"B,L(&9U>GIY"FUS9VED(")(;W)I>F]N=&%L('!A9&1I
M;F<B"FUS9W-T<B`BRZ[&O<_?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,0HC+"!F=7IZ>0IM<V=I9"`B2&]R:7IO;G1A
M;#HB"FUS9W-T<B`BRZ[&O<_?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U
M"B,L(&9U>GIY"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R("+7UK;.ROW$O[FRO,8_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("+7UK;.ROW$O[FR
MO,8_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B
M2'5M:61I='DB"FUS9W-T<B`BRJJVR"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`BRJJV
MR#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO
M<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y
M(@IM<V=S='(@(M#9T<#`^R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(DE-05`@T\K/Y+VHP:+*I[#<.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-
M05`@T\K/Y,F^L_W*I[#<.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@T\K/Y+3%Q<S%Y-;#
MO:C!HLJGL-PZ("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q
M-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("*UV-:W(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4""UV-:WSMZW
MJ,JYT\,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX
M.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B25`@M=C6M[*BLKO4VB!#2412(+7$O=/*W,?XO^G6
MT"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(K'Y
MM;HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(M:[T]#-O+'J(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F
M;W(@)7,B"FUS9W-T<B`B)7,@M<31H<_N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(LV\
ML>J\L,[$U]8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED
M("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E
M;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS
M<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B26UA9V4@
M4')E=FEE=SHB"FUS9W-T<B`BU*3`P"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*(RP@9G5Z>GD*;7-G:60@
M(DEM86=E(%523"(*;7-G<W1R("+-O,:L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"B,L(&9U>GIY
M"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(LV\QJPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L
M;V%D(@IM<V=S='(@(LG/M*O-O,:L(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("+-O,:L(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`BN^/(ZRP@LKW6Z"`E9"(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("*[X\CKU]:VSCH@)7,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O
M<G1E9"!F:65L9',Z(@IM<V=S='(@(KOCR.O7UK;..B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I
M9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(LKDR.NRN]7]R+>UQ-?W
MT\/"ZRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BSK36JK7$T\.[I\/[N_+#W,+K
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B
M"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E
M87-E($EN9&5N="(*;7-G<W1R("+4]KS3R_7%Q2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B26YD:6$B"FUS9W-T<B`BTZ&VR"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(KCVL?#3P[NG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`BTZ&V
MR,3ASO?1QR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`BT,7/HB(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*;7-G:60@(DEN9F]R;6%T:6]N(@IM
M<V=S='(@(M#%SZ(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M($EM86=E(@IM<V=S='(@(K+ER.O3RKS^(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE
M(@IM<V=S='(@(K+ER.NQ[;CQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM
M<V=S='(@(K+ER.O-^,+GP:R]TR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#
M;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S
M='(@(K+ER.N_R<SFM/K$H[#F(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S
M='(@(K+ER.O3RKS^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-E
M;&P@8F5F;W)E(@IM<V=S='(@(K+ER.NQ[;CQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS
M97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A
M9V5S(@IM<V=S='(@(K+ER.O3RKS^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("*RY<CKL>VX\2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S
M='(@(K+ER.NQ[;CQ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM
M<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y
M($EM86=E(@IM<V=S='(@(K+ER.LOL>2X_,V\QJPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O
M36]D:69Y($QI;FLB"FUS9W-T<B`BLN7(ZR^QY+C\S?C"Y\&LO=,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`BU?O*_2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@
M;&ES="(*;7-G<W1R("+5^\K]P=`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(L[>T*>UQ"!51$@HT\.[
MI\K]OMVQ[<VW*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G
M<W1R("+.WM"GM<3-\M/#PNO*_;[=+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@
M(L[>T*>UQ-.FT\.SS-#R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)
M1"XB"FUS9W-T<B`BSM[0I[7$Q?JTSKK%PNLN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D
M+B(*;7-G<W1R("+,X;V[M<3*_;[=SM[0IRXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L
M:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`BSM[0I[7$Q+^QZM>A
MUK<B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX
M,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS
M9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(K*[NL^WJ+7$SL2\
M_KCQRKTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("+.
MWM"GM<33IM/#L\S0\BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("+.WM"GM<33IM/#L\S0\BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN
M=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(L[>T*>UQ"!M<V=?='EP92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@
M(L[>T*>UQ+ORU=*RN[6](&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("+.WM"GM<2[\M72LKNU
MO;+.ROTN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED
M("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("*RN[K/MZBU
MQ+BXR*C/WBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@
M(K*[NL^WJ+7$N+C(J,_>+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E
M+B(*;7-G<W1R("+.WM"GM<3-J-&VT*W2Z2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(L[>T*>UQ,VHT;;0K=+I+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(L[>T*>UQ+#FL;ZZQ<+K(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BLKNZ
MS[>HM<3.Q+S^N/'*O2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D
M<F5S<RXB"FUS9W-T<B`BSM[0I[7$P+34M->AUK<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("))
M;G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`BSM[0I[7$S?+3P\+KROV^
MW2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E
M;&5C=&EO;B(*;7-G<W1R("*\],?0T:'4\2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I
M9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("+2P<#*TL'+
MN<"\N;*ZS;GZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(M+!P*V_RR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R
M("*PKK;[P+PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`BPORUNB(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E
M9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES
M<F%E;"(*;7-G<W1R("+2U,FKP=`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(L>IMZ+5
MWR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(M"QS.4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DET86QY(@IM<V=S='(@(M+BM//`^R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B2F%M86EC82(*;7-G<W1R("+1P,+RO-,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*
M;7-G<W1R("+2N]3"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G
M<W1R(")*87!A;B`HR-6QOBDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("+(U<[$
M("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O
M;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I
M<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(M3S
MSO>UNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(M2\
MM:DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R("+&W]3"(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T
M<B`BP?G4PB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S@*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GDB"FUS9W-T
M<B`BO[_7\[;4QNLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS
M9W-T<B`BUL/6T"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T
M<B`BU_/3TK;4QNLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S
M='(@(K^_U_.VU,;K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`BO[_3TK;4QNLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T
M86XB"FUS9W-T<B`BN?[(^+_+R[G,N2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_
M(@IM<V=S='(@(K&CP?34K='Y(#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME
M;GEA(@IM<V=S='(@(K_/Q.'1QR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@R,_6I+3MSO,N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W
M8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("+#W-2_O:C!
MHB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I
M9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(L/<U+_,V-7W(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N
M9W1H(@IM<V=S='(@(L/<U+^SI+;((@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("+#W-2_
MP.#0S2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX
M"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`BP]S4O]/OMZ@B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
MM;''L+7$N:N_JL/<U+^W_L[QQO?6T"S2T;ZMM.;4VL3ZM<3#W-2_+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(KOY
MP.^PS<NYN;*ZS;GZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("*SK\_*(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`BNJNY^B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+
M;W)E86X@*$550RU+4BDB"FUS9W-T<B`BNJO.Q"`H155#+4M2*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(K_&S?[,V"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("*\JK;[O*K+N<RY
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"B,L(&9U>GIY"FUS
M9VED("),85]Y;W5T(@IM<V=S='(@(K#FP^;%Y-;#(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B
MT^_1U"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`BP,_.SB(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("+/PK#KU,(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@
M(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(L/<PNLZ("(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G
M:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("+/PL_2U,(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R
M("+)S[3.N/S0PCHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
MR<_2N[3.M<?"O#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<R(*;7-G<W1R("+)S]*[M,ZUQ\*\.B`E<R#7U"`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`BR<_2N[3.M<?"O#H@M=K2N[3.M<?"O"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(L"MS='.K-''(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y
M"FUS9VED("),87EO=70B"FUS9W-T<B`BL.;#YL7DUL,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("+`Z+#-Q-LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*(RP@9G5Z
M>GD*;7-G:60@(DQE9G0B"FUS9W-T<B`BU_/2QB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*
M;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(K_5L-?6M2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("+`L\OWS=`B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(K33SK0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`BP/NQR,#OT<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`BP/NQR-''(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(L'0UJ>VV,J_
MM<<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("*UK<"V
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*
M(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`BM<?"O"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED
M("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN
M($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0HC
M+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("*UK<"V(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@
M(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T
M<B`BP/NQR,#OT<<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T
M"FUS9VED("),:6YK(@IM<V=S='(@(L&LO=,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(L&LO=,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S
M='(@(L'0L_8@+2#3P[NGO\G2U+^TM;W5XKCVSL2\_KS0(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI
M<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BP="S]LNUP_>QZLSB(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="!486)L
M97,B"FUS9W-T<B`BLN7(Z['MN/$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@
M(LS6PMO3P[NGU^DMSL2\_KGQ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("+,UL+;
MT\.[I]?I+<?SUOHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("+,UL+;T\.[I]?I+<JV
ML?"ZQ<+K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`BS-;"V]/#NZ?7Z2W3M=/0
MU=\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(LS6PMO3P[NGU^DMO,2\_LC+(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@
M(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(LS6PMO3P[NGU^DMMJG4Q"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),
M:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(LS6PMO3P[NGU^DMR*'/^[:IU,0B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R
M("+!T+/VT\.[I[7$N:;$W+&[N=BQU2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!F86EL960Z("5S(@IM<V=S='(@(L'0L_;3P[NGM<2YIL3<L;NYV+'5(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+!T+/VT\.[I[7$
MN:;$W+&[N=BQU2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I
M9"`B3&ET97)A='5R92(*;7-G<W1R("+.Q-&G(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),:71H=6%N:6$B"FUS9W-T<B`BP:+,U<WP(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PHC+"!F=7IZ>0IM<V=I
M9"`B3&]A9&EN9RXN+B(*;7-G<W1R("+4V,CKNJ_*O;_BUM`N+BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T
M:6UE.B`B"FUS9W-T<B`BM;&UV,JQO.0Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(K78
MQ_C3Z\JQO.0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(K78Q_@B"@HC.B!L;V=I;BYP:'`Z,3<R
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@
M:6XB"FUS9W-T<B`BM<?"O"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(M>BS_HB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(K7'PKPB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),
M;V=I;B!487-K<R(*;7-G<W1R("+!K+W3(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+B(*;7-G<W1R("*UQ\*\RJ>PW"P@Q^N\[++IQ/JUQ-/#NZ?#^[K-P]S"ZRP@
MR+NZ\];8RM0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS
M9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(K7'PKS*I[#<+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@(DQO
M;F<@=&5X="(*;7-G<W1R("+7HL_Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0X"B,L(&9U>GIY"FUS9VED("),;W9E(@IM<V=S='(@(LF^L_TB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K
M(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("+"K,FML:0B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(M3"(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("+#O\C5T,7/
MHB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V
M"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(DU3+51.148@N+V\T\[$O/[6T,.[T]#*_;[=+B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(M;0N?JPQ,/%(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`BPNW&Y+;9N;*ZS;GZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(L+MM.^\T\NYO-.UNB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B
M36%G:6,B"FUS9W-T<B`BPNW`^R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("+3RKS^(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G
M<W1R("+3RKS^N=S`[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R
M("+"[<"MS?XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S
M='(@(L+MP+3.]]''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*
M;7-G<W1R("+"[;;[M/JW\B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*
M;7-G<W1R("+"[<#[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G
M<W1R("+"[;;ZR_LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G
M:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-
M87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G
M:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM
M<V=S='(@(LC]U,(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS
M9W-T<B`BPNW,X<3AO\NUNB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,B"FUS9W-T<B`BL>J\Q[/)(+^TN?TOSK2_M+G](@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM
M<V=S='(@(K'JO,>SR<;DR_RUQ,JVL?`@*,#]R.<N(-;8TJHOTM&[V+BT*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R
M("+"[<G<MOO(NK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E
M(@IM<V=S='(@(L+MS.'$X;_+M;HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(M7]
MU-K&I<7DU]:VSB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*
M;7-G<W1R("+#J\#OR_[$X=''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R
M:71I=7,B"FUS9W-T<B`BPZO`[\?SR[DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO
M=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`BN+V\_LK]Q+_2T;.LL_:]T\K<
MR<_/WBXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(M?NO?P@,C0@T*'*L;7$
MU^ZXW\["ML@Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED
M(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("+7[KW\(#8@T*'*
ML;7$U^ZXW\["ML@Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G
M:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(KW3RMS7[K3SLZ2VR"(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED
M(")-87DB"FUS9W-T<B`BSN74PB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA
M>6]T=&4B"FUS9W-T<B`BPNW4O,S8R+JUNB(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
MT+N^^"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BL\G4L2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BT:&U
MI<2CRKTZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BT\J\_B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B
MT\J\_M'IUJ32T<WJL\DLM:O*Q]/#NZ>UQ,>IP_O(M,[>MZC-J+G]T>G6I"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BT,7/HM+1
MN?W&VBXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS
M9W-T<B`BT,7/HL#@T,TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*(RP@
M9G5Z>GD*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`BM;''L,SLQO@B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A<B#'^+_ISMZWJ,JYT\,N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DUE=&%R(,?XO^G.
MWK>HRKG3PRX@S[B]VL?KLLZ_O,^US;.YW,#MM<?"O"XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO
M="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(K>]MZ@B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]2
M4$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("*WO;>H
M("<E<R<@SK2QN[:HTN4B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N
M($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS
M9VED(")-971R:6,B"FUS9W-T<B`BN:O6QB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B365X:6-O(@IM<V=S='(@(L2KSO>XYR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(L/<
MO\O"WL3ASO?1Q\&JL.ZY^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(L2CO^DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;64@
MP.#0S2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`BU^Z]_"`R-"#0H<JQM<37
M[K7-SL*VR#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@
M(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(M?NO?P@-B#0H<JQ
MM<37[KC?SL*VR#H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S-`IM<V=I9"`B36ER<F]R(@IM<V=S='(@(M.S
MR>0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E
M;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("+%Y-;#SL2\
M_M+%RJ<N(,CGN?O2JLJYT\/5XKCVTZ;3P[/,T/+$^K'8T.O/UM3:OLVR^LGZ
MR_LN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@
M(M72LKNUO=#%SZ*UQ"!)1"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED
M(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(M72LKNUO;OAQMJUQ"!)
M1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4V"FUS9VED(")-;R(*;7-G<W1R("+0Q\;:TKLB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@
M(M#0MJ_3RKS^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(L/)
MS-C(^\"MS-@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I
M9"`B36]D:69I960@1&%T92(*;7-G<W1R("*X_-#"R-7&VB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM
M<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R
M("+$H[_I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI
M8R!O9B(*;7-G<W1R("+$IK;[MN#-WR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]N86-O(@IM<V=S='(@(L2FQ,FXYR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36]N9V]L:6$B"FUS9W-T<B`BP\FYQ2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(M3"
MNLW$ZB(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BP[_4PB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("+#R<S8R/O`K<S8(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("+4PL'!TZ^_]R(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L
M9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(L2FPN6XYR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO
M<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("+/PM+&(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE
M9G0B"FUS9W-T<B`BU_/2QB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("+3TM+&
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(LG/TL8B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB
M"FUS9W-T<B`BS\+2QB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("+)S]+&(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(L2JR:.Q
MR+_+(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`HC+"!F=7IZ
M>0IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(L_"P*VRR[6E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT
M:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BN+31H2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B
MSM*UQ-7+NL4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z
M>GD*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BQ/JU
MQ-#%SZ(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED
M(")->2!0;W)T86PB"FUS9W-T<B`BSM*UQ,/%NZ<B"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM
M<V=S='(@(L[2M<3#Q;NGTK/#YL7DUL,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUY86YM87(B"FUS9W-T<B`BP^6UZ2(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@
M06=R964B"FUS9W-T<B`BLKLLSM*RN\VLTN(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+#^[/&(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(L3)P]>QR-''(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("+HI\*S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("+$X;*TMOLB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(KK)P+PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T
M<B`BNLG*]+"RM=C!T,NY(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@
M(KOYT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`BN_G3VDYE='-C87!E(+7$S?C6MR(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"B,L(&9U
M>GIY"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(KOY
MT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-`HC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A
M;"!54DPB"FUS9W-T<B`BN_G3VDYE='-C87!E(+7$S?C6MR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"B,L(&9U>GIY"FUS9VED
M(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("*[^=/:3F5T<V-A
M<&4@M<3-^-:W(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R
M(").971S8V%P92!34TP@M_[.\<;WP_NSQB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I
M8V%T92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E(,C/UJ2UQ,7ZUZ(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92#(
MS]:DP.#0S2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G
M:60@(DYE='=O<FLB"FUS9W-T<B`BS?C"YR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(K33SK0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N
M:6$B"FUS9W-T<B`BT,*_IL#OMN#$X=''(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!#871E9V]R>2(*;7-G<W1R("+0PK^FP.^VX,3AT<<B"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*
M;7-G<W1R("+0Q<^BP.#0S2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM
M<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`BT,+4PB(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H
M;W!T:6]N86PI(@IM<V=S='(@(M#"T\.[I\/[("BWQ['8TJHI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("+0PL[WP+PB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G
M:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+#W,+K(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM<V=I
M9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`BP]S"Z['8
MT.O.Q[K/+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B
MT,*TL+_:("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`BT,+.Q2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*(RP@9G5Z>GD*;7-G:60@(DYE
M=W-G<F]U<',B"FUS9W-T<B`BT\.[I]?I(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`BS\+2N[*]
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").
M97AT(#0@4&AA<V5S(@IM<V=S='(@(L_"TKO2LR(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`BS\+2N[CV
MT:'/[B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"B,L(&9U
M>GIY"FUS9VED(").97AT/B(*;7-G<W1R("+/PM*[LKTB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("+$X;S3P*VYSR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`BQ.'(U;;[(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(L3AR-7`^]''(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B
M"FUS9W-T<B`BS>W)SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G
M<W1R("+%IK"CM;HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.38S"B,L(&9U>GIY"FUS9VED(").;R(*;7-G<W1R("+.WB(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B
M3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E
M<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S
M=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(LOYUKBVJ+7$SKO6
MP\G/P[O3T,?XO^FTYM3:(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3T,SAN:G(U<#ZP_NS
MQM+4N:D@34-!3"#1Z=:D+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T
M"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(LZTL>2X_"XB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@HC+"!F=7IZ
M>0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`BM;''L,OYM*:UQ-7BN/:UR+RVSMZWJ-3VO-.T
MSLBHS]XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S<S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B
MP[O3T-:XMJBUQ"`E<R#%Y-;#T,7/HBXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(L.[T]#6N+:H
MM<0@1E10(%9&4R#%Y-;#T,7/HBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(L.[T]#6N+:HM<0@
M4U%,(%9&4\7DUL/0Q<^B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(L.[T]#6
MN+:HM<0@4U%,+49I;&4@5D93Q>36P]#%SZ(N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C
M<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*(RP@9G5Z>GD*;7-G:60@(DYO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("+#N]/0P^C*]B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R("+.Q+S^SK3)S[2K(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(").;R!I8V]N<R!F
M;W5N9"XB"FUS9W-T<B`BP[O3T,/HRO8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@
M<V5T+B(*;7-G<W1R("+.N];#T,7/HLG0SK3%Y-;#(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(LZ[UL/0Q<^BR=#.M,7DUL,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T
M<B`BT,7/HM+1N?W&VBXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S
M<&5C:69I960N(@IM<V=S='(@(LZTUKBVJ+6QM=C3[]'4+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"B,L(&9U
M>GIY"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("+.M-:X
MMJBUL;78T^_1U"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G
M:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
MP[O3T-:XMJC#W,+KTM2YJ2!(5%10(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBV
MJ,/<PNO2U+FI($E-05`@T>G6I"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6N+:HP]S"
MZ]+4N:D@2V5R8F5R;W,@T>G6I"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("+#N]/0UKBVJ,/<PNO2U+FI($QO9VEN(-'IUJ0N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`BP[O3T-:XMJC#W,+KTM2YJ2!005-35T0@T>G6I"XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[
MT]#6N+:HP]S"Z]+4N:D@4TU"(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(L.[T]"T
M_<GSM<37HK+AR>K'ZRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(LZ[UL/0Q<^BR=#.M,7DUL,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED
M(").;R!R=6QE<R(*;7-G<W1R("*_U;#7UK4B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O
M<B!S<&5C:69I960N(@IM<V=S='(@(LZTUKBVJ+6QM=C3[]'4+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*
M(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(K&XS?S"O"(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H
M(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R("+.WM3=M.;$O\*\O\FYJ;_LR*$N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*
M(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S
M96YT+B(*;7-G<W1R("+.M-:JM<33P[NGP_N[\L/<PNLN(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D(@IM<V=S='(@(L.[T]"ZS[>HM<0@6$U,(,K]OMVQ
MN[2KN]@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(K_5L-?6M2(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+4K<J\Q>36P\[$O/[6T-72LKNUO;#FL;[0
MQ<^B+B#6V-#"LOK)^L7DUL/.Q+S^+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(M3:Q/JUQ,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@UMC0PK+ZR?K%Y-;#
MSL2\_BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"FUS9VED(").;VYE(@IM<V=S='(@(L[>(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM
M<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`BR-6V^L+\
MSL0@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L
M:R!)<VQA;F0B"FUS9W-T<B`BQ;6XH[_+M;HB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(K&QL.O'\B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(K&QPNW`
M[]''Q,G(NK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T
M<B`BQ;+-_B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`BM\?6KKKS(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"
M969O<F4B"FUS9W-T<B`BM\?6KL>P(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
MLKO*Q]*[N/;$O\*\(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`BR=#.M,JUS]8N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R("*QN,W\PKPB"@HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`BSK2QN]:GL]8B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*
M;7-G:60@(DYO=&5S(@IM<V=S='(@(K&XS?S"O"(*"B,Z('-E<G9I8V5S+V]B
M<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("+*
MKM*[U,(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED
M(").=6UB97(B"FUS9W-T<B`BROW7UB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(M?6M_O*_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R
M("+7UK;.ROW$OR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("*Q
MRLK](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T
M<B`BUO?6O"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("*VU,_SO:C!HM7?(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS
M9W-T<B`BL,N]^,Z[(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BRJ[4PB(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(K#LN:O*TB(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L
M9"!P87-S=V]R9"(*;7-G<W1R("+#W,+K(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R("*PHL+\(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(M:[T]`@24U!4""W_L[QQO?6I[/6
MSL2\_KS0N;+/[;FFQ-PN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU
M"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@
M86QL;W=E9"XB"FUS9W-T<B`BUKN]T\K<TKNX]M/*O/ZUV-:W+B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS
M9W-T<B`BUKO3T-.UT]#5W]/KS[7-L[G<P.W4L;_)TM2QY+C\N;+/[<BHS]XB
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`BU-K0PK2PO]K6T+3ROZHB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"B,L(&9U>GIY"FUS9VED
M(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(M3:
MT,*TL+_:UM"T\K^J(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS
M9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T
M<B`BT:'/[B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS
M(&9O<B`E<R(*;7-G<W1R("(E<R"UQ-&AS^XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI
M<W0B"FUS9W-T<B`BS^[$O['@NL4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@
M(M?IUJ\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("+7Z=:OM:7.
MNR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*
M;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`BU^G6KR(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R("+4K<J\TZ;3P[/,T/+$H[#F(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("+4VB`E<SH@UM"UQ-2MRKS$
MH[#F+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("+&
MY,O\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H
M97(@26YF;W)M871I;VXB"FUS9W-T<B`BQN3+_-#%SZ(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R("+3M=/0U=_(J,_>(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B4$%-(-'IUJ3.WM"G+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B
M4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I
M9VYA='5R92(*;7-G<W1R(")01U`@ROW7UL>IP_LB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B4$=0(+S3P]S7RL'/(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B4$=0(+FKOZK#W-2_(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")01U`@TM''J</[+]+1O-/#W"#7RL'/(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")0
M2%`@L\S0\K3ZPNLB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@
M(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@O<6QOB(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!2
M86EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM
M<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,30Y"B,L(&9U>GIY"FUS9VED(")07TA0(%-H96QL
M(@IM<V=S='(@(E!(4""]Q;&^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@
M(K#-N_G+N<RY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T
M<B`BQ<'`S2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`BL,W`U<NYS+FQN]6\P>S'^"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(K#-Q,/"[2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R
M("*PS;*\T<?0PKRXQ-K1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G
M=6%Y(@IM<V=S='(@(K#-P*VYYR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(L/<PNLB"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("+#W,+K.B`B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R
M97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#
MN]/0UKBVJ,/<PNO2U+FI(%)!1$E54R#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N(@IM<V=S='(@(L/<PNO(M\C/(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`BP]S"
MZSHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B
M4&%S<W=O<F0Z("(*;7-G<W1R("+#W,+K.B`B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@
M;75S="!M871C:"XB"FUS9W-T<B`BP]S"Z['8T.O.Q[K/+B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("+,
M^<G/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`BS/G)
MSR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`BPK>^MB(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM
M<V=S='(@(K3]R?.UQ\*\H[HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R("*]Q\FK(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G
M:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+6M-#0SJR[I++9U_<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(K7'PKRZ\]:T
MT-#.K+NDLMG7]S\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+(J,_>(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@
M(B<E<R<@M<3(J,_>SK2QN\F^L_TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU.#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@
M(K3FR*'4XK[<(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E
M<FUI<W-I;VYS(@IM<V=S='(@(LBHS]XB"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+(
MJ,_>N=S`[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B
M4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BSM*UQ"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("+#V,*S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")0971S(@IM<V=S='(@
M(M>HL+@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S
M='(@(K?&PLFQ]B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(K7GN[`B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS
M9W-T<B`BU=7&K"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM
M<V=S='(@(L:DS-B_M;6Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BQ^O*Y,CKTKNX]M3"
MM]V\L,3JM]TN(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(L?KRN3(Z]*[N/;4
MPK?=O+#$ZK?=+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N(@IM<V=S='(@(L?KRN3(Z[K/MZBUQ,JQO.0N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"XB"FUS9W-T<B`BQ^O*Y,CKTKNX]KK/MZBUQ,C5QMH[T:'4\;3+U,*WW;7$
MR-7&VBXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("+'Z\KDR.NZ
MS[>HM<3*L;SD+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2XB"FUS9W-T<B`BQ^O,X;FISLK,XK7$U:K2JBXB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D(@IM<V=S='(@(L?KRN3(Z\3ZM<33P[NGP_N\L,/<PNLB"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(L?KU,2VP<_"P=#$VLC=+L3ZL=C0Z\VLTN+5XM"IRL+/[K+%Q-S*
MN=/#S[7-LRXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E
M9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O
M;&%N9"(*;7-G<W1R("*RJ,"\(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4W"B,L(&9U>GIY"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("+-ML:Q(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B
M"FUS9W-T<B`BS;;&L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L
M(@IM<V=S='(@(L;/S-'1P"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(K7=R\W3
MRKS^M;W5XKCVSL2\_KS0("AN;W0@96YF;W)C960@8GD@24U!4"DB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ("(*;7-G<W1R("+7[KW\("5S(-"ARK&UQ+VUT^K!OSH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B4')E9G-?;&1A<#H@U=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BXB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G
M:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@U=*RN[6]R_G0
MZ-*JM<0@<V5S<VEO;B#`J=6YU^F\_BXB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`BQOC1N2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@
M;&5V96PZ("(*;7-G<W1R("*ZH\:]P^;&^-&Y.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S
M='(@(L;XT;DZ("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@
M(M2DP,`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+4VM#"M+"_VM;0M/*_
MJB(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O
M<'1I;VYS(@IM<V=S='(@(LG/TKNX]M&AS^XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(LN]P]S#W-2_
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F
M=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("+.RLSB/R(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO
M;B(*;7-G<W1R("+.RLSBP^C*]B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(M>HL+@B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM
M<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`BS.'*OL3:R-TB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+
M97DB"FUS9W-T<B`BN:N_JL/<U+\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB
M"FUS9W-T<B`BN:N_JL/<U+_1W<OC(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#0*(RP@9G5Z>GD*;7-G:60@(E!U8FQI8R!+97D@
M26YF;R(*;7-G<W1R("*YJ[^JP]S4OR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I
M<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BN:N_JB_+
MO</<P]S4O[;4LJ+.M+&[LOK)^BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0
M=65R=&\@4FEC;R(*;7-G<W1R("*RJ+;@P.BX]R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E%A=&%R(@IM<V=S='(@(K^HR_ZV^R(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B475E<GDB"FUS9W-T<B`BROV^
MW;_BLNG1KR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!F=7IZ
M>0IM<V=I9"`B475O=&$B"FUS9W-T<B`BOZC+_K;[(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!(+FKOZK#
MW-2_("@E9"#.NRDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T
M"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`BM:71H2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"B,L(&9U>GIY
M"FUS9VED(")286EN(@IM<V=S='(@(E-P86EN("C.][#@T<`I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A
M:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E)A:6X@3&%T92(*
M;7-G<W1R("+*I<*LSO?1Q[6Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W
M"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*
M(RP@9G5Z>GD*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(LOCP_PB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A
M=&EO(@IM<V=S='(@(K'(PLHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("*VP<BA(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@
M(E)E860@;65S<V%G97,B"FUS9W-T<B`BML'(H=/*O/XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`BU>:UQ-*JR;ZS_2`E<R#"\#\@U>+/[K+9U_>]
MJ\[>MZB[UKBT+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`BU>:UQ-*JR;ZS_2`E<R#"\#\@U>+/[K+9
MU_>]J\[>MZB[UKBT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(LBAS_NXM-2M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I
M9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@
M4&]R=&%L(%9I97<Z(@IM<V=S='(@(LNBT,+#Q;NGRM/-O#HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED
M(")296=E>"(*;7-G<W1R("*YYM3RL>VT[\J](@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(K;!R*$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("+&P,+;(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B
M"FUS9W-T<B`BU+:SS+?^SO'&]R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(M2VL\S-^-:W("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("+)OK/](@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB
M"FUS9W-T<B`BR;ZS_<?XO^DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L
M=6UN(@IM<V=S='(@(LF^L_W3P[NG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&9O<FUA='1I;F<B"FUS9W-T<B`BR;ZS_;;4(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@
M(LF^L_VVU"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@
M(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(*;7-G<W1R("+7U+?^SO'&]]3=M.;$O\*\UM#)OK/]TM&Q
MH[3FM<3%Y-;#L\S0\BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V
M92!T:&4B"FUS9W-T<B`BR;ZS_=/#NZ<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`BR;ZS_=/#NZ<B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M
M;W9E('5S97(Z("5S(@IM<V=S='(@(LF^L_W3P[NG.B`E<R(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G
M<W1R("+0Z,?SSK2QN\_LTZ8Z(+3MSO.ZQ<+K.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`BR<^TJ\[$
MO/ZRHLZTL;NQH[3F+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E,B1S(+7$Q>36P['8
MT.O6N+:H("<E,21S)R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@M<3%Y-;#L=C0Z]:XMJ@@
M)R5S)R(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ>36P\K]OMVQV-#K
MUKBVJ"`G)7,G(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`BUMC)
MZ"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY
M"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("+#W,+K(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E)E
M<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BR+?(S\/<PNLB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")297-T;W)E($QA
M<W0@475E<GDB"FUS9W-T<B`BS\+/TM3"(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`BO>&Y^R(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`BM[6[
MV-&AS^XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*(RP@
M9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`BT:'4
M\</<PNLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@
M(E)E=6YI;VX@*,'TQ.'-^K6Z*2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`HC+"!F=7IZ>0IM<V=I
M9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`BLOK)^B`E<R"UQ,^U
MS;/%Y-;#(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F=7IZ
M>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(K>U
MN]C1H<_N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2
M:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`BS>W)SR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$W"B,L(&9U>GIY"FUS9VED(")2:6=H="!V
M86QU97,B"FUS9W-T<B`BM:W`MB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`BO<?)
MJR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]M
M86YI82`HPM["[<3AT<<I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("+0
M_=>J(#$X,""VR"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(L_RU_/0
M_=>J(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(L_RT]+0_=>J(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM
M<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(KW'R:LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("+6M-#0(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<W-I86X@
M1F5D97)A=&EO;B`HMNW"WLNY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W
M86YD82(*;7-G<W1R(")2=V%N9&$@*,*LL+*T[RDB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12"\T\/<QZG#^R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED
M(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`BT\J\_M+1RKG3
MPR!3+TU)344@O-/#W"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B4T%33"#1Z=:DSM[0IRXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S
M='(@(M#%SZ(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-1
M3"!3:&5L;"(*;7-G<W1R("+*_;[=O^*]Q;&^(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L
M=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`BO-/#W-;5MLN[^B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BL\FYIB(*
M"B,Z(&QI8B]A<&DN<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B4U]13"!3:&5L
M;"(*;7-G<W1R("+*_;[=O^*]Q;&^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`BT,?&
MVL'Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S
M='(@(LJENM7`U<3#M;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI
M='1S(&%N9"!.979I<R(*;7-G<W1R("+*I;OYM<*ZS<'0SJS+N2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`BRJ7"K,[WT<>U
MNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`BRJ7&I+"CMONZS<+SO\O"U\BZM;HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<R(*;7-G<W1R("+*I<[$R:W,V+K-N/'!UL3)M.\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`BS:S2N[CVM+"_VB`H7W-E;&8I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`BR/C$IM''(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("+*I<+MP:;%
MM2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP
M92(*;7-G<W1R("+*I;;@P\"ZS<;5P=;.]['((@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R
M(@IM<V=S='(@(L[`T,?,X;FIU=\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3
M875D:2!!<F%B:6$B"FUS9W-T<B`BR;/,V+"BP*VRKB(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("*Q
MH[3F(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T
M<B`BL:.TYB`E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`BL:.TYB`E
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@
M3W!T:6]N<R(*;7-G<W1R("*QH[3FT:'/[B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`BO:NR^LGZM<3%Y-;#SL2\_M+4
M(%!(4"#3[]'4N/'*O;&CM.:UO<3ZM<2W_L[QQO?4W;3FQ+_"O-;0+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L7DUL,@)7,@
MTM&QH[3F+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("*X_-#"L\S0\M+1L:.TYK6].B`G
M)7,G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`BR]'1L"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(LO1
MT;`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`BT:'4\=*[N/;(U<;:(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+1H=3QTKNX]LC5QMHB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T
M(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(M&AU/'2N[CVT\.[I]?IT\/2U-#"
MU/8B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")3
M96QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`BT:'4\=*[SKO0PK7$T[73T-7?
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")3
M96QE8W0@82!S97)V97(B"FUS9W-T<B`BT:'4\=*[LK^W_L[QQO<B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@
M=7-E<B!T;R!A9&0B"FUS9W-T<B`BT:'4\=*[SKO3P[NGT\/2U-#"U/8B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(M&AU/'2N[CVR-7&
MVB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("+1H=3QR_G3T,C5
MQMK7Z;S^+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-S,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS
M9W-T<B`BT:'4\=*[SKO0PK7$T[73T-7?(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&YO;F4B"FUS9W-T<B`BT:'4\=*[SKO0PK7$T[73T-7?(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82XB"FUS9W-T<B`BT]K2U,_"M<2TL+_:UM#1H<BAQ/K2JK7$U]:W^R[2
MU,KSL>JXM-;&R_G1H<[$U]8LR+NZ\\SYR<_.Q+S^L>"\K<?X+B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+1H=3QR-7&VK?6N/0Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(M&AU/'(U<;:R-7&VKCQRKTZ(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("+1H=3QRK&\Y+?6N/0Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C
M="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(M&AU/'(U<;:RK&\Y+CQRKTZ
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(M&AU/'/X+NEQJ7%
MY+7$MOZX]M?6MLXN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM
M<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("+1H=3Q
MQ/JUQ-'5R:O%Y-;#(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM
M<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R
M("+1H=3QQJNZP]/OT=0Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B
MM*O+S<[*S.*WM-.F(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"`H
MR/O$VKS3MOLI(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@
M(E-E;G-O<CH@(@IM<V=S='(@(K2KN-#&]SH@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*
M;7-G<W1R("*^Q=3"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R
M(")397)B:6$@86YD($UO;G1E;F5G<F\@*,C[MOO.K-''T^O#R<S8Q.&XY\+>
M*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS
M9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(M#RNL4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A
M<B#'^+_ISMZWJ,JYT\,N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L
M(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(LBHS]ZYW,#M
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(KOA
MQMH@240@TM&Y_<;:+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM
M<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`BR*C/WB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("+%Y-;#(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R
M("+%Y-;#U+:SS+?^SO'&]\G/RO33VL3ZM<2X]LC+U;[,J"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T
M<B`BQ>36P\3ZM<3&J[K#T^_1U"P@RK''^-+4O+#(U<;:N/'*O2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("+%
MY-;#Q/JUQ,;TRKS3IM/#L\S0\BS1U<FKQ>36PRS2L\/FN/S0PL:UPLHLO+#&
MY,O\S]3*OM&AS^XN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC
M+"!F=7IZ>0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`BQ>36PR(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"B,L(&9U>GIY"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(KC\
MT,*SS-#RTM&QH[3FM;TZ("<E<R<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB
M;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`BT]"ZP[RXN/:UV+7C
MNLW5XKCVLL[*_=/0N=@Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H
M96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<R`HR/O.]+;[*2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM<V=S
M='(@(KFZSN\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("*\\K;,U:K2JB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E
M<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("+*
MQ[?QSJJT\[*_M]VUQ,&LO=.VJ-+EO^R]W;FFQ-R\_#\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G
M<W1R("+/U,J^(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I
M9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(L._M,ZUQ\*\NO//U,J^R<_2N[3.M<2UQ\*\RK&\Y"`_(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("+/
MU,J^M>/1H<;W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I
M9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@
M(M/:U_.QW\_4RKX@)7,@LLNUI3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(L[$O/[)S[2K(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(E-H;W=E<G,B"FUS9W-T<B`BS]3*OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")3:&]W97)S
M($5A<FQY(@IM<V=S='(@(KSRMLS5JM*J(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`BRM7+]2(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(E-I97)R82!,96]N92`HRJC7T\F]N?HI(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U
M<"(*;7-G<W1R("+7HK+A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+'J</[(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@
M(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`BQZG#^]'=R^,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E
M("C0PKS3QL(I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R("*T\]"A(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E
M;F%N8V4B"FUS9W-T<B`BPM2Y_<ZLNZ0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3;&]V86MI82(*;7-G<W1R(")3;&]V86MI82`HR[G"Y;>EO\LI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=F5N:6$@
M*,NYPN6WI<3AT<<I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T<B`BS]3*
MOB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U
M"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS
M9W-T<B`BN_W1J<GNML@Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R
M"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T
M<B`B4V]L;VUO;B!)<VQA;F1S("C+]\+>P\7(NK6Z*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI82`HR_?"[<#[T<<I
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F
M(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(L7%
MP="WO<_RT:'4\2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM
M<V=S='(@(L"TU+2UV-:W(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@
M069R:6-A(@IM<V=S='(@(E-O=71H($%F<FEC82`HQ,^WQRDB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I(@IM<V=S='(@(L3/Q;<@*$E33RTX.#4Y+3,I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<R(*;7-G<W1R(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`BQ,^PZ\?R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"B,L(&9U>GIY"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`BP*R[^-/*O/XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(RP@9G5Z>GD*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B4W!A:6X@*,[WL.#1P"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS
M9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")3<&%I;B`HSO>PX-'`*2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G
M<W1R("+`K+OXT\J\_B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM
M<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`BS-C*XM?6
MM_O*Y,CK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I
M9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(M:GL]8B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@
M3&%N:V$@*,NYP._`O+^H*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R("*QZM>\(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R
M"B,L(&9U>GIY"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`BQO3*O,3JM]TB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B
MQO3*O,3JM]TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BRJ$B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B
M4W1A='5S(@IM<V=S='(@(M>TS*PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("*QH[3F
MN/'*O2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R
M"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R("*]UK7`(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B
M4W1R:6ME=&AR;W5G:"(*;7-G<W1R("+)OK/]S]\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R
M("+7UK?[M*[!T"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@
M(E-U(@IM<V=S='(@(M#'QMK,["(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2`E<RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED
M(")3=6)J96-T(@IM<V=S='(@(M;WUKPB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`BS.&]NR(*"B,Z('-I9VYU<"YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E
M<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L
M;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BS\*QZB(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM
M<V=I9"`B4W5C8V5S<R(*;7-G<W1R("*SR;FF(@H*(SH@861M:6XO=7-E<BYP
M:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`BL\FYIKS3
MR.L@)R5S)R"UO<^US;/6T"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`BL\FYIM?4S[7-L];0R;ZS_2`G)7,G("XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB
M"FUS9W-T<B`BL\FYILF^L_T@)R5S)R`N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("*SR;FF
MU]3/M<VSUM#)OK/]("<E<R<@+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HU-PHC+"!F=7IZ>0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+%Y-;#("5S(-+1L:.TYBXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D
M871E9"!<(B5S7"(B"FUS9W-T<B`BL\FYIKC\T,(@)R5S)R(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*
M;7-G<W1R("+2T;/)N::XLKC'("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W5D86XB"FUS9W-T<B`B4W5D86X@*,O5M:0I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M
M;6%R>2(*;7-G<W1R("+5JM*J(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("+(U;/V(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(LC5
MPN0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.0HC+"!F=7IZ>0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4W5D86X@*,O5M:0I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B
M4W5N<FES92(*;7-G<W1R("+(U;/V(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E
M+U-U;G-E="(*;7-G<W1R("+(U;/V+\C5PN0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B
MR-6S]CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM
M<V=I9"`B4W5N<V5T(@IM<V=S='(@(LC5PN0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R("+(
MU<+D.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("+)S['J(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I9"`B4W5P<&]R="(*
M;7-G<W1R("+6I[/6(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B
M"FUS9W-T<B`B4W5R:6YA;64@*,O5P/O$SRDB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B4W5R;F%M92(*;7-G<W1R
M("*TPKK%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA
M;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W87II;&%N
M9"`HRK?-W[S#P+PI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM
M<V=S='(@(E-W961E;B`HR/"UY"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I
M='IE<FQA;F0B"FUS9W-T<B`B4W=I='IE<FQA;F0@*,CPRK\I(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(E-Y
M;F,@;&]G(&1E;&5T960B"FUS9W-T<B`BLKO)OK/](@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3
M>7)I86X@07)A8B!297!U8FQI8R`HT/#`^]''*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@HC+"!F
M=7IZ>0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`BM+#,Y2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T
M;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")404(@M]:X
M]+CQRKW.Q+S^(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1E86PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE
M(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A
M;B(*;7-G<W1R("+,J,WE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`BS*C-Y2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T
M86XB"FUS9W-T<B`B5&%J:6MI<W1A;B`HR_Z\JLNYS+DI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G
M<W1R(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F("C,N<G0Q.'1QRDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"FUS9VED(")487)G970Z(@IM<V=S='(@(L2_L>HZ(@H*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W
M"FUS9VED(")487-K<R(*;7-G<W1R("*T_;#LRL+/[B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(K7GN["ZQ<+K(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(M?NO?S2N]"ARK&UQ,["ML@Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("+.PK;((@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R("+.PK;(.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E
M/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(M72LKNUO<2CL.8@)R5S)RXB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`BQ*.PYKG<P.TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B
M"FUS9W-T<B`BQ-K(W2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*
M;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("*TO\[$U]8B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"B,L(&9U
M>GIY"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(K2_SL37UB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*(RP@9G5Z
M>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`BQ-K(W2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM
M<V=S='(@(M#'QMK+Q"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS
M9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("+,J<[$("A425,M-C(P*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EL
M86YD("C,J;GZ*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM
M<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R
M("+0N]"[Q/K*N=/#L;[/M<VS+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")&5%`@T=/)["AE>'1E;G-I;VXISM[0IRXB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*(RP@9G5Z>GD*;7-G:60@
M(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S
M='(@(LG/M*O.Q+S^LJ+.M+&[L:.TYBXB"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I
M9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N8V4@
MP."Q\+*BSK2SR;FFU-C(ZR(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO
M<V5D+B!%>&ET:6YG+B(*;7-G<W1R("+1H<_NM+"_VM+4N=BQU2[`Z[^JUM`N
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M
M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"B,L
M(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("+-J-&VROV^W=+1
ML\FYIK7$U/:\T[6]Q/JUQ,VHT;:ROM;0+M/#RO.QZK"TS\+!T,_NQ+_2U+SL
MRM,Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM
M<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`BT>G6I-/*O/['J</[T.C2JM/0TKNX]M+1O>*_JK7$(%!'4"#'^+_I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B
M"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"B,L(&9U>GIY"FUS
M9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M(@IM<V=S='(@(K3+U_?3P\ZTL;O6I[/6+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E
M<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("+0
MZ-*JTKNX]KZMN?V\T\/<M<3-^,+GP:R]TRXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(L[$O/X@)7,@TZ:XP[#\NJS2
MN[CV("5S(,7DUL,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RXB"FUS9W-T<B`BSL2\_B`E<R#3IKC#L/RZK-*[T*D@)7,@Q>36
MPRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*(RP@9G5Z
M>GD*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+B(*;7-G<W1R("*TR\[$O/[6T,.[T]#*_;[=+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(K3+SL2\_M;0P[O3T,K]OMTN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`BTM3/PLK'(')F8S@R,B#3RKS^
MM<2Q[<VW+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P
M<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R
M965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.CDP"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(K3+M_[.\<;W(%PB
M)7-<(B#2T;&[R;ZS_2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU
M4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L
M87-S+B(*;7-G<W1R(")';G501R"V_M2JSL2\_K7$PK>^MK'8T.NVJ-+EU-H@
M0W)Y<'1?<&=P.CH@P."Q\-;0+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B
M965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED
M(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(K'8T.O*Q]*[N/;*_=?6+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&]R9&5?0W)Y<'1?<VUI
M;64Z.B#`X+'P++'8T.C2JM/0(&]P96YS<VP@Q*._Z2XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A
M8FQE('-I>F4B"FUS9W-T<B`BM,O&J[K#(%PB)7-<(B#*_;[=TO+.JK.LN?W7
M[K3SO=/*W-:U+,OYTM3.WK>HL;NQH[3F(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("+3
MP]+4O.S*T[3+ROV^W<#@T,T@*"5S*2"UQ+/,T/*RHK*[M.;4VM/:S[7-L\G/
M+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B
M5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE
M9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(K3+M_[.\<;W(%PB)7-<(B#2T;&[R;ZS_2XB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`BM,NW_L[QQO<@
M7"(E<UPB(-+1L;NQH[3F+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B5S(+7$UZ*RX=#HQ_/2T;&[R;ZS
M_2XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*
M;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("+6N+:HM<2\Q\*\LJ*RN[3FU-HN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HQ-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(M:XMJBUQ+S'PKRRHK*[M.;4VBXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B
M5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S
M('-T97`N(@IM<V=S='(@(K33R<_2N[CVLKW6Z-:NNO/)S[2KM<3*_;[=TL7*
MIRXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`BR<^TJ\[$O/ZR
MHLZTL;NQH[3F+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B=V5A=&AE<BYC;VT@Q_B_Z<[>MZC*N=/#
M+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R("+5TK*[M;W$H[#F("<E<R<N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B365T87(@Q_B_
MZ<[>MZC*N=/#+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(L[>N+V\_K_)UK&]T[3ROZHN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`BM,O7
MUK;.UM"P_+JLS*NVX+7$U];*_2[$^M+1RN3(ZR`E<R"X]M?6ROT[Q/K*Y,CK
MM<37ULK]L=C0Z]"AT]H@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U
M<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S
M(@IM<V=S='(@(M#"U/8@)R5S)R"UO<^US;,Z("5S(,JQMZ+)^M*[N/;.RLSB
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("+7U,^U
MS;/)OK/]("<E<R<@RK&WHLGZTKNX]L[*S.(Z(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("+7U,^US;/)OK/]("<E<R<@RK&WHLGZTKNX]L[*S.(Z(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS
M9W-T<B`BN/S0PB`G)7,G.B`E<R#*L;>BR?K2N[CVSLK,XB(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(LG/M*O.Q+S^RK&WHLGZ
MTKNX]L[*S.(Z("5S(,ZTL;O)S[2K+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H
M)60@8GET97,I+B(*;7-G<W1R("+)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB.B`E
M<R"T\]"ALZRY_;W3RMS7[K3SUK4@*"5D(&)Y=&5S*2XB"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T
M<B`BR<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@O?:RO[?6M<0@)7,@SL2\_K&[
MR<^TJRXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("*\[,K3T\J\_LJQMZ+)^M*[N/:T
M[<[S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O
M;G1A8W0@9&%T82XB"FUS9W-T<B`BN^/(Z[3+S:C1MK*^ROV^W<JQMZ+)^K3M
MSO,N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`BN^/(Z[3+S:C1MK*^ROV^W<JQMZ+)
M^K3MSO,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O
M<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N
M(@IM<V=S='(@(M3:Q>36P[2PS.76T+>BR?K!R]*[N/:T[<[S+M/0O\G$W,3Z
MTL7"J<'+L=C0Z\SNT+2UQ-?6MLXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B
M;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(KOCR.NTR\VHT;:ROLK]OMW*L;>BR?JT
M[<[S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(R"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("*[X\CKM,O-J-&VLK[*_;[=RK&WHLGZM.W.
M\RXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(K3+($E-05`@M_[.\<;WLJ+.M-:G
ML];.Q+S^O-"WUL_MN:;$W"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("+5XLO&NO6RN\K'
MU?W(M[7$(')A<B#1N<OUSL2\_BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("+5XLO&NO6RN\K'
MU?W(M[7$('II<"#1N<OUSL2\_BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BU>++QKKULKO*Q]7]R+>UQ-#%
MT\._J+K%PNLN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z
M+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@
M;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*
M(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M(@IM<V=S='(@(K3+U]:VSLK'L=C0Z-*JM<0N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("*TR]?6ML[$VLC=UKN]T\K<U?O*
M_<K]U]8N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BXB"FUS9W-T<B`BM,O7UK;.Q-K(W=:[O=/*W,K]U]:\L,.PNL4N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T
M<B`BM,O7UK;.Q-K(W=:[O=/*W+#+O?C6QLK]UK4N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B
M"FUS9W-T<B`BM,O7UK;.Q-K(W;'8T.O.JK:ZNL6[\K_5L->WUKCTM<3*_=?6
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(K'8T.O*
MQ]*[N/;*_=?6+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*
M;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S
M-&%F)RXB"FUS9W-T<B`BM,O7UK;.Q-K(W;'8T.NP_+JLTKO7Z<JNP?F]^-;&
MM<0@4D="(-'5R:NT^L+K+,#]R.<@)R,Q,C,T868G+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E
M861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("+5XKCVM+#,Y=+1L;NTIL#M
MN?TN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`BU>+*QR`E<RXB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*
M(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(K3+ROW6M=?NR=FQV-#K
MRL<@,2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP
M:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("*TR[?^SO'&]\[>MZBVU"!Z:7`@
MO+`@9WII<""X\<J]SL2\_KWXT-"]XM&YR_4B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("*TR\^US;.UL<>P
MRL?-H]/#M<37M,RL+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM
M<V=S='(@(K'8T.O*Q]*[N/;*_=?6+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@
M8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`BM,NTL+_:
ML=C0Z]*JT\G1H<_NM+"_VBA/<'1I;VXIR_FZ]+W0(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`HC
M+"!F=7IZ>0IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("*_S;NGN:37][6E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`BRK&\Y"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@
M5')A8VMI;F<B"FUS9W-T<B`BRK&\Y->WU]DB"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(LJQO.2X\<J]
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM
M92!S96QE8W1I;VXB"FUS9W-T<B`BRK''^-&AU/$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(K'J
MS.(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(LK5O/[(RR(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*
M(LCGN?O2JKBTT:$LQ^O4VK7CT:'*\['JM<3-K,JQL+0@0V]N=')O;+S\*+CV
MR,N\QLOCN_HI(+OR($-O;6UA;F2\_"C&N[G[O,;+XR(*(KOZ*2XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*
M;7-G<W1R("*]\<SL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(DA434P@U*W*O,[$O/XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O
M(@IM<V=S='(@(K;@N.<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U
M(@IM<V=S='(@(LW0O\O`S<BZM;HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("+#]\SL(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`BS,"\TR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PHC+"!F=7IZ>0IM<V=I9"`B5&]P(@IM<V=S='(@(LK5O/[(RR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@
M(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS
M9W-T<B`BU^G6KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`BS-C!HL3AM.^ZS;;@L,VXYR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B
M"FUS9W-T<B`BU>:[\KS9(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`BT,?&VK;^(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("+-N\3AR[DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`BS<&V^L;D
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@
M*$E33RTX.#4Y+3DI(@IM<V=S='(@(LW!MOK&Y,[$("A)4T\M.#@U.2TY*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("+-
MP;_BPOS+N<RY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A
M:6-O<R!)<VQA;F1S(@IM<V=S='(@(LS8O\O+N;K-OZV_QLNYR+JUNB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("+-O,W?PJPB"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@
M8VAO:6-E.B`B"FUS9W-T<B`BRN3(Z\3ZM<31H=3Q.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B
M"FUS9W-T<B`BU\_-XL_?UKC*_3H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ
M-PIM<V=I9"`B55),(@IM<V=S='(@(LWXUK<B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3<*;7-G:60@(E523#HB"FUS9W-T<B`BS?C6MSHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M"FUS9VED(")59V%N9&$B"FUS9W-T<B`BSMJXR;3O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("+.VK_+P+PB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E
M<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BSMZWJ+3FR*$@5D93(,2_PKPN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("+7HK+ARK'.WK>HU/:\T[;NS>*UQ-/#NZ?0
MQ<^B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.WK>HN,2QY"!61E,@SL2\
M_B!<(B5S7"(@M<3(J,_>+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#.Q+S^
M("5S+R5S(+7$R*C/WBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O
M("5S+B(*;7-G<W1R("+.WK>HL>2X_,ZJ("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T
M<B`BSMZWJ+3ROZH@5D93(,[$O/X@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#.
MQ+S^("5S+R5S(+7$P_NSQBXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q
M;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+B(*;7-G<W1R("+.WK>HP:R]T];!(%-13""W_L[QQO<N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("+.WK>HRKG3PR!34TP@P:R]TRXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BSMZWJ+BT
MUL8@5D93(,[$O/XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+VHP:(@5D93(,2_PKP@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BSMZWJ+VHP:(@5D93(,2_PKPN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`BSMZWJ+VHP:(@
M5D93(,[$O/XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#.Q+S^
M(%PB)7-<(B"UQ,/[L\8N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HO:C!HB!61E,@SL2\_BXB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(L[>MZB]J\K]OMV]
MXM&YR_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`BSMZWJ,F^L_T@)7,LM,O$O\*\
MLJ*WQ[_5L-<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`BSMZWJ,F^L_T@
M)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("+.
MWK>HR;ZS_2`E<RRTR\2_PKRRHK?'O]6PUR(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("+.WK>HM=VYZ<F^L_W$O\*\+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L[>MZC)
MOK/](%9&4R#$O\*\+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(L[>MZC)OK/](%9&4R#$O\*\.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BSMZW
MJ,F^L_T@5D93(,[$O/X@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(L[>MZC)OK/]
M(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@SL2\
M_B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+B(*;7-G<W1R("+.WK>HM=VYZ<F^L_T@5D93.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM<V=I9"`B56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B
MSMZWJ,70ML^UL<>PM<3$O\*\+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS(@IM<V=S='(@(L[>MZB]XK^JQK[6I,^XO=HB"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`BSMZWJ+S3U-@@)7,@M<2VJ-+EROV^W2XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(L[>MZC2QK:O(%9&4R#.Q+S^
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(L[>MZBT\K^J(%9&4R#.Q+S^(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`BSMZWJ-"TR.L@5D93(,[$O/XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@
M(L[>MZBT\K^J(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`BSMZWJ+3ROZK1N<OUSL2\_BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*
M;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B!<(B5S7"(@M<3#^[/&+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(L[>MZC0M,CK(%9&4R#.Q+S^ROV^W2XB"@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R
M("+.WK>HL>2X_"!61E,@SL2\_K7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`BSMZWJ+;!R*$@=F9S<F]O="#$
MO\*\+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+.WK>H
ML>2X_"!61E,@Q+_"O+7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@
MQ+_"O#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(L[>MZBQY+C\(%9&4R#.Q+S^(%PB)7-<(B"UQ,/[L\8N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BSMZWJ+'DN/P@5D93
M(,[$O/X@)7,O)7,@M<3#^[/&+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4N(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#.Q+S^M<3#^[/&+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM
M<V=S='(@(L[>MZBQY+C\SJH@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`BSMZWJ->JN[L@5V]R
M9"#.Q+S^(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
MSMZWJ-"TR.L@5D93(%PB)7-<(B#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`BSMZWJ-"T
MR.L@5D93(,[$O/[*_;[=+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("+.WK>HT+3(
MZR!61E,@SL2\_LK]OMTN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T
M,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q
M=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("+.WK>HT+3(ZR!61E,@
MSL2\_LK]OMTN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(L_"NZ[/WR(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA
M;F=E<R(*;7-G<W1R("+(H<_[N/RXQ"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(KBTU*TB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("*W_L[Q
MQO?!K+W3RK&WHLGZSK34I,;:M<2[V-.F.B`B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("*WHLGZSK34I,;:M<2[V-.F
M+-/)M_[.\<;W.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0HC+"!F=7IZ>0IM<V=I9"`B56YF:6QE9"(*;7-G
M<W1R("+*I[#<(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@
M(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("+-\M/#PNL@*%541BTX*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R
M("*PHL"MLJ[!JKK/Q_6SI+GZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET
M960@2VEN9V1O;2(*;7-G<W1R("+3HKGZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I
M9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("+#P+GZ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M(@IM<V=S='(@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("*UI=2J(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G
M<W1R("+.M-:JM<0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G
M:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(LZ[UL/0
MQ<^BR=#.M,7DUL,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(LZTUJJUQ-/#NZ?#^[ORP]S"ZRXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L
M(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(LZTP_S#^R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@
M(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S
M;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z
M:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C
M<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,@HC+"!F=7IZ>0IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`BU];0S='5
MR:LB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T
M960@17AT96YS:6]N(@IM<V=S='(@(LZTUJ>SUK7$P*G5N</[(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("*QY+C\
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`BN/S0PB`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@
M(E5P9&%T92!U<V5R(@IM<V=S='(@(KC\T,+3P[NG(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("+2T;C\T,(@)R5S)RXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S
M8W)I<'0@9&5L971E9"XB"FUS9W-T<B`BN/S0PK/,T/+2T<F^L_TN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B
MR<^TJR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+B(*;7-G<W1R("+2T<G/M*O+^=/0TZ;3P[/,T/*UQ,7DUL/.Q+S^M;VW
M_L[QQO<N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS
M9W-T<B`BSMK`K;GG(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("*UL<>PS^#.NR(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED
M(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B
M"FUS9W-T<B`BT\.[IR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("+3P[NG("5S(,ZTS:BY
M_2`E<R"UQ,K:R*C1Z=:D+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I
M9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+3P[NGN=S`[2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`BT\.[I]&AS^XB"@HC.B!S:6=N=7`N<&AP.C8R
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("+3P[NGUZ*RX2(*
M"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(K3+U;[,
MJ+7$T\.[I]>BLN'/M<VSTM'-H]/#+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HT-CD*(RP@9G5Z>GD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U
M;F0B"FUS9W-T<B`BU=*RN[6]("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(M/#NZ?#^R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`BT\.[I\/[("<E<R<@TM&TYM3:+B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(M/#
MNZ?#^SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED
M(")5<V5R;F%M93H@(@IM<V=S='(@(M/#NZ<Z("(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T
M96TZ(@IM<V=S='(@(L^US;/6T+7$T\.[ISHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS
M9VED(")5>F)E:VES=&%N(@IM<V=S='(@(L[:U\BQ\+_+R[G,N2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(E9&4R#$O\*\LJ*RN[3FU-HN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T
M<B`BO-G&VB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I
M9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("+2
MT=72M;W3T-"GM<2UV+7C.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`BT]#0I]#4
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*
M;7-G<W1R("+2U+?6UM/.JK6ESKLHM-//UM3:QO#+XRDB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`BUK4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM
M<V=S='(@(LW?PK.PHLV\(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`BL>2[KR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("+.K\3:R/#`K2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED
M(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`BT>G6I,JGL-P@+2"TR]/*
MO/Z_R<3<TM'4XLC+R</7U+3;N,0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BL.:Q
MOB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E
M<G-I;VX@0V]N=')O;"(*;7-G<W1R("*PYK&^O]C6QB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@
M(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A
M9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FEE="!.86TB"FUS9W-T<B`BU+W$SR(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@
M(M2]Q,_.Q"`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM
M<V=S='(@(KSLRM,@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS
M9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(M3:T,*T
ML+_:M/*_JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@
M(M+4("5S(++IO[0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("+3HLKTSJRV^[ZIR+JUNB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@
M(L/`RO3.K+ZIR+JUNB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS
M9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(L3<O/NVR"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R("+$W+S[ML@Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R("+2XK3SP/NW_+7"M^>UY]#%N:O+OLVXN?T@
M4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B
MOJ^XYB(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+B(*;7-G<W1R("*^K[CF(2$A(+33("5S(,K6MJ_)OK/]L\S0
M\BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(LW?P/O+N;K-
MN+O-O,BZM;HB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BOJ^XYB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E
M(@IM<V=S='(@(M#'QMK(_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("+,[,;X
MU*2RXB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G
M:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*(RP@9G5Z>GD*;7-G:60@(E=E
M871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(,WXU;XB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(LWXU;XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@
M4VET92(*;7-G<W1R("+-^-6^(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(L._
MUMPB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B
M5V5L8V]M92(*;7-G<W1R("*[MM.M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BN[;3K;6]
M("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(KNVTZTL("5S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S
M='(@(L[WQ;<@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("+.
M]\6W("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R
M;B!386AA<F$B"FUS9W-T<B`BSO?(]KG^P*TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(K7'PKRZ\].FN,//R,_4RKX@)7,@Q,32N[CVTZ;3P[/,T/(_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(M?6MLZUQ+?6N/37UK?[
M/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(M+]RO:UQ,>P
MM;RW^S\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`V,0HC+"!F=7IZ>0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P
M(@IM<V=S='(@(K#$M//`^]''(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S
M"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B
M;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T
M"B,L(&9U>GIY"FUS9VED(")7:61T:"(*;7-G<W1R("*WY\O9.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-3
M4R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU
M(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$P"B,L(&9U>GIY"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(L&BS-7-
M\"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`U"B,L(&9U>GIY"FUS9VED(")7:61T:#HB"FUS9W-T<B`BM^?+V3HB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*(RP@9G5Z
M>GD*;7-G:60@(E=I;F0B"FUS9W-T<B`BM^?+V3HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R("*WY\O9.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@
M(K?GR]DHO=HI(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(K?GR]DZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(K?GR]DZ("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*(RP@
M9G5Z>GD*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(L;:M/W/[L2_(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V
M-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(K#LN:O*TK78UK<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS
M9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(K#LN:O*TK7GN[`B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(LBHS]ZRN]?C+,[>MZB]J,&B(%9&4R#.Q+S^+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*
M;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8
M-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@P*G5N</[(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(L3J(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"FUS
M9VED(")965E9(@IM<V=S='(@(L3J(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS
M9W-T<B`B66%H;V\@(2"UV,V\(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(L._
MQ.HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("+2LL/%
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B
M"FUS9W-T<B`BRL>UQ"S.TLVLTN(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RXB"FUS9W-T<B`BQ/JUL<>PRKG3P[2_SL37UK'@T+3$H\J]+B#*
MN=/#(%L\/ET@L+3%I;_)Q]"[N\ZJS?C2L['@T+3$H\J]+B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO
M8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R
M"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I
M;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U
M"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N(@IM<V=S='(@(L3ZLJ+.M,KDR.O2N[CVNL^WJ+7$M>?7T]/*O/ZUV-:W
M+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@
M=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S
M("(*(FEN("5S+B(*;7-G<W1R("+$^K*BSK33R;6\R.NUQ,[$O/[6T+;4T[/(
MSKK.U]:VSK6]("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(L3Z
MTM&^K=>BS_HN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM
M<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(L3ZL=C0
MZ\KDR.O2N[CVNL^WJ+7$UK4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A
M5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("+$^K'8T.O/
MR+GFNZZZP\K]OMW*]RA$871A5')E92FW_L[QMLNRQ<3<O,S0^,JYT\/0PM/#
MNZ?7HK+AM_[.\2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U
M-@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N(@IM<V=S='(@(L3ZL=C0Z\_(N>:[KKK#ROV^W<KW*$1A=&%4<F5E
M*;?^SO&VR[+%Q-R\S-#XRKG3PR!(;W)D92XB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(L?KP^C*]L[*S.*CK-3:Q/JTJ\O-SLK,XK&HN.;6
MKL>P+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("+$^K'8T.O*Y,CKM,O!K+W3R_G6
MN,_RM<3-^-:W(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`BQ^O6N+:HTJK)OK/]M<2W_L[QQO<N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("+'Z]:XMJC2JLF^
ML_VUQ-/#NZ<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("+'
MZ]:XMJC2JLF^L_VUQ-/#NZ<N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(L?KUKBV
MJ-*JT,+4]K7$T\.[IRXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS
M9W-T<B`BQ^O6N+:HTJJX_-#"M<33P[NG+B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("+'Z]:XMJC2
MJM:TT-"UQ-?WT\,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`BQ^O6N+:HTJK)OK/]
MM<33P[NG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N
M($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`BQ/JUQ"`E<R"[X<;:TM&Y_<JQ+L?KUMC0PK7'PKPN(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@
M16UA:6P@061D<F5S<R(*;7-G<W1R("+$^K7$M>?7T]/*O/ZUV-:W(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("+$^K7$M>?7T]/*O/ZUV-:W(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(L3ZM<30Q<^B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HBU]2TT\3ZM<0@)7,@N^'&VK^J
MRKS2U,"TQ/JUQ-+RS-C-^+78UK?2T;'DN/PN(,ZJL:.[I,3ZM<2PLLBKQO"\
M^Z.LQ/JQV-#KUMC0PB(*(K7'PKPN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+$^K7$
MT-7#^R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L
M(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K
M96YD+B(*;7-G<W1R("+$^K7$T>G6I+;+LJ+.M-:GL];0PM3VT\.[I[ORN,.Y
MIL3<TM&QN[G8L=4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(L3ZM<31Z=:DMLNRHLZTUJ>SUL'0L_;3P[NGN_*XP[FFQ-S2
MT;&[N=BQU2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B+7U+33Q/JUQ"`E<R"[X<;:OZK*
MO-+4P+3$^K7$Y*_`P,;WR\:Z]=+1L>2X_"X@SJJQH[NDQ/JUQ+"RR*O&\+S[
MHZS$^K'8T.O6V-#"(@HBM<?"O"XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!F96%T=7)E+B(*;7-G<W1R("+$^K7$Y*_`P,;WLJ+.M-:GL];5XKCVN:;$
MW"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F
M=7IZ>0IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M(@HB=&\@<')I;G0N(@IM<V=S='(@(L3ZM<3DK\#`QO>RHLZTUJ>SUK3RTZ'1
MH<_N+L?KL+0@0U123"M0(-+4M/+3H2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G
M<W1R("+$^K6QQ[#+^<7DUL.UQ,JQQ_@Z(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@
M:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`BQ/JUQ-&AS^[2T;C\T,(N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("+$K,C/R>VWW<JVL?`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY"FUS9VED
M(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BQ/JUQ-#5P_LB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R
M(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("+$^K7$T:'/[M+1N/S0PBXB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@
M(L3ZM<31H<_NTM&X_-#"+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N(@IM<V=S='(@(L3ZM<31H<_NTM&X_-#"+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(L3ZM<34
MMK/,M_[.\<;W.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S
M;&%V:6$B"FUS9W-T<B`BQ,_+N<"MM_(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("+4^M+!MOLB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`BU-ZQR-''
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`BO?*P
MS;*\SJ0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII
M<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM
M<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");SLK,XK&HN.9=(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S
M(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB
M"FUS9W-T<B`B6\Z[T]K0T"`E<R"YLB`E<R#0T%TB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(KG<P.TB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"B,L(&9U>GIY"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`BROV^W2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B
M7T1E;&5T92!2;W<B"FUS9W-T<B`BR;ZS_2(*"B,Z(&QI8B]A<&DN<&AP.C$S
M,PHC+"!F=7IZ>0IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("+3P[NGU^DB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY
M"FUS9VED(")?2&5L<"(*;7-G<W1R("*P[];Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?
M26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G
M(&EN(@IM<V=S='(@(K7'PKPB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U="(*;7-G<W1R
M("+7HL_Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`BLN7(ZR^QY+C\S?C"Y\&LO=,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R("+1H<_N(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"B,L(&9U
M>GIY"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`BR*C/WB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-@HC+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(LF^
ML_VVU"(*"B,Z(&QI8B]A<&DN<&AP.C$R-0HC+"!F=7IZ>0IM<V=I9"`B7U-E
M='5P(@IM<V=S='(@(L7DUL,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0HC+"!F
M=7IZ>0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(M/#NZ<B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S
M<R!B;V]K(@IM<V=S='(@(LVHT;:ROB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC
M+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BR-7`^B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(L'C
MO+:WYR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X
M"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED
M(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC
M+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("+%
MY-;#(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*
M;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G
M:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E
M;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`BU=*RN[6](@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#4U"FUS9VED(")F:6QE(@IM<V=S='(@(L[$O/XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(K33("5S("@E<RD@T]H@)7,@
M)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U
M>GIY"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(BP@U?.WYR`E<R`E<R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G
M:60@(F@Z(@IM<V=S='(@(LJQ.B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H
M;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM
M;65D:6%T92(*;7-G<W1R("+!HKRT(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@
M(FEN;&EN92(*;7-G<W1R("+/PKNNS]\B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,PHC+"!F=7IZ>0IM<V=I9"`B;&EN97-=(@IM<V=S='(@(K?6(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S
M"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`BP_NSQB(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L
M96UE;G1E9"(*;7-G<W1R("+)T,ZTRK7/UBXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M
M96YT960B"FUS9W-T<B`BR=#.M,JUS]8N(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`BM.;(H=3BOMPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P
M:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(LBHS]XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@HC+"!F
M=7IZ>0IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")-971A
M<B#'^+_ISMZWJ,JYT\,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY
M.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I
M9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<R"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB"FUS9W-T<B`BML'(H2(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET
M8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0HC
M+"!F=7IZ>0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(M?6M_NTKL'0(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@
M(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB
M"FUS9W-T<B`BP[^TSK7'PKPB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(M39M,[*Y,CK
MQ/JUQ,/<PNO2U,BWR,_.WL[S(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(G5N
M:69I960B"FUS9W-T<B`BRJ>PW"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`BSK3#_,/[(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("+3P[NGT:'4\2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R
M("+0Q\;:.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS
M9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2#-^-6^(@H`
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&\O>FA?5%<N<&\`````````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#8T,#0R,P`Q,#4Q-30S,3`V,@`P,38T,S``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R!(
M;W)D92!4<F%D:71I;VYA;"!#:&EN97-E(%1R86YS;&%T:6]N+@HC($-O<'ER
M:6=H="`H0RD@,C`P,2!$879I9"!#:&%N9RX@L6FH?:3E+*5XQE<*(R!$879I
M9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SXL(#(P,#$N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G-<
M;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,2TP-2`Q-3HP-"LP.#`P
M7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`Q+3$R+3(P(#$R.C`P*S`X,#!<
M;B(*(DQA<W0M5')A;G-L871O<CH@1&%V:60@0VAA;F<@/&1A=FED0'1M=BYG
M;W8N='<^7&XB"B),86YG=6%G92U496%M.B!4<F%D:71I;VYA;"!#:&EN97-E
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0DE'-5QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@I-&K92DB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@
M)7,I(@IM<V=S='(@(B`HI]:QML'D("5S*2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S@Q"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB
M"FUS9W-T<B`B("@E<R"DT:2Z*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,S<W"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@**2UI-$I(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S-SD*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S
M='(@(B`HJ?JDT2DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I
M9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`HK%&DT2DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y
M-@IM<V=I9"`B(&%T("(*;7-G<W1R("*I\R(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(*2CK$^D0*W3I=B__2(*"B,Z(&QI
M8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@I*.L
M3Z1`K=.FLZ[$JKJ_[[[<+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z
M-C4R(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3`T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@J7REO*9B($A/4D1%(*JZM?FE
M5<#)*%)E9VES=')Y*:2DLUVI=RXB"@HC.B!L:6(O2&]R9&4O5')E92YP:'`Z
M,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R
M(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCL(%PB)7-<(B!T<F5E(')E;F1E
M<F5R+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB
M"FUS9W-T<B`B7"(E<UPBI'>FJ*5<JKJE6Z1*J.RX<[+5J'2RSJ2D+B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN(@IM<V=S='(@(EPB)7-<(J1WI5ND2L5VK:VH=++.+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S
M+B(*;7-G<W1R(")<(B5S7"*HPZ6\J]BEWSH@)7,N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U
M<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(J1WJ,^E
MSB`E+C)F34(@+*YEMG$@)2XR9DU"("RST;YL("@E+C)F)24I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@I4BDSB`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("*SS*KQI$"FN+%+O5C%
MW*?SJ?,@)60@I-&K92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("*SS*KQ("5D(*31KO"V2+EWL_@B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I
M8V4B"FUS9W-T<B`B)7,@+2"SQJ?1O_TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P
M<FEN="(*;7-G<W1R("(E<R"K_*^^(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C@T,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VXB"FUS9W-T<B`B)7,@NOO%0+[>IT`@+2"]5+M[(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(+-=J7<B
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(+7YI54B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(*90MTZVM:78
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0S,B!L:6(O5D93+W-M8BYP:'`Z-#DT
M(&QI8B]61E,O9G1P+G!H<#HV-S$*(SH@;&EB+U9&4R]F='`N<&AP.C<S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B)7,@I'>F<Z9B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T
M<B`B)7,@IF(@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(E<R"D=[1.
MI%6F0ZC&MK6JNKK[Q4"^WJ=`M$ZZ_"X@O="I\Z:YKLFDQ+_OIT&W4:UNOMZG
M0*JZMK6EV"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("*ELKO=K6X@
M)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(*3`(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H["`E<RXB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B`E<R"H["`E<R"F0"`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5SJKJS<;!4O_TB
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5SJKJFYJC&ON0B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B)7.JNK/&I]&__2(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S
M:VQI<W0B"FUS9W-T<B`B)7.JNJO=O^S#KR(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET
M(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN
M:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@
M<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B"S;ZO*JTBE
M\Z2CI$"I=Z]UI=&K2*2DJKJQ2*7SI$BITK%(M6\N(+W0JF"W3J15ID.ITJ:S
MJKJZ]+CTLW.ULJ:SI6FOX*RJNGPB"B*G0:JZK=.D2+CJKL8N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@
ML'VMMR`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@
M)7,@)7,B"FUS9W-T<B`B+""P?:VW("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(BS%W*3&MG&Q<2`E<R"H["`E<R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#<S(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3,R(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,S0X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HW-#4*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2"_[[[<
M("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R
M($9O<FUA="(*;7-G<W1R("(Q,B"D<*[)J.XB"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T(*1P
MKLFH[B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R
M-"!H;W5R<R(*;7-G<W1R("(R-""D<*[)J.XB"@HC.B!L:6(O2&]R9&4O54DO
M4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`BI%>D0*VV
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T
M<B`BIKFPS[;TI;*VMZUNJ_RI=[CJKL:N=Z;XJD&ZW2XB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`BM6^ES:1&I$"MT\19K:NJNK_YNWXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(K']I5NQ
M2[9LI?,LP=F[W:UNIK.D0*W3(%!'4""DO;9]JO?&7RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("*Q_<7GP]*D=\.QL[FJNK9LI?,LP=F[W:UNIK.D0*W3(%!'4""DO;9]
MJO?&7RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G
M92XB"FUS9W-T<B`BL?VXT;%+MFRE\RS!V;O=K6ZFLZ1`K=.DO;9](%!'4""J
M]\9?+*APL4L@4$=0(*KWQE\LI4BDSK-QP_:D9J5/+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("*Q_;#UIN:V;*7S
MP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%!'4""J]\9?+*APL4L@4$=0(*KWQE\L
MI4BDSK-QP_:D9J5/+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D
M96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BL?VXT;%+MFRE\RS!V;O=K6ZF
MLZ1`K=.DO;9](%--24U%(*KWQE\LJ'"Q2R!334E-12"J]\9?+*5(I,ZS<</V
MI&:E3RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I
M9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(K']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"M
MTZ2]MGT@4R]-24U%(*KWQE\LJ'"Q2R!3+TU)344@JO?&7RRE2*3.LW'#]J1F
MI4\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@
M(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`BL?VE6[%+MFRE\RS!V;O=K6ZFLZ1`K=,@4TU)
M344@I+VV?:KWQE\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(J3(JV6FL[:S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*
M;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`BI,BK9:1PJT(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B
M04T@4F%I;B(*;7-G<W1R("*DR*MEIK.K0B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM
M<V=S='(@(J3(JV6P?:M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("*DR*MEL'VSMR(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS
M9VED(")!32]032(*;7-G<W1R("*DR*ME+Z3(J^$B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S
M='(@(D%022"]<[BY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T
M<B`BP_:I\[-OK=.]<[_HOKDB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`BP_:I\RXN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@
M(D%B<V)O='1O;2(*;7-G<W1R("*EOZ15I.@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B
M"FUS9W-T<B`BI;^DI*6A(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(L5VK:VDHZBL++5,JFNKV*7?(%9&4R"EV+_]+B(*"B,Z(&QI8B]6
M1E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92XB"FUS9W-T<B`BQ7:MK:2CJ*PLM4RJ:ZO8I=\@5D93(,#)
MKM<N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`BL6*XN;CJL%0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS
M9W-T<B`BL6*XN;M0L4N]6"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B
ML6*XN:1WK>&ULBXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U
M"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(K6RL6(B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z
M,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*
M;7-G:60@(D%D9"(*;7-G<W1R("*W<[Q7(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'
M<F]U<"(*;7-G<W1R("*W<[Q7IKBX<[+5(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!
M9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("*W<[Q7I&S%=JVM(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*
M;7-G<W1R("*F8J:YMW.\5SHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A
M9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G
M<W1R("*W<[Q7N'.RU2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M
M:7-S:6]N(@IM<V=S='(@(K=SO%?%=JVM(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`BMW.\5Z:XN'.R
MU:CL(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M7"(E<UPB(@IM<V=S='(@(K=SO%>FN,5VK:VFW%PB)7-<(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B
MMW.\5Z1`K=.HSZ7.JLPZ(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U,PIM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("*W<[Q7
MQ.:F["(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*
M;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("*W<[Q7I$"MTZ:HK?LZ
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D
M('!A:7(B"FUS9W-T<B`BMW.\5[GO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`BMW.\5R`E<R"LL"!-;WII
M;&QA(*JZI,"MMB(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(K=S
MO%>H[*JZLW&P5+_].B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`BMW.\5ZCLI]JJNK-QL%2__2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS
M9VED(")!9&0@=7-E<B(*;7-G<W1R("*W<[Q7J,^ESJK,(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E
M<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`BI'>W<[Q7
M(%PB)7-<(B"H[*ATLLZDI"X@IOVU3*IKMW.\5\-"I7ZJNK7YI56XZK!4.B`E
M<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M(@IM<V=S='(@(J1WMW.\5R!<(B5S7"(@J.RH=++.I*0N(*=!LGNF8J5II4BV
M::;FM6ZD2J1&+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(K=SO%>HSZ7.JLRJNJ5<K^"EV*MELU'#]K.L+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#0U(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS
M9VED(")!9&1R97-S(@IM<V=S='(@(J9AIWTB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
MLW&P5+_](@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT
M"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<R(*;7-G<W1R("*FJ*RPNMZR>JW[("T@K+"HY*5,J,^ESJK,LUVI
M=\5VK:TB"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T
M<B`BNMZR>B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G
M:60@(D%D<R(*;7-G<W1R("*\<Z=I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B069G:&%N:7-T86X@**K\M$FFO2DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM
M<V=S='(@(D%L8F%N:6$@**K\NKBDVJ6GJ,@I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*
M;7-G<W1R(")!;&=E<FEA("BJ_+JXI,ZG4:C(*2(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R
M("*V;*7SIT^F5R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(KGON_0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W
M"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(KGON_2DZ*:A.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(JG2
MIK,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R("*ITJ:SI'?%Y\/2JKJHSZ7.JLPB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@
M1W)O=7!S(@IM<V=S='(@(JG2IK.X<[+5(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HY,2!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N<&AP.C<U"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`BJ=*FL\5VK:TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W
M"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("*E?J[8O74B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S(@IM<V=S='(@(J2YLURF;K18K=.Y<:1LMFRE\Z9AIWTB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("*DN;-<Q=RG\[:U
MI=B]<[BYJKJKK+I!/R(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP
M.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`BI'>F<Z9B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E
M($E-4U`@3&]G:6XB"FUS9W-T<B`BQ=RG\R!)35-0(+5NI$HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!0
M87-S=V]R9"(*;7-G<W1R("+%W*?S($E-4U`@L4N]6"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N
M86UE(@IM<V=S='(@(L7<I_,@24U34""HSZ7.JLPB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`BQ=RG\[EQI&RV;*7SINVG?2(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM
M<V=S='(@(L7<I_.\RZI/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@
M=&5X=#HB"FUS9W-T<B`BM,"E3J3EIG(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO
M82(*;7-G<W1R(")!;65R:6-A;B!386UO82`HK/S$4K#MPL2\KZC(*2(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"XB"FUS9W-T<B`BI$"MT[5,KL2JNJW(LU&HSZ7.+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R
M;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(K5OI<VD1J1`K=.EO*J^JKJ_^;M^
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82`HIG>Y1*;5*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$@**9WK?2IU"DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82`HIG>F8ZG4KG$I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@
M4')O>'DB"FUS9W-T<B`BL,ZF5Z5.LGJF<ZCZ(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("*UJJ[7
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<F-T:6-A("BK;K>E
MI&JSL"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N
M=&EG=6$@86YD($)A<F)U9&$@**9WM*.ERJYQI,ZDVKJXI:RY1JYQ*2(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U
M(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T
M<B`BP+.ESK5[IJ$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G
M:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BP+.ESK5[IJ&R3;/F(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I
M;VX@:7,@<F5A9'DN(@IM<V=S='(@(L"SI<ZU>Z:AI'>T3KK\(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H
M:6QD(%-H87)E<R(*;7-G<W1R("*N3:7.J.RITJ:SJKJFN*9`J,DB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P
M<F]V92(*;7-G<W1R("*GY:WC(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C@T,`IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("*Y
M=Z;TI&JD<"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R("*E?*3K(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S$*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M("*J_*G4IT*DY2`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C4Y(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS
M9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("+`H\%9P,FD:J1P(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("+`
MH\%9P,FF5[K9(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/R(*;7-G<W1R("*G0;U4J7>M;J=2L*,@)7,@JKJU^:55MMP@/R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E
M<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`BIT&]5*EWK6ZG4K"C
M(%PB)7-<(B"E2*3.I?2F\ZJZIKBX<[+5(#\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B
M"FUS9W-T<B`B07)G96YT:6YA("BJ_*[:I\HI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*
M;7-G<W1R(")!<FUE;FEA("BHR*S\I:>HR"DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W,@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T
M<B`BJ,BL_*6GJ,BDY2`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(L/`LTXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M<G5B82(*;7-G<W1R(")!<G5B82`HJOR^?*3:KG$I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S
M='(@(D%S8V5N<VEO;B!)<VQA;F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("*DY:9RP\"S3B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF
M:6,@4F5G:6]N(@IM<V=S='(@(JC(K'<OI-.EK:QVIF&PSR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G
M<W1R("*P]:;FOMZG0+K[Q4"K9<7CI=R]5+M[N>^XW#\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S$P,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM
M<V=S='(@(J3`L'3$YJ;L(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(L!\N-6G4K"CI$"MTZ2CIG.F8JJZN'.RU2XB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+`?+C5IU*PHZ1`
MK=.DHZ9SIF*JNL5VK:TN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("+`?+C5O7._Z*1`K=.DHZ9SIF*JNKASLM4N(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(L!\N-6]<[_H
MI$"MTZ2CIG.F8JJZID"HR2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R("+$W:G*(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("*D2Z3K(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86QI82`HOT2D:J=1J,@I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B075S=')I82(*;7-G<W1R(")!=7-T<FEA("BV^*9AIU$I(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?8W)Y<W%L.B"GY*2CJ.RITKO=K6ZJNB!I;6%P(*FUIOFN3:7S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@IOBJ0;K=J,.EO+2CJ-&X
MT[:UI.2TJ2XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS
M9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?8W)Y=7,Z(*?DI*.H[*G2N]VM;JJZ(&EM
M87`@J;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM
M<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@
M<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@I^2DHZCLJ=*[W:UNJKH@
M1E10(*FUIOFN3:7S+KW0K:NW<[USQ+8@4$A0(*C#I4*E6Z1*("TM96YA8FQE
M+69T<""_[R(*(K:U+*C2IG`@8V]N9FEG=7)E("TM96YA8FQE+69T<"(*"B,Z
M(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]I;6%P.B"GY*2CJ.RITKO=K6ZJNB!)34%0(*FUIOFN3:7S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]K<F(U.B"GY*2CJ.RITKO=K6ZJNB!K<F(U(*FUIOFN3:7S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z(+=SO%>HSZ7.JLRS;[:UI5RO
MX*78JV6HPZ2CI.2TJ:78O_VJ0;#((@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M075T:%]L9&%P.B"G4K"CJ,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]
MJD&PR"(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]L9&%P.B"GY*2CJ.RITKO=K6ZJNB!,1$%0(*FUIOFN
M3:7S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U
M=&A?;&1A<#H@M4RJ:[=SO%>HSZ7.JLP@)7,N(*;XJD&^N:9>P+,Z(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S
M='(@(D%U=&A?;&1A<#H@M4RJ:[*^L*.HSZ7.JLP@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T
M:%]L9&%P.B"U3*IKI_.W<ZC/I<ZJS"`E<R(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G
M<W1R(")!=71H7VQD87`Z(*?SMW.HSZ7.JLRS;[:UI5ROX*78JV6HPZ2CI.2T
MJ:78O_VJ0;#((@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G
M:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(*?DI*.H[*G2N]VM;JJZ($U#04P@
MJ;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@I^2DHZCLJ=*[W:UN
MJKH@<VUB875T:""IM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O24U!4"]!9&UI
M;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(DE-05`@IOBJ0;ZYQ>?#TK_YNWXN(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+%Y\/2I:*QT2XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+%Y\/2I:*QT2X@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B4D%$2553(,7GP]*_^;M^+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX
M-S$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")&5%`@Q>?#TK_YNWXN(@H*(SH@;&EB+U9&4R]S;6(N<&AP
M.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(E--0B#%Y\/2O_F[?BXB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*
M;7-G<W1R("*E::7.JKK$YJ;L.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T
M<B`B07IE<F)A:6IA;B`HJ,BVZZOTM4TI(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("*M2;2Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C
M:V=R;W5N9"!#;VQO<B(*;7-G<W1R("*M2;2ZPT.FXB(*"B,Z(&QI8B](;W)D
M92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O
M<F0N(@IM<V=S='(@(FME<F)E<F]S(+%+O5B_^;M^+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA
M;64N(@IM<V=S='(@(FME<F)E<F]S(*C/I<ZJS*97NMF_^;M^+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA<R`HI-JKHK"H*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A
M:')A:6XB"FUS9W-T<B`B0F%H<F%I;B`HI-JJ3"DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W,PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS
M9W-T<B`BJFG#N:JZKORDY2`H25-/+3@X-3DM,3,I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA
M9&5S:"(*;7-G<W1R(")"86YG;&%D97-H("BI<Z5;J=0I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R
M8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,@**3:J*FF:"DB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
MI^2DHZCLN<^EW*78O_T@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B
M"FUS9W-T<B`BL/*]=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B0F5L87)U
M<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEU;2`HI/&G4:[)*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4@**BIJ+VTM2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"96YI;B(*;7-G<W1R(")"96YI;B`HJ*FYYRDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A
M(@IM<V=S='(@(D)E<FUU9&$@**;*O'VY1BDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS
M9W-T<B`B0FAU=&%N("BDHZ2F*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("*ES:3I
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLP+.ESK5[IJ%<(B4R
M)'-<(JJZL,^V]%PB)3$D<UPB+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`BL,^V
M]+-=J7<B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G
M:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`BL,^V]*NLND$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B
M"FUS9W-T<B`BLLK%Z2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I
M82`HK,&G4;K[J,@I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P
M-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(J[1Q=(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED
M(")";W)D97(B"FUS9W-T<B`BKMB]=2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(J[8O76D:J1P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*
M;7-G<W1R("*NV+UU(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*
M;7-G<W1R(")";W-N:6$@86YD($AE<GIE9V]V:6YA("BJ::1HI:>HR*3.ML+!
MR:WTNONHNBDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@
M(D)O=&@B"FUS9W-T<B`BI?ZSH2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@
M(D)O='-W86YA("BJ::6^J+HI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T
M<B`BJ;.SH2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T
M($ES;&%N9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z:6P@**3:IN@I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2`H
MJ%JUW"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QG87)I82`HJT^E
M6Z=1J,@I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("*VM:78LL6X
MN2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\@
M**6LM%BOQZIKK\$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I
M("B[6K:IIF$I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM
M<V=I9"`B0TU3(@IM<V=S='(@(JJIK;&ZWK)Z(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),(*3`LZ'"22(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+`>*9S
MKN:DNJYE+BXN7V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G
M<W1R("*GUJCZJNRI;*3&J7REO*>YIJ@N(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X,B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(J;FJ,:^Y"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`BN7.OQ:VW(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A;6)O9&EA("BL6JY(N>LI(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M97)O;VX@*+/8L\&VJ2DB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`BM4RJ:Z;;L,JMJ[AML4N]6"R]T,%P
MM;BG0:JZJ'2RSKK>LGJM^RXB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(K5,JFN\9Z1*P,FNUR!<(B5S7"(B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R("*U3*IKLW.]=:;<($E-05`@IOBJ0;ZY
M.B`E<R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(K5,JFNV
M?;'2P,FNUR!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A;F%D
M82`HI5NNLZ1J*2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R
M+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ
M,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM
M<V=S='(@(JCZKO@B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(JCZ
MKOBPW<-$IEZS^"(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`BM4RJ:Z=2L*/`R:[7(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@
M(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
MI^2DHZCLO,BF<Z78O_TN(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ
M"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N(@IM<V=S='(@(J_*I-8@)W1A<F=E=$9I;&4G(+#1O,:U3*IK
MQ'[$\K-"LGHN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(K5,JFNROK"CI=B__2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A
M=&%4<F5E+G!H<#HQ,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+B(*;7-G<W1R("*U3*IKLKZPHSL@)60@K=.D;+:PI'>F<Z9B
M+B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B
M(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N
M(@IM<V=S='(@(K5,JFNMJ[+5H4.ITK2CJ-&JNK!/O_V\QJ78NU"E_:MEJ=+`
M>*9SJKJXZJ[&I*.RQ2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`BM4RJ:[;'L&7"LK!4J.RK_*EWJKJX
MN;U8+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B0V%P92!697)D92`H
MNON\=ZBD*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BNZ&I^J3E
MIG(B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`HC+"!F
M=7IZ>0IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("*ONZSUIN(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA
M8F5L<R(*;7-G<W1R("*DP,/^NU"\T,72(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA
M;F1S(@IM<V=S='(@(D-A>6UA;B!)<VQA;F1S("BV?;#2N'.N<2DB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R("*FYK#*N7&XW"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R("+`>*9SKN:DNJYE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@
M<&%D9&EN9SHB"FUS9W-T<B`BP'BF<Z[FN=2E4CHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#
M96QL('!R;W!E<G1I97,B"FUS9W-T<B`BP'BF<Z[FI+JN92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#
M96QL('-P86-I;F<Z(@IM<V=S='(@(L!XIG.NYK:AMEHZ(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("*F
MYK#*N7&XW"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED(")#
M96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("*VZ[JXKU.DY2`H25-/+3@X
M-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(KAMI*0B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC("BDI*M$ID"I3;#J*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<U"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*2(*;7-G<W1R("*DI+S:("A)4T\M.#@U.2TR,"(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$
M971A:6QS(@IM<V=S='(@(K[,P]*RT[A@(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S
M='(@(K[,P]*^UJ:SJLPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`BOLS#
MTJQ&M:8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B0VAA9"`HK&2\=RDB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BI_.G
M[R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B
M0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BI_.G[Z=!JKJQ2[U8(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B
MI_.G[Z=!JKJJNJ7^IE>E2*3.IEZV;*9AIWTN(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(J78JV6JNK-=J7>HPZ6\I.2TJ;%+O5C%W*?S+B"]T,%PM;BG0:JZ
MNMZR>JW[+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`BIG*DN"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`BP,NL9+-SM;(N
M+BY?:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE("BTO*=1*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-H:6YA(@IM<V=S='(@(D-H:6YA("BDI+#J*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<V"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BDB"FUS9W-T<B`BPK+%Z:2DI.4@*$=",C,Q,BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2DB"FUS9W-T<B`BI;_%Z:2DI.4@*$)I9S4I(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*
M;7-G<W1R("*_[[[<P+.ESK5[IJ$Z(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@
M(K_OOMRQ2[U8(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*
M;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(K_OOMRD0*W3J,^E
MSJK,IE>ZV2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@
M(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`BI.FTP<7C
MI=RDZ*:A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("*_[[[<MK6EV*NLND&J
MNJVWKN8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(D-H<FES
M=&UA<R!)<VQA;F0@*+ATO<^N<2DB"@HC.B!L:6(O5D93+G!H<#HY,3,@;&EB
M+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCL("5S
M(*JZP_ZG3ZEWN'$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(K2X(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("*R3;"CMTRS;B!/9F9I8V4@
MO-#%TB(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(K)-L*.L9+C?(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(K)-L*.HSZ7.JLPZ("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U
M<V5R(@IM<V=S='(@(K)-L*.HSZ7.JLPB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S
M='(@(K)-L*.HSZ7.JLRJNKCJKL8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G
M<W1R("*QW\+@M+@B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T
M<B`BJ_:WQKFKP>2E2,1^Q/(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G
M<W1R(")#;&EC:V%T96QL(+-ZN4P@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I
M9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(L/VLZRU^+6A(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("*VL[9Q
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*
M;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("*FK:9HMK,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO
M=61Y(@IM<V=S='(@(K.Q(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B"FUS9W-T<B`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3
M:61E8F%R(@IM<V=S='(@(J?IQ7RXZJ[&IZ@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL
M87!S960@8F]R9&5R<R(*;7-G<W1R("*GZ<5\P^2LR2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M
M8FEA(@IM<V=S='(@(D-O;&]M8FEA("BM]*W;I/&HR"DB"@HC.B!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM
M<V=I9"`B0V]L;W(B"FUS9W-T<B`BPT.FXB(*"B,Z(&QI8B](;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,C4@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,R-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G
M:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("*]U:;BO4PB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C@S-0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G
M<W1R("(Q-K9IINS#0Z;BI4Z]6"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("+$
MYCHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN
M('1I=&QE<R(*;7-G<W1R("+$YJ;LO-##1"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R("*E9+-Q(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S
M='(@(JE2I4\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O
M;6UA;F0@4VAE;&PB"FUS9W-T<B`BI^6FN*E2I4\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`BM?N]
MUR(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#
M;VUM;VX@3F%M92(*;7-G<W1R("*ZV:E)(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS
M9W-T<B`B0V]M;W)O<R`HK.R\K\.Y*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(J2]
MI7$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U
M=&5R<R(*;7-G<W1R("*Y<;BC(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(L#TN=(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*
M;7-G<W1R("*Q^*7S(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G
M:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`BKG2RIR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R
M871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@
M3W5T;&]O:RXB"FUS9W-T<B`BNU`@4$1!(+1XI%>KK+EQN*,LM+R\>JNLI.*^
M]Z5(I,X@3W5T;&]O:R"JNJ90J$*S7:EW+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N(@IM<V=S='(@(K-=J7>XZJ[&N4RTP2XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E
M<R(*;7-G<W1R("*S7:EW("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M("*]5+M[L4N]6"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(D-O;F=O("BMZ*I'
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T
M:&4B"FUS9W-T<B`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F
M('1H92`HK>BJ1Z9`J4VPZBDB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("*S<[6RI:*Q
MT2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BLW.ULJ6BL=$Z("(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("*S<[6RIMRD
MO;9]JO?&7Z;XJD&^N:[)OD2IVBXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB
M"FUS9W-T<B`BLW.ULJ;<I+VV?:KWQE^F^*I!OKFNR;Y$J=HN(*WLIETZ("5S
M("@E<RDB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#8U"FUS9VED(")#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("*S<[6RIMP@1E10
M(,#)KM>F^*I!OKFEHK'1+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("*S<[6XI$@B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`BL$^__:1WIJBE7*9AMW.\5Z;<IT&JNK-QL%2__:2D+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#
M;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`BP*/!
M6<#)KM>JNJ2ZKF6KK+I!.B`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB
M(,#)KM>DNJYE(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU
M92(*;7-G<W1R("+$?L3R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@
M(D-O;VL@27-L86YD<R`HK.RG2KASKG$I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")#;V]K:64B"FUS9W-T<B`BPT.F
MXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R("*]QKMS(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A
M:6QE9#H@)7,B"FUS9W-T<B`BO<:[<Z6BL=$Z("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`BO<:[<R(*"B,Z(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ-S`@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I
M9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S
M='(@(D-O<W1A(%)I8V$@**WTM+6D:KZDI5LI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV
M;VER92(*;7-G<W1R(")#;W1E(&0G279O:7)E("BV2*3ZKORII"DB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`BM4RJ:Z5((%!'4""E6[%+
MMFRE\SH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R("*U3*IK
MI4@@4$=0(+#UIN:V;*7SP[&SN3H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R("*U3*IKI4@@4R]-24U%(*5;L4NV;*7S+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`BM4RJ:ZRP(%,O34E-
M12"V;*7SP[&SN2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,B"FUS9W-T<B`BM4RJ:[=SO%>S<[6XI$@N("5S(@H*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.CDV(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(K5,JFO#M+6R($Q$05`@IOBJ0;ZY(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A
M<"!S97)V97(B"FUS9W-T<B`BM4RJ:\.TM;(@;&1A<""F^*I!OKDB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("*U3*IKP,NL
M9+=LKW$N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I
M9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B
MM4RJ:[-SM;*FW"!L9&%P(*;XJD&^N2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`BM4RJ
M:[-SM;*FW*;XJD&^N2!<(B5S7"(@J,^ESB!&5%`Z("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("*U3*IKJ]BEW[!TN&VX<[+5+B`E<R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'
M4"!D871A.B`B"FUS9W-T<B`BM4RJ:[C1L4L@4$=0(+CJKL8Z("(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`BM4RJ:[C1L4L@4R]-24U%
M(+CJKL8N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(K5,JFNG4K"CLW.UN*1(+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`BM4RJ:Z=2L*.P=+AMLDVSYBX@)7,B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T
M<B`BM4RJ:Z=2L*.G\[=SM7NFH2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HS.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34S
M"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@861D<F5S<RXB"FUS9W-T<B`BM4RJ:ZA-J7>FK*7SI$BJNKEQI&RV
M;*7SINRG?2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B
M;V]K+B(*;7-G<W1R("*U3*IKP/*H^J>YON.JNK-QL%2__2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(K5,JFO`\JCZI[F^XZJZL'2X;;)-L^8N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T
M<B`BM4RJ:\#RJ/JP=+AMLDVSYJ2DJKJX<[+5+B(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS
M9W-T<B`BM4RJ:[C\I$JUIK*D(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB
M"FUS9W-T<B`BM4RJ:ZO8I=^EV+_](%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(K5,JFNFVZKW
MQE^F^*I!OKFH^K%OI+VV?:KWQE\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`BM4RJ:[9]L=(@7"(E<UPB(*5(O&>D2BXB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0U"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM
M<V=S='(@(K5,JFNV?;'2("5S+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC
M92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(K5,JFNV?;'2
MNOO%0*1UIT"\TK+5("5S(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BM4RJ
M:[9]L=*EV+_](%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HU,38@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@
M(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(K5,
MJFNS<[&U($Q$05`@(*;XJD&^N2XB"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z
M,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*
M;7-G<W1R("*U3*IKQ:JH^B`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S
M=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T
M:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*(K5,JFNMJ[=SLUVI=ZC/I<ZJS*JZL4N]
M6"X@LZ&DP*JZLM.X8*2CI;^]5"X@O=#!<+6XIT&JNJATLLZZWK)ZK?NE2*CS
MIU6S0K)Z+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*
M;7-G<W1R("*U3*IKQ:JH^J9SJ/JQL:CNJNTH06-C97-S($-O;G1R;VP@3&ES
M="DB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S
M(&)O;VLN("5S(@IM<V=S='(@(K5,JFO%JJCZLW&P5+_]+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("*U3*IKQ:JH^K!TN&VR3:55+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,B"FUS9W-T<B`BM4RJ:\6JJ/JP=+AMLDVE52X@)7,B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<R(*;7-G<W1R("*U3*IKQ:JH^J;XJD&^N:JZK-O#]J]3
MJ<HB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(K5,JFNF7K1?
MLUVI=RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<FUD:7(@7"(E<UPB+B(*;7-G<W1R("*U3*IKIU*PHZ78O_T@7"(E<UPB+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(K5,JFO`>*9S("5S(*JZLUVI=RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B
MM4RJ:\!XIG.SQJ7WLUVI=RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("*U3*IKP'BF<[/&I?>S7:EW
M.B`E<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("*U3*IKP'BF<Z?SMW.U>Z:AJ.PZ
M(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("*U3*IKP'BF<[/&I?>S7:EW
M("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HBM4RJ
M:\!XIG.S7:EWP,DE<RX@IT&E::5(J,^ESB5SI*2JNJCDI4RE7*_@P'BF<[-=
MJ7>ISJ3BL,J]QKMSI%6ML;5[IJ&]6*CL("5S+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(K5,JFNW:K1-($Q$05`@(*;XJD&^N2XB
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:Z=2L*,@7"(E<UPB+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("*U
M3*IKI_.W<[-SM;BD2"X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(K5,JFNG\[=S
ML'2X;;)-I54N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T
M:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(K5,JFO"T+QG(%PB)7-<(CH@
M)7,@JKJS7:EW+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(J?DI*.H["!-;WII
M;&QA(*JZI,"MMBX@O="]5+M[I,"MMJQ/IU^V?;'2+B(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(K5,
MJFN]X:2IJ,^ESJK,(%PB)7-<(B"D5:9#Q7:MK:CLJTBE\Z=8(%PB)7-<(CH@
M)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E
M9"!T97AT(@IM<V=S='(@(J?>LTZE>2(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(K#JKF$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S
M(@IM<V=S='(@(KW2JNTB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G
M<W1R("*KV*7?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(JO8I=^D0*W3LW.ULB(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T
M<B`BJ]BEWZ1`K=.W<ZJZ(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B
MJ]BEWZ:XJTBE\Z=8(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#`*
M;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BJ]BEWZK,JKK%
M=JVM(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3D*;7-G:60@(D-R961I
M="!C87)D(&YU;6)E<B(*;7-G<W1R("*K2*7.I62XN;U8(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R
M;V%T:6$B"FUS9W-T<B`B0W)O871I82`HITK#N:;HJ,@I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B
M82(*;7-G<W1R(")#=6)A("BE:J3:*2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R
M("*EV*MEJKJDZZS;(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED
M(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(J78JV6W?+3!(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED
M(")#=7)R96YT(%1I;64B"FUS9W-T<B`BI=BK9:[)MJ$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G
M:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(J78JV6Z]*=](@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(J78JV6JNJC/I<ZJS"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*
M;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("*EV*MEI-&N\"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`BI=BK9:JZJJRJ<#H@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B
M0W5R<F5N="!S='EL92(*;7-G<W1R("*EV*MEJKJMMZ[F(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(J;;K7&D0*C'M6ZD2B5SJ^&ITJUNL/6FYJJZI'6G0"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G
M:60@(D-U="(*;7-G<W1R("*PQ:15(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*
M;7-G<W1R("*PQ:15(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-Y<')U<R`H
MP<FTMK#'M+4I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@
M(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(J;HJ+VZN*3E("A+3TDX+5(I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(J;HJ+VZN*3E("A7:6YD;W=S+3$R
M-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("*FZ*B]NKBDY2^O4:=*
MQ/6DY2`H2T])."U5*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(D-Z96-H(%)E<'5B;&EC("BQMJ=*ID"I3;#J*2(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#D@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(J3I(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R-S`*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@HBN.JNQJC3M[VF5[K9("B]T+#1IM(@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RTB"B)D<VXN<&AP*2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(JA#I.DB"@HC.B!A9&UI;B]D
M871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T
M<B`BOO"JK+CJKL;"<\3](@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-C@*
M;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("*XZJ[&KG>W:K1-(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#(@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`BI.FTP2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(J:LJ.RDZ;3!(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(W.38*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S
M='(@(K_OOMRDZ;3!(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$
M87DB"FUS9W-T<B`BI=6DT2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`BIU*PH\3FINQ?;"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("*D4:1'I.LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`BI%&V
M::;LO,:F<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("*T[J36
MP5FQQB(*"B,Z(&QI8B]P<F5F<RYP:'`Z,3$W(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3@W"FUS9VED(")$969A=6QT(@IM<V=S='(@(KEWLUTB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I
M9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("*Y=[-=PT.FXB(*"B,Z(&QI8B](
M;W)D92])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`BN7>S7:JZJ*VE]\/1IT\B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`BN7>S7:E2
MI4^XT:I2OKDH4VAE;&PI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S
M"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("*I=[AQ(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW,2!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(J=2L*,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(J=2L*/`>*9SKN8B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R
M-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(J=2L*.X<[+5(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@
M3&]G(@IM<V=S='(@(J=2L*.L]K_](@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L
M971E(%!E<FUI<W-I;VXB"FUS9W-T<B`BIU*PH\5VK:TB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,B"FUS9W-T<B`BIU*PHZ%"LDVJQ;9LI?,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W
M"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("*G4K"CP'BF<Z[F(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("*G4K"CQ.:F["(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(J=2L*.R>Z9SJKJTP*5.
MO,NJ3R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM
M<V=S='(@(J=2L*-<(B5S7"*JNL5VK:TB"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS
M9W-T<B`BO52I=ZUNIU*PHUPB)7-<(JJZQ7:MK:5(I,ZFN,5VK:T@/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BIU*PHZ9#(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L
M971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(J=2L*.ITK_OOMRJNJBM
MI??#T:=/N.JNQB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT
M(&-O;'5M;B(*;7-G<W1R("*G4K"CI=BK9:JZQ.:F["(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("*G4K"CI=BK9:JZ
MID,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`BI_.W<[5[IJ$@7"(E<UPB(*1WIU*PHRXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BN[RP9:[)MJ$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1E;FUA<FL@**2FL\$I(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R
M:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(K#=PT2T>:UZ(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M("*T>:UZ(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`BLM.X8"`HO="P
MT:;2($AO<F1E(+!/O_W`R:[7*3HB"@HC.B!L:6(O2&]R9&4N<&AP.C(P,0IM
M<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`BLM.X8+W0L-&FTJATLLZZWK)ZM6Z__2XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R("*LX[5O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("+%4\))M\6KUR(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA
M<W0@:&]U<CH@(@IM<V=S='(@(K/,J^&D0*1PKLFJNL53PDFWQ:O7.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@
M<&]I;G0Z("(*;7-G<W1R("+%4\))M\6KUSH@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`BL7&EJJ;<I6LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("*Q<:5KIMREJB(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`BI=B__2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@
M(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`BI4@@,C0@I'"NR:CN
MQ>.EW#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BQ>.EW+_OMK4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0B"FUS9W-T<B`BQ>.EW+C4LM.JNKEWL_@B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4
M048I(@IM<V=S='(@(L7CI=RY=[/X("A4048I(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(X,#8*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(L7C
MI=RNYJ:A(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HQ.3`*;7-G:60@
M(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("*VQ[!EIEZQ^"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)O=71I("BF3J6LIF$I(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D
M96QE=&4B"FUS9W-T<B`BI*.G4K"C(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<"(*;7-G<W1R("*DHZUNJKVQM:9SJ/H@;6%I;G1E;F%N8V4N
M<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#HB"FUS9W-T<B`BLL2D0+6GL$^__:Q/IU^E7:=TQ.:F[*97NMD_
M(*9PJD>L3[W0I,2_[RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI
M;FEC82`HIFBI^J6GI5LI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(D1O;6EN:6-A;B!297!U8FQI8R`HIFBI^J6GI5NF0*E-L.HI(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@
M:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("+!V:A3IK.Q8KBY
MMMP_(+7YI54N(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U
M,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BI%6X_"(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&]W;FQO860@)7,B"FUS9W-T<B`BI%6X_"`E<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(J15N/RS7:EWP,FN
MUZ5TIG.LL"!02%`@M7NFH2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q
M,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`BI%6IU*5<K^"J[2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS
M9W-T<B`BP\2K?B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B12U-86EL(@IM<V=S='(@(KEQI&RV;*7S(@H*(SH@;&EB+TYE="]3
M35,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A
M=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES
M('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@
M(K_YNWXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5C=6%D;W(@**3,I<JF
M:+JX*2(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(KUSO^@B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`BO7._Z+#/MO0B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R
M-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("*]<[_HN'.RU2(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("*]<[_HQ7:M
MK2(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`BO7._Z,5VK:TB"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(KUSO^@E<ZJZQ7:MK2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T
M:6]N<R!F;W(Z(@IM<V=S='(@(KUSO^B_[[:U(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(KUSO^A<(B5S7"*JNL5VK:TB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(KUS
MO^@E<ZJZQ7:MK2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I
M9"`B161U8V%T:6]N(@IM<V=S='(@(K'0J'PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G
M<W1R(")%9WEP="`HKDJDSBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S
M='(@(D5L(%-A;'9A9&]R("C"Q+JXI<NF:"DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L
M96UE;G0N+BXB"FUS9W-T<B`BI+BE\RXN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B
MN7&D;+9LI?,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`BN7&D;+9LI?.F[:=](@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R("*Y<:1LMFRE\Z;MIWVELK:WIVNF6"XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`BN7&D;+9LI?.]5+M[(@H*(SH@;&EB+TYE="]335,O9V5N97)I
M8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS
M9W-T<B`B16UA:6PM=&\M4TU3(+EHN42^N2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.3<*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R("*J[;&ALL6XN2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("*JQ:75
MJTBE\RXB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C8V,B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R("*JQ:75M;*J1RXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O
M<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R
M("*JQ:75MVJT3;:UI=@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W
M"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("*DN;-<IMO#P+19M*&D2K?3
MI/FH[*M(I?.DI"BZ]*VVO7.\9[S2IJ$I(#\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/R(*;7-G<W1R("*QTK#*M\:YJZ5KP>2E7*_@JNT_(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(U.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#`*
M;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(K6RI_2F?J7W(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`BJ?&D:KUSO^B^N2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("*F<*I'IT&[W:UNK:NS7;%+
MO5@LO="_Z:1*I$"MTZ9WI?ZPW:5Y+*C2IG`@)Z=!PV2JJZJZIE>ZV2`_)SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*
M;7-G<W1R("*F8J:YO^FD2KQVN;.JNKKTIWTB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@Y"FUS9VED(")%;G1E<B!T:&4@;&5T
M=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN
M96$B"FUS9W-T<B`B17%U871O<FEA;"!'=6EN96$@**BJN42T6*2ZJ,@I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5A("BDS*7?KU.HO:9W*2(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("*_^;M^(@H*(SH@;&EB+TAO<F1E
M+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(JO8I=^PS[;T)7.NR;5OI<V_
M^;M^(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S
M(@IM<V=S='(@(J=2L*.F4*A"P>/"23H@)7,@KLFU;Z7-O_F[?B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("*G4K"C
MIE"H0K!/O_TZ("5S(*[)M6^ES;_YNWXB"@HC.B!L:6(O2&]R9&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(@IM<V=S='(@(L6JJ/JDNJYE.B5S(*[)M6^ES;_YNWXB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S
M='(@(J?SMW.Q2[U8.B`E<R"NR;5OI<V_^;M^(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(D5R<F]R
M('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`BO7._Z*1`JVBP5*ZG(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E
M<UPB+B(*;7-G<W1R("*\9Z1*(%PB)7-<(B"NR;5OI<V_^;M^+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5S=&]N:6$B"FUS9W-T<B`B17-T;VYI82`HMU*H1J6GJ,@I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M171H:6]P:6$B"FUS9W-T<B`B171H:6]P:6$@**;GK\&D\:C(*2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@
M(KK8L=HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M175R;W!E(@IM<V=S='(@(D5U<F]P92`HO-JL=RDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S
M='(@(JA#(#$U(*3`Q,$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS
M"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BJ$,@,B"DP,3!(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(JA#
M(#,P(*SMQ,$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R("*H0R`U(*3`Q,$B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("*H0Z:XM6ZD2B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R("*H0R`S,""DP,3!(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED
M(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BJ$,@,2"DP,3!(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S
M.B(*;7-G<W1R("*]9*C2K<@Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q
M(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W
M"FUS9VED(")%>&5C=71E(@IM<V=S='(@(K#UIN8B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("*N
M:;9](@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I
M9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`BKFFV?;CJKL:GJ"(*"B,Z(&QI
M8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@
M)RDG(@IM<V=S='(@(JUNJ$0@)RDG(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O
M=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@
M(JCLM,&DZ2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS
M9VED(")%>'!O;F5N="(*;7-G<W1R("*XT;NAK?LB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&
M1R!#;VQO<B(*;7-G<W1R("*K9;2ZPT.FXB(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T
M<B`B1E10(*17ML>S7:EW+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP
M.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM
M<V=S='(@(L6JJ/JPOJ9NLUVI=Z6BL=$B"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("*U
M3*IKLW.]=:;<($Q$05`@IOBJ0;ZY+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M
M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(K5,JFNS<[UUIMP@4TU"(*;XJD&^N2XB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-S`V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("*]QKMSI:*QT:;;(%PB)7-<
M(BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S$Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BO<:[<Z6B
ML=&H["!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`BM4RJ:ZO8I=^D0*W3MW.JNB!305-,(+-SL;4N(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C4P,2!L:6(O5D93+V9T<"YP:'`Z-S0T"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`BMVBROJ6BL=&H["!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0V
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S
M(@IM<V=S='(@(L)>J/JEHK'1.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(K2V
MLW$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T
M<B`B1F%L:VQA;F0@27-L86YD<R"J:\3UITJZUKASKG$@*+"HNKBZ^Z_'M+6X
M<ZYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R;V4@27-L
M86YD<R(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@
M17)R;W(Z(@IM<V=S='(@(L19K:N_^;M^.B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`BML>O
M=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A
M>&5S(@IM<V=S='(@(K;'KW4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`BI$>DZR(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S
M='(@(K=0Q+$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P
M"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`BMU#$L3H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E
M=R!3:&]W97)S(@IM<V=S='(@(J3RI/*K0B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(K5UO,BP?;.W(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Y-#@*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("+$YJ;LL'VF0R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(S"FUS9VED(")&:6=L970@0T%0
M5$-(02(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-PHC
M+"!F=7IZ>0IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`BO^^^W,#)KM>E
M2+;7I$HZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II("BTM,#9*2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B1FEL92(*;7-G<W1R("+`R:[7(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("+`
MR:[7O,:EV#H@)7,@K=/`R:[7(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`BP,FN
MU[S&I=@Z("5S(,#)KM<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`BP,FNU\%@NMXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(L#)KM>F
M5[K9(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.#0*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(L#)KM>_[[[<(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T.3`*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(L#)KM>D
M5[;'(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X-0IM<V=I9"`B1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(L#)KM>D5[;'I5RO
MX*6\LU&DY+2I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM
M<V=I9"`B1FEL=&5R<R(*;7-G<W1R("*Y3,)OOKDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD
M(@IM<V=S='(@(D9I;FQA;F0@**KBQ/4I(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("*D5Z5BI.LB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V
M"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(J17J;8B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4U"FUS9VED(")&:7@@
M<F%T:6\B"FUS9W-T<B`BJ52I=Z3QJ-(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,P"FUS9VED(")&;&EP(@IM<V=S='(@(J17
MI%7$0:W+(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`BKT*PRB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED
M(")&;V<B"FUS9W-T<B`BP_HB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C,W(&QI
M8B]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD
M97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`BI=B__2`E<R"DHZ9SIF(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R
M"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(J9RJZS#0Z;B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(JVY
MJJLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(J9=K+#"<\3]OKFHPZ6\I.2TJ;QV
MN;.E7*_@+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&
M;W)E8V%S="`H5$%&*2(*;7-G<W1R("*N\+9(N7>S^"`H5$%&*2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A
M<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U
M<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B*Y
M=[/XI-&\QB`HN7>S^*31O,:E7:Q!I=6DT:5(I,ZI7;:AJKJXZJ[&.Z9PJD>Y
M=[/XI-&\QKC[JOBQ3J;[I<ZD\;C[O&6T5*JZJJDB"B*ML2DB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@
M<&%S<W=O<F0_(@IM<V=S='(@(J?1L$^Q2[U8(#\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("*J[;/F
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE
M(@IM<V=S='(@(J1PNWDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*
M;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("*D<+MYP_ZKK"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T
M<B`BI'"[>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B
M1F]R='5N97,@,B(*;7-G<W1R("*D<+MY(#(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`BO=>^PB(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A
M<F1S(@IM<V=S='(@(J;;L,K"X*M((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`BK%"T
MP:2M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(J[8K%LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-E("BJ:[#J*2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A
M;B(*;7-G<W1R(")&<F%N8V4L($UE=')O<&]L:71A;B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC
M:"!'=6EA;F$B"FUS9W-T<B`B1G)E;F-H($=U:6%N82`HJFO$W;M<J,BHNBDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F5N8V@@4&]L
M>6YE<VEA("BJ:\3=K,&G4:6GINBHR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T
M:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("*Q2*7SI$@B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y
M-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(K%Q(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I
M;VXB"FUS9W-T<B`BI[F^X[1YK7HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM
M<V=S='(@(KJAI.LB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.
M86UE(@IM<V=S='(@(J7^IE<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O
M;B`HI5NT7BDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I
M;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R
M>3HB"FUS9W-T<B`BP\"T63HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M
M8FEA("BES*3QJ,@I(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(K*CI<T@)7,@K=.H=++.LUVI=R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D
M92(*;7-G<W1R("*D=[*CI<VJNK-=J7>XZJ[&(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*
M;7-G<W1R(")'96]R9VEA("BS[*IVJ,BF0*E-L.HI(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N
M>2(*;7-G<W1R(")'97)M86YY("B\=[#J*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S
M='(@(D=H86YA("BM>Z_'*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")'
M:6)R86QT87(@**J]I:S#N:K[*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(J97NMDB"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T
M<B`BJV6IN2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B
M1V]E9&5L(@IM<V=S='(@(JWTO'>ZN"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R(")';V]G;&4@IF&YSR(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE(+=JM$TB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,V"FUS
M9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`BIL>VI2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B
M"FUS9W-T<B`B1W)E96-E("BGQL.^*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Q"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`BI\;#
MOJ3E("A)4T\M.#@U.2TW*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'
M<F5E;FQA;F0@**[FLZ[$]:YQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B
M9W)E;F%D82`HKN:WYZ_'N48I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*
M;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(KASLM6ZWK)Z
M(@H*(SH@;&EB+TAO<F1E+T=R;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>2(*;7-G<W1R("*X<[+5IE>ZV:2CL6^JQ:75(@H*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@M4RJ:[=S
MO%>X<[+5("5S+B"F^*I!OKFF7L"S.B`B"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,3$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM
M<V=S='(@(D=R;W5P7VQD87`Z(+5,JFNG4K"CN'.RU2`E<R(*"B,Z(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z(+5,
MJFNG\[=SN'.RU2`E<R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$T
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`BN'.RU2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L;W5P92`HK?2\=ZREM+8I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2`HP_:N<2DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82`HI<JF8;"HJ=0I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G
M<W1R("*NYJZFINBN<2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C(V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(JC3NZO%=JVM(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(K-8
MJ\BO9*BE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE82`HM%BDNJC(
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES
M<V%U("BT6*2ZJ,BD\:_!ID"I3;#J*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S
M='(@(D=U>6%N82`HNURHR*BZ*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY
M-C0*;7-G:60@(DA434PB"FUS9W-T<B`BME>DY;-SM;*[>:BE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H
M<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("*GY*2CJ.P@2%144"#%Y\/2+B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS
M9W-T<B`B2&%I=&D@**[\IF$I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("+"^+3J+;IT
MNN(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,@IM<V=I9"`B2&%Z92(*;7-G<W1R("+&1R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C$*;7-G:60@(DAE861E
M<B(*;7-G<W1R("*J[<!9(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`BJNW`62(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S
M='(@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(
M96%V>2!4+5-T;W)M(@IM<V=S='(@(J1JN7"K0B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS
M9W-T<B`BI\:G0JC3I.4@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`BL*JKUR(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ
M.#0@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B
M2&5L<"(*;7-G<W1R("*[H:GZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B
M"FUS9W-T<B`BO7._Z+ZYJ,^ESKNAJ?HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3,W-0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(KNAJ?HB"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B
MI6*R>2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(K-ON,RL3\#)KM>JNK9]
MJ6PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`BL*HB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N
M:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(JYA7VTB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")(;VQY(%-E
M92`HL>N_S:FC*2(*"B,Z(&QI8B](;W)D92YP:'`Z,34S.0IM<V=I9"`B2&]M
M92(*;7-G<W1R("*N82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U
M"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BINVN8:9AIWTB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y
M(@IM<V=S='(@(JYAI=B__2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(J;MKF&Y
M<;C<(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R`HI[NS
MHZG4M+4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG
M("BMN[3D*2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I
M9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B"V;*7S("4R)',@I*2Y2JCLM4RNQ*JZ("4Q
M)',@6$U,N.JNQB(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@M4RV
M;*7SOD&F6*JKI?,@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@MFRE\R`E,B1S(*2DI^2DHZCLJJNE\ZNLND$@)3$D<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B"D=Z:HI5RJNK*^L*,@)7,@7"(E<UPB(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B
M.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL
M)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"^XZ98I'6U
M>[O=K6X@)V1O;7AM;"<@JKH@4$A0(*FUIODB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@M4RJ:ZO8I=\@)7,@JJNE\ZJZ(%A-3""^
M\"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"U3*IKLKZPHR`E<R!<(B5S
M7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B"U3*IKP/*H^K.AI?<@)7,@JZRZ0:JZ($U)344@P]&G3[BYO5@B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"U3*IKIE"H0B`E<R!<
M(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,S,R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@M4RJ:Z90
MJ$*DP*C).B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@I;RJOJJZI,"HR2!<(B5S7"(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T
M"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BI/2EK;UU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(J3TI:VYU*52(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I
M9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`BI/2EK3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(J=!IG"F\ZCLIKD@/R`HO="QU*UZ(2DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M("*G0:UNIEBHUJ9HI-:MT\3FINRI3S\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS
M*2!A<F4@=&AE<F4_(@IM<V=S='(@(L3FINR\QJ78ID"M<#\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS
M9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R("*G0:UNIEBHUJ9HI-:F0ZE//R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G
M:60@(DAU;6ED:71Y(@IM<V=S='(@(K?#J]<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@
M(K?#J]<Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B
M2'5M;W)I<W1S(@IM<V=S='(@(K?&O5VD:JYV(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y
M(@IM<V=S='(@(DAU;F=A<GD@**9)I/JG42DB"@HC.B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C,U
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(DE-05`@MFR]8ZO8I=^EHK'1.B`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U=&@O
M8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!4""V;+UCIU*P
MHZ6BL=$Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.2!L
M:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("))34%0(+9LO6.ZS[K0L'2X;:O8I=^EHK'1.B`E<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S(@IM<V=S
M='(@(DE0(*;LIWTB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW
M-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))
M4""F[*=]M4RJ:ZC/I<XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP
M:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN(@IM<V=S='(@(DE0(*;LIWVHPZ2CIF(@0TE$4B"JNJ2YLURP
MS[;TI*0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`BIF*K
MX:VQM*&D2J9#7VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B26-E;&%N
M9"`HID*N<2DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED
M("))8V]N<R!/;FQY(@IM<V=S='(@(J_"N<^EW"(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@
M)7,B"FUS9W-T<B`B)7.JNKG/I=PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`BN<^EW*3.
MI.6F<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED
M96YT:71Y)W,@;F%M93HB"FUS9W-T<B`BJ*VE]\/1IT^JNJ97NMDZ(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(J9PJD>U3*IK
MI;^]5*9AQ>.EW"P@)7,@I4BE=+9]L=*V;*7SJ?.W<[7XM:&W[:2D+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D
M;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y
M;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HBJ,^ESB!);G1E<FYE="!%
M>'!L;W)E<B#"<\3]OKFNR:9PJD>H4Z:SK-VH[*7TIO.JNJ1PN<^EW"P@IT&E
M::_@N]VM;J3$O^^S;ZW3MK4B"B*EV*5(P_:SK"!03D<@O':YLZJZP?3"PZ[$
MJD<N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W
M,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*
M(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(J9PJD>LW:CL
MLV^K:*A3IK.\=KFSJKJP5*ZG++-OJNVEW*=!JKK"<\3]OKFU3*IKQ>.EW*17
MML>JNKQVN;,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*
M;7-G<W1R("*\=KFSN7?$_3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS
M9W-T<B`BO':YL[KTIWTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB
M"FUS9W-T<B`BO':YL[KTIWTZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDB"FUS9W-T<B`BO':YLZC3IMO#P+19(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(KQVN;.HTZ;;
MP\"T63HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA
M9V4@=7!L;V%D(@IM<V=S='(@(J17ML>\=KFS(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("*\=KFS(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`BMM>D2BP@J$+&2B`E9"(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("*VUZ1*Q.:F
M[#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED
M("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(K;7I$K$YJ;L.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`BIF*KX:VQM*&D
M2J9#7W,B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G
M:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`BO^FD
M2J2CI;^]5*JZIT"ESKU8+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(KW0P,NL9*=!JKJHSZ7.JLRF5[K9I,ZQ2[U8
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*
M(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`BJ,^ESJK,IE>ZV:2CI;^]
M5*G.JLRY<:1LMFRE\Z;MIWVD=\7<I_,NO=#!<+6XIT&JNJATLLZZWK)ZK?NE
M2*CSIU6S0K)Z+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("*\
M5Z5;P5FQQB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:6$@**9,J]<I
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS
M9W-T<B`BK=.G3ZC/I<ZJS"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(DEN9&]N97-I82`HIDREIRDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("*XZK!4(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M871I
M;VXB"FUS9W-T<B`BN.JP5"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N(@IM<V=S='(@(K5,I6FESJJZN.JP5"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN
M<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$K$YJ;L7V\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("*TH:1*
MN<^D^2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("*TH:1*JNVNYB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*
M;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("*TH:1*NO2X]+-SM;(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R
M("*F8JMEK;&TH:1*Q.:F[%]#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("*F8J78
MJV7$YJ;LJ^&ML;2AI$JD0*W3MW/$YJ;L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`BIF*EV*MEQ.:F[*MEK;&TH:1*I$"MT[=SQ.:F["(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`BIF*EV*MEID.KX:VQM*&D2J1`K=.W<Z9#(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`BIF*EV*MEID.K9:VQM*&D2J1`K=.W<Z9#(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*
M;7-G<W1R("*F8J78JV6X8,))J^&ML;2AI$JD0*W3K'&XJ"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N
M;V1E(@IM<V=S='(@(J9BI=BK9;A@PDFK9:VQM*&D2J1`K=.L<;BH(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`BM*&D2J5IM,"E3KS+JD\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#HB"FUS9W-T<B`BMW.Q2[U8L4ZQ2+5OJ.RS;ZW3MFRE\Z9AIWTZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`BIF*KX:VQ
MM*&D2L!XIG.NYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*
M;7-G<W1R("*F8JMEK;&TH:1*P'BF<Z[F(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T
M(&-O;'5M;B!A9G1E<B(*;7-G<W1R("*F8JOAK;&TH:1*Q.:F["(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(J9BJV6ML;2A
MI$K$YJ;L(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP
M"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`BM*&D2K9LI?,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B
MIF*KX:VQM*&D2JQQN*@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(J9BJV6ML;2AI$JL<;BH(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("*F8JOAK;&TH:1*ID,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("*F8JMEK;&T
MH:1*ID,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("))
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ(@IM<V=S='(@(J9WI?ZPW:5YJKJUJJ[7.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R
M="]-;V1I9GD@26UA9V4B"FUS9W-T<B`BM*&D2B_%W*?SO':YLR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@
M(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("*TH:1*+\7<I_.Z]+CTLW.U
MLB(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(L))O,:DHZBLI4BFW*GSM4RJ:[;'L&6U
MN;!TN&VX<[+5+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(L))
MO,:DHZBL+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<Y"FUS9VED("))
M;G1E9V5R(@IM<V=S='(@(K[CO,8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(K[CO,:F0R(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("))
M;G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("*U3*[$
MJKH@541(**C/I<ZJS+CJKL:J[<!9*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E
M<W,O>FEP+G!H<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV
M86QI9"!:25`@9&%T82(*;7-G<W1R("*U3*[$JKH@6DE0(+CJKL8N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`BM4RNQ*JZP+.ESK5[IJ$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@
M8F%T8V@@240N(@IM<V=S='(@(K5,KL2JNJ?EIKBXN;U8+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#DQ(&QI8B](;W)D92]&;W)M+G!H<#HR,38R(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C,V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,S`S(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED
M("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("*P9:58JKJXZJ[&
MM4RNQ"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R
M("*U3*[$JKJEV+S0INVG?2(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N
M<&AP.C$P.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I
M;&4@9F]R;6%T(@IM<V=S='(@(K5,KL2JNL#)KM>NYJ:A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E
M;G-E(&ME>2XB"FUS9W-T<B`BM4RNQ*JZL<+%=KU8+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(K5,KL2JNJ9AL,\N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@
M;7-G7W1Y<&4N(@IM<V=S='(@(K5,KL2JNB!M<V=?='EP92XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`BM4RNQ*JZJ<ZGY*2CJ.P@
M87!I7VED+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS
M9W-T<B`BM4RNQ*JZJ<ZGY*2CJ.RPT;S&+B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`BM4RNQ*JZI/?%=JVM+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB
M"FUS9W-T<B`BM4RNQ*JZN=FF\</1IT^]6"XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D
M92XB"FUS9W-T<B`BM4RNQ*JZLJ.K?KU8+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L
M+B(*;7-G<W1R("*U3*[$JKJS<;!4J/.I=RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C<Q"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@
M(K5,KL2JNJ:LI?.D2#I<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$P-S4@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4X"FUS9VED("));G9A;&ED
M('-H87)E(&]B:F5C="(*;7-G<W1R("*U3*[$JKJDP*C)JJNE\RXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV
M86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`BM4RNQ*JZJ-.WO:;MIWTN
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G
M:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("*U3*[$JKJX5;#J
MO5BXZJ[&+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("*XZK*C(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-0IM<V=I9"`B26YV97)T('-E;&5C
M=&EO;B(*;7-G<W1R("*F7K1?O^^^W"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F("BE[*[4*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%Q("BE[*G4
MITHI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER96QA;F0@*+=2NKC$
M]2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE
M(&]F($UA;B(*;7-G<W1R("))<VQE(&]F($UA;B`HL-*N<2DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O
M;&%T960@5"U3=&]R;7,B"FUS9W-T<B`BI[VSH;EPJT(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES
M<F%E;"(*;7-G<W1R("))<W)A96P@**5(IN*F0RDB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(L.Q
MM6^JS"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(K'7Q>DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET
M86QY(@IM<V=S='(@(DET86QY("BX<:1JIU$I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A
M(@IM<V=S='(@(DIA;6%I8V$@**3ZME*E6RDB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,SDY(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("*D0*3K
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!A;B`HI.FENRDB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B2F%P86YE<V4@*$E33RTR
M,#(R+4I0*2(*;7-G<W1R("*DZ:3E("A)4T\M,C`R,BU*4"DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B
MOT&FZ*YQ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&%N("BL^:6Y
M*2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*
M=6QY(@IM<V=S='(@(J1#I.LB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("*DNZ3K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I
M9"`B2G5S=&EF>2(*;7-G<W1R("*Y[[OT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(KAMI*0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF
M>2!&=6QL(@IM<V=S='(@(J6JI6NY[[OT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I
M9GD@3&5F="(*;7-G<W1R("*^8:6JN>^[]"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T
M:69Y(%)I9VAT(@IM<V=S='(@(KYAI6NY[[OT(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS
M=&%N(@IM<V=S='(@(DMA>F%K:'-T86XB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C8S"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("*K3Z]DK>R\RR`_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+
M96YY82`HJM:HR"DB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM
M<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")+97)B97)O<R"[>\/2O_F[?BXB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@
M(J[6I-^W<Z3B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`BJO?&7ZO8I=\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN
M="(*;7-G<W1R("*J]\9?KU.\>"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("*J]\9?JOBKUR(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y
M<&4B"FUS9W-T<B`BJO?&7ZNLND$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(JKWQE^[>:IK
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(J78JV6JNJ2]MGVJ]\9?IOBJ0;ZYI*0LI'>X9Z9SIF*G0:JZJO?&7RXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS
M9W-T<B`BJ."UHR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A
M=&D@*+#RJ+VDVK2U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8@**5?P?HI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96$L(%)E<'5B;&EC(&]F("BK;L'Z
M*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")+;W)E86X@
M*$550RU+4BDB"FUS9W-T<B`BP?JDY2`H155#+4M2*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W
M86ET(@IM<V=S='(@(DMU=V%I="`HK.RKPJ]3*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ
M<W1A;B(*;7-G<W1R(")+>7)G>7IS=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(JJIK;&P=+AM
M7WDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),
M86YG=6%G92(*;7-G<W1R("*[>:BE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86\@4&5O<&QE)W,@1&5M
M;V-R871I8R!297!U8FQI8R`HO&2PZBDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`BI%6E8J3K(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D
M($-H86YG92(*;7-G<W1R("*SS*KQI$"FN+%+O5C%W*?SJ?,B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED
M("),87-T(%%U87)T97(B"FUS9W-T<B`BI%6IMJ3K(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B
MI%>FN*?SMW,Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("*D5Z1`IKBU
M;J1*.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("*D
M5Z1`IKBU;J1*.B`E<R"FVR`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW
M,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(J17I$"FN+5N
MI$HZ(++$I$"FN+5NI$HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),871V
M:6$@**G4LN:Z^ZC(*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM
M<V=I9"`B3&%W(@IM<V=S='(@(JIKJ]\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*
M;7-G<W1R("*JJ:VQL'2X;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQE
M8F%N;VX@*+ZDI-JYX"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`BI:K#
MY"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`X"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R("*EJL/DJNW`62(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`T"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("*EJL/DK<@B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R`HO^"OP::K*2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5V96PB"FUS9W-T<B`BMU*QH2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G
M<W1R("),:6)E<FEA("B_X*3QM^>HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B
M($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB>6%N($%R86(@2F%M86AI<FEY82`H
MIU&D\:C(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C
M:'1E;G-T96EN("BF0Z3DM+"TM;5N*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM
M<V=S='(@(K=,JT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("*D<*M"(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G
M:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`BIJVFLZ1PJT(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B
M3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(K'?IK.D<*M"(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT
M(%)A:6X@4VAO=V5R(@IM<V=S='(@(J1PL'VK0B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN
M('=I=&@@5&AU;F1E<B(*;7-G<W1R("*D<*M"IK.Y<"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3
M;F]W(@IM<V=S='(@(J1PL[<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS
M9W-T<B`BI'"P?;.W(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS
M9VED("),:6UE<FEC:R(*;7-G<W1R("*EM*ION-8B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("*S<[6R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`BLW.ULL))J.PZ
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<B"FUS9W-T<B`BQ>.EW*[)LW.ULK9LI?.F[:=]J.R]<[QGMFRE\ZVV
MK;$B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ
M.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(K-SM;(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("+#0Z;B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B
M"FUS9W-T<B`BID.E6"`M(*C/I<ZJS*5II4BLW:CLLV^MTZM(I?.G6"(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S
M(@IM<V=S='(@(J9#I5BXZJ[&KG<B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("*F0Z58
MNZ&I^KS0PT0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),
M:7-T(%1A8FQE<R(*;7-G<W1R("*F0Z58JNVNYB(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(K!1O=>X<[+5+<#)KM?"9"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E
M<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(K!1O=>X<[+5
M+:A$IU4B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`BL%&]U[ASLM4MP]&G3[BYO5@B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N
M97(B"FUS9W-T<B`BL%&]U[ASLM4MOM:FLZK,(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B
ML%&]U[ASLM4ML4BE\Z1((@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("*P4;W7N'.R
MU2VM<;Y<(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS
M9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(K!1O=>X<[+5+:CZKOBM
M<;Y<(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("*F
M0Z58MWRTP:6BL=$Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R("*F0Z58J,^ESJK,I:*QT3H@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(J9#I5BHSZ7.JLRJNJ5<K^"S4</VLZPB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B
M"FUS9W-T<B`BI.6^QR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI
M=&AU86YI82`HI=^SLZE[*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(KC\I$JD
MI"XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G
M:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("*W[:9AKLFVH3H@(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`BIF&PS[M0KLFVH2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV
M-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BIF&PSR(*"B,Z(&QO9VEN+G!H
M<#HQ.#8@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R("*U;J1*(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BM6ZE6"(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`BM6ZD
M2B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN
M(%1A<VMS(@IM<V=S='(@(K5NI$JD=:=`(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS
M9W-T<B`BM6ZD2J6BL=$L(+W0P,NL9+O5I%6JNJ7.I.&F5ZE-L4N]6"P@M4VK
MX:VKN-4N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX.`IM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R("*U;J1*I:*QT2XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(JKXI7DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS
M9W-T<B`BMU*QH2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`BIT,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS
M9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(J1PO&>GQL.^O,:F
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`BI'"\9ZG4I$*\QJ9R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R("*D<+QGP[FPJ+S&IG(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`B3'5X96UB;W5R9R`HOV.TR[/Y*2(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.3@@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S-@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`BI.LB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(JA#I.FP5*ZG
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED
M(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S
M='(@(DU3+51.148@JOZE6\#)KM>DI*A3IK.XZJ[&+B(*"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(DU31R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C
M86\@*+]$JODI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F("BPJ*CDN7FF0*E-L.HI(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-C87(@*+"HN4:E6[2U
MI5LI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I
M8R(*;7-G<W1R("+%7;-.(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C@S"FUS9VED(")-86EL(@IM<V=S='(@(K9LI?,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@
M(K9LI?.ZWK)Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S
M='(@(JO8I=^S<[6R7VLN+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-
M86QA=VD@*+"HJ=2KPBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA
M;&%Y<VEA("BPJ*C3INBHR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@
M(DUA;&1I=F5S("BPJ+JXIF&DTBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B
M36%L:2`HL*BG42DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A("BP
MJ+JXI4PI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B
M"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("*ZWK)ZIT&JNJ3`P_XLJ,.E
M0JRPI,##_K-=J7?#0Z;B+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P
M,C0@IF&YSR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#@T"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W0@IF&Y
MSR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B
M36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`BI%2DZR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+#Y*S)(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@
M4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`BO-"P3Z:H(*S=N4POI;RLW;E,
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R("*\T+!/IJBHY*5,JKK#T:=/("BHTJ9P+B"MJZUN+Z1W
MIE["T"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R
M<VAA;&P@27-L86YD<R`HL*BN3+JXN'.N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ
M=64B"FUS9W-T<B`B36%R=&EN:7%U92`HL*BTHZ6GITJN<2DB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE
M;&1S(@IM<V=S='(@(J3'L'3$YJ;LI*0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B
M"FUS9W-T<B`B36%U<FET86YI82`HK52G4;;PI:>HR"DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA
M=7)I=&EU<R(*;7-G<W1R(")-875R:71I=7,@*+ROJ+VFZ+2U*2(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@
M86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(J2YLURJNK/,I&K"2;S&+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`BJOZE\[S&I=BD
M=[97I5BDN;-<I%>MK2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM
M<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(K/,JO$@
M,C0@I'"NR:JZL\RPJK?%J]<Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("*S
MS*KQ(#8@I'"NR:JZL\RPJK?%J]<Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS
M9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@
M(K#/MO2D5ZVMO,:EV"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#(@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#,*
M;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(J2YLURSS*1JJOBKUR(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB
M"FUS9W-T<B`BI*VDZR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y
M;W1T92`HL*BL^:]3KG$I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P
M"FUS9VED(")-961I8VEN92(*;7-G<W1R("+"Y;['(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G
M<W1R("*FJ*W[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I
M9"`B365N=2!M;V1E.B(*;7-G<W1R("*_[[/FO-*FH3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED
M(")-97)G92!C96QL<R(*;7-G<W1R("*F6*C6P'BF<Z[F(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*
M;7-G<W1R("*V;*7S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("*V;*7SQ>?#TJ1WI[FFJ"RF_:Q/J,^ESJK,JKK#
ML;.YJV^U3*IKLW&Y3,7GP](N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T
M<B`BPK*P5*1WN4RTP2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@
M='EP92(*;7-G<W1R("+"LK!4JZRZ02(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("*E
MV*MEI-&N\"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R(+#/MO2U
M3*IKJ,^ESBXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B
M(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B365T
M87(@L,^V]+5,JFNHSZ7.+B"RT[A@O="PT:;2J'2RSKK>LGJU;K_]+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B365T87)$0B"I?*6\LW.Q
MM2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-R!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM
M<V=S='(@(J3HJFLB"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$@
M;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("*DZ*IK
M(%PB)7-<(B"EO+-1J7>X<2(*"B,Z(&QI8B](;W)D92]24$,O<F5S="YP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<R(*;7-G<W1R("*DZ*IKI;RI=[AQ+B"E2*E)I7.D
MZ*IK.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L
M:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B
MI+VH[B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE>&EC;R`HOJ6FZ*WT
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM
M<V=S='(@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8@*+%+ITK#
MN:6GINBHR"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R("*DI+:A(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-
M:6UE(%1Y<&4B"FUS9W-T<B`B36EM92"KK+I!(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R("*SS*KQ(#(T(*1PKLFJNK/,IT.WQ:O7.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`BL\RJ\2`V(*1PKLFJNK/,L*JWQ:O7.B`B"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O
M<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`BL\RU=;%+O5BN
MQ+3!J7REO*CLM,$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,S"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BK$VN9R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*
M;7-G<W1R("+"^+:U(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(J?DI*.H["!0
M14%2(*5=N,L@2%144%]297%U97-T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("*S7:EWP,F_\J6B+B"F<*I'
MK6ZHSZ7.LV^MT\"SI<ZU>Z:AIT&ELK:WLGNF8K1.LJ.ES:5,+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(J?DI*.H[,*RL%2JNB!)1"XB"@HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED
M(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R
M("*GY*2CJ.RELK:WJKH@4$5!4B"E7;C+($UA:6PN(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S
M<VEO;B!)1"XB"FUS9W-T<B`BI^2DHZCLMWRTP:JZ($E$+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO
M(@IM<V=S='(@(JQ0M,&D0"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`BIN:PRK9LI?,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I
M9"`B36]D97)A=&4B"FUS9W-T<B`BM\6I32(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS
M9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(J?SMW.DZ;3!(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S
M"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(JW7I^^Z]*=](@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS
M9W-T<B`BO-*RU2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B36]L9&]V82P@4F5P=6)L:6,@;V8@*+RONKBF:*7+*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R`HO*^OQZWT*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L:6$@*+M8I6HI(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U.#@*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S
M='(@(J3KI,ZF?B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3<*
M;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BJ$.DZR(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E
M<G)A="(*;7-G<W1R("*[6+;KJ=2O4R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B
M"FUS9W-T<B`BI.NLVR(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DV(&QI8B]&
M:6QE+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM
M<V=S='(@(J9BLL0E9*;FI^2H[*JZQ.:F[+S&I=BD=[97I5BY=[3!)60N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(KROK*6M]"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`BIFBVLZ[)M+@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*
M;7-G<W1R("*F:+:SKLFSL2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B
MM+BNR:9HMK,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#D*
M;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("*D5;*^(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`BI:JROB(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4Q-PIM
M<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("*E:[*^(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@
M(J17LKXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(S"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`BI%6ROB(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C(@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PIM<V=I9"`B36]V92!U<"(*;7-G
M<W1R("*D5[*^(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M
M8FEQ=64@*++VI%2D\:=**2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X
M"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B
MO<:_[Z:AI%6IU*5<K^"J[2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#4U"B,L(&9U>GIY"FUS9VED(")-=6QT:6UA<"!52R!M
M87`B"FUS9W-T<B`BIFB\=KFS(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R
M-#8*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("*]QK_O(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C
M;W5N="(*;7-G<W1R("*GVJJZL6*XN2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M("*GVJJZL6*XN;CJL%0B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`BK=.D2*^XI7@B"@HC.B!S
M97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@
M3&%Y;W5T(@IM<V=S='(@(JW3I$BON*5XK;:ML;!TN&TB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY
M86YM87(B"FUS9W-T<B`B37EA;FUA<B`HO7&H;"DB"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@
M1&\@3D]4($%G<F5E(@IM<V=S='(@(J2C+*?:I*.F4+=.(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("*F5[K9(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI
M8FEA(@IM<V=S='(@(DYA;6EB:6$@**BZILRD\:C(*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U
M<G4B"FUS9W-T<B`B3F%U<G4@*+_5OGPI(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G
M<W1R(").97!A;"`HI:>J>;JX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS
M9W-T<B`B3F5T:&5R;&%N9',@*++\Q/4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S
M($%N=&EL;&5S(@IM<V=S='(@(DYE=&AE<FQA;F1S($%N=&EL;&5S("BR_,3=
MIG>F8:9#M+4I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(DYE='-C87!E(*RP
ML/+"IJJZNO2G?2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T
M"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").
M971S8V%P92"^S,/2IT"\;[KTIWTB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G
M<W1R(").971S8V%P92"^S,/2K$:UIKKTIWTB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@I_.W<[KTIWTB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B3F5T<V-A<&4@IT"\;[KTIWTB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33""F^*I!OKFF5[K9(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E
M(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V-A<&4@OLS#TJJZ
MM?FXT2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED
M(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(DYE='-C87!E
M(+[,P]*KK+I!(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM
M<V=I9"`B3F5T=V]R:R(*;7-G<W1R("*Z]+CTI'6HXR(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(K%QI;PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B
M3F5W($-A;&5D;VYI82`HMW.SV*B]IFBEIZC(*2(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O
M<GDB"FUS9W-T<B`BMW.\5Z3`P_XB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY
M-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BO&>K
M2+6Y("5S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M
M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@
M36]O;B(*;7-G<W1R("*W<Z3K(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB
M"FUS9W-T<B`BMW.HSZ7.JLRF5[K9("BK1*6RK6XI(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@
M6F5A;&%N9"(*;7-G<W1R(").97<@6F5A;&%N9"`HK\.FZ,3U*2(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W
M;W)D(@IM<V=S='(@(K=SL4N]6"(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP
M:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`BMW.Q2[U8L4ZI\R5XJ.RTP2XB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(K=SL4N]6*2CLL6F6"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ
M"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(K=SM?BUH2`H
M7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,CDQ"FUS9VED(").97=S(@IM<V=S='(@(K=SNT0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@
M(K=SNT2X<[+5(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`BI%6D0*A"(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S(@IM
M<V=S='(@(J15K=.DZZS;(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS
M-S(@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R("*D5:1`K=._[[:U(@H*(SH@;&EB+TAO<F1E+U5)+U!A
M9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(J15I$"MMB(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82`HI:>E6ZG4I<HI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B`HI:>DZ2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82`HJ6"DSJ=1J,@I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B
M"FUS9W-T<B`BL=^D5R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E("BO
MPZY*KG$I(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`BIU\B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S
M='(@(K5,I6FHT<7CI=RN=+*GJKJS7:EWN.JNQBXB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("*U3*5II<ZJNK6FLJ2K
MV+-Y($E33R"\=KFS+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B
MJ%.FLZ?EIKB\RZ:A+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C<Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(T-0HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(JG2J_RI=ZJZ
MINRX;:17J%.FL[#/MO2F<Z9B(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP
M:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.THZC1IN:HQK[DIE>Z
MV:5(J-$@34-!3"#%Y\/2+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T
M"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(JA3IK/%W*?S+B(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("*U3*IK
MIF*EV*MEQ7:MK:2DO%>E6Z:XQ7:MK2XB"@HC.B!L:6(O2&]R9&4N<&AP.C$V
M.2!L:6(O2&]R9&4N<&AP.C4P."!L:6(O2&]R9&4O571I;"YP:'`Z-S8X"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`BJ%.FLZO\J7>JNB`E<R"S
M7:EWN.JP5"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#0T"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RXB"FUS9W-T<B`BJ%.FLZO\J7>JNB!&5%`@5D93(+-=J7>XZK!4+B(*"B,Z
M(&QI8B]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("*H
M4Z:SJ_RI=ZJZ(%-13"!61E.S7:EWN.JP5"XB"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(JA3IK.K
M_*EWJKH@4U%,+49I;&4@5D93LUVI=[CJL%0N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T
M+B(*;7-G<W1R("*U3+/1OFS"2;S&+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+B(*;7-G<W1R("*EO+2CJ-&EV*JZ+B(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,#,*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B
MP,FNUZ6\I%>VQR(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I
M9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(J?DI*.H[+G/I=PN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@
M(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`BINRX;;CJL%2I?*6\LUVI
M=R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@
M(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("*I?*6\M*.HT:;LN&VX
MZK!4+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*
M;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(J6\M*.HT<*R
ML%0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM
M<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(J6\J_RI=Z97NMDN
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I
M9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BI;RK_*EWN+F]6"XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("*GY*2CJ.RYSZ7<+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`BJ%.FLZO\J7>Q2[U8I4BHT2!(5%10(,7GP](N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BJ%.FLZO\J7>Q
M2[U8I4BHT2!)34%0(,7GP](N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BJ%.FLZO\J7>Q2[U8I4BHT2!+
M97)B97)O<R#%Y\/2+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C<W
M(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC.B!L:6(O2&]R9&4O075T
M:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(
MJ-$@3&]G:6X@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP
M.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BJ%.FLZO\J7>Q2[U8I4BHT2!005-3
M5T0@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("*H4Z:SJ_RI=[%+O5BE2*C1(%--0B#%Y\/2+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@HBI;R_Z:1*($]P96Y34TP@I$>DN+#UIN;`R:JZ
MI?ZX]*Y\+B!02T-3(#$R(+-7KN:JNJ5;L4NXZJ[&N]VM;J7.J.RXT[5[IJ$N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I
M9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("*H4Z:SJ]V\9JJZM?FE
M5:73O=`N(@H*(SH@;&EB+U9&4RYP:'`Z-S8U"FUS9VED(").;R!Q=6]T82!S
M970N(@IM<V=S='(@(KK/NM"P=,-"I;RS7:EW(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@
M<G5L97,B"FUS9W-T<B`BM4RNYKUU(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT
M.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(JE\
MI;RK_*EWQ.:F[*3`N6JF<J2X+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM
M<V=S='(@(K5,KMB]=2(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#<*;7-G:60@
M(DYO('-U8V@@9FEL92(*;7-G<W1R("*U3*:YP,FNUR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`BM4R\R*9S
MI=B__:5IJ-&GUJCZ+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S$@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(J6\
MML>P9:C/I<ZJS*97NMFISK%+O5@N(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR
M<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B
M"FUS9W-T<B`BM4RE::7.JKH@6$U,(+CJKL:S4;;'IEXB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(JK%
MI=6MR"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*M[*ELLUVI=\#)I*2G
MY*2CJ.RJJ:6[N.JP5"X@K:NW<[*CI<VS7:EWP,DN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BIF*G0:JZLUVI=\#)I*2GY*2CJ.RJJ:6[N.JP5"X@K:NW<[*C
MI<VS7:EWP,DN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I
M9"`B3F]N92(*;7-G<W1R("*U3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I
M="DB"FUS9W-T<B`BM4P@*'5S92!I;7!L:6-I="DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS
M9W-T<B`BI.FFU;#2I.4@*$E33RTX.#4Y+3$P*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L
M:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L:R!)<VQA;F0@*+_5NM:G2JYQ*2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BI5^E8K)Y
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS
M9W-T<B`B3F]R=V%Y("BNOZO"*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`BJT2DIZOA(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"
M969O<F4B"FUS9W-T<B`BJT2DIZME(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT
M,3(*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("*DHZQ/I$"MTZ78
MO_TB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO
M="!I;7!L96UE;G1E9"XB"FUS9W-T<B`BM7NFH:E\I;RGN::H+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@
M(DYO="!S970B"FUS9W-T<B`BI*.S7:EW(@H*(SH@;&EB+U9&4RYP:'`Z,3DS
M(&QI8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S,@;&EB+U9&4RYP:'`Z
M,C4Q"B,Z(&QI8B]61E,N<&AP.C(V."!L:6(O5D93+G!H<#HR.#0@;&EB+U9&
M4RYP:'`Z,S`P(&QI8B]61E,N<&AP.C,Q-0HC.B!L:6(O5D93+G!H<#HS,S(@
M;&EB+U9&4RYP:'`Z,S8U(&QI8B]61E,N<&AP.C0R-2!L:6(O5D93+G!H<#HU
M,#0*(SH@;&EB+U9&4RYP:'`Z-3<S(&QI8B]61E,N<&AP.C4Y,"!L:6(O5D93
M+G!H<#HV-C@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO<F1E
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR
M,S8*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(J6\LU&DY+2I(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BL\:GT;_](@H*(SH@<V5R
M=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O
M(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`BJ%.FLZ5IPG/$_:JZ+*9>I6@N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO
M=F5M8F5R(@IM<V=S='(@(J11I$"DZR(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`BO,:F<B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#(Y"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R("*F<J2XO,8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`BIG*DN+QE
MJ]<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M
M8F5R(&]F(')O=W,B"FUS9W-T<B`BIN:\QB(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(J?SMW.P=+AMN'.RU:[)I;RK_*EWO,:EV"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S
M='(@(D]+(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,`IM<V=I9"`B3V)J96-T(@IM<V=S='(@(JJKI?,B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`BJJNE\ZO8I=^JS"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R("*D2[9IINPB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R
M("*D4:3K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/
M9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B"FUS9W-T<B`BO^RDO:O'(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@
M86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@
M(K=SL4N]6*6RMK>[4,+"L4N]6*2CIE`N(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B
MPL*Q2[U8(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS
M9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(L+"
ML4N]6*2CI;^]5"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N("BJ_+#2
M*2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`BI76FLR!)34%0(*;XJD&^N:3DM*FK2*7SIUBDP*C)I5ROX"XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@
M(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(J?DI*.H[+G/I=PN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-S4*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"XB"FUS9W-T<B`BI76DN;-<I$"MT[9LI?.F[:=]+B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B
MI76FL[[6IK.JS+M0J'2RSKK>LGJM^Z5II4C%W*?SID"HR<5VK:TB"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT
M,`IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BIF*W<ZJZ
MM?BUH;9]L=(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM
M<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B3W!E;E-33""_^;M^
M.B"U3*IKL7$@4R]-24U%(,.QL[FJ_J7SN-&V?;CJKL8N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS
M9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(J9BMW.JNK7XM:&V?;'2LW.ULB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("*G0+=^J'2R
MSB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`BO^^VM2(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E<[_OMK4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED
M(")/<F1E<F5D($QI<W0B"FUS9W-T<B`BMK6EV+USN+DB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM
M<V=S='(@(K+5PK0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V
M.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("*RU<*TL^:F
M["(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R
M9V%N:7II;F<B"FUS9W-T<B`BLM7"M"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*
M;7-G<W1R("*M[*ELP+.ESK5[IJ&\RZI/(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.B(*;7-G<W1R("*F8B`E<SH@I*2JNJWLJ6R\RZI/+B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(JCDI4PB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO
M;B(*;7-G<W1R("*HY*5,N.JP5"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(K[6
MIK.JS,5VK:TB"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"FUS9VED
M(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B4$%-(,7GP]*U3*[$+B(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B
M4$5!4CHZMFRE\Z;XJD&ZW2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")0
M1U`@O,:F[,.QL[DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R
M"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0(*5;L4NX
MZJ[&(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B
M4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B4$=0(*2]MGVJ]\9?(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@I'?#L;.Y+Z1WI5NQ2R"XZJ[&
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*
M;7-G<W1R(")02%`@M7NFH;U8(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P
M"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(*_SO5HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@
M3&EG:'0@4F%I;B(*;7-G<W1R("*DR*OAI'"K0B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S
M(@IM<V=S='(@(J3(J^&P?:M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`BI,BK
MX::SL[<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(J3(J^&P?;.W
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*
M;7-G:60@(E!-(%-U;B(*;7-G<W1R("*DR*OAM+@B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R
M;7,B"FUS9W-T<B`BI,BKX;EPJT(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R(")03U-)6"!E>'1E;G-I;VX@O_*EHB(*"B,Z(&QI8B]A<&DN<&AP.C$T
M.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")02%`@K_.]6E]((@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("*YU*52(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI
M<W1A;B(*;7-G<W1R(")086MI<W1A;B`HI-JP\K2UJ5HI(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B4&%L874@**FMKULI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;FEA
M;B!497)R:71O<GDL($]C8W5P:65D("BDVK#'M+6I6J;[N^*PSRDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$@**3:KK.PJ"DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$@3F5W($=U:6YE82`H
MI-JEK*C(MW.T6*2ZJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B
M4&%R86=U87D@**3:J=2F8RDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M("*F:+:S(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ-3$@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-PHC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(K%+O5@B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*Q2[U8Q=RG\Z>Y
MIJ@N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED
M(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`BL4N]6*2CI;^]5"(*"B,Z
M(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R
M9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("*H4Z:SJ_RI=[%+O5BE2*C1(%)!1$E54R#%Y\/2+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#4W"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R("*Q2[U8O52[>R(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(K%+O5@Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`BL4N]6#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34P(&QI8B](;W)D92]&;W)M+G!H<#HR,#,X"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R("*Q2[U8I;*VMZ=KIE@N(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(K9+I%<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS
M9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("*V2Z17(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R("*X]*Y\(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B
MJ]V\9K5NO_VA1R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I
M9"`B4&5O<&QE(@IM<V=S='(@(J:HK?LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G
M<W1R("*FRJ3`I/$B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(K#UIN:Z^\5`OMZG0"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BM6ZD2JOAL/6FYKK[Q4"^WJ=`
M/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(L5VK:TB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R(")<(B5S7"*JNL5VK:VEO+-1IU*PHRXB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R("*F<ZCZOD2IVB(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R("+%=JVM(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI
M;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MQ7:MK;K>LGHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@
M(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(J?:JKHB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(E!E<G4B"FUS9W-T<B`B4&5R=2`HK[6^?"DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`BPV2JJR(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B4&AI;&EP<&EN97,@*+7AJ]^[JRDB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`BN7&XW"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G<W1R("+#P+19(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(KFSK\`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(KW0MFFD2L!X
MIG.NYL))O^\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`BO="]
M5*EWK6ZROK"CIKFDN*7S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G
M<W1R("*]T+U4J7>G0:UNI*3"7Z:YI+BE\ZJZLW.ULBXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C4V-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`BO="_Z:1*I$"MTZ3KI?>DSJ9^I?<N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(@IM<V=S='(@(KW0O^FD2K=SO%>DP,/^JKJF5[K9.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S`U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+B(*;7-G<W1R("*]T+_II$JD0*W3IK.NQ*JZ($E0(*;L
MIWTB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T-PIM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"XB"FUS9W-T<B`BO="_Z:1*I$"MTZ:SKL2JNJ3IM,$[
MI,2_[Z:YI.NE]ZJZI.FTP2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U
M,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B
MO="_Z:1*I$"MTZ:SKL2JNJ[)MJ$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("*]T+2CJ-&PW<-$JKJZ2ZUN+B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`BO="_Z:1*IT&JNJC/I<ZJ
MS*97NMFDSK%+O5@B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U
M($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T
M96TN(@IM<V=S='(@(KW0OES%JJ15ID.DNJYE+J=!I;*VMZ90MTZS;ZC'J,:V
MM:1^K^"HSZ7.J'2RSBXB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E
M9V]R>2!N86UE.B(*;7-G<W1R("*]T+_II$JW<ZJZI,##_J97NMDZ(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L86YD("BJ:<3U*2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B
MK$:J=B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@
M(E!O;&QS(@IM<V=S='(@(J?KLKPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G
M<W1R(")0;W)T=6=A;"`HN+*UY:3Z*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("*\=KFSINRX;2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS
M9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(JKMKN:F
M[+AM(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS
M9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!
M4"DB"FUS9W-T<B`BN[RP9;9LI?.H[+-OK=.K2*7SIU@@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(K/,JO$@
M)7,@I'"NR:JZK;"K0K9Q.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM
M<V=S='(@(JVPJT(\8G(@+SZ^][)V(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD
M87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(*?DI*.H
M[*G2N]VM;JJZ($Q$05`@J;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7W-E<W-I;VXZ(*?DI*.H[*G2N]VM;JJZ('-E<W-I;VX@J;6F^:Y-I?,N(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM
M<V=S='(@(J[PP*,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`BKOREK:VQKO#`
MHSH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R("*N\,"C.B`B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4')E=FEE=R(*;7-G<W1R("*Y=\3](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BIF*W<ZJZ
MM?BUH;EWQ/V\=KFS(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C(@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8*;7-G:60@(E!R979I;W5S(&]P
M=&EO;G,B"FUS9W-T<B`BI%>D0*W3O^^VM2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(J9#IDRDY:7S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("*H<+%+JO?&
M7R(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB
M"FUS9W-T<B`BL-W#1"(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM
M<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("*PW<-$M'FM>B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE
M8W1S(@IM<V=S='(@(K%-KM<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S(W-`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`BM*.EW*2ZKF4B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+
M97DB"FUS9W-T<B`BI+VV?:KWQE\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T
M<B`BI+VV?:KWQE^Z=+KB(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("*DO;9]JO?&
M7[CJL%0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(J2]MGTOJ'"Q2ZKWQE^Y[ZC#I;RS4;*CI<TN(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I8V\@**II
MIFB^I*95*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(E%A=&%R("BE9+E&
M*2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS
M9W-T<B`BK&2XWR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I
M9"`B475O=&$B"FUS9W-T<B`BNL^ZT+!TN&TB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B
M;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")24T$@I+VV?:KWQE\@*"5D(*;L
MI+@I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A9&EO
M('-E;&5C=&EO;B(*;7-G<W1R("*_[[[<MG,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R
M("*K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(J:MIK.K0B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")2
M86EN($QA=&4B"FUS9W-T<B`BL=^FLZM"(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM
M<V=S='(@(K!]JT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("*K0J:S
ML[<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(JM"PN"SMR(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*
M;7-G<W1R("+`2+[WI'"[>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS
M9VED(")2871I;R(*;7-G<W1R("*D\;)V(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`BQ:JH^B(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A
M9"!M97-S86=E<R(*;7-G<W1R("+%JJCZMFRE\R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R("*O=:JZK6ZG4K"C("5S(+;</R"S;[:UOMZG0+%.M4RJ
M:ZOLM%\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(J]UJKJM;K)-L*.HSZ7.JLP@)7,@JKJXZJ[&MMP@/R"S;[:U
MOMZG0+%.M4RJ:ZOLM%\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`BJ/JN^+1?K>PB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S
M:"(*;7-G<W1R("*MJ[=SON.R>B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*
M;7-G<W1R("*MJ[=SON.R>K#*ND&EV+_]I+BE\SHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*
M;7-G<W1R("*MJ[=SON.R>JW3I$BON*5XI+JN93HB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G<W1R("*Q8+-7JNVE
MW*:A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,S@*;7-G:60@(E)E;&%T
M:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(L/VP7#"<\3]OKDB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`BK:O%JB(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S
M='(@(K7[O=<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED
M(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("*[M[K=IOBJ0;ZY(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`BN[>Z
MW;KTIWT@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@
M(K*^L*,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G
M:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("*ROK"CL,^V]"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(E)E;6]V
M92!C;VQU;6XB"FUS9W-T<B`BLKZPH\3FINPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R
M;6%T=&EN9R(*;7-G<W1R("*E:+"CKN:FH2(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("*R
MOK"CN>\B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`BIMNF^*I!OKF\R*9SI=B__:2DLKZPHZ1WP'BF
M<ZJZLUVI=[5[IJ$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S
M='(@(K*^L*,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`BIMNDY:7SI*2ROK"CIKFD0+A@PDDB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED
M(")296UO=F4@=7-E<B(*;7-G<W1R("*ROK"CJ,^ESJK,(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("*ROK"CJ,^ESJK,.B`E<R(*
M"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M(@IM<V=S='(@(KO=J$2EO+-1IE[`LSH@O_F[?KBYO5@Z(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.RITKO=
MJKJJ0;#(+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<V(&QI8B](;W)D92YP:'`Z
M-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B4R)',@
MJKJS7:EWI;*VMZO\J7<@7"(E,21S7"(B"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M-C<X(&QI8B]61E,O9G1P+G!H<#HX-3`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@
MJKJS7:EWI;*VMZO\J7<@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP
M.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*S7:EWN.JN
MQJ6RMK>K_*EW(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(J6RMK?$
MYJ;L(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,T,R!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`BK:NS72(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E
M="!087-S=V]R9"(*;7-G<W1R("*MJ[-=L4N]6"(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(JVKLUVG0:JZL4N]6#HB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`BIEZF
M<[/,J^&D0*W3K&2XWR(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED
M(")297-U;'1S(@IM<V=S='(@(K6RJD<B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G
M:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(JKPIEZ_[[:U(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(J9!IKB_Z:1*MW.Q2[U8(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N("BO9*6GJ?2N<2DB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(J9>
MM%^S7:EW(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(KKTK;:]<[_HOKF_
M[[:U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D
M;&5S(@IM<V=S='(@(L&\NWDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@
M(J5KP^0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q,`IM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(J5KP^2J[<!9(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,Q,#8*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("*E:\/D
MK<@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("*F0Z2ZKF5?=RXN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(JBDIN(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")2;VUA;FEA(@IM<V=S='(@(E)O;6%N:6$@*,.YL*BEIZC(*2(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*;7-G:60@(E)O
M=&%T92`Q.#`B"FUS9W-T<B`BL=O"X"`Q.#`@J]<B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"FUS9VED(")2;W1A=&4@3&5F
M="(*;7-G<W1R("*P9J[)L'<@.3`@J]>QV\+@(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-PIM<V=I9"`B4F]T871E(%)I9VAT
M(@IM<V=S='(@(K:VKLFP=R`Y,""KU[';PN`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@
M4')O<&5R=&EE<R(*;7-G<W1R("*F0Z2ZKF4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@
M<')O<&5R=&EE<R(*;7-G<W1R("*F0Z2ZKF4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS
M9W-T<B`BID,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("*NYKUU(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<R(*;7-G<W1R("+$YJ;LNU"F0Z[FO74B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*
M;7-G<W1R("+$YJ;LKN:]=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(J9#KN:]=2(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("*P]:;F
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<W-I
M86X@1F5D97)A=&EO;B`HJUC#N;2U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G
M<W1R(")2=V%N9&$@*+]CIG>Y1BDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E(@IM<V=S='(@(E,O34E-12"E6[%+P[&SN2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4B"FUS9W-T<B`BMFRE\Z1WJ,^ESB!3+TU)344@I5NQ2R(*"B,Z(&QI
M8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@Q>?#TK5,
MKL0N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B
M4TU3($UE<W-A9VEN9R(*;7-G<W1R("+"LK!4(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`BN.JNQJYWK_.]
M6B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<R"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R("*E
M6[%+LM>ZW;[W(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(J:HI5PB
M"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T
M<B`BN.JNQJYWK_.]6E]1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`BK%"TP:2[(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A:6YT($AE;&5N82`H
MN'2[KK#'K\<I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS
M9W-T<B`B4V%I;G0@2VET=',@86YD($YE=FES("BX=*=*J+VTM:9HNM:DSJ6G
MNONTM2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT($QU
M8VEA("BX=,53INBHR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI
M<75E;&]N(@IM<V=S='(@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G
M<W1R(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R`HN'2DY;3+
MI,ZNYK?GJ+JD0BDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T
M<B`BIE"D0*W3M?BUH2`H7W-E;&8I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T
M<B`B4V%M;V$@*,+$O*^HR+ASKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*
M;7-G<W1R(")386X@36%R:6YO("BX=+"HIU&_U2DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@86YD(%!R:6YC
M:7!E("BX=*9HK/RDSK2VJDRFZ*3Q*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@
M(KW#K%"THZC1JLPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B
M4V%U9&D@07)A8FEA("BH1J]1IF&J_*G4IT(I(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(L!XIG,B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(L!XIG,@7"(E
M<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("+`>*9S("5S(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS
M(@IM<V=S='(@(L!XIG._[[:U(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB
M9&ER96-T;W)Y+B(*;7-G<W1R("*Q3K*CI<VJNK-=J7?`R:5((%!(4""[>:BE
MKN:FH<!XIG.H[*=!JKJF^*I!OKF\R*9SI=B__:2D+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(K-=J7<@)7,@I'?`>*9S+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(J?SMW.U>Z:AI'?`>*9SJ.PZ(%PB)7-<(BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A
M='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(KESK%"Y<*M"(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(JSL
MOL<B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM
M<V=S='(@(K=JM$TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(R
M"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("*W:K1-I-[`NB(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR.38R"FUS9VED(")396QE8W0@1FEL97,B
M"FUS9W-T<B`BO^^^W,#)KM<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@R"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(K_OOMRD0*W3I.FTP2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`BO^^^
MW*1`K=.X<[+5I<ZE2+=SO%<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`BO^^^
MW*1`INRW<ZJZOM:FLZK,(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`BO^^^W*1`
MLZ&F^*I!OKDB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM
M<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BO^^^W*1`INRH
MSZ7.JLRESJ5(MW.\5R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S,*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BO^^^W*G2
MIK,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U,`IM<V=I9"`B4V5L96-T
M(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(K_OOMRITJ:SI.FTP:2X
MI?,N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W
M,`IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("*_[[[<I$"MTZJK
MI?,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<T
M"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("*DH[_OOMPB"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA
M<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A
M;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A
M<F5A+B(*;7-G<W1R("*I\Z5(I%6JNK7XM:&DI+_OJ/JG0:UNJKJF<J2X+J5(
MM\:YJ[W&NW.ITK_OI.6F<BRU3:OAMDND5Z3EI?.]<[_HL,\N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z(@IM<V=S='(@(K_OOMRDZ;3!I,"Y:CHB"@HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E
M(&9O<FUA=#HB"FUS9W-T<B`BO^^^W*3IM,&DZ;3!KN:FH3HB"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B
MO^^^W+']Q=RG\ZJZJ*VE]\/1IT\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM
M<V=S='(@(K_OOMRNR;:AI,"Y:CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T
M<B`BO^^^W*3IM,&NR;:AKN:FH3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB
M"FUS9W-T<B`BO^^^W*S;I*RDQ[!TJKJD1ZW3Q.:F["XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N(@IM<V=S='(@(K_OOMRG0:JZPT.FXK!TN&TB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z(@IM<V=S='(@(K_OOMRPOJ9NNWFHI3HB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("*VQ[!EL-W#1*3/P+,B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`BML>P9<*RL%0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S
M='(@(E-E;F5G86P@*+;KI+JE6[JX*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("*W4+3ZOKDZ("(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB
M97(B"FUS9W-T<B`BI$6DZR(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R
M(")397)B:6$@86YD($UO;G1E;F5G<F\@*+;KNKBZ^ZC(NU"[6*]3I:>M],.Y
M*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")3
M97)I86P@3G5M8F5R(@IM<V=S='(@(J?'N+DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O
M<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("*F^*I!OKFXZJ[&O_F[?JG.JLRU
M3*IKJ,^ESBXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E
M<W-I;VX@061M:6XB"FUS9W-T<B`BMWRTP;K>LGHB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E
M>'!I<F5D+B(*;7-G<W1R("*W?+3!($E$(*1WN4RTP2XB"@HC.B!L:6(O87!I
M+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(K=\M,$B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q.`IM<V=I9"`B4V5T(@IM<V=S='(@(J[6
MJ/JDZ+;T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(J2YLURG0:GSI]&P
M3[%+O5BJNJ[)K=0LI6FE2*;;IN:MJ[-=L4N]6"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@
M=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS
M9W-T<B`BLUVI=[NWNMVF^*I!OKFD5\3=J?.G0:JZK=.D2*^XI7@N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM
M<V=S='(@(K-=J7>G0:JZL+ZF;KMYJ*4L(*[)L,^E2*3.I.FTP:[FIJ$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(K-=J7>G0:JZL=*I;,"SI<ZU>Z:A+,-#IN*P=+AM+*VVK;&G\[=SP%>R
M=BRDSJCDI4S%XZ7<O^^VM2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<U"FUS9VED(")3971U<"(*;7-G<W1R("*S7:EW(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`BI_.W<[5[IJ&T3KK\(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`BIK.F;K18K=.F8<))J4VS;ZW3L-&\QJ:SP_8Z("(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<R`HMNNI];JX*2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P
M:6YG(@IM<V=S='(@(L'*JJLB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("+"LK5U
MNDNM;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H
M;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*
M;7-G<W1R("*L3Z=?K+"D:K.AI?>JNK-SM;*I=[AQI]:QMJ5<K^#!Y#\B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R("+%XZ7<(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("+%XZ7<MW.RHZ7-NU"M[,!XIG.S7:EWP,FJNJYTLJ<N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("*H0Z:XM6ZD
M2JOAQ>.EW*17I$"FN*JZM6ZD2J[)MJ$@/R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`R"FUS9VED
M(")3:&]W('!I8VME<B(*;7-G<W1R("+%XZ7<PDF_[[ZY(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/R(*;7-G<W1R("+%XZ7<JNVNYK[>IT"E7*_@JNT@/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B
MJ?.EJL/DQ>.EW"`E<R"E7*_@JNT_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(L7CI=S`
M>*9SKN:DNJYEN>^XW*3HMO0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(L7CI=RJ[:[FI+JN9;GO
MN-RDZ+;T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>.EW*9#I+JN9;GON-RDZ+;T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("+%XZ7<O':YLZ2ZKF6Y[[C<I.BV]"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-S8W"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("+%
MXZ7<I%>VQR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(JOYQ/*P?:M"(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@
M(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`BIJVFL[!]JT(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R
M<R!,871E(@IM<V=S='(@(K'?IK.P?:M"(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y(@IM<V=S='(@(KNWI.BFL[!]JT(B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("*F
MK,%9(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C@S-@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HY,C(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3@T
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P-#<@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HQ,3$V(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q-#D*
M;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE("BWX*1LI'.PZBDB"@HC
M.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U
M<"(*;7-G<W1R("*U^:55(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+#L;.Y(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!
M;&=O<FET:&TB"FUS9W-T<B`BP[&SN;ITNN(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O
M<F4B"FUS9W-T<B`B4VEN9V%P;W)E("BW<Z5;J5DI(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.CDP,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(T,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(U,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-2!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HX-`IM<V=I9"`B4VEZ92(*;7-G<W1R("*D:J1P(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*
M;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BLJ2Y3+K[Q4`B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]V86MI82`HM+6LI:7OITHI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=F5N:6$@*+2UK*6E
M[Z6GJ,@I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`BL[<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W
M97(B"FUS9W-T<B`BL'VSMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
ML'VSMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`BIJVFL[!]
ML[<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`BL=^FL[!]L[<B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T
M:#H@(@IM<V=S='(@(K]NL[>R8*O7.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O
M;&]M;VX@27-L86YD<R`HK\'#N:KYN'.N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(E-O;6%L:6$@**_!L*BG4:C(*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("*Z
M<;M0N-8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-0IM<V=I9"`B4V]R
M="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`BL<:F0Z3HIE:_[[[<(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C$W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C0W"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-C8@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E
M<W,B"FUS9W-T<B`BJ-.WO:9AIWTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`B4V]U=&@@069R:6-A("BK;JM$*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RDB"FUS9W-T<B`BJVZ\VB`H25-/+3@X-3DM,RDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S
M='(@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("*K
M;J5BLGDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#$Y"FUS9VED(")3<&%C97(B"FUS9W-T<B`BJL6EU:;F(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS
M9VED(")3<&%C:6YG(@IM<V=S='(@(K:AMEHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C
M:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(K:AMEJ[4+G4I5(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M4W!A:6XB"FUS9W-T<B`B4W!A:6X@**;HKUJD^BDB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(JE5IZ.V
M;*7S(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C
M:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("*O4Z[MIG*DN+_II$HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(J3`L\[`>*9S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(J3`L\[$YJ;L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(J3`L\ZF0R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(KE"
ML,HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$@*+2U
MJ+W$]:5D*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R
M("*\T+?'(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3
M=&%R(%1R96LB"FUS9W-T<B`BK%"[VJJGQ5&^U"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3DP(&QI8B](;W)D92]&;W)M+G!H<#HR-SDX"FUS9VED(")3
M=&%R="!Y96%R(@IM<V=S='(@(K'2J6RF?J7W(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM
M<V=S='(@(JS9(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("*JK+I!(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,#0*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S
M='(@(L!XIG.NYJ:A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(K7SN40B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED
M(")3=')I:V5T:')O=6=H(@IM<V=S='(@(J=2L*.]=2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("*F
M<J;JID,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`BIMNV;*7SIF&G
M?:2DI6BPH[KTL.RF5[K9(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`BO,NFH2!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(JQ0M,&DT2(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
MI^2DHZCLIKBEV+_](%PB)7-<(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(J5$IJXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E
M;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("*P9:58(@H*
M(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO
M=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E
M;B!A<'!R;W9E9"XB"FUS9W-T<B`BO%>E6R!<(B5S7"(@J.RH=++.JKJET[W0
MI'>P9:58+B"G0:6RMK>UI:CLN-.ET[W0LU&NUJWCJ^&D?J_@M6ZD2BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS
M9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BI%6\T"(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,#0@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(J:HI5PB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@
M(J:HI5RJNJ5;I$H@7"(E<UPB(*CLJ'2RSJ2D+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(J:HI5RJNJ;;J'2RSJ2DLDVPHZC/I<ZJS"!<(B5S7"(@JKJXZJ[&
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L
M971E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(J1WIU*PHZ>YIJ@N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S
M='(@(J:HI5RJNJ;;J'2RSJ2DLKZPHR!<(B5S7"(N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D
M(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T
M<B`BI'>FJ*5<JKJF7K1?LUVI=RX@O="MJ[=SN/RD2L#+M?BN=+*G+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("*D=Z:HI5RJNK/&I?>S7:EWN.JNQBXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`BI'>FJ*5<JKJSQJ7WLUVI=[CJKL8@)7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("*FJ*5<JKJG
M\[=S(%PB)7-<(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("*D=Z:HI5RJNL+0O&<@)7,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=61A;B`HQ*RDIBDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V
M"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(KI+K6XB"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(J3II5@B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B
M"FUS9W-T<B`BI.FXJ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("*TN"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`BI.FE6"(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B
M"FUS9W-T<B`BI.FE6"^DZ;BH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(J3II5@Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U
M;G-E="(*;7-G<W1R("*DZ;BH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`BI.FXJ#H@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM
M<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BI%>\T"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
MI.2TJ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86UE("C$
MK*=1JVXI(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G
M:60@(E-U<FYA;64B"FUS9W-T<B`BNN^XN2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D
M(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@86YD($IA;B!-87EE
M;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6QA;F0@**5V
MI<O`V<3U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=V5D96X@*+?G
MJ.4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-W:71Z97)L86YD
M("BWYZ1H*2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS
M9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(J90J$*P3[_]I'>G4K"C
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,
M(@IM<V=S='(@(J90J$*FYK#*N,NX;2(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(K=JM$VVM:78I*2JNKMYJFN_^;M^(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WER:6%N($%R86(@4F5P
M=6)L:6,@*+'4IU&HR"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("*Y<*M"(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G
M:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(KEPJT*FLZVW(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@
M(E0M4W1O<FUS(@IM<V=S='(@(KEPJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB
M"FUS9W-T<B`BIJVFLZOYQ/*Y<*M"(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V
M+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E1!0B"DP+EJKN:F
MH<#)KM<B"@HC.B!L:6(O2&]R9&4O54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B
M5&%B;&4B"FUS9W-T<B`BJNVSYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E
M<G1I97,B"FUS9W-T<B`BJNVNYJ2ZKF4B"@HC.B!L:6(O2&]R9&4O1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T
M(@IM<V=S='(@(JKML^8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S
M(@IM<V=S='(@(JKMKN:DNJYE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A
M;B(*;7-G<W1R("*E>,97(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R("*E>,97(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")486II
M:VES=&%N("BV\*9.M+6I6BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8@**E:J7REIZC(*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`BI=B\
MT#HB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(JO=O^RH
MQK:U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`BN7&XW+BYO5@B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`BL\RJ\:1`I'"NR:JZM\6KUSH@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(K?%
MJ]<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED
M(")496UP97)A='5R93H@(@IM<V=S='(@(K?%J]<Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G
M<W1R("*WQ:O7/&)R("\^*"5SL*HE<R\E<Z=#)7,I("9D96<[)7,B"@HC.B!L
M:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.R\
MRZI/(%PB)7-<(BXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I
M9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`BO,NJ3[K>LGHB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S,R-0IM<V=I9"`B5&5X="(*;7-G<W1R("*DNJYE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@
M(J_"I.6F<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`BN>^[
M]*3EIG(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(KGON_2DY:9RL[NZW2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*
M;7-G:60@(E1H(@IM<V=S='(@(JQ0M,&E?"(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@W"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("*N]:3E
M("A425,M-C(P*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EL
M86YD("BN];#J*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-#`*;7-G:60@(E1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D94
M4""IM:;Y*&5X=&5N<VEO;BFU3*[$+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(@ON.F6*1UM7NHPZ6\I.2TJ2!<(B5S7"(B"@HC
M.B!L:6(O3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B24U34""L
M]K_]M4RJ:[-1JNRI;"XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N8V4@P_ZG3ZC#I;RF
MJ*5<N/RD2B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+B(*;7-G<W1R("*_[[:UM?BUH:5(P_:SK"["][9]I*0N(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HR-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE
M961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K
M96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T
M<B`BIT&JNJATLLZZWK)ZK?NELK:WI?VS7:EWIFZD0*W3Q7:MK:OANMVD?J_@
MQ?VG0:C/I<[%=JVMJ'2RSBXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I
M9&4@;VYL>2(*;7-G<W1R("*ILZ[8O74B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N
M=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO
M="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(L%PM;BXN;U8
MI;RK_*EW+*K%I=6ISJ9BN.JNQJYWI*2GY*2CJ.PN(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`BI'>FJ*5<JKJQ3L%PM;BD2+=SO%>FW+-QL%2__:2D+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(L7GP]*V;*7SP[&S
MN;O=K6ZFLZ1`K=.D=[C1MGVJNB!01U`@L,^V]"XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S
M='(@(K!TN&VX<[+5JKK#T:=/N+F]6"A)1"FDHZQ/I;RK_*EW++1.K$^JQ:75
MJ<ZJS*2CIF*XZJ[&KG>DI"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N(@IM<V=S='(@(K!TN&VX<[+5I;RK_*EW+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("*[W:UNI$"MT[AGN4RE6[%+JKJZ]+CTLW.ULBXB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$W-R!L:6(O2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I
M;F<N(@IM<V=S='(@(L#)KM<@)7,@P+.XTZ5=IW2D0*W3("5S(+-=J7<N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-S`@;&EB+TAO<F1E+G!H<#HU,#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RXB"FUS9W-T<B`BP,FNUR`E<R#`L[C3I5VG=*1`J,<@
M)7,@LUVI=RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R,PIM<V=I9"`B5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B
MM4RJ:[W&NW.H[*;;J*W`R:[7+B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR
M.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("*FN<#)KM>DI*A3IK.XZJ[&+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R("*E2*15K$\@<F9C.#(R(+9LI?.JNJKMP%DN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE
M(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@
M=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G
M<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI
M9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L
M:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO
M;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E
M96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W
M86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("*HK:7WP]&G3R`E<R"D=[-1IU*PHRXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("*EJJ[8O74B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R(")';G501R"D1Z2XP,FJNKCTKGRE
MLK:WJ7>X<:9B($-R>7!T7W!G<#HZ(,/^IT^DI"XB"@HC.B!L:6(O2&]R9&4O
M34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@
M:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M(@IM<V=S='(@(B(*(J=!M+^I\R`E<R"Q2+6Y("5S(*1`J\JE1*:NK+`@7"(E
M<UPB(*JZJTBE\Z1WLU&V?;'2+EQN(@HBIOVS;ZC#I*.OX*M/P]*XTZM(I?.J
MNJ2ZKF6D=Z>YI?ZS4::LI?.D2*S=I[FISJ1&N-$N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI
M;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("*S<[6RJ.R]<[QG
MMFRE\ZVVK;&ITJC/I<ZJNJ97NMDB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W
M-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC
M+B(*;7-G<W1R("*ELK:WK$^D0*W3O,:F<BXB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M(@IM<V=S='(@(DAO<F1E7T-R>7!T7W-M:6UE.CH@P_ZG3RRELKO=K6ZFLR!O
M<&5N<W-L(+S2LM4N(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(J:YL+ZF;B!<
M(B5S7"(@N.JNQJ9=K+"V5[E,L\RD:J2YLURMR"RITJ5(M4RJ:[-1P'BF<R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D
M92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)P;2YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP
M:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H
M<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V
M:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@
M<WES=&5M+B(*;7-G<W1R("*ESJ5(P,NU^*:YN.JNQL/^JZP@*"5S*2"JNK5[
MIJ&HPZ2CIG.F8JGSJ'2RSJ17+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@W
M"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(J3>K7JF<J6RMK>LL+/FI$"F<J2X+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM
M<V=S='(@(J6JI6NNV+UU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(J5KKMB]=2(*"B,Z(&QI8B]&:6QE+T-35BYP
M:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(L3FINRDP+EJIG*ELK:WK+"SYJ1`IG*D
MN"XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("*FN:;XJD&^N2!<(B5S7"(@I'>S4:=2L*,N(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S
M='(@(J:YIOBJ0;ZY(%PB)7-<(B"D=[-1P'BF<RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(E<R"JNK7Y
MI56[W:A$I'>S4;*^L*,N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`BJ_RI=ZJZL$^__:C#I*.F<Z9B+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R
M>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BO,BF<\#)
MKM=<(B5S7"*DHZ9SIF(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#`*
M;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE
M('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`BIT&ITK_II$JJNKCJKL:[
M4+5EK;&XZJ[&I*.RQ2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>2(*;7-G<W1R("*D5Z15KMB]=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@
M(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(J17KMB]=2(*"B,Z(&QI8B](
M;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("*Q<:17
MI$"MTZA"QDJDIZOAI%>VQZJZN.JNQK_RI:(N(@H*(SH@;&EB+TAO<F1E+T1A
M=&$O8W-V+G!H<#HR-C(@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S(*;7-G
M:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS
M9W-T<B`BI%>VQ\#)KM>HPZ6\LU'`>*9S+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B=V5A=&AE<BYC;VT@L,^V]+5,JFNHSZ7.+B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(J?DI*.H[+S+IJ&P=+AMI=B__2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92XB"FUS9W-T<B`BM4RE::7.JKJ_[[:U+B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HS-#D*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("*U
M3*K^I?.E::J]L;6V?;'2+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`U
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*
M;7-G<W1R("*FN<3FINRDI*5=IW2DTZ9HJKJF<KS&+J=!I'>_Z:1*("5S(*W3
MIG*\QCNG0;_II$JJNJ9RO,:ELK:WI'"I\R`E<RXB"@HC.B!S:6=N=7`N<&AP
M.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M
M.B`E<R(*;7-G<W1R("*W<[Q7(%PB)7-<(B"H[*ATLLXZ("5S(*[)M6^ES:1`
MK=.PW<-$+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(J;;J'2R
MSK)-L*,@7"(E<UPB(*JZN.JNQJ[)M6^ES:1`K=.PW<-$.B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("*FVZATLLZROK"C(%PB)7-<(B"NR;5OI<VD0*W3L-W#1#HB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@
M(J?SMW,@7"(E<UPB.B`E<R"NR;5OI<VD0*W3L-W#1"(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+B(*;7-G<W1R("*D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E
M<R"EO+-1I%>VQRXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(J17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z("5S(*1JI'"V5[E,I+FS7+/,I&JM
MR"`H)60@8GET97,I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"XB"FUS9W-T<B`BI%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@
MMLBSH:3`JKH@)7,@P,FNU[-1I%>VQRXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`BP,NU^+9L
MI?.NR;5OI<VD0*W3O_F[?BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C,Y(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O
M;G1A8W0@9&%T82XB"FUS9W-T<B`BMM>D2J:YLW&P5+_]N.JNQJ[)M6^ES;_Y
MNWXN(@H*(SH@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M(@IM<V=S='(@(K;7I$H@:4-A;&5N9&%R(+CJKL:NR;5OI<VD0*W3O_F[?BXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T
M<B`BIF*S7:EWJNVSYJ2DM6^ES:1&I$"MT[_YNWXNIK.E::_@IT&_\KI\I$:E
MLK:WMO&\9ZJZQ.:F["XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R
M;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE
M87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BL/6FYK-QL%2__:O\
MJ7>E7*_@KLFU;Z7-I$"MT[_YNWXN(+W0M7FKX:9!N-6D0*:X+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("*G\[=SP7"UN*1(
MN.JNQJ[)M6^ES:1&I$"MT[_YNWXN(+W0M7FKX:9!N-4N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("*G\[=SL'2X;;ASLM6NR;5OI<VD1J1`K=._^;M^
M+B"]T+5YJ^&F0;C5+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(J:Y($E-05`@IOBJ0;ZY
MJ,.EO*3DM*FK2*7SIUBDP*C)I5ROX"XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`BLV^F_*5'I*.L
M3Z6_O52JNB!R87(@P*/!6<#)KM<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(K-OIORE1Z2CK$^EO[U4
MJKH@>FEP(,"CP5G`R:[7+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3,T
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`BLV^F_*5'I*.L3Z6_O52JNJM(I<ZE9+BYO5@N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@
M*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDX,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`V,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y,`HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$Q.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X-B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(V,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,30P,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,34V,0HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@T,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3DV,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P.0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`S,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`X,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$U,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0Q,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U-`HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R-@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S(Y-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@P,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S@Q,0IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB
M"FUS9W-T<B`BIKG$YJ;LK$^ELKO=K6ZJNBXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+B(*;7-G<W1R("*FN<3FINRDNJYEI76DN;-<ON.\QKS&IG(N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C`*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM
M<V=S='(@(J:YQ.:F[*2ZKF6E=:2YLUR\QJ9RI,ZK7[BY+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("*FN<3FINRDNJYEI76D
MN;-<I$NV::;LO,:MR"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R-PIM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`BIKG$YJ;LI+JN9:6R
MMK>LL+-RN+FISJK%I=6DP+EJJKJ\QJ9R(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+B(*;7-G<W1R("*ELK:WK$^D0*W3O,:F<BXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@R-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("*FN<3FINRDNJYEI;*VMZ5=
MIW2D0++5I%&DN[9IINRJNB!21T(@PT.FXJ5.O5@LJ-*F<"`G(S$R,S1A9B<N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("*S;ZW3JNVS
MYJ1WLU&S0K)ZN4PN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`BLV^L
M3R`E<RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C
M="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL
M("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A
M<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT
M<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HBLV^L3R!+;VQA8B"X<[+5
MJKJD0*W3JJNE\RX@L?W`R[7XIKFJJZ7SN]VM;J_@I.2TJ4MO;&%B(+ASLM6N
MYJ:AJKJY<:1LMFRE\[-N(@HBQ>DNO="PT:;2("5S(*5(I$:XT;-OJ,>V;*7S
MLV[%Z2(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM
M<V=S='(@(K-OJ\JV;*7SJ,.K1*5(IT&Z1*7.JKJF<J2XMK"FTZQ/J,^ESB`H
M)7,I(*[1O&>FTZ:H+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(V
M"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS
M9W-T<B`BIKF\QJW(L\RDUJ6RMK>L3R`Q+B(*"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(J:YIOBJ0;ZY
MM4RJ:[GO('II<""DSB!G>FEP(*[FIJ'`R:[7MFFFYKC1P*/!62(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z,3@R"FUS9VED(")4:&ES('-Y<W1E;2!I
M<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(J:YJ'2RSJ78JV6L
M3["QI<ZJNJJLND$N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C0*
M;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B
MI;*VMZQ/I$"MT[S&IG(N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("*FN;7XM:&ELK:WK6ZE
MT;_OMK6U^+6A*$]P=&EO;BFITJE)I7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R
M("*Y<"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@
M(E1I8VME=',B"FUS9W-T<B`BL-W#1+!LPMPB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(E1I;64B"FUS9W-T<B`BKLFVH2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`BKLFV
MH:O\JVXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@
M9F]R;6%T(@IM<V=S='(@(J[)MJ&NYJ:A(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(U,S4*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(J[)L,^_
M[[[<(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S
M=&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
MO-##1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`BO-##1"`H
M=&]O;'1I<"DZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(J:LI?.D2"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HV-3$*;7-G:60@(B(*(E1O('-E
M;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A0
M0RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM
M<V=S='(@(B(*(J9PJD>M;KW&O^\LO="F8L))O^^WQKFKJKJF4*[)J_8@0V]N
M=')O;,'D**W3I$BY<;BC*2"ISB!#;VUM86YDP>0HQ*NJ1[EQN*,I+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y
M(@IM<V=S='(@(J2UI-$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS
M9W-T<B`B2%1-3""M[*ELP,DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O
M9V\@**9HK?0I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`BJ?JDT2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S
M='(@(E1O;F=A("BJ1J5;*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(K.[
MLZ$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(K/,I%>\:*[8
MK%L@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U
M>GIY"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`BQ=RDQB(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`BI&2HO;E&I,ZFJZBI
MK?0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O
M<B!F86QS92(*;7-G<W1R("*O=:G.L+`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("*L
M4+3!I$<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;FES:6$@**SP
MI:>FZ*C(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)K97D@**1G
MIM6HY"DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`BI&>FU:CDI.4@*$E33RTX.#4Y
M+3DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI
M<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G
M<W1R(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B5'5V86QU("BD9Z7+OGPI(@H*(SH@;&EB+TAO<F1E+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
MO^FD2J=!JKJ_[[[<.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`BM;6E?KUUJ_R\
MQCH@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R("*Z
M]*=](@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM
M<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`BNO2G?3HB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R
M"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A("BO4:1ZN48I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM
M<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:6YE("BO4:=*Q/4I(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HT,38*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BM4RJ:Z9SJ/H@5D93(*78O_TN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE
M('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U
M<"XB"FUS9W-T<B`BM?FE5:[)M4RJ:[Q7I5O#0J5^JKJHSZ7.JLRXZK!4+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(K5,JFNG[\7<(%9&4R#`R:[7(%PB)7-<(B"JNL5VK:TN
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS.#D@;&EB+U9&4R]M=7-Q;"YP:'`Z
M-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(K5,JFO%W*?S
M(%9&4R#`R:[7("5S+R5S(*JZQ7:MK2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M-S<U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N(@IM<V=S='(@(K5,JFO%W*?SK+`@)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:\#+K&3`R:[7I&JD
M<"!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV.3(@;&EB+U9&4R]S
M<6PN<&AP.C$P,3D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#0R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(*;7-G<W1R("*U3*IKP,NL9,#)KM>D:J1P(%PB)7,O)7-<(BXB
M"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`BM4RJ:[-SM;(@
M4U%,(*;XJD&^N2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#4Y"FUS9VED(")5
M;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`BM4RJ:ZC/I<X@
M4U-,(+-SM;(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,CD@;&EB+U9&4R]F
M:6QE+G!H<#HR,S0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`T"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,3<*
M;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("*U3*IK
MO<:[<R!61E,@P,FNURXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S<P"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(K5,JFNKV*7?(%9&4R"EV+_](%PB)7-<(BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,U."!L:6(O5D93+VUU<W%L+G!H<#HR
M-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(K5,JFNKV*7?(%9&4R"E
MV+_]+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:ZO8I=\@5D93(,#)
MKM<N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G
M<W1R("*U3*IKJ]BEWR!61E,@I=B__2!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR-CD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(K5,JFNKV*7?JL6EU:JZ(%9&4R#`R:[7+B(*"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V(&QI8B](;W)D92]#;VUP
M<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82XB"FUS9W-T<B`BM4RJ:[%.N.JNQKC1P*/!62XB"@HC.B!L:6(O5D93
M+W-M8BYP:'`Z,C(X(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("*U3*IKIU*PHR!<(B5S7"(LIKFE
MV+_]J,.K1*K%I=4N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`BM4RJ:Z=2L*,@7"(E
M<UPB.B`E<R(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,U(&QI8B]61E,O<W%L
M+G!H<#HS.34@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R
M("*U3*IKIU*PHR`E<RRFN:78O_VHPZM$JL6EU2(*"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,U-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-C`*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB
M"FUS9W-T<B`BM4RJ:[N\L&JG4K"CI=B__2XB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,T,2!L:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T,R!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BM4RJ:Z=2L*,@5D93(*78O_TN(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C0R,"!L:6(O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(K5,JFNG4K"C(%9&4R"EV+_].B`E<RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKIU*PHR!61E,@
MP,FNUR!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,#<@;&EB+U9&
M4R]S<6PN<&AP.C(Y,2!L:6(O5D93+VUU<W%L+G!H<#HQ-C<*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS.3$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDY
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("*U
M3*IKIU*PHR!61E,@P,FNURXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(K5,JFNG4K"C(%9&4R"EV+_](%PB)7-<(BXB
M"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T
M<B`BM4RJ:[N\L&JG4K"C(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@R,PIM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BM4RJ:Z=0PE^EV*MEJKJEV+_]+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(K5,JFNXT;9]OLS#
MTK+3N&`B"@HC.B!L:6(O3F5T+TE-4U`N<&AP.C0S-R!L:6(O3F5T+TE-4U`O
M075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("*U3*IKN/RD2B5S
MJKJI=[AQ+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`P(&QI8B]61E,O9FEL
M92YP:'`Z,C`U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W-`HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+B(*;7-G<W1R("*U3*IKMVBROB!61E,@P,FNURXB"@HC.B!L:6(O5D93
M+W-M8BYP:'`Z.3,@;&EB+U9&4R]S;6(N<&AP.C$P-B!L:6(O5D93+W-M8BYP
M:'`Z-C4R"B,Z(&QI8B]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(K5,JFNV?;'2(%9&4R#`R:[7(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C(X,2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F
M;W(@=W)I=&EN9RXB"FUS9W-T<B`BM4RJ:[QGI$H@5D93(,#)KM<N(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP.C$S-"!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N(@IM<V=S='(@(K5,JFNV?;'2(%9&4R#`R:[7+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(K5,JFNV?;'2P*/!
M6<#)+B(*"B,Z(&QI8B]61E,N<&AP.C@U-0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`BM4RJ
M:\6JJ/H@5D93(,#)KM<@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"@HC.B!L:6(O
M5D93+G!H<#HX.#8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(K5,JFO%JJCZ(%9&4R#`
MR:[7("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@H*(SH@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`BM4RJ:\6JJ/K`R:[7.B`B"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C8W,PIM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+B(*;7-G<W1R("*U3*IKQ:JH^B!V9G-R;V]T(*78O_TN
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3`T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N
M(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("*U3*IKI_.F5R`E<R"L
ML"`E<SH@IEVLL*78O-"K2*7SIUBD=Z9SIF(B"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BM4RJ:\7<I_,@5D93(*78O_VJNJ97NMDN(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("*U3*IK
MLKZPHR!61E,@I=B__3H@)7,N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(W,2!L
M:6(O5D93+V9T<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKQ=RG
M\R!61E,@P,FNUR!<(B5S7"(@JKJF5[K9+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z-C$T(&QI8B]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M("*U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNJ97NMDN(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C,R-B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M
M=7-Q;"YP:'`Z-#4R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,R!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N(@IM<V=S='(@(K5,JFO%W*?S(%9&4R#`R:[7JKJF5[K9+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5
M;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`BM4RJ:[#UIN8@)VUK
M:7-O9G,G+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N="(*;7-G<W1R("*U3*IKPN"TJR!7;W)D(*3EI?,B"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BM4RJ:[QGI$H@5D93(%PB)7-<(B#`R:[7+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,3@S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("*U3*IKO&>D2B!61E,@P,FNUR`H
M8V]P>2@I(&9A:6QE9"DN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.#4@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U
M,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S
M='(@(K5,JFN\9Z1*(%9&4R#`R:[7N.JNQBXB"@HC.B!L:6(O5D93+G!H<#HX
M-C$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"XB"FUS9W-T<B`BM4RJ:[QGI$H@5D93(,#)KM<L(+K/
MNM"P=,-"I'>ZH2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`BJ;.]=2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA
M;F=E<R(*;7-G<W1R("*H^J[XI_.G[R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(K1?K>PB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(J;XJD&^N;-SM;*NR;5OI<VE
MO+EWM,&JNJ9>P+,Z("(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("*U;Z7-I;RY=[3!
MJKJF7L"S+*71IOBJ0;ZY.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("*EO*3`
MP_XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B56YI8V]D
M92`H551&+3@I(@IM<V=S='(@(KA5L.J]6"`H551&+3@I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N
M:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(E5N:71E9"!!<F%B($5M:7)A
M=&5S("BJ_*G4IT+!<*98I&JDO;#J*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D
M;VTB"FUS9W-T<B`B56YI=&5D($MI;F=D;VT@**U>L.HI(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R(*;7-G<W1R(")5;FET960@4W1A=&5S("BL_+#J*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD
M<R(*;7-G<W1R(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`BL^:F["(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R.2!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`BI;RJOJJZ(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`BI;RJOJJZ
M($%022"P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(J6\JKZJNJO(
MI.&P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(J6\JKZJNJ;LN&VXZK!4+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("*EO*J^JKJHSZ7.JLRF
M5[K9J<ZQ2[U8+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B"FUS9W-T<B`BI*3"7Z78JV6DN*7SJKJS<[6R(@H*(SH@;&EB
M+TAO<F1E+TED96YT:71Y+G!H<#HS,#$*;7-G:60@(E5N;F%M960B"FUS9W-T
M<B`BI;RI4J97(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N
M;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R
M("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H
M;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@
M:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D
M+B(*;7-G<W1R("(B"B*F7:9WI?[%5;Q[I*.DN;-<I;RQPL5VJKJU>Z:AL/6F
MYK#%I%4OO<:[<R^V2Z17+B#"2;_OO52I=Z5(P,NU^"!M;WII;&QA+F]R9R"I
MTB(*(K2CJ-&JNJS;P_:GWK-.I.6E\RS%_:=!I6FE2+C1L*.FN:1`K:VH[JC#
MIMNFYK9]J?&U>Z:AIG.H^K#%MDO#KRXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R("*H^J[XPT.FXB(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O
M<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`BI;RDY+2IJKJPQL#)IE<B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(L7<I_,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("*G\[=S("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D
M871E('5S97(B"FUS9W-T<B`BI_.W<ZC/I<ZJS"(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"*D=Z?SMW,N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N(@IM<V=S='(@(J?SMW.U>Z:AI'>G4K"C+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(J17ML<B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`BI'>D5[;'J=*FL\"SI<ZU>Z:AJKJS7:EWP,FH[*;XJD&^N2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(J1JO&>I
MU*1"O,:F<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`BI&J\9\.YL*B\QJ9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R(")5<G5G=6%Y("BO4:G4IF,I(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M($-U<G)E;G0Z("5S(@IM<V=S='(@(JC/I<ZEV*MEJKHZ("5S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-3
M3"(*;7-G<W1R("*HSZ7.(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(J9PJD>G0:JZJ,^ESJK,IE>Z
MV2^Q2[U8NU`@24U34""F^*I!OKFDHZ90+*5IIF*FN;-=J7<N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*
M;7-G<W1R("*HSZ7.JLPB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`BJ,^ESJK,("5S(*6\LW&Y3"`E<R"JNK'"
MQ7;%Y\/2+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("*HSZ7.JLRZWK)Z(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G
M<W1R("*HSZ7.JLR_[[:U(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E
M<B!296=I<W1R871I;VXB"FUS9W-T<B`BJ,^ESJK,M?FE52(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(J:YK[BE>*JZJ,^ESJK,
MM?FE5:ATLLZD=["QI<XN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V
M.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("*GY*2C
MJ.RHSZ7.JLRQ8KBY(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,V(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.3@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$U,`HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HS,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5
M<V5R;F%M92(*;7-G<W1R("*HSZ7.JLRF5[K9(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA
M;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("*HSZ7.JLRF5[K9
M(%PB)7-<(B"D=Z9SIF(N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BJ,^ESJK,IE>ZV3HB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R
M;F%M93H@(@IM<V=S='(@(JC/I<ZJS#H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`BJ'2RSJ2DJKJHSZ7.JLPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A
M;B(*;7-G<W1R(")5>F)E:VES=&%N("BO4:_WIT^G2BDB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C$V-R!L:6(O5D93+V9I;&4N<&AP.C(U.0IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93(*78O_VH
MPZ2CIG.F8BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS
M9VED(")686-A=&EO;B(*;7-G<W1R("*PLK3!(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z("(*;7-G<W1R("*D=Z?DJ.RFLZ[$JKJF8<)).B`B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`BIK.NQ*G*(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`BI4BDP,3!
MK+"SYJ;L*+%QLGNF8K!?NN(I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@V
M,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C`*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,3<@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("*MR"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3$S(&QI8B](;W)D92]&;W)M+G!H<#HR,3DP
M"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`BO^^H^JW(
MIMLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4@**7+I:.J
M_+G/*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G
M:60@(E9A<FEA8FQE(@IM<V=S='(@(L7<I,8B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E
M;&$B"FUS9W-T<B`B5F5N97IU96QA("BI9:2ZM^>IU"DB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N(@IM<V=S='(@(L7GP]*EHK'1("T@IKFV;*7SI6FOX*1WOD2D2+[5IMN_
M>:?O+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED
M(")697)S:6]N(@IM<V=S='(@(JJII;LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B
MJJFEN[&QJ.XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R
M("*KJZJ]N>^[]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B
MJZNJO;G4I5(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`BJZNJO3HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I
M9"`B5F5R>2!(:6=H(@IM<V=S='(@(JM$L6"PJB(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@
M3F%M(@IM<V=S='(@(E9I970@3F%M("BV5JMN*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S
M='(@(K96JVZDY2`H5DE30TE)*2(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R("+`R[7X("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I
M9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("*F8K=SM?BU
MH;9]L=(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`BI4@@)7,@
MP,NU^"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S
M='(@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H("BM7L3=NONHRKASKG$I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B5FER9VEN
M($ES;&%N9',L(%4N4RX@**S\Q-VZ^ZC*N'.N<2DB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("*OX*BC
MJ]<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED
M(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`BK^"HHZO7.B`B"@HC.B!L:6(O3F5T
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("*X<:1JIU&E\;QWK;>Y<:M(I+VE
M<;-ZN4P@4TU44"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("+$M:=I(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N(@IM<V=S='(@(L2UIVDA(2$@L7$@)7,@I.*PRK*^L*.U>Z:A+B(*"B,Z
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@
M2%144"(*;7-G<W1R(")724X@N&>ET2!(5%10(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES
M(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES(&%N9"!&=71U;F$B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-"!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BQ+6G
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3@*;7-G:60@(E=E(@IM<V=S='(@(JQ0M,&D5"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*
M;7-G<W1R("*DT:[PN7>T^B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G
M<W1R("*N\+9(N.JNQK2CJ-$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV
M"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2"Z]*^X
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G
M<W1R("*Z]*^X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM
M<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`BNO2ON"(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("*H0[9G
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E
M;&-O;64B"FUS9W-T<B`BQ7>J[R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(L5WJN^H["`E
M<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE+"`E<R(*;7-G<W1R("+%=ZKO+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DQ"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R
M("*FZ+S:("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DR"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`BINB\
MVB`H25-/+3@X-3DM,34I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S
M='(@(E=E<W1E<FX@4V%H87)A("BFZ+R[JZ*IU"DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P
M;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S
M='(@(K5NI$JKX<"SN-.E_<7CI=P@)7,@K?ZD0*W3P+.ESK5[IJ$_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(L3FINRJNJ3`N6JF
M<J2X/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED
M(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(J3>K7JJ
MNJMEN&VF<J2X/R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T
M<B`B5VAE<F5I<R!!=7-T<F%L:6$@IF&YSR(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(JW^K=.DZZS;
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*
M;7-G<W1R("*Z]*VVO7._Z+ZYJKJTH:7S*'!L=6=I;G,IL=*PRK&QJ.XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`BO&6KUR(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3$T"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS
M9W-T<B`BI4@@0U-3(*RPL^:F[*JZO&6KUR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(J6JP^0E<Z5<K^"J[:JZO&6KURBD5::XM6ZD2JEL
MI<VNQ"DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("*J
M[:[FO&6KUR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(KQEJ]>SYJ;L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("*\9:O7.B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`BMK#%
MZ;/0IT`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7
M:6YD(@IM<V=S='(@(JVW(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`BIJVF
MLZVW(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S
M<&5E9"!I;B!K;F]T<R(*;7-G<W1R("*MM[-T*+A@*2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("*MM[-T.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I
M;F0Z("(*;7-G<W1R("*MM[-T.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("*TO+QZ(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T
M<B`BM,&KW<*GJJLB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`BI'6G0"(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BO^RDO:O'
MIF&G?2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR
M"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(K_LI+VKQ[EQN-PB"@HC.B!L
M:6(O1FEL92]#4U8N<&AP.C$Y,R!L:6(O1FEL92]#4U8N<&AP.C(Y-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI
M;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`BLL0E9*;F
MJKK$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE=:?DJ.PE9*W3
MQ.:F["XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(L3FINR\QJ78I*.EO[U4+B#`L[C3K6ZFLR5D
MK=/$YJ;L+*5UI^2H["5DK=/$YJ;L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,3$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@
M)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("*U3*IKQ=RG
M\R!61E,@P,FNUZJZIE>ZV2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S
M='(@(E@U,#EV,R"IM:;YJO?&7[MYJFLB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@I42FKK3`I4ZF5[K9(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV,R"E1*:NJO?&7\/1
MIT^JS"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED
M(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@L,;`R:97(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(J9^
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4S"FUS9VED(")9
M65E9(@IM<V=S='(@(J9^(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H
M;V\@(2"F8;G/(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM
M<V=I9"`B665A<FQY(@IM<V=S='(@(JA#IGXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*
M;7-G<W1R(")996UE;B`HN*VJ^2DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`BK$\B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(JQ/JKHLI]JF4+=.(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(J=!I=BK9:C/
MI<ZOPJ3EIG*]<[QGO-*FH2X@J,^ESB!;/#Y=(*OVMG.E::3!M*NLL+KTK;:]
M<[QGO-*FH2XB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`BI*.DN;-<IT&KV*7?
M)62E2*17JKJPS[;T+B(*"B,Z(&QI8B](;W)D92YP:'`Z,30Q-0IM<V=I9"`B
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`BIT&EO+-1L<+%
M=BXB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P-PIM<V=I9"`B66]U
M(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92XB"FUS9W-T<B`BIT&JNJ7^IE>DI*2CI6FFLR`G7%PG(+-OO,NJNJ9R
MI+@N("(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4Y(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED
M(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(J=!J,.EO+_II$JD0*W3IK.NQ*JZ
MN7&D;+9LI?.F[*=]+B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`BIT&HPZ6\I=&VUZ1*JKK`R:[7
MI*2Y[ZQ-I?2F\\3FINRH["`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY
M.#0*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B
MIT&D=[AGM6ZE6"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V-0IM<V=I
M9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*
M(KW0O^FD2J1`K=.FLZ[$JKJY<;C<N+F]6"RPZKO:N7&XW+BYO5BVR*5UI+FS
M7+S&IG*XN;U8+*C#M?BQH:IPI6FI\ZMEK;&F0:5;I$`B"B*MTR`G*R<N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(J=!I;*VM[_II$JD0*W3
MIK.NQ*JZK<@N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS-PIM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T
M;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`BIT&ELK:WI?VS5[FZIFZ^\*JLN.JN
MQBA$871A5')E92FF^*I!NMVD?J_@Q'[$\JC/I<ZW<Z7.I.&U^:55JD&PR"XB
M"@HC.B!L:6(O2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(J=!I;*VMZ7]LU>YNJ1`K=.U
MZL#`P,FNUZATLLXH5D93*:;XJD&ZW2XB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N(@IM<V=S='(@(KW0M'FM>K#=PT2A0:9BIT&VQ[!EL-W#1+/XIVFDIZME
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;R(*;7-G<W1R("*G0:6RMK>_Z:1*IKFS<[6RJ=*K_*96
MJKJZ]*=](@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB
M"FUS9W-T<B`BO="K_*EWK6ZG4K"CJKJF^*I!OKDN(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@8VQE87(@;W5T+B(*;7-G<W1R("*]T*O\J7>M;K)-L*.JNJC/I<ZJS"XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(KW0J_RI=ZUNLKZP
MHZJZJ,^ESJK,+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("*]T*O\J7>M;K=SO%>J
MNJC/I<ZJS"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B
MO="K_*EWK6ZG\[=SJKJHSZ7.JLPN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S
M+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T
M:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(KW0J_RI=ZUNL/6FYJJZIT"ESBXB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM
M<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G
M<W1R("*G0:6RMK>_Z:1*MW.DP,/^JKJF5[K9+B(*"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O
M('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`BIT&E
MLK:WM*.HT:1`K=.X<:1JIU&YTJ2ZJKJY<;C<N+F]6"(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HY-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(J=!JKH@)7,@MWRTP:1WN4RNR2Z]T*VKMW.U;J1*+B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL
M($%D9')E<W,B"FUS9W-T<B`BIT&JNKEQI&RV;*7SINVG?2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S
M<SHB"FUS9W-T<B`BIT&JNK%(I?.D2+EQI&RV;*7SINVG?3HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`BIT&J
MNKCJL%0B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@HBIMNQ<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&JNKKT
MN]JZ]+CTINRG?:1WQ=RG\RX@K+"K3\5`IT&JNJ9WI?ZP7ZBCH4&G0:6RMK>M
MJR(*(K=SM6ZD2BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(J=!JKJF5[K9(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D
M9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D
M;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R
M96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(J=!
MJKK%Y\/2IOBJ0;K=J,.DHZ3DM*FW<[Q7J,^ESJK,+B"F<*I'IT&GQK'FNMZR
M>JC/I<ZJS+%BN+DLIT&ELK:WI72_[ZCDI4RJNL7G(@HBP]*F^*I!NMTN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(J=!JKK%
MY\/2NMVHPZ6\I.2TJ:9#I5BHSZ7.JLRISKC3I5ROX*1WLU'#]K.L+B(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B*FV[%QIT&JNB`E<R"W?+3!MGVI;*5(J-.G0:JZPG/$_;ZYIORE
M1Z1WQ=RG\RX@K+"K3\5`IT&JNJ9WI?ZP7ZBCH4&G0:6RMK>MJ[=S(@HBM6ZD
M2BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM<V=I9"`B66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R
M("*G0:JZPG/$_;ZYJ,.EO*3DM*FS;ZW3I5ROX"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(J=!JKK"
M<\3]OKFHPZ6\I.2TJ:9#IDR_[[:U+KW0J_8@0U123"]#;VUM86YD("L@4""F
M0Z9,+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(J=!I=BK9:G2LUVI=ZJZ
MKLFPSSHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3@*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("*[
MU:15N7>S7:JZJ*VE]\/1IT^D=\7<I_,N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G
M<W1R("*[U:15N7>S7:JZJ*VE]\/1IT\Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(J=!
MJKJE_J97.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.38*;7-G:60@(EEO
M=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(J=!JKJU;J1*I'>H[+3!
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B
M"FUS9W-T<B`BIT&F8B`E<R"DI*JZMW.Q2[U8K$\Z("5S(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BXB"FUS9W-T<B`BIT&F8K5NI$JTP;:AJKJ_[[:UI'>S4:?SMW,N(@H*(SH@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BIT&JNK_OMK6D=Z?SMW,N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`BIT&JNK%+O5BD
M=ZVKMW.S7:EW(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("*Q2[U8I'>S4:VKMW.S7:EW++=SJKJQ2[U8I'>S>KE,
MN7&D;+9LI?.Q2+5OO="E2+C3L4N]6+5NI$HN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.C<S,`IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB
M"FUS9W-T<B`BIT&JNK%+O5BD=ZCLM,$N(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*
M;7-G<W1R("*G0:JZN[>ZW:;XJD&^N3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M675G;W-L879I82(*;7-G<W1R(")9=6=O<VQA=FEA("BK;K2UJ=2DTBDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM
M<V=S='(@(EIA:7)E("C"Q*7L*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R
M("):86UB:6$@**E\I/&HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R
M(")::6UB86)W92`HJ*^DVJO"*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1
M=6]T960@5&5X=%TB"FUS9W-T<B`B6\'TPL.DWJUZ72(*"B,Z('-E<G9I8V5S
M+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S
M='(@(ENPW<-$I,^L35TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G
M<W1R(");Q>.EW*3>K7H@+2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");Q>.EW*3>
MK7H@+2`E<R"FYETB"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6Z;LJ?.FYB`E
M<R"F0"`E<R"FYETB"@HC.B!L:6(O2&]R9&4N<&AP.C$U-#4@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(KK>LGI?02(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,
M22(*;7-G<W1R("*I4J5/ID-?0R(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I
M9"`B7T1A=&%4<F5E(@IM<V=S='(@(K[PJJRXZJ[&7T0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G
M:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(J=2L*.F0U]$(@H*(SH@;&EB+V%P
M:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(KASLM5?1R(*"B,Z
M(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@
M(KNAJ?I?2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`BO':YLZ2ZKF5?22XN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H
M<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BM6ZD2E],(@H*(SH@;&EB
M+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B
MM6ZE6%],(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T
M<B`BK=>G[[-SM;)?32XN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*
M;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(K_OMK5?3R(*"B,Z(&QI8B]A<&DN
M<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(L5VK:U?4"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(K*^L*.Y
M[[-SM;)?4BXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P
M(@IM<V=S='(@(K-=J7=?4R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`BJNVNYJ2ZKF5?5"XN+B(*"B,Z(&QI8B]A<&DN
M<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(JC/I<ZJS%]5(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C`*;7-G:60@(F%D9')E<W,@8F]O:R(*
M;7-G<W1R("*S<;!4O_TB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S
M='(@(K-QL%2__2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$R"FUS9VED
M(")C86QE;F1A<B(*;7-G<W1R("*FYJC&ON0B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("*Y<Z_%K;<B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`BM4RJ:ZO8I=^_Z:58P,FNUR(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N
M;F]T(&]P96X@:6YP=70B"FUS9W-T<B`BM4RJ:[9]L=*_Z:1*(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B8VQI8VL@:&5R
M92(*;7-G<W1R("*K]J:Y(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T
M<B`BL4NE3Z9#NWFJ:[_YNWXB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B
MLUVI=[_YNWXB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-30*
M;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B
MO_*EHJVKK6ZJNJATLL[`R:[7(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("*X
MZJ[&KN:FH;_YNWXB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("*GY*2CJ.RP3[_]
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*
M(RP@9G5Z>GD*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`BM?NDP"(*"B,Z(&QI
M8B](;W)D92]"<F]W<V5R+G!H<#HX.#$*;7-G:60@(F9I;&4B"FUS9W-T<B`B
MP,FNUR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF
M;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T
M<B`BL7$@)7,@*"5S*2"I\R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`BL'VMMR(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#@*;7-G
M:60@(F@Z(@IM<V=S='(@(J[).B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-3<*;7-G:60@(FAH(@IM<V=S='(@(J[)(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA
M;64@=6YK;F]W;B(*;7-G<W1R("*EO*J^JKJV;*7SI42^]Z97NMDB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS
M9W-T<B`BI=^G62(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`BJKVQ
MM<7CI=RI\Z6[I.6PSR(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(K_II$HO
MO^FE6+_YNWXB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#8*
M;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(J2ZLZ&S
M;L7IO_F[?B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`BIN9=(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-C@*;7-G:60@(FUM(@IM<V=S='(@(J3`(@H*(SH@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W
M,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N
M86UE(@IM<V=S='(@(J97NMDB"@HC.B!L:6(O2&]R9&4O4E!#+G!H<#HQ,C0*
M;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("*I?*6\N>JG0"XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`BJ7REO+GJIT`N(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`BL\:G
MT;_](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("*FRJ3`I/$B"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI
M<W-I;VX@9&5N:65D(@IM<V=S='(@(J9SJ/J^1*G:(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B
M<&EX96QS(@IM<V=S='(@(KFSK\`B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R("*S<:M(J/.I=[NWNMV_^;M^(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R
M("*D5Z3)(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R"FUS
M9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(K5,I6FESJJZJD&P
MR"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@
M9&EF9F5R96YC97,B"FUS9W-T<B`BQ>.EW*YTLJ<B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA
M($A45%`B"FUS9W-T<B`B<VUS,F5M86EL(+AGI=$@2%144"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0*;7-G:60@(G-S(@IM
M<V=S='(@(JSM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("+#K:EW(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R
M;W(B"FUS9W-T<B`BJ'2RSK_YNWXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDR.`IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(JO=O^S#KR(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y
M(&9A:6QU<F4B"FUS9W-T<B`BO,BNR:G*JKJEHK'1(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@
M(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B
MID&FN+_II$JG0:JZL4N]6*5(O52[>[5,NWXB"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI
M9FEE9"(*;7-G<W1R("*^XZ98(@H*(SH@;&EB+TAO<F1E+TU)344O4&%R="YP
M:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`BI;RI4J97(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`BJ,^ESJK,O^^^W"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,`IM<V=I9"`B
M=SHB"FUS9W-T<B`BK%"TP3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC
M;VT@NO2ON"(*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P;R]H=5](52YP;P``````````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P-S$W,C<V`#$P-3$U-#,Q,#8R`#`Q-C0R,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C($AO<F1E
M($AU;F=A<FEA;B!T<F%N<VQA=&EO;B!F:6QE+@HC($-O<'ER:6=H="`H0RD@
M,C`P,BTR,#`V($QA<WIL;R!,+B!4;W)N;V-I"B,@5&AI<R!F:6QE(&ES(&1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E
M('!A8VMA9V4N"B,@3&%T97-T('9E<G-I;VYS.B!F='`Z+R]X96YI82YS;W1E
M+FAU+W!U8B]L:6YU>"]H;W)D92\*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#8M,#(M,3<@,3`Z,#`K,#$P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-BTP,BTQ-R`Q,#HS."LP,3`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($QA<WIL;R!,+B!4;W)N;V-I(#QT;W)L87-Z0'AE;FEA+G-O=&4N:'4^
M7&XB"B),86YG=6%G92U496%M.B!(=6YG87)I86X@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR7&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O
M*2(*;7-G<W1R("(@*"5S(&YA<'!A;"!E>F5L]71T*2(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B("A!;'0M8FEL;&5N='G[("5S*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@
M9&%Y<RDB"FUS9W-T<B`B("@E<R!N87`@;?IL=F$I(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S-S<*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H;6$I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-SD*;7-G:60@(B`H=&]M;W)R
M;W<I(@IM<V=S='(@(B`H:&]L;F%P*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S<U"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AT96=N87`I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B(#H@(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@;F5M(&%L
M:_9N>79TX7(N(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM
M<V=S='(@(EPB)7-<(B!N96T@Z7)VZ6YY97,@=N%L87-Z=.%S+B(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-S$P(&QI8B](;W)D92]296=I<W1R>2YP
M:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S
M7"(@;FEN8W,@:V]N9FEG=7+A;'9A(&$@2&]R9&4@4F5G:7-T<GEB96XN(@H*
M(SH@;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB
M)7-<(B!F87-T<G5K=/IR82UM96=J96QE;NUT]2!N96T@=&%LX6QH873S+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T
M<B`B7"(E<UPB+70@:&]Z>N%A9'1U:R!A(&-S;W!O<G1O:VAO>BXB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(M="!H;WIZX6%D='5K(&$@:F]G;W-U;'1SX6=I
M(')E;F1S>F5R:&5Z+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S7"(M="!N
M96T@:&]Z='5K(&SI=')E.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR
M9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"(&9E;&AA<WIN
MX6QT(&$@)2XR9DU"(&UE9V5N9V5D971T8O5L("@E+C)F)24I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@Z7,@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO
M=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B)60@;F%P(&WZ;'9A(&QE
M:N%R(&IE;'-Z87;A;F%K(.ER=NEN>65S<^EG92XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"!N87!O<R!E;/5R96IE;'KI<R(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($9I9WEE;&UE>G1E
M=.ES(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@;&5N
M>6]M870B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@:V%R8F%N
M=&%R=.%S:2!F96QA9&%T;VL@+2!M96=E<O5S[73I<R(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R!B9>%L
M;.UTX7,B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(&QO9VEN
M(&[I=B!I9^EN>6SI<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B)7,@<WIO;&?A;'1A=.%S:2!F96QTZ71E;&5K(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C0S,B!L:6(O5D93+W-M8BYP:'`Z-#DT(&QI8B]61E,O
M9G1P+G!H<#HV.#(*(SH@;&EB+U9&4R]F='`N<&AP.C<U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B02!<(B5S
M7"(@;F5V^R#A;&QO;>%N>2!MX7(@;.ET97II:RXB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A="`E<R`E<R(*;7-G<W1R("(E<R`Z("5S("5S(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB
M"FUS9W-T<B`B(@HB02AZ*2`E<R!KZ7-Z96X@X6QL(&%Z(&%LX6)B:2!K87)B
M86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<^ER92Y*96SV;&IE(&MI("(*
M(F%Z;VMA="!A(&9E;&%D871O*&MA*70L(&%M:2AK92ET(&UO<W0@96P@:^UV
MX6X@=NEG97IN:2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!K
M:73V;'3I<V4@<WK\:W/I9V5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E
M<R!P97)C(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(B5S(&YE;2!T86SA;&AA=/,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E
M<R(*;7-G<W1R("(E<R`M("5S("CV<W-Z97-E;B`E<RDB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D
M9')E<W,@0F]O:R(*;7-G<W1R("(E<R!C[6UJ96=Y>NEK92(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`B)7,@;F%P=.%R82(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A
M9"(*;7-G<W1R("(E<R!F96QJ96=Y>NES96DB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T
M(@IM<V=S='(@(B5S(&9E;&%D871L:7-TX6IA(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I
M;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S
M;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z($QE:&5T<^EG97,L
M(&AO9WD@97H@82!L97;I;"!V86SS:N%B86X@;F5M(&$@;65G861O='0@9F5L
M863S=/-L("(*(G-ZX7)M87II:RX@1V]N9&]L:F$@;65G+"!M:65L]71T('+A
M:V%T=&EN="!V86QA;6ER92P@=F%G>2!S>F5MZ6QY97,@(@HB:6YF;W)MX6-I
M\W0@860@;65G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G
M=7-T:6YG("(*;7-G<W1R("(L('-ZZ6QL]FOI<V5K(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@)7,@
M)7,M<R!S>NEL;/9KZ7-E:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<R(*;7-G<W1R("(L(';A;'1O>O,@)7,@Z7,@)7,@:_9Z]G1T(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,S(@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HS-#@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C<T.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(';A;&%S<WIO
M;B`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U
M<B!&;W)M870B"FUS9W-T<B`B,3(@\W+A<R!F;W)MX71U;2(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T
M<B`B,C0@\W+A<R!F;W)MX71U;2(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"#S<F$B"@HC.B!L
M:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS
M9W-T<B`B/$5L]7KU(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C8*;7-G
M:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RXB"FUS9W-T<B`B17IE;B!B;&]K:R!H87-Z;N%L873A:&]Z(&5G>2!A
M9&%T8N%Z:7,@86QR96YD<WIE<B!S>OQK<^EG97,N(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM
M<V=S='(@(DAE;'ER96AO>FAA=&%T;&%N(&AI8F$@=/9R=.EN="(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B02!L97;I;"!T:71K;W/M=.%SX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K
M=6QC<R!S>OQK<^EG97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB02!D:6=I=.%L
M:7-A;B!A;.'M<G0@;&5VZ6P@96QL96[U<GKI<^EH97H@96=Y(&YY:6QVX6YO
M<R!01U`@:W5L8W,@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)!('1I=&MO<^UT;W1T
M(&QE=NEL(&1E:_-D;VSA<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,L
M(&5G>2!T:71K;W,@4$=0("(*(FMU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\
M:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,38*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"B)!(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E
M9WD@;GEI;';A;F]S(%!'4"!K=6QC<RP@96=Y('1I=&MO<R!01U`@:W5L8W,@
M(@HBZ7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B
M"B)!('1I=&MO<^UT;W1T(&QE=NEL(&1E:_-D;VSA<^%H;WH@96=Y(&YY:6QV
MX6YO<R!3+TU)344@:W5L8W,L(&5G>2!T:71K;W,@4R\B"B)-24U%(&MU;&-S
M(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB02!L
M97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY:6QVX6YO<R!3+TU)
M344@:W5L8W,L(&5G>2!T:71K;W,@4R]-24U%("(*(FMU;&-S(.ES(&5G>2!J
M96QM;VYD870@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D$@;&5VZ6P@=&ET
M:V]S[73A<^%H;WH@96=Y(&YY:6QVX6YO<R!3+TU)344@:W5L8W,@<WK\:W/I
M9V5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")$Z6QE;/5T="!B;W)U;'0@
MZ6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")$Z6QE;/5T="!G>65N
M9V4@97/U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B1.EL96SU='0@97/U(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G
M:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B1.EL96SU='1I('KA<&]R;VLB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I
M9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D3I;&5L]71T(&CS>N%P;W)O
M:R(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]0
M32(*;7-G<W1R(")D92]D=2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$("AA
M('!R;V=R86UO>N%S:2!F96S\;&5T(&%Z;VYO<^UT\VIA*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B
M;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D5R<O5L(&%Z(&5D:71O<G+S;"(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN
M+B(*;7-G<W1R(").Z79J96=Y+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S
M='(@(F%B<WH@86QU;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")A8G-Z
M(&OV>NEP(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYI
M;F-S(&IO9V]S=6QT<^%G82!A(%9&4R!A;&OV;GEV=.%R(&SI=')E:&]ZX7/A
M:&]Z+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B3FEN8W,@:F]G
M;W-U;'1SX6=A(&$@5D93(&;A:FP@;.ET<F5H;WKA<^%H;WHN(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I
M;VXB"FUS9W-T<B`B0F5J96QE;G1K97KI<VD@:6YF;W)MX6-I\R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R
M9"(*;7-G<W1R(")*96QS>O,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@
M(D$@:F]G;W-U;'1SX6<@9F5L('9A;B!F_&=G97-Z='9E+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS
M9W-T<B`B4.EN>OQG>65K(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T
M<B`B0F5V:71E;"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B
M06QC<V]P;W)T(&SI=')E:&]ZX7-A(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")*;V=O<W5L='/A9VD@86QC<V]P
M;W)T(&SI=')E:&]ZX7-A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!9&1J=6L@:&]Z>N$@:71T
M.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(MIJ(&-S;W!O<G0@
M;.ET<F5H;WKA<V$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES
M<VEO;B(*;7-G<W1R("+::B!J;V=O<W5L='/A9R!LZ71R96AO>N%S82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM
M<V=S='(@(D%L8W-O<&]R="!H;WIZX6%DX7-A(%PB)7-<(BUH97HB"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")*
M;V=O<W5L='/A9VD@86QC<V]P;W)T(&AO>GKA863A<V$@7"(E<UPB+6AE>B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB
M"FUS9W-T<B`BVFH@9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("+::B!O<WIL;W`@:&]Z>N%A9.%S82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N
M97<@;65M8F5R<R(*;7-G<W1R("+::B!T86=O:R!F96QVZ71E;&4B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*
M;7-G<W1R("+::B!PX7(@:&]Z>N%A9.%S82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(D$H>BD@)7,@;65N
M_'0@861J=6L@:&]Z>N$@82!-;WII;&QA(&UE;OQS;W)H;WHB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@
M861D<F5S<R!B;V]K.B(*;7-G<W1R(")!9&IU:R!H;WIZX2!A(&/M;6IE9WEZ
MZ6MH97HZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!9&IU
M:R!H;WIZX2!A(&/M;6IE9WEZZ6ME;6AE>B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("+::B!F96QH87-Z;N%L\R!H
M;WIZX6%DX7-A(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B
M"B(E<RXB"FUS9W-T<B`B(@HB7"(E<UPB(&9E;&AA<WINX6SS="!H;WIZX6%D
M='5K(&$@<F5N9'-Z97)H97HL(&1E(&YE;2!S:6ME<OQL="!A('3V8F)I("(*
M(F)E:F5L96YT:V5ZZ7-I(&%D870@=.%R;VSA<V$Z("5S+B(*"B,Z('-I9VYU
M<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B7"(E
M<UPB(&9E;&AA<WINX6SS="!F96QV971TZ6L@82!R96YD<WIE<F)E+B!-;W-T
M(&WA<B!B96IE;&5N=&ME>FAE="XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D
M+B(*;7-G<W1R(")!(')E;F1S>F5R:&5Z(&YE;2!A9&AA=/-K(&AO>GKA(/IJ
M(&9E;&AA<WINX6SS:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-2!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*
M;7-G<W1R(")#[6TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q
M"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B0^UM:F5G>7KI:R(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN
M:7-Z='+A8VGS("T@:F]G;W-U;'1SX6=O:R!A9.%S82!T;W;A8F)I(&9E;&AA
M<WINX6SS:VYA:R(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")!9&UI;FES>G1RX6-I\R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R(")(:7)D973I<V5K(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G86YI<WITX6XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;&)A;FEA(@IM<V=S='(@(D%L8N%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM
M<V=S='(@(D%L9^ER:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"FUS9VED(")!;&EG;B(*;7-G<W1R(")%;&AE;'EE>NES(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI
M9VYM96YT.B(*;7-G<W1R(")296YD97KI<SHB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")A>B#V<W-Z97-E="(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S
M(@IM<V=S='(@(DUI;F1E;B!N96T@=F5N9.EG(&9E;&AA<WINX6SS(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R(")-:6YD96X@8W-O<&]R="(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(DUI
M;F1E;B!J;V=O<W5L='/A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S
M(@IM<V=S='(@(DUI;F0@82!NZ6=Y(&]L9&%L;VX@;&5G>65N(&ME<F5T(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S4*;7-G:60@(D%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<R(*;7-G<W1R(")%;F=E9&K\;FL@;65G('3V8F(@8^UM
M970@:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")!
M('-O<G-ZX6UO<R!F96QS;W)O;.%S('3M<'5S82!VX6QT;WIT871H873S(&QE
M9WEE;C\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*;7-G
M:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DWA<B!LZ71E>FEK(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-
M4U`@3&]G:6XB"FUS9W-T<B`B24U34"!B96IE;&5N=&ME>NES:2!P87)A;>ET
M97)E:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L
M=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(DWA<VEK+"!)35-0(&IE
M;'-Z\R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L
M=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(DWA<VEK+"!)35-0(&)E
M:F5L96YT:V5ZZ7-I(&[I=B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R
M(")-X7-I:R!E;6%I;"!C[6TB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")!;'1E<FYA
M=.UV('-A8FQO;F]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B06QT97)N873M=B!S>O9V96<Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC
M86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK86D@4WIA;6]A(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q
M-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G
M<W1R(")!(&UE9V%D;W1T(.ER=.EK(&YE;2!F;V=A9&AA=/,@96PN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B27-M97)E=&QE;B!H
M:6)A('3V<G3I;G0N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I
M;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO
M;FEM('!R;WAY;B!K97)E<WIT_&QI(&EN=&5R;F5T(&5LZ7+I<R(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS
M9W-T<B`B5N%L87-Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A
M<FMT:7-Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!
M;G1I9W5A(.ES($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T
M(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O2&]R9&4O0FQO8VLO54DN<&AP
M.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G
M:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%L:V%L;6%ZX7,B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B
M"FUS9W-T<B`B06QK86QM87KA<V]K(&QI<W3A:F$B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB
M"FUS9W-T<B`B07H@86QK86QM87KA<R!KZ7-Z+B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R
M97,B"FUS9W-T<B`B02!K]GKV<R!TX7)T97+\;&5T(&%L8W-O<&]R=&IA:7)A
M(&ES(.ER=NEN>65S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B2O-VX6AA9WGA<R(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$*;7-G:60@(D%P
M<')O>&EM871E(%-I>F4B"FUS9W-T<B`B2_9R_&QB96S\;&D@;>ER970B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`BX7!R:6QI<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B87)A8B`H
M5VEN9&]W<RTQ,C4V*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R(")!('3V;?9R[71E='0@X6QL;VWA;GD@;>ER
M971E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G
M<W1R(")!('3V;?9R[71E='0@X6QL;VWA;GD@;F5V92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B0FEZ=&]S(&)E;FYE
M+"!H;V=Y('3V<O9L;FD@:^UVX6YJ82`E<R!B96IE;&5N=&ME>NES:2!I9^EN
M>>ET/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B
M0FEZ=&]S+"!H;V=Y('3V<O9L;FD@86MA<FIA(%PB)7-<(BUT(&%L8W-O<&]R
M=&IA:79A;"!E9WG\='0_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R
M9V5N=.UN82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`BUG)MZ6YY;W)S>N%G
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N
M("A!4DU30TE)+3@I(@IM<V=S='(@(O9R;>EN>2`H05)-4T-)22TX*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@
M(DW[=NES>F5T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B4&]H;G!E:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%S8VEI(')A:GIO:R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A
M8VEF:6,@4F5G:6]N(@IM<V=S='(@(L%Z<VEA+T-S96YD97,M\V-EX6YI('+I
M9VGS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_(@IM<V=S='(@(B(*(DOI<FIE;B!A(')E;F1S>F5R(&UE9V5R
M]7/M=.ES="!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K(&5L=NEG>NES92!E
M;/5T=#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(DAO>GKA<F5N9&5LZ7-I(&]S>FQO
M<&]K(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(DYE;6SI
M=&5Z]2!C<V]P;W)T;W0@:^USZ7)E;'0@;65G('3V<O9L;FDN(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5M;.ET
M97KU(&IO9V]S=6QT<^%G;W0@:^USZ7)E;'0@;65G('3V<O9L;FDN(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(").96ULZ71E
M>O4@:F]G;W-U;'1SX6=O="!K[7/I<F5L="!M96<@;65G=N%L=&]Z=&%T;FDN
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(DYE
M;6SI=&5Z]2!K]GKV<R!TX7)T97+\;&5T970@:^USZ7)E;'0@;65G(&UE9W;A
M;'1O>G1A=&YI+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(E1U;&%J9&]N<^%G;VLB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(F%U9W5S>G1U
M<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-Z='+A;&EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')I82(*;7-G<W1R(")!=7-Z=')I82(*"B,Z(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y
M<G-Q;#H@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T
M:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B
M:6QI=&5S+B(*;7-G<W1R("(B"B)!=71H7V-Y<G5S.B!A(&CA='3I<G-Z;VQG
MX6QT873A<R!N96T@<F5N9&5L:V5Z:6L@82!K[7;A;G0@:^EP97-SZ6=E:VME
M;"XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?8WER=7,Z(&$@<WK\:W/I9V5S(&EM87`@8O5V[73I
M<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z(&$@<WK\:W/I9V5S
M(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N($9O<F3M='-A(&QE(&$@4$A0
M+70@87H@+2TB"B)E;F%B;&4M9G1P(&]P8VGS=F%L+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P
M.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?:W)B-3H@82!S>OQK<^EG97,@:W)B-2!B]7;M=.ES(&YE;2!T86SA
M;&AA=/,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED
M(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@;F5M(&AO
M>FAA=/-K(&SI=')E(/IJ(&9E;&AA<WINX6SS:R!!8W1I=F4@1&ER96-T;W)Y
M(&5S973I;B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,U-PIM<V=I
M9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@9F5L
M:&%S>F[A;/-K(&YE;2!T]G+V;&AE=/5K($%C=&EV92!$:7)E8W1O<GD@97-E
M=.EN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VQD87`Z(&$@<WK\:W/I9V5S($Q$05`@8O5V[73I<R!N
M96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A
M9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM
M<V=S='(@(D%U=&A?;&1A<#H@)7,@9F5L:&%S>F[A;/,@:&]Z>N%A9.%S82!N
M96T@<VEK97+\;'0N($$@<WIE<G9E<B!VX6QA<WIA.B`B"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T
M:%]L9&%P.B`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E(&YE;2!S:6ME<OQL="(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*
M;7-G<W1R(")!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS(&%D871A:6YA:R!M
M96?Z:NUTX7-A(&YE;2!S:6ME<OQL="(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R
M(")!=71H7VQD87`Z(&$@9F5L:&%S>F[A;/-K(&YE;2!M\V1O<^UT:&%T\VL@
M06-T:79E($1I<F5C=&]R>2!E<V5TZ6XB"@HC.B!L:6(O2&]R9&4O075T:"]M
M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@82!S>OQK
M<^EG97,@34-!3"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?<VUB875T:#H@82!S>OQK<^EG97,@<VUB875T:"!B]7;M=.ES(&YE;2!T
M86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(").96T@<VEK97+\;'0@87H@24U!4"!S>F5R=F5R96X@=F%L\R!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"(*;7-G<W1R(")!(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@<VEK97+\
M;'0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B
M02!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('-I:V5R_&QT+B`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!
M(&9E;&AA<WINX6SS(&%Z;VYO<^UTX7/A="!A(%)!1$E54R!S>F5R=F5R(&5L
M=71A<^UT;W1T82XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#@R"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M3F5M('-I:V5R_&QT(&%Z($944"!S>F5R=F5R:&5Z('9A;/,@9F5L:&%S>F[A
M;/-A>F]N;W/M=.%S+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(").96T@<VEK97+\;'0@87H@4TU"('-Z97)V97)E;B!V86SS(&9E;&AA
M<WINX6SS87IO;F]S[73A<RXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")!(')E
M;F1E;&ME>NES<F4@X6QL\R!M97KU:SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM
M<V=S='(@(D%Z97)B86ID>G/A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D$@9V]N;W-Z(')E
M;F1S>F5R9V%Z9&$@;65N='/I9V5I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N
M9"(*;7-G<W1R(")(X71TZ7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(DCA='3I<B!S>NUN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B
M3F5M(&UE9V9E;&5L]2!K97)B97)O<R!J96QS>O,N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B3F5M(&UE9V9E;&5L]2!K97)B97)O<R!F96QH87-Z;N%L
M\V[I=BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%MX6LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(D)A:')E:6XB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T
M<B`B8F%L=&D@*$E33RTX.#4Y+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS
M9W-T<B`B0F%N9VQA9&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R
M8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B02!G<F%F:6MU<R#A;&QO;>%N>6]K(%PB)7-<
M(B!A;&OV;GEV=.%R82!N96T@=&%LX6QH873S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B86QA<'9O;F%L;VXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM
M<V=S='(@(D9E:.ER;W)O<WIO<G-ZX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S
M='(@(D)E;&=I=6TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM
M<V=S='(@(D)E<FUU9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=.%N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G
M:60@(D)I<G1H9&%Y(@IM<V=S='(@(E-Z_&QE=.ES;F%P(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B02!<(B5S7"(@8FQO:VL@82!<(B5S7"(@<')O9W)A
M;6UA;"!N96T@=&%LX6QH873S+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B2^EP
M97)N>?5RZ7-Z(&)EX6QL[73A<R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")+Z7!E<FYY
M]7+I<WH@=.UP=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B9NEL:_9VZ7(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")";VQI=FEA(@IM<V=S='(@(D)O;.UV:6$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B
M2V5D=F5N8R!W96)C[6UE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R
M(")+97)E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(DME
M<F5T=F%S=&%G<^%G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B
M2V5R971E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T
M<B`B0F]S>FYI82U(97)C96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")-:6YD:V5T=/4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T
M=&]M(@IM<V=S='(@(F%L=6PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(D)O=79E="US>FEG970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A
M>NUL:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(@IM<V=S='(@(D)R:70@26YD:6%I+?-C9>%N:2!497+\;&5T(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QGX7)I82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U
M;&QE=&5D($QI<W0B"FUS9W-T<B`B1F5L<V]R;VSA<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI
M;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I
M(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B5V5B;VQD86P@:V%R8F%N=&%R
M=.%S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G
M:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS
M9W-T<B`B02!T86[Z<^UT=N%N>79I<W-Z879O;N%S:2!L:7-TX6L@*$-23"D@
M8^UM96DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B0V5L;&$@='5L86ID;VYSX6=O:R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N(@IM<V=S='(@(D$@8V%C:&4@:6YI8VEA;&EZX6SA<V$@;F5M
M(&9E:F5Z]63V='0@8F4N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0X-2!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,`HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*
M;7-G<W1R(").87!TX7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(DYY=6=O9'0B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]D>G-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB
M"FUS9W-T<B`B2V%M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R(").
M96T@<VEK97+\;'0@82!J96QS>O-T(.%TX6QL[71A;FDL(&9O<F1U;&IO;B!A
M(')E;F1S>F5R9V%Z9.%H;WHN(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB
M)7-<(B(*;7-G<W1R(")!*'HI(%PB)7-<(B#A;&QO;>%N>2!N96T@[7)H873S
M+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R(")!
M(&O\;'/U(&9E;&AA<WINX6SS:V%P8W-O;&%T+6ME>F5L]6L@;F5M(&%D;6EN
M:7-Z='+A;&AA=/-K+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR
M,S4@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS
M9W-T<B`B02!K]G9E=&ME>O4@24U!4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PZ
M("5S(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<
M(B5S7"(@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE9RXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA
M9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D
M;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#
M86YC96PB"FUS9W-T<B`B3>EG<V4B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(DWI9W-E(&O\;&3V:R!H:6)A:F5L96YTZ7-T(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L
M971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B#A;&QO;>%N
M>2!N96T@=/9R]FQH973U+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T
M(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").96T@=&%L
MX6QH873S(&%Z(&ED96EG;&5N97,@X6QL;VWA;GEO:V%T('1A<G1A;&UA>O,@
M86QK]FYY=G3A<BXB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G
M:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M
M971E<BXB"FUS9W-T<B`B02`G=&%R9V5T1FEL92<@<&%R86WI=&5R(&UE9V%D
MX7-A(&[I;&O\;"!N96T@9F]L>71A=&AA=&IU:RXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@86QK]FYY
M=G3A<B!N96T@=/9R]FQH973U+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP
M:'`Z,3(X(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="XB"FUS9W-T<B`B3F5M('3V<O9L:&5T]2P@)60@86QC<V]P;W)T:F$@=F%N
M+B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B
M(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N
M(@IM<V=S='(@(B(*(D%Z(/IJ('-O<F)A<F5N9&5ZZ7,@;F5M(&QE:&5T<^EG
M97,L(&$@;65G861O='0@861A=&]K('-ZX6UA(&YE;2!E9WEE>FEK(&$@(@HB
M=.%R;VQT86OI=F%L+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+B(*;7-G<W1R(")!(&UE9V%D;W1T('-ZX6UR82!N96T@
M:_QL9&AE=/4@96P@87H@_'IE;F5T+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS
M9W-T<B`B6O9L9"UF;VMI+7-Z:6=E=&5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO
M;B(*;7-G<W1R("+!8G)A<WKV=F5G(@H*(SH@;&EB+TYE="]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B4WIO;&?A
M;'1A=/,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A
M=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9_-R:>%K(.ES(&IE
M;/9LZ7/\:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")+86IM
MX6XM<WII9V5T96LB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I;"!T96QE
M9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(D-E
M;&QA='5L86ID;VYSX6=O:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S
M='(@(D-E;&QA(&)E;'/U(&UA<F?S.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O
M<&5R=&EE<R(*;7-G<W1R(")#96QL871U;&%J9&]N<^%G;VLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B
M0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")#96QLX6L@:_9Z]G1T:2!RZ7,Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*
M;7-G<W1R(")-;V)I;"!T96QE9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(FME
M;'1A("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T
M<B`B:_9ZZ7`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B2_9ZZ7`M869R:6MA:2!+]GITX7)S87/A9R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*2(*;7-G<W1R(")K96QE="UE=7+S<&%I("A)4T\M.#@U.2TR*2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T
M:69I8V%T92!$971A:6QS(@IM<V=S='(@(D$@=&%N^G/M=';A;GD@<NES>FQE
M=&5I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@
M(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(D$@=&%N^G/M=';A;GD@='5L
M86ID;VYO<V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM
M<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B5&%N^G/M=';A
M;GD@9F5L:&%S>F[A;.%S:2!I<N%N>65L=F5K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM
M<V=S='(@(D-SX60B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N
M9V4B"FUS9W-T<B`B5N%L=&]Z=&%TX7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM
M<V=S='(@(D$@:F5L<WKS(.%TX6QL[73A<V$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R(")!>B#6;B#A;'1A;"!E;&O\
M;&3V='0@;&5V96QE:V5N('-Z97)E<&SU(&[I=B#I<R!C[6T@;65G=N%L=&]Z
M=&%TX7-A+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM
M<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R
M=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)!(&IE;&5N(&MO
M;F9I9W5RX6-I\V)A;B!N96T@;&5H971SZ6=E<R!A(&IE;'-Z879A:R!M\V1O
M<^UTX7-A+B!&;W)D=6QJ;VX@82`B"B)R96YD<WIE<F=A>F3A:&]Z+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B2V%R86MT97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G
M:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(DQI;E]K96QL96[U<GKI<RXN
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B
M"FUS9W-T<B`B2^UN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS
M9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B:^UN
M86DL(&5G>7-Z97+[<^UT971T("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M(@IM<V=S='(@(FOM;F%I+"!H86=Y;VWA;GEO<R`H0FEG-2DB"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I
M;VXZ(@IM<V=S='(@(E;A;&%S<WIO;B!K:2!E9WD@86QK86QM87KA<W0Z(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(E;A;&%S<WIO;B!J96QS>O-T(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A
M('5S97)N86UE(@IM<V=S='(@(E;A;&%S<WIO;B!E9WD@9F5L:&%S>F[A;/-N
M979E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H
M;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B5N%L87-S>F$@
M:VD@82!DX71U;6]K(&UE9VIE;&5N[73I<VD@9F]R;>%JX70Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@9F5L<V]R;VSA<R!T[7!U
M<^%T("AS>N%M;WIO='0@;&ES=.%K;N%L*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)
M<VQA;F0B"FUS9W-T<B`B2V%RX6-S;VYY+7-Z:6=E=&5K(@H*(SH@;&EB+U9&
M4RYP:'`Z.3$T(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(D$H>BD@)7,@8VQA<W,@9&5F:6[M8VGS:F$@;F5M('1A;.%L:&%T\RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM
M<V=I9"`B0VQE87(B"FUS9W-T<B`B1&5R_&QT(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/
M9F9I8V4@=&%G<R(*;7-G<W1R(")4]G)L:2!A>B!-4T]F9FEC92!T86=E:V5T
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E
M<GDB"FUS9W-T<B`B02!L96OI<F1E>NES('3V<FSI<V4B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B)7,@9F5L:&%S>F[A;/,@
M=/9R;.ES92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")!(&9E;&AA<WINX6SS('3V
M<FSI<V4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM
M<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@
M861A=&%I;F%K('3V<FSI<V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R
M(")%<W3I<F4@9&5R_&QT(.EG(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E
M(@IM<V=S='(@(D$@9F]L>71A=.%S:&]Z(&MA='1I;G1S;VX@87H@96?I<G)E
M;"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@
M<WIO;&?A;'1A=.%S($A45%`M;B!K97)E<WIT_&PB"@HC.B!S97)V:6-E<R]K
M97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*
M;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")!>B!A8FQA:R!B97KA<N%S
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B
M"FUS9W-T<B`B0F]R=6QT(.EG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R
M(")296=G96P@9F5L:/5S(&ED]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B1F5L
M:/5S(&ED]2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S
M='(@(DOS:W5S>BUS>FEG971E:R(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B
M5/QN=&5S<_QK(&5L(&%Z(&]L9&%L<_,@;65N_'0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#
M;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("+6<W-Z97KA<G0@:V5R971E:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEA(@H*(SH@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*
M;7-G:60@(D-O;&]R(@IM<V=S='(@(E-Z[6XB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S,Q(&QI8B](;W)D92]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS,S(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4P,R!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS
M9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4WKM;G;A;&%S>G3S(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S(*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B4WKM;G;A;&%S>G3A<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G
M<W1R(")/<WIL;W!O:SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU,`IM
M<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")!>B!O<WIL;W!O:R!C[6UE
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O
M;6EC<R(*;7-G<W1R(")6:6-C96LB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B4&%R86YC<R(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R
M(")087)A;F-SZ7)T96QM97KU(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DUE9VIE9WEZZ7,B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`B3NEV+"!E;&YE=F5ZZ7,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O
M<R(*;7-G<W1R(")#;VUO<F4M<WII9V5T96LB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R
M(")#Z6<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O
M;7!U=&5R<R(*;7-G<W1R(")3>N%M[73S9^EP96LB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`B263U:N%RX7-I(&AE;'EZ970B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("))9/5JX7+A<VD@:&5L
M>7IE="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(DO\;/9N8G/I9V5K(&$@
M:V]N9FEG=7+A8VGS8F%N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L
M(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B)+Z7II<WKA
M;>UT\V?I<&5K:V5L+"!O:V]S=&5L969O;F]K:V%L+"!/=71L;V]K:V%L('9A
M;/,@861A='-Z:6YK<F]N:7KA;.%S("(*(FMO;F9I9W5RX6-I\VIA(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B02!K;VYF:6=U<N%C:?,@;>%R
M(&YE;2#I<G;I;GEE<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(E
M<R!K;VYF:6=U<N%C:?-J82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B
M02!J96QS>O,@;65G97+U<^UTZ7-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B
M2V]N9_,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE(@IM<V=S='(@(DMO;F?S:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%S
MX6<B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")3:6ME<G1E;&5N(&$@:V%P8W-O;&%T
M+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960Z("(*;7-G<W1R(")3:6ME<G1E;&5N(&$@:V%P8W-O;&%T
M.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B02!N>6EL=N%N;W,@:W5L8W-O:R!S>F5R=F5R92!E;'5T87/M=&IA
M(&$@:V%P8W-O;&%T;W0N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S
M='(@(D$@;GEI;';A;F]S(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A
M(&MA<&-S;VQA=&]T+B!/:V$Z("5S("@E<RDB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")3:6ME<G1E;&5N(&%Z($944"!S>F5R=F5R<F5L('9A;/,@
M:V%P8W-O;&%T+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W"FUS
M9VED(")#;VYT86-T<R(*;7-G<W1R(")087)T;F5R96LB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B02!P87)T;F5R96ME="!S:6ME<F5S96X@:&]Z>N%A9'1U:R!A
M(&/M;6IE9WEZZ6OI:&5Z+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F
M:6QE.B`B"FUS9W-T<B`B02!T]FWV<NUT971T(.%L;&]MX6YY('3M<'5S83H@
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N
M=',@;V8@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!T87)T86QM82(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B1F]L>71A
M=.%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VLM<WII9V5T
M96LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI
M92(*;7-G<W1R(")3_'1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@
M(DWA<V]L:G5K(.%T(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!MX7-O
M;.%S(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*
M;7-G<W1R(")!(&MI:F5L]FQT('+I<WH@;>%S;VSA<V$B"@HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B4WKA;6SA>N%S:2!A>F]N
M;W/M=/,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D5L96;A;G1C<V]N='!A
M<G0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B3F5M('-I
M:V5R_&QT(%!'4"UV96P@=&ET:V]S[71A;FD@82!L979E;&5T.B`B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(D$@;&5V96QE="!N96T@<VEK
M97+\;'0@4$=0(&%LX>URX7-S86P@96QLX71N:3H@(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M96YC<GEP="!M97-S86=E+B(*;7-G<W1R(")!(&QE=F5L970@;F5M('-I:V5R
M_&QT(&%Z(%,O34E-12!S>F%B=N%N>2!S>F5R:6YT('1I=&MO<^UT86YI+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B02!L979E;&5T
M(&YE;2!S:6ME<OQL="!3+TU)344@86SA[7+A<W-A;"!E;&SA=&YI+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R
M(")!('!A<G1N97(@861A=&%I="!N96T@<VEK97+\;'0@96QTX7)O;&YI+B`E
M<R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U
M-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(D%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!E;&QE;O5R:7IN:2!A('-ZX6ULX6KA;B!R96YD96QK97KI<W)E(.%L;/,@
M]G-S>F5G970N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM
M<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DYE;2!S:6ME<OQL="!A>B!,1$%0('-Z97)V97)H97H@:V%P8W-O;/-D
M;FDN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@
M=7-I;F<@1E10.B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@82AZ*2!<(B5S
M7"(@<WIE<G9E<G)E;"!&5%`@:V%P8W-O;&%T;W0@9F5L=F5N;FDZ("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(&OV
M<FQE=NEL;&ES=.%T+B`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS
M9W-T<B`B07H@861A=&]K(%!'4"!T:71K;W/M=.%S8O-L('3V<G3I;O4@9&5K
M\V1O;.%S82!N96T@<VEK97+\;'0Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`B07H@861A=&]K(%,O34E-12!T:71K;W/M=.%S8O-L
M('3V<G3I;O4@9&5K\V1O;.%S82!N96T@<VEK97+\;'0N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(D$@
M<&%R=&YE<B!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(D$@:_9R;&5VZ6QL:7-T82!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@
M)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT('3V<O9L;FD@82AZ
M*2!<(B5S7"(@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE
M;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&UE
M9^%L;&%P[71A;FD@82!C[6UZ971T(&5M86EL(&/M;>ET+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@8^UM:F5G>7KI:V5T+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A('1E;&IE<R!K]G)L97;I
M;&QI<W3A="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(").96T@<VEK97+\;'0@
M8F5O;'9A<VYI(&$@:_9R;&5VZ6QL:7-TX6L@=&5L:F5S(&9E;'-O<F]LX7/A
M="XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB('-T<F%TZ6=I
M82!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(")!
M*'HI(%PB)7-<(B!A;&OV;GEV=.%R(&YE;2!H;WIH873S(&SI=')E+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T
M(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B02!N>6EL=N%N;W,@:W5L8W-O="!N96T@<VEK97+\;'0@;65G<WIE<F5Z
M;FD@82!K=6QC<W-Z97)V97)R]6PN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B3F5M('-I:V5R_&QT(%PB)7-<(BUT(.URX7-I(&/I;&QA;"!M96=N
M>6ET;FDN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").96T@<VEK97+\;'0@)7,M
M="!M96=N>6ET;FDN(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT
M,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B02`E<R!K87)B86YT87)T
MX7-I(&UO9'5L(&YE;2!N>6ET:&%T\R!M96<B"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R(")!*'HI(%PB)7-<(B!A;&OV;GEV=.%R(&YE;2!N>6ET:&%T\R!M
M96<N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")!>B!,1$%0('-Z97)V97(@
M;F5M(.ER:&5T]2!E;"XB"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R
M("(E<R!N96T@;VQV87-H873S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@HB3F5M('-I:V5R_&QT(&$@:^UVX6YT(&9E
M;&AA<WINX6SS(&IE;'-Z87;A="#A=.%L;.UT86YI+B!!>B!M96=A9&]T="!A
M9&%T;VL@(@HB;F5M('9A9WD@;F5M('1E;&IE<V5N(&9E;&5L;F5K(&UE9RX@
M4'+S8N%L:F$@^FIR82P@=F%G>2!H82!T;W;A8F)I("(*(G-E9^UT<^EG<F4@
M=F%N('-Z_&MSZ6=E+"!F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S<U(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").
M96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&%Z(&5LZ7+I<VD@:F]G;W-U;'1S
MX6=O:V%T("A!0TPI(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@8F5O
M;'9A<VYI(&$@8^UM:F5G>7KI:V5T+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M(").96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5VZ6QL:7-TX70N("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@8F5O;'9A<VYI
M(&$@:_9R;&5VZ6QL:7-TX6MA="X@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DW(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<R(*;7-G<W1R(").96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&$@<WIE
M<G9E<B!KZ7!E<W/I9V5I="(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B3F5M('-I:V5R_&QT('9I<W-Z8>%L;.UT86YI(&5Z(&5R961E=&D@
M:V]N9FEG=7+A8VGS="XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!A
M;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&5L
M;65N=&5N:2`E<R!K;VYF:6=U<N%C:?-T+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R
M(").96T@<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I
M\W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A(&)A8VMU
M<"!K;VYF:6=U<N%C:?-T.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!E;&UE;G1E;FD@82AZ*2!<(B5S7"(@<V5T=7`@=7!G<F%D92!P
M<F]G<F%M;W0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&5L
M;65N=&5N:2!A*'HI("5S(&)A8VMU<"!K;VYF:6=U<N%C:?-T+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S
M879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@
M8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB02AZ*2`E<R!K;VYF:6=U
M<N%C:?-S(.%L;&]MX6YY="!N96T@<VEK97+\;'0@96QM96YT96YI+B!686=Y
M(&AA<WINX6QJ82!A("5S("(*(F]L9&%L;VX@;&5V]2!L96AE=/5SZ6=E:V5T
M+"!V86=Y(&WA<V]L:F$@X70@87H@86SA8F)I(&OS9&]T(&ED93H@)7,N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B07H@3$1!4"!S
M>F5R=F5R96X@;F5M('-I:V5R_&QT(&5L=NEG97IN:2!A(&ME<F5SZ7-T+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@
M7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@;F5M('9O;'0@=/9R]FQH973U+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*
M;7-G<W1R(")!('!A<G1N97(@861A=&%I="!N96T@<VEK97+\;'0@;?-D;W/M
M=&%N:2X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A(&OV
M<FQE=NEL;&ES=&$@;?-D;W/M=.%S82X@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R
M:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F5M
M('-I:V5R_&QT(&5L;65N=&5N:2!<(B5S7"(@:V]N9FEG=7+A8VGS:N%T.B`E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD
M;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S
M:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(D$@36]Z:6QL82!M96[\<V]R(&YE
M;2!T86SA;&AA=/,N($5L;&5N]7)I>GIE+"!H;V=Y(&UE9R!V86XM92!N>6ET
M=F$N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E
M<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B(@HB3F5M('-I:V5R_&QT(%PB)7-<(B!F96QH87-Z
M;N%L\VYA:R!J;V=O<W5L='/A9V]T(&%D;FD@82AZ*2!<(B5S7"(@;6%P<.%H
M;WHZ("4B"B)S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C,*;7-G:60@
M(D-O=6YT960@=&5X="(*;7-G<W1R(")+;W)LX71O<R!S>O9V96<B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*
M;7-G<W1R(")/<G-ZX6<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(E3A=F]K=&%TX7,B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("),Z71R96AO>N%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(DQI;FL@;.ET<F5H
M;WKA<V$B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(MIJ(&SI=')E
M:&]ZX7-A(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4R
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E
M871E('-U8B!F;VQD97)S(@IM<V=S='(@(D%L;6%P<.%K(&SI=')E:&]ZX7-A
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T
M;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B07H@;V)J96MT=6T@;.ET<F5H;WKS
M:N%N86L@:F]G;W-U;'1SX6=A:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C$V"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B2&ET96QK
MX7)T>6%S>N%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B2&]R=N%T;W)S
M>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(DIE;&5N;&5G:2`T(&;A>FES(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P
M"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(D$@:F5L96YL96=I
M(&9E;&AA<WINX6SS:V%P8W-O;&%T;VLB"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM
M92(*;7-G<W1R(")0;VYT;W,@:63U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R(")!(&IE;&5N;&5G:2!54DPB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B
M2F5L96YL96=I(&9E;&AA<WINX6SS:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")*96QE;FQE
M9VD@:63U:N%RX7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D$@:F5L
M96YL96=I(&ED]6KA<N%S:2!H96QY>F5T.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y
M;&4B"FUS9W-T<B`B2F5L96YL96=I('-T[6QU<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"B)-
M:6QY96X@<&%R86YC<V]K(&9U<W-A;F%K(&QE(&%U=&]M871I:W5S86X@82`E
M<V)E('3V<G3I;O4@8F5J96QE;G1K97KI<VMO<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@
M(D-U="(*;7-G<W1R(")+:7;A9^%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*
M;7-G<W1R(")!(&MI:F5L]FQT('+I<WH@:VEVX6?A<V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R
M=7,B"FUS9W-T<B`B0VEP<G5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(F-I<FEL;"`H
M2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")C:7)I;&P@*%=I;F1O
M=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(F-I<FEL;"UU
M:W+A;B`H2T])."U5*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(D-S96@@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<V
M"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S
M='(@(B(*(D133B`H861A=&9O<G+A<VQE[7+S("T@;.%S9#H@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92XB"B)D8BYI
M;G1R;RUD<VXN<&AP*2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(FYA<&]N=&$B"@HC.B!A9&UI;B]D
M871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T
M<B`B1&%T851R964@8O9N9^ES>O4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S(W-`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(D%D871BX7II
M<V)A;B!V86SS(&ME<F5SZ7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0P
M,B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B
M1&%T92(*;7-G<W1R(")$X71U;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@
M(D$@8F7I<FME>NES(&YA<&IA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W
M.3,*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(D3A='5M(&MI=N%L
M87-Z=.%S82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM
M<V=S='(@(FYA<'!A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB
M"FUS9W-T<B`B3W-Z;&]P('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$S(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B9&5C96UB
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B
M<WKA;6]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(D)E:V5Z
M9.ES(&MI:FIE8F(B"@HC.B!L:6(O<')E9G,N<&AP.C$Q-R!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")!;&%P
MZ7)T96QM97IE='0B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")!
M>B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!S>NUN(@H*(SH@;&EB+TAO<F1E
M+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G
M<W1R(")!;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/,B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB
M"FUS9W-T<B`B06QA<.ER=&5L;65Z971T('-H96QL(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")$
M969I;NUC:?-K(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C,R-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDX('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L
M971E(@IM<V=S='(@(E3V<FSI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E
M;&PB"FUS9W-T<B`B02!C96QL82!T]G)LZ7-E(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'
M<F]U<"(*;7-G<W1R(")!(&-S;W!O<G0@=/9R;.ES92(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G
M<W1R(")!(&YA<&SSX6QL;VWA;GD@=/9R;.ES92(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*;7-G
M:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(D$@:F]G;W-U;'1SX6<@
M=/9R;.ES92(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("),
M979E;&5K('3V<FSI<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G
M<W1R(")!(&-E;&QA('3V<FSI<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L
M=6UN(@IM<V=S='(@(D%Z(&]S>FQO<"!T]G)LZ7-E(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B5/9R]FQJ_&L@:VD@82!M96=LZ7;U(&%L
M=&5R;F%T[78@<V%B;&]N="(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(D$@
M;&5V96QE:R!T]G)LZ7-E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&IO9V]S=6QT<^%G86EN86L@=/9R
M;.ES92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")4]G+V;&K\:R!<(B5S
M7"(@:F]G;W-U;'1SX6=A:70@Z7,@96YN96L@97-E=&QE9V5S(&%L8W-O<&]R
M=&IA:70_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")!('-O
M<B!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y
M+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S
M='(@(D$@:VEVX6QA<WIT;W1T(&%Z;VYO<^UT\R!T]G)LZ7-E(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@
M<W5B(&9O;&1E<G,B"FUS9W-T<B`B07H@86QM87!PX6L@=/9R;.ES92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R
M(")!(&IE;&5N;&5G:2!O<WIL;W`@=/9R;.ES92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")!(&IE;&5N;&5G:2!S
M;W(@=/9R;.ES92(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@7"(E<UPB+B(*;7-G<W1R(")4]G+V;'3\:R!A*'HI(%PB)7-<(B!S971U
M<"!U<&=R861E('!R;V=R86UO="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E
M;&EV97)Y('1I;64B"FUS9W-T<B`B02!KZ7IB97/M=.ES(&ED96IE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&5N;6%R:R(*;7-G<W1R(")$X6YI82(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE
M;2(*;7-G<W1R(")!9&IO;B!L9>URX7-T(&$@<')O8FSI;>%R\VPB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.30R('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM
M<V=S='(@(DQE[7+A<R(*"B,Z(&QI8B](;W)D92YP:'`Z,3DW"FUS9VED(")$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(E+I
M<WIL971E:R`H82!(;W)D92!L;V=FX6IL8F%N(&ES(&UE9W1A;.%L:&%T\RDZ
M(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D$@
M<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%MX7)A(&OI<WK\;/4@;F%P
M;/-FX6IL8F$@:V5R_&QT96LN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B1F5J;&5S>G3I
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I
M;G0B"FUS9W-T<B`B2&%R;6%T<&]N="(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(DAA<FUA='!O;G0@:F5L96YL96<Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@
M(DAA<FUA='!O;G0Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT
M(@IM<V=S='(@(F)A;'+S;"!J;V)B<F$@[7+A<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO
M;B!R:6=H="!T;R!L969T(@IM<V=S='(@(FIO8F)R\VP@8F%L<F$@[7+A<R(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB
M"FUS9W-T<B`B0^UM=.%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W
M,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")!>B!I
M9/5P;VYT;VMA="`R-"#S<N%S(&9O<FWA='5M8F%N(&IE;&5N[71S_&L@;65G
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R(")-96=J96QE;NUTZ7-I(&)EX6QL[73A<V]K
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$
M:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(D$@<NES>FQE=&5S
M(&5L]7)E:F5L>NES(&UE9VIE;&5N[73I<V4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S
M='(@(D5L]7)E:F5L>NES(&UE9VIE;&5N[73I<V4@*')E</QL]73I<FDI(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#,*;7-G:60@(D1I<W!L87D@9F]R
M;6%T(@IM<V=S='(@(DUE9VIE;&5N[73I<VD@9F]R;>%T=6TB"@HC.B!L:6(O
M2&]R9&4O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N(@IM<V=S='(@(LER=&5S[73I<R!A(&OI>F)E<^UT971T(&QE
M=NEL('-O<G/A<O-L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1'IS:6)U
M=&DB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@
M;F]T(&1E;&5T92(*;7-G<W1R(").92!T]G+V;&K\:R(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B02!M86EN=&5N86YC92YP
M:'`@;F5M(.ER:&5T]2!E;"!K]GIV971L96[\;"XB"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")!
M>B!E;'/U('-O<B!A(&UE>O5K(&YE=F5I="!T87)T86QM87IZ83\@2&$@:6=E
M;BP@:F5L]FQJ92!K:2!E>G0Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B
M1&]M:6YI:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B
M1&]M:6YI:V%I($OV>G3A<G-A<^%G(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(*;7-G<W1R(").:6YC<R!MZ6<@;&]G:6X@;F5V93\@26?I;GEE;&IE
M;B!E9WEE="XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4R
M"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("),973V;'3I<R(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B5/9L='/\:R!L92`E<RUT(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B
M5/9L='/\:R!L92!02%`@<')O9W)A;2!F;W)MX6KA8F%N(&%Z(&5L:^ES>OQL
M="!K;VYF:6=U<N%C:?-T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$Q
M"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("),96?V<F3\;/4@;&ES
M=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S
M(@IM<V=S='(@(DOA8NUT\W-Z97)E:R(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(F5M86EL(@H*(SH@
M;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM
M=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O
M=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(D5M86EL8O5L(%--4RUK
M_&QD]2!M96=H86IT\RP@:&$@82!T96QE9F]N=.%R<V%SX6<@8FEZ=&]S[71J
M82!E>G0@82`B"B)S>F]L9^%L=&%TX7-T+B(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM
M<V=S='(@(DA)0D$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5C=6%D;W(B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B3?-D
M;W/M=.%S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B
M161I="!";&]C:R(*;7-G<W1R(")";&]K:R!M\V1O<^UTX7,B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B
M161I="!'<F]U<"(*;7-G<W1R(")#<V]P;W)T(&WS9&]S[73A<R(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")*;V=O<W5L
M='/A9R!M\V1O<^UTX7,B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(DIO9V]S=6QT
M<^%G;VL@;?-D;W/M=.%S82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B)7,@:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O
M<'1I;VYS(&9O<CHB"FUS9W-T<B`B365L>6EK(&]P8VGS:V%T(';A;'1O>G1A
M<W-U:SHB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B7"(E<UPB(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S82(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@:F]G
M;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B3VMT873A<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G>6EP=&]M(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!3
M86QV861O<B(*;7-G<W1R(")386QV861O<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE
M;65N="XN+B(*;7-G<W1R(")%;&5M+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@
M(F%Z("=M)R!B973[('-ZZ6QE<W/I9V4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@W,R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-`IM
M<V=I9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*
M;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16UA:6P@8^UM(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")!>B!E;6%I;"!C[6UE:VYE:R!E9WEE
M>FYI_&L@:V5L;"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,PIM<V=I
M9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B16UA:6P@=FES
M<WIA:6=A>F]LX7-S86PB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N
M<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")%
M;6%I;"U335,@X71JX7+S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(DAA;F=U
M;&%T:6MO;F]K(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(MQR97,@_'IE
M;F5T+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR-#,@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z-C8R(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N
M(@IM<V=S='(@(DYI;F-S(&EL>65N+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(E3V<O9L:OQK(&MI(&$@:V5R97/I<V5K970B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")%
M;F=E9&K\:R!M96<L(&AO9WD@:^EP96ME="!I;&QE<W-Z_&YK(&$@<WKV=F5G
M8F4@82!&;W3S9V%LZ7)IX6MB\VP_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`B3&5G>65N(&IO8F(@96?I<F=O;6)B86P@96SI<FAE=/4L
M(&MO;G1E>'1U<V;\9V?U(&UE;OP_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(U.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3<*;7-G:60@(D5N9"!Y96%R
M(@IM<V=S='(@(D%Z('5T;VQS\R#I=B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(L%T=N%L=.%S(&O\;/9N(&%B;&%K<F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB061J82!M96<@87IT
M(&$@8FEZ=&]N<^%G:2!KZ7)DZ7-T+"!A;65L>7)E(&UA:F0@=N%L87-Z;VQN
M:6$@:V5L;"!J96QS>F%VX6YA:R`B"B+A=.%L;.UTX7/A:&]Z+"!P;"X@)VAO
M9WD@:.UV:N%K(&$@:W5T>>%JX70_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")!9&IA(&UE9R!A(&OI
M<"!54DPM:NET(&ET="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*
M;7-G<W1R("+-<FIA(&)E(&%Z(&%LX6)B:2!B973[:V5T.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q
M=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D5G>65N;.UT]6DM1W5I;F5A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5A(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*;7-G
M:60@(D5R<F]R(@IM<V=S='(@(DAI8F$B"@HC.B!L:6(O2&]R9&4O5&5M<&QA
M=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN
M9R!B;&]C:SH@)7,B"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&$@8FQO:VL@;.ET
M<F5H;WKA<V%K;W(Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN
M8R!A;F-H;W(Z("5S(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A>B!A9&%T<WII
M;FMR;VYI>N%C:?-S(&IE;"!T]G)LZ7-E:V]R.B`E<R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")!>B!A9&%T<WII
M;FMR;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GD@=/9R;.ES92!N96T@<VEK97+\
M;'0Z("5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G
M<W1R(")(:6)A('3V<G3I;G0@87H@861A=&QE:^ERZ7-B96XZ("5S(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")(
M:6)A('3V<G3I;G0@82!J96QS>O,@;65G=N%L=&]Z=&%TX7-A:V]R.B`E<R(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED
M(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(DAI8F$@87H@
M96UA:6P@_'IE;F5T8F5N+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@
MX6QL;VWA;GER82!N96T@<VEK97+\;'0@[7)N:2XB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA
M(@IM<V=S='(@(LES>G1O<G-ZX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M(")%=&GS<&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED
M(")%=&AN:6,B"FUS9W-T<B`B3F5M>F5T:7/I9V5K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7+S
M<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(C$U('!E<F-E;FOI;G0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B
M"FUS9W-T<B`B,B!P97)C96YKZ6YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(C,P(&WA<V]D<&5R8V5N:^EN="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(C4@<&5R
M8V5N:^EN="(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G
M:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(FUI;F1E;B!B96IE;&5N=&ME>NES
M:V]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E
M<GD@:&%L9B!H;W5R(@IM<V=S='(@(F;I;/-RX6YKZ6YT(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR
M"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B<&5R8V5N:^EN="(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE
M('9A;'5E<SHB"FUS9W-T<B`B4.EL9&$@Z7)TZ6ME:SHB"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B5NEG<F5H
M86ITX7,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(DYY:7-S=6L@<WKI="(*"B,Z
M('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N
M9"!3:61E8F%R(@IM<V=S='(@(DIE;&5N[71S_&L@;65G(&%Z(&]L9&%L<_,@
M;65N_'0B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G
M:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("))='0@)RDG(&ME;&QE;F4@:_9V
M971K97IZ96XB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*
M;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FTB"FUS9W-T<B`B(@HB271T(&-S=7!A<WH@<WKS;F%K('9A9WD@:63I>O5J
M96QB96X@;&5V]2!K97)E<^ES:2!K:69E:F5ZZ7-N96L@:V5L;&5N92!L96YN
M:64B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X
M<&ER871I;VX@1&%T92(*;7-G<W1R(")!>B#I<G;I;GEE<W/I9R!L96KA<F%T
M82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R(")+:71E=O4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO
M<B(*;7-G<W1R(")3>NUN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")!(&MO;F9I
M9W5RX6-I\R!&5%`M;B#A="!V86SS(&9E;'3V;'3I<V4B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R(")!('-Z96WI;'EE<R!B9>%L;.UTX7-O
M:V%T(&YE;2!S:6ME<OQL="!B96]L=F%S;FDN(@H*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B07H@3$1!4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B07H@4TU"('-Z97)V97(@;F5M(.ER
M:&5T]2!E;"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M(").96T@<VEK97+\;'0@82AZ*2!<(B5S7"(M8O5L('3V<G3I;O4@;>%S;VSA
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I
M:V5R_&QT(&$H>BD@7"(E<UPB+6)E('3V<G3I;O4@;>%S;VSA<RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R
M96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(").96T@<VEK97+\
M;'0@^FH@4T%33"!K87!C<V]L871O="!LZ71R96AO>FYI+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HU,#$@;&EB+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@
M(DYE;2!S:6ME<OQL="!A*'HI(%PB)7-<(BUB92!T]G)TZ6[U(.%T:&5L>65Z
MZ7,N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(L%L;&]MX6YY
M:&]Z>N%FZ7+I<VD@:&EB83H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")4:7-Z
M=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T
M<B`B1F%L:VQA;F0M<WII9V5T96L@*$UA;'9I;F%S*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E
M($ES;&%N9',B"FUS9W-T<B`B1F%R;V4M<WII9V5T96LB"@HC.B!L:6(O2&]R
M9&4O0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")(
M96QY<F5H;WIH871A=&QA;B!H:6)A.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B
M"FUS9W-T<B`B1F%X(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(F9E8G)UX7(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R
M(")(]6WI<G/I:VQE=.ER>F5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(DCU;>ER
M<^EK;&5TZ7)Z970Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")%9WDM
M96=Y('KA<&]R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4WKS
M<G;A;GEO<V%N(&CS>N%P;W)O:R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.30X"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B365Z]2!MX71R:7@B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R.0IM<V=I9"`B1FEG;&5T($-!
M4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$@*&)E=/MK:7)A:_,@:'5M
MX6YT97-Z="DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,S,PIM<V=I9"`B
M1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&
M:61Z<VDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(D9I;&4B"FUS9W-T<B`B1N%J;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B
M02!FX6IL;VL@<WKA;6$Z("5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B02!F
MX6IL;VL@<WKA;6$Z("5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D;A:FP@;65N961Z
M<V5R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R
M(")&X6IL;NEV(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.#$*;7-G:60@
M(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(D;A:FP@:VEJ96SV;.ES(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T.3`*;7-G:60@(D9I;&4@=7!L;V%D(@IM
M<V=S='(@(D;A:FP@9F5L=/9L=.ES92(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,#(*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R(")&X6IL;VL@9F5L=/9L=.ES92!N96T@;&5H971SZ6=E<RXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B4WK[<O5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YN
M;W)S>N%G(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER
M<W0@2&%L9B(*;7-G<W1R(")E;'/U(&;I;"(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U
M87)T97(B"FUS9W-T<B`B96QS]2!N96=Y960B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B5N%L=&]Z871L86X@;>ER971A<N%N>2(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T
M<B`B5/QK<O9ZZ7,@*&;V;"]L92DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(DOV9"(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HR,S<@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*
M;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(E<R!M
M87!P82!N96T@;.ET97II:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B
M0F5T^W-Z[6XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@
M(D9O;V0B"FUS9W-T<B`BR71E;&5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")/
M;'EA;B!B]FYGZ7-Z]6L@<WKA;>%R82P@86UI:R!N96T@:F5L96[M=&EK(&UE
M9R!A(&OI<&5K970B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I
M9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B16SU<F5J96QZZ7,@*')E</QL
M]73I<FDI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS
M9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D
M(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M(@IM<V=S='(@(B(*(D%Z(&5L]7)E:F5L>NES(&ED]71A<G1A;6$@;F%P;VMB
M86X@*&%Z(&5L]7)E:F5L>NES(&YA<'!A;&D@Z7,@Z6IS>F%K86D@(@HB861A
M=&]K870@=&%R=&%L;6%Z+"!E>NER="!A(&YA9WD@<WKA;6]K('-ZZ6QE<R!B
M;&]K:V]T(&5R961MZ6YY97IN96LI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G
M<W1R(")%;&9E;&5J=&5T=&4@82!J96QS>F%VX70_(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BVW)L
M87!K97IE;.ES(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(DEDZ7IE="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(DEDZ7IE
M="!F86ITX6IA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R("))9.EZ971E:R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("))9.EZ
M971E:R`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I
M9"`B1F]R=6US(@IM<V=S='(@(D;S<G5M;VLB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")4;W;A
M8F+M=.%S;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")0Z2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@
M(D9R86UE<R(*;7-G<W1R(")&<F%M92UE:R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G
M<W1R(")&<F%N8VEA;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(D9R
M86YC:6%O<G-ZX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D9R
M86YC:6$@1W5Y86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T
M<B`B1G)A;F-I82!0;VQI;NEZ:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R
M;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N8VEA($3I;&D@5&5R_&QE=&5K
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G
M:60@(D9R;VTB"FUS9W-T<B`B1F5L863S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@
M(D9R;VT@=&AE("(*;7-G<W1R("))<N%N>3H@(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B4NES>FQE=&5S(&QE[7+A<R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO
M;VXB"FUS9W-T<B`B=&5L:6AO;&0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I
M9"`B1G5L;"!.86UE(@IM<V=S='(@(E1E;&IE<R!NZ78B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O
M;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B365L>6EK(&=A;.ER:>%B\VP@
M=F5G>?QK(&$@:^EP970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM
M<V=S='(@(DOI<&=A;.ER:6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A
M;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M(")(;WIZ=6L@;.ET<F4@82AZ*2`E<R!K;VYF:6=U<N%C:?-JX70B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N
M97)A=&5D($-O9&4B"FUS9W-T<B`B02!K96QE=&ME>F5T="!K\V0B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")'96]R9VEA(@IM<V=S='(@(D=R^GII82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B3NEM971O<G-ZX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':.%N
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QTX7(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M
M92(*;7-G<W1R(")+97)E<WIT;NEV(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO
M;G,B"FUS9W-T<B`B1VQO8N%L:7,@8F7A;&SM=.%S;VLB"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B365H970B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*
M;7-G<W1R(")']F1E;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G
M;&4@=.ER:^EP(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I
M9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@:V5R97/I<R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@
M(D=R87ES8V%L92(*;7-G<W1R(")&96ME=&4O9F5HZ7(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E
M96-E(@IM<V=S='(@(D?V<O9G;W)S>N%G(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")G
M]G+V9R`H25-/+3@X-3DM-RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B
M1W+V;FQA;F0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B0W-O<&]R="!A9&UI;FES>G1RX6-I\R(*"B,Z(&QI
M8B](;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B02!C<V]P;W)T;NEV(&UA<F%D:&%T(/QR97-E;B(*"B,Z(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D=R;W5P7VQD87`Z("5S
M(&-S;W!O<G0@:&]Z>N%A9.%S82!N96T@<VEK97+\;'0N($$@<WIE<G9E<B!V
MX6QA<WIA.B`B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$X(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD
M87`Z("5S(&-S;W!O<G0@=/9R;.ES92!N96T@<VEK97+\;'0B"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B`E
M<R!C<V]P;W)T(&%D871A:6YA:R!M96?Z:NUTX7-A(&YE;2!S:6ME<OQL="(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS
M9VED(")'<F]U<',B"FUS9W-T<B`B0W-O<&]R=&]K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L
M;W5P92(*;7-G<W1R(")'=6%D96QO=7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T
M<B`B1W5A;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E
M>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E9E;F3I9R!J;V=O<W5L='/A9V]K
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E
M<W1B;V]K(@IM<V=S='(@(E9E;F3I9VOV;GEV(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM
M<V=S='(@(D=U:6YE82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R
M(")":7-S874M1W5I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y
M86YA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B
M2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA:FQA;F3S(&$@<V]R('5T;VQS
M\R!C96QLX6KA="!T]G+V;&YI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T
M86)L92XB"FUS9W-T<B`B2%1-3$%R96$@9WGA=F%SX6=B\VP@;F5M(&AA:FQA
M;F3S(&$@=.%B;.%Z870@=71O;'/S(&]S>FQO<.%T('3V<O9L;FDN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!G>>%V
M87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA="!U=&]L<_,@<V]RX70@
M=/9R]FQN:2XB"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G
M:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M($A45%`@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!T86SA;&AA=/,N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T
M<B`B2&%S:"!A;&=O<FET;75S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B2_9D(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDR,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDQ.`IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D9E:FSI8R(*"B,Z(&QI8B](
M;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(D9E:FSI8R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D+2#I<R!-8T1O;F%L9"US
M>FEG971E:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(D5R]7,@>FEV
M871A<B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R
M97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B:.EB97(@*$E33RTX.#4Y+3@M
M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B36%G87-SX6<B"@HC
M.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ
M.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B4V5G[71SZ6<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q
M"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")396?M='/I9R!A
M('-Z97)K97-Z=/4@:&%S>F[A;&%TX6AO>B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S<U"FUS9VED(")(96QP97(B"FUS9W-T<B`B4V5G[71SZ6<B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS
M9W-T<B`B1NEL=&5K92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E
M(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(D5Z(&$@
M9N%J;"!E;&5J93HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,`IM<V=I9"`B2&EG:"(*;7-G<W1R(")N86=Y(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")+97ID]6QA
M<"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM
M<V=S='(@(E9A=&EKX6YVX7)O<R(*"B,Z(&QI8B](;W)D92YP:'`Z,34S.0IM
M<V=I9"`B2&]M92(*;7-G<W1R(")+97ID]6QA<"(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
M3W1T:&]N:2!C[6TB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G
M:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(E-Z96WI;'EE<R!A;&OV;GEV
M=.%R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*
M;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B3W1T:&]N:2!T96QE9F]N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M2&]N9R!+;VYG(@IM<V=S='(@(DAO;F=K;VYG(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&AI8N%S
M("5S(%A-3"!A9&%T('9A;B!A*'HI("5S(/QZ96YE=&)E;B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@;FEN8W,@82AZ*2`E<R!O8FIE:W1U;6YA
M:R!M96=F96QE;/4@_'IE;F5T(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(&YI;F-S("5S('3M<'5S^B!O8FIE:W1U;2!A*'HI("5S(/QZ
M96YE=&)E;B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!3:6ME<F5S96X@
M=/9R]FQT_&L@97IT.B`E<R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(&%Z(&EN=&5G<N%L\R!P<F]G<F%M:&]Z('-Z
M_&MSZ6=E<R!A("=D;VUX;6PG(%!(4"!B]7;M=.ES(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE;2!S:6ME<OQL="#Z:B!834P@
M9N%T(&SI=')E:&]Z;FD@82AZ*2`E<R!O8FIE:W1U;6AO>B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@=/9R]FQN:2`E<RUT(%PB
M)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0X,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@HB
M2&]R9&4O2V]L86(Z(&YE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@82!-24U%
M($E$+6KA="!A(&OV=F5T:V5Z]2!T[7!U<_H@(@HB;65L;.EK;&5T;F5K.B`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;2!S:6ME<OQL
M="!S>FEN:W)O;FEZX6QN:2`E<R!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M("(B"B)(;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT(&$@:_9V971K97KU(&OV
M>O9S('3A<G1E<OQL970@<WII;FMR;VYI>N%LX7-A.B`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@:7-M97)E=&QE;B!K]GKV<R!TX7)T97+\;&5T(%PB)7-<(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G
M:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")6[7IS>FEN=&5S('9O;F%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(E;M>G-Z:6YT
M97,@;6%R9_,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")6[7IS>FEN
M=&5S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0
M;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B2&]G>2!J=71O='0@:61E/R`H2^ER
M:OQK(.UR:F$@;65G(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(X6YY(&]S>FQO
M<&]T(&OM=N%N(/9S<WIE;VQV87-Z=&%N:3\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DCA;GD@;65Z]2`H;W-Z;&]P*2!V
M86X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B2.%N>2!S;W)T(&OM=N%N(/9S<WIE;VQV
M87-Z=&%N:3\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")(=6UI9&ET>2(*;7-G
M<W1R(")0X7)A=&%R=&%L;VTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(E#A<F%T87)T
M86QO;3H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(
M=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W3A:R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R
M>2(*;7-G<W1R(")-86=Y87)O<G-ZX6<B"@HC.B!L:6(O2&]R9&4O075T:"]C
M>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L
M('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL
M960Z("5S(@IM<V=S='(@(D%Z($E-05`@;&5VZ6QLX61A(&SI=')E:&]ZX7-A
M(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP
M:'`Z,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(D%Z($E-05`@;&5VZ6QLX61A('3V<FSI<V4@;F5M('-I:V5R
M_&QT.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B07H@24U!4"!L97;I;&SA9.%H;WH@=&%R=&]Z\R!K=O-T82!LZ71R
M96AO>N%S82!N96T@<VEK97+\;'0Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@8^UM(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B07H@25`@8^UM(&YE;2!H
M873A<F]Z:&%T\R!M96<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP
M:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN(@IM<V=S='(@(D%Z($E0(&/M;2!N:6YC<R!A(&UE9V5N9V5D
M971T($-)1%(@=&%R=&]MX6YY8F%N+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I
M;VXN(@IM<V=S='(@(E1I;'1O='0O;65G=N%L=&]Z;W1T($E0(&/M;2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")3;W(@
M8F5I;&QE<WITZ7-E(&5F]FSI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@
M(DEZ;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@
M(DEC;VYS($]N;'DB"FUS9W-T<B`B8W-A:R!I:V]N;VLB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@
M9F]R("5S(@IM<V=S='(@(B5S(&EK;VYJ86DB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B
M:6MO;F]K(.ES('-Z]G9E9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B07H@87IO;F]S
M[73S:&]Z(';A;&%S>G1O='0@96QN979E>NES.B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")(82!A(&UE9VIE;&5N[73I<R!N
M96T@;65G9F5L96SU+"`E<R!E9WD@^FH@86)L86MB86X@=F%L\R!M96=N>6ET
MX7-H;WHN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B
M(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)(82#6
M;B!);G1E<FYE="!%>'!L;W)E<G0@:&%S>F[A;"P@Z7,@;F5M(&IE;&5N;F5K
M(&UE9R!A>B!I:V]N;VLL(&%K:V]R("(*(G;A;&%S<WIA(&5Z="!A>B!O<&-I
M\W0L(&UE;&QY96P@:VEK87!C<V]L:F$@82!03D<@:^EP96L@=')A;G-Z<&%R
M96YC:>%JX70N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T
M(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T
M(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*
M(DAA(&SA=&IA(&5Z="!A('-Z]G9E9V5T+"!D92!A(&OI<&5T(&YE;2P@86MK
M;W(@8O9N9^ES>O5P<F]G<F%M:F$@;F5M(&OI<&5S("(*(FUE9VIE;&5N[71E
M;FD@82!S>F5R=F5R<F4@:_QL9&5N9/4@:^EP970N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS
M9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")%;/5Z971E<R!NZ7IE=#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B02!KZ7`@55),+6IE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(D$@:^EP
M(%523"UJ93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R(")-96QY:6L@9V%LZ7)IX6+S;"!V86X@82!KZ7`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B2^EP
M(&5B8O5L(&$@9V%LZ7)IX6+S;#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(DOI<"!F96QT]FQT
MZ7-E(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E
M<R(*;7-G<W1R(")+Z7!E:R(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM
M<V=S='(@(DEM<&]R=.%LX7,L("5D+B!LZ7#I<R(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M=&5D(&9I96QD.B`E<R(*;7-G<W1R(")!>B!I;7!O<G3A;'0@;65Z]3H@)7,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O
M<G1E9"!F:65L9',Z(@IM<V=S='(@(D%Z(&EM<&]R=.%L="!M97KU:SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(E-O<B!B
M96EL;&5S>G3I<V4@97IA;.$B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB
M"FUS9W-T<B`B2&EBX7,@<&%R86YC<W!A<F%MZ71E<BXB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(").96T@;65G9F5L
M96SU(&$@8F5J96QE;G1K97KI<VD@;NEV(.ES+W9A9WD@82!J96QS>O,N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3F5M(&UE9V9E;&5L]2!A
M(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!A>B!A;'1E<FYA=.UV(&/M;2X@4'+S
M8N%L:F$@^FIR82!V86=Y("(*(F9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H
M;WHL(&AA('1O=N%B8FD@<V5G[71SZ6=R92!V86X@<WK\:W/I9V4N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I
M9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(D)E:V5Z9.ES(&)E;&IE8F(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B16=Y97,@9F5L
M:&%S>F[A;/-K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;V[I
M>FEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;W)MX6-I\R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S
M='(@(DEN9F]R;>%C:?,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+B(*;7-G<W1R(")!>B!I;F9O<FWA8VGS(&WA<B!N96T@X6QL(')E;F1E;&ME
M>NES<F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*
M;7-G<W1R(")/<WIL;W`@8F5S>OIRX7-A(&5Z=73A;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM
M<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(DOI<"!B96EL;&5S>G3I<V4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P
M"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B5.%B;.%Z870@8F5I;&QE
M<WITZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DQI;FL@
M;.ET<F5H;WKA<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E
M9F]R92(*;7-G<W1R(")/<WIL;W`@8F5S>OIRX7-A(&5Z96SI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")/<WIL;W`@8F5S>OIRX7-A(&5Z=73A;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(D]S>FQO<"!B97-Z^G+A<V$@97IE;.DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(E-O<B!B97-Z^G+A<V$@97IA;.$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R(")3;W(@8F5S>OIRX7-A(&5F]FSI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R(")"96ME>F3I<R!B96EL;&5S>G3I<V4@97IU=.%N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B0F5K97IDZ7,@8F5I;&QE<WITZ7-E(&5Z96SI(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B2&]Z>G5N:R!LZ71R92!A;'1E<FYA=.UV
M('-A8FQO;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED
M("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B061J;VX@;65G(&5G
M>2!E;6%I;"!C[6UE="P@;65L>7)E(&5L:_QL9&AE=/4@87H@UFX@^FH@:F5L
M<WIA=F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T
M<B`B0V5L;&$@8F5I;&QE<WITZ7-E(&5Z=73A;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN
M<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")#96QL82!B96EL;&5S>G3I<V4@
M97IE;.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S
M='(@(D]S>FQO<"!B97-Z^G+A<V$@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B3W-Z;&]P(&)E<WKZ<N%S82!E
M>F5LZ2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,"!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("),979E;&5K(&)E;>%S;VSA<V$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B0F5K
M97IDZ7,@8F5I;&QE<WITZ7-E(&5Z=73A;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B0F5K97IDZ7,@8F5I;&QE
M<WITZ7-E(&5Z96SI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*
M;7-G<W1R(")3;W(@8F5S>OIRX7-A(&5Z86SA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS
M97)T(')O=R!B969O<F4B"FUS9W-T<B`B4V]R(&)E<WKZ<N%S82!E9O9LZ2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB
M"FUS9W-T<B`B061J82!M96<@82!K[7;A;G0@=N%L87-Z="!A(&)I>G1O;G/A
M9VD@:^ER9.ES<F4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G
M<W1R(")+Z7`@8F5I;&QE<WITZ7-E+VWS9&]S[73A<V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B3&EN:R!B96EL;&5S>G3I<V4O;?-D
M;W/M=.%S82(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D$@<WKA;6SA:N%N(&YI;F-S
M(&5LZ6<@9F5D97IE="#\>F5N971E="!K_&QD96YI(&$@:_9R;&5VZ6QL:7-T
MX7)A+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*
M;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(D$@<WKA;6SA
M:N%N(&YI;F-S(&5LZ6<@9F5D97IE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")%9^ES>B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R(&QI<W0B"FUS
M9W-T<B`B16?I<WH@<WKA;6]K(&QI<W3A:F$B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T
M;&%N(%5$2"`H57-E<B!$871A($AE861E<BDN(@H*(SH@;&EB+TAO<F1E+T-O
M;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP
M.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@
M(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T
M;&%N(%I)4"!T]FWV<NUTZ7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")(:6+A
M<R]E;&9O9V%D:&%T871L86X@86QK86QM87KA<RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C
M:"!)1"XB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N(&)A=&-H(&%Z
M;VYO<^UT\RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S-@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB
M"FUS9W-T<B`B02!K_&QD]G1T(&%D870@:&EBX7,O96QF;V=A9&AA=&%T;&%N
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DAI
M8N%S+V5L9F]G861H871A=&QA;B!C[6UZZ7,N(@H*(SH@;&EB+TAO<F1E+T-O
M;7!R97-S+V1B>"YP:'`Z,3`Y(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP
M.C$S.0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@
M(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA
M=&%T;&%N(&;A:FP@9F]R;>%T=6TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G
M<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@;&EC96YS>FMU;&-S+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L
M:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H
M871A=&QA;B!VX7)O<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B
M2&EBX7,O96QF;V=A9&AA=&%T;&%N(/QZ96YE='3M<'5S+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T
M871L86X@=F%G>2!H:>%N>7KS('!R;V=R86UO>N%S:69E;/QL970M87IO;F]S
M[73S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N('!A<F%MZ71E<F5K+B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B2&EBX7,@87H@;V)J96MT=6T@96SI
M<NES:2!J;V=O<W5L='/A9V$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M(")(:6+A<R]E;&9O9V%D:&%T871L86X@<&%R=&YE<F%Z;VYO<^UT\RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A
M;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T
M;&%N('1E<FWI:VOS9"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B
M2&EBX7,O96QF;V=A9&AA=&%T;&%N('!R;W1O:V]L;"XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM
M<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!C[6UZ971T.B!<(B5S7"(B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P.#`@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R
M(")(:6+A<R]E;&9O9V%D:&%T871L86X@;65G;W-Z=&]T="!O8FIE:W1U;2(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")(:6+A<R]E;&9O
M9V%D:&%T871L86X@9F5L863S:2!C[6TN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D
M871A+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@=6YI8V]D92!A
M9&%T+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@
M(DEN=F5N=&]R>2(*;7-G<W1R(").>6EL=N%N=&%R=.%S(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T
M('-E;&5C=&EO;B(*;7-G<W1R(")!(&MI:F5L]FSI<R!I;G9E<G3A;.%S82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))
M<N%N:2!)<WILX6T@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T
M<B`B27)A:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("+-<F]R<WKA9R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@
M36%N(@IM<V=S='(@(DUA;BUS>FEG970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R
M;7,B"FUS9W-T<B`B4WKS<G;A;GEO<R!Z:79A=&%R;VLB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES
M<F%E;"(*;7-G<W1R("))>G)A96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(D$@=&%N^G/M=';A
M;GD@:VEA9/-J82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(F3U;'0B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DET86QY(@IM<V=S='(@(D]L87-Z;W)S>N%G(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA
M:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`R(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")J86YUX7(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<.%N(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B:F%PX6X@*$E33RTR,#(R+4I0*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)DX6YI82(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(FKZ
M;&EU<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED
M(")*=6YE(@IM<V=S='(@(FKZ;FEU<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB
M"FUS9W-T<B`B4V]R:VEZX7+A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E
M;G1E<B(*;7-G<W1R(")K]GKI<')E(')E;F1E>NES(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@
M(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")S;W)K:7KA<N%S(&UI;F1KZ70@;VQD
M86QR82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B<V]R
M:VEZX7+A<R!B86QR82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM
M<V=S='(@(G-O<FMI>N%RX7,@:F]B8G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N
M(@IM<V=S='(@(DMA>F%H<WITX6XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R(")487)T<W5K(&UE9R!A>B!E<F5D971I=#\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA
M(@IM<V=S='(@(DME;GEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B02!K97)B97)O<R!S>F5R=F5R(&5L=71A<^UT;W1T
M82!A(&9E;&AA<WINX6SS87IO;F]S[73A<W0N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")+
M97ID]2!K97)N96QF96IL97-Z=/5K(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B2W5L8W,@
M;.ET<F5H;WKA<V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30*
M;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(")!(&MU;&-S(&QE;GEO
M;6%T82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B
M2V5Y($QE;F=T:"(*;7-G<W1R(")+=6QC<VAO<W-Z^G/A9R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T
M<B`B2W5L8W,@=.UP=7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(D$@:W5L8W,@:&%S>F[A
M;&%T82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R(")!(&MU;&-S(&WA<B!LZ71E>FEK(&$@;GEI;';A;F]S(&MU;&-S
M<WIE<G9E<F5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I
M9"`B2VED<R(*;7-G<W1R(")'>65R96ME:R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB
M"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC
M(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A:2!.Z7!I($1E
M;6]K<F%T:6MU<R!+]GITX7)S87/A9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DMO<F5A:2!+]GITX7)S87/A9R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS
M9W-T<B`B:V]R96%I("A%54,M2U(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T
M<B`B2W5V86ET(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=I
M>FES>G3A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I
M9"`B3&%?>6]U="(*;7-G<W1R(")?5&5R=F5ZZ7,B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(").
M>65L=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,B"FUS9W-T<B`B3&%O<WII($[I<&D@1&5M;VMR871I:W5S($OV>G3A<G-A
M<^%G(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(
M86QF(@IM<V=S='(@(G5T;VQS\R!FZ6PB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@
M(D%Z('5T;VQS\R!J96QS>O-VX6QTX7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T
M97(B"FUS9W-T<B`B=71O;'/S(&YE9WEE9"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E5T;VQS
M\R!VX6QT;WIT873A<SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E5T
M;VQS\R!B96IE;&5N=&ME>NES.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<R(*;7-G<W1R(")5=&]L<_,@8F5J96QE;G1K97KI<SH@)7,L("5S(&/M
M;7+U;"(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@
M;&]G:6XZ($YE=F5R(@IM<V=S='(@(E5T;VQS\R!B96IE;&5N=&ME>NES.B!M
MZ6<@<V]H82!N96T@=F]L="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQE
M='1O<G-ZX6<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@
M(DQA=R(*;7-G<W1R(")*;V<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R
M(")%;&AE;'EE>NES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<B(*;7-G<W1R(")(86=Y:F$@_')E<V5N+"!H82!N96T@86MA<B!K97)E=&5T
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G
M:60@(DQE9G0B"FUS9W-T<B`B8F%L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,#4*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(D)A;"!O;&1A;&D@
M9F5J;.EC(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(D)A;"!O;&1A;&D@Z7)TZ6ME:R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R(")3>FEN
M="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I<FEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DSM8FEA:2!!<F%B
M(%-Z;V-I86QI<W1A($YA9WD@3NEP:2!+]GKV<W/I9R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE
M8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT
M($1R:7IZ;&4B"FUS9W-T<B`B1WEE;F=E('-Z:73A;/,@97/U(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI
M9VAT(%)A:6XB"FUS9W-T<B`B1WEE;F=E(&5S]2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN
M($5A<FQY(@IM<V=S='(@(D3I;&5L]71T(&=Y96YG92!E<_4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG
M:'0@4F%I;B!,871E(@IM<V=S='(@(D3I;'5TX6XO97-T92!G>65N9V4@97/U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*
M;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(D=Y96YG92!ZX7!O
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")'>65N
M9V4@>FEV871A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(D=Y96YG92!H
M879A>N%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(D=Y96YG
M92!H\WKA<&]R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED
M("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("),:6YK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED
M("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B02!L:6YK(&ED92!M=71A=#HB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W.0IM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R(")-96=J96QE;NUTZ7-K;W(@;75T87-S;VX@96=Y(&QI
M;FL@82!L97;I;&/M;7+U;"!A(&QE=NEL[7+S(&%B;&%K:&]Z(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),
M:6YK<R(*;7-G<W1R("),:6YK96LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A
M;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-TX7KA<R`M(&$@9F5L:&%S
M>F[A;/,@;.%T:F$@82!M87!PX70B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")!>B!A9&%T8N%Z
M:7-O:R!L:7-TX6IA(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*
M;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B07IO:VYA:R!A('3I
M;>%K;F%K(&$@;&ES=.%J82!A;6ER]6P@<V5G[71SZ6<@:V%P:&%T\R(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM
M<V=S='(@(D%Z(&%D871TX6)LX6L@;&ES=.%J82(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(DQI<W1A(&%R8VCM=G5M(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R
M<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES=&$@<V5G
M[71SZ6=KZ7+I<R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T82!A>F]N;W/M=/,B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M
M3W=N97(B"FUS9W-T<B`B3&ES=&$@='5L86ID;VYO<R(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S
M='(@(DQI<W1A(&QE=NEL[7+A<R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E
M<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES
M=&$@9F5L:7)A=&MO>N%S("AS=6)S8W)I8F4I(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM
M<V=S='(@(DQI<W1A(&QE:7)A=&MO>N%S("AU;G-U8G-C<FEB92DB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(D$@9F5L:&%S>F[A
M;/-K87!C<V]L871O:R!K:6QI<W3A>N%S82!N96T@<VEK97+\;'0Z("5S(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")!(&9E;&AA<WIN
MX6SS:R!K:6QI<W3A>N%S82!N96T@<VEK97+\;'0Z("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")!(&9E;&AA<WINX6SS:R!K:6QI
M<W3A>N%S82!T:6QT=F$@=F%N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("))<F]D86QO;2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI=';A;FEA(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N
M+BXB"FUS9W-T<B`B3&5T]FQTZ7,N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B
M2&5L>6D@:63U.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G
M:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R(").>65L=BP@9.%T=6TL(&ED
M]2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`B2&5L>2(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")"
M96IE;&5N=&ME>NES(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S
M='(@(D%Z(&5L]7KU(&%D871S>FEN:W)O;FEZX6-I\R!N87!L\^%L;&]MX6YY
M82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@
M(DQO9R!O=70B"FUS9W-T<B`B2VEJ96QE;G1K97KI<R(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B0F5J96QE
M;G1K97KI<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-S96P@:V%P8W-O
M;&%T;W,@9F5L861A=&]K(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0IM
M<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB
M02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="P@;65R="!R;W-S>B!F96QH
M87-Z;N%L\VYE=F5T('9A9WD@:F5L<WKS="!A9&]T="`B"B)M96<N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*
M;7-G<W1R(")!(&)E:F5L96YT:V5ZZ7,@;F5M('-I:V5R_&QT+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,S8Y"FUS9VED("),;VYG('1E>'0B"FUS9W-T
M<B`B2&]S<WKZ('-Z]G9E9R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M.`IM<V=I9"`B3&]V92(*;7-G<W1R(")3>F5R96QE;2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED("),;W<B"FUS
M9W-T<B`B86QA8W-O;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L
M971T97)S(@IM<V=S='(@(F?V<O9G(&MI<V)E=/MK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I
M9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")L871I;B!K:7-B973[
M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B:VES8F5T^W,@<O-M86D@<WKA;6]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G
M(@IM<V=S='(@(DQU>&5M8G5R9R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB
M"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S
M"FUS9VED(")-3U1$(@IM<V=S='(@(DYA<&D@_'IE;F5T96LB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@
M071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B07H@35,M
M5$Y%1B!M96QLZ6ML971B96X@;FEN8W,@861A="XB"@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU3
M1R(*;7-G<W1R("+<6D5.150B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA
M:V'S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%K963S;FEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A
M9V%S8V%R(@IM<V=S='(@(DUA9&%G87-Z:^%R(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")687+A>G-L870B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB
M"FUS9W-T<B`B3&5V96QE>NES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")%;6%I;"!D;VUA
M:6X@:V5Z96SI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G
M<W1R("),:6YK(&OI<WKM=.ES92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@
M(DUA;&%W:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L86IZ:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&3M=BUS>FEG971E:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*
M;7-G<W1R(")-X6QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM
M<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB061A=&%I
M="!K871E9_-R:>%K8F$@<V]R;VQH871J82X@17IE:R!I='0@9&5F:6YIX6QH
M873S:RP@;?-D;W/M=&AA=/-K+"`B"B)T;W;A8F+A('-Z[6YE:R!R96YD96QH
M973U:R!H;WIZX6IU:RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T
M('3I<FOI<"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#@W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W0@=.ER
M:^EP(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED
M(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(D$@:&]Z>N%R96YD96SI<V5K
M970@96QM96YT971T_&LN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(FWA<F-I=7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS
M9VED(")-87)G:6XB"FUS9W-T<B`B36%R9_,B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B
M"FUS9W-T<B`B07H@3VQV87-O='0O3VQV87-A=&QA;B!J96QZ971E:R!H87-Z
M;N%L871A(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB
M"FUS9W-T<B`B3>%S(&IE;'IE=&5K("AP;"X@1F]N=&]S+TUE9W;A;&%S>F]L
M="D@:&%S>F[A;&%T82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G
M<W1R(")-87)S:&%L;"US>FEG971E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*
M;7-G<W1R(")-87)T:6YI<75E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")%9WEM
MX7-N86L@;65G9F5L96SU(&UE>O5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(DUA=7)I=.%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R
M(")-875R:71I=7,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")-
M87AI;>%L:7,@<F5N9&5L:V5ZZ7-R92#A;&SS('-ZX6UL8?9S<WIE9RXB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(D%Z(/QZ96YE
M="!T^FP@<V]K('+I<WIB]6P@X6QL+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B07H@96QM^FQT(#(T(/-R82!M87AI;>%L:7,@:/5MZ7)SZ6ML971E.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@
M;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B07H@96QM^FQT(#8@\W)A(&UA>&EM
MX6QI<R!H]6WI<G/I:VQE=&4Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(D%Z
M(/9S<WIE9_5O;&1A;"!B;&]K:VIA:6YA:R!M87AI;>%L:7,@<WKA;6$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`R(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M(&QE
M;F=T:"(*;7-G<W1R(")-87AI;>%L:7,@:&]S<WHB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(FWA:G5S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R
M(")/<G9O<W1U9&]MX6YY(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")486=O:R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB
M"FUS9W-T<B`B02!M96[\(&UE9VIE;&5NZ7-E.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE
M<F=E(&-E;&QS(@IM<V=S='(@(D-E;&SA:R!E9WEB96]L=F%S>G3A<V$B"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-
M97-S86=E(@IM<V=S='(@(MQZ96YE="(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB02!D:6=I=.%L:7-A;B!A
M;.'M<G0@_'IE;F5T(&AI=&5L97,L(&1E(&%Z(&%LX>UR\R!T86[Z<^UT=N%N
M>>%T(&YE;2!S:6ME<OQL="`B"B)E;&QE;O5R:7IN:2XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R("),96KA<G0@87H@_'IE;F5T(.ER=NEN>65S<^EG
M92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R
M(")!>B#\>F5N970@=.UP=7-A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(DUE=&%R(&ED]6KA<N%S
M:F5L96YTZ7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!($UE=&%R(&)L
M;VMK(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HB02!-971A<B!B;&]K:R!N96T@X6QL(')E;F1E
M;&ME>NES<F4N($$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%MX7)A
M("(*(FOI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")!($UE=&%R1$(@;F5M(.ER:&5T]2!E
M;"XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-R!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM
M<V=S='(@(DWS9'-Z97(B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z
M.#$@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")!
M*'HI(%PB)7-<(B!M\V1S>F5R(&1E9FEN:>%L871L86XB"@HC.B!L:6(O2&]R
M9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B02!M
M\V1S>F5R(&1E9FEN:>%L871L86XN($$@;65G:.UV;W1T(&WS9'-Z97(Z("5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#(*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-971R:6MU
M<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE>&EK\R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O
M;NEZ:6%I(%-Z]G9E='/I9VD@P6QL86UO:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(FOV>NEP(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B34E-12!T[7!U
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B07H@96QM^FQT(#(T(/-R82!L
M96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")!>B!E;&WZ;'0@-B#S<F$@;&5G86QA8W-O;GEA8F(@:/5MZ7)S
MZ6ML971E.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,SD*;7-G
M:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B
M"FUS9W-T<B`B3>EG(&YE;2!T96QT(&5L(&$@;6EN:6WA;&ES(&ED]2!A(&IE
M;'-Z\R!M96=VX6QT;WIT873A<^%H;WHB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B
M5/QK<O9ZZ7,@*&IO8F(O8F%L*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")696=Y97,B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B2&GA;GEZ:6L@82!(5%107U)E<75E<W0@
M4$5!4B!C<V]M86<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM
M<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P
M;&EC871I;VXN(@IM<V=S='(@(B(*(DMO;F9I9W5RX6-I\R!S>OQK<^EG97,N
M($5Z="!M;W-T(&ME;&P@;.ET<F5H;WIN:6$L(&AA(&AA<WINX6QN:2!A:V%R
M:F$@87H@(@HB86QK86QM87KA<W0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`B2&GA;GEZ:6L@87H@_'IE;F5T(&%Z;VYO<^UT\VIA+B(*"B,Z
M(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@
M(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@
M(DAIX6YY>FEK(&$@36%I;"!014%2(&-S;VUA9RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S
M:6]N($E$+B(*;7-G<W1R(")(:>%N>7II:R!A(&9E;&AA<WINX6SS:V%P8W-O
M;&%T(&%Z;VYO<^UT\VIA("AS97-S:6]N($E$*2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G
M<W1R(")(Z2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I
M9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B3&5V96QE>NES(&UO8FEL=&5L969O
M;G+S;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")+]GIE<&5S(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B02!M\V1O
M<^UTX7,@9.%T=6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S
M='(@(D%Z(%523"!M\V1O<^UTX7-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QU<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&]V
M86D@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA
M8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F?S;&EA(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#@*;7-G:60@(DUO;G1H(&%N9"!Y96%R
M(@IM<V=S='(@(DCS;F%P(.ES(.EV(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")H879O;G1A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G
M:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DAO;&1FX7II<V]K(@H*(SH@;&EB
M+T9I;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O0U-6+G!H<#HR.#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B02`E9"X@<V]R8F%N('3V
M8F(@;65Z]2!V;VQT+"!M:6YT(&$@=N%R="`E9"XB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C
M8V\B"FUS9W-T<B`B36%R;VMK\R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T
M<B`B5/9B8FYY:7)E(&1E<OQL="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S
M='(@(E3V8F)N>6ER92!B;W)U;'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S
M='(@(E3V8F)N>6ER92!N87!O<R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B
M=FEG>?QK(&QE(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")V:6=Y_&L@8F%L
M<F$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U
M-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")V:6=Y_&L@:F]B8G)A(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G
M:60@(DUO=F4@57`B"FUS9W-T<B`B=FEG>?QK(&;V;"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R(")V:6=Y_&L@;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(U(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B=FEG>?QK(&;V
M;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I:R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E;"!D
M<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B5/9B8G-Z:6YT^R!L96?V<F3\;/4@
M;&ES=.%K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P-3@*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA
M<"!.86=Y+4)R:71A;FYI82!TZ7)KZ7`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E3V
M8F)S>O9R]G,@=N%L87-Z=.%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")"96IE;&5N=&ME
M>NES:2!B9>%L;.UTX7-O:R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR
M.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")"96IE
M;&5N=&ME>NES:2!A9&%T86EM(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HT-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(E-A:N%T(/9S<WIE
M9WKU(&]L9&%L86TB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#,*
M;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B4V%JX70@]G-S>F5G
M>O4@;VQD86QA;2!T97)V97KI<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`B36EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T
M<B`B3D5-+"!N96T@96=Y97IE;2!B96QE+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G
M:60@(DYA;64B"FUS9W-T<B`B3NEV(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S
M='(@(DYA;>UB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").97!A;"(*;7-G<W1R(").97#A;"(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R
M;&%N9',B"FUS9W-T<B`B2&]L;&%N9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S
M($%N=&EL;&5S(@IM<V=S='(@(DAO;&QA;F0@06YT:6QLX6LB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@8N%Z:7,M55),(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E('1A;OIS[71VX6YY:VEA
M9.%S:6IO9RA#02DM=FES<WIA=F]NX7-I(%523"(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(DYE='-C87!E('1A;OIS[71VX6YY9F5L:&%S>F[A;.%S
M:2!I<N%N>65L=B!54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@=&%N^G/M=';A;GEM96?Z:NUTX7-I(%523"(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T
M:6]N(%523"(*;7-G<W1R(").971S8V%P92!T86[Z<^UT=N%N>79I<W-Z879O
M;N%S:2!54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM
M<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C
M87!E(%-33"!S>F5R=F5R;NEV(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B
M"FUS9W-T<B`B3F5T<V-A<&4@=&%N^G/M=';A;GD@;65G:F5G>7KI<R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(DYE='-C87!E('1A;OIS[71V
MX6YY=.UP=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS
M9VED(").971W;W)K(@IM<V=S='(@(DCA;/-Z870B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G
M<W1R(")S;VAA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(MIJ
M+4MA;&5D\VYI82(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`BVFH@:V%T
M96?S<FEA(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z
M.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@
M(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(MIJ(&QE=NEL("5S(&/M;7)E
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H
M<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*
M;7-G<W1R("+Z:FAO;&0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G
M<W1R("+::B!F96QH87-Z;N%L\V[I=B`H;W!C:6]NX6QI<RDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(DYE=R!:96%L86YD(@IM<V=S='(@(MIJ+5KI;&%N9"(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM
M<V=S='(@(MIJ(&IE;'-Z\R(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z
M,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X
M<&ER92!O;B`E>"XB"FUS9W-T<B`B07H@^FH@:F5L<WKS(.ER=NEN>65S<^EG
M92!E:VMO<B!JX7(@;&4Z("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB
M"FUS9W-T<B`B02!M96=A9&]T="#Z:B!J96QS>F%V86L@;F5M(&5G>65Z;F5K
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`BVFH@86)L
M86L@*/QR97,I(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B2.UR96LB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S
M='(@(DCM<F-S;W!O<G1O:R(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(DOV=F5T:V5Z]2(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*
M;7-G<W1R(")+]G9E=&ME>O4@-"!FX7II<R(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,S8V(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<P"FUS9VED
M(").97AT(&]P=&EO;G,B"FUS9W-T<B`B2_9V971K97KU(&]P8VGS:R(*"B,Z
M(&QI8B](;W)D92]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G
M<W1R(")+]G9E=&ME>O4^(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B
M3FEC87)A9W5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6?I<FEA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B
MZ6IS>F%K82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B
M"FUS9W-T<B`B3F5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N
M:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"B).:6YC<R!R
M96YD96QK97KI<W)E(.%L;/,@:V]N9FEG=7+A8VGS+"!A;6EH97H@:^EP97-T
M(&$@:_QL]FYB<^EG96ME="!M96<@(@HB;&5H971N92!M=71A=&YI+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(DYI
M;F-S(&QE:&5T]7/I9R!)4T\@X6QL;VWA;GEO:R!LZ71R96AO>N%SX7)A+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED
M(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B2&GA;GEZ:6L@82!K]G1E
M9V5L="!F96QD;VQG;WKA<VAO>B!S>OQK<^EG97,@;6EN=&$@*&)A=&-H('1E
M;7!L871E*2XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$P,0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C,X-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P
M-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VXB"FUS9W-T<B`B02!K[7;A;G0@:&5L>65N(&YI;F-S(&)L;VMK(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(D%Z($U#04P@9F5L:&%S>F[A;/-A>F]N;W/M=.%S:&]Z(&YI;F-S
M(&UE9V%D=F$@82!N87!TX7(@;F5V92XB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(").:6YC<R!VX6QT
M;WKA<RXB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B16AH97H@82!J;V=O<W5L='/A9VAO>B!N96T@:&]Z:&%T\R!L
MZ71R92!J;V=O<W5L='/A9VD@86QC<V]P;W)T+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,38Y(&QI8B](;W)D92YP:'`Z-3`X(&QI8B](;W)D92]5=&EL+G!H<#HW
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")(:>%N>6]Z;F%K
M(&$@:V]N9FEG=7+A8VGS<R!A9&%T;VL@)7,M:&5Z+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HX-34*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(")!>B!&5%`@5D93
M(&YI;F-S(&MO;F9I9W5RX6QV82XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-C<R
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B07H@4U%,(%9&4R!N:6YC<R!K;VYF
M:6=U<N%L=F$N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+B(*;7-G<W1R(")!>B!344PM1FEL92!61E,@;FEN8W,@
M:V]N9FEG=7+A;'9A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B07H@
MUFX@<WKA;6SA:N%N(&5L9F]G>6]T="!A(')E;F1E;&ME>NES<F4@X6QL\R#V
M<W-Z96<N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DYI
M;F-S(&/M;7KI<RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(P"FUS
M9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(D$@<WIE<G9E<G)E(&YE
M;2!T]FQT]63V='0@9F5L('-E;6UI;'EE;B#A;&QO;>%N>2(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM
M<V=S='(@(D%Z(&EK;VYO:R!N96T@=&%LX6QH873S:RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,`IM<V=I9"`B3F\@;&]C
M871I;VX@:7,@<V5T+B(*;7-G<W1R(").:6YC<R!M96=A9'9A(&$@:&5L>2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3FEN8W,@;65G861V82!A
M(&AE;'DN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B07H@_'IE
M;F5T(/QR97,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYI;F-S
M(&UE9V%D=F$@82!NZ78N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T
M<B`B3FEN8W,@;65G861V82!A('-ZX6TN(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T
M<B`B3F4@;&5G>65N(&UE9V)O='+A;FMO>G1A=/,@:63I>F5T(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").:6YC
M<R!J96QS>O,@;65G861V82!A($A45%`@86QA</H@9F5L:&%S>F[A;/-I(&%Z
M;VYO<^UTX7-H;WHN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L<WKS(&UE9V%D=F$@87H@24U!
M4"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BXB"@HC.B!L:6(O
M2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M:6YC<R!J96QS>O,@;65G861V82!A($ME<F)E<F]S(&%L87#Z(&9E;&AA<WIN
MX6SS:2!A>F]N;W/M=.%S:&]Z+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN
M<&AP.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC.B!L:6(O2&]R
M9&4O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI;F-S(&IE
M;'-Z\R!M96=A9'9A(&$@3&]G:6X@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO
M<^UTX7-H;WHN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DYI;F-S(&IE;'-Z\R!M96=A9'9A(&$@4$%3
M4U=$(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI;F-S
M(&IE;'-Z\R!M96=A9'9A(&%Z(%--0B!A;&%P^B!F96QH87-Z;N%L\VD@87IO
M;F]S[73A<VAO>BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R
M.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(DYI;F-S(&UE
M9V%D=F$@87H@3W!E;E-33"!P<F]G<F%M(&5LZ7+I<VD@^G1V;VYA;&$N($%Z
M($]P96Y34TP@<')O9W)A;2`B"B)S>OQK<^EG97,@82!02T-3(#$R(&%D871O
M:R!K97IE;.ESZ6AE>BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@
M(DYI;F-S(/IJ(&)E:F5L96YT:V5ZZ7-I(&EGZ6YY+B(*"B,Z(&QI8B]61E,N
M<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(").:6YC<R!K
M=O-T82!B9>%L;.UT=F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T
M<B`B3F4@;&5G>65N96L@=F]N86QA:R!S96AO;"XB"@HC.B!L:6(O1FEL92]#
M4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS
M9W-T<B`B3FEN8W,@9&5F:6YIX6QV82!E;';A;&%S>G3S(&MA<F%K=&5R+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DYE(&QE9WEE;B!K97)E
M="(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R(").:6YC<R!I;'EE;B!FX6IL(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C
M=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(").:6YC<R!I9&5I
M9VQE;F5S(.%L;&]MX6YY;VL@=.%R;VSA<^%R82!S>F]L9^%L\R!A;&OV;GEV
M=.%R+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DAIX6YY>FEK(&$@
M9F5L:&%S>F[A;/-NZ78@Z7,O=F%G>2!A(&IE;'-Z\RXB"@HC.B!L:6(O2&]R
M9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T
M82!R971U<FYE9"(*;7-G<W1R(")!('9I<W-Z86MA<&]T="!A9&%T;VL@;F5M
M(.ER=NEN>65S(%A-3"!A9&%T;VLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3<T(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HY.#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDY-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(DYI;F-S(&%D870B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3FEN8W,@;>EG(&MO;F9I9W5RX6-I
M\RP@9V5N97+A;&IO;B!E9WEE="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").
M:6YC<R!MZ6<@:V]N9FEG=7+A8VGS:F$L(&=E;F5RX6QJ;VX@96=Y970N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G
M<W1R(")N:6YC<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T
M<B`B;FEN8W,@;65G861V82`H;&5G>65N(&%L87#I<G1E;&UE>F5T="DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M
M.#@U.2TQ,"DB"FUS9W-T<B`B;F]R9&EK=7,@*$E33RTX.#4Y+3$P*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L:RUS>FEG970B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(LES>F%K
M:2!FZ6QT96ME(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B
M"FUS9W-T<B`BR7-Z86MI+4UA<FEA;F$M<WII9V5T96LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO
M<G=A>2(*;7-G<W1R(").;W)VZ6=I82(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B3F5M(&OI
M<_5B8B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@0F5F;W)E(@IM<V=S='(@(DYE;2!K;W+A8F)A;B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B3F5M(&%L:_9N>79TX7(B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z
M-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX
M-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.CDU"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B02!P<F]G
M<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A;/-S[71V82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS
M9VED(").;W0@<V5T(@IM<V=S='(@(DYI;F-S(&)EX6QL[71V82(*"B,Z(&QI
M8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,#@@;&EB+U9&4RYP:'`Z,C,T
M(&QI8B]61E,N<&AP.C(U,@HC.B!L:6(O5D93+G!H<#HR-CD@;&EB+U9&4RYP
M:'`Z,C@U(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93+G!H<#HS,38*(SH@;&EB
M+U9&4RYP:'`Z,S,S(&QI8B]61E,N<&AP.C,V-B!L:6(O5D93+G!H<#HT,C8@
M;&EB+U9&4RYP:'`Z-3`U"B,Z(&QI8B]61E,N<&AP.C4W-"!L:6(O5D93+G!H
M<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y"B,Z(&QI8B](;W)D92]397-S:6]N2&%N
M9&QE<BYP:'`Z,30U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,38P
M"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<U(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M(").96T@=.%M;V=A=&]T="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U.`HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G
M<W1R(")&96QJ96=Y>NES96LB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E
M>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*
M;7-G<W1R(").:6YC<R!B]FYGZ7-Z:&5T]2!A9&%T+"!TZ7)J96X@=FES<WIA
M+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").
M;W9E;6)E<B(*;7-G<W1R(")N;W9E;6)E<B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B4WKA;2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#(Y"FUS9VED(").=6UB97(@;V8@8VAA<F%C
M=&5R<R(*;7-G<W1R(")+87)A:W1E<F5K('-ZX6UA(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM
M<V=S='(@(D]S>FQO<&]K('-ZX6UA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(E-O<F]K
M('-ZX6UA(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B02!K]G)L97;I;&QI<W1A
M(&WS9&]S[73A<^%H;WH@;F5M(&%D;W1T(&UE9R!S>N%M;VMA="XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@
M(D]+(@IM<V=S='(@(D]+(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K='5M
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B
M:F5C="!#<F5A=&]R(@IM<V=S='(@(D%Z(&]B:F5K='5M(&SI=')E:&]Z\VIA
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM
M<V=S='(@(D]K=.%L:7,@<WKA;2(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(F]K=/-B97(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL
M=&5R(@IM<V=S='(@(E-Z^W+I<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")(:79A=&%L+VUU;FMA
M:&5L>2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I
M9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*
M;7-G<W1R(")!('+I9VD@Z7,@87H@^FH@:F5L<WKS;F%K(&O\;/9N8O9Z;FEE
M(&ME;&PN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS
M9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B02!RZ6=I(&IE;'-Z\R(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")!('+I9VD@:F5L<WKS
M(&YE;2!M96=F96QE;/4N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]MX6XB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@
M(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM
M<V=S='(@(D-S86L@87H@24U!4"!S>F5R=F5R96L@=.%M;V=A=&KA:R!A(&UA
M<'#A:R!M96=O<WITX7/A="XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(D-S
M86L@;65G8F]T<N%N:V]Z=&%T\R!I9.EZ970@;&5G>65N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S4*;7-G
M:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B
M0W-A:R!E9WD@96UA:6P@8^UM(&%D:&%T\R!M96<N(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B
M"B)#<V%K(&$@='5L86ID;VYO<R!V86=Y(&$@<F5N9'-Z97)G87ID82!VX6QT
M;WIT871H871J82!M96<@96=Y(&OV>O9S("(*(G3A<G1E<OQL970@='5L86ID
M;VYO<^%T('9A9WD@96SI<NES:2!J;V=O<W5L='/A9V%I="(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C0P"FUS
M9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(").>6ES<W5K(&UE
M9R#Z:B!A8FQA:V)A;B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D
M871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N
M4U-,(&AI8F$Z($YE;2!S:6ME<OQL="!K:6YY97)N:2!A>B!A9&%T;VMA="!A
M>B!A;.'M<G0@4R]-24U%('+I<WIB]6PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3GEI<W-U:R!M
M96<@97IT(&$@8^UM970@96=Y(/IJ(&%B;&%K8F%N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S
M='(@(D]P97+A8VGS<R!R96YD<WIE<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!C:?-K
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S
M(@IM<V=S='(@(B5S(&)EX6QL[73A<V%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T
M(@IM<V=S='(@(E-O<G-ZX6UO<R!F96QS;W)O;.%S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G
M<W1R(")3>F5R=F5Z970B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")3>F5R
M=F5Z971I(&5G>7/I9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B375N:V%S>F5R=F5ZZ7,B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B07H@86QK86QM87KA<R!E
M<F5D971I('-A8FQO;FIA(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.B(*;7-G<W1R("(E<R!E<F5D971I('-A8FQO;FIA:3HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT
M"FUS9VED(")/=&AE<B(*;7-G<W1R(")%9WGI8B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(D5G>>EB(&EN9F]R;>%C:?,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")!
M('1U;&%J9&]N;W,@:F]G;W-U;'1SX6=A:2(*"B,Z(&QI8B](;W)D92]!=71H
M+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")!(%!!32!F96QH87-Z;N%L\V%Z;VYO<^UT
MX7,@;F5M(.%L;"!R96YD96QK97KI<W)E+B(*"B,Z(&QI8B].970O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B
M"FUS9W-T<B`B4$5!4CHZ36%I;"!A;')E;F1S>F5R(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T
M=7)E(@IM<V=S='(@(E!'4"!D:6=I=.%L:7,@86SA[7+A<R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")01U`M=F5L('1I=&MO<^UT;W1T(&%D870B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC
M($ME>2(*;7-G<W1R(")01U`@;GEI;';A;F]S(&MU;&-S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R
M>7!T960@1&%T82(*;7-G<W1R(")01U`M=F5L(&%LX>UR="]T:71K;W/M=&]T
M="!A9&%T(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R(")02%`@:_-D(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B1.EL=73A;B]E<W1E(&=Y96YG92!E<_4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B
M4$T@4F%I;B(*;7-G<W1R(")$Z6QU=.%N(&5S]2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3:&]W97)S
M(@IM<V=S='(@(D3I;'5TX6XO97-T92!ZX7!O<F]K(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<B
M"FUS9W-T<B`B1.EL=73A;B]E<W1E(&AA=F%ZX7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(D3I;'5TX6XO97-T92!H\WKA<&]R;VLB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B
M4$T@4W5N(@IM<V=S='(@(D3I;'5TX6X@;F%P<_QTZ7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B1.EL=73A;B]E<W1E('II=F%T87)O:R(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO
M;B!I<R!M:7-S:6YG(@IM<V=S='(@(DAIX6YY>FEK(&$@4$]325@@8O5V[73I
M<R(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(F)E;'/U(&UA
M<F?S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<WITX6XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S
M=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-Z=&EN
M(%1E<OQL970@*&UE9W-ZX6QL="DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R
M(")086YA;6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B
M4.%P=6$@VFHM1W5I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B
M4&%R86=U87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")-Z7)SZ6ME
M;'1E;B!B;W)U;'0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3@P(&QI8B](;W)D92]&;W)M+G!H<#HR,#(R"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C$U,2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B2F5L
M<WKS(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED
M(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B02!J
M96QS>O-T('-I:V5R97-E;B!M96=VX6QT;WIT871T=6LN(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O
M<G)E8W0B"FUS9W-T<B`B3F5M(&UE9V9E;&5L]2!J96QS>O,B"@HC.B!L:6(O
M2&]R9&4O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B02!2
M041)55,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S:&]Z(&IE;'-Z\R!S>OQK<^EG
M97,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3<*;7-G:60@(E!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DIE;'-Z\R!M96=E<O5S
M[73I<W-E;"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM
M<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DIE;'-Z\SHB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G
M<W1R(")*96QS>O,Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T
M<B`B02!J96QS>F%V86MN86L@96=Y97IN:?QK(&ME;&PN(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(D)E
M:6QL97-Z=.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`B0F5I;&QE<WITX7,@82!VX6?S87-Z=&%L<O-L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*
M;7-G<W1R("+:='9O;F%L(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`BVFH@9F5L
M:&%S>F[A;/-N86L@8F5J96QE;G1K97IE='1E:SHB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")%;6)E<F5K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B<WKA>F%LZ6LB"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(DMA<F)A
M;G1A<G3A<VD@9F5L861A=&]K(';I9W)E:&%J=.%S82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B0F5J96QE;G1K97KI<VMO
M<B!H86IT<W5K(';I9W)E(&$@:V%R8F%N=&%R=.%S:2!F96QA9&%T;VMA=#\B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES
M<VEO;B(*;7-G<W1R(")*;V=O<W5L='/A9R(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<
M(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&IO9V]S
M=6QT<^%G;W0@;F5M('3V<O9L=/QK+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU
M.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(M9N;F5K(&YI
M;F-S(&5H:&5Z(&5L96=E;F3U(&IO9V]S=6QT<^%G82(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T
M"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")*;V=O<W5L='/A9V]K(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B2F]G;W-U;'1SX6<@861M:6YI<WIT<N%C:?,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E-Z96WI;'EE<R!A9&%T;VLB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("+!;&QA=&ME9'9E;F-E:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1OQL]G`M<WII9V5T96LB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&Z6YY:^EP
M9V%LZ7)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")P:7AE;"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")+
M]GIH96QY96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE
M(&-E;&PB"FUS9W-T<B`B2V%T=&EN='-O;B!V86QA;65L>6EK(&-E;&SA<F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B0FEZ=&]S86X@=/9R
M]FQN:2!A:V%R:F$@97IT(&%Z(&5L96UE=#HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE
M;65N="XB"FUS9W-T<B`B2^ER96T@97+U<^UT<V4@;65G+"!H;V=Y('9A;/-B
M86X@=/9R]FQN:2!K[7;A;FIA(&5Z="!A>B!E;&5M970N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U-C8*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H
M(&%N9"!A('EE87(N(@IM<V=S='(@(DOI<F5M(&%D:F]N(&UE9R!E9WD@:/-N
M87!O="#I<R!E9WD@Z79E="XB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B2^ER96T@861J82!M
M96<@87H@^FH@:V%T96?S<FEA(&YE=NET.B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S`U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+B(*;7-G<W1R(")+Z7)E;2!V86SS<R!)4"!C[6UE="!A9&IO;B!M96<N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#0*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I
M;B!T:&4@;6]N=&@N(@IM<V=S='(@(DOI<F5M('9A;/-S(&3A='5M;W0@861J
M;VX@;65G+"!E;&QE;O5R:7IZ92!A(&CS;F%P(&YA<&IA:70N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED('1I;64N(@IM<V=S='(@(DOI<F5M('9A;/-S(&3A='5M;W0@861J;VX@
M;65G+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G
M:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB
M"FUS9W-T<B`B2^ER96T@<O9V:61E;B#M<FIA(&QE(&$@<')O8FSI;6$@;.EN
M>65GZ70N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")+Z7)E;2!A
M9&IA(&UE9R!A(&)E:F5L96YT:V5ZZ7-I(&YE=NET(.ES(&IE;'-Z87;A="(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@HB2^ER96T@;VQV87-S82!E;"!A(&OV=F5T:V5Z]2!S>O9V96=E="X@02!R
M96YD<WIE<B!H87-Z;N%L873A;F%K(&9E;'3I=&5L96ET("(*(F5L($M%3$P@
M9F]G861N:6$N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`B2^ER96T@861J82!M96<@87H@^FH@:V%T96?S<FEA
M(&YE=NET.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(DQE;F=Y96QO<G-Z
MX6<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET
M:6-S(@IM<V=S='(@(E!O;&ET:6MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B4WIA=F%ZX7-O:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9^%L:6$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B02!KZ7`@96QH96QY97KI<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L92(*;7-G<W1R(")!('3A8FSA>F%T(&5L:&5L>65ZZ7-E(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*(DOV
M>G9E=&QE;B!L97;I;&O\;&3I<R!E8F)E(&$@;6%P<.%B82`H24U!4"!N96T@
M;6EN9&EG('9E<WII(&9I9WEE;&5M8F4I(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B
M"FUS9W-T<B`B07H@96QM^FQT("5S(/-R82!C<V%P863I:VUE;FYY:7/I9V4Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@
M(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B0W-A<&%DZ6L\
M8G(@+SYV86SS<WKM;OMSZ6<B"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP
M:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@;F5M('1A;.%L
M:&%T\R!A('-Z_&MSZ6=E<R!,1$%0(&MI=&5R:F5S>G3I<RXB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I
M;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4')E9G-?<V5S<VEO;CH@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E
M<R`H<V5S<VEO;BD@:VET97)J97-Z=.ES+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("),Z6=N>6]MX7,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@
M870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B02!T96YG97)S>FEN=&YE:R!M96=F
M96QE;/4@;.EG;GEO;>%S.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(DSI9VYY;VWA
M<SH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B16SU>F5T97,@
M;65G=&5K:6YTZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!(&OI<"!E;/5Z971E<R!M
M96=T96MI;G3I<V4@^FH@86)L86MB86XB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B
M4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")%;/5Z]2!O<&-I\VLB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED
M(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")!(&1O:W5M96YT=6T@:VEN>6]M
M=&%TX7-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED
M(")0<FEV871E($ME>2(*;7-G<W1R(")4:71K;W,@:W5L8W,B"@HC.B!L:6(O
M2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(DAI
M8F%B96IE;&5N=.ES(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS
M9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(D$@:&EB82!L9>UR
MX7-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B
M4')O:F5C=',B"FUS9W-T<B`B4')O:F5K="!K97IE;.ES(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Q,34@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3(@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,R.#`*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S
M='(@(D$@<')O;7!T('-Z]G9E9V4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B3GEI;';A;F]S
M(&MU;&-S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(DYY:6QVX6YO<R!K
M=6QC<_H@86QG;W)I=&UU<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B3GEI;';A
M;F]S(&MU;&-S(&EN9F]R;>%C:?,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E
M;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D$@;GEI;';A;F]S+W1I
M=&MO<R!K=6QC<W#A<G0@;F5M('-I:V5R_&QT(&SI=')E:&]Z;FDN(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I8V\B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(D$@;&5V96QE:R!VZ6=L96=E<R!T]G)LZ7-E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(DME<F5S]2]P
M87)A;F-S('-T<FEN9R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM
M<V=I9"`B475O=&$B"FUS9W-T<B`B2W;S=&$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B
M;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")24T$@;GEI;';A;F]S(&MU;&-S
M("@E9"!B:71E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V.`IM<V=I
M9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E+A9&GS9V]M8F]S(&MI=N%L
M87-Z=.%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#0*;7-G:60@(E)A:6XB"FUS9W-T<B`B17/U(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@16%R
M;'DB"FUS9W-T<B`B17/U(&3I;&5L]71T(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@3&%T92(*;7-G
M<W1R(")%<_4@9.EL=73A;B]E<W1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S
M='(@(EKA<&]R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#@*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B17/U(.ES
M(&AA=F%ZX7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT.0IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(DAA=F%S97/U
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&
M;W)T=6YE(@IM<V=S='(@(E;I;&5T;&5N(&EDZ7IE="(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")!<N%N>2(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(D]L=F%SX7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-#<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS
M9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DQE=F5L96L@;VQV87/A<V$B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB5.EN>6QE9R!T]G+V
M;&K\:R`E<R!F96QH87-Z;N%L\W0_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O
M<F3M=&AA=/,@=FES<WIA+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@
M=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)4Z6YY;&5G('3V<O9L:OQK("5S(&9E
M;&AA<WINX6SS(&%D871A:70_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O<F3M
M=&AA=/,@(@HB=FES<WIA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(MIJ<F$@=NEG<F5H86IT:F$@87H@=71O;'/S(';A;'1O
M>G1A=.%S="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(D9R
M:7-S[73I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@
M(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")!(&UE
M;OP@9&EN86UI:W5S(&5L96UE:6YE:R!F<FES<^UTZ7-I(&=Y86MO<FESX6=A
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E
M<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D%Z(/9S<WIE9WKU;VQD86P@9G)I
M<W/M=.ESZ6YE:R!G>6%K;W)I<^%G83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(S-0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B
M"FUS9W-T<B`B3V)J96MT=6T@8O9N9^ES>O4B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B1G)I<W/M=.ES(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B
M365G:F5G>7KI<V5K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM
M<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B5.%V;VQI('-Z97)V97)E
M:R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(D$@=.%V;VQI(%523"`H<&PN(&AT='`Z+R]W=W<N=F%L86UI+FAU
M+VUE9W9A;&%M:2DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS
M9VED(")296UO=F4B"FUS9W-T<B`B5/9R;.ES(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T
M<B`B0FQO:VL@=/9R;.ES92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B
M3W-Z;&]P('3V<FSI<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G
M<W1R(")!(&9O<FUA='3A;.%S('3V<FSI<V4B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B
M02!PX7(@=/9R;.ES92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*
M;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)4]G+V;&K\:R!A>B!E;&UE
M;G1E='0@<')O9W)A;6]T(&$@<WIE<G9E<B!I9&5I9VQE;F5S(.%L;&]MX6YY
M;VMA="!T87)T86QM87KS("(*(F%L:_9N>79TX7+A8O-L+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM
M<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")696=Y_&L@:VD@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P
M"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM
M<V=S='(@(E9E9WG\:R!K:2!E>G0@82!RZ7-Z="!A(&1O:W5M96YT=6UB\VPB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED
M(")296UO=F4@=7-E<B(*;7-G<W1R(")!(&9E;&AA<WINX6SS('3V<FSI<V4B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(B5S(&9E
M;&AA<WINX6SS('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP
M:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(")!(&OI<NES(&YE;2!T96QJ
M97/M=&AE=/4N($$@:V%P;W1T(&AI8F%K\V0Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B02!K97)E<V5T="!S>F]L
M9^%L=&%TX7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$W
M-B!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")!(&OV=&5L97KU96X@;65G861A;F3S(%PB)7-<(B!N96T@
M<WIE<F5P96P@)7,@:V]N9FEG=7+A8VGS:N%B86XN(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C8W."!L:6(O5D93+V9T<"YP:'`Z.#8Q(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B02!K]G1E;&5Z]65N(&UE9V%D86YD\R!<(B5S7"(@;F5M('-Z97)E<&5L
M(&$@5D93(&MO;F9I9W5RX6-I\VKA8F%N+B(*"B,Z(&QI8B](;W)D92]5=&EL
M+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B02!K
M]G1E;&5Z]65N(&UE9V%D86YD\R!<(B5S7"(@;F5M('-Z97)E<&5L(&$@:V]N
M9FEG=7+A8VGS8F%N+B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H
M<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(E-Z_&MSZ6=E
M<R!M97KU(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,T,R!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")297-E="(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E
M="!087-S=V]R9"(*;7-G<W1R(")!(&IE;'-Z\R#A=.%L;.UTX7-A(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B07H@UFX@:F5L<WIA=N%N86L@X73A;&SM
M=.%S82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O
M<F4@3&%S="!1=65R>2(*;7-G<W1R(")!>B!U=&]L<_,@:V5R97/I<R!V:7-S
M>F'A;&SM=.%S82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")2
M97-U;'1S(@IM<V=S='(@(D5R961MZ6YY(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS
M9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")6:7-S>F$@87H@;W!C
M:?-K:&]Z(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS
M9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(D%Z(/IJ(&IE;'-Z
M\W0@[7)J82!B92!I<VWI="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B
M4NEU;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I
M;VXB"FUS9W-T<B`BP6QL[71S=6L@=FES<WIA(&$@:V]N9FEG=7+A8VGS="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X
M="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")2:6-H(%1E>'0@161I=&]R(&]P
M8VGS:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED
M9&QE<R(*;7-G<W1R(")486SA;/-S(&OI<F3I<V5K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2
M:6=H="(*;7-G<W1R(")J;V)B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,#<*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")*;V)B(&]L9&%L:2!F
M96ILZ6,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,PIM<V=I9"`B4FEG
M:'0@=F%L=65S(@IM<V=S='(@(DIO8F(@;VQD86QI(.ER=.EK96LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")3;W(@='5L
M86ID;VYSX6=O:RXN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E-Z97)E<"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]MX6YI82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B
M"FUS9W-T<B`B1F]R9V%TX7,@,3@P(&9O:VMA;"(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T
M(@IM<V=S='(@(D)A;')A(&9O<F=A=.%S(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM
M<V=S='(@(DIO8F)R82!F;W)G873A<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P
M97)T:65S(@IM<V=S='(@(E-O<B!T=6QA:F1O;G/A9V]K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I
M9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4V]R('1U;&%J9&]N<^%G;VLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B4V]R;VLZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B
M4G5L97,B"FUS9W-T<B`B5F]N86QA:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T
M<B`B36EN9&5N('-O<B#I<R!O<WIL;W`@:_9Z]G1T(&QE9WEE;B!V;VYA;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(D-S86L@87H@;W-Z;&]P;VL@:_9Z]G1T(&QE9WEE
M;B!V;VYA;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY(@IM<V=S='(@(D-S86L@82!S;W)O:R!K]GKV='0@;&5G
M>65N('9O;F%L(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B
M4G5N(@IM<V=S='(@(D9U='1A=.%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E
M<F%T:6]N(@IM<V=S='(@(D]R;W-Z($;V9&5RX6-I\R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W
M86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E(@IM<V=S='(@(E,O34E-12!D:6=I=.%L:7,@86SA[7+A<R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%('-Z86)VX6YY('-Z97)I
M;G0@=&ET:V]S[71O='0@;&5VZ6PB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L
M+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")305-,(&9E;&AA<WINX6SS87IO;F]S[73A<R!N
M96T@=&%LX6QH873S+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3(&O\;&3I<R(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<X"FUS9VED(")3
M44P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-13"!P
M87)A;F-S(&$@:V5R97/I<VAE>B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@
M(E-50T-%4U,B"FUS9W-T<B`B4TE+15+<3%0B"@HC.B!L:6(O87!I+G!H<#HQ
M-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS
M9W-T<B`B4WIO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-Z
M96YT($EL;VYA+7-Z:6=E="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE
M=FES(@IM<V=S='(@(E-A:6YT($MI='1S(.ES($YE=FES(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED(")3
M86EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0@4&EE<G)E
M(.ES($UI<75E;&]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="#I<R!'<F5N861I
M;F4M<WII9V5T96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T
M<B`B56=Y86YA>B!A(&9R86UE("A?<V5L9BDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*
M;7-G<W1R(")3>F%M;V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@
M(E-A;B!-87)I;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B
M"FUS9W-T<B`B4V%O(%1O;>D@Z7,@4'+M;F-I<&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*
M;7-G<W1R(")-^VAO;&1A<R!I;G1E<FYE=&5LZ7+I<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A
M=61I($%R86)I82(*;7-G<W1R(")3>F'Z9"U!<N%B:6$B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M365N=.ES(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")<
M(B5S7"(@;65N=.ES92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B)7,@
M;65N=.ES92(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@
M(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")!(&)EX6QL[73A<V]K(&UE;G3I<V4B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(DUE;G1S_&L@96P@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0@4$A0
M('!R;V=R86T@9F]R;>%JX6)A;B!A('-Z97)V97(@(@HB:61E:6=L96YE<R#A
M;&QO;>%N>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%RX6)A;BXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!K;VYF:6=U
M<N%C:?-JX70@96QM96YT971T_&LN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B16QM96YT971T_&L@
M82!S971U<"!U<&=R861E('!R;V=R86UO="!I9&4Z(%PB)7-<(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B4WKS<G;A;GEO<R!Z:79A=&%R
M;VLB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N
M8V4B"FUS9W-T<B`B5'5D;VWA;GDB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DME<F5SZ7,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*
M;7-G<W1R(")+97)E<^ES:2!S>F]L9^%L=&%TX7-O:R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.34Y"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B
MP6QL;VWA;GEO:R!K:7;A;&%S>G3A<V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM
M<V=S='(@(E;A;&%S<WIO;B!K:2!E9WD@9.%T=6UO="(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T
M;R!A9&0B"FUS9W-T<B`B365L>6EK(&-S;W!O<G1O="!K[7;A;FIA(&AO>GKA
M861N:2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@
M(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A>B#Z
M:B!T=6QA:F1O;F]S="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E;A;&%S<WIO
M;B!S>F5R=F5R="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")-96QY:6L@
M9F5L:&%S>F[A;/-T(&OM=N%N:F$@:&]Z>N%A9&YI(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L
M;"(*;7-G<W1R(")-:6YD970@:VEJ96SV;&K\:R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-C0W"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RXB"FUS9W-T<B`B5N%L87-S>F$@:VD@87H@]G-S>F5S(&3A='5M]G-S>F5T
M97;U="XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E;A;&%S<WIO
M;B!E9WD@;V)J96MT=6UO="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(D5G
M>2!S92!L96=Y96X@:VEJ96SV;'9E(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B
M(@HB5N%L87-S>F$@:VD@82!K[7;A;G0@:V%R86MT97(H96ME*70@87H@86SA
M8F)I(&QE:&5T]7/I9V5K(&OV>OQL+B!%>G5TX6X@(@HB7")C;W!Y+W!A<W1E
M7"(@;?-D<WIE<G)E;"!A(&UE9V9E;&5L]2!H96QY<F4@;>%S;VQH871J82#U
M:V5T+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")6X6QA<W-Z82!K
M:2!A(&3A='5M96QVX6QA<WIT\R!K87)A:W1E<G0Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M
M870Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@9.%T=6T@9F]R;>%T=6WA=#HB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS
M9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB
M"FUS9W-T<B`B5N%L87-S>F$@:VDL(&UE;'EI:R!A>F]N;W/M=/-JX70@:^UV
MX6YJ82!M96=VX6QT;WIT871N:3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS
M9W-T<B`B5N%L87-S>F$@:VD@87H@:63U96QVX6QA<WIT\R!K87)A:W1E<G0Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C
M="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&%Z(&ED
M]2!F;W)MX71U;>%T.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R
M(")6X6QA<W-Z;VX@:VD@:^ET(&5G>6WA<VYA:R!M96=F96QE;/4@;65Z]70N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A(&OM
M=N%N="!S>NUN96=Y_'1T97-T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB
M"FUS9W-T<B`B5N%L87-S>F$@:VD@87H@UFYN96L@;65G9F5L96SU(&YY96QV
M970Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G
M:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B2&EB86IE;&5N=.ES
M(&O\;&3I<V4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4TU3(&O\;&3I<V4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-Z96YE9^%L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(E-Z96YZ;W(Z("(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B<WIE<'1E;6)E<B(*"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A
M;F0@36]N=&5N96=R;R(*;7-G<W1R(")3>F5R8FEA(.ES($UO;G1E;F5G<O,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R
M:6%L($YU;6)E<B(*;7-G<W1R(")3;W)O>F%T<WKA;2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D$@<WIE<G9E<G3U;"!K
M87!O='0@861A="!H:6+A<RP@=F%G>2!N96T@X6QL(')E;F1E;&ME>NES<F4N
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D
M;6EN(@IM<V=S='(@(D$@9F5L:&%S>F[A;/-K87!C<V]L871O:R!A9&UI;FES
M>G1RX6-I\VIA(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B3&5J
MX7)T(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S:F$@*'-E<W-I
M;VX@240I+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B
M"FUS9W-T<B`B1F5L:&%S>F[A;/-K87!C<V]L871O:R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S$X"FUS9VED(")3970B"FUS9W-T<B`B2&%L;6%Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N(@IM<V=S='(@(DQE:&5T]7/I9R!J96QS>F%VX6YA
M:R#A=.%L;.UTX7/A<F$L(&%B8F%N(&%Z(&5S971B96XL(&AA(&5L9F5L96IT
M96[I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B)4X79O;&D@<WIE<G9E<F5K
M(&5LZ7+I<V4@X6QL[71H873S(&)E+"!M96QY96ME="!A>B!I;F1U;/-O;&1A
M;.%N(&OM=N%N("(*(FUE9VIE;&5N[71E;FDN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(D$@:^UV
MX6YT(&YY96QV+"!I9/5Z\VYA(.ES(&3A='5M9F]R;>%T=6T@8F7A;&SM=.%S
M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB0F7A;&SM=&AA=/,L(&AO9WD@;65L>6EK(&%L:V%L;6%Z
MX7,@:F5L96YJ96X@;65G(&$@8F5J96QE;G1K97KI<R!U=.%N+"`B"B)M:6QY
M96X@<WKM;F5G>?QT=&5S="P@;VQD86QF<FES<^UTZ7-I(&=Y86MO<FESX6=O
M="!I;&PN(&5G>>EB(&)EX6QL[73A<V]K870@(@HB<WIE<F5T;F4N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T
M<B`B0F7A;&SM=.%S;VLB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L92(*;7-G<W1R(")!(&)EX6QL[73A<V]K870@;65G^FKM=/,@<')O9W)A
M;6]K(.%L;&YA:R!R96YD96QK97KI<W)E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S
M<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B02!M96=A9&]T
M="!P87)A;>ET97(@=/9B8B!H96QY970@:7,@:F5L96YT:&5T.B`B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL92US>FEG971E:R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P
M:6YG(@IM<V=S='(@(E;A<^%R;.%S(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B
M4O9V:60@]G-S>F5F;V=L86SA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")%;"!K[7;A;FIA(.ER;FD@87H@96=Y
M97,@9G5N:V-I\VMA="!!;'0M8FEL;&5N='G[+6MO;6)I;N%C:?-K:V%L(&ES
M/R(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3
M:&]W(@IM<V=S='(@(DUE9VIE;&5N[73I<R(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E
M;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB375T87-S=6L@;65G(&$@:_QL
M]FYB<^EG96ME="!A>B!E;&UE;G1E='0@Z7,@87H@^FIO;FYA;B!LZ71R96AO
M>F]T="`B"B)K;VYF:6=U<N%C:?,@:_9Z]G1T+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@HB36EN9&5N(&)E:F5L96YT:V5Z
MZ7-K;W(@[7+S9&KI:R!K:2!A(&MO<N%B8FD@=71O;'/S(&)E:F5L96YT:V5Z
MZ7,@:61E:F4_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-CD*;7-G:60@
M(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B5N%L87-Z
M=&AA=/,@;&5G>65N(&%Z(&5R961E=&D@;65G=&%R=.%S82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-SDY"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R
M("),96=Y96X@9.%T=6UVX6QA<WIT\R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\B"FUS9W-T<B`B3&5G>65N(&5G>2!TX6)LX7IA=&ME>F5L]2!M96[\<V]R
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T
M<B`B375T87-S=6L@82`E<R!M96[\="!A(&)A;"!O;&1A;&]N/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R(").Z7IZ_&L@;65G('3A8FSA>F%T(&-E;&SA:6YA:R!T=6QA
M:F1O;G/A9V%I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B3NEZ>OQK(&UE9R!TX6)LX7IA="!T
M=6QA:F1O;G/A9V%I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[I>GK\:R!M96<@=.%B
M;.%Z870@<V]R86EN86L@='5L86ID;VYSX6=A:70B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[I
M>GK\:R!M96<@82!KZ7`@='5L86ID;VYSX6=A:70B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3<V-PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B375T
M87-S=6L@82!F96QT]FQTZ7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B6N%P
M;W)O:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4R"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(EKA<&]R;VL@9.EL
M96SU='0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(EKA<&]R;VL@9.EL
M=73A;B]E<W1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S
M='(@(DAE;'EI('KA<&]R;VLB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(DMI8W-I
M;GGM=.ES(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HY,3`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY
M-S(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S="(*;7-G<W1R("(B"B)%;/5S>O9R(&MI8W-I;GGM=&5N:64@
M:V5L;"P@=F%G>2!E;"!K96QL(&UO>F3M=&%N:6$@82!H96QY970@96QF;V=L
M86SS("(*(F)L;VMK;VMA="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`BVFH@9F5L:&%S>F[A
M;/-K(&)E:F5L96YT:V5ZZ7-E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")$:6=I=.%L:7,@
M86SA[7+A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS
M9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D$@9&EG:73A;&ES
M(&%LX>URX7,@86QG;W)I=&UU<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS
M9W-T<B`B4WII;F=A</IR(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDP,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(U,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,CDQ-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P.0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HW,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M-`IM<V=I9"`B4VEZ92(*;7-G<W1R(")-Z7)E="(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA
M:6YT96YA;F-E(@IM<V=S='(@(D$@:V%R8F%N=&%R=.%S(&MI:&%G>>%S82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-Z;&]VX6MI82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-L;W9E;FEA(@IM<V=S='(@(E-Z;&]VZ6YI82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(@IM
M<V=S='(@(DAA=F%ZX7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B2/-Z
MX7!O<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4W"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B2/-ZX7!O<F]K(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G
M:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")(\WKA<&]R;VL@9.EL
M96SU='0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B2^ES]2!D
MZ6QU=.%N:2]E<W1I(&CS>N%P;W)O:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@U"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B02!H\R!MZ6QY
M<^EG93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*;7-G:60@(E-N
M;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(DCS(';M>FUE;FYY
M:7/I9V5B96X@:VEF96IE>G9E.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N
M9',B"FUS9W-T<B`B4V%L86UO;BUS>FEG971E:R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L
M:6$B"FUS9W-T<B`B4WIO;>%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B1&%L;VLL('9E
M<G-E:R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3$R"FUS9VED(")3;W)T
M(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")!('-O<F)A<F5N9&5ZZ7,@:7+A
M;GGA;F%K(&MI=N%L87-Z=.%S82(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D9E;&%D\VD@
M8^UM(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(D3I;"U!9G)I
M:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(F3I;"UE=7+S<&%I("A)
M4T\M.#@U.2TS*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B1.EL:2U'96]R9VEA(.ES
M($3I;&D@4V%N9'=I8V@M<WII9V5T96LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(D3I;&D@9NEL=&5K92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C
M92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(E-Z;VUS>NED;W,@
M8V5L;.%K(&OV>O9T=&D@=.%V;VQSX6<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")!(&-E;&QA
M('1A<G1A;&UA(.ES(&ME<F5T92!K]GKV='1I('3A=F]L<^%G(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(DAE
M;'EK:73V;'3U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(E3A=F]L
M<^%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R
M(")4X79O;'/A9R#I<R!B96QS]2!M87)G\R!B9>%L;.UTX7,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M4W!A:6XB"FUS9W-T<B`B4W!A;GEO;&]R<WKA9R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A;6%S
M<V%S<VEN92!B9>%L;.UTX7-O:R(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B
M4W!E8VGA;&ES(&MA<F%K=&5R(&)E=FET96QE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L
M:70@8V5L;"(*;7-G<W1R(")!(&-E;&QA(&ME='3I8F]N=.%S82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*
M;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")!>B!O<WIL;W`@:V5T=.EB
M;VYTX7-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(D$@<V]R
M(&ME='3I8F]N=.%S82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)T(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N
M:V$B"FUS9W-T<B`B4W+M($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z.#$*;7-G:60@(E-T
M86YD87)D(@IM<V=S='(@(E-T86YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(W.34*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B07H@96QS]2#I
M=B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("+!;&QA;2!V86=Y('1A<G1O;>%N
M>2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS
M9VED(")3=&%T=7,B"FUS9W-T<B`BP6QL87!O="(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#`Q"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")-
M96YTZ7-I(&9O<FWA='5M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D/M;2`H=71C
M82DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(N%T:/IZ;W1T(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L:7-T
M(@IM<V=S='(@(E-T<FEN9R!L:7-T82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*
M;7-G<W1R(")4]G+V;&K\:R!A(&/M;6+U;"!A($`@=73A;FD@<NES>G0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")3=.UL=7,@6T-34UTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R
M"FUS9VED(")3=2(*;7-G<W1R(")682(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@86QK]FYY=G3A
M<B!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E3A<F=Y(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S-B!L:6(O2&]R9&4O1F]R;2]296YD
M97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B2_QL9&K\:R!E
M;"(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S
M(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(EPB)7-<(B#Z:B!F96QH87-Z
M;N%L\R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T;W;A8F+M=&]T='5K+B#6
M;B!C<V%K("(*(FOI<F5L;>EN96L@96QF;V=A9.%SX70@:_9V973U96X@='5D
M(&UA:F0@8F5J96QE;G1K97IN:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T
M<B`B86QS\R!I;F1E>"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS
M9VED(")3=6-C97-S(@IM<V=S='(@(E-I:V5R_&QT(@H*(SH@861M:6XO=7-E
M<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")3:6ME<F5S96X@
M:&]Z>N%A9'1U:R!<(B5S7"(M="!A(')E;F1S>F5R:&5Z+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(EPB)7-<(B!F96QH87-Z;N%L\R!A9&%T86ET('-I:V5R
M97-E;B!T]G+V;'3\:R!A(')E;F1S>F5R8O5L+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(E-I:V5R97-E;B!T]G+V;'3\:R!<(B5S7"(M="XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4VEK
M97)E<V5N(&5L=.%V;VSM=&]T='5K(%PB)7-<(BUT(&$@<F5N9'-Z97)B]6PN
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S
M<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@
M8VAA;F=E<RXB"FUS9W-T<B`B(@HB02!K;VYF:6=U<N%C:?-T('-I:V5R97-E
M;B!V:7-S>F'A;&SM=&]T='5K+B!!(';A;'1O>N%S;VL@;65G=&5K:6YTZ7/I
M:&5Z("(*(F9R:7-S[71S92!A>B!O;&1A;'0N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(D$@8F%C:W5P(&MO;F9I9W5RX6-I\W0@96QM96YT971T_&LN(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(E-I:V5R97-E;B!E;&UE;G1E='3\:R!A
M*'HI("5S(&)A8VMU<"!K;VYF:6=U<N%C:?-T+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D
M871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&%D871A:6YA:R!M\V1O<^UT
MX7-A('-I:V5R97-E;B!M96=T]G)TZ6YT+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R(")3
M:6ME<F5S96X@96QM96YT971T_&L@82`E<R#A;&QO;>%N>70N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4W5D86XB"FUS9W-T<B`B4WIU9.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R
M>2(*;7-G<W1R("+6<W-Z969O9VQA;.%S(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R(").87!K96QT92(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*
M;7-G<W1R(").87!N>75G=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B;F%P;W,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3
M=6YR:7-E(@IM<V=S='(@(DYA<&ME;'1E(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR
M:7-E+U-U;G-E="(*;7-G<W1R(").87!K96QT92]N87!N>75G=&$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E
M.B`B"FUS9W-T<B`B3F%P:V5L=&4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R(").87!N>75G
M=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED
M(")3=6YS970Z("(*;7-G<W1R(").87!N>75G=&$Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R
M<V-R:7!T(@IM<V=S='(@(F9E;'/U(&EN9&5X(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")/;FQI
M;F4@:V]M;75N:6OA8VGS("AC:&%T*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM
M<V=S='(@(E-U<FEN86UE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B0W-A;.%D;NEV(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R
M9"#I<R!*86X@36%Y96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
M4WIVX7II9O9L9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=NED;W)S
M>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-VX6IC(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G
M(&1E;&5T960B"FUS9W-T<B`B07H@861A='-Z:6YK<F]N:7KA8VGS<R!N87!L
M\^%L;&]MX6YY="!T]G+V;'3\:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<R(*;7-G<W1R(")3>FEN=&%K=&EK86D@:&EB82!A(&ME<F5S
M]6MI9F5J97KI<V)E;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M(@IM<V=S='(@(E-Z[7)I86D@07)A8B!+]GITX7)S87/A9R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T
M;W)M(@IM<V=S='(@(EII=F%T87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB
M"FUS9W-T<B`B6FEV871A<BP@97+U<R!S>NEL(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS(@IM
M<V=S='(@(EII=F%T87)O:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")+;W)A:2!Z:79A=&%R;VLB"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP
M.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6("A404(@:V%R86MT
M97)R96P@96QVX6QA<WIT;W1T(.ER=.EK96LI(.%L;&]MX6YY(@H*(SH@;&EB
M+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@
M(E3A8FSA>F%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G
M<W1R(")!('3A8FSA>F%T('1U;&%J9&]N<^%G86DB"@HC.B!L:6(O2&]R9&4O
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T
M<B`B02!TX6)LX7IA="!T=6QA:F1O;G/A9V%I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1A:7=A;B(*;7-G<W1R(")486IV86XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA(@IM<V=S='(@(E1A:G9A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B5&%D>G-I:VES>G3A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>N%N:6%I($5G>65S_&QT
M($MI<N%L>7/A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B02!CZ6PZ(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#D@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B1F5L861A=&]K
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E
M;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L969O;G-ZX6TB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B07H@96QM^FQT(/-R82!H]6WI<G/I:VQE=&4Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*
M;7-G<W1R(")(]6WI<G/I:VQE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B2/5M
MZ7)SZ6ML970Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")(]6WI<G/I:VQE=#QB<B`O
M/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,B"@HC.B!L:6(O2&]R9&4O5&5M
M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!S86)L;VX@
M;F5M('1A;.%L:&%T\RXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM
M<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4V%B;&]N
M;VL@861M:6YI<WITX6-I\VIA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,34@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,S$*;7-G:60@(E1E>'0B"FUS9W-T
M<B`B4WKV=F5G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I
M9"`B5&5X="!/;FQY(@IM<V=S='(@(F-S86L@<WKV=F5G(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I
M9"`B5&5X="!A;&EG;B(*;7-G<W1R(")3>O9V96=E;&AE;'EE>NES(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I
M9"`B5&5X='1O<"(*;7-G<W1R(")S>O9V96<@=&5T96IE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B
M"FUS9W-T<B`B0W/\(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G
M:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(G1H86D@*%1)4RTV,C`I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6;V;&0B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")!>B!F='`@8O5V[73I<R!N96T@=&%L
MX6QH873S+B(*"B,Z(&QI8B](;W)D92](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B
M5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")!($AI
M<W1O<GD@<F5N9'-Z97(@;?MK]F3I<V4@;FEN8W,@96YG963I;'EE>G9E+B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,X"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B02!(;W)D92]+;VQA8B!I;G1E
M9W+A8VGS(&5Z="!N96T@=.%M;V=A=&IA.B!<(B5S7"(B"@HC.B!L:6(O3F5T
M+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B07H@24U34"!N87!L\WKA
M<W0@;F5M('-I:V5R_&QT(&UE9VME>F1E;FDN(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(D$@36%I;G1E
M;F%N8V4Z.B!O<WITX6QY(&)E=/9L=.ES92!N96T@<VEK97+\;'0B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M07H@3W!C:?,@86)L86L@8F5ZX7)O9&]T="X@2VELZ7#I<R!K]G9E=&ME>FEK
M+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](;W)D92]097)M
M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z,C,T(&QI8B](
M;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C8T
M(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI
M<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES
M<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N(@IM<V=S='(@(B(*(D$@2F]G;W-U;'1SX6=O:R!H87-Z;N%L873A;F%K
M(&5L]69E;'3I=&5L92P@:&]G>2!A(')E;F1S>F5R9V%Z9&$@(@HB:V]N9FEG
M=7+A;&IO;B!E9WD@82!J;V=O<W5L='/A9VD@861A=&]K870@=&%R=/-S86X@
M=.%R;VQN:2!KZ7!E<R!A;')E;F1S>F5R="XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@
M8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")#<V%K(&%L=6P@;&5G>65N(&ME
M<F5T(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM
M<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A
M=&%B87-E+B(*;7-G<W1R("(B"B)!('!A<G1N97(@87IO;F]S[73S<WKA;6$@
M;F5M('9O;'0@;65G861V82_\<F5S96X@;6%R861T('9A9WD@87H@861A=&+A
M>FES8F%N("(*(FYE;2!V;VQT(&UE9W1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")!('!A<G1N97(@861A=&%I="!S:6ME<F5S96X@:&]Z>N%A
M9'1U:R!A(&/M;6IE9WEZZ6OI:&5Z+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(DO\;/9NX6QL\R!01U`@86SA[7+A<VD@8FQO
M:VL@<WK\:W/I9V5S(&$@9&EG:73A;&ES86X@86SA[7)T(/QZ96YE="`B"B)H
M:71E;&5S<^EGZ6YE:R!E;&QE;O5R>NESZ6AE>BXB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S
M='(@(B(*(D$@:_9R;&5VZ6QL:7-T82!A>F]N;W/M=/-S>N%M82!N96T@=F]L
M="!M96=A9'9A+_QR97-E;B!M87)A9'0@=F%G>2!A>B`B"B)A9&%T8N%Z:7-B
M86X@;F5M('9O;'0@;65G=&%LX6QH873S+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B02!K]G)L97;I;&QI
M<W1A(&YE;2!V;VQT(&UE9V%D=F$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H
M<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@
M82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*(D$@=&ET:V]S
M[73A<VD@<WIO;&?A;'1A=.%S;VMH;WH@8FEZ=&]N<^%G;W,@*'1I=&MO<^UT
M;W1T*2!W96(@:V%P8W-O;&%T(&ME;&PN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-S<@;&EB+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R
M(")!*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@96=Y
M("5S(&)EX6QL[73A<VYA:RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$W,"!L:6(O
M2&]R9&4N<&AP.C4P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B
M"B)!*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@=F%L
M86UI;'EE;B`E<R!B9>%L;.UTX7,H;VLI;F%K+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+B(*;7-G<W1R(")!(&;A:FP@;F5M(&WA<V]L:&%T\R#V;FUA
M9^%R82XB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B02!FX6IL8F%N(&YE
M;2!V;VQT(&%D870N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(D%Z
M(/QZ96YE="!F96ILZ6-S;W)A:2!A(&OV=F5T:V5Z]6LN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F
M(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H
M97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R
M("(B"B)!('1E;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9"!P<F]B;.EMX6MA="!O
M:V]Z:&%T(&%Z($EN=&5R;F5T($5X<&QO<F5R("(*(FAA<WINX6QA=&$@97-E
M=.EN+"!M97)T(&5B8F5N(&]L>6%N('!R;V=R86UH:6+A:R!V86YN86LL(&%M
M:6ME="!N96T@='5D='5N:R`B"B)M96=K97+\;&YI+B!!(&OI<&5R;GGU:F4@
M;VQV87-H871A=&QA;F[A(';A;&AA="P@8FEZ;VYY;W,@961I=&]R(&9U;FMC
M:?-K("(*(FAIX6YY;WIH871N86L@Z7,O=F%G>2!VX7)A=&QA;G5L(&QE9F%G
M>6AA="!A(&+V;F?I<WKU<')O9W)A;2X@5VEN9&]W<R`Y>"`B"B)H87-Z;N%L
M871A(&5S973I;B!N86=Y;VX@=F%L\W-Z[6[[+"!H;V=Y("='96YE<F%L('!R
M;W1E8W1I;VX@9F%U;'0G(&AI8F$@(@HB;6EA='0@^FIR82!K96QL(&EN9.UT
M86YI82!M86ID(&$@9^EPZ70N7%QN7%QN1FEG>65L;65Z=&5T=/QK(2!+871T
M:6YT<V]N(&%Z("(*(D]+(&=O;6)R82P@:&$@;>EG:7,@;65G(&OM=N%N:F$@
M:^USZ7)E;&YI(&$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M;?-D;W0N(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(D$@7"(E<UPB(&%Z;VYO<^UT\W0@:VET]G+V;'3\:RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED
M(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")#<V%K(&)A;"!O
M;&1A;&]N(&QE9WEE;B!K97)E="(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M(@IM<V=S='(@(B(*(D$@1VYU4$<@<')O9W)A;2!H96QYZ70@;65G(&ME;&P@
M861N:2!A($-R>7!T7W!G<#HZ(&]S>G3A;'D@:&%S>F[A;&%TX6AO>BXB"@HC
M.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(D$@;&5VZ6PL(&UE;'EE="`E<R!N
M87!JX6X@:_QL9/9T="`E<R!C[6UZ971T;F5K(%PB)7-<(B!TX7)G>6)A;BP@
M82!C[6UZ971T("(*(G-ZX6WM=/-GZ7#I;B!M96=J96QE;G0N($%R<F$@;FEN
M8W,@9V%R86YC:6$L(&AO9WD@96P@:7,@;VQV87-TX6L@:6QL+B!H;V=Y("(*
M(FUE9^ER=&5T=.EK+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#@Q"FUS
M9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP
M;W-E('!A9V4B"FUS9W-T<B`B36D@;&5G>65N(&$@;&5VZ6SM<O,@86)L86MH
M;WH@;75T873S(&QI;FL@96QN979E>NES92(*"B,Z(&QI8B]&:6QE+T-35BYP
M:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N(@IM<V=S='(@(D$@;65Z]6L@<WKA;6$@8W-A:R!N=6UE<FEK=7,@
MZ7)TZ6L@;&5H970N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ
M,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"B)!
M>B!O<&5N<W-L(&UO9'5L('-Z_&MSZ6=E<R!A($AO<F1E7T-R>7!T7W-M:6UE
M.CH@;W-Z=.%L>2!H87-Z;N%L873A:&]Z+B(*"B,Z(&QI8B](;W)D92]0<F5F
M<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E
M;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G
M<W1R("(B"B)!(%PB)7-<(B!S>F5MZ6QY97,@8F7A;&SM=.%S(&YE;2!M96YT
M:&5T]2!E;"P@;65R="!MZ7)E=&4@;65G:&%L861J82!A("(*(FUE9V5N9V5D
M971T(&UA>&EM=6UO="(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N
M<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B).96T@=&%LX6QH
M873S(&%Z(&$@<')O9W)A;2!A('-Z97)V97)E;BP@86UI('-Z_&MSZ6=E<R!E
M;FYE:R!A>B!A9&%T=.UP=7-N86L@(@HB*"5S*2!A(&UE9VIE;&5N[73I<^EH
M97HN(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`B07H@:63I>O5J96P@:V%R86MT97(@8W-A:R!E9WEE=&QE;B!K87)A
M:W1E<B!L96AE="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>2(*;7-G<W1R(")*;V)B(.ES(&)A;"!O;&1A;&]N(&QE9WEE
M;B!K97)E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL
M>2(*;7-G<W1R(")#<V%K(&IO8F(@;VQD86QO;B!L96=Y96X@:V5R970B"@HC
M.B!L:6(O1FEL92]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")!>B!E;';A
M;&%S>G3S(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT97(@;&5H970N
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@<WIE<G9E<G0@=/9R]FQT_&LN(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(D$H>BD@7"(E<UPB('-Z97)V97)T(&5L;65N=&5T=/QK+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S
M='(@(B5S(&)E:F5L96YT:V5ZZ7-I(&OI<F5L;>ET('3V<O9L=/QK+B(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D$@;65G861O='0@<V]R("@E9"D@;F5M(&SI
M=&5Z:6LN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!I9&5I9VQE;F5S(&;A:FP@;F5M
M(&SI=&5Z:6LN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#8*;7-G:60@
M(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@
M;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B02!B9>UR="!S>O9V96<@;F5M(&5G
M>65Z:6L@82!KZ7!E<FYY]6X@;&5V]79E;"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")!;'5L(.ES(&;V
M;/QL(&QE9WEE;B!K97)E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O
M;FQY(@IM<V=S='(@(D-S86L@9F5N="!L96=Y96X@:V5R970B"@HC.B!L:6(O
M2&]R9&4O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B02!F
M96QT]FQT]G1T(&%D871O:R!A>B!E;/5Z]2!LZ7#I<R#S=&$@96QV97-Z=&5K
M+B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D92]$
M871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D$@9F5L=/9L=/9T="!FX6IL="!N
M96T@<VEK97+\;'0@96QM96YT96YI+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B02!W96%T:&5R+F-O;2!B;&]K:R!N96T@:&%S>F[A;&AA
M=/,N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B02!M96=J96QE;NES:2!S=.UL=7,@*'1H96UE<RD@86QK]FYY
M=G3A<B!<(B5S7"(@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+B(*;7-G<W1R(").:6YC<V5N(';A;&%S>G1H873S(&]P8VGS+B(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HS-#D*;7-G:60@(E1H
M97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE
M+B(*;7-G<W1R(").:6YC<R!A(&QE=NEL(&)E;'-E:NEB96X@;65G:F5L96[M
M=&AE=/4@;65L;.EK;&5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`U
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*
M;7-G<W1R("(B"B)4^FP@<V]K(&MA<F%K=&5R('9A;B!E8F)E;B!A(&UE>O5B
M96XN(-9N("5S(&MA<F%K=&5R="!A9&]T="!M96<[(&$@(@HB;6%X:6WA;&ES
M86X@;65G861H873S('!E9&EG(&ME=F5S96)B+"!M:6YT("5S+B(*"B,Z('-I
M9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H
M92!S>7-T96TZ("5S(@IM<V=S='(@(EPB)7-<(B!F96QH87-Z;N%L\VYA:R!A
M(')E;F1S>F5R:&5Z(&%DX7-A:V]R(&AI8F$@=/9R=.EN="X@)7,B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")<(B5S7"(@9F5L:&%S>F[A;/,@
M861A=&%I;F%K('3V<FSI<V4@<V]RX6X@:&EB82!LZ7!E='0@9F5L.B`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B7"(E<UPB(')E;F1S>F5R8O5L('9A;/,@=/9R;.ES
M96MO<B!H:6)A(&SI<&5T="!F96PZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B7"(E<UPB(&WS9&]S[73A<V$@
M<V]RX6X@:&EB82!LZ7!E='0@9F5L.B`E<R(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A
M9&5D+B(*;7-G<W1R("(B"B)!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@
M<WIE<G9E<G)E(&9E;'3V;'1E;FDN("5S(&YE;2!T]FQT]63V='0@9F5L+B(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB07H@X6QL;VWA
M;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B`E<R!N
M86=Y;V)B+"!M:6YT(&$@(@HB;6%X:6WA;&ES86X@;65G96YG961E='0@;>ER
M970@*"5D(&+A:G0I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB07H@X6QL;VWA;GET(&YE;2!S:6ME
M<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B!!*'HI("5S(&;A:FQN86L@
M8W-A:R!E9WD@(@HB<NES>F4@=/9L=/5D]G1T(&;V;"XB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T
M<B`B02!L97;I;"!E('+I<WKI;F5K(&UE9VIE;&5N[73I<V5K;W(@:&EB82!T
M]G)TZ6YT(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(D$@<&%R=&YE<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@
M:&EB82!T]G)TZ6YT+B(*"B,Z(&QI8B](;W)D92]$871A+VEM8RYP:'`Z,S$*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R(")!>B!I0V%L96YD87(@861A=&]K(&EM<&]R
M=.%LX7-A('-O<N%N(&AI8F$@=/9R=.EN="XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB2&EBX7,@82!M96=A
M9&]T="!K;VYF:6=U<N%C:?,N($QE:&5T+"!H;V=Y(&YE;2!T]FQT]G1T(&MI
M(&5G>2!S>OQK<^EG97,@(@HB;65Z]70N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(D$@<&%R=&YE<FIE9WEZZ6MK96P@:V%P8W-O;&%T;W,@9F5L861A="!VZ6=R
M96AA:G3A<V$@<V]RX6X@:&EB82!LZ7!E='0@9F5L+B`B"B)+Z7)E;2!P<O-B
MX6QJ82!M96<@:^ES]6)B+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"B)(:6)A('3V<G3I;G0@82!P87)T;F5R(&%D871A
M:6YA:R!F<FES<^UTZ7-E('-O<N%N+B!+Z7)E;2!P<O-BX6QJ82!M96<@:^ES
M]6)B+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB02!K]G)L97;I
M;&QI<W1A(&%D871A:6YA:R!F<FES<^UTZ7-E('-O<N%N(&AI8F$@=/9R=.EN
M="X@2^ER96T@<'+S8N%L:F$@;65G("(*(FOI<_5B8BXB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R("(B"B)%>B!A>B!)34%0('-Z97)V97(@;F5M('3A;6]G871J82!A(&UA
M<'#A:VAO>B!V86SS(&AO>GKA9NERZ7,@;65G;W-Z=.%SX70N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S
M='(@(D5Z(&YE;2!T^VYI:R!S>F%BX6QY;W,@<F%R(.%L;&]MX6YY;F%K+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*
M;7-G<W1R(")%>B!N96T@=/MN:6L@<WIA8N%L>6]S('II<"#A;&QO;>%N>6YA
M:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S,0IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(D5Z(&YE;2!T^VYI:R#I<G;I;GEE<R!KX7)T>6%S>N%M;F%K+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%>B!A
M(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M:V%P8W-O;&%T
M;VX@4TU3+70@:_QL9&K\;FL@82`B"B)#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI('-Z;VQGX6QT873S;B#A="XB"@HC.B!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@HB17H@82!M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G
M>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK(&$@5TE.("(*(BAH
M='1P.B\O=VEN<&QC+F-O;2D@<WIO;&?A;'1A=/-N(.%T+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%>B!A(&UE9VAA:G3S
M(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M:V%P8W-O;&%T;VX@4TU3+70@
M:_QL9&K\;FL@87H@(@HB<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@<WIO;&?A;'1A=/-N(.%T+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O
M9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O
M9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*
M(D5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@4TU44"UK87!C
M<V]L871O;B!335,M="!K_&QD:OQN:R!6;V1A9F]N92`B"B)S>N%M;VMR82!A
M(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@<WIO;&?A;'1A
M=/-N(.%T+B!!("(*(G-Z;VQGX6QT873A<R!I9^EN>6)E=NET96SI:&5Z(%9O
M9&%F;VYE($ET86QY(&5M86EL(&/M;2!S>OQK<^EG97,N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.CDX,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3`Y,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(V,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30P,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,34V,0HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3@T,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`P.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$U,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R-2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0Q,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U-`HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C8T,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q-"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$R,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P
M,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S@Q-PIM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B
M17H@82!M97KU(&YE;2!M87)A9&AA="#\<F5S+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N(@IM<V=S='(@(D5B8F5N(&$@;65Z]6)E;B!C<V%K(&5G
MZ7-Z('-ZX6UO:R#A;&QH871N86LN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(T,C`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D5B8F5N(&$@;65Z]6)E;B!C
M<V%K(&5GZ7-Z('-ZX6UO:R#I<R!K971T]7-P;VYT(&QE:&5T+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")%8F)E;B!A(&UE
M>O5B96X@8W-A:R!O:W3A;&ES('-ZX6UO:R#A;&QH871N86LN(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M(@IM<V=S='(@(B(*(D5Z(&$@;65Z]2!C<V%K('9E<W-Z]79E;"!V86=Y('-Z
M\VOV>GIE;"!E;';A;&%S>G1O='0@96?I<WH@<WKA;6]K870@(@HB=&%R=&%L
M;6%Z:&%T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI
M<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")%>B!A
M>B#I<G3I:R!C<V%K('-ZX6T@;&5H970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(X,C(*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@
M8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE
M("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B16)B96X@82!M97KU8F5N(&AE>&%D
M96-I;>%L:7,@4D="('-Z[6YK\V0@X6QL:&%T+"!P;"X@)R,Q,C,T868G+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B17IE;B!A9&%T
M;VMK86P@:V%P8W-O;&%T;W,@9F5L861A=&]K870@82!S>F5R=F5R(&WA<B!E
M;';I9V5Z=&4N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B17H@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L
M:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R
M;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A
M<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB17H@96=Y($MO;&%B($=R;W5P=V%R
M92!O8FIE:W1U;2X@07H@:6QY96X@;V)J96MT=6T@;65G:F5L96[M=.ESZ6AE
M>B!O;'EA;B`B"B)E;6%I;"!K;&EE;G-P<F]G<F%M('-Z_&MSZ6=E<RP@86UE
M;'D@:^EP97,@82!+;VQA8B!'<F]U<'=A<F4@9F]R;>%T=6T@(@HB:V5Z96SI
M<^ER92X@26QY96X@96UA:6P@:VQI96YS96L@;&ES=.%J82!LX71H873S(&ET
M=#H@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I
M;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*
M;7-G<W1R(")%>G0@82!L979E;&5T(&WA<R!K87)A:W1E<FOI<WIL971T96P@
M*"5S*2#M<G3A:RP@;6EN="!A;6ET(-9N(&AA<WINX6PN(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")%>B!A('-ZX6T@;F5M(&QE:&5T
M(&5G>6[I;"!K:7-E8F(N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N
M<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B17H@82!S>F5R=F5R(&YE;2!K
MZ7!E<R!K:6)O;G1A;FD@82!Z:7`@:6QL+B!G>FEP(.%L;&]MX6YY;VMA="XB
M"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")%>B!A
M(')E;F1S>F5R(&IE;&5N;&5G(&EN86MT:7;A;'9A('9A;BXB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")%>B!A>B#I<G3I:R!C<V%K('-ZX6T@
M;&5H970N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS
M-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/
M<'1I;VYS('=I;F1O=R(*;7-G<W1R(")%>G0@87H@86)L86L@8W-A:R!A>B!/
M<&-I\VL@86)L86MB\VP@:.UV:&%T\R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R(@IM<V=S='(@
M(E9I;&SA;6SA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*
M;7-G:60@(E1I8VME=',B"FUS9W-T<B`B2&EB86)E:F5L96YTZ7,M:V5Z96SI
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(Y('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("))9/4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R
M86-K:6YG(@IM<V=S='(@(DUU;FMA:63U+6YY:6QVX6YT87)TX7,B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S
M='(@(DED]2!F;W)MX71U;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,U
M"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("))9/4@=N%L87-Z=.%S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B2V5L970M5&EM;W(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET
M=6QU<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B0^UM("AT
M;V]L=&EP*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<U"FUS9VED(")4;R(*;7-G<W1R(")#[6UZ971T(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS
M9W-T<B`B(@HB2&$@=/9B8B!E;&5M970@:7,@:VD@86MA<B!J96SV;&YI+"!T
M87)T<V$@;&5N>6]M=F$@82!#;VYT<F]L("A00RD@=F%G>2!A("(*(D-O;6UA
M;F0@*$UA8RD@8FEL;&5N='G[="!A(&MA='1I;G3A<R!K]GIB96XN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B36$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T
M<B`B2%1-3"!F;W)RX7-NZ7IE="!K:2]B92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS
M9W-T<B`B5&]G;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@
M(E1O;6]R<F]W(@IM<V=S='(@(DAO;&YA<"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM
M<V=S='(@(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B9O9L_&PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS
M"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(DQE9V9E;'/U(&9R
M86UE("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(D9O<F3M=.%S;VLB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D(.ES(%1O
M8F%G;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E
M(&]R(&9A;'-E(@IM<V=S='(@(DEG87H@=F%G>2!H86UI<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U
M(@IM<V=S='(@(DME(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6[I
M>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E3V<O9K;W)S>N%G(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E3
M3RTX.#4Y+3DI(@IM<V=S='(@(G3V<O9K("A)4T\M.#@U.2TY*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4_')K;65N:7-Z=.%N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM
M<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS
M+2#I<R!#86EC;W,M<WII9V5T96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T
M<B`B5'5V86QU(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4
M>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`BS7)J82!B92P@;6ET(';A;&%S
M>G1O='0Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*
M;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R(")55B!I;F1E>#H@(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T
M<B`B(@HB55),+"!M96QY96X@96=Y('!R;V=R86T@96QF;V=A9&IA(&$@<WIO
M;&?A;'1A=/,@X6QT86P@:_QL9/9T="!K_&QD]G1T("(*(FOI>F)E<^UTZ7-I
M(&IE;&5N=.ES="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(E5K<F%J;F$B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0Q.0IM
M<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(").96T@<VEK97+\;'0@82!61E,@86QK]FYY=.%R8F$@8F5LZ7!N:2XB"@HC
M.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+B(*;7-G<W1R("(B"B)!(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%G(&EG
MZ6YY;.ES96MO<B!N96T@<VEK97+\;'0@87H@861A=&]K(&5L=.%R;VSA<V$N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@HB3F5M('-I:V5R_&QT(&$H>BD@7"(E<UPB(%9&
M4R!FX6IL(&5LZ7+I<VD@:F]G;W-U;'1SX6=A:70@;65G=N%L=&]Z=&%T;FDN
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS.3(@;&EB+U9&4R]M=7-Q;"YP:'`Z
M-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*(DYE;2!S
M:6ME<OQL="!A*'HI("5S+R5S(%9&4R!FX6IL(&5LZ7+I<VD@:F]G;W-U;'1S
MX6=A:70@;65G=N%L=&]Z=&%T;FDN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+B(*;7-G<W1R(").96T@<VEK97+\;'0@82AZ*2`E<R!A;&OV;GEV=.%R8F$@
M8F5LZ7!N:2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB
M+B(*;7-G<W1R(")!*'HI(%PB)7-<(B#A;&QO;>%N>2!MZ7)E=&4@;F5M(.%L
M;&%P[71H873S(&UE9RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Y-2!L:6(O
M5D93+W-Q;"YP:'`Z,3`R."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<R\E<UPB(.%L;&]MX6YY
M(&WI<F5T92!N96T@X6QL87#M=&AA=/,@;65G+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(*;7-G<W1R(")!>B!344P@<WIE<G9E<B!N96T@Z7)H973U
M(&5L+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")!>B!34TP@:V%P8W-O;&%T
M(&YE;2#I<.UT:&5T]2!F96PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,S(@
M;&EB+U9&4R]F:6QE+G!H<#HR,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`T
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G
M<W1R(")!(%9&4R!FX6IL(&YE;2!MX7-O;&AA=/,@X70N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").96T@<VEK
M97+\;'0@82AZ*2!<(B5S7"(@5D93(&%L:_9N>79TX7)T(&SI=')E:&]Z;FDN
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-C$@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").96T@<VEK97+\;'0@
M;.ET<F5H;WIN:2!A(%9&4R!A;&OV;GEV=.%R="XB"@HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M(@IM<V=S='(@(DYE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@5D93(&;A:FQT
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`B02AZ*2!<(B5S7"(@5D93(&UA<'!A(&YE;2!H;WIH873S(&SI=')E+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").96T@<VEK97+\;'0@;.ET
M<F5H;WIN:2#\<F5S(%9&4R!FX6IL="XB"@HC.B!L:6(O2&]R9&4O0V]M<')E
M<W,O=&%R+G!H<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*
M;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(D$@
M=/9M]G+M=&5T="#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&MI8F]N=&%N:2XB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C(X(&QI8B]61E,O9G1P+G!H<#HS,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"(@
M;F5M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N96T@_')E<RXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z
M("5S+B(*;7-G<W1R(")<(B5S7"(@=/9R;.ES92!N96T@<VEK97+\;'0Z("5S
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,X(&QI8B]61E,O<W%L+G!H<#HS
M.34@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C,T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(E<R!N
M96T@=/9R]FQH973U+"!A>B!A;&OV;GEV=.%R(&YE;2#\<F5S+B(*"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C,U-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U
M<G-I=F5L>2XB"FUS9W-T<B`B02!61E,@86QK]FYY=G3A<B!N96T@=/9R]FQH
M973U(')E:W5R>NUV86XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#0@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-0HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4R
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(D$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2XB"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z-#(P(&QI8B]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B02!61E,@86QK]FYY=G3A<B!N96T@=/9R]FQH973U.B`E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")!*'HI(%PB)7-<(B!61E,@9N%J;"!N96T@=/9R]FQH973U+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,S$P(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X,"!L:6(O
M5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92XB"FUS9W-T<B`B02!61E,@9N%J;"!N96T@=/9R]FQH
M973U+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B02AZ*2!<(B5S7"(@5D93(&UA<'!A(&YE;2!T]G+V;&AE=/4N(@H*
M(SH@;&EB+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@
M(DYE;2!VZ6=E>FAE=/,@<F5K=7)Z[78@=/9R;.ES(&$@5D93+6)E;CH@)7,N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E
M=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5M(&AA=.%R
M;WIH873S(&UE9R!A(&IE;&5N;&5G(.ER=NEN>65S(&%L:_9N>73A<BXB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE
M('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(")!('1A
M;OIS[71VX6YY('+I<WIL971E<R!A9&%T86D@;F5M(&AA=.%R;WIH873S:R!M
M96<B"@HC.B!L:6(O3F5T+TE-4U`N<&AP.C0S-R!L:6(O3F5T+TE-4U`O075T
M:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(").96T@<VEK97+\;'0@
M8F5O;'9A<VYI("5S(&1E9FEN[6-I\VKA="XB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C(P,R!L:6(O5D93+V9I;&4N<&AP.C(P."!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HQ-S0*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B02!61E,@9N%J;"!N
M96T@:&5L>65Z:&5T\R#A="XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z.3,@;&EB
M+U9&4R]S;6(N<&AP.C$P-B!L:6(O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(%9&
M4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR.#0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M(&YY:71H873S(&UE
M9R#M<N%S:2!CZ6QL86PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O
M5D93+V9I;&4N<&AP.C$S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(D$@5D93(&;A
M:FP@;F5M(&YY:71H873S(&UE9R`N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92XB"FUS9W-T<B`B02!T]FWV<NUT971T(.%L;&]MX6YY(&YE
M;2!N>6ET:&%T\R!M96<N(@H*(SH@;&EB+U9&4RYP:'`Z.#4V"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*
M;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!O;'9A<VAA=/,@*&$@9FEL97-I>F4H
M*2!S:6ME<G1E;&5N('9O;'0I+B(*"B,Z(&QI8B]61E,N<&AP.C@X-PIM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B02!61E,@9N%J;"!N96T@;VQV87-H873S("AA(&=E
M=$9I;&53:7IE*"D@<VEK97)T96QE;B!V;VQT*2XB"@HC.B!L:6(O2&]R9&4O
M4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R
M96%D(&9I;&4Z("(*;7-G<W1R(")%>B!A(&;A:FP@;F5M(&]L=F%S:&%T\SH@
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B02!V9G-R;V]T
M(&%L:_9N>79TX7(@;F5M(&]L=F%S:&%T\RXB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$Q,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(B5S(&YE;2!N979E>FAE=/4@X70@)7,@;NEV<F4Z(&WA
M<B!LZ71E>FEK(&EL>65N(&YE=OL@;6%P<&$B"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B02!61E,@86QK]FYY=G3A<B!N96T@;F5V97IH973U
M(.%T+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`B02!61E,@86QK]FYY=G3A<B!N96T@;F5V97IH973U(.%T.B`E<RXB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C<Q(&QI8B]61E,O9G1P+G!H<#HS-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(%9&4R!FX6IL(&YE;2!N
M979E>FAE=/4@X70N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV,3<@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D$H>BD@)7,O)7,@
M5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="XB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z,S(V(&QI8B]61E,O;75S<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H
M<#HT-3(*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92XB"FUS9W-T<B`B02!61E,@9N%J;"!N96T@;F5V97IH973U(.%T+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B07H@)VUK:7-O9G,G('!R
M;V=R86T@;F5M(&9U='1A=&AA=/,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DYE;2!S:6ME<OQL="!L969O
M<F3M=&%N:2!E>G0@82!7;W)D(&1O:W5M96YT=6UO="(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HQ-30@;&EB+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")!*'HI(%PB)7-<(B!61E,@9N%J;"!N96T@[7)H873S+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")!(%9&4R!FX6IL(&YE
M;2#M<FAA=/,@*&$@8V]P>2@I('-I:V5R=&5L96X@=F]L="DN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HR.#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30V(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(D$@5D93(&;A:FP@861A=&%I(&YE
M;2#M<FAA=/-K(&MI+B(*"B,Z(&QI8B]61E,N<&AP.C@V,@IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+B(*;7-G<W1R(")!(%9&4R!FX6IL(.URX7-A(&MV\W1A=/IL;.EPZ7,@;6EA
M='0@;F5M(&9E:F5Z:&5T]2!B92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T
M<B`B86SA:/IZ;W1T(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM
M<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(DWI9W-E(&UE;G1S_&L@96PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")6:7-S
M>F%V;VYJ82!A>B!U=&]L<_,@=N%L=&]Z=&%TX7-T(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"B)!(&MA<&-S
M;VQA="!F96QVZ71E;.ET(&OV=F5T]65N(';A<F%T;&%N(';A;&%S>B#I<FME
M>F5T="!A('-Z97)V97)T]6PZ("(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,S.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")6X7)A
M=&QA;B!VX6QA<WH@Z7)K97IE='0@82!S>F5R=F5R=/5L(&5R<F4Z("(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(D)E<V]R;VQA=&QA;B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T
M<B`B56YI8V]D92`H551&+3@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A
M=&5S(@IM<V=S='(@(D5G>65S_&QT($%R86(@16WM<G/I9V5K(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")%9WEE<_QL="!+:7+A;'ESX6<B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(D5G>65S_&QT(,%L
M;&%M;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',B"FUS9W-T<B`B16=Y97/\;'0@P6QL86UO:RP@:VES96)B(&O\
M;'/U('-Z:6=E=&5K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N:71S(@IM<V=S
M='(@(F5G>7/I9R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R.2!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B27-M
M97)E=&QE;B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M(@IM<V=S='(@(DES;65R971L96X@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM
M<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M;7-G<W1R("))<VUE<F5T;&5N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I
M9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B02!M96=A
M9&]T="!H96QY(&ES;65R971L96XN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(DES;65R971L96X@9F5L:&%S>F[A;/-I(&[I
M=B!V86=Y(&IE;'-Z\RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R
M<F5N="!E;&5M96YT(@IM<V=S='(@(E3A=F]L[71S=6L@96P@:6YN96X@82!L
M:6YK970B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,@IM<V=I9"`B
M56YN86UE9"(*;7-G<W1R(").:6YC<R!E;&YE=F5Z=F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(D)I>G1O;G/A
M9VD@;VMO:V+S;"!A(&9E;&AA<WINX6SS:2!P<F]G<F%M;VL@;F5M(&AA<WIN
MX6QH871JX6L@82!+:7;A9^%S+R(*(DWA<V]LX7,O0F5I;&QE<WITZ7,@;?-D
M<WIE<G0N($MA='1I;G1S;VX@87H@3TL@9V]M8G)A+"!H82!A(&UO>FEL;&$N
M;W)G("(*(G=E8F]L9&%L;VX@96P@:^UVX6YJ82!O;'9A<VYI(&$@=&5C:&YI
M:V%I(&QE[7+A<W0@;65L>2!M96=A9&IA+"!H;V=Y86X@;&5H970@(@HB97IT
M(&WI9VES(&5N9V5DZ6QY97IN:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R(")!('-Z[6X@=FES<WIAX6QL[73A<V$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.CDR-PHC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(DYE;2!TX6UO9V%T
M;W1T(&5X=&5N>FGS(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T
M92(*;7-G<W1R(")-\V1O<^UTX7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E
M<R(*;7-G<W1R("(E<R!A9&%T86EN86L@;?-D;W/M=.%S82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U
M<V5R(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@861A=&%I;F%K(&WS9&]S[73A
M<V$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB
M(';A;'1O>N%S86ET(&5L;65N=&5T=/QK+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R(")!>B!U<&=R861E('!R;V=R86UO="!T]G+V;'3\:RXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")&96QT
M]FQTZ7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BXB"FUS9W-T<B`B07H@]G-S>F5S(&%L:V%L;6%ZX7,@:V]N9FEG=7+A
M8VGS:N%T(&9E;'3V;'3V='3\:R!A('-Z97)V97)R92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS
M9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(FQA=&EN(&YA9WEB
M973[:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B;F%G>6)E=/MS('+S;6%I('-ZX6UO:R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U
M87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#
M=7)R96YT.B`E<R(*;7-G<W1R(")(87-Z;N%L:G5K(&$@:F5L96YL96=I=#H@
M)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS
M9VED(")5<V4@4U-,(@IM<V=S='(@(DAA<WINX6QJ=6YK(%-33"UT(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T
M<B`B(@HB06MK;W(@:&%S>F[A;&IU:RP@:&$@87H@24U34"!S>F5R=F5R96X@
M;>%S(&$@8F5J96QE;G1K97KI<VD@;F5V_&YK+R(*(FIE;'-Z879U;FLN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B
M57-E<B(*;7-G<W1R(")&96QH87-Z;N%L\VD@;NEV(@H*(SH@;&EB+TAO<F1E
M+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E
M<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B5S(&9E;&AA
M<WINX6SS(&YE;2!J;V=O<W5L="`E<RUR92XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1F5L
M:&%S>F[A;/-K(&%D;6EN:7-Z='+A;.%S82(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B1F5L
M:&%S>F[A;/-I(&)EX6QL[73A<V]K(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B0F5J96QE;G1K97KI<R!J
M;V=O<W5L='/A9R!I9^EN>6SI<V4B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+B(*;7-G<W1R("(B"B)%>F5N(&$@<F5N9'-Z97)E;B!N:6YC<R!E
M;F=E9.EL>65Z=F4@87H@^FH@9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-I
M("(*(FIO9V]S=6QT<^%GX6YA:R!I9^EN>6SI<V4N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N
M9"(*;7-G<W1R(")!>B!F96QH87-Z;N%L\VD@87IO;F]S[73S(&YE;2!T86SA
M;&AA=/,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z,34P"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,S('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE
M(@IM<V=S='(@(D9E;&AA<WINX6SS:2!NZ78B"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M
M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D$H>BD@7"(E<UPB
M(&9E;&AA<WINX6SS:2!NZ78@;>%R(&SI=&5Z:6LN(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`B1F5L:&%S>F[A;/-I(&[I=CHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(D9E;&AA<WIN
MX6SS:2!NZ78Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(D$@<F5N
M9'-Z97(@9F5L:&%S>F[A;/-I.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS
M9W-T<B`BW'IB96=I<WITX6XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L
M:6(O5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B02!61E,@86QK]FYY=G3A<B!N96T@;.ET
M97II:RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED
M(")686-A=&EO;B(*;7-G<W1R(")3>F%B861SX6<@86QA='1I(&%U=&]M871I
M:W5S(&5M86EL+7;A;&%S>B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-S`*
M;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T
M<B`B02!K]G9E=&ME>O4@:&5L>65K970@=&%LX6QT=6LZ("(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G
M<W1R("+)<G;I;GEE<W/I9R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(D%Z(.ER=.EK96ME="!P97)C8F5N(&%D:G5K(&UE9RP@;6]S=&%N=/-L('-Z
MX6WM='9A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C`@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(D$@Z7)T
MZ6L@;F%G>6]B8BP@;6EN="!A(&QE9VYA9WEO8F(@;65G96YG961E='0@:&]S
M<WKZ<^%G.B`E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T."!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(W,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,R,`HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-"!L:6(O2&]R9&4O1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(LER=.EK
M96LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$Y,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S
M='(@(E;A;&%S>G1H873S(.ER=.EK96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM
M<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")VX6QT;WKS(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM
M<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"XB"FUS9W-T<B`B(@HB02!H:71E;&5S[73I<R!N96T@<VEK97+\;'0@
M+2!L96AE="P@:&]G>2!A(&QE=F5L970@=F%L86MI(&UE9W;A;'1O>G1A='1A
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(E9E<GII\R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")6
M97)Z:?-K]G9E=.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS
M9W-T<B`B1OQG9RX@96QH96QY97KI<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I
M;F<B"FUS9W-T<B`B1OQG9_5L96=E<R!B96QS]2!M87)G\R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L.B(*;7-G<W1R(")F_&=G]6QE9V5S.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y($AI9V@B
M"FUS9W-T<B`B;F%G>6]N(&UA9V%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS
M9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW"FUS
M9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(G9I971N86UI("A6
M25-#24DI(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B5S(&UE9W1E
M:VEN=.ES92(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I
M97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B2_QL<_4@=V5B;VQD
M86P@;65G:F5L96[M=.ES92(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G
M<W1R(")*96QE;NUT<_QK(&UE9RP@;6EN="`E<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(D)R:70@5FER9VEN+7-Z:6=E
M=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
M06UE<FEK86D@5FER9VEN+7-Z:6=E=&5K(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B3.%T\W3A=F]L
M<^%G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I
M9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(DSA=/-TX79O;'/A9SH@(@H*(SH@
M;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B
M5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@271A
M;'D@<WIO;&?A;'1A=.%S(%--5%`M;B!K97)E<WIT_&PB"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@
M(E=!4DXB"FUS9W-T<B`B1DE'645,345:5$54R5,B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B
M1DE'645,345:5$54R5,A($O)6EI%3"!4P59/3,U44T$@14P@02!30U))4%1%
M5"`E<RU2U4PN(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S,PIM
M<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!S>F]L9^%L=&%TX7,@
M2%144"UN(.%T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T
M<B`B5V%L;&ES(.ES($9U='5N82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM
M<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")&:6=Y96QM97IT973I<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@
M(E=E(@IM<V=S='(@(E-Z92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("))9/5J
MX7+A<R!E;/5R96IE;'KI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G
M<W1R(")!>B!I9/5JX7+A<VD@861A=&]K(&9O<G+A<V$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.#DV"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S
M='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8FAE;'EE:R(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")H
M971E;G1E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`BW&1V]GKV;&K\:R(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(MQD=O9Z]FQJ_&LZ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(MQD=O9Z]FQJ_&LL
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(FYY=6=A="UE=7+S<&%I("A)4T\M
M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B;GEU9V%T+65U<O-P86D@
M*$E33RTX.#4Y+3$U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M(").>75G870M4WIA:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B36EL>65N(&%L
M:V%L;6%ZX7-T(&UU=&%S<V]N("5S(&$@8F5J96QE;G1K97KI<R!U=.%N/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")-:2!A>B!E
M;';A;&%S>G3S(&MA<F%K=&5R/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M(@IM<V=S='(@(DUI(&%Z(&EDZ7IE=&MA<F%K=&5R/R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8T"FUS9VED(")7:&5R96ES
M($%U<W1R86QI82!M87`B"FUS9W-T<B`B5VAE<F5I<R!!=7-Z='+A;&EA('3I
M<FOI<"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@
M<&AA<V5S(@IM<V=S='(@(DUE;'EI:R!C:6ML=7,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DUE;'EI:R!M
M;V1U;&]K870@86MT:7;A;&IU:R!A(%)I8V@@5&5X="!E9&ET;W)B86X_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B4WKI;&5S<^EG(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,3$*;7-G:60@(E=I9'1H(&EN($-34R!U;FET
M<R(*;7-G<W1R(")3>NEL97-SZ6<@0U-3(&5G>7/I9V)E;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(D$@)7,@;65N_"!S>NEL97-S
MZ6=E(&$@8F%L(&]L9&%L;VX@*&$@:_9V971K97KU(&)E:F5L96YT:V5ZZ7-T
M(&OV=F5T]65N(&QE<WH@(@HBZ7)VZ6YY97,I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R(")!('3A8FSA>F%T('-ZZ6QE<W/I9V4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM
M<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")!('-ZZ6QE<W/I9R!MZ7)TZ6ME
M9WESZ6=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R(")3>NEL97-SZ6<Z(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*
M;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM
M<V=I9"`B5VEN9"(*;7-G<W1R(")3>NEL(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R;'DB"FUS
M9W-T<B`B4WKI;"!A(')E9V=E;&D@\W+A:V)A;B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T
M<B`B4WKI;'-E8F5S<^EG(&-S;VWS8F%N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E-ZZ6PZ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(E-ZZ6PZ("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM
M<V=I9"`B5VES9&]M(@IM<V=S='(@(D+V;&-S97-SZ6<B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R
M(")+[7;A;G/A9VQI<W1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U
M"FUS9VED(")7;W)K(@IM<V=S='(@(DUU;FMA(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")-
M=6YK86AE;'EI(&/M;2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(DUU;FMA:&5L
M>6D@=&5L969O;B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE
M+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R(")!("5D+B!S;W)B86X@;F5M(&UE9V9E;&5L]2!A(&UE>O5K
M('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"XB"@HC.B!L:6(O1FEL92]#
M4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(DYE
M;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@5N%R=#H@)60L('1A;.%L=#H@
M)60N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92XB"FUS9W-T<B`B2&EBX7,@;V9F<V5T("@E9"D@82!61E,@9N%J;"!O;'9A
M<^%S86MO<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS
M9VED(")8+5)E9B(*;7-G<W1R("),:6YU>"!F;W)RX7-K\V0@:V5R97-Z<F5F
M97)E;F-I82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS
M9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S
M(&%L87!V973U(&MO<FSA=&]ZX7-O:R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E
M(@IM<V=S='(@(E@U,#EV,R!K:71E<FIE<WIT971T(&MU;&-S:&%S>F[A;&%T
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U
M,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S
M('1U;&%J9&]N;W,@86QT97)N873M=B!M96=N979E>NES92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@='5L86ID;VYO<R!K
M=6QC<V%Z;VYO<^UT\R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@
M:VET97)J97-Z=.ES96LB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B65DB"FUS9W-T<B`B65DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`B65E962(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO
M;R$@;6%P(@IM<V=S='(@(EEA:&]O(2!TZ7)KZ7`B"@HC.B!L:6(O2&]R9&4O
M36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`BZ79E
M;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B2F5M96XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B
M"FUS9W-T<B`B26=E;B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B
M26=E;BP@8F5L96=Y97IE;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RXB"FUS9W-T<B`B(@HB36]S="!(5$U,(%1%6%0@;?-D8F%N('9A;BX@
M2&%S>F[A;&IA(&$@6SP^72!G;VUB;W0L(&AA('9I<W-Z82!A:V%R(';A;'1A
M;FD@82`B"B)S>F]KX7-O<R!G<F%F:6MU<R`H5UE325=91RD@;65G:F5L96[M
M=.ES<F4N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E
M9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B3F5M
M(&AO>FAA="!LZ71R92`E9"!B;&]K:V[A;"!T]F)B970N(@H*(SH@;&EB+TAO
M<F1E+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+B(*;7-G<W1R(")!>B#6;B!F96QH87-Z;N%L\V%Z;VYO<^UTX7-A(&YE;2!T
M]G)TZ6YT(&UE9RXB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P.`IM
M<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B02!T96QJ97,@;NEV8F5N(&YE;2!S
M>F5R97!E;&AE="!A("=<7"<@:V%R86MT97(N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-SD*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B3F5M(&%D;W1T(&UE9R#I<G;I;GEE<R!E;6%I;"!C[6UE="XB"@HC.B!L
M:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@
M9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM
M<V=S='(@(B(*(DYE;2!A9'1A(&UE9R!A(&UE9V9E;&5L=&5TZ7-T(&%Z(&EM
M<&]R=.%L="!FX6IL(.ES(&$H>BD@)7,@;65Z]6D@:_9Z]G1T+B(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="XB"FUS9W-T<B`B4VEK97)E<V5N(&MI:F5L96YT:V5Z971T+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O
M;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB16=Y(&UO8FEL=&5L
M969O;G-ZX6UO="!K96QL(&UE9V%D;FEA+"!C<V%K(&$@<WKA;6IE9WEE:V5T
M+"!E<V5T;&5G(&5G>2`G*R<@(@HB:V%R86MT97)R96P@:V5Z9'9E+"!H82!N
M96UZ971K]GII('3A<F-SX7KA<VD@;?-D;W0@:^UVX6X@:&%S>F[A;&YI+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3DR"FUS9VED(")9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")%;&9O9V%D:&%T\R#I
M<G3I:V5T(&ME;&P@;65G861N:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB02!$871A
M5')E92!A;')E;F1S>F5R="!B92!K96QL(.%L;.UT86YI(&$@8F5J96QE;G1K
M97KI<VD@:F]G;W-U;'1SX6=O:R`B"B)I9^EN>6SI<^EH97HN(@H*(SH@;&EB
M+TAO<F1E+G!H<#HT-C(*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+B(*;7-G<W1R(")!(%9&4R!A;')E;F1S>F5R(&YI;F-S(&)E
MX6QL[71V82XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ
M,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*
M(D5L]6)B(&QE(&ME;&P@[7)N:6$L(&AO9WD@;6EL>65N('!R;V)LZ6WA="!T
M87!A<WIT86QT+"!M:65L]71T(&5L:_QL9&D@82`B"B)H:6)A:F5L96YTZ7-T
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;R(*;7-G<W1R(")-96<@:V5L;"!A9&YI(&5G>2!54DPM
M="P@86AO=F$@97H@82!L:6YK(&UU=&%T(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V
M97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B2VD@:V5L;"!VX6QA<WIT86YI
M(&5G>2!T]G)L96YD]2!S>F5R=F5R="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N(@IM<V=S='(@(DUE9R!K96QL(&%D;FEA+"!H;V=Y(&UE;'EI:R!F
M96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N:F$@=/9R]FQN:2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(DUE9R!K96QL(&%D;FEA(&%Z(&5L
M=.%V;VSM=&%N9/,@9F5L:&%S>F[A;/-I(&YE=F5T+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*
M;7-G<W1R(")-96<@:V5L;"!A9&YI82!A(&AO>GKA861A;F3S(&9E;&AA<WIN
MX6SS(&YE=NET+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R
M(")-96<@:V5L;"!A9&YI82P@:&]G>2!M96QY:6L@9F5L:&%S>F[A;/,@861A
M=&%I="!K[7;A;FIA(.%T[7)N:2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B365G(&ME;&P@861N:6$@96=Y('!A
M<F%N8W-O="XB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")-96<@:V5L;"!A9&YI82!A>B#Z:B!K871E9_-R:6$@
M;F5VZ70N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H
M;VYE(&YU;6)E<B(*;7-G<W1R(")/;&%S>F]R<WKA9VD@=&5L969O;G-ZX6UO
M="!K96QL(&UE9V%D;FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB07H@UFX@)7,@
M:V%P8W-O;&%T82!I9/5T^FQLZ7#I<R!M:6%T="!M96=S>F%K861T+B!+Z7)E
M;2!J96QE;G1K97IZ96X@8F4@^FIR82XB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(D%Z(-9N(&5M86EL(&/M;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(D%Z(-9N(&9E;&%D\VD@*$9R;VTZ*2!C[6UE.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")3>F5MZ6QY97,@
M:6YF;W)MX6-I\R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+B(*;7-G<W1R("(B"B)!>B#6;B`E<R!K87!C<V]L873A;F%K(&ME
M>F1E=&4@\W1A(&UE9W;A;'1O>F]T="!A>B!I;G1E<FYE="!C[6UE+B`B"B)"
M:7IT;VYSX6?A;F%K(.ER9&5KZ6)E;B!I<VWI="!B92!K96QL(&IE;&5N=&ME
M>FYI92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM
M<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(D%Z(-9N(&YE=F4B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG
M('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI
M<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@
M(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB07H@UFX@
M9F5L:&%S>F[A;/-A>F]N;W/M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE
M:&5T]7;I(&%Z(/IJ(&9E;&AA<WINX6SS:R`B"B)LZ71R96AO>N%SX70N($AA
M(&$@2&]R9&4@<F5N9'-Z97)R96P@:^UVX6YJ82!K97IE;&YI(&$@9F5L:&%S
M>F[A;/-I("(*(F%D871O:V%T+"!A:VMO<B!MX7-I:R!F96QH87-Z;N%L\V%Z
M;VYO<^UT\R!A;')E;F1S>F5R<F4@=F%N('-Z_&MSZ6=E+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)!>B#6;B!F96QH
M87-Z;N%L\V%Z;VYO<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U
M=ND@82!F96QH87-Z;N%L\VL@(@HB;&ES=.%ZX7/A="P@=F%G>2!V86QA;6D@
M;VMB\VP@;&5T:6QT;W1TX6L@97IT(&$@;&5H973U<^EG970N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B(*(D%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&UE9W;A;'1O>F]T="!A>B#6
M;B`E<R!M=6YK86MA<&-S;VQA=.%N86L@:V5Z9&5T92`B"B+S=&$N($)I>G1O
M;G/A9V$@Z7)D96OI8F5N(&ES;>ET(&)E(&ME;&P@:F5L96YT:V5Z;FEE+B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4U"FUS9VED(")9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(D%Z
M(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T:F$@97IT(&$@;&5H
M973U<^EG970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z
M-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*
M(G1O('!R:6YT+B(*;7-G<W1R("(B"B)!>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ
M82!N96T@=.%M;V=A=&IA(&5Z="!A(&YY;VUT873A<VD@;W!C:?-T+B!0<O-B
MX6QJ;VX@82`B"B)#=')L+5`@*'9A9WD@0V]M;6%N9"U0*2!L96YY;VWA<^%V
M86P@;GEO;71A=&YI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*
M;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(D$@:F5L
M96YL96<@Z7)VZ6YY97,@:63U>O-N83HB"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@
M8VAA;F=E9"XB"FUS9W-T<B`B07H@UFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN
M=&D@87IO;F]S[73S:F$@;65G=N%L=&]Z;W1T+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB
M"FUS9W-T<B`B07H@UFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S
M[73S:F$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B
M66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(D%Z(-9N('1E;&IE<R!N979E.B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@
M:&%S(&5X<&ER960N(@IM<V=S='(@(DQE:N%R="!A(&)E:F5L96YT:V5ZZ7-I
M(&IO9V]S=6QT<^%G82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F
M;W(@)7,@:7,Z("5S(@IM<V=S='(@(D%Z(-9N("5S+7)E(&AA<WINX6QT(/IJ
M(&IE;'-Z879A.B`E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34T
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(D%Z(-9N(/IJ
M(&)EX6QL[73A<V%I="#I<G;I;GEE<^UT971T_&L@82!M;W-T86YI(&)E:F5L
M96YT:V5ZZ7,@:61E:NER92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R(")!>B#6;B#Z:B!B9>%L;.UTX7-A:70@96QM96YT971T_&LN(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B07H@UFX@:F5L<WIA
M=N%T(.%TX6QL[71O='1U:R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B
M"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB07H@UFX@:F5L<WIA=N%T(.%TX6QL
M[71O='1U:RP@;NEZ>F4@;65G(&$@;&5V96QE:70L(&UA:F0@:F5L96YT:V5Z
M>F5N(&)E(&%Z("(*(OIJ(&IE;'-Z\W9A;"XB"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*
M;7-G<W1R(")!>B#6;B!J96QS>F%VX6YA:R!L96KA<G0@87H@Z7)VZ6YY97-S
MZ6=I(&ED96IE+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU
M.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B07H@UFX@
MX6QT86P@:&%S>F[A;'0@=.%V;VQI('-Z97)V97)E:SHB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<WILX79I82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS
M9W-T<B`B6F%I<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM.92!M
M=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E=%TB"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R
M(");2&EB86IE;&5N=.ES72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM
M<V=S='(@(EM-=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E="`M(@H*(SH@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T
M"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=(@IM<V=S='(@(EM-=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E
M="`M("5S('-O<ETB"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6R5S+R5S('-O
M<ETB"@HC.B!L:6(O2&]R9&4N<&AP.C$U-#4@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!
M9&UI;FES>G1RX6-I\R(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,
M22(*;7-G<W1R(")?4&%R86YC<W-O<B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM
M<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B4V]R=/9R;.ES(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]#<V]P;W)T;VLB"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")3
M95]G[71SZ6<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(D$@:^EP('1U;&%J9&]N<^%G86DN+BXB"@HC.B!L:6(O2&]R
M9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(D)E:F5L
M96YT:V5ZZ7,B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?
M3&]G(&]U="(*;7-G<W1R(")?2VEJ96QE;G1K97KI<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I
M9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(D$@;&EN:R!M\V1O<^UTX7-A
M+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO
M;G,B"FUS9W-T<B`B7T]P8VGS:R(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I
M9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]*;V=O<W5L='/A9V]K(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B02!L:6YK('3V
M<FSI<V4N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*
M;7-G<W1R(")?0F7A;&SM=.%S;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E3A8FSA>F%T('1U;&%J9&]N<^%G;VLB
M"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?
M1F5L:&%S>F[A;/-K(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C4*;7-G
M:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")C[6UJ96=Y>NEK(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R(")A(&/M;7IE='0@:7-M97)E=&QE;B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3$W"FUS9VED(")C86QE;F1A<B(*;7-G<W1R
M(")N87!TX7(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(FYY=6=O9'0B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T
M<B`B82!K:6UE;F5T:2#A;&QO;>%N>2!N96T@:&]Z:&%T\R!LZ71R92(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T
M(&]P96X@:6YP=70B"FUS9W-T<B`B82!B96UE;O4@X6QL;VWA;GD@;F5M(&YY
M:71H873S(&UE9R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU
M.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B:V%T=&EN='-O;B!I9&4B
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")P87)A;F-S<V]R:2!H
M:6)A(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(FMO;F9I9W5RX6-I\W,@
M:&EB82(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I
M9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")H:>%N
M>7II:R!E9WD@9F]N=&]S(')E;F1S>F5RX6QL;VWA;GDB"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R
M<F]R(@IM<V=S='(@(F%D871F;W)MX71U;2!H:6)A(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R(")M\V1O
M<^UTX7,B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G
M:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")A>B!A9&%T(&YE;2!T86SA
M;&AA=/,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")C<_9K:V5N(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.C@Y.`IM<V=I9"`B9FEL92(*;7-G<W1R(")F
MX6IL(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R
M("(E<R`H)7,I(&ERX6YY8O-L+"`E<R`E<R!S96)E<W/I9V=E;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B
M"FUS9W-T<B`B<WKI;&SV:^ES96LB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R(")M.B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@
M(FAH(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B82!GZ7`@
M;F5V92!N96T@:7-M97)T(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(F%Z;VYN86QI(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G
M<W1R(")I;G!U="]O=71P=70@:&EB82(*"B,Z(&QI8B](;W)D92]-24U%+TUE
M<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B
M"FUS9W-T<B`B8F5L<_4@<')O9W)A;6AI8F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S
M='(@(G-O<ETB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@HB07H@;6MS:6]F<R!P<F]G
M<F%M("5D(&AI8F%K\V1D86P@;&7A;&QT(&%Z($E33R#A;&QO;>%N>2!KZ7-Z
M[73I<V4@:_9Z8F5N+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-S`*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,0IM<V=I
M9"`B;F%M92(*;7-G<W1R(")NZ78B"@HC.B!L:6(O2&]R9&4O4E!#+G!H<#HQ
M,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")!('!R;V=R86UN
M86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I
M;7!L96UE;G1E9"(*;7-G<W1R(")!('!R;V=R86UN86L@97H@82!RZ7-Z92!M
MZ6<@;FEN8W,@;65G=F%L\W/M='9A+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(FIE9WEZ971T]FUB(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")S>N%Z86SI:R(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`B;FEN8W,@;65G9F5L96SU(&IO9V]S=6QT<^%G
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AE;"(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(F%D873A='9I=&5L:2`H<')O=&]K
M;VQL*2!H:6)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S0*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")E;65L:V5D:6LB"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I
M8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B82!S>F]L9^%L=&%TX7,@;F5M(.%L
M;"!R96YD96QK97KI<W)E(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ
M,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B;NEZ>OQK(&UE
M9R!A(&O\;/9N8G/I9V5K970B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T
M<B`B<VUS,F5M86EL('-Z;VQGX6QT873A<R!(5%10+6X@X70B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,PIM<V=I9"`B<W1E861Y(@IM<V=S='(@(G;A;'1O>F%T;&%N(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T
M96T@97)R;W(B"FUS9W-T<B`B<F5N9'-Z97)H:6)A(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")F96QA
M9&%T;&ES=&$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C8*
M;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(N%T;65N971I(&AI
M8F$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;2(*;7-G<W1R(")M96=E<O5S[73I<VOI;G0@:^ET<WIE<B#M<FIA
M(&)E(&$@:F5L<WKS="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA
M;65D(@IM<V=S='(@(F[I=B!NZ6QK_&PB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")A(&9E;&AA
M<WINX6SS(.%L=&%L(';A;&%S>G1H873S(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A
M<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R
M"FUS9VED(")W.B(*;7-G<W1R(")S>CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]F:5]&22YP;P``
M````````````````````````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M-S,R,C`P`#$P-3$U-#,Q,#8R`#`Q-C,T-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($9I;FYI<V@@=')A;G-L871I;VX@
M9F]R($AO<F1E+@HC($-O<'ER:6=H="`H0RD*(R!,965N82!(96EN;R`\;&EI
M;G5`=71A+F9I/BP@,C`P,2TR,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#(M,C<@,3DZ-3$K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP,BTR-"`Q,CHU.2LP,C`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^7&XB"B),86YG
M=6%G92U496%M.B!&:6YN:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B("@E<R!PY&EVY.0@<VET=&5N*2(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S
M<VME>2`E<RDB"FUS9W-T<B`B("A0:6MA;N1P<.1I;B`E<RDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("@E<R!PY&EVY'-SY"DB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(@*'3D;N3D;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&AU;VUE;FYA
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H
M>65S=&5R9&%Y*2(*;7-G<W1R("(@*&5I;&5N*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS
M9VED("(@870@(@IM<V=S='(@(B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@96D@;VQE(&AA:V5M:7-T
M;R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T
M<B`B7"(E<UPB(&5I(&ME;'!A82!V86QI;FYA:W-I+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@96D@;VQE(&%S96YN971T=2!(;W)D
M96X@<F5K:7-T97)I<W/D+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP
M.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E
M<B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!P=6ED96X@:W5V86%J86$@
M96D@;/9Y='EN>70N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@;&ESY'1T:6EN(')Y:&WD:N1R:F5S
M=&5L;>3D;BXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@;&ESY'1T:6EN(&]I
M:V5U:W-I:6XN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!E:2!L=6]T
M=3H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E
M+C)F)24I(@IM<V=S='(@(B4N,F9-0B!KY'ET971T>2`E+C)F34(@<V%L;&ET
M=7-T82`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S
M='(@(B5D("5S(&IA("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E
M<RXB"FUS9W-T<B`B4V%L87-A;F%S:2!V86YH96YT=74@)60@<.1I=N1N('#D
MY'-TY"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E
M9"!PY&EVY&X@96YN=7-T=7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T
M<B`B)7,@+2!);&UO:71U<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R
M:6YT(@IM<V=S='(@(B5S(%-O<FUE;FKD;&MI(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#0P(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*
M;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(%EL;.1P:71O=&]I;65N
M<&ET965T("T@5F%R;6ES='5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(&%S96YN=7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@:VER:F%U='5M:6YE;B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@:^1Y
M='3V96AD;W0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`B)7,@;VX@:F\@;VQE;6%S<V$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@
M)7,@)7,B"FUS9W-T<B`B)7,@<W5U;G1A("5S("5S(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB
M"FUS9W-T<B`B(@HB)7,@;VX@=F%L;6ES('-U;W)I='1A;6%A;B!Y;&SD<&ET
M;W1O:6UE;G!I=&5I=.0N(%9A;&ET<V4@=F%L:6YT87)U=61U:7-T82`B"B)S
M=6]R:71E='1A=F%T('1O:6UE;G!I=&5E="XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E
M<75I<F5D(@IM<V=S='(@(B5S(&]N('!A:V]L;&EN96XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU
M=&5S(@IM<V=S='(@(B5S(&UI;G5U='1I82(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!E:2!L]GET>6YY="XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S("T@)7,@+R`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S.FX@
M;W-O:71E:VER:F$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@
M(B5S.FX@:V%L96YT97)I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S
M='(@(B5S.FX@;75I<W1I;&ES=&$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T
M(@IM<V=S='(@(B5S.FX@=&5H=.1VY&QI<W1A(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y
M(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@
M9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B(@HB)7,@.B!4Y&WD('9I97-T:2!E:2!O;&4@=N1L='3D;>1T=.0@
M<VEL=.0@;.1H971TY&KD;'3D+"!J;VMA(&]N(&UE<FMI='1Y("(*(FSD:&5T
M=.1JY&MS:2X@4W5H=&%U9'4@=F%R875K<V5L;&$@=FEE<W1I<W/D(&]L979I
M:6X@;&EN:VME:6AI;B!J82!V87)O("(*(F%N=&%M87-T82!LY&AE='3D:N1L
M;&4@;6ETY.1N('EK<VEL]FEV:>0@=&EE=&]J82XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!P=75S:VET
M=&%I<W1A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG
M("5S("5S(@IM<V=S='(@(BP@<'5U<VMI='1A:7-T82`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A:6AT96QE=F%A
M("5S("T@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-S0X(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-S,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$S,@IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('9A;&ET<V4@
M+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@
M1F]R;6%T(@IM<V=S='(@(C$R+71U;FYI;B!JY')J97-T96QMY"(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,C0M='5N;FEN(&KD<FIE<W1E;&WD(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('1U
M;G1I82(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("(\161E;&QI;F5N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B5&EE=&]K86YT871A
M=7-T86KD<FIE<W1E;&WDY"!E:2!O;&4@;>3D<FET96QT>2!TY&QL92!O<VEO
M;&QE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C(*;7-G:60@
M(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(E1A<&%H='5I
M('9A:V%V82!V:7)H92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B5FEE<W1I;B!S86QA=6MS
M965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G
M92XB"FUS9W-T<B`B06QL96MI<FIO:71E='5N('9I97-T:6X@=&%R:VES='5K
M<V5E;B!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B)386QA='5N('9I97-T:6X@879A86UI<V5E;B!T87)V:71A86X@:G5L
M:VEN96X@4$=0+6%V86EN+"!S86QA:6YE;B!01U`M879A:6X@(@HB:F$@<V%L
M87-A;F%T96MS=&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E9I97-T:6X@86QL96MI<FIO:71T
M86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BP@<V%L86EN
M96X@4$=0+2(*(F%V86EN(&IA('-A;&%S86YA=&5K<W1I+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B(@HB5FEE<W1I;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK
M:6YE;B!3+TU)344M879A:6XL('-A;&%I;F5N(%,O34E-12UA=F%I;B!J82`B
M"B)S86QA<V%N871E:W-T:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E9I97-T:6X@
M86QL96MI<FIO:71T86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-
M12UA=F%I;BP@<V%L86EN96X@4R\B"B)-24U%+6%V86EN(&IA('-A;&%S86YA
M=&5K<W1I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E9I97-T:6X@<V%L875K<V5E
M;B!T87)V:71A86X@:G5L:VEN96X@4TU)344M879A:6XN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO
M=61S(@IM<V=S='(@(D%-(%!I;'9IY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM
M<V=S='(@(D%-(&ME=GET=.0@<V%D971T82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S
M='(@(D%-('-A9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")!32!S871E
M:71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")!32!L=6UI<V%T
M96ET82(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!
M32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S
M='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@
M(E1I971O:F$@961I=&]R:7-T82(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")4:65T;VIA+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM
M<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D%B<RX@86QI;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R(")!8G,N(&ME<VME;&SD(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")3:6YU;&QA(&5I(&]L
M92!O:6ME=6MS:6$@;'5O9&$@5D93+6AA:V5M:7-T;V$N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B4VEN=6QL82!E:2!O;&4@
M;VEK975K<VEA(&QU;V1A(%9&4RUT:65D;W-T;V$N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS
M9W-T<B`B2^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S
M='(@(DOD>71TY&KD='5N;G5K<V5N('-A;&%S86YA(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2^1Y='3D:N1T:6QI('-U;&IE='1U
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C
M8V]U;G1I;F<B"FUS9W-T<B`B2VER:F%N<&ET;R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M,0IM<V=I9"`B061D(@IM<V=S='(@(DQI<^3D(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL
M9"!'<F]U<"(*;7-G<W1R("),:7/DY"!A;&ER>6AMY"(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B3&ESY.0@86QI;VEK975S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("),:7/DY"!TY&CD;CHB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q
M.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("),:7/DY"!U=7-I(')Y
M:&WD(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B3&ESY.0@=75S:2!O:6ME=7,B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R
M("),:7/DY"!A;&ER>6AMY"!R>6AMY.1N(%PB)7-<(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(DQI
M<^3D(&%L:6]I:V5U9&5T(%PB)7-<(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P
M"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3&ESY.0@=75S:2!K
MY'ET=.1JY#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(DQI<^3D('-A
M<F%K92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*
M;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("),:7/DY"!U=7-I82!J
MY'-E;FGD(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I
M9"`B061D('!A:7(B"FUS9W-T<B`B3&ESY.0@<&%R:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(DQI<^3D
M("5S('9A;&EK:V\@36]Z:6QL86X@4VED96)A<B!O<VEO;VXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(DQI<^3D(&]S;VET96MI<FIA
M86XZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(DQI
M<^3D(&]S;VET96MI<FIA86YI.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS
M9VED(")!9&0@=7-E<B(*;7-G<W1R("),:7/DY"!KY'ET=.1JY"(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*
M(DQI<^1T=&EI;B!<(B5S7"(@:N1R:F5S=&5L;>3D;BP@;75T=&$@96D@=F]I
M(&QI<^1TY"!S:7/DY&YK:7)J875T=6UI<W!Y>6YN]FX@(@HB;&ESY'1I971O
M:F$Z("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RXB"FUS9W-T<B`B3&ESY'1T:6EN(%PB)7-<(B!JY')J97-T96QMY.1N
M+B!6;VET(&YY="!K:7)J875T=6$@<VESY.1N+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(DOD>71TY&II96X@;&ESY.1M:6YE;B!O;B!E
M<W1E='1Y+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U"FUS9VED(")!
M9&1R97-S(@IM<V=S='(@(D]S;VET92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")/<V]I
M=&5K:7)J82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDU"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<R(*;7-G<W1R(")6;VD@87-E='1A82!T86D@;>3D<FET96QL
MY"!O:6ME=6MS:6$@=&]I<VEL;&4@:^1Y='3D:FEL;&4B"@HC.B!A9&UI;B]I
M;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B66QLY'!I=&\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T
M<B`B36%I;F]K<V5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.`IM<V=I9"`B069G:&%N:7-T86XB
M"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$*;7-G:60@(D%L8F%N
M:6$B"FUS9W-T<B`B06QB86YI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0*;7-G:60@(D%L9V5R
M:6$B"FUS9W-T<B`B06QG97)I82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L
M:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B5&%S86$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED
M(")!;&EG;FUE;G0Z(@IM<V=S='(@(E1A<V%U<SHB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")+86EK:VDB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R(")+86EK:VD@875T96YT:6MO:61U="!KY'ET=.1JY'0B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(DMA:6MK:2!R>6AMY'0B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$*;7-G:60@(D%L;"!097)M:7-S
M:6]N<R(*;7-G<W1R(")+86EK:VD@;VEK975D970B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!
M;&P@9F]U<B!S:61E<R(*;7-G<W1R(")+86EK:6QT82!N96QJY&QTY"!S:79U
M;'1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E-A;&QI(&UO;F5T
M(&]S;VET=&5E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(E-A;&QI(&KD<FIE<W1E='EN(&QI<W1A;B!T>7EP:6X@87-E='5S+B(*
M"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM
M<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B3VX@:F\@;VQE;6%S<V$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA
M=&4@24U34"!,;V=I;B(*;7-G<W1R(")686EH=&]E:'1O:6YE;B!)35-0+7-I
M<^3D;FMI<FIA=71U;6EN96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")6
M86EH=&]E:'1O:6YE;B!)35-0+7-A;&%S86YA(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B5F%I:'1O96AT;VEN96X@24U34"UKY'ET=.1JY'1U;FYU<R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")686EH=&]E:'1O:7-E="!S
MY&AK]G!O<W1I;W-O:71T965T(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B5F%I:'1O
M96AT;VES970@;6%L;&ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@
M=&5X=#HB"FUS9W-T<B`B5F%I:'1O96AT;VEN96X@=&5K<W1I.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C<*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(EEH9'ES=F%L
M=&%I;B!386UO82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B06YN971T
M=2!A<G9O(&5I(&ME;'!A82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+B(*;7-G<W1R(")T87!A:'1U:2!T=6YT96UA=&]N('9I<FAE+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U
M<R!0<F]X>2(*;7-G<W1R(")!;F]N>7EM:2!P<F]X>2(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M5F%S=&%U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B06YT87)K=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.0IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&IA($)A<F)U9&$B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,S8@861M:6XO=&5M<&QA=&5S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S
M='(@(D]H:F5L;6$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G
M:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B3VAJ96QM86QI<W1A(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I
M;VX@:7,@<F5A9'DN(@IM<V=S='(@(D]H:F5L;6$@;VX@=F%L;6ES+B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T
M;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B3&%I=&$@:^1Y='3V]FX@:V%I:VMI
M(&%L:6IA:V]I:&EN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B2'EVY&MS>2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,`IM<V=I9"`B
M07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")!<G9I;VET=2!K;VMO(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@
M(D%P<FEL(@IM<V=S='(@(FAU:'1I:W5U(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M(")!<F%B:6$@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-@IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B
M4&%K971I;B!K;VMO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*
M;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")086ME=&EN(&YI;6DB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D]L
M971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82!S:7/DY&YK:7)J875T
M=6UI<W!Y>6YN]FX@)7,@/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P
M<S\B"FUS9W-T<B`B3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!P;VES=&%A
M(%PB)7-<(B!J82!K86EK:VD@<V5N(&%L:7)Y:&WD=#\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B06=E;G1I:6YA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,@IM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FUE;FEA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)
M+3@I(@IM<V=S='(@(D%R;65N:6$@*$%235-#24DM."DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")486ED92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N
M($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I;VX@<V%A<F5T(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B
M07-C:6DM=&%I9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07-I86XO
M5'EY;F5N;65R96X@86QU92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")+>7-Y('9A<FUI<W1U
M<R!E;FYE;B!K=6EN('1E:&3DY&X@>6QLY'!I=&]T;VEM96YP:71E970N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B07-S:6=N
M;65N="!C;VQU;6YS(@IM<V=S='(@(E1E:'3D=N1S87)A:VME970B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B67)I=&5T=&EI;B!P;VES
M=&%A(&]L96UA=&]N=&$@<GEH;>3D+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(EER:71E='1I:6X@<&]I<W1A82!O
M;&5M871O;G1A(&]I:V5U='1A+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B67)I=&5T=&EI;B!M=6]K871A(&]L96UA=&]N
M=&$@;VEK975T=&$N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M(@IM<V=S='(@(EER:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&IA:V]A
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"FUS9VED(")!='1R
M:6)U=&5S(@IM<V=S='(@(DQI<^1MY.1R:71Y:W-E="(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`B96QO:W5U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.0IM<V=I9"`B075S=')A;&EA
M(@IM<V=S='(@(D%U<W1R86QI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`B273D=F%L=&$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q
M;#H@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@
M(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@5&%U<W1A:N1R:F5S
M=&5L;>0@96D@='5E('1A<G9I='1A=FEA(&]M:6YA:7-U=6MS:6$N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S
M=&$@96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N
M<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!T87)V:71T
M879A82!&5%`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N($ODY&YNY"!02%`@
M:^1Y='3D96X@+2TB"B)E;F%B;&4M9G1P(&%S971U<W1A+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VEM87`Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y
M='EN>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM
M<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@5&%R=FET=&%V86$@:W)B-2UL
M86%J96YN=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R(")!=71H7VQD87`Z(&OD>71TY&II96X@;&ESY.1M:6YE;B!!8W1I=F4@
M1&ER96-T;W)Y>6X@96D@;VQE('1U971T=2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B075T:%]L9&%P.B!+Y'ET=.1J:65N('!O:7-T86UI96YN($%C
M=&EV92!$:7)E8W1O<GES=.0@96D@;VQE('1U971T=2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)!=71H7VQD87`Z($5I('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N
M(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DZ("(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#H@16D@=F]I9&$@<&]I<W1A82!KY'ET=.1JY.0@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<R(*;7-G<W1R(")!=71H7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET
M=.1JY.0@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P
M-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD
M87`Z($OD>71TY&II96X@<.1I=FET=.1M:6YE;B!!8W1I=F4@1&ER96-T;W)Y
M>6X@96D@;VQE('1U971T=2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC
M86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!487)V:71T
M879A82!-0T%,+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H
M.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?<VUB875T:#H@5&%R=FET=&%V86$@<VUB875T:"UL86%J96YN
M=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%D
M;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT:6MO:6YT:2!)34%0+7!A;'9E
M;&EM96QL92!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R(")!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<R(*;7-G<W1R(")!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I
M+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@4D%$2553+7!A;'9E;&EM96QT
M82!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@X,@IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@1E10+7!A;'9E;&EM96QL92!E
M<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P
M"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@4TU"+7!A;'9E;&EM96QL92!E
M<.1O;FYI<W1U:2XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U
M"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")+Y'ET971TY'9I
M<W/D;VQE=F%T(&ME;G3D=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(D%Z97)B86EZ9&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"!S
M96QI='EK<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")4
M875S=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(E1A=7-T
M87;D<FDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS
M9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(E;DY'+D(&ME
M<F)E<F]S('-A;&%S86YA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T
M<B`B5N3D<N0@:V5R8F5R;W,@:^1Y='3D:N1T=6YN=7,N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-0IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X
M"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB
M"FUS9W-T<B`B0F%L=&EA("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T"FUS
M9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,S"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")'<F%F:6EK;VED96X@<&5R=7-H86ME;6ES=&]A(%PB)7-<(B!E:2!L
M]GET>6YY="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3D*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(E!E<G5S
M=FEI=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Y"FUS9VED(")"96QA<G5S(@IM<V=S='(@(E9A
M;&MO+59E;N1JY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4*;7-G:60@(D)E;&=I=6TB"FUS9W-T
M<B`B0F5L9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@
M(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#`*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E
M;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,0IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M
M=61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-@IM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(E-Y;G1Y;>1PY&EVY"(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D]S:6]T82!<(B5S7"(@;VAJ
M96QM86QL92!<(B5S7"(@96D@;/9Y='EN>70N(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G
M<W1R(")/<VEO;B!A<V5T=6MS970B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B3W-I;VX@
M='EY<'!I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(DQI:&%V;VET=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*
M;7-G<W1R(")+:7)J86YM97)K:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS
M9W-T<B`B4F5U;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R
M(")2975N86X@=F%H=G5U<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(E)E=6YA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(*;7-G:60@(D)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$B"FUS9W-T<B`B0F]S;FEA($AE<GIE9V]V:6YA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(DUO
M;&5M;6%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B
M0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*;7-G<W1R(")!;&EN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V
M970@<V%A<F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-`IM<V=I9"`B0G)A>FEL(@IM<V=S='(@
M(D)R87-I;&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<*;7-G:60@(D)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET86YN:6%N($EN=&EA;B!V
M86QT86UE<F5N('1E<G)I=&]R:6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-A;&%M(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-PIM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS
M9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E!A;&QU:VMA;&ES=&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN
M82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"
M=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),+6IA:V5L=6]S
M;VET=&5E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")37V]L=6X@=&EE9&]T+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"XB"FUS9W-T<B`B5N1L:6UU:7-T:6X@86QU<W1U<R!E:2!V86QM
M:7-T=6YU="XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@U(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$V"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P-#`*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N=&5R:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A
M;&TB"FUS9W-T<B`B5'EY;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.`IM<V=I9"`B0V%M8F]D
M:6$B"FUS9W-T<B`B2V%M<'5T<V5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,`IM<V=I9"`B0V%M
M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R(")386QA<V%N86$@96D@=F]I('1Y:&IE;G3DY"!A=71O;6%A='1I<V5S
M=&DL(&]T82!Y:'1E>71TY"!Y;&SD<&ETY&KDY&XN(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B16D@=F]I(&MI
M<FIO:71T86$@=&EE9&]S=&]O;B!<(B5S7"(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B56QK;VES:6$@:7-T=6YT;VOD<VET
M=&5L:6KV:73D(&5I(&]L92!M86AD;VQL:7-T82!H86QL:71A+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DE-05`M
M<&%L=F5L:6UE96X@96D@<V%A='4@>6AT97ET=.0Z("5S(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('9O:2!A=F%T
M82!T:65D;W-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$*;7-G:60@(D-A;F%D
M82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M
M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R(")097)U(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M(")097)U(&]N9V5L;6%V:65S=&DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A('1I961O
M<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-#8*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5N1L:6%I:V%I<VAA:V5M:7-T;V$@96D@
M;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R(")%:2!V;VED82!J871K86$@
M:6QM86X@)W1A<F=E=$9I;&4G("UP87)A;65T<FEA+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I
M9&$@<&]I<W1A82!H86ME;6ES=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(D5I('9O
M:61A('!O:7-T86$L("5D(&%L:71A<V]J82!O;&5M87-S82XB"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*
M(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*
M;7-G<W1R("(B"B)%:2!V;VD@=75D96QL965N:N1R:F5S=.3D+"!A;FYE='1U
M:F5N('1I971U96ED96X@;>3D<N0@96D@=F%S=&%A("(*(G1A;&QE=&5T='5J
M96X@=&EE='5E:61E;B!MY.1RY.0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(")%:2!V
M;VD@;VAJ871A('9I97-T:>0@86YN971T=75N(&YU;65R;V]N+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C4*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")+=79A=&5K<W1I(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS
M9VED(")#87)R:65R(@IM<V=S='(@(E!A;'9E;'5N=&%R:F]A:F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD
M($QA8F5L<R(*;7-G<W1R(")+871E9V]R:6%T(&IA(&]T<VEK;W0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N
M('-A87)E="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B4'5H96QI;BA'
M4TTI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E-O
M;'5N('1I961O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(E-O
M;'5N('3D>71E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G
M<W1R(")3;VQU;B!T:65D;W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R(")3;VQU;B!VY&QY<SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36%T:V%P=6AE;&EN
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H
M25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1T:2`H25-/+3@X-3DM,30I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(DME<VMI=&5T='DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4T"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B2V5S:VDM069R:6MA;B!T87-A=F%L=&$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B2V5S:VDM175R;V]P<&$@*$E33RTX.#4Y+3(I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E
M<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B5F%R;65N=&5E;B!T:65D;W0B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I
M9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B5F%R;65N=&5E;B!O;6ES
M=&%J82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW
M"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")687)M96YT
M965N('!O;&ET:6EK870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$*;7-G:60@(D-H860B"FUS
M9W-T<B`B5'-A9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG
M92(*;7-G<W1R(")-=75T82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M5F%I:&1A('-A;&%S86YA<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"B)6;VET(&UU=71T86$@;.1H971TY&UI
M<W/D<VD@<^1H:_9P;W-T96ES<V$@;N1K>79IY"!N:6UI+2!T86D@;W-O:71E
M=&EE=&]J82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*
M;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB4V%L87-A;F%N
M('9A:6AT;R!E:2!O;&4@:^1Y=/9S<^0@;GEK>6ES:6QLY"!A<V5T=6MS:6QL
M82X@3W1A('EH=&5Y='3D("(*(GEL;.1P:73D:FEI;BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED
M(")#:&%R(@IM<V=S='(@(DUE<FMK:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K
M($QI;FLN+BXB"FUS9W-T<B`B5&%R:VES=%]A(&QI;FMK:2XN+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2VEI;F$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I(@IM<V=S='(@(DMI:6YA('EK<VEN:V5R=&%I<W1E='1U("A'0C(S,3(I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@
M5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(DMI:6YA('!E<FEN=&5I;F5N
M("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@
M(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B5F%L:71S92!O:&IE;&UA
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I
M9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B5F%L:71S92!S86QA<V%N
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G
M:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(E9A;&ET<V4@:^1Y='3D
M:N1T=6YN=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED
M(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E9A;&ET
M<V4@<.1I=N1MY.1R:65N(&5S:71Y<V%S=3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS
M9W-T<B`B5F%L:71S92!L:7-T86X@='EY<'!I("AJY')J97-T971Y:6QL92!L
M:7-T;VEL;&4I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-@IM<V=I9"`B0VAR:7-T;6%S($ES;&%N
M9"(*;7-G<W1R(")*;W5L=7-A87)E="(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HY,30@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(DQU;VMK86WDY')I='ES=.0@)7,@96D@;/9Y='EN>70N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*
M;7-G:60@(D-L96%R(@IM<V=S='(@(E-E;&MEY"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U3
M3V9F:6-E('1A9W,B"FUS9W-T<B`B4&]I<W1A($U33V9F:6-E('1A9VET(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E<GDB
M"FUS9W-T<B`B4&]I<W1A(&MY<V5L>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U
M="!U<V5R.B`E<R(*;7-G<W1R(")0;VES=&$@:^1Y='3D:N0Z("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A
M<B!U<V5R(@IM<V=S='(@(E!O:7-T82!KY'ET=.1JY"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A
M=&$B"FUS9W-T<B`B4&]I<W1A(&OD>71TY&KD;B!T:65D;W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE
M87)I;F<@3&%T92(*;7-G<W1R(")396QK96YE=N3D(&UY]FCDY&XB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I
M9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B3F%P<V%U=&$@:F%T:V%A
M:W-E<VDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B0VQI:V%T96QL($A45%`Z;B!K875T=&$B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G
M:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")3=6QJ92!I:VMU;F$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@
M(E!I;'9IY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B4&EL=FEN96X@
M86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(E!I;'9I;F5N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,@IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T
M<B`B2V]O:V]S("A+965L:6YG*2!S86%R970B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM
M<V=S='(@(E!I96YE;F[D('-I=G5V86QI:VMO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4&EE;F5N;F5T>70@<F5U;F%T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,@IM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L=6UB:6$B
M"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B5N1R:2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#,*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S-0HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,V('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME
M<B(*;7-G<W1R(")6Y')I=F%L:71S:6XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#,R"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(E;D<FEV86QI;G1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(E-A<F%K.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M
M;B!T:71L97,B"FUS9W-T<B`B4V%R86MK96ED96X@;W1S:6MO="(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R(")387)J86MU=F%T(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(V"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(DMO;65N=&\B"@HC.B!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B2V]M
M96YT;W1U;&MK:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUM96YT=&DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`B66QE:6YE;B!N:6UI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`*
M;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)I="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A
M;GDB"FUS9W-T<B`B67)I='ES(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B5&EE=&]K;VYE970B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD
M:71I;VXB"FUS9W-T<B`B3VQO<W5H9&4B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")/;&]S=6AT965T
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B07-E='5K<VEE;B!E<F]T(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/
M=71L;V]K+B(*;7-G<W1R(")!<V5T=6MS970@4$1!+6QA:71T96ED96XL(.1L
M>7!U:&5L:6UI96X@:F$@3W5T;&]O:VEN('-Y;FMR;VYO:71I:6XN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B07-E='5K<VEA('!I=.3D('#D
M:79I='3DY"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")!<V5T82!A
M<V5T=6MS970@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E9A:'9I
M<W1A(&MI<FIO:71T86UA;&QA('-A;&%S86YA('5U9&5S=&%A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-34*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,PIM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R(")+;VYG;VX@9&5M;VMR86%T=&EN96X@=&%S879A;'1A(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DX"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0IM<V=I
M9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(EEH=&5Y<R!E<.1O;FYI
M<W1U:2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`Y"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(EEH=&5Y
M<R!E<.1O;FYI<W1U:3H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(EEH=&5Y<R!J=6QK:7-T96X@879A
M:6YT96X@<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")9:'1E>7,@:G5L:VES=&5N(&%V
M86EN=&5N('!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X@5FER:&4Z("5S("@E
M<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B66AT
M97ES(&9T<"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(EEH=&5Y<W1I961O="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM
M<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(EEH=&5Y<W1I961O="!L:7/D='1I
M:6X@;W-O:71E:VER:F%A<VDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R
M97-S960@9FEL93H@(@IM<V=S='(@(E1I:79I<W1E='EN('1I961O<W1O;B!T
M>7EP<&DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(EPB
M)7-<(CIN('-I<^1L=/8B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S,@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O
M;G1I;G5E(@IM<V=S='(@(DIA=&MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.`IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(D-O;VL@<V%A<F5T(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B17;D<W1E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&EO:2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")+;W!I;VEN=&D@97#D;VYN
M:7-T=6DZ("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P
M:6]I('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R(")#;W-T($E$(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-PIM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(").
M;W)S=6YL=75R86YN:6MK;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4Z("(*;7-G<W1R(")6:65S=&EN(%!'4"US86QA=7-T82!E:2!V;VET=2!T
M96ADY#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U
M-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R
M(")6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4$=0+6%L;&5K:7)J;VET
M=7-T83H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R(")6:65S=&EN(%,O34E-12US86QA=7-T82!E:2!V;VET=2!T96AD
MY"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(E9I97-T:6EN(&5I('9O:71U(&UU;V1O<W1A82!3+TU)344M86QL96MI<FIO
M:71U<W1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B16D@=F]I='4@;W1T86$@>6AT97ET
M=.0N("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("),9&%P+7!A;'9E;&EM965N(&5I('-A871U
M(&%U=&]R:7-O:71U82!Y:'1E>71TY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@
M(D5I('9O:71U('1A<FMI<W1A82!S86QD;V$N("5S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`M<&%L=F5L:6UE96X@96D@<V%A
M='4@>6AT97ET=.0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")%:2!V;VET=2!O='1A
M82!Y:'1E>71TY"!P86QV96QI;65E;B!<(B5S7"(@:^1Y='3D96X@1E10.B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('9O:71U(&QU;V1A
M(&IA:V5L=6QI<W1A82X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@(@IM<V=S='(@(E!'4"US86QA='1U82!T:65T;V$@96D@=F]I='4@875K
M86ES=&$Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS
M9W-T<B`B4R]-24U%+7-A;&%T='5A('1I971O82!E:2!V;VET=2!A=6MA:7-T
M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(D5I('9O:71U('!O:7-T86$@>6AT97ES
M=&EE=&]A+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('9O
M:71U('!O:7-T86$@:F%K96QU;&ES=&%A+B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M(")%:2!V;VET=2!P;VES=&%A('#D:79I='ES<VMR:7!T:>0@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM
M<V=S='(@(E9I97-T:6X@;.1H971TY&KD;B!SY&AK]G!O<W1I;W-O:71E='1A
M(&5I('!Y<W1Y='1Y(&WDY')I='1E;&5MY.1N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")%
M:2!V;VET=2!H86ME82!K;VMO(&]S;VET96MI<FIA82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R(")%:2!V;VET=2!H86ME82!K;VMO(&IA:V5L=6QI<W1A82XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T
M-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B16D@=F]I='4@:&%K96$@
M:V]K;R!L:7-T86$@:F%K96QU;&ES=&]I<W1A+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VET
M=2!L=6ME82!S=')A=&5G:6%A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C
M="YP:'`Z,S`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(")+;VUE
M;G1O(&UK9&ER(%PB)7-<(B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DIU
M;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L=&$@96D@<V%A='4@:G5L:VES
M=&$@879A:6YT82XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B5&EE9&]S=&]O;B!<(B5S7"(@96D@=F]I(&MI<FIO:71T
M86$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M("5S+B(*;7-G<W1R(")%:2!V;VET=2!A=6MA:7-T82`E<RXB"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<R(*;7-G<W1R(")9;&SD<&ET;VUO9'5U;&EN("5S(&%U:V%I
M<W4@97#D;VYN:7-T=6DB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B16D@=F]I(&%U:V%I<W1A(&AA:V5M:7-T;V$@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4"UP86QV96QI;65L
M=&$@96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(E<SKDY"!E:2!V;VET=2!L=6ME
M82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B
M(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(DOD>71TY&KD;B!S86QA<V%N86$@96D@=F]I='4@;F]L;&%T82X@2F]T
M:W5T('1A<G9I='1A=F%T('1I961O="!O=F%T(';DY')I;BX@(@HB67)I=.0@
M=75D97-T86%N('1A:2!O=&$@>6AT97ET=.0@>6QLY'!I=&]O;B!J;W,@=&%R
M=FET<V5T(&QI<^3D(&%P=6$N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R(")%:2!V;VET=2!H86ME82!!0TPM=&EE=&]J82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(D5I('9O:71U(&AA:V5A(&]S;VET96MI<FIA82X@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('9O:71U(&AA:V5A
M(&IA:V5L=6QI<W1A82X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G
M<W1R(")%:2!V;VET=2!H86ME82!J86ME;'5L:7-T;VIA+B`E<R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3@*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(R"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(D5I('9O:71U(&AA:V5A('1I971O:F$@<&%L=F5L:6UE;B!T;VEM:6YN;VES
M=&$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D5I('9O:71U
M('!A;&%U='1A82!A<V5T=6MS:6$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N
M(@IM<V=S='(@(DMO;65N=&\@<FUD:7(@7"(E<UPB(&5PY&]N;FES='5I+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(D5I('9O:71U('1A;&QE='1A82`E<R!A<V5T=6MS:6$N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8S"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN(@IM<V=S='(@(D5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R
M;75U<VMO<&EO=&$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B16D@=F]I='4@=&%L;&5T=&%A(&%S
M971U<W1E;B!V87)M=75S:V]P:6]T82`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@
M(D5I('9O:71U('1A;&QE='1A82!A<V5T=7-PY&EV:71Y<W-K<FEP=&GD.B!<
M(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B16D@=F]I='4@=&%L;&5T=&%A
M(&%S971U<W1E;B!V87)M=75S:V]P:6]T82`E<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*(D%S971U<W1I961O<W1O;B`E<R!T86QL
M971U<R!E<.1O;FYI<W1U:2X@5F]I="!KY'ET=.3D(&IO=&%K:6X@87-E='5S
M=&$@(@HB=&%L;&5T=&%A:W-E<VD@:V]O9&EN('1A:V%I<VEN("5S('1A:2!T
M86D@:V]P:6]I9&$@:^1S:6X@86QL82!O;&5V86X@:V]O9&EN("(*(G1I961O
M<W1O;VX@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("),1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES=&$@
M971S:>0N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")+;VUE
M;G1O('5N;&EN:R!<(B5S7"(@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G
M<W1R(")%:2!V;VET=2!PY&EV:71TY.0@>6AT97ES=&EE=&]J82X@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")%:2!V;VET=2!PY&EV:71TY.0@
M:F%K96QU;&ES=&%A+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG
M=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(")6:65S=&5JY"!E:2!V
M;VET=2!P;VES=&%A(&MA;G-I;W-T82!<(B5S7"(Z("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B36]Z:6QL82!3:61E8F%R(&5I(&SV>71Y;GET+B!687)M
M:7-T82!E='3D(%-I9&5B87(@;W-I;R!O;B!A=6MI+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@HB2^1Y='3D:N1L;&4@7"(E<UPB(&5I('9O:71U(&%N=&%A('-E=7)A
M879I82!O:6ME=7-I82!K86YS:6]O;B!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT(@IM
M<V=S='(@(DQA<VME='1U('1E:W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(DUA
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O
M=7)S97,B"FUS9W-T<B`B2W5R<W-I="(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(DQU;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN
M:R(*;7-G<W1R("),=6\@=75S:2!L:6YK:VDB"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@
M;VYE(@IM<V=S='(@(DQU;R!U=7-I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R(")6;VD@;'5O9&$@=75S:6$@:V%N<VEO:71A(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B3VEK975D970@=&5K:6KD;&SD(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Q-@IM<V=I9"`B0W)E9&ET(&-A<F0@
M;G5M8F5R(@IM<V=S='(@(DQU;W1T;VMO<G1I;FYU;65R;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8T"FUS9VED(")#=6)A(@IM<V=S='(@(DMU=6)A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(E3D;>1N:&5T:VEN96X@-"!V86EH971T82(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")4Y&WD
M;FAE=&MI<V5T(&ES='5N;F]T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@
M;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS
M9W-T<B`B2V5L;&]N86EK82!TY&QLY"!H971K96QLY"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I
M9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B5.1MY&YH971K:6YE;B!54DP@
M;VXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@
M57-E<G,B"FUS9W-T<B`B5.1MY&YH971K:7-E="!KY'ET=.1JY'0B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B
M"FUS9W-T<B`B5.1MY&YH971K:6YE;B!SY.0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@
M(@IM<V=S='(@(E3D;>1N:&5T:VEN96X@=&EL83H@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R(")4Y&WD;FAE=&MI;F5N('1Y>6QI(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S
M='(@(B(*(E9O:70@;75O:V%T82!T96ATY'9IY"P@:F]T:V$@<W5O<FET971A
M86X@:W5N(&MI<FIA=61U=&%A;B!S:7/DY&X@;VAJ96QM86%N("4B"B)S+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DQE:6MK86$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#
M=70@<V5L96-T:6]N(@IM<V=S='(@(DQE:6MK86$@=F%L:71T=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C<*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")+>7!R;W,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB
M"FUS9W-T<B`B2WER:6QL:6YE;B`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R(")+>7)I;&QI;F5N("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*2(*;7-G<W1R(")+>7)I;&QI;F5N+U5K<F%I;F$@*$M/23@M52DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8X"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")4
M<V5K:6X@=&%S879A;'1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`B4%`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C<V"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*(D133B`H;&ESY'1I971O82!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BXB
M"B)P:'`I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B4.1I=FET=.1I;B(*"B,Z
M(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E
M<B(*;7-G<W1R(")$871A5')E92US96QA:6XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C<T"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T
M<B`B5&EE=&]K86YT86AA:W4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,#(*;7-G:60@(D1A=&4B"FUS9W-T<B`B4.1I=N1Y<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(E#D:7;D;>3D<N0@=F%S=&%A;F]T971T=2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3,*;7-G:60@(D1A=&4@<V5L96-T
M:6]N(@IM<V=S='(@(E#D:7;D;>3D<N1N('9A;&EN=&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")0Y&EVY"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B4&]?:7-T82!S87)A
M:V4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B:F]U;'5K=74B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5S:6UA86QI;G5M
M97)O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")0:65N96YN
MY"!S:7-E;FYY<W3D(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T
M<B`B3VQE='5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B3VQE
M='5S=N1R:2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B3VQE='5S<')O
M9FEI;&DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E
M9F%U;'0@4VAE;&PB"FUS9W-T<B`B3VQE='5S(&MO;65N=&]T=6QK:VDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS
M(@IM<V=S='(@(DWDY')I=&5L;>1T(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E!O
M:7-T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B4&]I
M<W1A('-O;'4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U
M<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E!O:7-T
M82!R>6AMY"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM
M<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")0;VES=&$@;&]K:2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM
M<V=S='(@(E!O:7-T82!O:6ME=7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<R(*;7-G<W1R(")6;VD@<&]I<W1A82!J82!T=6AO=&$@<&]I<W1E
M='1U:F$@=FEE<W1E:N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G
M<W1R(")0;VES=&$@<V]L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB
M"FUS9W-T<B`B4&]I<W1A('-A<F%K92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(E!O:7-T82!O;&5M87-S82!O;&5V870@=F%I:'1O96AT
M;VEN96X@;6%L;&DB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(E9O
M:2!P;VES=&%A('9I97-T96KD(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4&]I<W1A(%PB)7-<(CIN(&]I
M:V5U:W-I82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")/;&5T
M:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@7"(E<UPB(&IA(&MA:6MK
M:2!S96X@86QI;VEK975D970_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*
M;7-G<W1R(")0;VES=&$@<FEV:2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>2(*;7-G<W1R(")0;VES=&$@=F%L:71T=2!P<F]F:6EL:2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$
M96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B5F]I(&QU;V1A('5U<VEA(&MA
M;G-I;VET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(*;7-G<W1R(")0;VES=&$@=F%L:71T=2!S87)A:V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4&]I<W1A
M('9A;&ET='4@<FEV:2(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")0;VES=&5T='4@<.1I=FET>7-S:W)I
M<'1I(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"FUS9VED(")$96QI=F5R>2!T
M:6UE(@IM<V=S='(@(E1O:6UI='5S86EK82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$*;7-G:60@
M(D1E;FUA<FLB"FUS9W-T<B`B5&%N<VMA(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(D]N9V5L;6%N(&MU=F%U<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")+
M=79A=7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-PIM<V=I
M9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R
M(")487)K96UM870@=&EE9&]T("AL]GET>7;D="!M>?9S($AO<F1E.FX@;&]K
M:71I961O<W1O<W1A*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C(P,0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B5&%R:V5M;6%T('1I961O="!O;B!T
M86QL971E='1U('EL;.1P:61O;B!KY'-I=&5L=.1VY&MS:2XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*
M;7-G<W1R(")+96AI='ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*
M;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")+;W-T975S<&ES=&4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R(")%9&5L;&ES96X@='5N;FEN(&MO<W1E=7-P
M:7-T93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM
M<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B2V]S=&5U<W!I<W1E.B`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS
M9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3=75N=&$@
M=F%S96UM86QT82!O:6ME86QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T
M;R!L969T(@IM<V=S='(@(E-U=6YT82!O:6ME86QT82!V87-E;6UA;&QE(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*
M;7-G<W1R(")(86ME;6ES=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(DOD
M>73D(#(T+71U;FYI;B!A:6MA97-I='ES=.0N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(D[D:WEMY&X@87-E='5K<V5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(D5S:71Y<W1A<&$@>6MS:71Y:7-K;VAT86EN96X@96YN=7-T92(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B17-I='ES=&%P82!E;FYU<W1E96QL92`H
M5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#,*;7-G:60@
M(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D5S:71Y<W1A<&$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B4&5R:6QL96UE;F]I;&UO:71U<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S`*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)O=71I
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B16D@<V%A('!O:7-T86$B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(L1LY"!KY'ET
MY"!S=6]R86%N(&UA:6YT96YA;F-E+G!H<#ITY"(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(DIO
M<R!E;G-I;6WD:6YE;B!R:79I('-I<^1L=.3D('-A<F%K:V5I9&5N(&]T<VEK
M;W0L(&YI:6X@=F%L:71S93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R"FUS9VED(")$;VUI;FEC
M82(*;7-G<W1R(")$;VUI;FEK86%N:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,*;7-G:60@
M(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEK86%N:6YE;B!T
M87-A=F%L=&$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(D5I:_8@;VQE(&OD>71TY&KD='5N;G5S=&$_($MI<FIA=61U(&OD>71TY&KD
M:W-I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U
M,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B5&%L;&5N;F$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B5&%L;&5N;F$@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R
M(")486QL96YN82!L=6]T=2!A<V5T=7,@4$A0+7-K<FEP=&ENY"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R(")!;&%S=F5T;W9A;&EK:V\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(DAU=6UE970B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R(")3Y&AK]G!O<W1I;W-O:71E(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"B)%36%I;"UT;RU3
M35,@9V%T97=A>2!A:G5R:2P@;FEI;&QE('!A;'9E;'5N=&%R:F]A:FEL;&4L
M(&IO=&MA('1A<FIO879A="!TY'3D("(*(G!A;'9E;'5A+B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")625)(12(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S4*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16-U861O<B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")-=6]K:V%A
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B
M161I="!";&]C:R(*;7-G<W1R(")-=6]K:V%A(&]S:6]T82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(DUU;VMK86$@<GEH;>3D(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@
M(DUU;VMK86$@;VEK975T=&$B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(DUU;VMK
M86$@;VEK975K<VEA(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R(")-=6]K:V%A("<E<R<Z;B!O:6ME=6MS:6$B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R(")-=6]K:V%A(&%S971U:W-I83HB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B375O:VMA82!<
M(B5S7"(Z;B!O:6ME=6MS:6$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(DUU;VMK86$@)7,Z;B!O:6ME=6MS:6$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G
M<W1R(")+;W5L=71U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<*;7-G:60@(D5G>7!T(@IM<V=S
M='(@(D5G>7!T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-PIM<V=I9"`B16P@4V%L=F%D;W(B
M"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N
M+BXB"FUS9W-T<B`B16QE;65N='1I+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@
M(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")%;6%I
M;"(*;7-G<W1R(")3Y&AK]G!O<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(E/D:&OV<&]S=&EO<V]I
M=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38W"FUS9VED(")%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B4^1H:_9P;W-T
M:6]S;VET=&5I9&5N('!I=.3D(&]L;&$@<V%M870N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B4^1H:_9P;W-T:2!V87)M:7-T=6MS96QL82(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS
M9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")%;6%I;"UT;RU3
M35,@1V%T97=A>2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")(>6UI]G0B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E1Y:&KD('9I
M97-T:2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E1Y:&KD
M('9A<W1A=7,N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E1Y:&KD
M(&AA:W5T97)M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G
M:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(E-A;&QI(&MU=FEE;B!L86ET=&%M
M:6YE;B!K=79A9V%L;&5R:6%S=&$@=&5K<W1I;B!J;W5K:V]O;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("),86ET82!PY.1L;&4@;VEK
M96%N('!A:6YI:VME96X@:V]N=&5K<W1I;65N=2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DR(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W
M.3<*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(E#DY'1T>6UI<W9U;W-I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B4W5U<F5N;F$@961I=&]R
M:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B
M(@HB06YN82!K>7-Y;7ES(&IO:V$@:WES>73DY&XL(&IO<R!S86QA<V%N87-I
M(&IO=61U=&%A;B!N;VQL86%M86%N(&5S:6UE<FMI:W-I("(*(B=M:6OD(&]N
M(&QE;6UI:VMI<VD@;FEM:3\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@
M=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(DQA:71A(&MU=F$@55),('3D
M:.1N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(D%N;F$@:VER:F%I;65T(&%L;&4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.0IM<V=I9"`B17%U
M871O<FEA;"!'=6EN96$B"FUS9W-T<B`B16MV871O<FEA86QI;F5N($=U:6YE
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E
M82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`IM<V=I9"`B17)R;W(B
M"FUS9W-T<B`B5FER:&4B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN
M9R!B;&]C:SH@)7,B"FUS9W-T<B`B5FER:&4@<.1I=FET971TY&5S<^0@;W-I
M;W1A.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<R(*;7-G<W1R(")6:7)H92!PY&EV:71E='3D97-SY"!S>6YC(&%N8VAO
M<B`M=&EE=&]A.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<R(*;7-G<W1R(")6:7)H92!P;VES=&5T=&%E<W-A('-Y;F,@;&]K
M:6$Z("5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R(")6:7)H92!H865T=&%E<W-A('-I<^1L=/;D.B`E<RXB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S
M='(@(E9I<FAE('#D:79I=&5T=.1E<W/D('-A;&%S86YA83H@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*
M;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B5FER
M:&4@<^1H:_9P;W-T:79I97-T:7-SY"XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB
M+B(*;7-G<W1R(")6:7)H92!K:7)J;VET971T865S<V$@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S8*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B165S=&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&EO<&EA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T
M<B`B171N:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]O<'!A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R("(Q-2!M:6YU=71I;B!VY&QE:6XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B
M,B!M:6YU=71I;B!VY&QE:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B,S`@<V5K=6YN:6X@=N1L96EN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-2!M:6YU=71I
M;B!VY&QE:6XB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")*;VMA:7-E
M;&QA('-I<^3D;FMI<FIA=71U;6ES96QL82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")0
M=6]L96X@='5N;FEN(';D;&5I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(DUI;G5U=&EN(';D;&5I;B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB
M"FUS9W-T<B`B17-I;65R:VMI87)V;W0Z(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C4Q(&%D;6EN+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@(E-U;W)I=&$B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM
M<V=I9"`B17AP86YD(@IM<V=S='(@(DQA86IE;FYA(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B3&%A:F5N;F$@<VEV=79A;&EK:V\B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`B3V1O=&5T=&EI;B!M97)K:VGD("<I)R(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A
M<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B4V%N82!S
M96QL86ES96YA86X@=&%I(&AA:W5T97)M:2!L86EN875S;65R:V5I<W/D(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B3&]P<'5PY&EVY&WDY'+D(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X
M<&]N96YT(@IM<V=S='(@(D5K<W!O;F5N='1I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@
M0V]L;W(B"FUS9W-T<B`B1D<@=N1R:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B
M07-E='5S=&EE9&]S=&]J96X@='5O;G1I($944#IL;.0B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")!<V5T=7-T96X@:&%K=2!E
M<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(EEH
M=&5Y<R!,1$%0+7!A;'9E;&EM965N(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B66AT97ES(%--0BUP86QV
M96QI;65E;B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B2V]P:6]I;G1I(%PB)7-<(CIL=.0@
M97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R(")+;W!I;VEN=&D@7"(E<UPB.FQL92!E<.1O;FYI<W1U
M:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED
M(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(E5U9&5N(%-!4TPM>6AT97ED96X@;'5O;6EN96X@97#D;VYN:7-T=6DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")3:6ER=&\@7"(E<UPB
M.N3D;B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(@IM<V=S='(@(E-I:7)T;R!E<.1O;FYI<W1U:3H@)7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B
M1F%I<B(*;7-G<W1R(")+875N:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T"FUS9VED(")&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1I;B!S
M86%R970@*$UA;'9I;F%S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B1N1R('-A87)E="(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")686MA
M=F$@=FER:&4Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A:W-I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T
M<B`B1F%K<VET(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(FAE;&UI:W5U(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B
M"FUS9W-T<B`B5'5N='5U(&MU:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B5'5N
M='5U(&MU:6XZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")-=75T86UI
M82!S871E:71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B375U
M=&%M:6$@;'5M:7-A=&5I=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.30X"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B2V5N='3D;6%T
M<FEI<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(Y"FUS9VED
M(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%05$-(02(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S,*;7-G:60@(D9I9VQE="!F
M;VYT(@IM<V=S='(@(D9I9VQE="!K:7)J87-I;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,*;7-G
M:60@(D9I:FDB"FUS9W-T<B`B1FED>FDB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B5&EE9&]S=&\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(E1I961O<W1O
M:F5N(&QU:W5MY.1RY#H@)7,@=&EE9&]S=&\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE<R(*;7-G<W1R(")4:65D;W-T;VIE;B!L=6MU;>3D<N0Z("5S
M('1I961O<W1O82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")4:65D;W-T;VIE;B!KY'-I
M='1E;'DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`IM<V=I9"`B
M1FEL92!.86UE(@IM<V=S='(@(E1I961O<W1O;B!N:6UI(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDX,0IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B5&EE9&]S=&]N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")4
M:65D;W-T;VX@='5O;G1I(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B5&EE9&]S=&]J96X@='5O;G1I(&5I(&]L92!KY'ET971TY'9I
M<W/D+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B
M1FEL=&5R<R(*;7-G<W1R(")3=6]D871T:6UE="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(*;7-G
M:60@(D9I;FQA;F0B"FUS9W-T<B`B4W5O;6DB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D5N<VEM;>1I
M;F5N('!U;VQI<VMO(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R
M(")%;G-I;6WD:6YE;B!N96QJY&YN97,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B2V]R:F%A('-U:&1E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")+Y.1N
M;N0@>6UPY')I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B2V5L;'5V
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q
M"FUS9VED(")&;V<B"FUS9W-T<B`B4W5M=2(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(DMA;G-I;W1A("5S(&5I(&]L92!O;&5M87-S82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS
M9VED(")&;VYT($-O;&]R(@IM<V=S='(@(DMI<FIA<VEM96X@=N1R:2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M(")2=6]K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B4V5L86EM:6QL92P@:F]T
M:V$@96EVY'0@='5E(&MU=FEA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(D5N;G5S=&4@*%1!
M1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@
M(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R
M96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS
M9W-T<B`B(@HB16YN=7-T971T879A="!V=6]R;VMA=61E="`H2'5O;6%A=&AA
M;B!E='3D(&5N;G5S='5K<V5S<V$@;VX@=&EE9&]T('-E:^0@(@HB<.1I=FES
M=.0@971TY"#V:7-TY"P@:F]T96X@<W5U<FD@;>3D<N0@<.1I=FGD(&%I:&5U
M='1A82!L:6EA;B!L979EY&X@;W-I;VXI(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*
M;7-G<W1R(")5;F]H9&ET:V\@<V%L87-A;F%S:3\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("),;VUA
M:VME970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O
M<G1U;F4B"FUS9W-T<B`B36EE=&5L875S92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(DUI971E
M;&%U<V5E;B!T>7EP<&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(DUI971E;&%U<V5E="(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R(")-:65T96QA=7-E970@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;V]R=6UI="(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S
M(@IM<V=S='(@(E5U9&5L;&5E;F]H:F%U:W-E="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(G!E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(DME:'EK<V5T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(E)A;G-K82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B4F%N<VMA+"!-971R;W!O;&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDQ"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(E)A
M;G-K86X@1W5Y86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0*;7-G:60@(D9R96YC:"!0;VQY
M;F5S:6$B"FUS9W-T<B`B4F%N<VMA;B!0;VQY;F5S:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M(")286YS:V%N(&5T96SD:7-E="!T97)R:71O<FEO="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B3.1H971TY&KD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@
M=&AE("(*;7-G<W1R(")3=75N;F%S=&$@(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4&ED96UP:2!K=79A=7,Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*
M;7-G<W1R(")4Y'ES:6MU=2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&
M=6QL($YA;64B"FUS9W-T<B`B2V]K;R!N:6UI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.`IM<V=I
M9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&QE<FEA+"!J
M;W-T82!K=79A(&]T971A86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ
M(@IM<V=S='(@(D=A;&QE<FEA.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38*;7-G:60@(D=A;6)I
M82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B5&5E("5S(&%S971U:W-E="(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@
M0V]D92(*;7-G<W1R(")'96YE<F]I='4@:V]O9&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP"FUS
M9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(E-A:W-A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,PIM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT"FUS9VED(")'
M:6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS
M9W-T<B`B171U;FEM:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S
M='(@(EEL96ES970@87-E='5K<V5T(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(DUE;F4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")']F1E
M;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@2V%R=&%T
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R(")';V]G;&4@:&%K=2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES8V%L
M92(*;7-G<W1R(")(87)M86%SY'9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`*;7-G:60@(D=R
M965C92(*;7-G<W1R(")+<F5I:VMA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")+<F5I
M:VMA("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N
M9"(*;7-G<W1R(")'<O9N;&%N=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y"FUS9VED(")'<F5N
M861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W
M.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4GEH;>1N
M('EL;.1P:71O(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")2>6AM:65N(&YI
M;65T(&5I=N1T('-A82!O;&QA('1Y:&IIY"(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D=R;W5P7VQD87`Z($5I
M('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N(%!A;'9E;&EM96X@=FER:&5I
M;&UO:71U<R!O;&DZ("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D
M(&OD>71TY&KDY"`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($5I('9O:61A('#D
M:7;D='3DY"!KY'ET=.1JY.0@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S
M='(@(E)Y:&WD="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@*;7-G:60@(D=U861E;&]U<&4B"FUS
M9W-T<B`B1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S"FUS9VED(")'=6%M(@IM
M<V=S='(@(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,@IM<V=I9"`B1W5A=&5M86QA(@IM
M<V=S='(@(D=U871E;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B5FEE<F%I;&EJ86X@;VEK975D970B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B5FEE
M<F%S:VER:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDW"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`T"FUS9VED(")'=6EN96$M0FES<V%U(@IM
M<V=S='(@(D=U:6YE82U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4*;7-G:60@(D=U
M>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!P96QK=7)I;6%I
M<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!R:79I;B!V:6EM96ES=.0@
M<V]L=6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M("(B"B)(5$U,07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES
M=&%M87-T82!V:6EM96ES=.0@<V%R86ME='1A("(*(G1A=6QU:V]S=&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"B)(5$U,07)E
M82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!V:6EM
M96ES=.0@<FEV:>0@=&%U;'5K;W-T82XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(DA45%`M875T96YT:6MO:6YT:6$@96D@;/9Y
M='EN>70N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$P"FUS9VED(")(86ET:2(*;7-G<W1R(")(
M86ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S:"UA;&=O<FET;6DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM
M<V=I9"`B2&%Z92(*;7-G<W1R(")5<W9A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3(S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3@*;7-G
M:60@(DAE861E<B(*;7-G<W1R(")/='-A:V4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM
M<V=S='(@(D]T<V%K92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-PIM<V=I9"`B2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D(&IA($UC
M1&]N86QD('-A87)E="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E9O
M:6UA:V%S('5K:V]S;7ER<VMY(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(97!R
M96$@*$E33RTX.#4Y+3@M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B2V]R:V5U<R(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*
M;7-G<W1R(")/:&IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T
M<B`B07!U82!E9&ET;W)I;B!KY'ET=/;V;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-S4*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")/:&IE(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM
M<V=S='(@(E!A;&QO;G!U;VQI<VMO.B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(E3D<W/D(&]N('1I961O<W1O;B!A;&MU;W-A.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H(@IM
M<V=S='(@(DMO<FME82(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B2V]?=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")0>6CD(&ES
M='5I;B`H5F%T:6MA86YI;B!K875P=6YK:79A;'1I;RDB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$*;7-G:60@(DAO;64B"FUS9W-T<B`B
M2V]T:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DMO=&EO<V]I=&4B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER
M96-T;W)Y(@IM<V=S='(@(DMO=&EH86ME;6ES=&\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(E!U:&5L:6X@*&MO=&DI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X"FUS
M9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-@IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!%<.1K96QP;V$@)7,@6$U,+61A=&%A('9I97-T:7-SY"`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O
M;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@66MS:6OD
MY&X@=FEE<W1I(&5I('9A<W1A82!O8FIE:W1I82`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!9:'3D:^3D;B!O8FIE:W1I
M82`E<R!E:2!L]GET>6YY="!V:65S=&ES=.0@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@4&]I<W1E='1I:6X@)7,@7"(E<UPB(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!)
M;G1E9W)A871I;VMO;F4@=F%A=&EI('1O:6UI86MS965N("=D;VUX;6PG(%!(
M4"UL86%J96YN=6MS96XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@16D@=F]I9&$@;'5O9&$@=75T=&$@6$U,+7!U=71A
M(&]B:F5K=&EL;&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@16D@=F]I='4@<&]I<W1A82`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%:2!V
M;VED82!H86ME82!-24U%($E$.N0@;W-I;VQL92!T>7EP<&GD("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@=F]I('-Y:W)O
M;F]I9&$@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($5I('9O:61A('-Y;FMR;VYO:61A(&IA:V]J83H@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(%1U;G1E;6%T;VX@:F%K;R!<(B5S7"(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS
M9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B5F%A:V%S=6]R82!SY.1N
M=/8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B5F%A:V%S
M=6]R82!TY'ET92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(E9A86MA
M<W5O<F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@
M*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")-:71E;B!T=6QI="!TY&YN93\@
M*%)A<&]R=&]I(&MI:71O<R$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L
M=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2W5I;FMA
M(&UO;G1A('-A<F%K971T82!H86QU870@>6AD:7-TY.0_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")+96YT=&EE;B`H<V%R
M86MK96ED96XI(&QU:W5MY.1RY"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+=6EN:V$@
M;6]N=&$@<FEV:>0@:&%L=6%T('EH9&ES=.3D/R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*
M;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DMO<W1E=7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM
M<V=S='(@(DMO<W1E=7,Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T:70B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3$*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B56YK87)I(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!
M4"UP;W-T:6QA871I:V]N(&QU;VYT:2!E<.1O;FYI<W1U:3H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0
M+7!O<W1I;&%A=&EK;VX@<&]I<W1O(&5PY&]N;FES='5I.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(DE-05`M<&]S=&EL86%T:6MO;B!K:6EN=&GV;B!L=6]N=&D@97#D;VYN:7-T
M=6DZ("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,R,`IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R("))4"UO<V]I=&4B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0+6]S;VET92!E:2!O;&4@:^1Y
M=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+B(*;7-G<W1R("))4"UO<V]I=&4@96D@;VQE('-A;&QI='5N
M($-)1%(M8FQO:VEN('-I<^1L;.0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B25`M<^3D;F[V<W3V;B!R:6MK;VUU<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DQ?
M86ET82!R:79I(&5N;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD
M(@IM<V=S='(@(DES;&%N=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E9A:6X@:6MO;FET(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N:70@)7,Z;&QE(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T
M97AT(@IM<V=S='(@(DEK;VYI="!J82!T96MS=&DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S
M='(@(E!R;V9I:6QI;B!N:6UI.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N(@IM<V=S='(@(DIO<R!S:79U(&5I(&[D>2!K=6YN;VQL
M82P@;FEI;B!A=6MA:7-E("5S(&5R:6QL:7-E<W/D(&EK:W5N87-S82XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(DIO<R!E="!NY&4@:6MO
M;F5I=&$@:^1Y='3D97-SY'-I($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;G1A
M+"!N:6EN('-I;G5N("(*(G!I=.3D(&]T=&%A('!O:7,@<.3D;'3D(%!.1R!L
MY'!I;N1K>79Y>7,@<F%S=&ET=&%M86QL82!TY&WD(&QA871I:VMO+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G
M:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@
M=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)*;W,@;N1E="!T
MY&WD;B!V:65S=&EN+"!M=71T82!E="!K=79A82P@;FEI;B!T=6]M86%S:2!K
M=79A82!E:2!V;VD@;N1Y='3DY"`B"B)KY'ET=.1MY'-SY'-I('-E;&%I;65S
M<V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M(")+=79I96X@97-I:V%T<V5L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R(")+=79A(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),
M.B(*;7-G<W1R(")+=79A(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")+=79A(&=A;&QE<FEA<W1A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DMU
M=F$@9V%L;&5R:6%S=&$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(DMU=F%N('9I96YT
M:2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B
M"FUS9W-T<B`B2W5V870B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-R!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R(")4=6]N=&DL(&%S:V5L("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE
M;&0Z("5S(@IM<V=S='(@(E1U;W1U(&ME;G1TY#H@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z
M(@IM<V=S='(@(E1U;V1U="!K96YTY'0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R("),85]I=&$@<FEV:2!JY&QK965N(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(E;D
MY'+D('1O:6UI;G1O:V]O9&D@86YN971T=2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B2^1Y='3D
M:N1T=6YN=7,@=&%I('-A;&%S86YA(&]N(';DY')I;BXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"B)6Y.1RY"!KY'ET=.1JY'1U;FYU<R!T86D@
M=F%I:'1O96AT;VEN96X@;W-O:71E+B!9<FETY"!U=61E<W1A86X@:F$@;W1A
M("(*(GEH=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E="!L:7/DY"!A
M<'5A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("),:7/DY"!S
M:7-E;FYY<W3D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I82(*;7-G<W1R
M("));G1I82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED
M=6%L(%5S97)S(@IM<V=S='(@(EEK<VET=.1I<V5T(&OD>71TY&KD="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N97-I
M82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(DEN9F]R;6%A=&EO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`B5&EE=&]A(&5I(&]L92!E;N3D('-A871A=FEL;&$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("),86ET
M82!S7V%R86ME(&KD;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!)
M;6%G92(*;7-G<W1R("),86ET82!K=79A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE
M(@IM<V=S='(@(DQA:71A('1A=6QU:VMO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(DQA:71A('=W=RUL:6YK:VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("),86ET82!?<V%R86ME
M(&5N;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),86ET82!U=7-I('-A<F%K
M92!N>6MY:7-E;B!JY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B3&%I
M=&$@=75S:2!S87)A:V4@96YN96X@;GEK>6ES=.0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(DQA:71A('5U<VD@<FEV:2!N>6MY:7-E;B!JY&QK965N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B3&%I=&$@=75S:2!R:79I(&5N;F5N(&YY:WEI<W3D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R("),86ET82!K87!P86QE(&YY:WEI<V5N(&YO
M9&5N(&KD;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("),86ET82!K87!P
M86QE(&5N;F5N(&YY:WEI<W3D(&YO9&5A(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B3&%I=&$@=F%I:'1O96AT;VEN96X@;6%L;&DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#HB"FUS9W-T<B`B06YN82!SY&AK]G!O<W1I;W-O:71E(&IO:&]N('5U<VD@
M<V%L87-A;F$@;.1H971E=.3D;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L
M;"!A9G1E<B(*;7-G<W1R("),86ET82!S;VQU(&KD;&ME96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS
M9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B3&%I=&$@<V]L=2!E
M;FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T
M<B`B3&%I=&$@<V]L=2!JY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O
M;'5M;B!B969O<F4B"FUS9W-T<B`B3&%I=&$@<V%R86ME(&5N;F5N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(DEN
M<V5R="!M97-S86=E<R(*;7-G<W1R(")6;VD@;&%I='1A82!V:65S=&5JY"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R
M("),86ET82!K87!P86QE(&KD;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(DQA:71A(&MA<'!A;&4@96YN
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DQA
M:71A(')I=FD@96YN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R("),86ET82!R:79I(&KD;&ME96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(D%N;F$@
M=F%A9&ET=&%V82!V87-T875S('1U<G9A:WES>6UY:W-E96XZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B
M26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("),:6ETY"]-=6]K:V%A(&MU
M=FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DQI:73D
M+TUU;VMK86$@;&EN:VMIY"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"B)3:6YU;&QA(&5I(&]L92!T87)P965K<VD@:W)E9&EI='1E:N0@;.1H
M971TY.1K<V5S:2!V:65S=&EN(&IA:V5L=6QI<W1A;&QE+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")2:6ET=.1MY'1T]FWD
M<W1I(&MR961I:71T96KD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")+;VMO;F%I<VQU:W4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R
M(&QI<W0B"FUS9W-T<B`B2V]K;VYA:7-L=6MU;&ES=&$B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@
M(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(D5P
MY&ME;'!O("!51$@@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(D5PY&ME;'!O82!:25`M=&EE=&]A+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC
M871I;VXN(@IM<V=S='(@(D5PY&ME;'!O(&]H:F5L;6$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")%<.1K96QP;R!B871C:"!)
M1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DQ(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-C(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(S-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S`S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(DSD:&5T971T:6EN(&5P
MY&ME;'!O82!T:65T;V$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N(@IM<V=S='(@(D5PY&ME;'!O('9A<W1A86YO='1A:F%N
M(&]S;VET92XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")%<.1K
M96QP;R!T:65D;W-T;VUU;W1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T
M<B`B17#D:V5L<&\@;&ES96YS<VEA=F%I;BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(")%<.1K96QP;R!P86EK:V%T:65T;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(D5PY&ME;'!O(&US
M9U]T>7!E("XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(D5PY&ME;'!O('1A:2!P=75T='5V82!A<&E?:60N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS
M9W-T<B`B17#D:V5L<&\@=&%I('!U=71T=79A('!A<F%M971R:2XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D5PY&ME;'9O="!O:6ME=61E="!Y
M;&5M;>1L;.0@=&%S;VQL82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@
M(D5PY&ME;'!O('!A<FYE<B!I9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS
M9W-T<B`B17#D:V5L<&\@='5O=&5K;V]D:2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(D5PY&ME;'!O('!R;W1O:V]L;&$N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R
M(")%<.1K96QP;R!V87-T86%N;W1T86IA.B!<(B5S7"(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R
M(")%<.1K96QP;R!J86MO+6]B:F5K=&DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@
M<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D5PY&ME;'!O(&SD:&1E;W-O:71E
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@
M(D5PY&ME;'!O82!U;FEC;V1E+71I971O82XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV
M96YT86%R:6\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DOD
MY&YNY"!V86QI;G1A(&ODY&YT96ES96MS:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.0IM<V=I
M9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N+"!)
M<VQA;6EL86EN96X@=&%S879A;'1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X"FUS9VED("))
M<F%Q(@IM<V=S='(@(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`B27)L86YT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")-86XM<V%A
M<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B17)I;&QI<VGD
M(%5K:V]S;7ER<VMY:N0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*
M;7-G<W1R("))<W)A96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(DQI:6MK965L;&5L
M87-K:6IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B2W5R<VEV;VET=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,0IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(S"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R(")T86UM:6MU=2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-0IM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P86YI(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B2F%P86YI("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-`IM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A
M;FEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B:&5I;N1K=74B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*
M;7-G<W1R(")K97/D:W5U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R
M(")+97-K:73D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S
M='(@(DME<VMI=.0@:V5S:V5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`IM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(DME<VMI=.0@=.1Y<VEN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*;7-G:60@(DIU
M<W1I9GD@3&5F="(*;7-G<W1R(")+97-K:73D('9A<V5M;6%L;&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")+97-K:73D(&]I:V5A
M;&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@
M(DMA>F%K<W1A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(E/D
M:6QY=.0@86QK=7!E<N1I;F5N/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-@IM<V=I9"`B2V5N
M>6$B"FUS9W-T<B`B2V5N:6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@97#D;VYN:7-T
M=6D@2V5R8F5R;W,M<&%L=F5L:6UE;&QE+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R
M;F5L(&%L;VET=&5L:6IA="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D%V86EM
M96X@;'5O;G1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B079A:6UE;B!T
M=6YN:7-T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")!=F%I;65N('!I='5U<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y(%1Y<&4B"FUS9W-T<B`B079A:6UE;B!T>7EP<&DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E
M(@IM<V=S='(@(D%V86EM96X@:^1Y='3V(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D%V86EN(&]N(&IO
M(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L;&$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B3&%P<V5T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Y"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I
M8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,@IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96$L(&1E;6]K<F%A
M='1I;F5N(&MA;G-A;G1A<V%V86QT82`H4&]H:F]I<RU+;W)E82DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+
M;W)E82P@=&%S879A;'1A("A%=&5LY"U+;W)E82DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(DMO<F5A("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T"FUS9VED(")+=7=A:70B
M"FUS9W-T<B`B2W5W86ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W"FUS9VED(")+>7)G>7IS
M=&%N(@IM<V=S='(@(DMI<F=I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")!<U]E='1E;'4B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG
M=6%G92(*;7-G<W1R(")+:65L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-PIM<V=I9"`B3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<RP@
M9&5M;VMR86%T=&EN96X@:V%N<V%N=&%S879A;'1A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(DKD;&MI
M;6WD:6YE;B!P=6]L:7-K;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B161E;&QI
M;F5N('-A;&%S86YA;G9A:6AT;R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R(")*Y&QK:6UMY&EN96X@;F5L:N1N;F5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B
M4.1I=FET971T>2!V:6EM96MS:3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`B161E;&QI;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B161E;&QI
M;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ("5S+"`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`B161E;&QI;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ($5I(&UI
M;&QO:6YK86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),871V:6$B"FUS9W-T
M<B`B3&%T=FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B3&%K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM<V=S
M='(@(D%S971T96QU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<B(*;7-G<W1R(")*Y'3D('1Y:&KD:W-I(&IO<R!E:2!R975N;VIA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#`*;7-G:60@(DQE9G0B"FUS9W-T<B`B5F%S96XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3`U"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M(")687-E;B!O='-A:V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3`Q"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")687-E;B!A<G9O="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&\B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(E1A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`B3&EB97)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-PIM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)Y82!!<F%B($IA;6%H
M:7)I>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#`*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B3&EC:'1E;G-T86EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T
M<B`B2V5V>71TY"!RY&YTY.0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")+
M:7)J875D=2!S:7/DY&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M(")+979Y='3D('-A9&5T=&$@86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(DME=GET=.0@<V%D971T82!M>?9H96UM:6XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B2V5V>6ETY"!S861E:W5U<F]J
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")+979Y
M='3D('-A9&5T=&$@:F$@;7ER<VMY:7-TY"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM
M<V=S='(@(DME=GET=.0@;'5M:7-A9&5T=&$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3
M:&]W97(B"FUS9W-T<B`B2V5V>6ETY"!L=6UI:W5U<F]J82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M3&EM97)I:VET(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q.`IM
M<V=I9"`B3&EN:R(*;7-G<W1R("),:6YK:VDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("),:6YK:VD@;W-O:71T86$Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W.0IM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("),:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I
M=&$@=75S:2!V:65S=&D@<VEV=6QL92!NY&MY;>1S<^0B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED
M("),:6YK<R(*;7-G<W1R("),:6YK:70B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"!P
M:7!A<F5I=&$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-PIM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(E9O:2!L:7-T875K<V5S<V$@;N1H9.0@:V%N<VEO;B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM
M<V=S='(@(D[D>73D('1I971O:V%N;F%T(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B
M3N1Y=.0@;VAJ96ED96X@86EH965T(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3N1Y=.0@=&%U;'5T
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T86XM07)K:7-T;R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),
M:7-T+4AE;'`B"FUS9W-T<B`B3&ES=&%N+4]H:F4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G
M<W1R("),:7-T86XM260B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T86XM
M3VUI<W1A:F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W1A+79I97-T:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED
M("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T86XM5&EL875S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI
M<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&%N+51I;&%U:W-E;BUL;W!E
M='1A;6EN96XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S
M='(@(DES='5N=&]J96X@;&ES=&%U<R!E<.1O;FYI<W1U:3H@)7,B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(DOD>71TY&II96X@;&ES
M=&%U<R!E<.1O;FYI<W1U:3H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(DOD>71TY&KD=&EE=&]J96X@;N1Y='3D;6EN96X@;VX@
M97-T971T>2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@
M(DQI=&5R871U<F4B"FUS9W-T<B`B2VER:F%L;&ES=75S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30T"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&EE='1U82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@
M(DQO861I;F<N+BXB"FUS9W-T<B`B3&%D871A86XN+BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B
M"FUS9W-T<B`B4&%I:V%L;&ES=&$@86EK86$Z("(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@
M(DQO:V%L:7-A871I;R!J82!A:6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4W"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")086EK:V$B"@HC
M.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR
M,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B2VER:F%U9'4@<VESY.1N(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(D5D96QL:7-E;B!S
M>6YK<F]N;VEN=&ES97-S:6]N(&QO:VDB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DMI<FIA
M=61U('5L;W,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@
M(DQO9VEN(@IM<V=S='(@(DMI<FIA=61U('-I<^3D;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@
M(E1E:'3D=N1T('-I<^3D;FMI<FIA=71U;6ES97-S82(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@HB4VESY.1N:VER:F%U='5M:7-E<VD@97#D
M;VYN:7-T=6DN(%1O9&5N;N1K]FES97-T:2!K:7)J;VET:70@=N3D<FEN("(*
M(FOD>71TY&KD='5N;G5K<V5S:2!T86D@<V%L87-A;F%S:2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`B4VESY.1N:VER:F%U='5M:6YE;B!E<.1O;FYI<W1U:2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`B4&ET:^0@=&5K<W1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(E)A:VMA=7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B
M3&]W(@IM<V=S='(@(DUA=&%L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R
M965K(&QE='1E<G,B"FUS9W-T<B`B4&EE;F5T(&MR96EK:V%L86ES970@:VER
M:F%I;65T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R(")0:65N970@;&%T:6YA;&%I<V5T(&MI<FIA:6UE="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4&EE;F5T
M(')O;VUA;&%I<V5T(&YU;65R;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4*;7-G:60@(DQU
M>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")+2R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS
M9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(DU3+51.148@;&EI=&5T:65D;W-T;R!O;&D@='EH:N0N(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(E9)15-422(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-PIM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86ME9&]N:6$L($5N=&EN96X@2G5G
M;W-L879I86X@=&%S879A;&QA;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B5&%I:W5U<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*
M;7-G<W1R(")3Y&AK]G!O<W1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")0;W-T:6X@>6QL
MY'!I=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M5&5E(&QI;FM?:VDN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4*;7-G:60@(DUA;&%W:2(*
M;7-G<W1R(")-86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<*;7-G:60@(DUA;&%Y<VEA
M(@IM<V=S='(@(DUA;&5S:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0*;7-G:60@(DUA;&1I
M=F5S(@IM<V=S='(@(DUA;&5D:6EV:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30*;7-G:60@
M(DUA;&DB"FUS9W-T<B`B4&]S=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(*;7-G:60@(DUA
M;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)6
M;VET(&AA;&QI;FYO:61A(&QI<W1A82!K871E9V]R:6]I<W1A+"!J;VED96X@
M879U;&QA('9O:70@;&EI='3DY"!A<VEO:71A("(*(GEH=&5E;B!S86UO:F5N
M(&]T<V%K:V5I9&5N(&%L;&4@:F$@;&EI='3DY"!N:6EH:6X@=N1R96KD+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V
M"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@:V%R='1A(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G
M:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!K87)T=&$B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I
M;F=S('-T;W)E9"XB"FUS9W-T<B`B5F%S=&%A=G5U9&5T('1A;&QE=&5T='4N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*
M;7-G:60@(DUA<F-H(@IM<V=S='(@(FUA86QI<VMU=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA<F=I;B(*;7-G<W1R(")-87)G:6YA86QI(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")6;VD@;65R:VETY"!686YH82]5=7-I
M('1I971O:F$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,`IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B5F]I(&UE<FMI=.0@=FEE<W1E:N0@
M*&5S:6TN(%3D<FMEY"]687-T871T=2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(*;7-G:60@
M(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R<VAA;&P@<V%A<F5T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34Y"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I
M;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E3D<VWDY';D="!K96YTY'0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C`*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U
M<FET86YI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,PIM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET
M+B(*;7-G<W1R(")3=75R:6X@<V%L;&ET='D@:W)E9&EI='1I+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM
M<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(E-U
M=7)I;B!S86QL:71T=2!V:65S=&EO<VEO;>3D<N0@>6QI=&5T='DN(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R(")%9&5L;&ES96X@,C0@='5N;FEN(&MO<FME
M:6X@;.1M</9T:6QA.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM
M<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B161E;&QI
M<V5N(#8@='5N;FEN(&MO<FME:6X@;.1M</9T:6QA.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R(")0;W)T86%L:6]S:6]I9&5N(&5N:6UMY&ES;>3D<N0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0S
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")3=75R:6X@<V%L;&ET
M='4@<&ET=75S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")T;W5K;VMU=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3,*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;VYE='1E(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*
M;7-G<W1R("),Y.1K971I961E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")*Y'-E;F5T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M
M;V1E.B(*;7-G<W1R(")-96YU;B!M=6]T;SHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G
M92!C96QL<R(*;7-G<W1R(")9:&1I<W3D('-O;'5T(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@
M(DUE<W-A9V4B"FUS9W-T<B`B5FEE<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)6:65S=&EN
M('1A<FMI<W1U<R!O;FYI<W1U:2P@;75T=&$@86QL96MI<FIO:71T86IA;B!V
M87)M96YN971T82!E:2!V;VET=2`B"B)T87)K:7-T86$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(E9I97-T:2!V86YH96YI+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-C`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,#(*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")6
M:65S=&EN('1Y>7!P:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-971A<B!SY.0B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")-971A<BUO<VEO(&5I(&]L92!KY'ET971TY'9I
M<W/D+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-971A
M<BUO<VEO(&5I(&]L92!KY'ET971TY'9I<W/D+B!487)K96UM870@=&EE9&]T
M(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N("(*(FOD<VET96QTY';D:W-I+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE
M=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B365T87)$0B!E:2!O
M;&4@>6AD:7-T971T>2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-971O9&DB"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D:6$@7"(E<UPB(&5I
M(&]L92!MY.1R:71E;'1Y(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP
M:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")-971O9&EA(&5I(&]L92!M
MY.1R:71E;'1Y+B!+=71S=79A(&UE=&]D:3H@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-PIM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I;F5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M"FUS9VED(")-97AI8V\B"FUS9W-T<B`B365K<VEK;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U
M"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S
M='(@(DUI:W)O;F5S:6$L(%EH9&ES='EN965T('9A;'1I;W0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*;7-G
M:60@(DUI9&1L92(*;7-G<W1R(")+97-K96QLY"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B
M"FUS9W-T<B`B36EM92UT>7EP<&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(D5D96QL:7-E;B`R-"!T=6YN:6X@;6%T86QI;B!LY&UP]G1I;&$Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R(")%9&5L;&ES96X@-B!T=6YN:6X@;6%T86QI
M;B!LY&UP]G1I;&$Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D(@IM<V=S='(@(E-A;&%S86YA(&5I(&]L92!V:65LY"!T87)P
M965K<VD@=F%N:&$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,U"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B4&5I;&EK=79A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL
M86YE;W5S(@IM<V=S='(@(E-E:V%L86ES970B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I
M;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4$5!4BUP
M86ME='1I($A45%!?4F5Q=65S="!P=75T='5U+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)0=75T='5V
M870@87-E='5S=&EE9&]S=&\N(%-I;G5N('!I=.3D('1E:&3D(&%S971U<W1I
M961O<W1O(&IO<R!H86QU870@(@HB:^1Y='3DY"!TY'3D(&]H:F5L;6%A+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")0=75T
M='5V82!M97-S86=E($E$+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")6Y&QT=.1MY'3V;B!0
M14%2+7!A:V5T=&D@36%I;"!P=75T='5U+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R(")0=75T='5V82!S97-S:6]N($E$+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*
M;7-G:60@(DUO(@IM<V=S='(@(FUA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I:6QI
M<^1H:_9P;W-T:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")+;VAT86QA:6YE
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I
M9FEE9"!$871E(@IM<V=S='(@(DUU;VMK875K<V5N('#D:7;D;>3D<N0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B375O:VMA82!54DPZ
M:6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM
M<V=I9"`B36]D=6QU<R(*;7-G<W1R(")+97)R;VEN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P
M"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9A
M+"!T87-A=F%L=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D*;7-G:60@(DUO;F%C;R(*;7-G
M<W1R(")-;VYA8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38*;7-G:60@(DUO;F=O;&EA(@IM
M<V=S='(@(DUO;F=O;&EA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4X.`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B:W5U:V%U<VD@
M:F$@=G5O<VDB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DMU=6MA=7-I='1A
M:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B
M36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B2W5U
M;B!V86EH965T(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE
M(&5X<&5C=&5D("5D+B(*;7-G<W1R(")2:79I;'3D("5D(&SV>71Y:2!E;F5M
M;>1N(&ME;G1T:>0@:W5I;B!O9&]T971T=2`E9"XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;VMK;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B16YI;6WD:W-I('-E;&MEY.0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY
M($-L;W5D>2(*;7-G<W1R(")%;FEM;>1K<VD@<&EL=FES=.0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B16YI;6WD:W-E96X@<&EL
M=FES=.0@:F$@='5U;&ES=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@
M(D5N:6UMY&MS965N(&%U<FEN:V]I<W1A(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W
M;B(*;7-G<W1R(")3:6ER<N0@86QA<W#D:6XB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V92!,
M969T(@IM<V=S='(@(E-I:7)RY"!V87-E;6UA;&QE(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO
M=F4@4FEG:'0B"FUS9W-T<B`B4VEI<G+D(&]I:V5A;&QE(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`B4VEI<G+D('EL]G-PY&EN(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(E-I:7)RY"!A;&%S<.1I;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!U
M<"(*;7-G<W1R(")3:6ER<N0@>6SV<W#D:6XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@*;7-G
M:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]S86UB:6LB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',B"FUS9W-T<B`B36]N:71A<V]I;F5N(&%L87-V971O=F%L
M:6MK;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#4X"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM
M87`@27-O+4)R:71A;FYI86X@:V%R='1A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S
M='(@(DUO;FEV86QI;G1A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")+Y'ET=.1JY'1U;FYU
M:W-E;FDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY
M($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B3VUA;B!KY'ET=.1JY'1U
M;FYU:W-E;B!T:65D;W0B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C0U"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B3VUA('!O<G1A86QI(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T
M86P@3&%Y;W5T(@IM<V=S='(@(D]M86X@<&]R=&%A;&EN(&%S971T96QU(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34U"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(@
M*$)U<FUA*2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B
M14DL($5.('-U;W-T=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#(@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(").86UE(@IM<V=S='(@(DYI;6DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD*;7-G
M:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.`IM
M<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<*;7-G
M:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U"FUS9VED
M(").971H97)L86YD<R(*;7-G<W1R(")!;&%N:V]M86%T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(D%L86YK
M;VUA:61E;B!!;G1I;&QI="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M(").971S8V%P92!"87-E(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N
M(%523"(*;7-G<W1R(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"UP86QV96QI
M;65N(&]S;VET92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM
M<V=S='(@(DYE='-C87!E('9A<FUE;G1E96X@:V]M;65N='1I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C
M87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@=F%R;65N
M=&5E;B!T>7EP<&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S
M"FUS9VED(").971W;W)K(@IM<V=S='(@(E9E<FMK;R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(D5I(&MO<VMA86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B575S:2U+86QE9&]N:6$B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(E5U<VD@;'5O:VET=7,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S
M='(@(E5U<VEK=74B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M(")5=7-I(&OD>71TY&KD='5N;G5S("AV87!A865H=&]I;F5N*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B575S:2U3965L
M86YT:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I
M9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E5U<VD@<V%L87-A;F$B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T
M<B`B575S:2!S86QA<V%N82!V86YH96YE92`E>"XB"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N
M)W0@;6%T8V@N(@IM<V=S='(@(D%N=&%M87-I('5U9&5T('-A;&%S86YA="!E
M:7;D="!TY'-MY.0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G
M<W1R(")5=7-I(&EK:W5N82`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(E5U
M=&ES970B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED
M(").97=S9W)O=7!S(@IM<V=S='(@(DME<VMU<W1E;'5R>6AMY'0B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR-0HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M,2!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-0IM<V=I9"`B3F5X="(*
M;7-G<W1R(")3975R86%V82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM
M<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(")3975R86%V870@-"!V86EH
M971T82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P
M=&EO;G,B"FUS9W-T<B`B4V5U<F%A=F%T(&%S971U:W-E="(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R
M(")3975R86%V83XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0*;7-G:60@(DYI8V%R86=U82(*
M;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$*;7-G:60@(DYI9V5R
M(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S"FUS9VED(").:6=E<FEA
M(@IM<V=S='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(")9]B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W.0IM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS
M9W-T<B`B16DB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL
M.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(D%S971U<W1I971O:F$@
M96D@;VQE('-A871A=FEL;&$L(&IO<W1A('9O:7-I(&[D>71TY.0@97)O879A
M:7-U=6MS:6$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(D5I(&]L92!S86%T879I;&QA
M('-U=6YN:71E;&UA82!)4T\@;&5V>6MU=F%T:65D;W-T;VIE;B!T96ME;6ES
M96MS:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R
M(")%:2!E<N1M86QL:6$N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(D]S:6]T
M82!E:2!O;&4@<'EY9&5T>7-SY"!P86EK87-S82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+
M86QE;G1E<FEN(&YI;67D(&5I(&]L92!A;FYE='1U($U#04PM875T96YT:6MO
M:6YN:6QL92XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B
M3F\@8VAA;F=E+B(*;7-G<W1R(")%:2!M=75T;W-T82XB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B06QI
M=&%S;VIA(&5I('9O:2!L:7/D=.0@=.1L;&4@;VEK975D96QL92XB"@HC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-C@@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")!<V5T=6MS:6$@96D@
M;/9Y='EN>70@)7,Z;&QE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#4U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B07-E='5K<VEA(&5I(&SV
M>71Y;GET($944"!61E,Z;&QE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B07-E='5K<VEA(&5I
M(&SV>71Y;GET(%-13"!61E,Z;&QE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@
M(D%S971U:W-I82!E:2!L]GET>6YY="!344PM1FEL92!61E,Z;&QE+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DMR961I:71I="!L
M;W!P=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM
M<V=S='(@(DMO:&1E='1A(&5I(&%N;F5T='4N(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3(P"FUS9VED(").;R!F:6QE('5P;&]A9&5D
M(@IM<V=S='(@(D5I('1U;W1U(&%I;G5T=&%K86%N('1I961O<W1O82(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U
M;F0N(@IM<V=S='(@(DEK;VYE:71A(&5I(&SV>71Y;GET+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3,P(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V"FUS9VED(").;R!L
M;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(E!A:6MK86$@96D@;VQE(&%S971E
M='1U+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")086EK:V%A(&5I
M(&]L92!A;FYE='1U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R(")%:2!A;FYE='1U('9I97-T:>0N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO
M(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").:6UEY"!E:2!O;&QU="!A;FYE
M='1U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M("),=6MU;>3D<N3D(&5I(&]L;'5T(&%N;F5T='4N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B16D@;&]U:VMA879A="!M:65T96QA=7-E970B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($A45%`M875T96YT:6MO:6YN:7-S
M82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(E-A;&%S86YA82!E:2!O;&4@86YN971T=2!)34%0+6%U
M=&5N=&EK;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA<V%N86$@96D@;VQE
M(&%N;F5T='4@2V5R8F5R;W,M875T96YT:6MO:6YN:7-S82XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-"!F<F%M97=O<FLO075T:"]!
M=71H+W!A;2YP:'`Z-S4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HW-PIM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA<V%N86$@96D@;VQE(&%N;F5T
M='4@3&]G:6X@875T96YT:6MO:6YN:7-S82XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA
M<V%N86$@96D@;VQE(&%N;F5T='4@4$%34U=$+6%U=&5N=&EK;VEN;FES<V$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")386QA<V%N86$@96D@;VQE(&%N;F5T='4@4TU"+6%U=&5N=&EK
M;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R
M>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T
M;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B)0;VQK
M=6$@3W!E;E-33"!K;VUE;G1O;VX@96D@;VQE(&WDY')I=&5L='DN($]P96Y3
M4TP@<&ETY.0@;VQL82!KY'ET971TY'9I<W/D("(*(FIO<R!KY'-I=&5L;.3D
M;B!02T-3(#$R(&1A=&%A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T
M<B`B16D@<VESY.1N:VER:F%U='5M:7-P>7EN=/9JY"!J;VYO<W-A+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E
M="XB"FUS9W-T<B`B2VEI;G1I]G3D(&5I(&]L92!A<V5T971T=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*
M;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(D5I('/DY&YT]FKD(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T
M;W(@<W!E8VEF:65D+B(*;7-G<W1R(")%<F]T:6YT82!E:2!O;&4@;>3D<FET
M96QT>2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")%:2!R975N
M;VIA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@
M(DYO('-U8V@@9FEL92(*;7-G<W1R(")%:2!L]GET>6YY="!T:65D;W-T;V$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(E;D;&EM=6ES=&EL;&4@96D@;VQE(';D;&EA:6MA:7-H86ME;6ES
M=&]A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="XB"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7-T82!T86D@<V%L87-A;F%A(&5I
M(&SD:&5T971T>2XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B2V%I:VMI('!A;&%U='5N=70@6$U,+61A=&$@;VQI(&5PY&ME;'!O82(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`B16D@87)V;VIA(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*(E9E<G-I;W1I971O:F$@96D@;/9Y='EN>70@
M86QK=7!E<N1I<VETY"!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@
M(@HB87-E='5K<V5T('5U9&5S=&%A;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"B)697)S:6]T:65T;VIA(&5I(&SV>71Y;GET(&%S971U:W-I<W1A+B!3
M:6YU;B!P:73DY"!T96ADY"!A<V5T=6MS970@=75D97-T86%N+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B16D@;6ETY.1N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*
M;7-G<W1R(")%:2!M:73DY&X@*$OD>73D(&EM<&QI<VEI='1I<W3D*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX
M.#4Y+3$P*2(*;7-G<W1R("),87!P:2]0;VAJ;VES;6%A="]%<VMI;6\@*$E3
M3RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,@IM<V=I9"`B3F]R9F]L:R!)<VQA
M;F0B"FUS9W-T<B`B3F]R9F]L:R!S86%R970B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(E!O:&IO:6YE;B!P86QL;VYP=6]L:7-K
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U.`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S(@IM<V=S='(@(E!O:&IO:7-E="!-87)I86%N:65N('-A87)E="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-@IM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<FIA(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO
M="!!9G1E<B(*;7-G<W1R(")%:2!JY&QK965N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS
M9W-T<B`B16D@96YN96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,34*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")%:2!O;&4@
M:&%K96UI<W1O(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*;7-G:60@(DYO
M="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B16D@;VQE('1O=&5U=&5T='4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM
M<V=I9"`B3F]T('-E="(*;7-G<W1R(")%:2!A<V5T971T=2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HQ.3,@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-3(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S,S(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C8*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3`U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4Y,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8Y
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")%:2!T=65T='4N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDP.`HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X"FUS9VED(").;W1E<R(*;7-G<W1R
M(")-=6ES=&EI;G!A;F]T(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N
M<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS
M9W-T<B`B16D@;6ETY.1N('-E;&%T=&%V86$L('!A;&%A('1A:V%I<VEN+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R(")M87)R87-K=74B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B
M3'5K=6WDY'+D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R.0IM
M<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B365R:VMI96X@
M;'5K=6WDY'+D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(E-A<F%K:V5I9&5N(&QU:W5MY.1RY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0W('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W
M<R(*;7-G<W1R(")2:79I96X@;'5K=6WDY'+D(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E
M<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(DIA:V5L=6QI<W1A;B!N=6UE<F]I=&$@96D@;VQE
M(&WDY')I=&5L='D@<.1I=FET971TY';D:W-I+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T
M<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT:2(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R(")/8FIE:W1I;B!L=6]J82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]K=&%A
M;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")L;VMA:W5U(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G
M<W1R("),;W5K:V%A=G5U<W-U;V1A=&EN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(E1O:6UI<W1O
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S
M='(@(E5U<VD@<V%L87-A;F$@96D@<V%A(&]L;&$@<V%M82!K=6EN(&YY:WEI
M;F5N('-A;&%S86YA<VDN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B5F%N:&$@<V%L
M87-A;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B5F%N
M:&$@<V%L87-A;F$@;VX@=N3D<FEN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,0IM<V=I9"`B
M3VUA;B(*;7-G<W1R(")/;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E9A:6X@24U!4"UP86QV
M96QI;65T('1U:V5V870@:F%E='1U:F$@:V%N<VEO:71A+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B5F%I;B!L;W5K:V%A=F%T(&UI971E;&%U<V5E="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R(")6;VET(&QA:71T86$@=F%I;B!Y:&1E;B!S
MY&AK]G!O<W1I;W-O:71T965N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB5F%I;B!O;6ES
M=&%J82!T86D@:N1R:F5S=&5L;>1N('EL;.1P:73D:N0@=F]I(&UU=71T86$@
M:F%K;VIE;B!O;6ES=&%J:6$@=&%I("(*(F]I:V5U:W-I82(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R"FUS
M9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!=F%A('5U9&5S
M<V$@:6MK=6YA<W-A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*
M(D]P96Y34TP@=FER:&4Z(%1I971O:F$@96D@<V%A='4@97-I;&QE(&%L;&5K
M:7)J;VET971U<W1A(%,O34E-12UO<V%S=&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%V86$@
M=.1MY&X@;&EN:VEN('5U9&5S<V$@:6MK=6YA<W-A(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S
M='(@(DOD>71T]FKD<FIE<W1E;&WD(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")!<V5T=6MS
M970B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B07-E='5K<V5T("5S.FQL92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@
M3&ES="(*;7-G<W1R(")*Y')J97-T971T>2!L:7-T82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I
M;VXB"FUS9W-T<B`B3W)G86YI<V%A=&EO(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B3W)G86YI<V%A=&EO>6MS:6MK]B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T
M<B`B3W)G86YI<V]I;G1I(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*
M;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@
M(D%L:W5P97+D:6YE;B!O:&IE;&UA;B!M86QL:2(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B06QK=7!E<N1I<V5T(&UA;&QI="`E
M<SIS<^0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@
M(DUU=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DUU=70@=&EE9&]T(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B3VUI<W1A:F%N(&]I:V5U9&5T(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-+6%U=&5N=&EK
M;VEN=&EA(&5I(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ
M36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.DUA:6P@=&%U<W1A:N1R:F5S
M=&5L;>0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B1&EG:71A
M86QI;F5N(%!'4"UA;&QE:VER:F]I='5S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(E!'4"US86QA='1U82!T:65T;V$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME
M>2(*;7-G<W1R(")*=6QK:6YE;B!01U`M879A:6XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"UA;&QE:VER:F]I=&5T='5A(&IA
M('-A;&%T='5A('1I971O82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM
M<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0+6MO;V1I(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0
M+6MO;65N=&]T=6QK:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0
M32!K979Y='3D('-A9&5T=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")032!S
M861E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B4$T@:W5U<F]J82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(E!-(&QU;6DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(E!-(&QU;6ES871E:71A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-U;B(*;7-G
M<W1R(")032!L=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E!-('5K
M:V]S;7ER<VMY:N0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS
M9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")03U-)
M6"UL86%J96YN=6MS970@<'5U='1U=F%T(@H*(SH@;&EB+V%P:2YP:'`Z,30Y
M"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`M:V]M96YT;W1U;&MK
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B5.1Y=&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#<*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-`IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DR"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D(@IM<V=S='(@(E!A;&5S=&EI;F$@*&UI96AI=&5T='D@86QU92DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#(*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#4*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T
M<B`B4&%P=6$@575S:2U'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO=61Y
M(@IM<V=S='(@(D]S:71T86EN('!I;'9I<W3D(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`R,@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B
M"FUS9W-T<B`B4V%L87-A;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R(")386QA<V%N86X@=F%I:'1O(&]N;FES='5I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S
M<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E;DY'+D('-A;&%S86YA(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4V%L87-A;F%A('1A<G9I=&%A;B!2041)55,M875T96YT:6MO:6YT
M:6EN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3<*;7-G:60@
M(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E-A;&%S86YA
M('9A<FUI<W1U:W-E;&QA(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4V%L87-A;F$Z(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W
M;W)D.B`B"FUS9W-T<B`B4V%L87-A;F$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")386QA<V%N;VIE;B!P:73DY"!O;&QA('-A
M;6%T+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")0
M87-T92(*;7-G<W1R("),:6ETY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O
M87)D(@IM<V=S='(@(DQI:73D(&QE:6ME</9Y9.1L=.0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H
M(@IM<V=S='(@(E!O;&MU(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B2F]N;W-S
M82!O;&5V870@<VESY.1N:VER:F%U='5M:7-P>7EN;O9T.B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DEH
M;6ES970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0<F]S96YT=&DB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM
M<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@
M(E-U;W)I=&$@>6QLY'!I=&]T;VEM96YP:71E970B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E-U;W)I=&$@>6QLY'!I=&]T
M;VEM96YP:71E970@<VESY.1N:VER:F%U='5M:7-E;B!Y:'1E>61E<W/D+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")0
M97)M:7-S:6]N(@IM<V=S='(@(D]I:V5U<R(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<
M(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(D]I:V5U='1A(%PB)7-<(B!E
M:2!P;VES=&5T='4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DOD>71T]B!K
M:65L;&5T='DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B3VEK975D970B"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-C`@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")/:6ME=6MS:65N('EL;.1P:71O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")/
M;6%T('1I961O="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R=2(*;7-G<W1R
M(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0
M971S(@IM<V=S='(@(DQE;6UI:VET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V"FUS9VED(")0
M:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<'!I:6YI="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE
M(@IM<V=S='(@(E!U:&5L:6XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B5F%L;VMU=F%T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I:W-E;&DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B
M2VQI<V5E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;"(*;7-G<W1R(").87!S875T82!J;W1A:6X@<V]L=6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`B5F%R;6ES=&$@971TY"!H86QU870@
M<&]I<W1A82!TY&WD;B!E;&5M96YT:6XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N(@IM<V=S='(@(E9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@;&EN
M:VET>6MS96X@=.1HY&X@96QE;65N='1I:6XN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4V-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`B06YN82!K=75K875S:2!J82!V=6]S:2XB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ
M,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3HB"FUS9W-T<B`B06YN82!N:6UI('5U9&5L;&4@;'5O:VET=6MS96QL
M93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")!;FYA
M(&]I:V5A($E0+6]S;VET92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C0T"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R(")!
M;FYA(&]I:V5A('#D:7;D;>3D<N0[(%1A<FMI<W1A('#D:79I96X@;'5K=6WD
MY'+D(&MU=6MA=61E<W-A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S
M='(@(D%N;F$@86EK82!O:6ME87-S82!M=6]D;W-S82XB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(D%N;F$@;'EH
M>70@:W5V875S(&]N9V5L;6%S=&$N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED
M(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*
M;7-G<W1R(")!;FYA(&OD>71TY&KD='5N;G5K<V5S:2!J82!S86QA<V%N87-I
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R
M("(B"B),=64@<V5U<F%A=F$@=&5K<W1I+B!3:6YU;B!0253$Q"!S=6]S='5A
M(&OD>71T]F5H=&]I:&EN('9O:61A:W-E<VD@:^1Y='3DY"`B"B)JY')J97-T
M96QMY.0N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93HB"FUS9W-T<B`B06YN82!N:6UI('5U9&5L;&4@;'5O:VET=6MS
M96QL93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#@*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0
M=6]L82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B4&]L:71I:6MK82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(DMY<V5L>70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T
M=6=A;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4B"FUS9W-T<B`B5.1MY&X@:W5V86X@<&%I:VMA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O
M<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B5.1MY&X@=&%U;'5K
M;VX@<&%I:VMA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3(*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*;7-G<W1R(")6;VD@;.1H971TY.0@=FEE<W1E:N0@:V%N
M<VEO;VX@*&5I(&MO<VME($E-05`@>6AT97EK<VGD*2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@(@IM<V=S='(@(E-A9&5MY.1RY"!E9&5L;&ES:6QL92`E<R!T=6YN
M:6QL93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM
M<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")(86EH
M='5V=75S(#QB<B`O/G1O9&5N;N1K]FES>7ES(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S
M"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(%1A<G9I
M='1A=F%A('-E<W-I;VXM;&%A:F5N;G5S=&$@96D@;/9Y='EN>70B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T
M<B`B26QM86YP86EN92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS
M9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("));&UA;G!A
M:6YE(&UE<F5N<&EN;F%S<V$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B26QM86YP
M86EN93H@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B17-I
M:V%T<V5L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D5S:6MA='-E;&4@:W5V82!U=61E
M<W-A(&EK:W5N87-S82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S4V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED
M(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D5D96QL:7-E="!A<V5T=6MS
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")4=6QO<W1A(&1O
M:W5M96YT=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E-A;&%I;F5N(&%V86EN
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R(")/;F=E;&UA(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S
M='(@(D]N9V5L;6%N(&MU=F%U<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:W1I="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$Y,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@P"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")+96AO='1E96X@=&5K
M<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(DIU;&MI;F5N(&%V86EN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U
M8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(DIU;&MI<V5N(&%V86EM96X@
M86QG;W)I=&UI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R(")*=6QK:7-E
M;B!A=F%I;65N('1I961O="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B2G5L:VES96XO<V%L
M86ES96X@879A:6YP87)I;B!L=6]N=&D@97#D;VYN:7-T=6DN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,0IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I
M8V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5F]I('1U:&]T82!P
M;VES=&5T='5J82!V:65S=&5JY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38*;7-G:60@(E%A
M=&%R(@IM<V=S='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T
M"FUS9VED(")1=65R>2(*;7-G<W1R(")+>7-E;&4B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMI:6YT:?8B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R(")24T$@2G5L:VEN96X@879A:6X@*"5D(&)I='1IY"DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I
M;VXB"FUS9W-T<B`B4F%D:6]P86EN:6ME(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B
M4V%D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0V"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(E-A9&5T=&$@86EK86ES
M:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(E-A9&5T=&$@;7GV:.3D;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")3861E:W5U<F\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R(")697-I(&IA(&QU;6DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!T
M;R!3;F]W(@IM<V=S='(@(E9E9&5S=.0@;'5M965N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@
M(E-A='5N;F%I;F5N(&UI971E;&%U<V4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E-U:&1E(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@
M(E)E860B"FUS9W-T<B`B3'5K=2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@X"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(E9O:2!L=6ME82!V:65S=&5JY"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R(")0;VES=&5T86%N:V\@)7,_(%3D=.0@=&]I;6EN=&]A(&5I('9O:2!P
M97)U=71T86$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(E!O:7-T971A86YK;R!T:65D;W0@:^1Y='3D:N1S=.0@
M)7,_(%3D=.0@=&]I;6EN=&]A(&5I('9O:2!P97)U=71T86$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5&5E(&UU=71O:W-E
M="!U=61E<W1A86XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R
M(")0Y&EV:73D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I
M9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(E#D
M:7;D="!D>6YA86UI<V5T('9A;&EK:V]E;&5M96YT:70Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE
M=SHB"FUS9W-T<B`B4.1I=FETY"!P;W)T86%L:6[D:WEMY.0Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I
M9"`B4F5G97@B"FUS9W-T<B`B4^3D;F[V;&QI;F5N(&QA=7-E:V4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,U"FUS9VED(")296QA=&EO;G-H
M:7`@0G)O=W-E<B(*;7-G<W1R(")296QA871I;W-E;&%I;B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("),871A82!U=61E
M;&QE96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B4F5M
M87)K<R(*;7-G<W1R(")-=6ES=&EI;G!A;F]T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B
M173D<&%L=F5L:6UE="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@IM<V=S='(@(D5TY'!A;'9E;'5N(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,R!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(R"FUS9VED(")296UO=F4B"FUS9W-T<B`B4&]I<W1A(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO
M8VLB"FUS9W-T<B`B4&]I<W1A(&]S:6\B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN
M(@IM<V=S='(@(E!O:7-T82!S87)A:V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T
M=&EN9R(*;7-G<W1R(")0;VES=&$@;75O=&]I;'4B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T
M<B`B4&]I<W1A('!A<FDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R
M"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B4&]I<W1A('1A;&QE=&5T='4@
M<VMR:7!T:2!P86QV96QI;65N(';D;&EA:6MA:7-H86ME;6ES=&]S=&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E!O:7-T82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R(")0;VES=&$@=.1MY"!N;V]D:2!D;VMU;65N=&ES=&$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")2
M96UO=F4@=7-E<B(*;7-G<W1R(")0;VES=&$@:^1Y='3D:N0B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E!O:7-T82!KY'ET=.1J
MY#H@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM
M<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B`B"FUS9W-T<B`B4'EY;G3V]FX@96D@=F]I='4@=F%S=&%T
M82X@5FER:&5K;V]D:3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+B(*;7-G<W1R(")0>7ED971T>>0@<&%L=F5L=6$@96D@;/9Y='EN
M>70N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S8@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5&%R=FET=&%V86$@7"(E<UPB+71I971O82!E:2!O
M;&QU="!MY.1R:71E;'1Y("5S(&%S971U:W-I<W-A+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#8Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,S$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1A<G9I='1A
M=F%A(%PB)7-<(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!61E,@87-E
M='5K<VES<V$N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<V"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1A<G9I='1A=F%A(%PB
M)7-<(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!A<V5T=6MS:7-S82XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G
M:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(E!A:V]L;&EN96X@:V5N='3D
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS-#,@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
M5'EH:F5N;N0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM
M<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B5'EH:F5N;N0@<V%L87-A
M;F$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")4>6AJ96YNY"!S86QA<V%N
M87-I(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R
M92!,87-T(%%U97)Y(@IM<V=S='(@(E!A;&%U=&$@961E;&QI;F5N(&MY<V5L
M>2(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S(@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM
M<V=S='(@(E1U;&]K<V5T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U
M<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")086QA82!A<V5T=6MS:6EN(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(E9A:'9I<W1A('5U<VD@<V%L87-A;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DW"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E=6YI
M;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(E!A;&%U=&$@87-E='5K<V5T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM
M<V=S='(@(E)I8V@@5&5X="!%9&ET;W)I;B!A<V5T=6MS970B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M07)V;VET=6MS970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*;7-G:60@(E)I9VAT(@IM<V=S='(@(D]I:V5A
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-PIM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(D]I:V5A(&]T<V%K92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G
M<W1R(")/:6ME82!A<G9O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E)I=FE?;B!T:65D;W0N+BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE
M(@IM<V=S='(@(E)O;VQI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.`IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R(")2;VUA;FEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M(")+Y.1N;N0@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B2^3D
M;F[D('9A<W1A<.1I=N3D;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M(")+Y.1N;N0@;7GV=.1PY&EVY.1N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`B4FEV:6X@=&EE9&]T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W
M('!R;W!E<G1I97,B"FUS9W-T<B`B4FEV:6X@=&EE9&]T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O
M=W,Z(@IM<V=S='(@(E)I=FET.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(E9I:79O:71I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B5FEI=F]I
M=&EN(&[D:WEY(&MA:6MK:65N(')I=FEE;B!J82!S87)A:VME:61E;B!VY&QI
M;&SD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'DB"FUS9W-T<B`B5FEI=F]I=&EN(&[D:WEY('9A:6X@<V%R
M86MK96ED96X@=N1L:6QLY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(E9I:79O:71I;B!NY&MY
M>2!V86EN(')I=FEE;B!VY&QI;&SD(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(E-U;W)I=&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DY"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B5F5NY&KD
M;B!&961E<F%T:6EV:6YE;B!T87-A=F%L=&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P"FUS
M9VED(")2=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@:W)Y<'1O9W)A869I
M;F5N(&%L;&5K:7)J;VET=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(E,O34E-12!S86QA='1U('9I97-T:2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"UA=71E;G1I
M:V]I;G1I(&5I(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T
M<B`B4TU3(%1E:W-T:79I97-T:70B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344PM:V]M96YT;W1U;&MK
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S@*;7-G:60@(E-1
M3"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,+6QA
M=7-E(&%R=F]J96X@:&%K96UI<V5E;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(D].3DE35%5)(@H*
M(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@
M(E-?44PM:V]M96YT;W1U;&MK:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(FQA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-PIM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A
M:6YT($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,0IM<V=I9"`B4V%I;G0@2VET=',@
M86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&IA($YE=FES(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Y"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,
M=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0@4&EE<G)E(&IA($UI<75E;&]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-`IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!J82!'<F5N861I:6YI
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")386UA86X@
M:V5H>6MS965N("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q"FUS9VED(")386UO
M82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(*;7-G:60@(E-A;B!-
M87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38*;7-G
M:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!J
M82!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")3871E;&QI
M:71T:2!P86QV96QU;G1A<FIO86IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,0IM<V=I9"`B
M4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I82!!<F%B:6$B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T
M<B`B5&%L;&5T82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T
M<B`B5&%L;&5T82!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(E1A;&QE=&$@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS
M9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B5&%L;&5T82!A<V5T=6MS970B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(E1A;&QE=&$@;'5O9'5T(&%S971U:W-E="!02%`M<VMR:7!T:6[D('!A
M;'9E;&EM97-I(';D;&EA:6MA:7-H86ME;6ES=&]O;BX@(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&%L;&5T971T:6EN("5S
M.FX@87-E='5K<V5T+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D%S971U<W1E;B!PY&EV:71Y<W-K
M<FEP=&D@;VX@=&%L;&5T971T=2!P86EK:V%A;CH@7"(E<UPB+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B2&%J86YA:7-I82!U:VMO<VUY
M<G-K>6KD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(E1I961E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")(86MU(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS
M9W-T<B`B2&%K=6MO;F5E="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-3D*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")686QI='-E('1I
M961O<W1O="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B5F%L:71S
M92!PY&EVY&WDY'+D(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")686QI
M='-E(&QI<^1T=.1VY"!R>6AMY"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6
M86QI='-E('5U<VD@;VUI<W1A:F$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")6
M86QI='-E('!A;'9E;&EN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E9A
M;&ET<V4@;&ESY'1TY';D(&OD>71TY&KD(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R(")686QI='-E(&MA:6MK:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-#<*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+B(*;7-G<W1R(")686QI='-E(&MA:6MK:2!PY&EVY&WDY'+D:V]M<&]N96YT
M:70B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9A;&ET<V4@
M;V)J96MT:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E1Y:&IE;F[D
M('9A;&EN=&$B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)686QI='-E('1A
M<G9I='1A=F%T(&UE<FMI="!A;&QA(&]L979I<W1A('9A;&EK;VES=&$N(%9O
M:70@<V5N(&KD;&ME96X@(@HB:V]P:6]I9&$@:F$@;&EI='3DY"!M97)K:70@
M=&5K<W1I:7-I+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")686QI
M='-E('#D:7;D>6MS96X@97)O=&EN;65R:VMI.B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.B(*;7-G<W1R(")686QI='-E('#D:7;D>6MS96X@97-I='ES=&%P83HB"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED
M(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS
M9W-T<B`B5F%L:71S92!M=75T971T879A('!R;V9I:6QI.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.B(*;7-G<W1R(")686QI='-E(&ME;&QO;F%J86X@97)O=&EN
M;65R:VMI.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED
M(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")686QI='-E(&%J
M86X@97-I='ES=&%P83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B5F%L:71S92!K86MS:2!Y:'1E96YS;W!I=F%A(&ME;G1TY.0N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+B(*;7-G<W1R(")686QI='-E(';D<FET965M82XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9A;&ET<V4@:^1Y=&5T
M=.1VY"!K:65L:3HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("),Y&AE
M=.0@;VYG96QM879I97-T:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R("),
MY&AE=.0@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G
M<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(E1U;FYI<W1I;CH@(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E
M;6)E<B(*;7-G<W1R(")S>7ES:W5U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R
M;R(*;7-G<W1R(")397)B:6$@:F$@36]N=&5N96=R;R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M
M8F5R(@IM<V=S='(@(E-A<FIA;G5M97)O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4&%L=F5L:6UE;B!T:65D;W0@;W9A
M="!VY.1R:>0@=&%I(&5I=N1T(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R("))<W1U;G1O:F5N(&AA;&QI;G1A(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N
M($E$(&5X<&ER960N(@IM<V=S='(@(E-E<W-I;VX@240@;VX@=F%N:&5N='5N
M=70N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G
M<W1R("))<W1U;FYO="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,3@*;7-G:60@(E-E="(*;7-G<W1R(")!<V5T82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+B(*;7-G<W1R("(B"B)386QA<V%N86X@<F5S971O:6YT:6EN(&QI:71T>79I
MY"!A<V5T=6MS:6$L(&IO<R!J;W-K=7,@=6YO:&1A="!S86QA<V%N87-I+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+B(*;7-G<W1R("(B"B)6;VET(&%S971T86$@=6QK;VES=&5N
M('!A;'9E;&EM:65N(&%S971U:W-E="P@:F]I=&$@:&%L=6%T(&OD>71TY.0@
M(@HB<&]R=&%A;&ES<V$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W
M"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(B(*(E9O:70@87-E='1A82!K
MY'ET971TY';D;B!K:65L96XL(&%I:V%V>?9H>6MK965N(&IA(&UU:71A('#D
M:7;D;>3D<N1A<V5T=6MS:6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(E9O:70@87-E='1A82!A;&]I
M='5S;VAJ96QM86XL(';D<FET965M86XL(&[D:WEMY&X@<.1I=FET>6MS96X@
M:F$@;75I=&$@(@HB;N1K>6WDY&X@;&EI='1Y=FGD(&%S971U:W-I82XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G
M<W1R(")!<V5N;G5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4B"FUS9W-T<B`B07-E;FYU:W-E;B!PY&EV:71Y<W-K<FEP=&D@;VX@<V%A
M=&%V:6QL82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*
M;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@(@IM<V=S='(@(E5S96%T('!A:6MA="!S;W!I=F%T(&%N;F5T
M='5U;B!P87)A;65T<FEI;CH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,PIM<V=I9"`B4V5Y
M8VAE;&QE<R(*;7-G<W1R(")397EC:&5L;&ET(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B3W-T
M;VMS970B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM
M<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("),>6AY="!K=79A=7,Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@
M(D%S971E=&$@<&EK879A;&EN=&%NY'!PY&EM970@=7-E:6UM:6QL92!L:6YK
M96EL;&4N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B3N1Y=.0B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D[D>73D(&5R;V%V86ES
M=75D970@87-E='5K<VEE;B!T86QL971E='5S<V$@:F$@=75D97-S82!J=75R
M:2!M=6]K871U<W-A("(*(G9E<G-I;W-S82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(D[D>73D(&5D96QL:7-E;B!S:7/DY&YK
M:7)J875T=6UI<V5N('#D:7;D>7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;"(*;7-G<W1R(").Y'ETY"!A<V5T=7,@<&ETY.1K<V5S:2!A;&MU<&5RY&ES
M96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDY"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R(").Y'ETY"!V86QI='-I;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B3N1Y=.0@=&%U;'5K:V]T;VEM:6YN
M;W0@=F%L:6MK;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_(@IM<V=S='(@(D[D>73D('9A<V5M;6%L;&$@)7,@=F%L:6MK;RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B3N1Y=.0@=&%U;'5K;VX@<V]L=6X@=&EE9&]T(&1I
M86QO9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(D[D>73D('1A=6QU:V]N('1I961O="!D:6%L
M;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B3N1Y=.0@=&%U;'5K;VX@<FEV:6X@=&EE
M9&]T(&1I86QO9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[D>73D(&MU=F%N('1I961O="!D
M:6%L;V=I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-PIM<V=I
M9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B3N1Y=.0@='5O;G1I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H
M;W=E<G,B"FUS9W-T<B`B4V%T96ET82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($5A<FQY(@IM
M<V=S='(@(E-A=&5I=&$@86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(E-A=&5I=&$@;7GV:&5M;6EN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y(@IM<V=S='(@(E-A=&5I=&$@;.1H971T>79I;&QA(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*
M;7-G:60@(E-H<FEN:R(*;7-G<W1R(")0:65N96YNY"(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q
M,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T
M<B`B4&EE;F5N;N0@=&%I('-I:7)RY"!V:65R96ES:>0@;W-I;VET82P@:F]T
M=&$@;F4@96EVY'0@;VQE('1I96QLY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P
M(@IM<V=S='(@(DMI<FIA=61U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")!;&QE
M:VER:F]I='5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QL
M96MI<FIO:71U:W-E;B!A;&=O<FET;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V"FUS9VED
M(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(T,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C4P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,38*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$P.0IM<V=I9"`B4VEZ92(*;7-G<W1R(")+;VMO
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VAI=&$@>6QL
MY'!I=&]T96ATY';D="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A:VEA
M(@IM<V=S='(@(E-L;W9A:VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.`IM<V=I9"`B4VQO
M=F5N:6$B"FUS9W-T<B`B4VQO=F5N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R("),
M=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3<*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(DQU;6ES861E='1A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("),=6UI<V%T96ET82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B3'5M:7-A=&5I=&$@86EK86ES
M:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B3'5M:7-A=&5I
M=&$@;7GV:.3D;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED
M(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B3'5M96X@<WEV>7ES.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B`B"FUS9W-T<B`B3'5M96X@;>3D<N0@=F5T96[D.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`R"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B
M4V%L;VUO;B!S86%R970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B3&%U;'5T(&IA(%)U
M;F]U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3(*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(DKD<FIE<W1Y:W-E;B!S
M=75N;F%N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S
M<R(*;7-G<W1R("),Y&AD96]S;VET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34*;7-G:60@
M(E-O=71H($%F<FEC82(*;7-G<W1R(")%=&5LY"U!9G)I:VMA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R(")%=&5LY"U%=7)O;W!P82`H25-/+3@X-3DM
M,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D5T96SD+4=E;W)G
M:6$@:F$@971E;.1I<V5T(%-A;F1W:6-H('-A87)E="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O
M=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B171E;.1I;F5N('!A;&QO;G!U
M;VQI<VMO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B
M"FUS9W-T<B`B5N1L:2!V:65R96ES970@<V]L=6IE;B!VY&QI<W/D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G
M:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB
M"FUS9W-T<B`B5N1L:2!S;VQU;B!L96EPY'1E:W-T:6X@:F$@<F5U;F%N(';D
M;&ES<^0@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$Y"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`B5N1L:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0IM<V=I9"`B4W!A8VEN9R(*
M;7-G<W1R(")6Y&QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN
M9R(*;7-G<W1R(")6Y&QI(&IA('3D>71E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`*;7-G:60@
M(E-P86EN(@IM<V=S='(@(D5S<&%N:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E)O<VMA<&]S=&DB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(D5R:6MO:7-M97)K:VEE;B!S>?9T
M=/8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(DIA82!S;VQU
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(DIA82!S87)A
M:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B2F%A(')I=FDB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*
M;7-G<W1R(")5<FAE:6QU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q"FUS9VED(")3<FD@3&%N
M:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8*;7-G:60@(E-T
M86YD87)D(@IM<V=S='(@(E-T86YD87)D:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E
M:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3`@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R
M(")!;&MA;6ES=G5O<VDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B
M3.3D;FD@=&%I(&%L=64B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E1I;&$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Q"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R(")486QL96YN=7-M=6]T;R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S
M<R(*;7-G<W1R(")+871U;W-O:71E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R("),Y'!I;'GV;G1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B365R:VMI:F]N
M;VQI<W1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I
M9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B4&]I
M<W1A('1O:6UI86QU92!O<V]I='1E97-T82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(E1Y>6QI(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T
M<B`B<W4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%L:6AA:V5M:7-T;V$@7"(E<UPB(&5I(&SV>71Y;GET+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G
M:60@(E-U8FIE8W0B"FUS9W-T<B`B3W1S:6MK;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S-B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("),Y&AE=.0B"@HC.B!S
M:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"B),Y&AE=&5T=&EI;B!<(B5S7"(Z;B!L:7/D
M>7-P>7EN=/8N($5T('9O:2!K:7)J875T=6$@<VESY.1N(&5N;F5N(&MU:6X@
M(@HB<'EY;G3V<VD@;VX@:^1S:71E;'1Y(&IA(&AY=N1K<WET='DN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I
M9"`B4W5B<V-R:7!T(@IM<V=S='(@(D%L:6MI<FIO:71U<R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R(")/;FYI<W1U:2(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB.B!L:7/DY&UI;F5N
M(&KD<FIE<W1E;&WDY&X@;VYN:7-T=6DN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B2^1Y='3D:N1N(%PB)7-<(B!KY'ET=.1JY'1I971O:F5N('!O:7-T86UI
M;F5N(&KD<FIE<W1E;&WD<W3D(&]N;FES='5I+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B!P;VES=&5T=&EI;B!O;FYI<W1U;F5E<W1I+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"(Z(&]N;FES='5T=&EI;B!P;VES=&%M86%N(&KD<FIE<W1E;&WD
M<W3D+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(E!A;&%T=&EI;B!O;FYI<W1U;F5E
M<W1I('9A;FAO:6AI;B!A<V5T=6MS:6EN+B!,871A82!S:79U('5U9&5S=&%A
M;B`B"B)NY&ADY&MS97-I(&UU=71O:W-E="XB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HU-R!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D*;7-G:60@
M(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B5&%L;&5N;F5T=&EI;B!A<V5T=6MS:65N('9A<FUU=7-K;W!I;RXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B5&%L;&5N;F5T=&EI;B!A<V5T=6MS
M:65N('9A<FUU=7-K;W!I;R`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E
M<UPB(@IM<V=S='(@(B<E<R<Z('#D:79I='ES(&]N;FES='5I+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E
M<R(*;7-G<W1R("(E<SIN(&MI<FIO:71T86UI;F5N(&]N;FES='5I+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")9:'1E96YV971O(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R
M(")!=7)I;F=O;FYO=7-U(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X
M"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(D%U<FEN9V]N;&%S:W4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M4W5N;GDB"FUS9W-T<B`B075R:6YK;VEN96XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D%U
M<FEN9V]N;F]U<W4B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM
M<V=S='(@(D%U<FEN:V\@;F]U<V5E+VQA<VME92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R
M(")!=7)I;F=O;FYO=7-U.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B075R:6YG;VYL87-K
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(D%U<FEN9V]N;&%S:W4Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U
M<&5R<V-R:7!T(@IM<V=S='(@(E#DY&QL96MI<FIO:71U<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`B5'5K:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")3=6MU;FEM:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B2'5I<'!U=G5O<F5T(&IA($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3D*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6UA82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#4*;7-G:60@(E-W961E;B(*;7-G<W1R(")2=6]T<VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4W9E:71S:2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC
M(&QO9R!D96QE=&5D(@IM<V=S='(@(E-Y;F,@;&]K:2!P;VES=&5T='4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS
M9W-T<B`B4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E-Y;G1A:W-I=FER:&4@:&%K=71E<FUE:7-SY"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y
M>7)I82P@87)A8FET87-A=F%L=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")5
M:VMO<VUY<G-K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")5
M:VMO<VUY<G-K>6KD(&IA('1U=6QI<W1A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S
M='(@(E5K:V]S;7ER<VMY="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")5:VMO<VUY<G-K>6KD(&%I:V%I<VEN(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6
M+71I961O<W1O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A=6QU:VMO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B
M5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")4875L=6MO;B!T:65D;W0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`B5&%U;'5K;VX@87-E='5K<V5T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")4875L=6MO
M;B!T:65D;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T"FUS9VED(")486EW86XB
M"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B5&%I=V%N+"!+:6EN86X@;6%A:W5N=&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(U"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9'II:VES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-0IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B(*;7-G<W1R(")486YZ86YI82P@66AD:7-T>6YY="!T87-A=F%L=&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"FUS9VED(")487)G970Z(@IM<V=S='(@(DMO:&1E.B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,R(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#D*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#D*;7-G:60@(E1A
M<VMS(@IM<V=S='(@(E1E:'3D=N1T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS
M9W-T<B`B4'5H96QI;FYU;65R;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("),Y&UP
M]G1I;&$@961E;&QI<V5L;&4@='5N;FEL;&4Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("),Y&UP
M]G1I;&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS
M9VED(")496UP97)A='5R93H@(@IM<V=S='(@(DSD;7#V=&EL83H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(DSD;7#V=&EL83QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B36%L;&EA(%PB)7-<(B!E:2!L]GET>6YY="XB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B36%L;&EE;B!H86QL:6YT82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S,0IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS=&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS
M9W-T<B`B5F%I;B!T96MS=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM
M<V=S='(@(E1E:W-T:6X@=&%S875S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R
M(")496MS=&ET;W`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")T;R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G
M<W1R(")4:&%I("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(E1H86EM86$B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B1E10+6QI<^1T;VEM:6YT;R!E:2!O;&4@
M:^1Y=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y
M+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D
M+B(*;7-G<W1R(")(:7-T;W)Y(&KD<FIE<W1E;&WD(&5I(&]L92!KY'ET971T
MY'9I<W/D+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86(@:6YT96=R;VEN=&EM;V]T=&]R:2!E:2!T=64@7"(E<UPB(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I
M9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS
M9W-T<B`B24U34"!L;VMI82!E:2!V;VET=2!A;'5S=&%A+B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")-
M86EN=&5N86YC93HZ("UL=6]K86X@;&%T86%M:6YE;B!E<.1O;FYI<W1U:2(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@
M(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R(")!<V5T=6MS970@:6MK=6YA(&]N('-U;&IE='1U+B!0;VES='5T86%N
M+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*(EEL;.1P:61O;B!P:73DY"!O='1A82!K
MY'ET=/;V;B!P>7-Y=N0@=&%L;&5T=7-T>7EP<&D@4&5R;6ES<VEO;BP@:F]S
M(&AA;'5A="`B"B)KY'ET=.3D(&YI:73D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B
M;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(E9A:6X@86QA<'5O;&DB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM
M<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A
M=&%B87-E+B(*;7-G<W1R("(B"B)#;VYT86-T(&ED(&YU;65R;V$@96D@;VQE
M(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY="!T:65T;VMA
M;FYA<W1A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B66AT97ES=&EE
M9&]T(&QI<^1T=&EI;B!O;FYI<W1U;F5E<W1I(&]S;VET96MI<FIA87-I+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@
M(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(E9I97-T:6X@86QL96MI<FIO:71U:W-E;B!T87)K:7-T86UI<V5E;B!T87)V
M:71A86X@97)I;&QI;F5N(%!'4"TB"B)A;&QE:VER:F]I='5S;&]H:V\N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*
M(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB2F%K96QU;&ES=&%N($E$
M(&5I(&]L;'5T(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY
M="!T:65T;VMA;FYA<W1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DIA:V5L=6QI<W1A
M82!E:2!O;&QU="!MY.1R:71E;'1Y+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")386QA
M=7-T;VEM:6YN;VX@:^1Y='3V('9A871I('-A;&%T='5A(%=75RUY:'1E>71T
MY"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-R!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S
M='(@(E1I961O<W1O<W-A("5S('!I=.1I<VD@;VQL82`E<R!A<V5T=7,N(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S`@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T
M<B`B5&EE9&]S=&]S<V$@)7,@<&ETY&ES:2!O;&QA(&IO:71A:VEN("5S(&%S
M971U:W-I82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C8*
M;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N
M(@IM<V=S='(@(E1I961O<W1O82!E:2!V;VED82!K;W!I;VED82!I='-E;G/D
M('#DY&QL92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G
M:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")4:65D
M;W-T;R!O;&D@='EH:N0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE
M(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS
M9W-T<B`B4V5U<F%A=F%S<V$@;VX@;W1S:6MK;W1I961O="!TY'-TY"!M97-S
M86=E+W)F8S@R,B`M=FEE<W1I<W3D+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB2V]K;W)U
M=61U;B!NY'ET=/9T:6QA(&%I:&5U='1A82!O;F=E;&UI82!J;VEL;&%K:6X@
M26YT97)N970@17AP;&]R97(@(@HB<V5L86EM96X@:^1Y='3D:FEL;.0N(%9A
M;&ET971T879A<W1I(&MY<V5I;F5N('-E;&%I;B!S:7/D;'3DY"!P:6ER=&5I
M=.0@:F$@(@HB=FER:&5I=.0@:F]I:&EN(&5I(&]L92!L]GET>6YY="!K;W)J
M875S=&$@=&%I(&ME:6YO82!K:65R=.3D(&]N9V5L;6$N("(*(DAU;VUA871H
M86X@971TY"!J;W,@:^1Y=.1T('3D=.0@;N1Y='3V=&EL86$@:F$@26YT97)N
M970@17AP;&]R97(@<V5L86EN=&$L("(*(FYI:6X@;N1Y='3V('-A871T86$@
M;65N;N0@<V5K86ES:6XL(&IO=&MU="!T;VEM:6YN;W0@96EVY'0@=&]I;6D@
M=&%I('-E;&%I;B`B"B)S86%T=&%A(&MA871U82X@2F]S(&OD>73D="!7:6YD
M;W=S(#EX('1A:2!-12!V97)S:6]T82P@;FEI;B!O;B!M86AD;VQL:7-T82`B
M"B)E='3D(&OD>71T]FKD<FIE<W1E;&WD(&MA871U=2!N<RX@)T=E;F5R86P@
M4')O=&5C=&EO;B!&875L="<@+79I<FAE97-E96X@:F$@(@HB<VEN=6X@<&ET
MY.0@:^1Y;FYI<W3DY"!K;VYE('5U9&5S=&%A;BY<7&Y<7&X@375I<W1A(&5T
M=.0@<VEN=6$@;VX@(@HB=F%R;VET971T=2X@3F%P<V%U=&$@3TLM;F%P<'5L
M86$@:F]S(&AA;'5A="!K;VME:6QL92!E9&ET;W)I;B!K;VMO<G5U='4@(@HB
M;N1Y='3V=&EL86$N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(E!O:7-T971T:6EN('!R;V9I:6QI(%PB)7-<
M(BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R(")686EN('9A<V5N('!U;VQI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B1VYU4$<@;VAJ96QM86X@<VEJ86EN=&D@<&ET
MY.0@;>3D<FET96QLY"!#<GEP=%]P9W`Z.B`M;'5O:V%S<V$N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(E9I97-T:2!LY&AE=&5T='D@)7,@
M=F%S=&%A;F]T=&%J86QL92`E<R!O='-I:VMO;F$@7"(E<UPB(&]N(&[D>71E
M='1Y+EQN(@HB16D@;VQE(&UI=.3D;B!T86ME:71A('-I:73D(&5T=.0@=FEE
M<W1I(&]N(&QU971T=2!T86D@>6UMY')R971T>2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3FEM:2!J
M;W1A(&OD>71E=.3D;B!L:6YK:71E='3D97-S82!L=6\@<VEV=6QL92(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")+96YT
M=&EE;B!MY.1RY"!P:73DY"!A;G1A82!N=6UE<F]I;F$N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+B(*;7-G<W1R(")-;V1U=6QI(&]P96YS<VP@=&%R=FET
M86%N($AO<F1E7T-R>7!T7W-M:6UE.CH@+6QU;VMA;B!KY'ET=.1M:7-E:W-I
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N
M;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)!<V5T=7-T82!<
M(B5S7"(@:V]S:V$@<V5N('1I961O="!Y;&ET=&EVY'0@=&%L;&5T=7-T879A
M;B!S=75R:6UM86X@<V%L;&ET=6X@(@HB<F%J86XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*(D]H:F5L;6%A+"!J;VQL82!V;VD@:V%T<V]A('9I97-T:71Y>7!P
M:>0@*"5S*2P@96D@;/9Y='EN>70@:N1R:F5S=&5L;>1S=.0N(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@
M8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(DQA:6YA=7-M97)K:VD@<&ETY.0@;VQL82!Y:W-I='3D:6YE;B!M97)K
M:VDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B5F%I;B!O:6ME82!J82!V87-E;B!P=6]L:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*
M;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")686EN
M(&]I:V5A('!U;VQI(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(D5R;W1I;B!P:73DY"!O;&QA('EK<VET=.1I
M;F5N(&UE<FMK:2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")086QV96QI;B!<(B5S7"(@;VX@<&]I
M<W1E='1U+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R(")086QV96QI;B!<(B5S7"(@;VX@=&%L;&5T971T
M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D
M+B(*;7-G<W1R(")3:7/DY&YK:7)J875T=6UI<W!Y>6YT]B`E<R!O;B!P;VES
M=&5T='4N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE
M9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3>3D<FET96QT
M>>0@<FEV:>0@*"5D*2!E:2!O;&4@;VQE;6%S<V$N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B5F%L:>1A:6MA:7-T:65D;W-T;V$@7"(E<UPB(&5I(&]L92!O;&5M87-S
M82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"FUS9VED(")4
M:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N
M('1H92!S8W)E96XN(@IM<V=S='(@(DMI<FIO:71T86UA<VD@=&5K<W1I(&5I
M('9A<W1A82!T96MS=&GD(')U=61U;&QA+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(E9A:6X@>6SD<'5O
M;&D@:F$@86QA<'5O;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL
M>2(*;7-G<W1R(")686EN('ELY'!U;VQI(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B5'5O='4@=&EE
M=&\@:.1V:7-I(&5D96QL:7-E;B!K;VAD86X@86EK86YA+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@
M;F]T(&)E('-A=F5D+B(*;7-G<W1R(")4=6]T=6$@=&EE9&]S=&]A(&5I('9O
M:71U('1A;&QE='1A82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B
M5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D]S:6]T82!W96%T:&5R+F-O;2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")4965M86AA:V5M:7-T;V$@7"(E<UPB(&5I(&SV>71Y;GET+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(D%S971U:W-I
M82!E:2!O;&4@<V%A=&%V:6QL82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HS-#@*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")%:2!O;&4@
M;W-I;VET82P@:F]T:V$@=F]I9&%A;B!NY'ET=.3D('9I97-T:65N('EH=&5Y
M9&5S<^0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@HB5.1S<^0@:V5N=.1S<^0@;VX@;&EI86X@;6]N=&$@;65R:VMIY"X@
M06YN;VET("5S(&UE<FMK:>0[('-I;G5N('!I=.3D(&%N=&%A("(*(G;D:&5M
M;>1N(&MU:6X@)7,@;65R:VMIY"XB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN
M+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G
M<W1R(")*;VET86MI;B!O;F=E;&UI82!<(B5S7"(@;&ESY.1M:7-E<W/D(&KD
M<FIE<W1E;&WDY&XZ("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B(@HB2^1Y='3D:N1N(%PB)7-<(B!KY'ET=.1JY'1I971O:F5N('!O:7-T
M86UI<V5S<V$@:N1R:F5S=&5L;>1S<^0@;VQI(&]N9V5L;6EA.B`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M.B`B"FUS9W-T<B`B2F]I=&%K:6X@;VYG96QM:6$@7"(E<UPB('!O:7-T86UI
M<V5S<V$@:N1R:F5S=&5L;>1S=.0Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B2F]I=&%K:6X@;VYG96QM:6$@
M7"(E<UPB('#D:79I='EK<V5S<^0Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.3(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"XB"FUS9W-T<B`B5&EE9&]S=&]N('1U;VYN:7-S82!O;&D@
M;VYG96QM:6$N(%EH=.3D;B`E<SIA(&5I('1U;W1U(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(E1I961O<W1O;B!T=6]N
M;FES<V$@;VQI(&]N9V5L;6EA+B`E<R!K;VMO(&]L:2!S=75R96UP:2!K=6EN
M('-U=7)I;B!S86QL:71T=2`B"B)K;VMO("@E9"!T879U82DN(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(E1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA+B`E<R!L
M871A=71U:2!V86EN(&]S86MS:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")487!A
M:'1U:2!V:7)H92!NY'ET971TY&5S<^0@=FEE<W1I;B!TY'3D(&]S:6]T82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@
M9&%T82XB"FUS9W-T<B`B66AT97ES=&EE=&]J96X@='5O;FYI<W-A('1A<&%H
M='5I('9I<FAE+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<BUT:65T;VIE;B!T=6]N
M;FES<V$@=&%P86AT=6D@=FER:&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB
M<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(D%S971U<W1I971O;&]M86MK
M965S<V$@;VX@:F]K:6X@=FER:&4N($5H:^0@:N1T:70@:F]N:W5N('!A:V]L
M;&ES96X@:V]H9&%N("(*(G3D>71TY&WD='3D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HB5&%P86AT=6D@=FER:&4@>7)I=&5T=.1E<W/D('-U
M;W)I='1A82!O<V]I=&5K:7)J871O:6UI;G1O82X@67)I=.0@;7GV:&5M;6EN
M("(*(G5U9&5S=&%A;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(EEH=&5Y<W1I971O:F5N('#D:79I
M='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E
M<W1A86XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(DIA:V5L=6QI<W1A;B!PY&EV:71Y:W-E<W/D('1A<&%H
M='5I('9I<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.0IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B5.1MY"!)34%0('!A;'9E;&EN(&5I('1U92!K86YS
M:6]I9&5N(&IA:V%M:7-T82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")4Y&WD('1I961O
M<W1O(&5I('9A:6MU=&$@<F%R+71I961O<W1O;'1A+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@
M(E3D;>0@=&EE9&]S=&\@96D@=F%I:W5T82!Z:7`M=&EE9&]S=&]L=&$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S,0IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(E3D;>0@96D@=F%I:W5T82!O:6ME86QT82!K;W)T=&EN=6UE<F]L=&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB
M8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E
M:N0@0VQI8VMA=&5L;&EN("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI("(*(F=A
M=&5W87D@<&%L=F5L=6$@2%144"!!4$DZ;&QA+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@HB5.1L;.0@86IU<FEL;&$@=F]I(&SD:&5T
M=.3D('9I97-T96KD(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87D@
M(@HB<&%L=F5L=6X@:V%U='1A($A45%`@05!).FQL82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E3D;&SD
M(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2`B"B)G871E=V%Y('!A;'9E;'5N(&MA=71T
M82!(5%10($%023IL;&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*(E3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!6
M;V1A9F]N96X@;G5M97)O:6AI;B!33510.FQLY"!KY'ET=.1E;B`B"B)6;V1A
M9F]N92!)=&%L>2!G871E=V%Y('!A;'9E;'5A+B!4Y'3D('!A;'9E;'5A('9O
M:2!KY'ET=.3D('9A:6X@5F]D869O;F4@(@HB271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2!T=6YN=6MS:6QL82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V,0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DP(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8P"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-38Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X,@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R,C4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$W"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")4Y&WD(&ME;G1TY"!O;B!P
M86MO;&QI;F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-CD*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`B5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!V86EN(&MO:V]N
M86ES;'5K=6IA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C`*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN(@IM<V=S='(@(E3D<W/D(&ME;G3D<W/D('!I=.3D(&]L
M;&$@;G5M97)O:71A(&IA('!I;&MK=2UM97)K:V5JY"XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")4Y'-SY"!K96YT
MY'-SY"!P:73DY"!O;&QA(&]K=&%A;&EL=6MU:F$N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B
M"FUS9W-T<B`B(@HB5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!L:7-T82!K
M;VMO;F%I<VQU:W5J82P@:F]T:V$@<&ETY.0@;VQL82!E<F]T971T=2`B"B)P
M:6QK=6QL82!T86D@=N1L:6QY]FYN:6QLY"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+B(*;7-G<W1R(")!<G9O;B!P:73DY"!O;&QA(&YU;65R;RXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(R"FUS9VED("(B"B)4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S
M='(@(B(*(E3D<W/D(&ME;G3D<W/D(&]N(';D<FEMY.1R:71Y<RP@:F]N:V$@
M<&ETY.0@;VQL82!21T(@2&5X(&UU;V1O<W,L("(*(F5S:6UE<FMI:W-I("<C
M,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C4*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B5.1MY"!L;VUA:V4@;VX@:F\@:^1S:71E;'1Y+B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@:7,@)7,N(@IM<V=S='(@(E3D;>0@;VX@)7,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*(E3D;>0@;VX@2V]L86(@1W)O=7!W87)E(&]B:F5K
M=&DN($MA='-O86MS97-I('3D;>1N(&]B:F5K=&EN('-I;G5L;&$@<&ETY.0@
M(@HB;VQL82!SY&AK]G!O<W1I;VAJ96QM82P@:F]K82!Y;6WD<G3DY"!+;VQA
M8B!'<F]U<'=A<F4@9F]R;6%A='1I82X@3&ES=&$@(@HB>6AT965N<V]P:79I
M<W1A('/D:&OV<&]S=&EO:&IE;&UI<W1A(&SV>71Y>2!O<V]I='1E97-T82`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB
M"FUS9W-T<B`B(@HB5.1MY"!V:65S=&D@;VX@:VER:F]I=&5T='4@97)I(&UE
M<FMI<W3V;&SD("@E<RD@:W5I;B!M:6OD('-I;G5L;&$@;VX@(@HB:^1Y=/9S
M<^0N("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS
M9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T
M<B`B3G5M97)O;B!P:73DY"!O;&QA(';D:&EN=.3D;B!Y:W-I+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N(@IM<V=S='(@(E3D;&SD('!A;'9E;&EM96QL82!E:2!V;VD@875K86ES
M=&$@>FEP+2!T86D@9WII<"UT:65D;W-T;VIA+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E
M;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E3D;>0@:N1R
M:F5S=&5L;>0@;VX@<&]I<R!PY.1L=.0N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BXB"FUS9W-T<B`B07)V;VX@<&ETY.0@;VQL82!N=6UE<F\N(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(*;7-G<W1R(")4Y&WD;B!I:VMU;F%N('9O:2!A=6MA:7-T82!V86EN
M($%S971U:W-E="!I:VMU;F%S=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")-
M>7)S:WDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED
M(")4:6-K971S(@IM<V=S='(@(E1I:V5T:70B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#(Y('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B5&EM92(*;7-G<W1R(")!:6MA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M(")!:F%N<V5U<F%N=&$B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G
M:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D%J86X@97-I='ES;75O=&\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,U"FUS9VED(")4:6UE('-E
M;&5C=&EO;B(*;7-G<W1R(")!:F%N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P
M"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I
M='1E;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(D]T<VEK
M:V\@*'1O;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(E9A<W1A86YO='1A
M:F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*
M(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)6;VED86MS97-I('9A;&ET
M82!U<V5A;7!I82!V86EH=&]E:'1O:F$L('!I9.0@0V]N=')O;"T@*%!#*2!T
M86D@0V]M;6%N9"T@(@HB*$UA8RD@;N1P<.1I;G3D('!O:&IA<W-A(&MU;B!N
M87!S875T870@:&EI<F5N('!A:6YI:V5T=&$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B5.1N
MY.1N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(D[D>73D
M($A434PM;.1H9&5K;V]D:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O9V\B
M"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8*;7-G:60@(E1O:V5L874B
M"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DAU;VUE;FYA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R.0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O
M;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S
M+B(*;7-G<W1R("(B"B),:6EA;B!M;VYT82!E<.1O;FYI<W1U;G5T=&$@:VER
M:F%U='5M:7-Y<FET>7-TY"!V:6EM96ES:6UP:65N(&UI;G5U='1I96X@(@HB
M:W5L=65S<V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Q"FUS9VED(")4;W`B"FUS9W-T<B`B66SV<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B66QI;7#DY&X@:V5H>6MS
M965N("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(DODY&YN]FMS970B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R
M:6YI9&%D(&IA(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5&]S:2!V86D@
M97#D=&]S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(G1I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M.`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<VEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<FMK:2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R(")4=7)K:VD@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-PIM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C`*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R(")4=7)K<R!J82!#86EC;W,@<V%A<F5T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,PIM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R(")+:7)J;VET82!V86QI;G1A<VDZ("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*
M;7-G<W1R(")5+E8N("UI;F1E:W-I.B`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R
M(")54DP@:F]H;VX@<&%L875T971A86X@<VMR:7!T:6X@<W1A='5S(')A<&]R
M='1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-PIM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN82(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,M:&%K96UI<W1O82!E
M:2!V;VET=2!L=6ME82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(DOD>71TY&KD;B!L
M:7/D=&EE=&]J96X@;&ESY'ES(&5I(&]N;FES='5N=70@:VER:F%U='5M:7-E
M<W-A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VD@=F%I:'1A82!O
M:6ME=6MS:6$@5D93+71I961O<W1O;&QE(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")%
M:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE("5S+R5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@
M(D5I('9O:61A('9A:6AT86$@)7,Z;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B5&EE9&]S=&]N
M(%PB)7-<(B!K;VMO82!E:2!V;VET=2!T87)K:7-T86$N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HX-3`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M,#(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(")%:2!V;VED82!N:6UE=.0@
M=75D96QL965N(%9&4RUT:65D;W-T;V$@7"(E<R\E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(E-13"UP86QV96QI;65E
M;B!E:2!S86%D82!Y:'1E>71TY"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(EEH=&5Y='3D(&5I('9O:61A(&UU;V1O<W1A82!34TPM<V%L
M871T=6YA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,M=&EE9&]S=&]A(&5I('9O:61A(&MO<&EO:61A+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(D5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C$@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(D5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(D5I('9O:71U
M(&QU;V1A(%9&4RUT:65D;W-T;V$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!N:6UE
M=.0@=75D96QL965N(%9&4RUK86YS:6]T82!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VET=2!L=6]D82!T
M>6AJY.0@5D93+71I961O<W1O82XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N(@IM<V=S='(@(E1I971O82!E:2!V;VED82!L86%J96YT86$N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%PB)7-<(BP@:&%K96UI<W1O
M(&5I(&]L92!T>6AJY"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")%:2!V;VED82!P
M;VES=&%A(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*
M;7-G<W1R(")%:2!V;VED82!P;VES=&%A("5S+"!H86ME;6ES=&\@96D@;VQE
M('1Y:&KD+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*
M;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A(')E:W5R
M<VEI=FES97-T:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D5I('9O:61A
M('!O:7-T86$@5D93+6AA:V5M:7-T;V$Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED
M82!P;VES=&%A(%9&4RUT:65D;W-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS.3D*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@
M(D5I('9O:61A('!O:7-T86$@5D93+71I961O<W1O82XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")%
M:2!V;VED82!P;VES=&%A(%9&4RUK86YS:6]T82!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G
M<W1R(")%:2!V;VED82!P;VES=&%A(%9&4SKDY"!R96MU<G-I:79I<V5S=&DZ
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED
M(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G
M<W1R(").>6MY:7-TY"!H86ME;6ES=&]A(&5I('9O:71U('-E;'9I='3DY"XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R(")687)M96YT965N('1I971O:F$@96D@=F]I9&$@97AT<F%K=&]I9&$B
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R
M:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`B3>3D<FET>6MS96X@)7,@;'5K96UI;F5N(&5PY&]N;FES='5I+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B
M16D@=F]I9&$@<VEI<G3DY"!61E,M=&EE9&]S=&]A+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.3@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HY,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C8U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('9O
M:61A('!O:7-T86$@5D93+71I961O<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(@IM<V=S='(@(D5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$@
M:VER:F]I='5S=&$@=F%R=&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VED82!A=F%T82!6
M1E,M=&EE9&]S=&]A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`B5&EI=FES=&5T>6X@=&EE9&]S=&]N(&%U:V%I
M<W4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U
M-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B16D@=F]I='4@;'5K96$@5D93+71I961O<W1O
M82`H9FEL97-I>F4H*2!E<.1O;FYI<W1U:2DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B16D@=F]I9&$@;'5K
M96$@5D93+71I961O<W1O82`H9V5T1FEL95-I>F4H*2!E<.1O;FYI<W1U:2DN
M(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS
M9W-T<B`B16D@=F]I='4@;'5K96$@=&EE9&]S=&]A.B`B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B=F9S<F]O="!J=75R
M:6AA:V5M:7-T;V$@96D@=F]I='4@;'5K96$N(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E
M861Y(&5X:7-T<R(*;7-G<W1R("(B"B)5=61E;&QE96YN:6UEY&UI;F5N("5S
M("5S.FMS:2!E<.1O;FYI<W1U:2!K;W-K82!K;VAD96AA:V5M:7-T;R!O;B!J
M;R!O;&5M87-S82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI
M<W1O82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(")%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&
M4RUH86ME;6ES=&]A.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE
M9&]S=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R(")%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&4RUT:65D
M;W-T;V$@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(Q,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R-@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS
M9W-T<B`B16D@=F]I='4@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM
M<V=S='(@(D5I('9O:61A('-U;W)I='1A82!K;VUE;G1O82`G;6MI<V]F<R<N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`B5V]R9"UD;VMU;65N='1I82!E:2!V;VET=2!KY.1N=.3D
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I
M9&$@:VER:F]I='1A82!61E,M=&EE9&]S=&]A(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('9O
M:61A(&MI<FIO:71T86$@5D93+71I961O<W1O;VX@*&-O<'DH*2!E<.1O;FYI
M<W1U:2DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(D5I('9O:61A(&MI<FIO:71T
M86$@5D93+71I961O<W1O;B!T:65T;VIA+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B16D@=F]I9&$@:VER
M:F]I='1A82!61E,M=&EE9&]S=&]A+"!K:6EN=&GV(&]N('3D>6YNY"XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS
M9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B06QL979I:79A='1U(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM
M<V=S='(@(E!E<G4@;75U=&]K<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S
M="!A8W1I;VXB"FUS9W-T<B`B4&5R=75T=&%A(&5D96QL:7-E;B!T;VEM96YP
M:71E96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@Y"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")4=6YT96UA=&]N('9A<W1A=7,@<&%L
M=F5L:6UE;'1A('EH=&5Y=&5E;CHB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#,*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z("(*;7-G<W1R(")4=6YT96UA=&]N('9A<W1A=7,@<&%L
M=F5L:6UE;'1A.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("),=6]K
M:71T96QE;6%T;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I
M9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G
M<W1R(")9:&1I<W1Y;F5E="!A<F%B:65M:7)A871I="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M.`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B66AD:7-T>6YE970@
M:W5N:6YG87-K=6YN870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P"FUS9VED(")5;FET960@
M4W1A=&5S(@IM<V=S='(@(EEH9'ES=F%L;&%T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.0IM
M<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM
M<V=S='(@(EEH9'ES=F%L=&]J96X@5'EY;F5N;65R96X@97)I;&QI<W-A87)E
M="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R(")-:71T87EK
M<VEK]G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C4X(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.0HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB
M"FUS9W-T<B`B5'5N=&5M871O;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")4=6YT96UA=&]N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(E1U;G1E
M;6%T;VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!;FYE='1U('!A:6MK871I971O
M(&]N('1U;G1E;6%T;VXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+B(*;7-G<W1R(")4=6YT96UA=&]N(&OD>71TY&KD='5N
M;G5S('1A:2!S86QA<V%N82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(E!O:7-T82!N>6MY:7-E;B!E;&5M
M96YT:6X@;&EN:VET>7,B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").:6UE=/9N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM
M<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B
M"B)4:65T;W1U<G9A<WEI<W3D(&5I+7!R:79I;&5E9VES970@<VMR:7!T:70@
M96EVY'0@=F]I(&MU='-U82!,96EK:V%A+TMO<&EO:2\B"B),:6ETY"!T;VEM
M:6YT;VIA+B!.87!S875T82!/2RUN87!P=6QA82!NY&ADY&MS97-I(&UO>FEL
M;&$N;W)G('-I=G5I;&QA("(*(F]L979A;B!O:&IE96XL(&IO<W-A(&YE=79O
M=&%A;B!M:71E;B!S:W)I<'1I<VD@=F]I=F%T(&OD>71TY.0@;&5I:V5P]GET
MY.0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B4&]I<W1A
M(';D<FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X
M-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P
M;W)T960@17AT96YS:6]N(@IM<V=S='(@(D5I+71U971T=2!L86%J96YN=7,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S
M='(@(E#D:79I=.0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M(")0Y&EV:73D("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B4.1I=FETY"!K
MY'ET=.1JY"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")0
MY&EV:71E='1I:6X@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R
M(")0Y&EV:71Y<W-K<FEP=&D@<&]I<W1E='1I:6XN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B5'5O(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S
M='(@(G1U;R!K86EK:VD@;VAJ96QM:65N(&%S96YN=7-T:65D;W-T;W0@<&%L
M=F5L:6UE;&QE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`B27-O="!L871I;F%L86ES970@:VER:F%I;65T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("))<V]T
M(')O;VUA;&%I<V5T(&YU;65R;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B2^1Y=.0@;GEK>6ES=.0Z
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B2^1Y=.0@4U-,+7-A
M;&%U<W1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BXB"FUS9W-T<B`B2^1Y=.0@:F]S('1U;FYU<R]S86QA<V%N82!O;B!E
M<FD@24U34"UP86QV96QI;65L;&4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")+Y'ET=.1J
MY"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R(")+Y'ET=.1JY&QLY"`E<R!E:2!O;&4@;VEK
M975K<VEA('1E:&3D("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I
M9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")+Y'ET=.1J:65N('EL
M;.1P:71O(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*
M;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")+Y'ET=.1JY&X@87-E='5K
M<V5T(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I
M;VXB"FUS9W-T<B`B2^1Y='3D:N1N(')E:VES=&5R]FEM:6YE;B(*"B,Z('-I
M9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(E3D<W/D(&KD<FIE
M<W1E;&WD<W/D(&5I('9O:2!R96MI<W1E<O9I9.0@:^1Y='3D:FGD+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N
M="!N;W0@9F]U;F0B"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7-T82!E:2!L]GET
M>6YY="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$U,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M
M92(*;7-G<W1R(")+Y'ET=.1JY'1U;FYU<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")+Y'ET=.1J
MY'1U;FYU<R!<(B5S7"(@;VX@:F\@;VQE;6%S<V$N(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`B2^1Y='3D:N1T=6YN=7,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")+Y'ET=.1JY'1U
M;FYU<SH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM
M<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B2N1R:F5S=&5L
M;>1N(&OD>71TY&KD=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES
M=&%N(@IM<V=S='(@(E5Z8F5K:7-T86XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")61E,M:&%K96UI<W1O82!E:2!O;&4@;VQE;6%S<V$N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T
M<B`B4&]I<W-A;VQO=FEE<W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@
M(@IM<V=S='(@(E!A:6MK;VIA(&SV>71Y:2!E<VEM97)K:6MS:3H@(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A
M;&ED:71Y(@IM<V=S='(@(E9O:6UA<W-A;VQO86EK82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PIM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B07)V;R!M
M:6YU=71E:7-S82!N>6MY:&5T:V5S=.0N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N(@IM<V=S='(@(D%R=F\@;VX@>6QI('!I='5U9&5N(&UA
M:W-I;6EA<G9O;B`E<RX\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<P"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,C`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDQ-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B07)V;W0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.3`*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")6
M86QI='1A=F%T(&%R=F]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.0IM<V=I9"`B5F%N=6%T
M=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%I:'1E;&5V
M86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B
M5F5N97IU96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")487)K
M:7-T=7,@97#D;VYN:7-T=6D@+2!4Y'3D('9I97-T:>0@;VX@=F]I='4@:^1S
M:71E;&SD+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<G-I;R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O
M;"(*;7-G<W1R(")697)S:6]N:&%L;&EN=&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;"!A;&EG;B(*;7-G<W1R(")0>7-T>7-U;W)A('1A<V%U<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B4'ES='ES=6]R82!TY'ET92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")0>7-T>7-U;W)A.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B17)I='3D:6X@:V]R:V5A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(E9I971N86T@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(").Y'ETY"`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B3N1Y=.0@97)I;&QI<V5NY"!W=W<M<VEV=6YA(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B3N1Y=.0@)7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G
M<W1R(").96ET<WET<V%A<F5T+"!"<FET=&ELY&EN96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0W"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(").96ET
M<WET<V%A<F5T+"!9:&1Y<W9A;'1A:6XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(").Y&MY=N1I<WEY
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R(").Y&MY=N1I<WEY<SH@(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*
M;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F
M;VYE($ET86QY(%--5%`Z;B!A=G5L;&$B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(E9!4D])5%53(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E9!
M4D])5%53(2$A(%!/25-402!32U))4%1)($OD4TE.(%!!3%9%3$E-14Q402`E
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!(5%10.FX@879U
M;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B
M"FUS9W-T<B`B5V%L;&ES(&IA($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R
M(")687)O:71U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(FME(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C
M87-T(@IM<V=S='(@(E/DY&5N;G5S=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B4^3D=&EE9&]T(&]N('1O:6UI='1A;G5T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B5U=7(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5U=7
M+7-I=G5S=&\B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B5FEI:V]I='1A:6XB
M"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R(")497)V971U;&]A(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5&5R
M=F5T=6QO82!O:&IE;&UA86X@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5&5R=F5T=6QO
M82P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3.1N<VEM86EN96X@*$E33RTX
M.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("),Y&YS:6UA:6YE;B]%=7)O
M("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.`IM<V=I9"`B5V5S=&5R;B!3
M86AA<F$B"FUS9W-T<B`B3.1N<VDM4V%H87)A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R
M(")-:6YKY"!O:&IE;&UA;B`E<R!KY'EN;FES=.3D('-I<^3D;FMI<FIA=71U
M;6ES96X@:N1L:V5E;BXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B
M"FUS9W-T<B`B36ETY"!M97)K:VGD(&OD>71E=.3D;B!E<F]T=&EM96YA/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(DUI=.0@;65R:VMI
MY"!KY'ET973DY&X@;&%I;F%U:W-E96X_(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C0*;7-G:60@(E=H97)E:7,@075S
M=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES($%U<W1R86QI86X@:V%R='1A
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`B36ET:^0@=F%I:&5E="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B5F]I="!MY.1R:71E
M;&SD(&QI<^1T;VEM:6YT;VIA(&QA:71E=&%A;B!PY.1L;&4@4FEC:"!497AT
M(&5D:71O<FES<V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B3&5V
M97ES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,0IM<V=I9"`B
M5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQE=F5Y<R!#4U,@;6ET=&%Y
M:W-I:VOV:6[D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B
M(@HB5F%S96UM86QL82!O;&5V86X@)7,@=F%L:6MO;B!L979E>7,@*'1U;&5E
M('9O:6UA86X@<V5U<F%A=F%L;&$@(@HB<VESY.1N:VER:F%U='5M:7-E;&QA
M*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(E1A=6QU
M:V]N(&QE=F5Y<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(DQE=F5Y
M9&5N('EK<VEK:_8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(DQE=F5Y<SHB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI
M(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED(")7:6YD(@IM<V=S='(@(E1U=6QI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB
M"FUS9W-T<B`B5'5U;&ES=&$@86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@
M(E1U=6QE;FYO<&5U<R!S;VQM=6ES<V$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$V,PIM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5'5U;&DZ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(E1U=6QI.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*
M;7-G:60@(E=I<V1O;2(*;7-G<W1R(")6:6ES875S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B
M5&]I=F5L:7-T870B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`B5'GV(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B3W-O:71E("AT>?8I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R
M(")0=6AE;&EN("AT>?8I(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3DS(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B5N3D<N0@;>3D
M<N0@:V5N='1IY"!R:79I;&SD("5D+B!/9&]T971T:6EN("5D+"!L]GET>6D@
M)60N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B5N3D<N0@;>3D<N0@:V5N='1I
MY"X@3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R
M(")6Y.1RY"!P;VEK:V5A;6$@)60@;'5E='1A97-S82!61E,M=&EE9&]S=&]A
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R(")8-3`Y=C,@<&5R=7-R86IO:71T965T(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S(&QI<^1T;VEM:6YN
M;W0@879A:6UE;B!KY'ET]FQL92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R!+;VAT965N('9A:6AT;V5H=&]I
M;F5N(&YI;6DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS
M9W-T<B`B6#4P.78S($MO:'1E96X@879A:6UE;B!T=6YN:7-T92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y
M=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,M;&%A:F5N;G5K<V5T(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(E96
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V
M"FUS9VED(")965E9(@IM<V=S='(@(E965E8B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R(")986AO;R$@:V%R='1A(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S
M='(@(E9U;W-I='1A:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R"FUS9VED(")996UE;B(*
M;7-G<W1R(")*96UE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")+>6QLY"(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS
M9VED(")997,L($D@06=R964B"FUS9W-T<B`B2WEL;.0L('-U;W-T=6XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM
M<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T
M=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(DOD
M>73D="!414M35$E424Q!02X@2^1Y=.0@6SP^72!N87!P=6QA82!V86EH=&%A
M:W-E<VD@=&%K86ES:6X@5UE325=91RUT:6QA86XN(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B170@=F]I('1E:&3D(&5N96UP
MY.0@:W5I;B`E9"!O<VEO=&$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R(")%="!O;&4@875T96YT:6MO:71U;G5T+B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T
M(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*
M;7-G<W1R(").:6UE<W/D<VD@96D@<V%A(&]L;&$@)UQ<)RUM97)K:VGD+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")%="!A;G1A;G5T(&]I:V5A
M;B!M=6]T;VES=&$@<^1H:_9P;W-T:6]S;VET971T82XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@HB170@;>3D<FET96QL>70@;6ET:^0@='5O9'5N('1I961O<W1O
M;B!K96YTY'0@=F%S=&%A=F%T(&UI=.1K:6X@:V5N='1IY"`E<SHB"B)S<^0N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D]L970@:VER:F%U='5N
M=70@=6QO<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8U"FUS
M9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B
M(@HB4VEN=6X@<&ETY.0@86YT86$@;VEK96$@;6%T:V%P=6AE;&EN;G5M97)O
M+"!V86EN(&YU;65R;VET82!J82!M86AD;VQL:7-E<W1I("(*(B<K)R!J;W,@
M:^1Y=.1T(&MA;G-A:6YVY&QI<W3D('!U:&5L:6YN=6UE<F]M=6]T;V$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B4VEN=6X@=.1Y
M='EY(&%N=&%A(&]I:V5A(&%R=F\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B)3
M:6YU;B!P:73DY"!A<V5N=&%A($1A=&%4<F5E+71A=7-T86KD<FIE<W1E;&WD
M(&5N;F5N(&MU:6X@=F]I="!KY'ET=.3D("(*(E-I9VYU<"UT;VEM:6YT;VIA
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#8R"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B4VEN
M=6X@<&ETY.0@87-E;G1A82!61E,M=&%U<W1A:N1R:F5S=&5L;>0N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)3:6YU;B!T=6QE92!K
M=79A:6QL82!O;F=E;&UA=&EL86YN971T82!E;FYE;B!K=6EN('9O:70@;.1H
M971TY.0@(@HB;VYG96QM879I97-T:6XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@
M(E-I;G5N('!I=.3D(&%N=&%A(%523"!M:6AI;B!TY&WD(&QI;FMK:2!O<V]I
M='1A82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(E-I;G5N('!I=.3D('9A;&ET82!P;VES=&5T=&%V82!P86QV96QI
M;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E-I;G5N
M('!I=.3D(&%N=&%A('!O:7-T971T879A(&OD>71TY&KD='5N;G5S+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B4VEN=6X@<&ETY.0@86YT
M86$@<&]I<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM
M<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A(&QI<^1T=.1VY"!KY'ET=.1JY'1U
M;FYU<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B4VEN
M=6X@<&ETY.0@86YT86$@<.1I=FET971TY';D(&OD>71TY&KD='5N;G5S+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M
M+B(*;7-G<W1R(")3:6YU;B!P:73DY"!V86QI=&$@<W5O<FET971T879A('1O
M:6UI;G1O+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N(@IM<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A('5U9&5N(&MA
M=&5G;W)I86X@;FEM:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O
M=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")3:6YU;B!P
M:73DY"!A;G1A82!I=&%L:6%L86EN96X@<'5H96QI;FYU;65R;R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B27-T=6YT;W-I("5S(&]N('9A;FAE;G1U;G5T+B!+
M:7)J875D=2!U=61E;&QE96X@<VESY.1N+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B
M"FUS9W-T<B`B4^1H:_9P;W-T:6]S;VET=&5E<VDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM
M<V=S='(@(E-I;G5N(&SD:&5T=.1JY&]S;VET=&5E<VDZ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]M870@
M=&EE=&]S:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*(E-I;G5N('1I971O:V]N965S:2!KY'ET
M=.1MY"!T:65T;W9E<FMK;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK
M965N(&MU;B`B"B)O;&5T(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O
M='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@:VER:F%U='5A("(*(G5U9&5S=&%A
M;B!JY')J97-T96QMY.1N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B3FEM97-I(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M(DOD>71TY&WD<VD@875T:&5N=&EC871I;VX@=&%U<W1A:N1R:F5S=&5L;>0@
M96D@='5E(&OD>71TY&II96X@;&ESY.1M:7-TY"X@(@HB2F]S(&AA;'5A="!H
M86QL:6YN;VED82!KY'ET=.1JY'1U;FYU:W-I82P@<VEN=6X@<&ETY.0@:^1Y
M='3DY"!J;W1A:VEN('1O:7-T82`B"B)A=71H96YT:6-A=&EO;B!T875S=&%J
MY')J97-T96QMY.0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*(DOD>71TY&WD<VD@875T:&5N=&EC871I;VX@=&%U<W1A
M:N1R:F5S=&5L;>0@96D@='5E(&OD>71TY&KD=&EE=&]J96X@(@HB;N1Y='3D
M;6ES=.0@=&%I('3D;>0@<&EI<G)E(&5I(&]L92!J;W-T86MI;B!S>7ES=.0@
M:^1Y=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)3:6YU;B!KY'ET=.1M
MY'-I('=W=RUS96QA:6X@;N1Y='3DY"!O;&5V86X@;75U='1U;G5T('-E;B!J
MY&QK965N(&MU;B!O;&5T("(*(F%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I
M971O='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@:VER:F%U='5A("(*(G5U9&5S
M=&%A;FKD<FIE<W1E;&WDY&XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92XB"FUS9W-T<B`B4V5L86EM97-I(&5I('1U92!TY'3D('1O:6UI
M;G1O82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@
M<')I;G0N(@IM<V=S='(@(B(*(E-E;&%I;65S:2!E:2!T=64@=&%R=FET=&%V
M86$@='5L;W-T=7-T;VEM:6YT;V$N(%!A:6YA($-O;G1R;VPO3W!T:6]N("L@
M4"`B"B)T=6QO<W1A86MS97-I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(D%I:V%V>?9H>6MK965S:3HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$W
M"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E
M9"XB"FUS9W-T<B`B3VQE='5S<')O9FEI;&ES:2!O;B!M=75T971T=2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ(@IM<V=S='(@(D]L971U<W!R;V9I:6QI<VDZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA
M;64Z(@IM<V=S='(@(DYI;65S:3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S
M='(@(DES='5N=&]S:2!O;B!V86YH96YT=6YU="XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E-I;G5N('-A
M;&%S86YA<VD@)7,Z;&QE(&]N.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM
M<V=S='(@(D%S971U:W-E<VD@;VX@<.1I=FET971T>2!J82!N92!O=F%T('9O
M:6UA<W-A('3D;>1N(&ES='5N;F]N(&%J86XN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"XB"FUS9W-T<B`B07-E='5K<V5S:2!O;B!PY&EV:71E
M='1Y+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E-A;&%S
M86YA<VD@;VX@;F]L;&%T='4B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(E-A;&%S86YA<VD@;VX@;F]L;&%T
M='4L('1A<FMI<W1A('/D:&OV<&]S=&ES:2!J82!K:7)J875D=2!S:7/DY&X@
M=75D96QL82`B"B)S86QA<V%N86QL87-I+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B4V%L87-A;F%S:2!O;B!V86YH96YT=6YU="XB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M
M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D5TY'!A;'9E;&EM97-I.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-30*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G
M;W-L879I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-@IM
M<V=I9"`B6F%M8FEA(@IM<V=S='(@(E-A;6)I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<*
M;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")::7!P
M>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R
M(");4&EI;&]T82!L86EN871T=2!T96MS=&E=(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B
M6T]N9V5L;6%=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B
M6T[D>73D(&QA:6YA='1U('1E:W-T:2`M(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*
M;7-G<W1R(");3N1Y=.0@;&%I;F%T='4@=&5K<W1I("T@)7,@<FEV:>1=(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EMR:79I;&SD("5S
M+R5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T-R!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B7UEL;.1P:71O(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]+;VUE;G1O='5L:VMI(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")?4&]I<W1A
M(')I=FDB"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS
M9W-T<B`B7U)Y:&WD="(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]/:&IE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S
M"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?2W5V86X@
M=&EE9&]T+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?2VER:F%U9'4@<VESY.1N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I
M9"`B7TQO9R!O=70B"FUS9W-T<B`B7TMI<FIA=61U('5L;W,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*
M;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?375O:VMA82!L:6YK
M:VGD(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM
M<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T%S971U:W-E="(*"B,Z(&QI8B]A
M<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]/:6ME
M=61E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@
M(E!O:7-T82!L:6YK:VDN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@
M(E]3971U<"(*;7-G<W1R(")?07-E;FYU<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A
M8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7U1A=6QU:V]N('1I961O="XN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@
M(E]+Y'ET=.1JY'0B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F]S;VET96MI<FIA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(G9A<W1A86YO='1A:F$@='5N
M=&5M871O;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$W"FUS
M9VED(")C86QE;F1A<B(*;7-G<W1R(")K86QE;G1E<FDB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(G1Y>6YTY"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(F5I('9O:2!L=6]D82!T
M=6QO<W1I961O<W1O82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")E
M:2!V;VD@875K86ES=&$@;.1H9&5T=.0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T
M<B`B;F%P<V%U=&$@=.1S=.0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(G9I<FAE(&MO;65N=&]R:79I;&SD(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`B87-E='5S=FER:&4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES
M=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")K<FEI='1I;F5N(&KD<FIE<W1E
M;&WD=&EE9&]S=&\@<'5U='1U=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G
M<W1R(")M=6]T;W9I<FAE('1I961O:7-S82(*"B,Z('1E;7!L871E<R]P;W)T
M86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B;75O:VMA82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B=&EE='5E='1A(&5I(&SV>71Y
M;GET(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B;&%S:V5V82(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y.`IM<V=I9"`B9FEL92(*;7-G
M<W1R(")T:65D;W-T;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`B<W5U;FYA<W1A("5S("@E<RD@;F]P975D96QL82`E<R`E
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@
M(F=U<W1I;F<B"FUS9W-T<B`B<'5U<VMI='1A:6XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G
M<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U
M;FMN;W=N(@IM<V=S='(@(G1U;G1E;6%T;VX@<&%L=F5L:6UE;B!N:6UI(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B=N1L:71T]FWD<W1I
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")I;FQI;F4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEO+79I<FAE(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L
M('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(F]H:F5L;6ES=&]N('-I<^1I;F5N
M('9I<FAE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")R:79I=%TB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,@=FER:&5K;V]D:2`E
M9"!)4T\Z82!T96AD97-SY"XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N:6UI(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(F5I(&]L92!T;W1E=71E='1U(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(F5I(&]L92!V:65LY"!T;W1E=71E='1U(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P860B
M"FUS9W-T<B`B;75I<W1I;&ES=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(G!R;W-E;G1T:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M(")KY'ET=/8@:VEE;&QE='1Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(G!I:W-E;&5I=.0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM
M<V=S='(@(F5TY'9I<FAE('!R;W1O:V]L;&%S<V$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM
M<V=S='(@(FYO=7-E=F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R
M(")P86QV96QU(&5I(&]L92!KY'ET971TY'9I<W/D(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS
M9W-T<B`B;N1Y=.0@97)O="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A4
M5%`B"FUS9W-T<B`B<VUS,F5M86EL($A45%`Z;B!A=G5L;&$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S
M<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B=F%K86$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(FKD<FIE<W1E;&WD=FER:&4B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(G1E:'3D=N1L:7-T82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*
M;7-G<W1R(")VY&QI86EK86EN96X@=FER:&4B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(G9A<FUI<W1A86MS97-I(&MI<FIO:71A('-A;&%S86YA(&MA:&1E<W1I(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEE9"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B
M"FUS9W-T<B`B;FEM973V;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B=7-E<B!S96QE8W0B
M"FUS9W-T<B`B:^1Y='3D:N1N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S
M='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS
M9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O971?144N<&\`````````````
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<R,#(P,0`Q
M,#4Q-30S,3`V,@`P,38S-#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!(3U)$12!%4U1/3DE!3B!44D%.4TQ!5$E/3B`*
M(PHC(%1O;VUA<R!!87,@/'1O;VUA<RYA87-`;6%I;"YE93XL(#(P,#(@+2`R
M,#`V(`HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!(;W)D92`S+C$M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP
M,RTS,"`Q-CHQ,2LP,S`P7&XB"B),87-T+51R86YS;&%T;W(Z(%1O;VUA<R!!
M87,@/'1O;VUA<RYA87-`;6%I;"YE93Y<;B(*(DQA;F=U86=E+51E86TZ($5S
M=&]N:6%N(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)
M4T\M.#@U.2TQ,UQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S('#D
M979A('1A9V%S:2DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S
M='(@(B`H2VEI<FML86AV("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(@*"5S('#D979A('#D<F%S="DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*'3D
M;F$I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B
M("AT;VUO<G)O=RDB"FUS9W-T<B`B("AH;VUM92DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T
M<B`B("AE:6QE*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@
M(B!K:6ER=7-E9V$@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&5I(&]L92!K871A;&]O9RXB"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<
M(B!E:2!O;&4@=O5I;6%L:6L@=F%L:6LN(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN
M(@IM<V=S='(@(EPB)7-<(B!E:2!O;&4@2&]R9&4@<F5G:7-T<FES(&CDY&QE
M<W1A='5D+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U
M;F0N(@IM<V=S='(@(EPB)7-<(B!P=74@97-I=&%J870@96D@;&5I='5D+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T
M<B`B7"(E<UPB(&QI<V%T:2!G<G5P<&ED92!S_'-T965M:2XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*
M;7-G<W1R(")<(B5S7"(@;&ES871I(/5I9W5S=&4@<_QS=&5E;6DN(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!E:2!L;V]D=60Z("5S+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R
M("(E+C)F34(@:V%S=71A='5D(&MO:VMU("4N,F9-0BUS="`H)2XR9B4E*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&IA("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B4VEN
M=2!P87)O;VP@865G=6(@)60@<.1E=F$@<.1R87-T+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D('#D979A(&5N;G5S='5S(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@5.1H96QE<&%N=2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S('/U
M<FUE:N1L9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(E<R!H;V]L9'5S=/;V9"`M(&MI;FYI='5S(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S('!A
M:6=A;&1U<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E
M<R!K;VYT;R!T86]T;&5M:6YE(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E
M;65N="(*;7-G<W1R("(E<R!K87-U='5S=&EN9VEM=7-E9"(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!O;B!J=6)A(&]L
M96UA<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!K
M:6ER=7-E9V$@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!O
M;B!V86QM:7,@=&5G96UA(&%L;'!O;VP@;&]E=&QE='5D(&AO;VQD=7-T]O9D
M+B!-Y')G:7-T82!T]O9D+"!M:61A("(*(G-O;W9I9"!P<F%E9W4@=&5H82XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&]N(&MO:'5S
M='5S;&EK(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&ET(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S
M(&5I(&QE:71U9"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S
M='(@(B5S(&MU;FD@)7,@)7,M<W0B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R(")+87-U=&%J82`E<R!A861R97-S:7)A86UA="(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%S=71A:F$@)7,@:V%L
M96YD97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B2V%S=71A
M:F$@)7,@;>1R:VUE9"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T
M<B`B2V%S=71A:F$@)7,@_&QE<V%N9&5D(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@HB)7,Z(%-E92!T96%D92!E:2!P<G5U9VD@;VQL82!S86%T:F%L="P@
M:V5L;&5L="!S964@<&%I<W1A8B!O;&5V870N(,1R82`B"B)K:6ER=7-T82!K
M;/5P<V%M82!S96QL97,@97-I;F5V86ED(&QI;FME(';U:2!E<VET86UA('-A
M871J86QE("(*(FUI;F=I=&ES:6ML:6MK=2!I;F9O="XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!T=75L
M96EI;&ED("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN
M9R`E<R`E<R(*;7-G<W1R("(L('1U=6QE:6EL:60@)7,@)7,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A
M<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V86AE;6EK=7,@)7,@
M:W5N:2`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=F%L:2`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B,3(M='5N;FEN92!E<VET=7,B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T
M+71U;FYI;F4@97-I='5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('1U;F1I(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM
M<V=S='(@(CQ%96QM:6YE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*
M;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB"FUS9W-T<B`B4V5E(&)L;VMK('9A:F%B(&%N9&UE8F%A<VD@
M='5G92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I
M9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B2G5H='5S
M(&MO:'5T878@=FEG82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B2VER:F$@:W+\<'1E97)I
M;6ES96MS(&]N('9A:F$@879A;&EK:W4@4$=0(';U=&ET+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(D%L;&MI<FIA(&MO;G1R;VQL:6UI<V5K<R!O;B!V86IA
M(&%V86QI:VMU(%!'4"!V]71I="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB2W+\<'1E97)I
M='5D(&MI<FIA(&%V86UI<V5K<R!O;B!V86IA(&%V86QI:VMU(%!'4"!V]71I
M="P@<V%L86IA<W0@4$=0(';U=&ET("(*(FIA('-A;&%S]6YA+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B)+:7)J82!A;&QK:7)J87-T86UI<V5K<R!O;B!V86IA(&%V86QI:VMU
M(%!'4"!V]71I="P@<V%L86IA<W0@4$=0(';U=&ET(&IA("(*(G-A;&%S]6YA
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS
M9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB2W+\<'1E97)I='5D(&MI<FIA(&%V
M86UI<V5K<R!O;B!V86IA(&%V86QI:VMU(%,O34E-12!V]71I="P@<V%L86IA
M<W0@4R]-24U%("(*(G;U=&ET(&IA('-A;&%S]6YA+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB2VER:F$@86QL:VER:F%S=&%M:7-E:W,@;VX@=F%J82!A=F%L:6MK
M=2!3+TU)344@=O5T:70L('-A;&%J87-T(%,O34E-12!V]71I="`B"B)J82!S
M86QA<_5N82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")+:7)J82!K<OQP=&5E<FEM
M:7-E:W,@;VX@=F%J82!A=F%L:6MK=2!3+TU)344@=O5T:70B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#
M;&]U9',B"FUS9W-T<B`B14P@<&EL=FEN92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(D5,(&ME<F=E('9I:&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R
M(")%3"!V:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B14P@:&]O=FEH
M;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S
M"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B14P@='5G978@;'5M
M97-A9'4B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B
M04TO4$TB"FUS9W-T<B`B14PO4$PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R
M(")396QL92!E9&ET;W)I(&EN9F\B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B26YF;RXN+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G
M:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-B;W1T;VTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`B06)S;6ED9&QE(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@:V%T86QO;V=I(&QO;VUI
M<V5K<R!J=75R9&5PY.1S(&ME96QA='5D(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92XB"FUS9W-T<B`B5D93(&9A:6QI(&QO;VUI<V5K<R!J=75R
M9&5PY.1S(&ME96QA='5D+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS
M"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DMO;G1O(&EN
M9F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U
M;G0@4&%S<W=O<F0B"FUS9W-T<B`B2V]N=&\@<V%L87/U;F$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G
M:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")+;VYT;R!L=6MU<W1A='5D
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C
M8V]U;G1I;F<B"FUS9W-T<B`B4F%A;6%T=7!I9&%M:6YE(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B3&ES82(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@
M0VAI;&0@1W)O=7`B"FUS9W-T<B`B3&ES82!A;&%M9W)U<'`B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM
M<V=S='(@(DQI<V$@86QA;?5I9W5S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("),:7-A('-I:6$Z
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR
M,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3&ES82!U=7,@9W)U
M<'`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R("),:7-A('5U<R#U:6=U<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(DQI
M<V$@9W)U<'`@7"(E<UPB(&%L;&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("),:7-A(/5I9W5S(%PB
M)7-<(B!A;&QA(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A
M(&YE=R!U<V5R.B(*;7-G<W1R("),:7-A('5U<R!K87-U=&%J83HB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED
M(")!9&0@8V]L=6UN(@IM<V=S='(@(DQI<V$@=F5E<F<B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE
M;6)E<G,B"FUS9W-T<B`B3&ES82!U=65D(&QI:6MM960B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R
M("),:7-A('!A87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<B(*;7-G<W1R(")4964@)7,@;65N_/P@36]Z:6QL82!K_&QG
M<FEB86MS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("),
M:7-A(&%A9')E<W-I<F%A;6%T=7-S93HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B3&ES82!M:6YU(&%A9')E<W-I<F%A;6%T=7-S
M92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G
M<W1R("),:7-A(&MA<W5T86IA(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB7"(E<UPB(&QI<V%T:2!S_'-T
M965M:2P@:W5I9"!TY&EE;F1A=F%T(&QI:71U;6ES:6YF;W0@<&]L;G5D(';U
M:6UA;&EK("(*(FQI<V%D83H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")<(B5S7"(@;&ES871I('/\
M<W1E96UI+B!._/QD(';U:60@<VES<V4@;&]G:61A+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(DMA<W5T86IA=&4@;&ES86UI;F4@<&]L
M92!L=6)A='5D+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED
M(")!9&1R97-S(@IM<V=S='(@(D%A9')E<W,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
M06%D<F5S<VER86%M870B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B2&%L9'5S("T@;75U9&$@
M=&5I<W1E(&MA<W5T86IA=&4@]6EG=7-I(@H*(SH@861M:6XO:6YD97@N<&AP
M.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(DAA;&1U<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(D%D<R(*;7-G<W1R(")296ML86%M
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G
M86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
M06QB86%N:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@
M(D%L>F5E<FEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"FUS9VED(")!;&EG;B(*;7-G<W1R(")*;V]N9'5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM
M96YT.B(*;7-G<W1R(")*;V]N9'5S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(DOU:6LB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G
M<W1R(")+]6EK('-I<W-E;&]G:71U9"!K87-U=&%J860B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@
M1W)O=7!S(@IM<V=S='(@(DOU:6L@9W)U<&ED(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T
M871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M2_5I:R#U:6=U<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B2_5I:R!N96QI(&O\;&=E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM
M<V=S='(@(DQU8F$@;6ET=70@86%D<F5S<VDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/R(*;7-G<W1R("),=6)A(&WDY')A=&$@:N1R:F5S=&%T=60@
M;&]E;F1I('3\_'`B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D]N
M(&IU8F$@;VQE;6%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM
M<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT97)N871I
M:79N92!)35-0(&MO;G1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT
M97)N871I:79N92!)35-0('-A;&%S]6YA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B06QT97)N871I:79N92!)35-0(&MA<W5T86IA;FEM:2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@
M96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=&EI=FYE(&4M<&]S=&D@
M86%D<F5S<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:6EV<V5D(&UA
M;&QI9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S
M='(@(D%L=&5R;F%T:6EV;F4@=&5K<W0Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE97)I:V$@4V%M;V$B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N(@IM<V=S='(@(E-I<V5S=&%T:2!L=6)A;6%T=2!VY.1R
M='5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*;7-G
M:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(DIU
M:'1U<R!T=6YD;6%T=2!V:6=A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R
M82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA
M(@IM<V=S='(@(D%N9V]O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL
M82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!
M;F]N_/QM;F4@=F%H96YD86IA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")687-T=7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I:V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S
M='(@(D%N=&EG=6$@:F$@0F%R8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B4F%K96YD=7,B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`B4F%K96YD=7-T92!N:6UE:VER:2(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES
M(')E861Y+B(*;7-G<W1R(")286ME;F1U<R!O;B!T]O9V86QM:7,N(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O
M($-H:6QD(%-H87)E<R(*;7-G<W1R(")286ME;F1A(&%L86UJ86=U9&5L92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED
M(")!<'!R;W9E(@IM<V=S='(@(DMI;FYI=&$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B3&EG:6MA=61N92!S=75R=7,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B07!R:6QL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G
M:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%A8FEA("A7
M:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*
M;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(D%R:&EI=FD@<W5U
M<G5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R
M8VAI=F4@3F%M92(*;7-G<W1R(")!<FAI:79I(&YI;6DB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D]L960@<V$@:VEN
M9&5L(&5T('-O;W9I9"`E<R!L:6ET=6UI<W-O;W9I(&MU<W1U=&%D83\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(B(*(D]L960@
M<V$@:VEN9&5L(&5T('-O;W9I9"!K=7-T=71A9&$@9W)U<&D@7"(E<UPB(&IA
M(&OU:6L@=&5M82!A;&%M9W)U<&ED/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R
M9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I:6YA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R(")!<FUE96YI82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G
M<W1R(")!<FUE96YI82`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(DMU;G-T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD
M(@IM<V=S='(@(DQI:&%V]71T97-A87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!4T-)22!J;V]N
M:7-T=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B06%S:6$O5F%I:W-E
M(&]O:V5A;FD@<&EI<FMO;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B2_QS:2!H;V]L9'5S
M=/;V9&4@=&5G96UI<V5K<R!K:6YN:71U<W0B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS
M9W-T<B`B5F5E<G5D(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S
M='(@(DMA='-E(&MU<W1U=&%D82!O;&5M871U="!G<G5P<&DN(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B2V%T<V4@
M:W5S='5T861A(&]L96UA='5T(/5I9W5S="XB"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DMA='-E(&UU=71A(&]L96UA='5T
M(/5I9W5S="XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS
M9W-T<B`B2V%T<V4@;75U=&$@;VQE;6%T=70@:F%G=2XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R
M(")!=')I8G5U9&ED(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!=6=U<W0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A86QI
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075S=')I
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G
M:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!V86IA;&EK:W4@24U!4"!L
M86EE;F1U<W0@96D@;&5I='5D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H
M7V-Y<G5S.B!S_'-T965M:6P@<'5U9'5V860@=F%J86QI:W5D(';U:6UE9"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@
M(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@=F%J86QI:VMU($E-05`@;&%I96YD
M=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP
M:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z(%9A:F%L:6MK
M=2!&5%`@;&%I96YD=7-T(&5I(&QE:71U9"X@2V]M<&EL965R:2!02%`@=O5T
M;65G82`M+65N86)L92TB"B)F='`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@5F%J
M86QI:VMU($E-05`@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E
M<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]K<F(U.B!686IA;&EK:W4@:W)B-2!L86EE;F1U<W0@96D@;&5I='5D+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!
M=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@06-T:79E($1I
M<F5C=&]R>2=S<V4@:V%S=71A:F%T92!L:7-A;6ES92!T=6=I('!U=61U8B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!
M=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!!8W1I=F4@
M1&ER96-T;W)Y<W0@:V%S=71A:F%T92!E96UA;&1A;6ES92!T=6=I('!U=61U
M8B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@
M(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VQD87`Z(%9A:F%L:6MK=2!,1$%0(&QA:65N9'5S
M="!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(*;7-G<W1R(")!=71H7VQD87`Z($5I('-A82!L:7-A9&$@:V%S=71A:F%T
M("5S+B!397)V97(@_'1L97,Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@
M56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@
M16D@<V%A(&5E;6%L9&%D82!K87-U=&%J870@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!
M=71H7VQD87`Z($5I('-A82!M=75T82!K87-U=&%J870@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O
M<GD@:V%S=71A:F%T92!M=75T;6ES92!T=6=I('!U=61U8BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ
M(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]M8V%L.B!686IA;&EK:W4@34-!3"!L86EE;F1U<W0@96D@;&5I='5D
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@5F%J86QI:VMU('-M8F%U
M=&@@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")3:7-S96QO9VEM:6YE(&YU<FIU<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,B"FUS9W-T<B`B4VES<V5L;V=I;6EN92!N=7)J=7,N("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B4D%$2553('-E<G9E<B!E:2!L=6)A;G5D('-I<W-E(&QO9VED82XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D94
M4"!S97)V97)I<W-E('-I<W-E;&]G:6UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4TU"('-E<G9E
M<FES<V4@<VES<V5L;V=I;6EN92!N=7)J=7,N(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS
M9W-T<B`B2V%S=71A=&%V860@=N1L:F%D.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%Z97)B86EJ86XB"FUS9W-T<B`B07-E<F)A:61Z86%N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T
M<B`B0D]&2"!E='1E:^3D;F1E9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B
M"FUS9W-T<B`B5&%U<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S
M='(@(E1A=7-T82!VY')V(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R
M(")686QE(&ME<F)E<F]S92!S86QA<_5N82XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA
M;64N(@IM<V=S='(@(E9A;&4@:V5R8F5R;W-E(&MA<W5T86IA;FEM:2XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F5I;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX
M.#4Y+3$S*2(*;7-G<W1R(")"86QT:2`H25-/+3@X-3DM,3,I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B1W)A869I:V$@</5H:6MA=&%L;V]G:2!<(B5S7"(@96D@
M;&5I='5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B0F%S96QI
M;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(E9A;&=E
M=F5N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L
M9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G
M:60@(D)I<G1H9&%Y(@IM<V=S='(@(E/\;FYI<.1E=B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D)L;VMK:2!<(B5S7"(@<F%K96YD=7-E<R!<
M(B5S7"(@96D@;&5I='5D+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO:VD@
M:.3D;&5S='5S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T
M"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(D)L;VMI('3\_'`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@
M(D)O;&0B"FUS9W-T<B`B4&%K<R!K:7)I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F]L:79I82(*;7-G<W1R(")";VQI:79I82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")*Y')J
M96AO:61J860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B4&EI<FIO
M;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")*;V]N92!P
M86MS=7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")0:6ER:F]O
M;F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82(*;7-G<W1R(")";W-N:6$@:F$@2&5R='-E9V]V:6EN82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")-]6QE
M;6%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T
M<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")!;&QA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970@
M<V%A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%S
M:6EL:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71I($EN9&EA($]O:V5A;FD@5&5R
M<FET;V]R:75M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L
M86TB"FUS9W-T<B`B0G)U;F5I(%-U;'1A;FER:6EK(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%A<FEA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R("),;V5T96QU(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R
M(")3:7-U:&%L9'5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")4_&AI<W1U<VYI;65K:7)J82!J
M86]T=7-P=6YK=&ED(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(DQ?86AT<FD@;VUA9'5S960N+BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A
M<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(")686AE;>1L=2!I;FET<VEA;&ES
M965R:6UI;F4@96D@:O5U9&YU9"!L]7!U;&4N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G
M:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R(")6
M86EK;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B
M2V%M8F]D>FAA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T
M<B`B2V%M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)087)O
M;VQI(&5I('-A82!A=71O;6%A='-E;'0@=/QH:7-T861A+"!V]71A(/QH96YD
M=7-T(&%D;6EN:7-T<F%A=&]R:6=A+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R
M:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(D5I(/5N;F5S='4@:VER:G5T
M861A(&9A:6QI(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM
M<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+B(*;7-G<W1R(")6Y&QI<V5I9"!S97-S:6]O;FEH86QD=7)E:60@<&]L
M92!V]6EM86QI:R!A9&UI;FES=')E97)I9&$N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B16D@<V%A(/QH96YD=7-T
M($E-05`@<V5R=F5R:6=A.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")%:2#U;FYE<W1U(&%V861A(&9A:6QI(%PB
M)7-<(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86YA
M9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("),
M;V]B=2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS
M9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B3&]O8G4B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%
M:2#U;FYE<W1U(&MU<W1U=&%D82!F86EL:2!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B16D@
M;&5I82!A:G5T:7-T(&MA=&%L;V]G:2(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B26QM
M82`G=&%R9V5T1FEL92<@<&%R86UE971R:71A(&5I('-A82!JY'1K871A+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B16D@]6YN97-T=2!E96UA;&1A9&$@:V%T86QO;V=I(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N
M(@IM<V=S='(@(D5I('-A82!E96UA;&1A9&$L("5D+6P@;VX@86QL=79A:60N
M(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X
M"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@
M<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*
M(G-T;W)E9"XB"FUS9W-T<B`B(@HB16D@<V%A(/QM8F5R(&KD<FIE<W1A9&$L
M(/QM8F5R:N1R:F5S=&%M:7-E:W,@;>3D<F%T=60@:V%N;F5T92!A<G8@96D@
M:VQA<&D@(@HB<V%L=F5S=&%T=60@87)V=6=A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T
M<B`B16D@<V%A('-U=6YA=&$@=&5A9&5T(&WDY')A='5D(&YU;6)R:6QE+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B4F]H96QI
M<V4@3F5E;64@<V%A<F5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R
M(")096%L:VER:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")4965N=7-E
M<&%K:W5J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B
M0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;V]R:6%D(&IA
M(&WD<F=E;F1I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD
M<R(*;7-G<W1R(")#87EM86YI(%-A87)E9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B
M"FUS9W-T<B`B36]B:6EL=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R("),86AT<FD@;VUA9'5S960B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L
M;"!P861D:6YG.B(*;7-G<W1R("),86AT<FD@=F]O9&5R9'5S.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*
M;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("),86AT<FD@;VUA9'5S
M960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("),86AT<FET92!V
M86AE:V%U9W5S.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*
M;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I:6QT96QE9F]N(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X
M-3DM,30I(@IM<V=S='(@(DME;'1I("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS
M9VED(")#96YT97(B"FUS9W-T<B`B2V5S:V5L92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G
M:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")+97-K+4%A
M9G)I:V$@5F%B87)I:6LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM
M<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B
M2V5S:RU%=7)O;W!A("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A
M:6QS(@IM<V=S='(@(E-E<G1I9FEK86%D:2#\:W-I:V%S:F%D(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(E-E<G1I9FEK86%D:2!O;6%N:6LB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B
M0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4V5R=&EF:6MA861I('!O
M;&EI=&EK860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B
M5'-H86%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(DUU=61A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")-=75D
M82!S86QA<_5N82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*(DUU=61A(&YI;64@:F$@86%D<F5S<VD@;6ED82!I
M;FEM97-E9"!NY&5V860@:W5I(&YA9"!S:6YU(&MI<FIU(&QO979A9"!J82`B
M"B)N96EL92!V87-T879A9"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
M4_QS=&5E;6D@:V]N9FEG=7)A='-I;V]N(&5I(';U:6UA;&1A('-A;&%S]6YA
M(&UU=71A+B!6]71A(/QH96YD=7-T("`B"B)A9&UI;FES=')A871O<FEG82XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(DWD<FLB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G
M:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E]+;VYT<F]L;&D@;&EN:VDN
M+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")4<VAI:6QI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2&EI;F$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(DAI:6YA(&QI:'1S=7-T871U9"`H
M1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")(:6EN82!T<F%D
M:71S:6]O;FEL:6YE("A":6<U*2(*"FUS9VED(")#:&]O<V4@07!P;&EC871I
M;VXZ(@IM<V=S='(@(E9A;&D@<F%K96YD=7,Z(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O
M<F0B"FUS9W-T<B`B5F%L:2!S86QA<_5N82(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE
M(@IM<V=S='(@(E9A;&D@:V%S=71A:F%N:6UI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R(")686QI(&MU=7#D979A9&4@97-I='5S=FEI<SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`B5F%L:2!L;V5N9&D@<W1I:6P@*&KD<FIE
M<W1A='5D(&QO96YD:71E(&IA;VMS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H
M<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B2O5U;'5S86%R960B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S<VD@)7,@:VER:F5L9'5S
M="!E:2!L96ET=60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(E-E;&=E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I
M9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(")%96UA;&1A($U33V9F
M:6-E(&WD<F=E;F1I9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G
M:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(E3\:&IE;F1A('#D<FEN9R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")%96UA;&1A
M(&MA<W5T86IA.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")%96UA;&1A(&MA
M<W5T86IA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*
M;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")4_&AJ96YD82!K87-U
M=&%J82!A;F1M960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("+5:'1U
M;"!S96QG:6YE8B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R
M(")+;/5P<V$@:N1T:V%M:7-E:W,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@
M=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"#\;&4@2%144"(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E-U;&4@86ME
M;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B
M"FUS9W-T<B`B4&EL=F5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")(
M;VUM:6MU;"!P:6QV97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(E!I;'9E<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM
M<V=S='(@(DMO;VMO<W-A87)E9"`H2V5E;&EN9VD@<V%A<F5D*2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E
M(%-I9&5B87(B"FUS9W-T<B`B4&5I9&$@:_QL9W)I8F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED
M(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")096ED971U9"!P:6ER:F]O
M;F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L
M=6UB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B5N1R=B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R
M(%!I8VME<B(*;7-G<W1R(")6Y')V:79A;&EK(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G
M<W1R(")6Y')V:2!V86QI:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")6965R
M9V4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B
M0V]L=6UN('1I=&QE<R(*;7-G<W1R(")6965R9W5D92!P96%L:VER:F%D(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S
M(@IM<V=S='(@(DMO;VUI:W-I9"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")+Y'-K(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DOD
M<W5R:61A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DMO;6UE;G1A87(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`B3&EH=&YI;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M0V]M;W)O<R(*;7-G<W1R(")+;VUO;W)I9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS
M9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G
M:60@(D-O;7!U=&5R<R(*;7-G<W1R(")!<G9U=&ED(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM<V=S
M='(@(DEL;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(DEL;2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(DMO;F9I9W5R871S:6]O;FD@97)I;F5V=7-E9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y
M;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS
M9W-T<B`B4V5A9&ES='5S('/\;FMR;VYI<V5E<FEM:7-E:W,@4$1!9&4L(&YU
M=&ET96QE9F]N:61E(&IA($]U=&QO;VMI9V$N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92XB"FUS9W-T<B`B4V5A9&ES='5S(&]N(&%E9W5N=60N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYF:6=U<F4@)7,B"FUS9W-T<B`B4V5A9&ES=&$@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A
M<W-W;W)D(@IM<V=S='(@(DMI;FYI=&$@<V%L87/U;F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G
M:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS
M9W-T<B`B2V]N9V\@1&5M;VMR86%T;&EK(%9A8F%R:6EK(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960N(@IM<V=S='(@(MQH96YD=7,@;G5R:G5S+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BW&AE;F1U<R!N=7)J=7,Z("(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R(")!=F%L:6L@=O5T;65S97)V97(@96D@86YN82#\:&5N9'5S="XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B079A;&EK
M(';U=&UE<V5R=F5R(&5I(&%N;F$@_&AE;F1U<W0N(%#U:&IU<SH@)7,@*"5S
M*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+<:&5N
M9'5S($944"!S97)V97)I9V$@;G5R:G5S+B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")+;VYT86MT
M:60B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT:60@]6YN97-T
M=7,@;&ES861A('-I;G4@86%D<F5S<VER86%M871U<W-E+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@<VES=2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B2N1T:V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O
M:VD@4V%A<F5D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED
M(")#;V]K:64B"FUS9W-T<B`B3?5T=&5T97)A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(DMO<&5E<FDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B2V]P965R:6UI;F4@;G5R:G5S.B`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(DMO<&5E<FD@=F%L:6LB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)
M1"(*;7-G<W1R(")#;W-T($E$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@
M4FEC82(*;7-G<W1R(")+;W-T87)I:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]T92!D)TEV;VER92(*;7-G<W1R(")#;W1E(&0G279O:7)E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B16D@<V%A;G5D(&MI
M<FIA(%!'4&=A(&MR_'!T:61A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+B(*;7-G<W1R(")%:2!S86%N=60@:VER:F$@4$=09V$@86QL:VER:F%S
M=&%D82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y
M,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(D5I('-A86YU9"!K:7)J82!3+TU)345G82!K<OQP=&ED82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D5I('-A
M86YU9"!K:7)J82!3+TU)345G82!A;&QK:7)J87-T861A+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B16D@<V%A;G5D(&QI<V%D82!K;VYT86MT:2X@)7,B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")%:2!S86%N=60@<VES<V4@3$1!4"!S97)V
M97)I<W-E+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@
M(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(D5I('-A
M86YU9"!S:7-S92!,1$%0('-E<G9E<FES<V4B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S
M='(@(D5I('-A86YU9"!K;VYT;VKDY&MI(&MO;G1R;VQL:61A+B`E<R(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")%:2!S86%N=60@_&AE
M;F1U<W0@3$1!4"!S97)V97)I9V$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T
M('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")%:2!S
M86%N=60@<V5R=F5R:6=A(%PB)7-<(B!&5%`@86)I;"#\:&5N9'5S=#H@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")*86]T=7-N:6UE:VER:F$@
M;&]O;6EN92!N=7)J=7,N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$N(@IM<V=S='(@(D5I('-A86YU9"!01U`@86YD;65I9"!D96MR_'!T:61A
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B
M16D@<V%A;G5D(%,O34E-12!A;F1M96ED(&1E:W+\<'1I9&$N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<R(*;7-G<W1R(")%:2!S86%N=60@:W5S='5T861A(&MO;G1A:W1I+B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('-A86YU9"!K=7-T=71A
M9&$@:F%O='5S;FEM96MI<FIA+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")%:2!S
M86%N=60@:W5S='5T861A('!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I<'1I
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@
M(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(")%:2!S=75T;G5D(';D;&IA('-E;&=I=&%D82!A
M9')E<W-A861I(&4M<&]S=&D@86%D<F5S<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;V=U
M(&%A9')E<W-I<F%A;6%T=2!K;VAA;&5T:7)I;6EN92!N=7)J=7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B2V]G=2!J86]T=7-N:6UE:VER:F$@:V]H86QE=&ER
M:6UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R
M(")+;V=U(&IA;W1U<VYI;65K:7)J861E(&YI;65K:7)J82!K;VAA;&5T:7)I
M;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2!<(B5S7"(N(@IM<V=S='(@(D5I(/5N;F5S='5N=60@;&%A9&ED82!S
M=')A=&5E9VEA="!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B;6MD:7(@7"(E<UPB
M(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N(@IM<V=S='(@(D5I('-A86YU9"!V]71M97-E<G9E<FES
M="!A=F%L:6MK=2!V]71I="!KY'1T92XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<
M(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B7"(E<UPB(&%V86UI;F4@:VER:G5T
M86UI<V5K<R!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(E<R!A=F%M:6YE(&YU<FIU<RXB
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(")%:2!S=75T;G5D(&OD:79I
M=&%D82!H;V]L9'5S=/;V(&UO;V1U;&ET("5S(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D5I('-A86YU9"!A=F%D82!K871A
M;&]O9VD@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B16D@
M<V%A;G5D(&OD='1E($Q$05`@<V5R=F5R:70N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B5S(&QU9V5M:6YE(&YU<FIU<RXB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB
M0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E
M9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T
M(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M(E-O;W9I='5D(&MA<W5T86IA('!A<F]O;&D@=/QH:F5N9&%M:6YE(&YU<FIU
M<RX@3?5N960@86YD;65D(&5I(&]L92#U:6=E9"X@(@HB4')O;W9I('5U97-T
M:2!V]6D@=O5T82#\:&5N9'5S="!A9&UI;FES=')A871O<FEG82P@:W5I('9A
M:F%D('-I:7-K:2!A8FDN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R
M(")!0TQI(&QA861I;6EN92!E8F'U;FYE<W1U<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=2!L86%D:6UI;F4@96)A]6YN97-T
M=7,N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")*86]T=7-N
M:6UE:VER:F$@;&%A9&EM:6YE(&5B8?5N;F5S='5S+B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J861E(&QA861I
M;6EN92!E8F'U;FYE<W1U<RX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")397)V97)I(';U:6UA;'5S
M=&4@;&%A9&EM:6YE(&5B8?5N;F5S='5S(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")+;VYF:6=U<F%T<VEO;VYI('1A9V%S:6UU=71M:6YE
M(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B<FUD
M:7(@7"(E<UPB(&5I(/5N;F5S='5N=60N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@<V5A9&ES='5S92!S
M86QV97-T86UI;F4@;G5R:G5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")+;VYF
M:6=U<F%T<VEO;VYI('9A<G5K;V]P:6$@<V%L=F5S=&%M:6YE(&YU<FIU<RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R(")+;VYF:6=U<F%T<VEO;VYI('9A<G5K;V]P:6$@<V%L=F5S
M=&%M:6YE(&YU<FIU<SH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")086EG86QD
M=7-E('5U96YD86UI<V4@<VMR:7!T:2!E:2!S86%N=60@<V%L=F5S=&%D82!K
M;VAT83H@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(D5I(/5N;F5S='5N
M=60@<V%L=F5S=&%D82!K;VYF:6=U<F%T<VEO;VYI9F%I;&D@=F%R=6MO;W!I
M870@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B
M"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y
M(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B)+
M;VYF:6=U<F%T<VEO;VYI9F%I;&D@)7,@96D@]6YN97-T=6YU9"!S86QV97-T
M861A+B!382!V]6ED(&MA<W5T861A(/QH="`B"B)V]6EM86QU<W0@:V]O9&D@
M<V%L=F5S=&%M:7-E:W,@=&%G87-I(&9A:6QI("5S(';U:2!K;W!E97)I9&$@
M:V]O9"!KY'-I='-I("(*(F9A:6QI("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4"!O='-I;F<@;G5R:G5S+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B=6YL:6YK(%PB)7-<
M(B!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+;VYT86MT:2!U=65N9&%M
M:6YE(&YU<FIU<RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")*
M86]T=7-N:6UE:VER:F$@=75E;F1A;6EN92!N=7)J=7,N("5S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM
M<V=S='(@(EPB)7-<(B!S96%D:7-T=7-E('-A;'9E<W1A;6EN92!N=7)J=7,Z
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B16D@;&5I9&YU9"!-;WII;&QA
M(&O\;&=I<F)A+B!686%T82!E="!K_&QG<FEB82!O;&5K<R!A=F%T=60N(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S
M7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB
M.B`E<R(*;7-G<W1R(")+87-U=&%J86QE(%PB)7-<(B!E:2!S86%N=60@86YD
M82!JY')G;6ES:2#U:6=U<V5I9"!K875S=&%L92!<(B5S7"(Z("5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T
M97AT(@IM<V=S='(@(E!I:7)A='5D('!I:VMU<V5G82!T96MS="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N
M=')Y(@IM<V=S='(@(E)I:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<G-U<V5D(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3&]O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS
M9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(DQI<V$@;&EN:R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R
M96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B3&ES82!U=7,B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E
M('-U8B!F;VQD97)S(@IM<V=S='(@(DQI<V$@86QA;6MA=7-T860B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O
M<B!097)M:7-S:6]N<R(*;7-G<W1R(")!=71O<FD@]6EG=7-E9"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D
M(&YU;6)E<B(*;7-G<W1R(")+<F5D:6ET:V%A<F1I(&YU;6)E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DAO<G9A871I82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5U8F$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`B4')A96=U<V5D(#0@9F%A<VDB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B06MT:6EV
M<V5D('-E<W-I;V]N:60B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O
M0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R
M(")+96QL86%E9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B4')A96=U;F4@55),(&]N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(D%K=&EI=G-E9"!K
M87-U=&%J860B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#
M=7)R96YT(%=E871H97(B"FUS9W-T<B`B4')A96=U;F4@:6QM(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C
M;VYD:71I;VXZ("(*;7-G<W1R(")0<F%E9W5N92!I;&TZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R
M<F5N="!S='EL92(*;7-G<W1R(")0<F%E9W5N92!S=&EI;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M(")(Y.1L97-T82!T]FED(&UI9&$@=&5H86MS92!S:7-E;F5M:7-E;"`E<RUI
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DSU:6MA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B
M0W5T('-E;&5C=&EO;B(*;7-G<W1R("),]6EK82!V86QI:R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")+_'!R;W,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS
M9W-T<B`B2VER:6QL:71S82`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G
M<W1R(")+:7)I;&QI='-A("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*2(*;7-G<W1R(")+:7)I;&QI='-A+U5K<F%I;F$@*$M/23@M52DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")4<V5H
M:&D@5F%B87)I:6LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$
M1"(*;7-G<W1R(")04"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS
M9W-T<B`B(@HB1%-.("AV86%T82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I
M9"`B1&%I;'DB"FUS9W-T<B`B26=A('#D978B"@HC.B!A9&UI;B]D871A=')E
M92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T
M851R964@<VER=FEJ82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")!;F1M96)A87-I
M;W1S:6YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$
M871E(@IM<V=S='(@(DMU=7#D978B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R
M(")386%B=6UI<V4@:W5U<.1E=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(DMU=7#D
M979A('9A;&EK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"FUS9VED(")$87DB
M"FUS9W-T<B`B4.1E=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB
M"FUS9W-T<B`B2W5?<W1U=&$@=F5E<F<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T
M<B`B1&5T<V5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S
M(@IM<V=S='(@(DO\;6YE;F1N=6UB<FED(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD
M96YT(@IM<V=S='(@(E;D:&5N9&$@=&%A;F1R:61A(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G
M:60@(D1E9F%U;'0B"FUS9W-T<B`B5F%I:VEM:7-I(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U
M;'0@0V]L;W(B"FUS9W-T<B`B5F%I:VEM:7-I(';D<G8B"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED
M96YT:71Y(@IM<V=S='(@(E9A:6ME:61E;G1I=&5E="(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R
M(")686EK:6UI<VD@<VAE;&PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(E/U;F%S96QE='5S960B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B2W5S='5T82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B
M1&5L971E($-E;&PB"FUS9W-T<B`B2W5S='5T82!L86AT97(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B
M1&5L971E($=R;W5P(@IM<V=S='(@(DMU<W1U=&$@9W)U<'`B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B
M"FUS9W-T<B`B2W5S='5T82!L;V=I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B2W5S='5T82#U
M:6=U<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(DMU<W1U=&$@:F$@965M86QD82!K:7)J860B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE
M=&4@8V5L;"(*;7-G<W1R(")+=7-T=71A(&QA:'1E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B2W5S='5T82!V965R9R(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@
M86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DMU<W1U=&$@;VQE;6%S;VQE
M=B!A;'1E<FYA=&EI=FYE(&UA;&PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM
M<V=S='(@(DMI<FIA9&4@:W5S='5T86UI;F4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")+=7-T=71A(/5I
M9W5S960@7"(E<UPB+6QE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(DMU<W1U=&$@]6EG=7-E9"!<(B5S7"(M;&4@:F$@:_5I:R!A;&%M]6EG
M=7-E9#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(DMU<W1U
M=&$@<FED82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI
M;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R
M(")+=7-T=71A('9A;&ET=60@:61E;G1I=&5E="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")+=7-T=71A(&%K
M=&EI=FYE('9E97)G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W(@IM<V=S='(@(DMU<W1U=&$@86MT:6EV;F4@<FED82(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M(")+=7-T=71A<VEN('!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I<'1I(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(DOD='1E=&]I;65T86UI<V4@865G(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&5N;6%R:R(*;7-G<W1R(")486%N:2(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE
M;2(*;7-G<W1R(")+:7)J96QD82!P<F]B;&5E;6DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B2VER:F5L9'5S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB
M"FUS9W-T<B`BW&MS:6MA<VIA9"`H:V%N='5D(&MA($AO<F1E(&QO9VEF86EL
M:2DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(MQK<VEK87-J860@;&]G:71I(&%D;6EN:7-T<F%A=&]R
M:2!J86]K<RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS
M9VED(")$979E;&]P;65N="(*;7-G<W1R(")!<F5N9'5S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")+
M87-T97!U;FMT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@
M(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B165L;6ES92!T
M=6YN:2!K87-T97!U;FMT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B2V%S=&5P=6YK
M=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3
M=75N9"!V87-A:W5L="!P87)E;6%L92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H
M="!T;R!L969T(@IM<V=S='(@(E-U=6YD('!A<F5M86QT('9A<V%K=6QE(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*
M;7-G<W1R(")+871A;&]O9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B17-I
M=&$@:V5L;&%A:F%D(#(T+71U;FYI<V5N82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D5K
M<F%A;FD@<V5A9&5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.CDV"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@
M(D[D:71A('#U:&IA;&EK:W4@96YN=7-T=7-T(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G
M<W1R(").Y&ET82!E;FYU<W1U<W0@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R
M(")%:W)A86YI('-E861E9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.
M+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G
M<W1R(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E
M(@IM<V=S='(@(L1R82!K=7-T=71A(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<"(*;7-G<W1R("+$<F$@_')I=&$@;6%I;G1E;F%N8V4N<&AP
M(&9A:6QI(&]T<V4@:^1I=FET861A(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B2W5I(&5S:6UE
M;F4@<FED82!S:7-A;&1A8B!VY&QJ861E(&YI;65S:60L(&WD<F=I('-E92!R
M=75T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O
M;6EN:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(D1O;6EN:6MA86YI(%9A8F%R:6EK(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O
M=6YT/R!3:6=N('5P+B(*;7-G<W1R(")3=6P@<&]L92!K;VYT;W0_(%)E9VES
M=')E97)U+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B4V%L=F5S=&$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B4V%L=F5S=&$@)7,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G
M<W1R(")386QV97-T82!L;V]D=60@<V5A9&ES='5S(%!(4"!S:W)I<'1I;F$N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O
M<"!D;W=N(&QI<W0B"FUS9W-T<B`B3FEM96MI<FDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(E)A=FEM:60B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(D4M<&]S="U335-I;&4@=F%H96YD
M=7-D<F%I=F5R+"!T965N=7-E<&%K:W5J871E;&4@:V5L;&5L('-E;&QI;F4@
M=&5E;G5S(&]N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S
M='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B
M16MU861O<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T
M97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(DUU
M=61A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(DUU=61A(&)L;VMK:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(DUU=61A(&=R=7!P:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")-=75D82#U:6=U<W0B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(DUU=61A(/5I9W5S:2(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B375U9&$@)7,@]6EG=7-I
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O
M<'1I;VYS(&9O<CHB"FUS9W-T<B`B375U9&$@<V5A9&5I9#HB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B375U
M9&$@7"(E<UPB(/5I9W5S:2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B375U9&$@)7,@]6EG=7-I(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B2&%R
M:61U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G:7!T
M=7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U
M<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(DS\;&ET
M82!S964@<VES<V4@:F$@<VEI<SH@)7,L(';U:2!K87-U=&$@;&EH='-A="!(
M5$U,('9E<G-I;V]N:3H@)7,N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!3
M86QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B
M16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM
M<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED
M(")%;6%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B12UP;W-T:2!A861R
M97-S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I9"`B
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D4M<&]S=&D@
M86%D<F5S<VED('!E879A9"!K;&%P<&EM82XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")%+7!O<W0@:VEN;FET=7-E9V$B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM
M=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B12UP;W-T+5--4VEL92!L_/QS(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM
M<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E-M86EL:60B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@
M(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E/U;G5M(&]N('3\:&DN(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM
M<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4=6QE;75S(&]N('3\:&DN
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I
M9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(D]T<VEN9W5T:6YG:6UU
M<R!O;B!T_&AI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B3'5B82!T96MS=&D@<VES<V4@;&ES
M861A('!I;'1E(&9O=&]G86QE<FEI9&5S="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_(@IM<V=S='(@(DQU8F$@<&%R96UK;/5P<W5G82!H_'!I:VUE;OS\
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")!
M87-T82!L]7!P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B4W5U
M<F5N9&$@961I=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM
M<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@
M=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M(@IM<V=S='(@(B(*(E-I<V5S=&$@<V%L86IA;F4@:_QS:6UU<R!M:61A('-I
M;G5L="!K_'-I=&%K<V4@<&%R;V]L:2!M=75T;6ES96MS+"!NY&ET96MS("(*
M(B=M:7,@;VX@<VEN=2!L96UM:6ML;V]M82!N:6UI/R<Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R
M"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B4VES
M97-T82!S:6EA('!I;&1I(%523"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S
M(&)E;&]W.B(*;7-G<W1R(")3:7-E<W1A(&%L;&$@=.1H960Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B16MV871O
M<FEA86PM1VEN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S
M='(@(D5R:71R96$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")6:6=A(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S
M='(@(E9I9V$@8FQO:VD@;&]O;6ES96PZ("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(E9I9V$@<_QN:W)O
M;FES965R:6UI<V%N:W)U(&MU<W1U=&%M:7-E;#H@)7,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B5FEG82!S_&YK
M<F]N:7-E97)I;6ES92!L;V=I(&MU<W1U=&%M:7-E;#H@)7,B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(E9I
M9V$@<VES=2!L86%D:6UI<V5L.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A
M=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B5FEG82!S86QA<_5N82!M=75T
M;6ES96PZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N(@IM<V=S='(@(E9I9V$@92UP;W-T:2!T96%T97,N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET
M:6YG(%PB)7-<(BXB"FUS9W-T<B`B5FEG82!<(B5S7"(@:VER:G5T86UI<V5L
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B165S=&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&EO;W!I
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC
M(@IM<V=S='(@(E)A:'9U<VQI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]O<&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(DEG82`Q-2!M:6YU=&D@=&%G86YT(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B179E<GD@,B!M:6YU=&5S
M(@IM<V=S='(@(DEG82`R(&UI;G5T:2!T86=A;G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G
M:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B26=A(#,P('-E:W5N9&D@
M=&%G86YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS
M9W-T<B`B26=A(#4@;6EN=71I('1A9V%N="(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN
M(@IM<V=S='(@(DEG86P@<VES<V5L;V=I;6ES96PB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T
M<B`B26=A('!O;VQE('1U;FYI('1A9V%N="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(DMO<F0@;6EN=71I<R(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E
M<SHB"FUS9W-T<B`B3N1I9&ES=N3D<G1U<V5D.B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE
M;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R(")+Y&EV:71A(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED
M(")%>'!A;F0B"FUS9W-T<B`B3&%I96YD82(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S
M='(@(D[D:71A(&O\;&=R:6)A(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(D]O
M=&%S:6X@)RDG(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;2(*;7-G<W1R(")/;W1A<VEN(&QI:'1S870@<_5N82!V]6D@:G5T
M=6WD<FMI9&5S(&]T<VEN9W5F<F%A<VDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G
M<W1R(")!96=U;6ES92!K=75PY&5V(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5K
M<W!O;F5N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E1E:W-T
M:2!VY')V(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B
M1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")396%D:7-T=7-E(/QL97-L
M86%D:6UI;F4@1E10(&MA=61U(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RXB"FUS9W-T<B`B2.3D;&5S='5S92!L86%D:6UI;F4@;G5R:G5S+B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B16D@<V%A;G5D(/QH96YD
M=7-T($Q$05`@<V5R=F5R:6=A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E
M<G9E<BXB"FUS9W-T<B`B16D@<V%A;G5D(/QH96YD=7-T(%--0B!S97)V97)I
M9V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM
M<V=S='(@(D5I('-A86YU9"!K;W!E97)I9&$@7"(E<UPB+7-T+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B16D@<V%A
M;G5D(&MO<&5E<FED82!<(B5S7"(M:2XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(E5U92!305-,(/QH96YD=7-E(&QO
M;VUI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B
M16D@<V%A;G5D('3U<W1A(%PB)7-<(BUI+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!R971R:65V93H@)7,B"FUS9W-T<B`B16D@<V%A;G5D('1I<FED83H@)7,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM
M<V=I9"`B1F%I<B(*;7-G<W1R(")(96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1I
M('-A87)E9"`H36%L=FEI;FED*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E
M($ES;&%N9',B"FUS9W-T<B`B1N3D<FD@<V%A<F5D(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@
M(DMO:'5T878@=FEG83HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@(D9A>&5S(@IM
M<V=S='(@(D9A:W-I9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")6965B<G5A
M<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,
M:6ME(@IM<V=S='(@(E1U;F1U8B!N86=U(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@
M(E1U;F1U8B!N86=U.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`BW&MS
M:6MU9"!V:6AM86AO;V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("+<:W-I:W5D(&QU;65S86IU:&]O9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")&:65L
M9"!M871R:7@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS
M9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%05$-(02(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE
M="!F;VYT(@IM<V=S='(@(D9I9VQE="!F;VYT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I
M9"`B1FEJ:2(*;7-G<W1R(")&:61Z:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R(")&86EL(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")&86EL:61E(&%R=CH@
M)7,@9F%I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@
M(D9A:6QI9&4@87)V.B`E<R!F86EL:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&86EL
M:6AA;&1U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED
M(")&:6QE($YA;64B"FUS9W-T<B`B1F%I;&D@;FEM:2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM
M<V=S='(@(D9A:6QI('9A;&EK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B1F%I;&D@_&QE
M<VQA861I;6EN92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(D9A:6QI9&4@_&QE<VQA861I;6ES="!E:2!T;V5T871A+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R(")&:6QT<FED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R(")3;V]M92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B17-I;65N92!P;V]L(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B
M1FER<W0@475A<G1E<B(*;7-G<W1R(")%<VEM96YE('9E97)A;F0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED
M(")&:7@@<F%T:6\B"FUS9W-T<B`B4^1I;&ET82!S=6AE(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI
M<"(*;7-G<W1R(")0965G96QD82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S
M='(@(DCU;&IU=B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B561U(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0B"FUS9W-T<B`B2V%T86QO;V=I("5S('!O;&4@;VQE;6%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")496MS=&D@=N1R=B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M(")4;VET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")6965B:6QE:&ET<V5J871E
M;&4@;6ES('!I;'1E(&5I('1O971A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(D5N;G5S='5S
M("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS
M9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D
M(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M(@IM<V=S='(@(B(*(E#D979A9&4@87)V("AO;&=U(/9E;&1U9"!E="!T86=A
M<W1A=&%V(&5N;G5S='5S('-I<V%L9&%B(&YI:2!PY&5V:2!K=6D@]FED.R`B
M"B)S=75R(&%R=B!V]6EB(&)L;VMI(&QA:6%K<R!V96YI=&%D82DB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO
M=7(@<&%S<W=O<F0_(@IM<V=S='(@(E5N=7-T87-I9"!S86QA<_5N83\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*
M;7-G<W1R(")6;W)M:60B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*
M;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B2VEL9"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(DMI
M;&QU('3\_'`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@
M(D9O<G1U;F5S(@IM<V=S='(@(DMI;&QU9"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")+:6QL=60@
M,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O
M<G5M<R(*;7-G<W1R(")&;V]R=6UI9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(D5D87-T=7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P
M"FUS9VED(")&<B(*;7-G<W1R(")292(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*
M;7-G<W1R(")286%M:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS
M9W-T<B`B4')A;G1S=7-M86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@
M(E!R86YT<W5S;6%A+"!%=7)O;W!A+6]S82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B4')A;G1S=7-E($=U86IA86YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
M4')A;G1S=7-E(%!O;/QN965S:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")0<F%N='-U<V4@
M3/5U;F%A;&%D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")+96QL96QT(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")3=75N86=A("(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&
M=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E#U:&IA;&EK(&MI<FIE;&1U<R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B5.1I<VMU=2(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B5.1I<VYI
M;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB
M"FUS9W-T<B`B1V%L97)I:2P@:W5S="!P:6QT(';U='1A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y
M"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEI.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R
M871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N97)E97)I("5S(&MO
M;F9I9W5R871S:6]O;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF
M:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'96YE
M<F5E<FET=60@:V]O9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS
M9W-T<B`B1W)U=7-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B4V%K<V%M86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G
M<W1R(")'86%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G
M<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")%97-N:6UI
M(@H*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(MQL9&ES960@<V5A
M9&5D(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O
M(@IM<V=S='(@(DUI;F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*
M;7-G:60@(D=O961E;"(*;7-G<W1R(")']F1E;"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@
M36%P<R(*;7-G<W1R(")';V]G;&4@:V%A<F1I9"(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
M1V]O9VQE(&]T<VEN9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(")(86QL
M=&]O;FED97-S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T
M<B`B2W)E96MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@
M(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")+<F5E:V$@*$E33RTX.#4Y
M+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R
M]O9N:6UA82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B
M1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U
M<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P<&ED92!H86QD=7,B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R=7!P:61E(&YI;65D(&5I(';U:2!O
M;&QA('3\:&IA9"(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@(@IM<V=S='(@(D=R;W5P7VQD87`Z($5I('-A82!L:7-A9&$@9W)U<'!I
M("5S+B!397)V97(@_'1L97,Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@16D@<V%A(&MU<W1U
M=&%D82!G<G5P<&D@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!%:2!S86$@;75U
M=&$@9W)U<'!I("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P
M:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U
M861E;&]U<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'
M=6%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'
M=6%T96UA86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM
M<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")+
M_&QA;&ES92#U:6=U<V5D(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DO\;&%L:7-T97)A86UA
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")':6YE82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'
M:6YE82U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G
M<W1R(")'=6%J86%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV
M,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(&ME96QD=6(@87)G</QK<VQI
M:W5L="!K=7-T=71A;6%S="!R96$@=FEI;6%S="!L86AT<FET+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@:V5E
M;&1U8B!A<F=P_&MS;&EK=6QT(&MU<W1U=&%M87-T('1A8F5L:2!V:6EM87-T
M('9E97)G=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@
M(DA434Q!<F5A(&ME96QD=6(@87)G</QK<VQI:W5L="!K=7-T=71A;6%S="!T
M86)E;&D@=FEI;6%S="!R:61A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B2%144"!A=71E;G1I;6ES="!E:2!L96ET=60N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86EI=&DB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA
M<V@M06QG;W)I=&AM(@IM<V=S='(@(E+D<VEA;&=O<FET;2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE
M(@IM<V=S='(@(DCD9W4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R
M(@IM<V=S='(@(E#D:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(E#D:7-E
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D:2!S86%R(&IA($UC1&]N86QD
M:2!S86%R960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")2Y&YK(.1I
M:V5S971O<FTB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B
M2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE96)R96$@*$E33RTX
M.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B2_5R9W5S
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS
M9VED(")(96QP(@IM<V=S='(@(D%B:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I
M=&]R(@IM<V=S='(@(D5D:71O<FD@:V%S=71A;6ES92!A8FDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T
M<B`B06)I;&EN92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B
M2&5M:7-P:&5R92(*;7-G<W1R(")P;V]L:V5R82(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M(@IM<V=S='(@(E-I:6X@;VX@9F%I;&D@86QG=7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G
M<W1R(")+]7)G92(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T
M96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?
M;64B"FUS9W-T<B`B7T%V86QE:'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")0_&AA(%1O
M;VP@*%9A=&EK86YI($QI;FYR:6EK*2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R(")!=F%L96AE;&4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*
M;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")+;V1U;F4@86%D<F5S<R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E
M8W1O<GDB"FUS9W-T<B`B2V]D=6MA=&%L;V]G(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R(")+;V1U;F4@=&5L969O;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5U<F%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9VMO;F<B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@
M(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@5FEG87-E9"`E<R!834P@86YD;65D(&MI<FIA<R`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O
M(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3V)J96MT:6QE("5S
M(&5I('9A<W1A(/QK<VMI(&MI<FDB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@16D@;&5I='5D(/QH=&MI("5S('3\_'!I(&]B
M:F5K=&D@:VER:F%S("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(-5N;F5S='5S(&5E;6%L9&%D82`E<R!<(B5S7"(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5G<F%T<VEO
M;VYI;6]O=&]R('9A:F%B("=D;VUX;6PG(%!(4"!L86EE;F1U<W0B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@<V%A
M(&QU=6$@=75T(%A-3"!P=75D(&]B:F5K=&D@)7,@:F%O:W,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@<V%A(&5E;6%L9&%D82`E<R!<
M(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!%:2#U;FYE<W1U(&AA;FMI9&$@34E-12!)1"UD
M("5S('3\_'!I(&]S82!J86]K<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($5I('-A82!S_&YK<F]N:7-E97)I9&$@)7,@7"(E<UPB
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I('-A
M82!S_&YK<F]N:7-E97)I9&$@:F%G=7-I9#H@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z(%1U;F1M871U(&IA9W4@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A
M;"!2=6QE(@IM<V=S='(@(DAO<FES;VYT86%L:F]O;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I<V]N=&%A;&YE('9O;V1E<F1U
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FES;VYT86%L;F4Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*2(*;7-G<W1R(")+=6ED87,@<V$@<VEI82!S871T=7-I9#\@
M*%!A;'5N('1E871A(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+=6D@<&%L:G4@
M=F5E<F=E('-O;W9I:W-I9"#\:&5N9&%D83\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DMU:2!P86QJ=2!VY&QJ=2`H=F5E
M<F=E*2!O;C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+=6D@<&%L:G4@<FED=2!S;V]V
M:6MS:60@_&AE;F1A9&$_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B3FEI<VMU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B3FEI<VMU
M<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R
M:7-T<R(*;7-G<W1R(")(=6UO<FES=&ED(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(=6YG87)Y(@IM<V=S='(@(E5N9V%R:2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@<&]S=&MA<W1I(&QO
M;VUI;F4@;G5R:G5S.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(DE-05`@<&]S=&MA<W1I(&MU<W1U=&%M:6YE
M(&YU<FIU<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O<W1K87-T:2!K=F]O9&D@;&]O
M;6EN92!N=7)J=7,Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!A861R97-S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A861R97-S
M('!O;&4@=&5A9&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC
M+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@
M0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@86%D<F5S<R!E:2!K=75L=2!L=6)A
M='5D($-)1%(@8FQO:VMI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+B(*;7-G<W1R("))4"!P:6ER86YG=2!R:6MK=6UI;F4N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B3&ES82!R
M:61A(%]E;FYE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S
M='(@(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G
M:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B06EN=6QT(&EK;V]N:60B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26-O;G,@9F]R("5S(@IM<V=S='(@(B5S(&EK;V]N:60B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS
M9W-T<B`B26MO;VYI9"!J82!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B261E
M;G1I=&5E9&D@;FEM:3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T
M(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@
M=VEN9&]W+B(*;7-G<W1R(")+=6D@<V5D82#U:65T:2!E:2!NY&ED871A+"`E
M<R!J82!S964@879A=&%K<V4@=75E<R!A:VYA<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN(@IM<V=S='(@(B(*(DMU:2!S82!K87-U=&%D($EN=&5R;F5T($5X
M<&QO<F5R:70@:F$@96D@;N1E(/QL9'-E(&EK;V]N92P@<VEI<R!P<F]O=FD@
M(@HB;>1R:VED82!S964@<G5U="P@;/QL:71A;6%K<R!S:7-S92!03D<@;.1B
M:7!A:7-T=G5S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R
M("(B"B)+=6D@<V$@;N1E9"!S961A('1E861E="!A9V$@<&EL=&D@96D@;N1E
M+"!S:6ES(&5I(&]S:V$@<VEN=2!V965B:6QE:&ET<V5J82`B"B)NY&ED871A
M('-E9&$@<&EL=&DL(&UI9&$@<V]O=FED(/QL97,@;&%A9&ED82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!I;&1I(&5E
M;'9A861E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")0:6QD
M:2!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B
M4&EL9&D@55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y(@IM<V=S='(@(E!I;'0@9V%L97)I:7-T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(E!I;'0@9V%L97)I:7-T
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM
M86=E('5P;&]A9"(*;7-G<W1R(")0:6QD:2#\;&5S;&%A9&EM:6YE(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R
M(")0:6QD:60B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("))
M;7!O<G0L('-A;6T@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B
M"FUS9W-T<B`B26UP;W)D:71U9"!VY&QI.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B26UP;W)D:71U9"!VY&QJ860Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R("),:7-A(')I9&$@7W#D<F%S="(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")%<VET
M871I('9A;&4@=&5G979U<V4@:V]O9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B5F%L92!K87-U
M=&%J86YI;6D@:F$O=O5I('!A<F]O;"XB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B)686QE(&MA<W5T86IA;FEM:2!V]6D@86QT97)N971I:79N
M92!A861R97-S+B!0<F]O=FD@=75E<W1I(';U:2!V]71A(/QH96YD=7-T("(*
M(F%D;6EN:7-T<F%A=&]R:6=A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*
M;7-G<W1R(")3=75R96YD82!T86%N9')I9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`BW&MS:6MU9"!K
M87-U=&%J860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G
M<W1R("));F1O;F5E<VEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M
M871I;VXB"FUS9W-T<B`B26YF;W)M871S:6]O;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO
M;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(E1E879E(&5I(&]L92!E;F%M(&OD
M='1E<V%A9&%V+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T
M97(B"FUS9W-T<B`B3&ES82!?=F5E<F<@<.1R87-T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS
M9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B3&ES82!P:6QT(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(DQI<V$@=&%B96PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E
M<G0@5V5B($QI;FLB"FUS9W-T<B`B3&ES82!H_'!E<FQI;FLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*
M;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("),:7-A('9E
M95]R9R!E;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),:7-A('5U<R!V965R
M9R!A:W1I:79S92!V965R=2!JY')E;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("),:7-A('5U<R!V965R9R!A:W1I:79S92!V965R=2!E='1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("),:7-A('5U<R!R:61A(&%K=&EI=G-E(')E82!JY')E;&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("),:7-A('5U<R!R:61A(&%K=&EI=G-E(')E
M82!E='1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T
M97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("),:7-A(&SU:6L@<')A96=U
M<V4@87-U:V]H82!JY')E;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("),:7-A
M(&SU:6L@<')A96=U<V4@87-U:V]H82!E='1E(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B3&ES82!A;'1E<FYA=&EI=FYE(&UA;&PB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#HB"FUS9W-T<B`B4VES97-T82!M86EL:6%A9')E<W,@:W5H=2!S86%K<R!S
M=6QL92!U=64@<&%R;V]L:2!S86%T83HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@
M8V5L;"!A9G1E<B(*;7-G<W1R("),:7-A(&QA:'1E<B!PY')A<W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y
M"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B3&ES82!L86AT
M97(@96YN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS
M9W-T<B`B3&ES82!V965R9R!PY')A<W0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@
M8V]L=6UN(&)E9F]R92(*;7-G<W1R("),:7-A('9E97)G(&5N;F4B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B
M26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DQI<V$@:VER:F%D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DQI<V$@
M;/5I:R!PY')A<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@
M8F5F;W)E(@IM<V=S='(@(DQI<V$@;/5I:R!E;FYE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("),:7-A(')I9&$@<.1R87-T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B3&ES82!R
M:61A(&5N;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED
M("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ(@IM<V=S='(@(DMI<FIU=&$@<V%L86O\<VEM=7-E(/5I9V4@
M=F%S='5S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B
M3&ES82]M=75D82!P:6QT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM
M<V=S='(@(DQI<V$O;75U9&$@;&EN:R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R(")*86]T=7-N:6UE:VER:F%L92!S86%T;6ES96MS(&5I(&KD=&MU
M(&MR961I:71I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*
M;7-G<W1R(")+<F5D:6ET:2!E:2!JY'1K=2XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(E3D:7-A
M<G8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("))
M;G1E9V5R(&QI<W0B"FUS9W-T<B`B5.1I<V%R=G5D92!N:6UE:VER:2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS
M9W-T<B`B5FEG86YE(%5$2"`H57-E<B!$871A($AE861E<BDN(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L
M:60@6DE0(&1A=&$B"FUS9W-T<B`B5FEG87-E9"!:25`@86YD;65D+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P
M;&EC871I;VXN(@IM<V=S='(@(E9I9V%N92!R86ME;F1U<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G
M:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(E9A;&4@8F%T8V@@240B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L
M:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(E-I<V5S=&%T:2!V:6=A<V5D
M(&%N9&UE9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RXB"FUS9W-T<B`B5FEG86YE('-I:'1A861R97-S+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@
M9FEL92!F;W)M870B"FUS9W-T<B`B5F%L92!F86EL:69O<FUA870B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A;&ED
M(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")6:6=A;F4@;&ET<V5N='-I=O5T:2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("))
M;G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")3:7-E<W1A=&D@
M=FEG86YE(&%S=6MO:'0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N
M(@IM<V=S='(@(E9I9V%N92!M<V=?='EP92(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B87!I7VED(&]N('!U=61U
M(';U:2!V:6=A;F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RXB"FUS9W-T<B`B5FEG87-E9"!V]6D@<'5U9'5V860@<&%R
M86UE971R:60N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")6:6=A
M;F4@_&QE;?5I9W5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S,*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B5FEG
M86YE('!A<G1N97)I($E$(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@
M(E9I9V%N92!T;V]T96MO;V0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O
M8V]L+B(*;7-G<W1R(")6:6=A;F4@<')O=&]K;VQL+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B5FEG86YE('-A
M86IA.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P
M-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A
M;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")6:6=A;F4@:F%G871U9"!O8FIE
M:W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S
M='(@(E9I9V%N92!LY&AT96%A9')E<W,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED
M('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B5FEG87-E9"!U;FEC;V1E(&%N9&UE
M9"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B3FEM96MI<FDB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L
M96-T:6]N(@IM<V=S='(@(E#V]G)D=F%L:6LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A86YI
M($ES;&%M:79A8F%R:6EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM
M<V=S='(@(DER86%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM
M<V=S='(@(DEI<FEM86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B36%N:2!S86%R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G
M:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(MQK<VEK=60@Y&EK97-E
M=&]R;6ED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B
M26ES<F%E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B5N1L:F%A;F1J82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B
M271A;&EC(@IM<V=S='(@(DMA;&1K:7)I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))=&%L>2(*;7-G<W1R("))=&%A;&EA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M(")*86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G
M<W1R(")*86%N=6%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G
M<W1R(")*86%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*86%P86YI("A)
M4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q
M,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y
M;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L
M87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)+=6YA('-I;G4@=F5E8FEL
M96AI='-E:F%S(&]N($IA=F%S8W)I<'0@:V5E;&%T=60L(&5I('!R=75G:2!S
M964@;&5H="#U:65T:2`B"B)P86ES=&$N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86%N
M:6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=75L:2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S
M='(@(DIU=6YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")2]O9P
M<V5L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")+
M97-K96QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")2
M]O9P<V5L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B
M5F%S86MU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R
M(")087)E;6%L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*
M;7-G<W1R(")+87-A:'-T86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R(")3Y&EL:71A(&]R:6=I;F%A;#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DME;GEA(@IM<V=S='(@(DME96YI82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W-E('-E<G9E<B!E
M:2!L87-K;G5D('-I<W-E+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L:2!V]6AI
M:W5D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B5O5T;64@;&]O;6EN92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y
M($9I;F=E<G!R:6YT(@IM<V=S='(@(E;U=&UE('/U<FUE:N1L9R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE
M;F=T:"(*;7-G<W1R(")6]71M92!P:6MK=7,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@
M(E;U=&UE('3\_'`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E;U=&UE(&MA<W5T
M=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G
M:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B5O5T:2!O;B!A=F%L:6MU<R!S97)V97)I<R!J=6)A(&]L
M96UA<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI
M9',B"FUS9W-T<B`B3&%P<V5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I
M8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B2V]R96$@4F%H=F%D96UO:W)A871L:6L@5F%B87)I:6LB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+;W)E
M82!686)A<FEI:R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED
M(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R96$@*$550RU+4BDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=79E:70B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2_5R9_5Z
M<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R(")?2W5J=6YD=7,B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")+965L
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I
M8R!297!U8FQI8R(*;7-G<W1R("),86]S92!286AV861E;6]K<F%A=&QI:R!6
M86)A<FEI:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA
M<W0@2&%L9B(*;7-G<W1R(")6:6EM86YE('!O;VPB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM
M<V=S='(@(E9I:6UA;F4@<&%R;V]L:2!M=75T=7,B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T
M(%%U87)T97(B"FUS9W-T<B`B5FEI;6%N92!V965R86YD(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T
M<B`B5FEI;6%T:2!M=75D971U9#HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`B165L;6EN92!K_&QA<W1U<SH@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")%96QM:6YE(&O\;&%S='5S.B`E
M<R!A861R97-S:6QT("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")%96QM:6YE
M(&O\;&%S='5S.B!M:71T92!K=6YA9VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQA='9I82(*;7-G<W1R("),Y'1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B4V5A9'5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED
M("),87EO=70B"FUS9W-T<B`B2W5J=6YD=7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(E3\:&D@=.1H96YD86(@<&EI<FIO
M;VYE('!U=61U;6ES="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*
M;7-G<W1R("),:6EB86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")6
M87-A:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@
M(DQE9G0@:&5A9&5R(@IM<V=S='(@(E9A<V%K('#D:7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A;'5E<R(*;7-G
M<W1R(")687-A:W5D(';DY')T=7-E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R(")487-E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5E<FEA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA
M(@IM<V=S='(@(DQI:6+\82!!<F%A8FEA(%9A8F%R:6EK(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E
M:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")4:6)U=&%B('9I:&UA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*
M;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B4V5E;F5V:6AM(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@=&EB=71A8B!V:6AM
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X
M"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`BU6AT=6P@=&EB=71A
M8B!V:6AM82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")+97)G
M92!H;V]V:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S
M='(@(DME<F=E('9I:&T@:F$@Y&EK92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(DME<F=E(&QU;65S861U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM
M<V=S='(@(DME<F=E(&QU;65T;W)M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE<FEK(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G
M<W1R("),:6YK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS
M9W-T<B`B3&EN:R!V:6ET86(@87-U:V]H=&$Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S
M<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R
M(")%<VET86UI<V5L('-E;W-T82!E+7!O<W1I(&%A9')E<W,@=75E(&MI<FIA
M(&%K;F%G82(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI;F=I9"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O
M:VEE(@IM<V=S='(@(DQI;G5X:2!P<N3D;FEK(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T("T@:V%S=71A:F$@
M=O5I8B!K875S=&$@;N1H82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*
M;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(D%N9&UE8F%A<VED92!L
M;V5T96QU(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@
M(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B06)I:6YF;R!T965M861E(&YI
M;65K:7)I(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES
M="!486)L97,B"FUS9W-T<B`B5&%B96QI=&4@;&]E=&5L=2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R
M8VAI=F4B"FUS9W-T<B`B3&ES="U!<F-H:79E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G
M<W1R("),:7-T+4AE;'`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T+4ED(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@
M(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES="U/=VYE<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@
M(DQI<W0M4W5B<V-R:6)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B
M3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM
M<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(E-E
M<W-I;V]N:61E(&YI;65K:7)J82!E<VET86UI;F4@;G5R:G5S.B`E<R(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V%S=71A:F%T92!N
M:6UE:VER:F$@97-I=&%M:6YE(&YU<FIU<SH@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(DMA<W5T86IA=&4@;FEM96MI<FIA('!O
M;&4@;'5B871U9"!NY&AA+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R(")+:7)J86YD=7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),965D=2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G
M:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&%E;BXN+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*
M;7-G<W1R(")+;VAA;&EK(&%E9SH@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B4F5G:6]O
M;B!J82!A96<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(D%S=6MO:'0B"@HC.B!L;V=I;BYP:'`Z
M,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),
M;V<@:6XB"FUS9W-T<B`B3&]G:2!S:7-S92(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@
M<V5S<VEO;B(*;7-G<W1R(")%96QM:7-E('/\;FMR;VYI<V5E<FEM:7-E(&QO
M9VDB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED
M("),;V<@;W5T(@IM<V=S='(@(DQO9VD@=N1L:F$B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(DMA<W5T86IA
M;FEM:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(E3V]F0@<VES<V5L;V=I;6ES96PB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(E-I<W-E;&]G:6UI;F4@;G5R:G5S
M+"!K=6YA(&MA<W5T86IA;FEM:2!V]6D@<&%R;V]L('!O;&YU9"#U:6=E+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@
M9F%I;&5D+B(*;7-G<W1R(")3:7-S96QO9VEM:6YE(&YU<FIU<RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E>'0B
M"FUS9W-T<B`B4&EK:R!T96MS="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")!<FUA<W1U<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B
M"FUS9W-T<B`B36%D86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L
M971T97)S(@IM<V=S='(@(DMR965K82!VY&EK973D:&5D(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM
M<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),861I;F$@=N1I
M:V5TY&AE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B5N1I:V5S960@<F]O;6$@;G5M8G)I9"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=6MS96UB=7)G(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")+2R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS
M9W-T<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148@;&ES86YD(&5I('-I<V%L9&%N
M=60@86YD;65I9"XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS
M9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R
M(")-86MA;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA:V5D;V]N
M:6$@*$5N9&EN92!*=6=O<VQA879I82!686)A<FEI:RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T
M<B`B36%A9VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS
M9VED(")-86EL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B4&]S
M=&D@861M:6YI<W1R86%T;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN
M+BXB"FUS9W-T<B`B7U1E92!L:6YK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M86QA>7-I82(*;7-G<W1R(")-86QA:7-I82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EI=FED(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O
M<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S
M("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R
M("(B"B)396%D:7-T82!K871E9V]O<FEA:60L(&UI9&$@:V%S=71A=&%K<V4@
M_&MS=7-T92!MY')G96YD86UI<V5K<R!J82!N96YD96QE("(*(FMA=&5G;V]R
M:6%T96QE('9A<W1A=F%I9"!VY')V92XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM
M<V=S='(@(DUA<#(T(&MA87)T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G
M<W1R(")-87!1=65S="!K86%R="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")6
M87-T879U<V5D('-A;'9E<W1A='5D+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-
MY')T<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")397)V(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")4Y&AI<W1A
M(&QO971U9"]L=6=E;6%T82!S=&%A='5S(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(E3D
M:&ES=&$@;75U('-T86%T=7,@*&YT+B!TY&AT:7,O=F%S=&%T=60I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA
M<G-H86QL:2!S86%R960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ
M=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B
M4V]B:79A9"!VY&QJ860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N
M:6$B"FUS9W-T<B`B36%U<F5T86%N:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:6ET:75S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-
M87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(E-U=7)I;2!L=6)A='5D(&MR
M961I:70N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"XB"FUS9W-T<B`B2VER:F$@;W-A9&4@<&EI<F%N9R#\;&5T871U9"XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(E9I:6UA<V4@,C0@='5N;FD@:_5R9V5I
M;2!T96UP97)A='5U<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*
M;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E9I:6UA
M<V4@-B!T=6YN:2!K]7)G96EM('1E;7!E<F%T=75R.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R(")3=75R:6T@<&]R=&%A;&D@8FQO:VMI9&4@87)V(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM
M<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B4W5U<FEM('!I:VMU<R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS
M9VED(")-87DB"FUS9W-T<B`B36%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I='-I:6XB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(DQI:6MM960B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE;OS\
M(&5S:71U<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("+<
M:&5N9&$@;&%H=')I9"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@
M(E1E861E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"B)+:7)I(&]N(&5D=6MA;'0@:V]N=')O;&QI
M='5D+"!E;G0@86QL:VER:F%S=&%J82!S97)T:69I:V%A=&D@96D@<V%A;G5D
M("(*(FMO;G1R;VQL:61A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D
M+B(*;7-G<W1R(")496%D92!O;B!A96=U;G5D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*
M;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")496%T92!T_/QP(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM
M<V=S='(@(DUE=&%R(&EL;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*
M;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DUE
M=&%R(&)L;VMK(&5I(&]L92!S86%D879A;"XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B365T87(@8FQO:VL@96D@;VQE('-A861A=F%L+B#<
M:W-I:V%S:F%D(&QO9VET:2!A9&UI;FES=')A871O<FD@:F%O:W,N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")-971A<D1"(/QH96YD=7,@
M<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM
M<V=I9"`B365T:&]D(@IM<V=S='(@(DUE971O9"(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`B365E=&]D(%PB)7-<(B!E:2!O;&4@9&5F
M:6YE97)I='5D(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<R(*;7-G<W1R(")-965T;V0@96D@;VQE(&1E9FEN965R
M:71U9"X@2^1I=FET871U9"!M965T;V0Z("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G
M:60@(DUE=')I8R(*;7-G<W1R(")-965T97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUE>&EC;R(*;7-G<W1R(")-96AH:6MO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B
M36EK<F]N965S:6$@1O9D97)A='-I;V]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B
M"FUS9W-T<B`B2V5S:V5L92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B34E-
M12!T_/QP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")6:6EM87-E(#(T('1U
M;FYI(&UA9&%L86EM('1E;7!E<F%T=75R.B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R(")6:6EM87-E(#8@='5N;FD@;6%D86QA:6T@=&5M<&5R871U=7(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R
M(")087)O;VQI(&UI;FEM86%L;F4@=F%N=7,@<&]L92!V965L('3D:7,B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"FUS
M9VED(")-:7)R;W(B"FUS9W-T<B`B4&5E9V5L9&$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M36ET;65S=6=U<W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E
M($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4'5U9'5B(%!%05(@<&%K971T($A4
M5%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS
M9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A='-I;V]N('!U=61U8BX@
M2W5I('1A:&%D('-E9&$@<F%K96YD=7-T(&MA<W5T861A+"!P96%D(&5N;F4@
M(@HB9V5N97)E97)I;6$@:V]N9FEG=7)A='-I;V]N:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@
M(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B4'5U9'5B('/U;G5M:2!)
M1"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B4'5U9'5B('9A:F%L:6L@4$5!4B!P86ME='0@
M36%I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T
M<B`B4'5U9'5B('-E<W-I;V]N:2!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")%
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B
M:6QE($UA:6PB"FUS9W-T<B`B36]B:6EL;F4@92UP;W-T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R
M871E(@IM<V=S='(@(DWU]61U:V%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B375U=&UI
M<V4@:W5U<.1E=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R
M(")-=75D82!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")*Y.1K(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-
M;VQD;W9A(%9A8F%R:6EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B
M"FUS9W-T<B`B36]N86MO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI
M82(*;7-G<W1R(")-;VYG;V]L:6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")+=74@
M:F$@86%S=&$B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DMO<F0@:W5U<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT
M<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")+=75F86%S
M:60B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N(@IM<V=S='(@(E)E87,@)60@;&5I=&D@<F]H:V5M(';D;&IU(&MU
M:2!E96QD871A=B`E9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B
M"FUS9W-T<B`B36%R;VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")6
M86QD879A;'0@<V5L9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")6
M86QD879A;'0@<&EL=F5S(@H*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I
M;F1Y(@IM<V=S='(@(E9A;&1A=F%L="!P:6QV97,@:F$@='5U;&EN92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED
M(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B5F%L9&%V86QT('#D:6ME<V5P86ES
M=&5L:6YE(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B3FEH=71A(&%L;&$B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@
M(DUO=F4@3&5F="(*;7-G<W1R(").:6AU=&$@=F%S86MU;&4B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`B3FEH=71A('!A<F5M86QE(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM
M<V=S='(@(DYI:'5T82#\;&5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@
M(DYI:'5T82!A;&QA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(DYI:'5T82#\
M;&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@
M(DUO<V%M8FEI:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*
M;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R(")-
M:71M971A<V5M96QI;F4@;&]E;F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P
M(@IM<V=S='(@(DUU;'1I;6%P(%5+(&MA87)T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(E9A;&EK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-:6YU(&MO;G1O(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DUI;G4@:V]N=&\@:6YF;R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R(")-:6YU('!O<G1A86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP
M:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUI;G4@
M<&]R=&%A;&D@:W5J=6YD=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM
M87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R
M964B"FUS9W-T<B`B14DL(&UA($5)($],12!N]75S(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3FEM:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI:6)I
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%A;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B2&]L
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE
M<R(*;7-G<W1R(")(;VQL86YD:2!!;G1I;&QI9"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E
M(%523"(*;7-G<W1R(").971S8V%P92!"87-E(%523"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#
M02!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92!#02!T_&AI<W1U
M<V4@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R(").971S8V%P92!U=65N9'5S92!54DPB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V
M;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@=/QH:7-T=7-E(%523"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED
M(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A<&4@
M4U-,('-E<G9E<FD@;FEM:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT(@IM<V=S='(@(DYE='-C87!E('-E<G1I9FEK86%D:2!K;VUM96YT86%R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A
M<&4@<V5R=&EF:6MA861I('3\_'`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(E;U<FLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(").979E<B(*;7-G<W1R(")-:71T92!K=6YA9VDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B575S+4MA;&5D;V]N
M:6$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(E5U<R!K871E
M9V]O<FEA(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G
M92!T;R`E<R(*;7-G<W1R(")5=7,@:VER:2`E<RUL92(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3F]O<FMU
M=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G
M:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(E5U<R!K87-U
M=&%J86YI;6D@*'!O;&4@:V]H=7-T=7-L:6LI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(").97<@6F5A;&%N9"(*;7-G<W1R(")5=7,M365R96UA82(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W
M;W)D(@IM<V=S='(@(E5U<R!S86QA<_5N82(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A
M<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R(")5=7,@<V%L87/U
M;F$@865G=6(@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R
M(")386QA<_5N860@<&5A=F%D(&ML87!P:6UA+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD
M;W<@*%]B;&%N:RDB"FUS9W-T<B`B575E<R!A:VYA<R`H7V)L86YK*2(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(").
M97=S(@IM<V=S='(@(E5U9&ES960B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7!I9"(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").
M97AT(@IM<V=S='(@(DKD<F=M:6YE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DKD<F=M:7-E9"`T
M(&9A87-I(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@
M;W!T:6]N<R(*;7-G<W1R(")*Y')G;6ES960@<V5A9&5D(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@
M(DKD<F=M:6YE/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM
M<V=S='(@(DYI:V%R86%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA
M(@IM<V=S='(@(DYI9V5E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`BUO8B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM
M<V=S='(@(D5I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M
M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O
M('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R(")0=75D=79A9"!K;VYF
M:6=U<F%T<VEO;VYI86YD;65D(&UI;&QE(&5R:6YE=G5S:2!NY&ED871A+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U
M"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@
M:6UA9V5S+B(*;7-G<W1R(")0=75D=6(@<W1R871E96=I82!)4T]D92!L;V]M
M:7-E:W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T
M<B`B4'5U9'5B(&UA;&PN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM
M<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VXB"FUS9W-T<B`B4V5L;&5S(&%S=6MO:&%S(&5I(&]L92!B;&]K:VDB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")-0T%,(&%U=&5N=&EM:7-E:W,@=F%J86QI:R!K86QE;F1R
M:2!N:6UI(&]N('!U=61U+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T
M"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(D5R:6YE=G5S:2!E:2!O;&4N
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@
M(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M(@IM<V=S='(@(E-E;&QE;&4@]6EG=7-E;&4@96D@<V%A(&%L86UA:60@;&ES
M861A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T
M:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(B5S
M(&CDY&QE<W1U<VEN9F\@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B1E10(%9&4R!H
MY.1L97-T=7-I;F9O('!U=61U8BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(E-13"!61E,@:.3D
M;&5S='5S:6YF;R!P=75D=6(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B4U%,
M+49I;&4@5D93(&CDY&QE<W1U<VEN9F\@<'5U9'5B+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DMR961I:70@;VX@86UM96YD871U
M9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S
M='(@(E-I:'1K;VAT(&WDY')A;6%T82XB"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS
M9W-T<B`B1F%I;&D@96D@;&%E='5D(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B26MO;VYE
M(&5I(&QE:71U9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R
M(")!<W5K;VAT(&WDY')A;6%T82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38Y"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B07-U:V]H="!MY.1R86UA=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G
M92!S=7!P;&EE9"XB"FUS9W-T<B`B4_5N=6T@<'5U9'5B+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED
M(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3FEM:2!P=75D=6(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYU;6)E
M<B!P=75D=6(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED
M(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B06EN=6QT('9I:7-A
M:V%D(&MI;&QU9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z
M.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")(5%10(&%U=&5N=&EM:7-E('-A;&%S]6YA
M('!U=61U8BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P
M.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DE-05`@875T96YT:6UI<V4@<V%L87/U;F$@
M<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@875T96YT:6UI<V4@<V%L
M87/U;F$@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DQO9VEN(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")005-35T0@875T96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B4TU"(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N(@IM<V=S='(@(B(*(D]P96Y34TP@<')O9W)A;6UI(&%S=6MO
M:'0@96D@;VQE(&WDY')A='5D+B!/<&5N4U-,('!R;V=R86UM(&]N('9A:F%L
M:6L@(@HB4$M#4R,Q,B!A;F1M971E9V$@=/;V=&%M:7-E:W,N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N
M9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")/;W1E;"!L:6ET=6UI<W-O;W9E(&5I
M(&]L92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B4&EI<F%N9W5T
M(&5I(&]L92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")0=75D
M=79A9"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I
M9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B17)A;&1A:F$@
M<&]L92!MY.1R871U9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R
M(")-:71T92#\:W-K:2!K_&QG(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")396QL:7-T
M(&9A:6QI(&5I(&]L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92XB"FUS9W-T<B`B4'5H=F5R9&%M:7-E:W,@<'5U9'5B(&%J
M=71I;F4@:V%T86QO;V<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+B(*;7-G<W1R(")+87-U=&%J86YI;64@:F$O=O5I('-A
M;&%S]6YA(&5I('-A861E='5D+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE
M9"(*;7-G<W1R(")%:2!T86=A<W1A='5D(&MO<G)E:W1S96ED(%A-3"!A;F1M
M96ED(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")6Y.1R='5S960@<'5U9'5V
M860B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB06QG;F4@:V]N9FEG
M=7)A='-I;V]N(&5I('-I<V%L9&$@=F5R<VEO;VYI+B!,;V\@:V]N9FEG=7)A
M='-I;V]N('5U97-T:2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")3:6YU(&MO
M;F9I9W5R871S:6]O;B!E:2!S:7-A;&1A('9E<G-I;V]N:2X@3&]O(&MO;F9I
M9W5R871S:6]O;B!U=65S=&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R(")-Y.1R86UA=&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(DWDY')A;6%T
M82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@
M*$E33RTX.#4Y+3$P*2(*;7-G<W1R(")0]6AJ86UA860@*$E33RTX.#4Y+3$P
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T
M<B`B3F]R9F]L:VD@<V%A<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE
M<F4B"FUS9W-T<B`B4/5H:F%P;V]L:V5R82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(E#U:&IA+4UA
M<FEA86YI('-A87)E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM
M<V=S='(@(DYO<G)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")-:71T92!H:6QJ
M96T@:W5I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B36ET=&4@=F%R96T@:W5I
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").
M;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B16D@;VQE(&MA=&%L;V]G(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB
M"FUS9W-T<B`B4&]L92!T96]S=&%T=60N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G
M<W1R(")-Y.1R86UA=&$B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S
M-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B16D@;VQE
M('1O971A='5D+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T
M<B`B3>1R:VUE9"(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(E!O;&4@;6ED86=I('-I<G9I9&$L(&UI;F4@=&%G87-I+B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E
M;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R(")!<G8B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@
M8VAA<F%C=&5R<R(*;7-G<W1R(")-Y')K:61E(&%R=B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB
M97(@;V8@8V]L=6UN<R(*;7-G<W1R(")6965R9W5D92!A<G8B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B
M3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B4FED861E(&%R=B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED
M(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")*86]T=7-N:6UE:VER:F%S(&UU=71M
M:7-E;&4@:W5U;'5V860@;G5M8G)I9"!P;VQE(&WDY')A='5D+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B
M:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K=&D@;&]O:F$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R
M(")+86AE:W-A;F1N=6UB97(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/:W1O
M;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F
M96YS92!F:6QT97(B"FUS9W-T<B`B5FEI<V%K=7-E(&%S=&4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`B2V]N=&]R:73V]B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF
M9F5R96YT+B(*;7-G<W1R(")686YA(&IA('5U<R!S86QA<_5N82!P96%V860@
M;VQE;6$@97)I;F5V860N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4')A96=U;F4@
M<V%L87/U;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*
M;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B
M4')A96=U;F4@<V%L87/U;F$@96D@;VQE(/5I9V4N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86%N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S
M97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(MQH:7-K
M875S='4@=O5I;6%L9&%V860@86EN=6QT($E-05`@<V5R=F5R:60N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R(")!:6YU;'0@96)A=FEI<V%K860@:VEL;'5D
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R
M97-S(&%L;&]W960N(@IM<V=S='(@(DQU8F%T=60@;VX@86EN=6QT(/QK<R!E
M+7!O<W1I(&%A9')E<W,N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M
M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)*86\@;VUA;FEK:W4@
M=O5I(&]M86YI:W4@]6EG=7-I('-A86(@;75U=&$@86EN=6QT(&]M86YI:R!V
M]6D@<_QS=&5E;6D@(@HB861M:6YI<W1R86%T;W(N(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(D%V82!U=65S(&%K;F%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM
M<V=S='(@(D]P96Y34TP@=FEG83H@06YD;65T92!E<F%L9&%M:6YE(&%L;&MI
M<FIA<W1A='5D(%,O34E-12!O<V%S="!N=7)J=7,N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED
M(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%V
M86(@<V5L;&4@;&EN9VD@=75E<R!A:VYA<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/
M<&5R871S:6]O;FES_'-T965M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")396%D960B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B4V5A9&ES='5S.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G
M<W1R(").=6UM97)D871U9"!L;V5T96QU(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G
M<W1R(")/<F=A;FES871S:6]O;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM
M<V=S='(@(D%L;/QK<W5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("));F9O(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(E)A:V5N9'5S92!A;&=N92!M86QL(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")!;&=S960@
M;6%L;&ED(&MA=&%L;V]G:7,@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(DUU=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DUU=2!I
M;F9O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B
M3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B3VUA;FEK=2#U:6=U<V5D(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-
M(&%U=&5N=&EM:6YE(&5I(&]L92!S86%D879A;"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z
M.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.CI-86EL('1U9VDB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@
M1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0(&1I9VET86%L86QL:VER
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@:W+\<'1I='5D
M(&%N9&UE9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"!A=F%L:6L@
M=O5T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*
M;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0
M(&%L;&MI<FIA<W1A='5D+VMR_'!T:71U9"!A;F1M960B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!K
M;V]D(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B4$A0(&OD<W5R:61A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B4$P@:V5R9V4@=FEH;2(*"FUS9VED(")032!286EN(@IM<V=S
M='(@(E!,('9I:&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")03"!H;V]V
M:6AM860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")03"!L=6UI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")03"!T:6AE(&QU;65S861U(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@
M(E!-(%-U;B(*;7-G<W1R(")03"!PY&EK92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*
M;7-G<W1R(")03"#D:6ME<V5T;W)M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS
M9W-T<B`B4$]325@@;&%I96YD=7,@<'5U9'5B(@H*(SH@;&EB+V%P:2YP:'`Z
M,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`@:^1S=7)I9&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(E3D:61E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9"(*;7-G<W1R(")086QE<W1I:6YA(&]K=7!E97)I='5D('1E<G)I=&]O
M<FEU;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A
M;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*
M;7-G<W1R(")086%P=6$@575S+4=I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U86DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L
M;W5D>2(*;7-G<W1R(")686AE;&1U=B!P:6QV:7-U<R(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W
M;W)D(@IM<V=S='(@(E-A;&%S]6YA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B4V%L87/U;F$@;75U9&5T=60N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`B5F%L92!S86QA<_5N82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(E)!1$E54R!A=71E;G1I;6ES96MS(&]N('9A:F%L:6L@<V%L87/U;F$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B4V%L87/U;F$@:VEN;FET
M=7-E9V$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G
M:60@(E!A<W-W;W)D.B(*;7-G<W1R(")386QA<_5N83HB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G
M<W1R(")386QA<_5N83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(E-A;&%S]6YA9"!P96%V860@:VQA<'!I;6$N(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@
M(D%S971A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B
M07-E=&$@;/5I:V5P=6AV<FES="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B07-U
M:V]H="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(D]O=&5L(&QI:71U;6ES<V]O
M=FED.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O
M<&QE(@IM<V=S='(@(DEN:6UE<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T
M<B`B4')O='-E;G1I(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R(*;7-G<W1R(")+Y&EV:71A(&AO;VQD=7-T]O9D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")4964@<VES<V5L
M;V=I;6ES96P@:&]O;&1U<W3V:60B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+5:6=U
M<R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S
M='(@(M5I9W5S="!<(B5S7"(@96D@:W5S='5T871U9"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4X-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI
M960B"FUS9W-T<B`B2G5U<F1E<.3D<R!K965L871U9"(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("+5:6=U
M<V5D(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`BU6EG=7-T92!H86QD=7,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DES:6ML:6L@:6YF;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B4&5R=2(*;7-G<W1R(")097)U=2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("),96UM:6ML;V]M860B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I
M;&EP:6EN:60B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM
M<V=S='(@(D9O=&]D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB
M"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I
M:W-L:70B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L
M871I='5D97,B"FUS9W-T<B`B3?5T=&5T=7-E9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")+;/5P<V$@;?5N
M9&$@;&%H=')I<W-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@
M(DMI;FYI=&$@970@<V]O=FED('-E;&QE(&5L96UE;F1I(&5E;6%L9&%D83HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B2VEN;FET82!E="!S
M;V]V:60@<V5L;&4@96QE;65N9&D@;&%H=&D@_&AE;F1A9&$N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B4VES97-T82!K=74@:F$@
M86%S=&$N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ(@IM<V=S='(@(E-I<V5S=&$@<V5L;&4@=75E(&MA=&5G
M;V]R:6$@;FEM:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q
M"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G
M<W1R(")3:7-E<W1A(&MO<G)E:W1N92!)4"!A861R97-S+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N(@IM<V=S='(@(E-I<V5S=&$@:V]R<F5K=&YE(&MU=7#D978L(&MO
M;G1R;VQL:2!PY&5V861E(&%R=G4@:W5U<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T
M:6UE+B(*;7-G<W1R(")3:7-E<W1A(&MO<G)E:W1N92!A96<N(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")+:7)J
M96QD82!P<F]B;&5E;6DN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R
M(")3:7-E<W1A(&]M82!K87-U=&%J86YI;6D@:F$@<V%L87/U;F$B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DQO
M92!JY')G;F5V('1E:W-T(&SD8FDN(%/\<W1E96UI(&MA<W5T86UI<V5K<R!0
M14%$('1I;F=I;75S=&5G82!N]75S='5M82XB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")+:7)J=71A
M('5U92!K871E9V]O<FEA(&YI;6DZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M;VQA;F0B"FUS9W-T<B`B4&]O;&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;&EI=&EK82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM
M<V=S='(@(DO\<VET;'5S960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T
M=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")396QL92!P:6QD:2!P
M86EG=71U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM
M<V=S='(@(E-E;&QE('1A8F5L:2!P86EG=71U<R(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B2VER
M:G5T82!S96QL97-S92!K875S=&$@*$E-05`@96D@:V]N=')O;&QI*2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA
M<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E9I:6UA<V4@)7,@='5N;FD@<V%D
M96UE9#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM
M<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")3861E
M;65T93QB<B`O/G3U96[D;W-U<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!6
M86IA;&EK:W4@3$1!4"!L86EE;F1U<W0@96D@;&5I='5D+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?
M<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!686IA;&EK:W4@<V5S<VEO;B!L
M86EE;F1U<W0@96D@;&5I='5D+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("+5:'5R]6AK(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L
M979E;#H@(@IM<V=S='(@(M5H=7+U:&L@;65R97!I;FYA;#HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@
M(@IM<V=S='(@(M5H=7+U:&LZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B
M"FUS9W-T<B`B165L=F%A9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")0:6QD:2!E96QV
M86%D92!U=65S(&%K;F%S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*;7-G
M:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B165L;6ES960@<V5A9&5D
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B5'+\:VD@9&]K=6UE
M;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E-A;&%J86YE(';U=&DB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B
M;&5M(@IM<V=S='(@(E!R;V)L965M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP
M:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R
M;V)L965M:2!K:7)J96QD=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT:60B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B4V5L9VET878@=&5K<W0B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!U8FQI8R!+97DB"FUS9W-T<B`B079A;&EK(';U=&DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME
M>2!!;&=O<FET:&TB"FUS9W-T<B`B079A;&EK=2!V]71M92!A;&=O<FET;2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B079A;&EK=2!V]71M92!I;F9O
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED
M(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R(")6]71M97!A87)I(&=E;F5R965R:6UI;F4@96D@
M]6YN97-T=6YU9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC
M;R(*;7-G<W1R(")0=65R=&]R:6EK;R(*"FUS9VED(")0=7)G92!M97-S86=E
M<R(*;7-G<W1R(")+=7-T=71A='5D(&MI<FIA9&4@965M86QD86UI;F4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")+871A<B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B
M4.1R:6YG(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1
M=6]T82(*;7-G<W1R(")0:6ER86YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!(&%V86QI:R!V]71I("@E
M9"!B:71T:2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS
M9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B5F%L:6LB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I
M;B(*;7-G<W1R(")6:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B2&]M
M;6EK=6P@=FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`BU6AT=6P@=FEH
M;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")(;V]V:6AM(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A
M:6X@86YD(%-N;W<B"FUS9W-T<B`B5FEH;2!J82!L=6UI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@
M=&\@4VYO=R(*;7-G<W1R(")6:6AM(&IA(&QU;6DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B
M2G5H=7-L:6L@:VEL9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4')O='-E;G0B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*
M;7-G<W1R("),;V4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),;V4@
M:VER:G4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B2V%S('3U97-T
M:2!K=7-T=71A9&$@)7,_(%-E92!T;VEM:6YG(&]N('#V]G)D=6UA='4N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@
M(DMA<R!T]65S=&D@:W5S='5T861A(&MA<W5T86IA("5S(&%N9&UE9#\@4V5E
M('1O:6UI;F<@;VX@</;V<F1U;6%T=2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L
M87-T(&%C=&EO;B(*;7-G<W1R(")486%S=&%B('9I:6UA<V4@=&5G979U<V4B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")6Y')S:V5N9&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B5N1R<VME;F1A(&3\
M;F%A;6EL:7-E9"!M96[\_"!E;&5M96YD:60Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS
M9W-T<B`B5N1R<VME;F1A('!O<G1A86QI('9A861E.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(E)E9W5L86%R879A;&1I<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R
M(@IM<V=S='(@(E-U:&5T92!S:7)V:6IA(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P
M.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(DQA92!U=65S=&DB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")-
MY')K=7-E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@
M(E)E;6]T92!397)V97)S(@IM<V=S='(@(E;D;&ES960@<V5R=F5R:60B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M(")6Y&QI;F4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*
M;7-G<W1R(")%96UA;&1A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B165M86QD82!B
M;&]K:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B2W5S='5T82!V
M965R9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D5E;6%L
M9&$@:W5J=6YD=7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R
M.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B165M86QD82!P86%R(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(DMU<W1U=&$@<V%L=F5S=&%T=60@<VMR:7!T('-E<G9E<FD@
M86IU=&ES97-T(&MA=&%L;V]G:7-T+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E
M('1H92(*;7-G<W1R(")%96UA;&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D5E;6%L9&$@
M9&]K=6UE;F1I<W0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")+=7-T=71A(&MA
M<W5T86IA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R
M(")+=7-T=71A(&MA<W5T86IA.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(")0Y')I;F=U
M;&4@<&]L;G5D(';U:6UA;&EK('9A<W1A=&$N(%1A9V%S=&%T:2!V96%K;V]D
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED
M(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S
M='(@(E-O;W9I=&%V870@=&5E;G5S="!E:2!L96ET=60N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M5F%J86QI:R!<(B5S7"(@<'5U9'5B("5S('-E861I<W1U<V5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9A
M:F%L:6L@7"(E<UPB('!U=61U8B!61E,@<V5A9&ES='5S97,N(@H*(SH@9G)A
M;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(E9A:F%L:6L@7"(E<UPB('!U=61U8B!S96%D:7-T=7-E
M<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*
M;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(DMO:'5S='5S;&EK(';D
M;&DB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS
M9W-T<B`B5/QH:F5N9&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B375U9&$@<V%L
M87/U;F$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I
M9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")5;G5S=&%S:6X@;VUA
M('-A;&%S]6YA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B
M4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(E1A87-T82!E96QM:6YE('#D
M<FEN9R(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S
M(@IM<V=S='(@(E1U;&5M=7-E9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B
M4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5&%G87-I('-E861I<W1U<W-E
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2
M971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(DMO<F1A('5U="!S86QA<_5N
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U
M;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B5O5T82!K;VYF:6=U<F%T<VEO;VX@=&%G87-I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(E)I8V@@5&5X="!%9&ET;W)I('-E861I<W1U
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE
M<R(*;7-G<W1R(")-]6ES=&%T=7-E9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS
M9W-T<B`B4&%R96TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q
M"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B4&%R96T@<.1I<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A
M;'5E<R(*;7-G<W1R(")087)E;6%D(';DY')T=7-E9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I
M9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]296$@<V5A9&5D+BXN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S
M-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VQL(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UE96YI82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T
M92`Q.#`B"FUS9W-T<B`B4/;V<F$@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B
M"FUS9W-T<B`B4/;V<F$@=F%S86MU;&4B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B
M"FUS9W-T<B`B4/;V<F$@<&%R96UA;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O
M<&5R=&EE<R(*;7-G<W1R(")296$@<V5A9&5D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W
M('!R;W!E<G1I97,B"FUS9W-T<B`B4F5A('-E861E9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S
M.B(*;7-G<W1R(")2:61U.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@
M(DIO;VYE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B2F]O;F5D('1E:VEV
M860@:_5I9VD@<FED861E(&IA('9E97)G=61E('9A:&5L92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM
M<V=S='(@(DIO;VYE9"!T96MI=F%D(&%I;G5L="!V965R9W5D92!V86AE;&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>2(*;7-G<W1R(")*;V]N960@=&5K:79A9"!A:6YU;'0@<FED861E('9A
M:&5L92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*
M;7-G<W1R(")+Y&EV:71A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA
M;B!&961E<F%T:6]N(@IM<V=S='(@(E9E;F4@1O9D97)A='-I;V]N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%
M(&MR_'!T;V=R86%F:6QI;F4@86QL:VER:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%(&MR_'!T:71U9"!K:7)I(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,
M(&%U=&5N=&EM:6YE(&5I(&]L92!S86%D879A;"XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S
M='(@(E--4R!L_&AI<_5N=6UI9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR
M,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!KY'-U<FED82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T
M96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,(&%V86QD:7,@
M=N3D<G1U<W1E(&QE:61M:7-E:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("+53DY%4U154R(*"B,Z
M(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")3
M7U%,(&OD<W5R:61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B3&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%I;G0@2&5L
M96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`B4V%I;G0@2VET=',@:F$@3F5V:7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R(")386EN="!0:65R<F4@:F$@36EQ=65L;VXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<R(*;7-G<W1R(")386EN="!6:6YC96YT(&IA($=R96YA9&EI;FED(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I
M9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E-A;6%S(')A86UI<R`H
M7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S
M='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M
M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@:F$@4')I;F-I<&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3
M871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QL:6ET<VED92!K87-U
M=&%J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G
M<W1R(")3875D:2!!<F%A8FEA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9E<W1A("(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4V%L=F5S=&$@7"(E
M<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")386QV97-T82`E<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T
M:6]N<R(*;7-G<W1R(")386QV97-T82!S96%D:7-T=7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S
M('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-A;'9E<W1A
M(&=E;F5R965R:71U9"!K;VYF:6=U<F%T<VEO;VX@4$A0('-K<FEP=&EN82!S
M97)V97)I(&%J=71I<W-E("(*(FMA=&%L;V]G:2XB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!K;VYF:6=U<F%T<VEO;VX@
M<V%L=F5S=&%T=60N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B4&%I9V%L9'5S92!U=65N9&%M:7-E
M('-K<FEP="!S86QV97-T871U9"!F86EL:3H@7"(E<UPB+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T
M=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B2&%J=7-A9"#D:6ME<VAO;V0B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS
M9W-T<B`B5&5A9'5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@
M(E-E87)C:"(*;7-G<W1R(")/='-I;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")/
M='-I;F=U;6]O=&]R:60B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5F%L:2!F86EL:60B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T
M"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9A;&D@:W5U<.1E=B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE
M8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5F%L:2!L:7-A=&%V(&=R=7!P
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L
M96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E9A;&D@=75S(&]M86YI:R(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T
M(&$@<V5R=F5R(@IM<V=S='(@(E9A;&D@<V5R=F5R(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@
M861D(@IM<V=S='(@(E9A;&D@;&ES871A=B!K87-U=&%J82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E
M;&5C="!A;&PB"FUS9W-T<B`B5F%L:2!K]6EK(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O
M;F5N=',N(@IM<V=S='(@(E9A;&D@:_5I:R!K=75PY&5V82!K;V]S=&ES;W-A
M9"XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9A;&D@;V)J
M96MT(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BQ')A('9A;&D@;6ED
M86=I(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B5F%L:2!V86IA;&EK=60@;>1R
M9VED(&MA<W1I9&5S="X@4VEI<R!S86%D(&YE960@:V]P965R:61A(&MI<FIA
M('-I<W-E+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")686QI(&MU
M=7#D979A(&5R86QD86IA.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")6
M86QI(&MU=7#D979A(&5S:71U<W9I:7,Z(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E9A;&D@:61E;G1I
M=&5E="!M:61A('-O;W9I9"!M=75T83HB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB
M"FUS9W-T<B`B5F%L:2!K96QL86%J82!E<F%L9&%J83HB"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O
M<FUA=#HB"FUS9W-T<B`B5F%L:2!K96QL86%J82!E<VET=7-V:6ES.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")686QI(&MA:W,@<V]B:79A
M="!VY&QJ82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED
M(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E9A;&D@=N1R
M=FES:V5E;2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9A
M;&D@;VUA(&QE;6UI:VME96PZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B4V%A9&$@<')O8FQE96UI(&MI<FIE;&1U<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--
M4R(*;7-G<W1R(")386%D82!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M96YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I
M9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD
M($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA(&IA($UO;G1E;F5G<F\B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B
M4V5R:6%L($YU;6)E<B(*;7-G<W1R(")*Y')J96YU;6)E<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-E<G9E<FD@86YD
M;65D(&]N('9A;&5D(';U:2!P=75D=79A9"XB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B4V5S<VEO
M;VYI9&4@:&%L9'5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N
M(@IM<V=S='(@(E-E<W-I;V]N:2!)1"!O;B!A96=U;G5D+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4U]E<W-I;V]N
M:60B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3
M970B"FUS9W-T<B`B2'5L:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B
M"B)-Y.1R82!A;F1M960@;6ES(';U:6UA;&1A=F%D('-U;"!O;6$@<&%R;V]L
M:2#D<F$@;75U=&$@:W5I('-A('-E;&QE('5N=7-T860N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M(@IM<V=S='(@(E-E861I<W1A(';D;&ES960@<V5R=F5R:60@;6ED82!S;V]V
M:60@;VUA('!O<G1A86QI<R!K87-U=&%D82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B4&%N92!P
M86EK82!O;6$@:V5E;&4L(&%J87;V]FYD:2!J82!K=75PY&5V82!S96%D:7-T
M=7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB3>3D<F$@;VUA(&%L9W)A:V5N9'5S+"!VY')V:7-K965M
M+"!L96AE:_QL:F4@=N1R<VME;F1A;6ES92!S86=E9'5S(&IA(&UU=60@("(*
M(F5S:71U<V4@<V5A9&5D+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(E!A:6=A;&1U<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(D]L96UA<V]L979A
M9"!P86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:60B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")0
M87)A;65E=&5R(&WDY')A8B!M:71U(';U:6UA;&EK:W4@87-U:V]H=&$Z("(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5I
M<VAE;&QI9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G
M:60@(E-H;W!P:6YG(@IM<V=S='(@(D]S=&QE;6EN92(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y
M(@IM<V=S='(@(DS\:&EK;VMK=7;U=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B2V%S(&5N86UU<V5L92!L:6YK
M:61E;&4@='5L96MS(&WDY')A=&$@:VEI<FML86AV:60_(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS
M9W-T<B`B3N1I=&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS
M9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(D[D:71A(&]L96UA<V]L979A(&IA(.1S:F$@9V5N97)E97)I
M='5D(&MO;F9I9W5R871S:6]O;FD@97)I;F5V=7-I+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B3N1I=&$@<VES<V5L;V=I;6ES
M96P@965L;6ES92!S:7-S96QO9VEM:7-E(&%E9V$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P
M(&]R:6=I;F%L(@IM<V=S='(@(E!A:W4@=O5I;6%L=7-T(&]R:6=I;F%A;&D@
M<^1I;&ET86UI<V5K<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(D[D:71A('9A;&EJ870B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(D[D:71A('1A8F5L
M:71O:6UI;F=U=&4@;65N_/QR:6)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/R(*;7-G<W1R(").Y&ET82!V87-A:W5L("5S(&UE;OS\
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!T86)E;&D@;&%H=')I(&]M861U
M<W1E(&1I86QO;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!T86)E;&D@;VUA9'5S
M=&4@9&EA;&]O9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O
M=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!T86)E;&D@<F5A
M(&]M861U<W1E(&1I86QO;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!P:6QD:2!O
M;6%D=7-T92!D:6%L;V]G:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(D[D:71A('5P;&]A
M9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")(;V]V:6AM(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E
M<G,@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@:&]O=FEH;6%D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H
M;W=E<G,@3&%T92(*;7-G<W1R("+5:'1U;"!H;V]V:6AM860B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO
M=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B2&]O=FEH;6%D(/QM8G)U
M<VMO;FYA<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(DMI='-E;F1A(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X
M-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S="(*;7-G<W1R(")+:71S96YD82!K]6EG97!E86QT(&YA86)E
M<F)L;VMK92!V]6D@;FEH=71A(&YE960@965S="#D<F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I
M9"`B4VEG;B!U<"(*;7-G<W1R("),:6ET=2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T
M<B`B06QL:VER:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L
M;&MI<FIA(&%L9V]R:71M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")3=75R=7,B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I
M9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")*Y'1A(&AO;VQD=7,@=F%H
M96QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B
M4VQO=F%K:VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS
M9W-T<B`B4VQO=F5E;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B3'5M:2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED
M(")3;F]W(%-H;W=E<B(*;7-G<W1R(")4:6AE(&QU;65S861U(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")4:6AE9&%D(&QU;65S86IU9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3
M;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@=&EH961A9"!L
M=6UE<V%J=60B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`BU6AT
M=6P@=&EH961A9"!L=6UE<V%J=60B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(DQU;64@<&%K<W5S
M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B3'5M92!V964M96MV:79A
M;&5N=#H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S
M(@IM<V=S='(@(E-A86QO;6]N:2!S86%R960B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%A;&EA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@
M(DQA=6QU9"!J82!L=75L971U<V5D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T
M<B`B4V]R=&5E<FEM:7-JY')J96MO<G)A('9A;&EK(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I
M9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B3.1H=&5A861R97-S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(DSU=6YA
M+4%A9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DSU=6YA+45U
M<F]O<&$@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T
M:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G
M<W1R("),]75N82U'96]R9VEA(&IA($SU=6YA+5-A;F1W:6-H:2!386%R960B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DSU=6YA
M<&]O;&ME<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL
M<R(*;7-G<W1R(")686AE(&QA:'1R:71E('9A:&5L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B
M5F%H92!L86AT<FD@<VES=2!J82#DY')E('9A:&5L(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B17)A
M;&1A:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B5F%H92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B5F%H960@
M:F$@=F]O9&5R9'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S
M='(@(DAI<W!A86YI82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")2Y&UP<W!O<W0B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN
M<'5T(@IM<V=S='(@(D5R:6WD<FMI9&4@<VES97-T=7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED
M(")3<&QI="!C96QL(@IM<V=S='(@(D5R86QD82!L86AT<FED(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM
M<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(DQA:'5T82!V965R9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("),86AU=&$@<FED82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S
M='(@(E-P;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS
M9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G:60@(E-T86YD87)D
M(@IM<V=S='(@(E-T86YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%L9W5S
M86%S=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B3W-A<FEI:R!V
M]6D@;6%A:V]N9"(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B3VQE:R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A9V4@9F]R;6%T
M(@IM<V=S='(@(E-A;'9E<W1U<V9O<FUA870B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B
M"FUS9W-T<B`B5.1N878@:F$@;6%J82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B
M"FUS9W-T<B`B3.1B:6IO;VYI='5D('1E:W-T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B
M4W1R:6YG:61E(&QO96YD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS
M9W-T<B`B17)A;&1A(&1O;65E;B!A861R97-S:7-T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I:6P@6T-34UTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*
M;7-G<W1R(")0_"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B06QA;6MA=&%L;V]G:2!<(B5S7"(@96D@;&5I='5D+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*
M;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B5&5E;6$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B2VEN;FET82(*"B,Z
M('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+B(*;7-G<W1R("(B"B)3;V]V(%PB)7-<(B!L:7-A;6ES96MS
M('/\<W1E96UI(&]N('-A;'9E<W1A='5D+B!382!E:2!S86$@<VES<V4@;&]G
M:61A(&5N;F4@(@HB:W5I('-I;G4@<V]O=B!O;B!H96%K<R!K:6ED971U9"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B06QA:6YD96MS(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(DSD:W,@:V]R9&$B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!O;B!S_'-T
M965M:2!L:7-A='5D+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!A
M;F1M960@;VX@<_QS=&5E;6ES="!E96UA;&1A='5D+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM
M<V=S='(@(EPB)7-<(B!O;B!K=7-T=71A='5D+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M
M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@
M;VX@<_QS=&5E;6ES="!E96UA;&1A='5D+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*
M(DMO;F9I9W5R871S:6]O;B!O;B!T86=A<VD@=O5E='5D+B!-=75T=7-T92!N
MY&=E;6ES96MS(';D<G-K96YD82!V86%D970N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(DMO;F9I9W5R871S:6]O;FD@=F%R=6MO;W!I82#U;FYE<W1U<R!S
M86QV97-T861A+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")+;VYF:6=U<F%T
M<VEO;VYI9F%I;&D@=F%R=6MO;W!I82`E<R#U;FYE<W1U<R!S86QV97-T861A
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB
M(&UU=71M:6YE(/5N;F5S='5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!K:7)J
M=71A;6EN92#U;FYE<W1U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N
M(@IM<V=S='(@(E-U9&%A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B4VES=6MO:VMU=O5T92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B4.1I:V5S973U=7,B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T
M<B`B4.1I:V5S96QO;VIA;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4.1I:V5S
M97!A:7-T96QI;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E#D:6ME<V5T]75S(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")0Y&EK97-E=/5U
M<R]L;V]J86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(E#D:6ME<V5T]75S.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B4.1I:V5S96QO;VIA;F<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")0
MY&EK97-E;&]O:F%N9SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B
MW&QA:6YD96MS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM
M<V=I9"`B4W5P<&]R="(*;7-G<W1R(")4=6=I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;6DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B4W5R;F%M92(*
M;7-G<W1R(")097)E:V]N;F%N:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!J82!*
M86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS
M9W-T<B`B4W9A87-I;6%A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N
M(@IM<V=S='(@(E)O;W1S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R(")3:'9E:71S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B
M4_QN:W)O;FES965R:6UI<V4@;&]G:2!K=7-T=71A='5D(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(E-Y
M;F--3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM
M<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")+
M:7)J879I9V$@;W1S:6YG=71I;F=I;75S=&5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4_S\<FEA($%R
M86%B:6$@5F%B87)I:6LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("+$:6ME<V5T
M;W)M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(E1U=6QI;F4@
M:F$@Y&EK97-E;&EN92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("+$:6ME<V5P
M=6AA;F=U9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R(")(;VUM:6MU
M;"#D:6ME<V5P=6AA;F=U9"(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135B!F86EL(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE
M(@IM<V=S='(@(E1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE
M<R(*;7-G<W1R(")486)E;&D@;VUA9'5S960B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B
M"FUS9W-T<B`B5&%B96QI=&4@:'5L:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R
M;W!E<G1I97,B"FUS9W-T<B`B5&%B96QI(&]M861U<V5D(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:79A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")4
M86EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A:79A;BP@2&EI
M;F$@<')O=FEN=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N
M(@IM<V=S='(@(E1A9'II:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YS86%N
M:6$@W&AE;F1V86)A<FEI:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B079A
M;F5M:6YE.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B
M5/;V9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S
M"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F;VYI;G5M
M8F5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E9I:6UA<V4@='5N;FD@=&5M<&5R
M871U=7(Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=75R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*
M;7-G<W1R(")496UP97)A='5U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E;7!E
M<F%T=75R/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<R(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(DUA;&QI(%PB)7-<(B!E:2!L96ET=60N(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(DUA;&QI9&4@:&%L9'5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")4
M97AT(@IM<V=S='(@(E1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(D%I;G5L="!T96MS="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B5&5K<W1I(&IO;VYD
M=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'1T;W`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4
M:"(*;7-G<W1R(").92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS
M9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")486D@*%1)4RTV,C`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&%I(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(E3D;F%M92!K_&QA
M<W1A;6%S="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B1E10(&QA:65N9'5S(&5I(&]L92!S86%D879A;"XB"@IM<V=I9"`B
M5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")(:7-T
M;W)Y('/\<W1E96T@;VX@=N1L:F$@;/QL:71A='5D+B(*"B,@<&AP+69O<FUA
M=`HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`IM<V=I9"`B5&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P
M;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8B!I;G1E9W)A='-I;V]N
M:6UO;W1O<B!E:2!T;V5T82!<(B5S7"(M:2(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C
M;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`@;&]G:2!A
M;&=VY.1R='5S=&%M:6YE(&YU<FIU<RXB"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I
M9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N8V4Z
M.B!K;&%S<VD@;&%A9&EM:6YE(&YU<FIU<R(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")396%D971E(&%K96X@
M;VX@<W5L971U9"X@5N1L:G5N+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(DMU:2!T
M86AA9"!K87-U=&%D82#U:6=U<VDL('!E86(@861M:6YI<W1R86%T;W(@<V5A
M9&ES=&%M82!P_'-I=F$@]6EG=7-T92`B"B)S_'-T965M:2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS
M9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")!:6YU;'0@86QU
M;6EN92!K_&QG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB2V]N=&%K=&D@
M240@;G5M8G)I="!E:2!MY.1R871U9"P@:N1E=&D@=/QH:F%K<R!V]6D@<V5E
M('!U=61U8B!A;F1M96)A87-I<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(DMI<FIE(/5N;F5S='5S(&QI<V%D82!S:6YU(&%A9')E<W-I<F%A;6%T
M=7-S92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"B)!;&QK:7)J87-T871U9"!K:7)J82!K;VYT<F]L;&EM:7-E:W,@
M;VX@=F%J82!E<F%L9&D@4$=0(&%L;&MI<FIA8FQO:VMI+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED
M("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@
M9&%T86)A<V4N(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J82!)1"!O;B!MY.1R
M86UA=&$L(&KD971I('3\:&IA:W,@=O5I('!U=61U8B!A;F1M96)A87-I<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+B(*;7-G<W1R(")*86]T=7-N:6UE:VER:2!P;VQE(&WDY')A='5D
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4
M:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+B(*;7-G<W1R(")+<OQP=&EM:7-E:W,@;VX@=F%J82!T=7)V
M86QI<W0@2%144"#\:&5N9'5S="XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A
M("5S('-E='1I;F<N(@IM<V=S='(@(D9A:6P@)7,@<&5A:W,@<VES86QD86UA
M("5S(&WDY')A;F=U="XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+B(*;7-G<W1R(")&86EL("5S('!E86MS('-I<V%L9&%M82!M
M:6YG96ED("5S(&WDY')A;F=U:60N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1F%I;&D@96D@<V%A(&MO<&5E<FED
M82!I<V5E;F1A;&4@;W1S82XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H
M<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")&86EL(&5I('-I<V%L9&%N=60@86YD;65I9"XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+B(*;7-G<W1R(")*Y')G;F5V860@<V5L;&4@;65S<V%G
M92]R9F,X,C(@:VER:F$@<.1I<V5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB5.1I<V5K
M<F%A;FER97II:6UI(&MA<W5T86UI;F4@=&5K:71A8B!P<F]B;&5E;64@26YT
M97)N970@17AP;&]R97)I<R!TY&YU("(*(G-E;&QE('9E96)I;&5H:71S96IA
M('9I9V%D96QE+"!M:61A(&UE:6P@96D@]6YN97-T=2!M86AA('-U<G5D82X@
M17-I;F5D82`B"B)V]6EB(&SD8G4@:W5J=71I<V5S+"!E9&ET;W)I(&9U;FMT
M<VEO;VYI9&4@<'5U9'5M:7-T(&IA+W;U:2!V965B:6QE:&ET<V5J82`B"B)J
M=6AU<VQI:VMU(&MI;FYI:F]O:W-M:7-T+B!+=6D@<VEN=2!A<G9U=&D@;W!E
M<F%T<VEO;VYI:W,@;VX@5VEN9&]W<R`Y>"P@(@HB<VEI<R!O;B!VY&=A('3U
M96[D;VQI;F4@970@<V%A9"!<(D=E;F5R86P@4')O=&5C=&EO;B!&875L=%PB
M('9E871E871E(&IA("(*(G!E860@87)V=71I('1A87-KY&EV:71A;6$N7%QN
M7%QN4VEN9"!O;B!H;VEA=&%T=60N($ML]7!S82!/2RP@:W5I('-O;W9I9"`B
M"B)S:6ES:VD@=.1I<V5K<F%A;FER97II:6UI('!R;V]V:61A+B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED
M96YT:71E970@7"(E<UPB(&]N(&MU<W1U=&%T=60N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B06EN=6QT('9A<V%K
M(&O\;&<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M(")#<GEP=%]P9W`Z.B!K;&%S<VD@:F%O:W,@<&5A8B!O;&5M82!MY.1R871U
M9"!';G501R!P<F]G<F%M;6D@87-U:V]H="XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<
M(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"XB"FUS9W-T<B`B(@HB2VER:2!M:7,@<V%A9&5T:2`E<R!A861R97-S:6QE
M("5S('1E96UA9V$@7"(E<UPB(&]N(&%V871U9"Y<;B(*(E-E92!E:2!G87)A
M;G1E97)I(&5T(&MI<FD@;.1B:2!L;V5T:2!V]6D@<V5L;&5S="!A<G4@<V%A
M9&DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E(@IM<V=S='(@(DYI;6D@;6ED82!K87-U=&%D82!E9&ET;W)I(&QE:&5G
M82!L:6YK:6UI<V5L(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0Q"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R
M:6,N(@IM<V=S='(@(E;D;&IA9&4@87)V('!E86(@;VQE;6$@87)V+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&]R9&5?0W)Y<'1?<VUI
M;64Z.B!K;&%S<R!V86IA8B!O<&5N<W-L(&UO;V1U;&ET+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)%96QI<W1U<W0@7"(E<UPB(&5I(/5N
M;F5S='5N=60@<V%L=F5S=&%D82P@:W5N82!A;F1M971E(&AU;&L@_&QE=&%S
M('-U=7)I;6$@(@HB;'5B871U9"!MY.1R82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP
M92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M(@HB4V5D82!T_/QP:2!A;F1M971E("@E<RD@=F%A=&%M:7-E:W,@=F%J86QI
M:VMU('!R;V=R86UM:2!E:2!L96ET=60@<_QS=&5E;6ES="XB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C
M:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T
M<B`B2G5T=6WD<FL@<&5A8B!O;&5M82#\:W,@;>1R:RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED
M(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")!:6YU
M;'0@=F%S86L@:F$@<&%R96T@:_QL9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")!:6YU;'0@<&%R96T@:_QL9R(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G
M<W1R(")%<F%L9&%J82!P96%B(&]L96UA(/QK<R!MY')K+B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(E-E<G9E<B!<(B5S7"(@;VX@:W5S='5T871U9"XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R
M(%PB)7-<(B!O;B!S86QV97-T871U9"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(E<R!L:6ET=6UI<W-O
M;W8@;VX@965M86QD871U9"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R(")-Y.1R871U9"!R:61A('!O;&4@;VQE;6%S
M+B(*"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")-Y.1R871U9"!R:61A("@E9"D@<&]L92!O;&5M87,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B06IU=&ES="!F86EL:2!<(B5S7"(@<&]L92!O
M;&5M87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I
M9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X
M="!O;B!T:&4@<V-R965N+B(*;7-G<W1R(")3:6YU('-I<V5S=&%T=60@=&5K
M<W0@96D@:V%T='4@96MR86%N:6P@;VQE=F%G82XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")!:6YU;'0@
M_&QE;6EN92!J82!A;'5M:6YE(&O\;&<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P
M('-I9&4@;VYL>2(*;7-G<W1R(")!:6YU;'0@_&QE;6EN92!K_&QG(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS
M9W-T<B`B4V%A9&5T=60@86YD;65D(&]N('9A:&5P96%L(&MA;W1S:2!LY&EN
M=60N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M
M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(E-A861E='5D
M(&9A:6QI(&5I('-A86YU9"!S86QV97-T861A+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B=V5A=&AE
M<BYC;VT@8FQO:VL@96D@;VQE(&OD='1E<V%A9&%V+B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DMU:G5N9'5S
M=&4@:V%T86QO;V=I(%PB)7-<(B!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B16D@;VQE(&UI9&%G:2!S96%D
M:7-T861A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DMI<FIA;"!E:2!O;&4@=F%H971U
M;'0@97-I=&%T879A:60@;W-I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N(@IM<V=S='(@(B(*(E-E;&QE<R!VY&QJ87,@;VX@;&EI86QT('!A
M;&IU(&WD<FME+B!382!S:7-E<W1A<VED("5S(&WD<FMI.R!L=6)A='5D('!O
M;&4@(@HB<F]H:V5M(&MU:2`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN
M+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G
M<W1R(")<(B5S7"(@;&ES86UI<V5L('/\<W1E96UI('1E:VMI<R!P<F]B;&5E
M;3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")+87-U=&%J
M82!<(B5S7"(@86YD;65T92!S_'-T965M:7-T(&5E;6%L9&%M:7-E;"!T96MK
M:7,@<')O8FQE96TZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")<(B5S7"(@965M86QD
M86UI<V5L('/\<W1E96UI<W0@=&5K:VES('!R;V)L965M.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(EPB)7-<
M(B!M=75T;6ES96P@=&5K:VES('!R;V)L965M.B`E<R(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(D9A:6QI(&QA861I;6ES96P@
M<V5R=F5R:7-S92!T96MK:7,@<')O8FQE96TZ("5S(&5I(&QA971U9"XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB1F%I
M;&D@;&%A9&EM:7-E;"!S97)V97)I<W-E('1E:VMI<R!P<F]B;&5E;3H@)7,@
M;VQI('-U=7)E;2!K=6D@=O5I;6%L9&%B("(*(G!I:7)A;F<@*"5D(&)A:71I
M*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"XB"FUS9W-T<B`B(@HB1F%I;&D@;&%A9&EM:7-E;"!S97)V97)I
M<W-E('1E:VMI<R!P<F]B;&5E;3H@)7,@;&%E=&D@86EN=6QT(&]S86QI<V5L
M="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R="(*;7-G<W1R(")396QL92!K:7)J82!O<V$@97-I=&%M
M:7-E;"!T96MK:7,@=FEG82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B2V]N=&%K=&%N9&UE
M=&4@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE
M;F1A<B=I(&%N9&UE=&4@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B
M"B)396%D:7-T=7-E('9O<FUI;"!E<VEN97,@=FEG82X@16AK(&KD='-I9"!T
MY&ET;6%T82!M]6YE(&MO:'5S='5S;&EK=2!VY&QJ82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*(E-O;W9I='5D(&%A9')E<W-I<F%A;6%T=2!O
M<&5R871S:6]O;FD@<V]O<FET86UI<V5L('1E:VMI<R!V:6=A+B!086QU;B!P
M<F]O=FD@(@HB:&EL:F5M('5U97-T:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(DMO;G1A:W1A;F1M971E
M('5U96YD86UI<V5L('1E:VMI<R!V:6=A+B!086QU;B!P<F]O=FD@:&EL:F5M
M('5U97-T:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B2F%O='5S;FEM96MI<FIA('5U96YD86UI<V5L('1E
M:VMI<R!V:6=A+B!086QU;B!P<F]O=FD@:&EL:F5M('5U97-T:2XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@
M(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N(@IM<V=S='(@(E-E92!)34%0('-E<G9E<B!E:2!V]6EM86QD82!K
M875S=&%D92!J86=A;6ES="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")3964@96D@;N1I
M(&]L979A="!K;W)R86QI:R!205(@87)H:6EV+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(E-E
M92!E:2!NY&D@;VQE=F%T(&MO<G)A;&EK(%I)4"!F86EL+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")3964@
M96D@;N1I(&]L979A="!K96AT:78@:V%A<F1I(&YU;6)E<BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M(E-E92!D<F%I=F5R(';U:6UA;&1A8B!S86%T82!S]6YU;65I9"!LY&)I($-L
M:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@(@HB;/S\<VDL(&MA
M<W5T861E<R!(5%10($%0270B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(E-E92!D<F%I=F5R(';U:6UA;&1A8B!S86%T82!S]6YU;65I
M9"!LY&)I(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&S\_'-I+"`B"B)K87-U
M=&%D97,@2%144"!!4$ET+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB4V5E(&1R86EV97(@=O5I;6%L9&%B
M('-A871A('/U;G5M96ED(&SD8FD@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M
M86EL+F-O;2D@(@HB;/S\<VDL(&MA<W5T861E<R!(5%10($%0270N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*
M(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER
M97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH
M='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(E-E92!D<F%I=F5R(';U
M:6UA;&1A8B!S]6YU;6ET92!S86%T;6ES="!33510('!R;W1O:V]L;&EG82!L
MY&)I(%9O9&%F;VYE("(*(DET86QY(&S\_'-I+"!A:6YU;'0@5F]D869O;F4@
M;G5M8G)I=&5L92X@4V5L;&5K<R!O;B!V86IA(%9O9&%F;VYE($ET86QY(&4M
M(@HB<&]S=&D@:V]N=&]T("AH='1P.B\O=W=W+C$Y,"YI="DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")3
M964@=N1L:2!O;B!K;VAU<W1U<VQI:RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N(@IM<V=S='(@(E-E92!VY&QI(';U:6(@<VES86QD861A
M('9A:60@=.1I<V%R=F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B4V5E(';D;&D@=O5I8B!S:7-A
M;&1A9&$@86EN=6QT(&YU;6)R96ED(&IA(&MO;VQO;FET+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(E-E92!VY&QI
M(';U:6(@<VES86QD861A(&%I;G5L="!K86AE:W-A;F1A<G9E+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S(@IM<V=S='(@(E-E92!VY&QI('!E86(@;VQE;6$@:V]M86=A(';U
M:2!T_&AI:W5G82!E<F%L9&%T=60@=.1I<V%R=G5D92!L;V5N9"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")3964@=N1L:2!P96%B
M(&]L96UA(&MO<G)E:W1N92!A<G8N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R(")3964@=N1L:2!P96%B('-I<V%L
M9&%M82!VY')V:6MO;V1I(%)'0B!(97@@:W5J=6PL(&[D:71E:W,@)R,Q,C,T
M868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R
M(")3964@=F]R;2!O;B!J=6)A(&SD8FD@=/;V=&%T=60N(@H*(SH@=&5M<&QA
M=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!I<R`E<RXB"FUS9W-T<B`B4V5E(&]N("5S+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E
M<R(*;7-G<W1R("(B"B)3964@;VX@2V]L86(@1W)O=7!W87)E(&]B:F5K="X@
M4V5L;&4@;V)J96MT:2!V86%T86UI<V5K<R!V86IA9"!E+7!O<W1I("(*(FML
M:65N=&D@;6ES(&WU:7-T86(@2V]L86(@1W)O=7!W87)E(&9O<FUA871I+B!3
M96QL:7-T92!E+7!O<W1I(&ML:65N=&ED92`B"B)N:6UE:VER:F$@;&5I860@
M86%D<F5S<VEL="`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BXB"FUS9W-T<B`B4V5E(&MI<FD@;VX@:VER:G5T871U9"!M
MY')G:7-T:6MU<R`H)7,I(&UI<R!E<FEN96(@<VEN=2!O;6%S="XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N
M=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E-E92!A<G8@
M<&5A8B!O;&5M82!VY&AE;6%L="#\:W,N(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B
M4V5E('-E<G9E<B!E:2!M]6ES=&$@;&%H=&D@<&%K:VED82!Z:7`@:F$@9WII
M<"!F86EL92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+B(*;7-G<W1R(")3964@<_QS=&5E;2!O;B!P<F%E9W4@=N1L:F$@
M;/QL:71A='5D+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S
M='(@(E-E;&QE(&MO:&$@<&5A;"!P96%B(&]L96UA(&%R=BXB"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM
M<V=S='(@(E-E92!A:V5N('1U;&5B(&%V861A(%-E861E=&4@86MN87-T(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`BQ&EK92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B2&5L<&1E
M<VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R(")!
M96<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4
M:6UE(%1R86-K:6YG(@IM<V=S='(@(E3V]F%J871A8F5L(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")!
M:F$@97-I='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM
M<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B06IA('9A;&EK(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B261A+51I
M;6]R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS
M9W-T<B`B4&5A;&MI<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S
M='(@(E!E86QK:7)I("AT;V]L=&EP*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(DME
M;&QE;&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)-:71M92!O8FIE:W1I
M('9A;&EM:7-E:W,@:&]I82!A;&P@0W1R;"`H4$,I(';U:2!#;VUM86YD("A-
M86,I(&ML86AV:2!J82`B"B)K;/5P<V$@;V)J96MT:61E;"XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*;7-G
M<W1R(")4Y&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(DA434P@:V]O9&D@<F5Z:6EM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G
M;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B2&]M;64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"FUS
M9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@
M;6EN=71E<RXB"FUS9W-T<B`B5FEI;6%S=&5L(&UI;G5T:71E;"!O;B!L:6EG
M82!P86QJ=2!N=7)J=6YU9"!S:7-S96QO9VEM:7-I+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B
M5&]P(@IM<V=S='(@(MQL97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM
M<V=S='(@(E!E86QM:7-E<R!R86%M:7,@*%]T;W`I(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B
M5/5L:V5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O
M8F%G;R(*;7-G<W1R(")4<FEN:61A9"!J82!4;V)A9V\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM
M<V=S='(@(E3U9&4@=O5I('9A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")492(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N965S
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5/QR
M9VDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES
M:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5/QR9VD@*$E33RTX.#4Y+3DI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U
M<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<R!J82!#86EC;W,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H
M;VEC93H@(@IM<V=S='(@(DMI<FIU=&$@;VUA('9A;&EK.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z
M("(*;7-G<W1R(")55BUI;F1E:W,Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(E-I;G4@<VMR:7!T:2!KY'1T971O:6UE=&%M:7-R87!O<G1I(%523"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G
M:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED
M(")5:W)A:6YE(@IM<V=S='(@(E5K<F%I;F$B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B16D@<.3D<V4@;&EG:2!61E,@:V%T86QO
M;V=I;&4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV
M"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R(")4Y&EE;F1A=F$@:V%S=71A:F%I
M;F9O(&QI<V%M:6YE(&QI:71U;6ES96P@96D@]6YN97-T=2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B16D@<V%A(&UU=71A(%9&4R!F86EL:2!<(B5S7"(@
M]6EG=7-I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(D5I('-A82!M=75T82!61E,@9F%I;&D@)7,O
M)7,@]6EG=7-I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M(@IM<V=S='(@(D5I('-A82!M:6YN82!K871A;&]O9VD@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S
M='(@(D9A:6QI(%PB)7-<(B!S=75R=7-T('!O;&4@=O5I;6%L:6L@:V]N=')O
M;&QI9&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R
M(")&86EL:2!<(B5S+R5S7"(@<W5U<G5S="!P;VQE(';U:6UA;&EK(&MO;G1R
M;VQL:61A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S
M='(@(D5I('-A82#\:&5N9'5S="!344P@<V5R=F5R:6=A+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"XB"FUS9W-T<B`B4U-,(/QH96YD=7-E(&%L9V%T86UI
M;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R
M-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G
M<W1R(")61E,@9F%I;&D@:V]P965R:6UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(E9&4R!K871A;&]O9VD@7"(E<UPB(&QO;VUI;F4@;G5R:G5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B5D93(&MA=&%L;V]G:2!L;V]M:6YE(&YU<FIU<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9F%I;&D@
M;&]O;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B5D93(&MA=7-T82!<(B5S7"(@
M;&]O;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE
M+B(*;7-G<W1R(")%:2!S86$@;'5U82!T_&AJ82!61E,@9F%I;&DN(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5
M;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("),86AT:7!A:VMI
M;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"(@96D@<V%A(&MU<W1U
M=&%D82P@:V%T86QO;V<@96D@;VQE('3\:&DN(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T
M<B`B16D@<V%A(&MU<W1U=&%D82!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM
M<V=S='(@(B5S(&5I('-A82!K=7-T=71A9&$L(&MA=&%L;V]G(&5I(&]L92!T
M_&AI(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S
M='(@(E9&4R!K871A;&]O9VEP=74@:W5S='5T86UI;F4@;G5R:G5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!K871A
M;&]O9VD@:W5S='5T86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@5D93(&MA
M=&%L;V]G:3H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@5D93(&9A
M:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9F%I;&D@:W5S='5T86UI
M;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@5D93(&MA
M=7-T82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT
M,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A(%9&
M4VD@<F5K=7)S:6EV<V5L=#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN(@IM<V=S='(@(DIO;VMS=F%T(&MA=&%L;V]G:2!E:2#U
M;FYE<W1U('1U=F%S=&%D82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R(")%:2!S86$@:^1T=&4@<V5R=&EF:6MA
M861I(/QK<VEK87-J=2(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H
M<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+B(*;7-G<W1R("(E<R!D969I;FET<VEO;VYI(&QA861I;6EN
M92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+B(*;7-G<W1R(")61E,@9F%I;&D@_&UB97)T]7-T;6EN92!N=7)J=7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B16D@<V%A(&%V861A(%9&4R!F86EL:2!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N(@IM<V=S='(@(D5I('-A82!A=F%D82!61E,@9F%I;&D@;75U
M=&UI<V5K<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92XB"FUS9W-T<B`B5D93(&9A:6QI(&%V86UI;F4@;G5R:G5S+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G
M:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T
M<B`B4&%K:71U9"!A<FAI:79I(&%V86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('-A82!L
M=6=E9&$@5D93(&9A:6QI("AF:6QE<VEZ92@I(&YU<FIU<RDN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B16D@
M<V%A(&QU9V5D82!61E,@9F%I;&D@*&=E=$9I;&53:7IE*"D@;G5R:G5S*2XB
M"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O
M;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G
M<W1R(")%:2#U;FYE<W1U(&QU9V5D82!F86EL:3H@(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@:V%T86QO
M;V=I(&QU9V5M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(B5S(&5I('-A82#\;6)E<B!N:6UE=&%D82`E<RUK<SH@
M<VEH=&MA=7-T(&]N(&IU8F$@;VQE;6%S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&MA=&%L;V]G:2#\;6)E<FYI
M;65T86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D5I('-A82#\;6)E<B!N:6UE
M=&%D82!61E,@:V%T86QO;V=I.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")%:2!S86$@_&UB97(@;FEM971A9&$@5D93(&9A
M:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV
M,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*
M;7-G<W1R(")%:2!S=75D82#\;6)E<B!N:6UE=&%D82!61E,@9F%I;&D@)7,O
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B5D93
M(&9A:6QI(/QM8F5R;FEM971A;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B16D@]6YN97-T
M=2!KY&EV:71A9&$@)VUK:7-O9G,G+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(E-E9&$@5V]R9&D@
M9&]K=6UE;G1I(&]N(';U:6UA='4@=/5L9V5N9&%D82(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('-A82!K:7)J=71A9&$@5D93
M(&9A:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN(@IM<V=S='(@(D5I('-A82!K:7)J=71A9&$@5D93(&9A:6QI
M("AC;W!Y*"D@;G5R:G5S*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B5D93(&9A
M:6QI(&%N9&UE=&4@<V%L=F5S=&%M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(D5I('-A
M82!K:7)J=71A9&$@5D93(&9A:6QI+"!K971T86MV;V]T(&SD:&5B(&SU:&MI
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")!;&QA:F]O;FET=60@=&5K
M<W0B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O
M($-H86YG97,B"FUS9W-T<B`B5&%A<W1A(&%L9W-E:7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")6]71A8B!V:6EM87-E('1E
M9V5V=7-E('1A9V%S:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(D]O=&%M871U('9A<W1U
M<R!S97)V97)I;'0@_&AE;F1U<V4@;&]O;6ES96PZ("(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(D]O=&%M871U('9A
M<W1U<R!S97)V97)I;'0Z("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@
M(DMA=&5G;V]R:6%T82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM
M<V=S='(@(D%R86%B:6$@W&AE;F1E;6ER86%D:60B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E-U=7)B<FET86YN:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@
M(D%M965R:6MA(-QH96YD<FEI9VED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@
M(D%M965R:6MA(-QH96YD<FEI:VED92!VY&EK97-A87)E9"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("+<:&EK=60B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(E1U;F1M
M871U(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(E1U;F1M871U(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(@IM<V=S='(@(E1U;F1M871U(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B3>3D<F%T:2!T=6YD;6%T=2!A<W5K;VAT+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B5'5N9&UA
M='4@:V%S=71A:F%N:6UI(&IA('-A;&%S]6YN82XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@
M(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(MQH96YD82!S
M964@96QE;65N="!L86AT:2XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").:6UE='4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y
M"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL
M;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@
M(B(*(M5I9W5S=&5T82!S:W)I<'1I9"!E:2!S86$@='5R=F%K86%L=71L=7-T
M96P@<')O9W)A;7-E;'0@<V]O<FET861A(&SU:6MA;6ES="\B"B)K;&5E<&EM
M:7-T+B!+=6D@:VSU<'-A9"!/2RP@;N1E9"!M;WII;&QA+F]R9R!T96AN:6QI
M<W0@<V5L9VET=7-T(&MU:61A<R`B"B)L=6)A9&$@<VMR:7!T:61E;"!L]6EK
M97!U:'9R:70@:V%S=71A9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B
M"FUS9W-T<B`B165M86QD82!VY')V(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY
M,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")4;V5T
M86UA=&$@;&%I96YD=7,B"@HC.B`M+2T@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*
M;7-G:60@(E5P9&%T92(*;7-G<W1R(")+:6YN:71A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&4@)7,B"FUS9W-T<B`B375U9&$@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*
M;7-G<W1R(")-=75D82!K87-U=&%J82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E
M<UPB+B(*;7-G<W1R(")<(B5S7"(@;75U9&5T=60N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N(@IM<V=S='(@(E5U96YD=7-E('-K<FEP="!K=7-T=71A='5D+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@
M(DQA92!S97)V97)I<W-E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N(@IM<V=S='(@(DOU:6L@<F%K96YD=7-E('!A:6=A
M;&1U<V9A:6QI9"!O;B!S97)V97)I<W-E(&QA971U9"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS
M9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(DQA9&EN82!S=75R
M=.1H960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(E-U=7)E9"!R;V]M82!N=6UB<FED(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%I(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(DMA<W5T82!P
M<F%E9W5S=#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")+87-U
M=&$@4U-,:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@
M(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N(@IM<V=S='(@(DMA<W5T82!J=6AU;"!K=6D@;FEM:2]S86QA<_5N
M82!)35-0('-E<G9E<FES(&]N(&5R:6YE=BXB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(DMA
M<W5T86IA(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(DMA<W5T86IA;"`E<R!E:2!O;&4@
M;'5B871U9"`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B2V%S=71A:F%H86QD=7,B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E
M<B!/<'1I;VYS(@IM<V=S='(@(DMA<W5T86IA('-E861I<W1U<R(*"B,Z('-I
M9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(DMA<W5T86IA(')E9VES=')E97)I;6EN92(*"B,Z('-I9VYU<"YP:'`Z,C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N(@IM<V=S='(@(E-E;&QE<R!S86ED:7,@:V%S=71A:F%T
M92!R96=I<W1R965R:6UI<W0@96D@=O5I;6%L9&%T82XB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O
M=6YD(@IM<V=S='(@(DMA<W5T86IA:V]N=&]T(&5I(&QE:71U9"(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DMA<W5T
M86IA;FEM:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R(")+87-U=&%J86YI;6D@7"(E<UPB(&]N(&IU
M8F$@;VQE;6%S+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DMA<W5T86IA;FEM:3HB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(DMA<W5T86IA;FEM:3HB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M
M.B(*;7-G<W1R(")+87-U=&%J860@<_QS=&5E;6ES.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57-B96MI<W1A;B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(E9&4R!K871A;&]O9VD@<&]L92!O;&5M87,N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`B4'5H:W5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@(@IM<V=S='(@(D]L96UA<V]L979A9"!K;W)R96MT<V5D(&%S=6MO:&%D
M(&]N.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S
M.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B2V5H=&EV=7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(DUI
M;G5T:71E(&%R=B!P<F%E9W5S97-T(&AE=&ME<W0@86QA=&5S+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@
M=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")6Y.1R='5S(/QL
M971A8B`E<R!M86MS:6UU;7!I:VMU<V4N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B5N3D<G1U<V5D
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R
M;VTB"FUS9W-T<B`B5N3D<G1U<V5D(&UI;&QE(&AU;&=A<W0@=F%L:61A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B
M5F%R:6%B;&4B"FUS9W-T<B`B375U=&QI:R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE='-U965L82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"XB"FUS9W-T<B`B2V]N=')O;&QI;6EN92!N=7)J=7,@+2!S
M964@:VER:2!V]6EB(&]L;&$@<&%H871A:'1L:6MU;'0@;75U9&5T=60N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@
M(E9E<G-I;VXB"FUS9W-T<B`B2N1R:F5N=6UB97(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`B5F5R<VEO;VYI:&%L9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@
M86QI9VXB"FUS9W-T<B`B5F5R=&EK86%L;F4@:F]O;F1U<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E
M<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R=&EK86%L;F4@=F]O9&5R9'5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:V%A;&YE.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED
M(")697)Y($AI9V@B"FUS9W-T<B`B5N1G82!K]7)G92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)
M*2(*;7-G<W1R(")6:65T;F%M:2`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(@IM<V=S='(@(E9A871A("5S(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*
M;7-G<W1R(")686%T82!VY&QI<W0@=F5E8FEL96AT92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9A871A(&MU:2`E<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S
M='(@(D)R:71I($YE:71S:7-A87)E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(E5302!.96ET<VES86%R
M960B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I
M;&ET>2(*;7-G<W1R(").Y&AT879U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(").
MY&AT879U<SH@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!3
M3510(@IM<V=S='(@(E9O9&%F;VYE($ET86QY(/QL92!33510(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")(3TE!5%53(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N
M(@IM<V=S='(@(DA/24%455,A(2$@2U535%5402!32U))4%0@2\13251322!+
M051!3$]/1TE35"`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)
M3B#\;&4@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@
M1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!J82!&=71U;F$B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B
M"FUS9W-T<B`B2&]I871U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(DMO(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R
M($9O<F5C87-T(@IM<V=S='(@(DEL;6%E;FYU<W1U<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P
M<F]V:61E9"!B>2(*;7-G<W1R("));&UA86YD;65I9"!P86MU8B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB
M"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E9E96(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R(")6
M965B:7-A:70B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B2V]R9"!NY&1A;&%S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E
M;&-O;64B"FUS9W-T<B`B5&5R92!T=6QE;6%S="(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@
M(E1E<F4@='5L96UA<W0@)7,M:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")497)E('1U;&5M
M87-T+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("),Y.1N92`H25-/+3@X-3DM
M,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(DSDY&YE("A)4T\M.#@U.2TQ-2DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B
M3.3D;F4M4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")-:6QL:7-E(')A:V5N
M9'5S92!P96%K<R`E<R!PY')A<W0@<VES<V5L;V=I;6ES="!A=F%M83\B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B36EL;&ES="!M
MY')K:2!K87-U=&%T86MS92!E<F%L9&%J86YA/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_(@IM<V=S='(@(DUI;&QI<W0@;>1R:VD@:V%S=71A=&%K<V4@
M:G5T=6WD<F=I;F$_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*
M;7-G<W1R(")7:&5R96ES($%U<W1R86QI82!K86%R="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(DUI
M;&QI<V5D(&9A87-I9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*
M;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BXB"FUS9W-T<B`B36EL;&ES96ED('!L=6=I;F%I9"!L=6)A
M9&$@4FEC:"!497AT(&5D:71O<FES+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM
M<V=S='(@(DQA:75S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQA:75S($-3
M4R#\:&EK=71E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@
M(B5S(&UE;OS\(&QA:75S('9A<V%K=6P@*&AA:VMA8B!M]6IU;6$@:N1R9VUI
M<V5L('-I<W-E;&]G:6UI<V5L*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A
M8FQE(@IM<V=S='(@(E1A8F5L:2!L86EU<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(DQA:75S_&AI:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B
M3&%I=7,Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I
M9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R(")4=75L(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@
M16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@='5U;"(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T
M<B`B5'5U;&4@:VEI<G5S('/U;&UE9&5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E1U=6PZ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(E1U=6PZ("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM
M<V=I9"`B5VES9&]M(@IM<V=S='(@(E1A<FMU<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(E-O
M;W9I;FEM96MI<FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`B5/;V(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B5/;V:V]H82!A861R97-S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G
M<W1R(")4]O9T96QE9F]N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B4F5A<R`E9"!O
M;B!V86QE(&%R=B!VY&QJ=2X@4&5A:W,@;VQE;6$@)60L(&%G82!O;B`E9"XB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@
M)60L(&9O=6YD("5D+B(*;7-G<W1R(")686QE(&%R=B!VY&QJ=2X@4&5A:W,@
M;VQE;6$@)60L(&%G82!O;B`E9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T
M("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5F%L92!A
M;&=U<W!U;FMT("5D(%9&4R!F86EL:2!L=6=E;6ES96PN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B
M6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U
M,#EV,R!P]6AI;&ES960@<&EI<F%N9W5D(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4B"FUS9W-T<B`B6#4P.78S(';U=&UE(&QA:65N9&%T=60@:V%S
M=71U<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S
M='(@(E@U,#EV,R!S=6)J96MT:2!A;'1E<FYA=&EI=FYE(&YI;6DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P
M.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S('-U
M8FIE:W1I(';U=&UE(&ED96YT:69I:V%A=&]R(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I
M;VYS(@IM<V=S='(@(E@U,#EV,R!L86EE;F1U<V5D(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"FUS9VED(")965E9
M(@IM<V=S='(@(D%!04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")9
M86AO;R$@:V%A<G0B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B2V]R9"!A87-T
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")*965M
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38S"FUS9VED(")997,B"FUS9W-T<B`B2F%H(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!
M9W)E92(*;7-G<W1R(")*86@L(&]L96X@;O5U<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R(")/;&5D(%1%2U-425)%6DE)34E3
M+B!+;/5P<V$@6SP^72!E="!M:6YN82!T86=A<VD@5UE325=91R!R97II:6UI
M+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")%:2!O;&4@;'5B871U9"!L=75A
M(')O:&ME;2!K=6D@)60@8FQO:VMI+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"XB"FUS9W-T<B`B4V$@96D@;VQE('-I<W-E(&QO9VET=60N(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C
M86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N
M86UE+B(*;7-G<W1R(")3:6YU('3D:7-N:6UI(&5I(';U:2!S:7-A;&1A9&$@
M)UQ<)R!MY')K:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B4V$@
M96D@<VES97-T86YU9"!K;W)R96MT<V5T(&4M<&]S=&D@86%D<F5S<VDN(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB
M:6X@)7,N(@IM<V=S='(@(E-A(&5I('-E861N=60@:6UP;W)D:71U9"!F86EL
M:2!VY&QJ=2!V87-T879U<W-E("5S(';D;&IA9&5G82XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="XB"FUS9W-T<B`B4VEN9"!L;V=I=&D@=N1L:F$N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E-A('!E860@<VES97-T
M86UA(&ME:'1I=F$@;6]B:6EL=&5L969O;FD@;G5M8G)I(&UI<R!S:7-A;&1A
M8B!A:6YU;'0@;G5M8G)E:60@(@HB:F$@;6EL;&4@86QG=7-E<R!V]6EB(&]L
M;&$@)RLG(')A:'9U<W9A:&5L:7-E('-U=6YA:V]O9&D@='5N;G5S96YA+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E-A('!E860@
M<VES97-T86UA(&MO<G)E:W1S92!VY.1R='5S92XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S
M='(@(DQI:71U;6ES92!L=6)A;6ES96MS('!E860@<V5A9&ES=&%M82!$871A
M5')E92!S_'-T965M:2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N
M(@IM<V=S='(@(E-A('!E860@<V5A9&ES=&%M82!61E,@<_QS=&5E;6DN(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")%;FYE('-A871M:7-T
M(&]L96MS('1A<FL@<')O8FQE96UI(&MI<FIE;&1A9&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(E-A('!E860@<VES97-T86UA(%523&D@:W5H=2!S964@;&EN
M:R!V:6ET86(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+B(*;7-G<W1R(")096%D(&WDY')A;6$@:W5S='5T871A=F$@<V5R=F5R:2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E!E860@;>3D
M<F%M82!K87-U=&%J86YI;64@;6ED82!T_&AJ96YD861A+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92XB"FUS9W-T<B`B4&5A9"!MY.1R86UA(&MA<W5T86IA
M;FEM92!M:61A(&5E;6%L9&%D82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B4&5A
M9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&QI<V%D82XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B4&5A9"!MY.1R86UA(&MA<W5T
M86IA;FEM92!M:61A(&UU=71A+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")096%D(&WDY')A;6$@
M=&5G979U<V4L(&UI9&$@<V]O=FED('1E:&$N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B4&5A9"!S
M:7-E<W1A;6$@=75E(&MA=&5G;V]R:6$@;FEM92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*
M;7-G<W1R(")096%D('-I<V5S=&%M82!)=&%A;&EA('1E;&5F;VYI;G5M8G)I
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"FUS9VED(")9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B4VEN=2`E<R!S97-S:6]O;B!O;B!A96=U;G5D+B!086QU;B!L
M;V=I('5U97-T:2!S:7-S92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(E-I;G4@92UP;W-T:2!A861R97-S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B
M4VEN=2!S86%T:F$@86%D<F5S<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B4VEN=2!I;F9O(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@HB4VEN=2!I;G1E<FYE=&EA861R97-S(&]N("5S('-E<W-I;V]N:2!J
M;V]K<W5L(&UU=71U;G5D+B!4=7)V86QI<W5S92`B"B)T86=A;6ES96MS('!E
M860@=75E<W1I('-I<W-E(&QO9VEM82XB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E-I
M;G4@;FEM:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU
M"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S
M92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T
M('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*
M;7-G<W1R("(B"B)3:6YU(&%U=&5N=&EM:7-S_'-T965M(&5I(';U:6UA;&1A
M(&MA<W5T86IA:60@;&ES861A+B!+=6D@<V]O=FED($AO<F1E(&%B:6P@(@HB
M:V%S=71A:F%I9"!H86QL871A+"!P96%D(&MA<W5T86UA('1E:7-T<W5G=7-T
M(&%U=&5N=&EM:7-S_'-T965M:2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BXB"FUS9W-T<B`B(@HB4VEN=2!A=71E;G1I;6ES<_QS=&5E;2!E
M:2!V]6EM86QD82!K87-U=&%J871E(&YI;65K:7)J82!NY&AA+"!V]6D@;VX@
M<V5E("(*(G;U:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA(&S\
M;&ET871U9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)3:6YU('9E96)I;&5H:71S96IA
M(&[D:6(@;VQE=F%T("5S('-E<W-I;V]N:2!J;V]K<W5L(&UU=71U;G5D+B!4
M=7)V86QI<W5S92`B"B)T86=A;6ES96MS('!E860@=75E<W1I('-I<W-E(&QO
M9VEM82XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G
M<W1R(")3:6YU('9E96)I;&5H:71S96IA(&5I(';U:6UA;&1A('-E9&$@;VUA
M9'5S="!K87-U=&%D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN
M="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(E-I;G4@=F5E8FEL96AI='-E
M:F$@96D@=O5I;6%L9&$@;FEI;6]O9&D@='+\:VMI9&$N(%9A:G5T82!T<OQK
M:VEM:7-E:W,@(@HB0V]N=')O;"M0(';U:2!#;VUM86YD*U`N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I
M;64@>F]N93HB"FUS9W-T<B`B4VEN=2!A:F%V]O9N9#HB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H
M87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")3:6YU('9A:6ME:61E;G1I=&5E
M="!O;B!M=75D971U9"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X
M"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E-I;G4@
M=F%I:V5I9&5N=&ET965T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")3:6YU('3D:65L
M:6L@;FEM:3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"FUS
M9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")3:6YU('-I
M<W-E;&]G:6UI;F4@;VX@865G=6YU9"XB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E-I;G4@=75S("5S('-A
M;&%S]6YA(&]N.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(DUU
M=61A='5S960@;VX@<V%L=F5S=&%T=60@<V5L;&4@<V5S<VEO;VYI(&SU<'5N
M:2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")-
M=75D871U<V5D(&]N('-A;'9E<W1A='5D+B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T(@IM<V=S='(@(E-I;G4@<V%L87/U;F$@;VX@=F%H971A='5D(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R
M("(B"B)3:6YU('-A;&%S]6YA(&]N('9A:&5T871U9"P@=F%A=&$@;VUA(&4M
M<&]S=&D@:F$@;&]G:2!S:7-S92!U=64@<V%L87/U;F%G82XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@
M:&%S(&5X<&ER960N(@IM<V=S='(@(E-I;G4@<V%L87/U;F$@;VX@865G=6YU
M9"XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@
M(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E-I;G4@=N1L:7-E9"!S
M97)V97)I9#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(DIU9V]S;&%A=FEA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R(")386UB:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB
M86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP
M<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T
M960@5&5X=%TB"FUS9W-T<B`B6U!E:61A(&]S=6YD871U9"!T96MS=%TB"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P
M;W)T72(*;7-G<W1R(");2&]R9&4@<')O8FQE96U=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6T[D:71A(&]S=6YD871U9"!T96MS=&D@
M+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6T[D:71A(&]S=6YD871U
M9"!T96MS=&D@+2`E<R!R:61A72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R(");<FED82`E<R`E<RUS=%TB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ
M,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E](86QD=7,B"@HC
M.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B2^1S=5]R
M:61A(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS
M9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*
M;7-G<W1R(")?2W5S='5T82!R:61A(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS
M9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P:60B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R
M(")!7V)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")?4&EL9&D@;VUA9'5S960N+BXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@
M(E],;V=I('-I<W-E(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7TQO9VD@=N1L:F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?375U
M9&$@;&EN:VDN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?4V5A9&ES='5S(@H*
M(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T
M<B`BU6EG7W5S960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*
M;7-G<W1R(")?165M86QD82!L:6YK+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U
M"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7U!A:6=A;&1U<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM
M<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7U1A8F5L:2!O
M;6%D=7-E9"XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S
M(@IM<V=S='(@(E]+87-U=&%J860B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR,0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F%A9')E
M<W-I<F%A;6%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(F%D<F5S
M<V%A="!T=6YD;6%T=2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")K86QE;F1E<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X
M"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B=F%I:VYE(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@
M(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B=N1L:G5N9&9A
M:6QI(&QO;VUI;F4@;G5R:G5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S
M='(@(G-I<V5N9&D@879A;6EN92!N=7)J=7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`B:VSU<'-A('-I:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(FOD<W5R96$@:V%S=71A;6ES92!V:6=A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R
M871I;VX@97)R;W(B"FUS9W-T<B`B<V5A9&ES='5S92!V:6=A(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I
M8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B96QU=.1H=&ES('/\
M<W1E96UI9F%I;"!O;B!P=75D=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G
M<W1R(")A;F1M971E(&9O<FUA861I('9I9V$B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(FUU=61A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@
M(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")K86YN970@96D@;&5I='5D(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(F9A;&QI;F<B"FUS9W-T<B`B;&%N9V5B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#4U"FUS9VED(")F:6QE(@IM<V=S='(@(F9A
M:6PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@
M(G-U=6YD("5S("@E<RD@:F$@:VEI<G5S("5S("5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R
M(")P=6AA;F=U;&EN92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(FLZ(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B
M:&@B"FUS9W-T<B`B='0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M='5N9&UA='4@:&]S=&EN:6UI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B
M"FUS9W-T<B`B=FEI=FET86UA='4B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM
M<V=S='(@(FEN;&EN92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B
M<VES96YD+W;D;&IU;F0@=FEG82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O
M<B(*;7-G<W1R(")T87)K=F%R82!S965S;6EN92!V:6=A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S
M72(*;7-G<W1R(")R:61A72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS
M9W-T<B`B;6MI<V]F<R!V96%K;V]D("5D($E33R!L;V]M:7-E;"XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED
M(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*
M;7-G<W1R(")N:6UI(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM
M<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(G!O;&4@=&5O<W1A='5D
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(G!O;&4@=F5E;"!T
M96]S=&%T=60B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM
M<V=I9"`B;F]T97!A9"(*;7-G<W1R(")MY')K;6EK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B
M<&5R8V5N="(*;7-G<W1R(")P<F]T<V5N=&DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`B]6EG=7-E9"!P=75D=79A9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I
M>&5L<R(*;7-G<W1R(")P:6MS;&ET(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;"(*;7-G<W1R(")P<F]T;VMO;&QI('9I9V$@=&5I<V5S(&]T<V%S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G
M:60@(G)I<VEN9R(*;7-G<W1R(")T]75S96(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL
M86)L92(*;7-G<W1R(")T965N=7,@<&]L92!KY'1T97-A861A=B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC
M97,B"FUS9W-T<B`B;N1I=&$@97)I;F5V=7-I(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E
M;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@_&QE($A45%`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS
M9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B_&AT
M;&%N92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED
M(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B;/QL:71A(&IA=F%S
M8W)I<'0@=N1L:F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(G/\<W1E96UI
M('9I9V$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I
M9"`B=&%S:R!L:7-T(@IM<V=S='(@(OQL97-A;FYE=&4@;FEM96MI<FDB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B
M=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B86IU=&EN92!T]7)G92(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"FUS9VED(")T<GD@86=A
M:6XB"FUS9W-T<B`B<')O;W9I('5U97-T:2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@
M(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B
M:VER:G5T82!S86QA<_5N82!E:W-I='5S92!VY&QT:6UI<V5K<R!K86MS(&MO
M<F1A(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B_&AI=&%T=60B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(FYI;65T=2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S
M96QE8W0B"FUS9W-T<B`B:V%S=71A:F$@=F%L:6LB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM
M<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B;#HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB
M"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]214%$344`````````````
M````````````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R-S<R
M`#$P-3$U-#,Q,#8R`#`Q-3<Q-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````]/3T]/3T]/3T]/3T]/3T]/3T]"B!4<F%N<VQA
M=&EO;B!'=6ED92`*/3T]/3T]/3T]/3T]/3T]/3T]/0H*.D1A=&4Z("`@("`D
M1&%T93H@,C`P-B\P-R\R-B`Q-#HP-CHU,2`D"CI2979I<VEO;CH@)%)E=FES
M:6]N.B`Q+C(Y+C0N,2`D"CI!=71H;W)S.B`@2F%N(%-C:&YE:61E<@HZ0V]N
M=&%C=#H@(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ"BXN
M('-E8W1I;VXM;G5M8F5R:6YG.CH*"E1R86YS;&%T:6]N(%1O;VP*/3T]/3T]
M/3T]/3T]/3T]/0H*8&!T<F%N<VQA=&EO;BYP:'!@8"!I<R!A('-M86QL(%!(
M4"!S8W)I<'0@=&AA="!S:&]U;&0@:&5L<"!T<F%N<VQA=&]R<R!D;VEN9PIT
M:&5I<B!W;W)K+@I!;GD@9F5E9&)A8VLL(&)U9R!R97!O<G1S(&%N9"!F96%T
M=7)E(')E<75E<W1S('-H;W5L9"!B92!S96YD('1O('1H92!@:3$X;@IM86EL
M:6YG(&QI<W1@7RX@5&AI<R!I<R!A;'-O('1H92!R:6=H="!P;&%C92!F;W(@
M;F5W('1R86YS;&%T:6]N<R!A;F0@9V5N97)A;`ID:7-C=7-S:6]N<R!O9B!I
M,3AN(&%N9"!L,3!N('%U97-T:6]N<R!A;F0@<')O8FQE;7,N"@I&;W(@82!L
M:7-T(&]F(&%V86EL86)L92!C;VUM86YD<R!R=6XZ.@H*("`N+W1R86YS;&%T
M:6]N+G!H<"!H96QP"@I&;W(@9&5T86EL960@:&5L<"!O;B!A(&-E<G1A:6X@
M8V]M;6%N9"!R=6XZ.@H*("`N+W1R86YS;&%T:6]N+G!H<"!H96QP(&-O;6UA
M;F0*"D%D9&ET:6]N86P@:6YF;W)M871I;VX@86)O=70@8W)E871I;F<@=')A
M;G-L871I;VYS(&%N9"!F:7AI;F<@<')O8FQE;7,@8V%N(&)E"F9O=6YD(&EN
M('1H92!F:6QE(&!@:&]R9&4O9&]C<R]44D%.4TQ!5$E/3F!@+@H*+BX@7VDQ
M.&X@;6%I;&EN9R!L:7-T.B!H='1P.B\O:&]R9&4N;W)G+VUA:6PO"@I0<F5R
M97%U:7-I=&5S"GY^?GY^?GY^?GY^?GX*"E1O(')U;B!T:&ES('-C<FEP="!Y
M;W4G;&P@;F5E9"!A(%!(4"!E>&5C=71A8FQE(&QI:V4@=&AE($-,22!O<B!T
M:&4@0T=)('9E<G-I;VX*=VET:"!@9V5T=&5X="!S=7!P;W)T8%\@8V]M<&EL
M960@:6X@86YD('1H92!B87-I8R!@4$5!4F!?(&QI8G)A<FEE<RX@5&AE"G-C
M<FEP="!E>'!E8W1S('EO=7(@4$A0(&5X96-U=&%B;&4@=&\@8F4@870@8&`O
M=7-R+VQO8V%L+W!S82]A9&UI;B]B:6XO<&AP8&`N($EF('EO=7(*97AE8W5T
M86)L92!I<R!A="!A;F]T:&5R('!L86-E+"!E:71H97(@961I="!T:&4@9FER
M<W0@;&EN92!O9@I@8'1R86YS;&%T:6]N+G!H<&!@('1O(')E9FQE8W0@>6]U
M<B!L;V-A=&EO;B!O<B!C86QL('1H92!S8W)I<'0@;&EK93HZ"@H@("]U<W(O
M;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`@+68@=')A;G-L871I;VXN<&AP+@H*
M66]U)VQL(&YE960@8&=E='1E>'1@7R`P+C$Q(&]R(&=R96%T97(L(&)U="!V
M97)S:6]N(#`N,3(@;W(@9W)E871E<B!I<R!S=')O;F=L>0IR96-O;6UE;F1E
M9"!A<R!T:&ES(&ES('1H92!F:7)S="!V97)S:6]N('1H870@<W5P<&]R=',@
M4$A0(&YA=&EV96QY+B!/;&1E<@IV97)S:6]N<R!M87D@;F]T(&5X=')A8W0@
M86QL('1R86YS;&%T96%B;&4@<W1R:6YG<R!C;W)R96-T;'DN"D$@=VEN9&]W
M<R!V97)S:6]N(&]F('1H92!G971T97AT(&)I;F%R:65S(&-A;B!B92!F;W5N
M9"!O;B!E=F5R>2!@1TY5(&9T<`IM:7)R;W)@7R!A<R!O9B!V97)S:6]N(#`N
M,3(N"@I9;W4G;&P@;F5E9"!T:&4@4$5!4B!P86-K86=E<R!@0V]N<V]L95]'
M971O<'1@7R`P+C$Q(&]R(&=R96%T97(L"F!#;VYS;VQE7U1A8FQE8%\@86YD
M(&!&:6QE7T9I;F1@7RX@5&\@:6YS=&%L;"!A;&P@;F5E9&5D('!A8VMA9V5S
M+"!R=6XZ.@H*("!P96%R('5P9W)A9&4@4$5!4B!#;VYS;VQE7T=E=&]P=`H@
M('!E87(@:6YS=&%L;"!#;VYS;VQE7U1A8FQE($9I;&5?1FEN9`H*;W(@9&]W
M;FQO860@=&AE(&YE=V5S="!P86-K86=E(&9R;VT@=&AE(&!014%28%\@<V5R
M=F5R(&%N9"!I;G-T86QL('1H96T*;6%N=6%L;'D@:6X@>6]U<B!014%2(&1I
M<F5C=&]R>2X*"BXN(%]G971T97AT.B!H='1P.B\O=W=W+F=N=2YO<F<O<V]F
M='=A<F4O9V5T=&5X="\*+BX@7V=E='1E>'0@<W5P<&]R=#H@:'1T<#HO+W=W
M=RYP:'`N;F5T+V=E='1E>'0O"BXN(%]'3E4@9G1P(&UI<G)O<CH@:'1T<#HO
M+W=W=RYG;G4N;W)G+W!R97`O9G1P+FAT;6P*+BX@7U!%05(Z(&AT='`Z+R]P
M96%R+G!H<"YN970O"BXN(%]#;VYS;VQE7T=E=&]P=#H@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+T-O;G-O;&5?1V5T;W!T+PHN+B!?0V]N<V]L95]4
M86)L93H@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T-O;G-O;&5?5&%B
M;&4O"BXN(%]&:6QE7T9I;F0Z(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]&:6QE7T9I;F0O"@I#<F5A=&EN9R!A(&YE=R!T<F%N<VQA=&EO;@I^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@H*5&\@8W)E871E(&$@;F5W('1R86YS
M;&%T:6]N('EO=2!F:7)S="!H879E('1O(&5X=')A8W0@86QL(&=E='1E>'0@
M;65S<V%G97,@9G)O;0IT:&4@4$A0('-O=7)C97,N(%1H97)E(&%R92!A;')E
M861Y('1E;7!L871E(&9I;&5S('=I=&@@=&AE(&!@+G!O=&!@('-U9F9I>"!I
M;@IT:&4@8&!P;V!@(&1I<F5C=&]R:65S('1H870@>6]U(&-A;B!U<V4@:68@
M>6]U(&AA=F4@=')O=6)L97,@97AT<F%C=&EN9R!T:&4*;65S<V%G97,@8G5T
M('1H97D@;6EG:'0@8F4@;W5T9&%T960N"E)U;CHZ"@H@("XO=')A;G-L871I
M;VXN<&AP(&5X=')A8W0*"EEO=2!N;W<@:&%V92!T;R!C<F5A=&4@82!N97<@
M4$\@9FEL92!F;W(@>6]U<B!L;V-A;&4N($$@;&]C86QE(&AA<R!T:&4@9F]R
M;0I@8&QL7T-#8&`@=VAE<F4@8&!L;&!@(&ES('1H92!T=V\@;&5T=&5R(&!)
M4T\@-C,Y8%\@8V]D92!O9B!T:&4@;&%N9W5A9V4@86YD"F!@0T-@8"!T:&4@
M='=O(&QE='1E<B!@25-/(#,Q-C9@7R!C;V1E(&]F('1H92!C;W5N=')Y+"!E
M+F<N(&!@9&5?1$5@8"P*8&!E;E]54V!@(&]R(&!@<'1?0E)@8"X*8&!T<F%N
M<VQA=&EO;BYP:'!@8"!I<R!A8FQE('1O(&=U97-S('1H92!L;V-A;&4@9G)O
M;2!T:&4@8&!,04Y'8&`@96YV:7)O;FUE;G0*=F%R:6%B;&4@8G5T(&ET(&ES
M('-A9F5R('1O('-P96-I9GD@=&AE(&QO8V%L92!W:71H('1H92!@8"UL8&`@
M<&%R86UE=&5R+@I4;R!C<F5A=&4@=&AE(%!/(&9I;&4@<G5N.CH*"B`@+B]T
M<F%N<VQA=&EO;BYP:'`@:6YI="`M;"!L;%]#0PH*3F]W('EO=2!C86X@<W1A
M<G0@=&AE('1R86YS;&%T:6]N(&)Y(&5D:71I;F<@=&AE(&-R96%T960@8&!L
M;%]#0RYP;V!@"F9I;&5S+B!)="!I<R!I;7!O<G1A;G0@=&\@<V5T('1H92!C
M;W)R96-T(&-H87)S970@9F]R('1H92!L;V-A;&4@:6X@=&AE"F!@0V]N=&5N
M="U4>7!E.F!@(&AE861E<BX*66]U('-H;W5L9"!F:6QL(&]U="!T:&4@=&AE
M(&-O;7!L971E(&AE861E<B!O9B!T:&4@8W)E871E9"!@8&QL7T-#+G!O8&`@
M9FEL92P*92YG+CHZ"@H@(",@1'5T8V@@=')A;G-L871I;VX@9F]R($AO<F1E
M+@H@(",@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*("`C(%1H
M:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E
M(&%S('1H92!(;W)D92!P86-K86=E+@H@(",@2F]R:7,@0G)A86MM86X@/&IB
M<F%A:VUA;D!Y86AO;RYC;VT^+"`R,#`T+@H@(",*("!M<V=I9"`B(@H@(&US
M9W-T<B`B(@H@(")0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#(N,UQN(@H@
M(")297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@H@(")03U0M0W)E871I;VXM1&%T93H@,C`P-"TP-"TQ-"`Q,#HS,"LP,C`P
M7&XB"B`@(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#0M,30@,3<Z,3<K,#(Z
M,#!<;B(*("`B3&%S="U4<F%N<VQA=&]R.B!*;W)I<R!"<F%A:VUA;B`\:F)R
M86%K;6%N0'EA:&]O+F-O;3Y<;B(*("`B3&%N9W5A9V4M5&5A;3H@:3$X;D!L
M:7-T<RYH;W)D92YO<F=<;B(*("`B34E-12U697)S:6]N.B`Q+C!<;B(*("`B
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<
M;B(*("`B0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"E1O
M(&-O;7!I;&4@=&AE('1R86YS;&%T:6]N<R!T;R!A(&)I;F%R>2!F;W)M870@
M<G5N.CH*"B`@+B]T<F%N<VQA=&EO;BYP:'`@;6%K90H*069T97(@>6]U(&-R
M96%T960@=&AE(&YE=R!T<F%N<VQA=&EO;B!Y;W4@:&%V92!T;R!A9&0@96YT
M<FEE<R!F;W(@=&AI<R!L;V-A;&4*:6X@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92!H;W)D92]C;VYF:6<O;FQS+G!H<"X*"E1/1$\Z(&9I;&QI;F<@;F5W('!O
M(&9I;&5S('=I=&@@<W1R:6YG<R!F<F]M('1H92!C;VUP96YD:75M+@H*+BX@
M7TE33R`V,SDZ(&AT='`Z+R]W=W<N;&]C+F=O=B]S=&%N9&%R9',O:7-O-C,Y
M+3(O"BXN(%])4T\@,S$V-CH@:'1T<#HO+W=W=RYI<V\N8V@O:7-O+V5N+W!R
M;V1S+7-E<G9I8V5S+VES;S,Q-C9M82]I;F1E>"YH=&UL"@I-86EN=&%I;FEN
M9R!T<F%N<VQA=&EO;G,*?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^"@I4:&ES
M('1O;VP@:7,@9&5S:6=N960@=&\@:&5L<"!Y;W4@=')A;G-L871O<G,@9&]I
M;F<@>6]U<B!G<F5A="!W;W)K+B!)="!C:&%N9V5S"F$@;&]T(&-O;7!A<F5D
M('1O('1H92!O;&0@;65T:&]D<R!C<F5A=&EN9R!A;F0@;6%I;G1A:6YI9R!Y
M;W5R('1R86YS;&%T:6]N<RX@5&\*;6%K92!T:&4@=')A;G-I=&EO;B!T;R!T
M:&4@=&]O;"!A<R!S;6]O=&@@87,@<&]S<VEB;&4@>6]U('-H;W5L9"!R96%D
M(&-H87!T97(*,RXQ(&)E9F]R92!U<VEN9R!T:&ES('1O;VP@=&AE(&9I<G-T
M('1I;64N"@I&:7)S="!T:6UE('5S92!O9B!T<F%N<VQA=&EO;BYP:'`*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&ES('1O;VP@:6YT
M<F]D=6-E<R!A(&YI8V4@9F5A='5R92!O9B!G971T97AT.B!C;VUP96YD:75M
M(&9I;&5S+B!!(&-O;7!E;F1I=6T*:7,@82!S<&5C:6%L(%!/(&9I;&4@8V]N
M=&%I;FEN9R!A('-E="!O9B!T<F%N<VQA=&EO;G,@<F5C=7)R:6YG(&EN(&UA
M;GD*9&EF9F5R96YT('!A8VMA9V5S+B!4:&5S92!C;VUP96YD:6$@=VEL;"!B
M92!U<V5D(&EN('1H92!B86-K9W)O=6YD('=I=&AO=70@;75C:`IF;W(@>6]U
M('1O(&-A<F4@86)O=70N($)U="!Y;W4@:&%V92!T;R!C<F5A=&4@86YD(&5D
M:70@82!C;VUP96YD:75M(&)E9F]R92!Y;W4*8V%N('5S92!I="X*"E1O(&-R
M96%T92!A(&-O;7!E;F1I=6T@;V8@86QL('EO=7(@97AI<W1I;F<@=')A;G-L
M871I;VYS(')U;CHZ"@H@("XO=')A;G-L871I;VXN<&AP(&-O;7!E;F1I=6T@
M+6P@;&Q?0T,*"E1H92!@8&-O;7!E;F1I=6TN<&]@8"!B96EN9R!C<F5A=&5D
M('=I;&P@8V]N=&%I;B!A;&P@;6]D=6QE<R<@=')A;G-L871I;VYS(&]F"G1H
M:7,@;&]C86QE(&UE<F=E9"!I;G1O(&$@<VEN9VQE(&9I;&4N(%EO=2!S:&]U
M;&0@=&%K92!A(&-L;W-E<B!L;V]K(&%T('1H:7,*9FEL92!B96-A=7-E('EO
M=2!M87D@9FEN9"!A(&QO="!O9B!S<&5C:6%L(&UA<FME9"!L:6YE<R!W:&5R
M92!Y;W4@=')A;G-L871E9`IC97)T86EN('-T<FEN9W,@9&EF9F5R96YT;'D@
M:6X@=&AE('9A<FEO=7,@;6]D=6QE<RX@270G<R!A(&=O;V0@:61E82!T;R!F
M:7@*=&AE(&UO9'5L97,G('1R86YS;&%T:6]N<R!N;W<@<V\@=&AA="!A;&P@
M;6]D=6QE<R!U<V4@=&AE('-A;64@=')A;G-L871I;VX@9F]R"G1H92!S86UE
M('-T<FEN9RX@66]U(&-A;B!A;'=A>7,@<F5C<F5A=&4@>6]U<B!C;VUP96YD
M:75M('=I=&@@=&AE(&%B;W9E"F-O;6UA;F0N"@I)9B!Y;W4G<F4@;6%I;G1A
M:6YI;F<@=')A;G-L871I;VYS(&9O<B!D:69F97)E;G0@8&)R86YC:&5S8%\@
M86YD(&%S<W5M960@=&AA=`IY;W4@:&%V92!A;&P@;6]D=6QE<R!O9B!T:&4@
M8&!(14%$8&`@8G)A;F-H97,@:6X@;VYE(&1I<F5C=&]R>2!A;F0@86QL(&]F
M('1H90I@8%)%3$5.1U\J8&`@8G)A;F-H97,@:6X@86YO=&AE<BP@>6]U('!R
M;V)A8FQY('=A;G0@=&\@<VAA<F4@82!C;VUP96YD:75M"F)E='=E96X@=&AE
M<V4@9&ER96-T;W)I97,N"@I9;W4@<VAO=6QD(&9I<G-T(&-R96%T92!A(&-O
M;7!E;F1I=6T@:6X@=&AE(&!@4D5,14Y'7RI@8"!B<F%N8V@L(')E=FEE=R!I
M="!A;F0*9FEX(&%L;"!T<F%N<VQA=&EO;G,@=6YT:6P@>6]U)W)E(&AA<'!Y
M('=I=&@@=&AE(')E<W5L="X@5&AE;B!C<F5A=&4@82!S96-O;F0*8V]M<&5N
M9&EU;2!I;B!T:&4@8&!(14%$8&`@8G)A;F-H(&%N9"!I;F-L=61E('EO=7(@
M9FER<W0@;VYE('=I=&@@=&AE("TM861D"F]P=&EO;BX*3F]W(&9I>"!T:&4@
M=')A;G-L871I;VYS(&EN('1H:7,@8G)A;F-H+B!)9B!Y;W4G<F4@<F5A9'D@
M>6]U(&-A;B!R96UO=F4@=&AE"F9I<G-T(&-O;7!E;F1I=6T@86YD(&9O<B!N
M;W<@;VX@=7-E('1H92!C;VUP96YD:75M(&EN('1H92!@8$A%041@8"!B<F%N
M8V@@9F]R"F)O=&@@8G)A;F-H97,N(%1O(&1O('-O('5S92!T:&4@8&`M+6-O
M;7!E;F1I=6U@8"!O<'1I;VX@=&\@<W!E8VEF>2!A('!A=&@@=&\*>6]U<B!C
M;VUP96YD:75M+@H*+BX@7V)R86YC:&5S.B!H='1P.B\O=W=W+FAO<F1E+F]R
M9R]S;W5R8V4O"@I5<&1A=&EN9R!T<F%N<VQA=&EO;G,*+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM"@I4:&4@<')O8V5S<R!O9B!U<&1A=&EN9R!T<F%N<VQA=&EO
M;G,@:7,@82!C>6-L92!W:&5R92!Y;W4@97AT<F%C="!N97<@9V5T=&5X=`IS
M=')I;F=S(&9R;VT@=&AE('-O=7)C97,L('1R86YS;&%T92!T:&]S92!N97<@
M<W1R:6YG<R!O<B!U<&1A=&4@=&AE(&%L<F5A9'D*=')A;G-L871E9"!S=')I
M;F=S(&%N9"!C;VUP:6QE('1H96T@869T97(N"@I4;R!U<&1A=&4@=&AE('1R
M86YS;&%T:6]N(&9O<B!A(&UO9'5L92P@<G5N.CH*"B`@+B]T<F%N<VQA=&EO
M;BYP:'`@=7!D871E("UM(&UO9'5L96YA;64@+6P@;&Q?0T,*"E1H:7,@97AT
M<F%C=',@=&AE(&YE=R!S=')I;F=S(&9R;VT@=&AE('-O=7)C97,@86YD('1R
M:65S('1O('5P9&%T92!T:&5M(&9R;VT*86QR96%D>2!E>&ES=&EN9R!T<F%N
M<VQA=&EO;G,@:6X@=&AE(&-O;7!E;F1I=6TN(%EO=2!J=7-T(&AA=F4@=&\@
M=')A;G-L871E"F%L;"!U;G-T<F%N<VQA=&5D('-T<FEN9W,@:6X@=&AE(&!@
M;&Q?0T,N<&]@8"!F:6QE(&EN('1H92!@8'!O8&`@9&ER96-T;W)Y(&]F"G1H
M92!M;V1U;&4@>6]U('5P9&%T960N"@I/;F-E('1H:7,@:7,@9&]N92P@>6]U
M(&-A;B!C;VUP:6QE('1H92!T<F%N<VQA=&EO;B!B>2!C86QL:6YG.CH*"B`@
M+B]T<F%N<VQA=&EO;BYP:'`@;6%K92`M;2!M;V1U;&5N86UE("UL(&QL7T-#
M"@I%>'1E;F1I;F<@97AI<W1E;G0@=')A;G-L871I;VYS"GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E1O(&AA=F4@>6]U<B!O=VX@=&5X=',@
M*&%S('-U<'!L:65D(&EN(&-O;F9I9R!F:6QE<R!F;W(@97AA;7!L92D@9&ES
M<&QA>65D(&EN"G-E=F5R86P@;&%N9W5A9V5S+"!Y;W4@:&%V92!T;PH*("`Q
M+B!S<&5C:69Y('EO=7(@=&5X=',@87,@9V5T=&5X="!A<F=U;65N=',L(&EN
M($5N9VQI<V@L"B`@,BX@961I="!T:&4@=')A;G-L871I;VX@9FEL97,@9F]R
M('1H92!R97%U:7)E9"!N871I;VYA;"!L86YG=6%G97,L"B`@,RX@8V]M<&EL
M92!T:&]S92!T<F%N<VQA=&EO;B!F:6QE<RX*"D)E('-U<F4@=&\@:V5E<"!R
M96-O<F1S(&]F('EO=7(@97AT96YS:6]N<RP@87,@>6]U('=I;&P@<')O8F%B
M;'D@:&%V92!T;PIR97!E870@<W1E<',@,B!A;F0@,R!A9G1E<B!T:&4@;F5X
M="!U<&1A=&4N"@I%+F<N+"!Y;W4@<&QA;B!T;R!O9F9E<B!T=V\@24U!4"!S
M97)V97)S('1O('-E;&5C="!F<F]M(&EN('1H92!796)M86EL(&QO9VEN"G-C
M<F5E;CH*"B`@,2X@26X@8&!H;W)D92]I;7`O8V]N9FEG+W-E<G9E<G,N<&AP
M8&`L('EO=2!S<&5C:69Y.CH*"B`@("`@("`D<V5R=F5R<ULG0V5N=')A;"==
M(#T@87)R87DH"B`@("`@("`@("`G;F%M92<@/3X@7R@B0V5N=')A;"!-86EL
M(%-E<G9I8V4B*2P*("`@("`@("XN+@H@("`@("`@)'-E<G9E<G-;)T-O;7!3
M8VDG72`](&%R<F%Y*`H@("`@("`@("`@)VYA;64G(#T^(%\H(DUA:6P@4V5R
M=FEC92!O9B!#;VUP=71E<B!38VEE;F-E($1P="XB*0H@("`@("`@+BXN"@H@
M(#(N($EN(&!@:&]R9&4O:6UP+W!O+V1E7T1%+G!O8&`@>6]U(&%D9"!T=V\@
M96YT<FEE<SHZ"@H@("`@("`@;7-G:60@(D-E;G1R86P@36%I;"!397)V:6-E
M(@H@("`@("`@;7-G<W1R("):96YT<F%L97(@36%I;'-E<G9E<B(*("`@("`@
M(&US9VED(")-86EL(%-E<G9I8V4@;V8@0V]M<'5T97(@4V-I96YC92!$<'0N
M(@H@("`@("`@;7-G<W1R(")-86EL<V5R=F5R($EN9F]R;6%T:6LB"@H@("`@
M($QI:V5W:7-E+"!Y;W4@86UE;F0@=&AE('1R86YS;&%T:6]N(&9I;&5S(&9O
M<B!O=&AE<B!L86YG=6%G97,L(&%S(&YE961E9"X*"B`@,RX@66]U(&-O;7!I
M;&4@=&AE('1R86YS;&%T:6]N<R!U<VEN9R!T:&4@8V]M;6%N9',Z.@H*("`@
M("`@("XO<&\O=')A;G-L871I;VXN<&AP(&UA:V4@+2UM;V1U;&4@:6UP("TM
M;F\M8V]M<&5N9&EU;0H*06-C97-S($ME>7,*/3T]/3T]/3T]/3T*"D%C8V5S
M<R!K97ES+"!A;'-O(&MN;W=N(&%S('-H;W)T8W5T(&ME>7,L(&%L;&]W(&5A
M<WD@86-C97-S('1O(&EM<&]R=&%N=`IF=6YC=&EO;G,L(&YO<FUA;&QY(&)Y
M(&AI='1I;F<@=&AE($%L="]-971A(&ME>2!I;B!C;VUB:6YA=&EO;B!W:71H
M(&%N;W1H97(*:V5Y+B!4:&ES(&ME>2!I<R!M87)K960@:6X@;6]S="!U<V5R
M(&EN=&5R9F%C97,@8GD@8F5I;F<@=6YD97)L:6YE9"X*"D%S('1H92!A8V-E
M<W,@:V5Y(&ES('!A<G0@;V8@=&AE('=O<F0@<F5P<F5S96YT:6YG('1H92!A
M8W1I;VX@8F5I;F<@97AE8W5T960L"FET(&ES(&EN('1H92!T<F%N<VQA=&]R
M<R!R97-P;VYS:6)I;&ET>2!T;R!S96QE8W0@86X@86-C97-S(&ME>2!W:&5N
M(&AE"G1R86YS;&%T97,@=&AE<V4@=V]R9',N(%1H92!A8W1I;VX@:7,@86QW
M87ES(&$@;&EN:R!I;B!(;W)D92X@5&AE(&%C8V5S<R!K97D*;V8@82!L:6YK
M(&ES('-E;&5C=&5D(&)Y('!R969I>&EN9R!I="!W:71H(&%N('5N9&5R<V-O
M<F4N"@I4:&4@:&5L<"!L:6YK(&EN('1H92!M96YU(&9O<B!E>&%M<&QE(&ES
M(&%L=V%Y<R`B7TAE;'`B+B!4:&ES(&UE86YS('1H870@=&AE"B)((B!O9B!T
M:&4@;&EN:R!W:6QL(&)E('5N9&5R;&EN960@86YD('1H92!H96QP(&-A;B!B
M92!O<&5N960@8GD@:&ET=&EN9PI!;'0K2"X@26X@=&AE(%!/(&9I;&4@=&AI
M<R!S=')I;F<@=VEL;"!A<'!E87(@87,Z.@H*("`C.B!T96UP;&%T97,O;65N
M=2]M96YU+FEN8SHU,PH@(&US9VED(")?2&5L<"(*("!M<V=S='(@(B(*"D$@
M4W!A;FES:"!T<F%N<VQA=&]R(&UI9VAT('=A;G0@=&\@=')A;G-L871E('1H
M:7,@=&\Z.@H*("`C.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHU,PH@(&US
M9VED(")?2&5L<"(*("!M<V=S='(@(E]!>75D82(*"E1R86YS;&%T;W)S(&]F
M(&UU;'1I8GET92!L86YG=6%G97,@;F5E9"!T;R!D;R!T:&ES(&$@8FET(&1I
M9F9E<F5N=&QY(&%S(&]N;'D*05-#24D@8VAA<F%C=&5R<R!A<F4@86QL;W=E
M9"!F;W(@86-C97-S(&ME>7,N($$@5')A9&ET:6]N86P@0VAI;F5S92!T<F%N
M<VQA=&]R"FUI9VAT('=A;G0@=&\@=7-E.CH*"B`@(SH@=&5M<&QA=&5S+VUE
M;G4O;65N=2YI;F,Z-3,*("!M<V=I9"`B7TAE;'`B"B`@;7-G<W1R(")?2.BJ
MJN:8CB(*"E1H:7,@<F5N9&5R<R!T;R`BZ*JJYIB.*$@I(B!I;B!T:&4@:6YT
M97)F86-E(&%N9"!Y;W4@8V%N"F%C8V5S<R!T:&ES(&QI;FL@=VET:"`B2"(@
M87,@=&AE(&%C8V5S<R!K97DN"@```````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&\O<G5?4E4N<&\`````````````````````````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#8V-3,R-``Q,#4Q-30S,3`V,@`P,38T-#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R!(
M;W)D92!2=7-S:6%N('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD*(R!)
M9VYA="!):W)Y86YO=B`\:6EG;F%T0&YE=VUA:6PN<G4^+"`R,#`Q"B,@1F5D
M;W(@02X@1F5T:7-O=B`\9F%F0'-S8RYR=3XL(#(P,#(*(R!!;&5X97D@6F%K
M:&%R;W8@/&)A8F5R0&UO<V=A+FYE=#XL(#(P,#8*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@=C,N,2U20S-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTP-R`Q,3HQ,"LP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$W(#$W.C`P*S`R,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@06QE>&5Y(%IA:VAA<F]V(#QB86)E<D!M;W-G
M82YN970^7&XB"B),86YG=6%G92U496%M.B!2=7-S:6%N(#QI,3AN0&QI<W1S
M+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0U`Q,C4Q7&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS
M9W-T<B`B(@HBS_#HZ^[FY>WHY2`E<R#C[O+NXNX@ZB#N\?/YY?'RXNOE[>C^
M(.[OY?#@]NCI(._NY.3E\.;JZ"P@[O+LY??E[>W[]2#MZ.;E+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z,3,W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S.#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,W-PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-SD*;7-G:60@(B`H=&]M;W)R;W<I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<U"FUS9VED
M("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@
M(B!A="`B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Q.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BRN#RX.ONXR(*"B,Z(&QI8B](;W)D92]#3$DN<&AP
M.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`BW?+N(.?MX/?E[>CE(.3NZ^;M
M[B#A^_+\(/?H\>ON["XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q
M,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@
M2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(L_PZ.ONYN7MZ.4@)R5S)R#MY2#Q
MZN[M].CC\_#H\.[BX.WN(.(@2&]R9&4@4F5G:7-T<GDB"@HC.B!L:6(O2&]R
M9&4O5')E92YP:'`Z,3<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7Q
MX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HBS^#OZN`@7"(E<UPB(.'[Z^`@\_'OY?CM[B#OY?#EZ.SE[>[BX.W@(.(@
M7"(E<UPB+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV
M*2`@(RTC+2,M(RTC7&XB"B);\?+P[NK@("5S(.CG("5S75QN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B);
M\?+P[NK@("5S(.CG("5S75QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B);\?+P[NK@("5S(.CG("5S75QN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M
M(RTC7&XB"B);\?+P[NK@("5S(.CG("5S75QN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B);\?+P[NK@("5S
M(.CG("5S72(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2DB"FUS9W-T<B`BR/'O[NO\Y^[BX.WN.B`E+C)FS.$@
MZ.<@)2XR9LSA("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(EOQ\O#NZN`@)7,@Z.<@)7-=(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y
M(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HV."!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7W1O<"YI;F,Z
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS
M9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#`@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#D@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`BSN_E\.#VZ/\@[^[DY.7P
MYNKH("5S("T@S^[D\N+E\.;DY>WHY2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.2!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0S,B!L:6(O5D93+W-M
M8BYP:'`Z-#DT(&QI8B]61E,O9G1P+G!H<#HV.#(*(SH@;&EB+U9&4R]F='`N
M<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T
M<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(L[R
M[.7R_/+E(/3KX.;JX.SH(.[OY?#@]NC^*.CH*2P@ZN[R[O#[Y2#"^R#U[O+H
M\N4@[O'S^>7Q\N+H\OPN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R(");\?+P[NK@("5S
M(.CG("5S72(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M061D<F5S<R!";V]K(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!4
M87-K;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@
M;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N
M($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F
M('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*(RP@
M9G5Z>GD*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B6_'R\.[JX"`E<R#H
MYR`E<UTB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$S,B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-S0V"B,L(&9U>GIY"FUS9VED("(M+2!S96QE8W0@
M+2TB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S
M+C$I("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,@9G5Z>GD*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G
M<W1R("(Q,BWWX/'NXN[I(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+??@\>[B
M[NDB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@
M:&]U<G,B"FUS9W-T<B`B,C0@]^#QX"(*"B,Z(&QI8B](;W)D92]522]086=E
M<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("+/
M\.7D^^3S^>#_(/'R\.#MZ/;@(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C(*(RP@
M9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S
M='(@(CQB/L_P[NCG[OCKX"#J\.CRZ/?E\>K@_R#N^.CAZN`Z/"]B/B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I
M9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S
M:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B
M04T@0VQO=61S(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-
M($QI9VAT(%)A:6XB"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"B,L(&9U>GIY"FUS9VED(")!32!2
M86EN(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3(*(RP@9G5Z>GD*;7-G:60@(D%-(%-H;W=E
M<G,B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3,*(RP@9G5Z>GD*;7-G:60@(D%-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("+([._N\/(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U
M="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED(")!8G-B;W1T;VTB"FUS
M9W-T<B`BPNSE\?+E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(DE-4"(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(W,`HC+"!F=7IZ>0IM
M<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L
M+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S-@HC+"!F=7IZ>0IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R("+3]^7R[>#_(.?@[^CQ_"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.`HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*
M;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM
M<V=S='(@(M/O\.#BZ^7MZ.4@\??E\N#LZ"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G1I;F<B"FUS
M9W-T<B`BQ/#SX^CE(/_YZ.KH(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@
M(D%D9"(*;7-G<W1R("+$[N'@XNCR_"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O
M=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY."!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDY"B,L(&9U>GIY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBR^CW[?OE(@H*(R!F
M=7IZ>0HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D
M($AE<F4Z(@IM<V=S='(@(L3NX>#BZ/+\.B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R
M;W5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B061D
M($YE=R!097)M:7-S:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+E
MZ_\B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("+-X/'R
M\.[IZN@B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-30*(RP@9G5Z>GD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M
M(RTC+2,M(UQN(@HBY.[AX.+H\OP@\?+NZ^'E]B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!N
M97<@;65M8F5R<R(*;7-G<W1R("+$[N'@XNCR_"#OX/#S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T
M<B`BQ.[AX.+H\OP@[^#P\R(*"B,@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M
M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W,0IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R(@IM<V=S='(@(L3NX>#BZ/+\($UO>FEL;&$@4VED96)A<B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(L#D\.7Q
M[>#_(.KMZ./@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("+$[N'@XNCR_"#O
MX/#S(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N
M;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB
M"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-2!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*;7-G<W1R
M("+`Y/#E\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G
M:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,@
M9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(LW@\?+P[NGJZ"`M
M(//Q\N#M[N+JX"#O\.#B(.3K_R#D\//CZ/4@[^[K_.?NXN#RY>OEZ2(*"B,@
M9G5Z>GD*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(M/O\.#BZ^7MZ.4B"@HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0S"B,L(&9U>GIY"FUS9VED(")!9',B"FUS9W-T<B`BQ.[AX.+H
M\OPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4V"B,L(&9U>GIY"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("+-X/'R
M\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*
M;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM
M<V=S='(@(L_QY>+D[NWH["(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+/\>7BY.[MZ.PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R("+/\>7BY.[M
MZ.PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8W"B,L(&9U>GIY"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(L_QY>+D
M[NWH["(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#<@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE
M;G1I8V%T960@57-E<G,B"FUS9W-T<B`BPO'E(.+N^.7D^.CE(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B
M06QL($=R;W5P<R(*;7-G<W1R("+"\>4@X_#S[^_[(@H*(R!F=7IZ>0HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDQ(&QI8B](;W)D92]097)M<R]D871A
M=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("+"
M\>4@[_#@XN`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$W"B,L(&9U>GIY"FUS9VED(")!;&P@9F]U<B!S:61E
M<R(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M-S4*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("+0X.?PY?CH
M\OP@[N_E\.#VZ.@@\>X@\>_H\>K@[.@B"@HC.B!L:6(O2&]R9&4O1&%T851R
M964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R
M;F%T92!)35-0($QO9VEN(@IM<V=S='(@(L#K_/+E\.W@\NCB[?OI($E335`B
M"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_#HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@
M24U34"!5<V5R;F%M92(*;7-G<W1R("+([/\@[^[K_.?NXN#RY>O_($E335`Z
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*
M;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(L+@^"!%
M;6%I;#HB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT
M97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*(RP@9G5Z
M>GD*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("+"X/@@16UA:6PZ
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q
M-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G
M<W1R("+!^^ON(//JX.?@[>X@[>7J[O#PY>KR[>[E(.?MX/?E[>CE+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*(RP@9G5Z>GD*;7-G
M:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(CQB
M/L_P[NCG[OCKX"#J\.CRZ/?E\>K@_R#N^.CAZN`Z/"]B/B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N
M9&]R<F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G
M:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,@9G5Z>GD*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z
M,S4@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G
M<W1R("+/\.CK[N;E[>CE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R
M"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(LW@
M\?+P[NGJZ"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@
M(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("+-X/'R\.[E[>XB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@
M=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#`*;7-G:60@
M(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3D@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GD*
M;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(LCL_R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<W"B,L(&9U>GIY"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T
M<B`BR.S_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S
M/R(*;7-G<W1R("+"^R#SXN7PY>W[+"#W\NX@]>[RZ/+E(.[WZ/'RZ/+\(/WR
M\R#OX._J\S\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
MS_'EXN3N[>CL(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B07)M96YI82(*;7-G<W1R("+/
M\>7BY.[MZ.PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B
M07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED
M(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM
M<V=S='(@(B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(L?@[_#@^.CBX/+\(._N
MY/+BY?#FY.7MZ.4@[^7PY>0@XOOO[NOMY>WHY>P@[N_E\.#VZ.D@[N'QZ_/F
MZ.+@[>C_/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`R"B,L(&9U>GIY
M"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB
MY.[AX.+H\OP@\?+NZ^'E]B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("+/[N_[\NK@(//DX.OH\OP@[>7Q\_GE\?+B\_[YZ.4@[_#@
MXN`B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(L_N[_ORZN`@\.7DX.KRZ/#NXN#R_"#MY?'S^>7Q\N+S_OGHY2#O\.#BX"(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-"!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U
M=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I
M9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I
M=&-H+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV
M-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T
M:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@
M56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?
M;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D
M('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B
M075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*(RP@9G5Z>GD*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+`Y/#E\>#R
M(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSK
MY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S
M+G!H<#HQ-S8*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C
M=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7D
MZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M.#@R"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#Q
MY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ
M>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L
M($Q$05`N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I
M9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BQ.[Q\O/O[?OE(._NZ_\Z
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"B,L(&9U>GIY
M"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(LCQ[^[K_.?NXN#R_"#G[>#W
MY>WHY2#O[B#S[.[K]^#MZ/XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"B,L(&9U>GIY"FUS9VED(")"86-K9W)O=6YD
M($-O;&]R(@IM<V=S='(@(LCQ[^[K_.?NXN#R_"#G[>#WY>WHY2#O[B#S[.[K
M]^#MZ/XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"86AA;6%S(@IM<V=S
M='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS9W-T
M<B`B24U0(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D)A
M;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E
M<V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E
M[2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+3Y.#KY>WM^^4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*(RP@
M9G5Z>GD*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`BT.#G[.7P(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ
M>0IM<V=I9"`B0F5L:7IE(@IM<V=S='(@(M#@Y^SE\"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G
M:60@(D)E;FEN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+3Y.#KY>WM^^4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M97)M=61A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)H=71A;B(*;7-G
M<W1R("))35`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BQ.7M_"#P[N;DY>WH_R(*
M"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS-30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A
M=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N
M[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS
M9W-T<B`BS>#Q\O#NZ>K@.B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("+0X/'XZ/#E[>CE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"B,L(&9U>GIY"FUS9VED(")";VQD(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F
M=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R
M9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I
M9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@
M2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<U"B,L(&9U>GIY"FUS9VED(")";W1T;VTB"FUS9W-T<B`BPNSE
M\?+E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY
M"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"=6QG
M87)I82(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*(RP@
M9G5Z>GD*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BRNOE
M\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Q"B,L(&9U>GIY"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@
M8V]M<&QE=&5D+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,R!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(LK@Z^7MY.#P_"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*(RP@9G5Z>GD*
M;7-G:60@(D-A;&TB"FUS9W-T<B`BSO+LY>W@(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@
M(D-A;6)O9&EA(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@
M(D-A;65R;V]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B++Z/?M^^4B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P
M87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS-3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL
M92!<(B5S7"(B"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-1
M3"#QY?#BY?#N["XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@
M(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(S-2!L
M:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B
M"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0
M+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+-
MY>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z
M>GD*;7-G:60@(D-A;F%D82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("+.\NSE[>`B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(L[R[.7MX"#N\O?E\N`@[B#O\.[A
MZ^7LY2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C4R"B,L(&9U>GIY"FUS9VED(")#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L
M[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(LWE(.SNX_,@[O+J
M\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D
M92]$871A5')E92YP:'`Z,3(X(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP
M.C8X,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR
M_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]$
M871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L
M(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@
M;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN
M;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z
M>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB
M+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`BRN#RY>/N\.CH(.@@
M[.7RZN@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E
M;&P@4&AO;F4B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U
M"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BRNOE
M\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Q"B,L(&9U>GIY"FUS9VED(")#96QL('!R;W!E<G1I97,B
M"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC(",M(RTC+2,M(R`@
M<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*(RP@9G5Z
M>GD*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M'N]?#@[>CR
M_"#JX.I<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C
M+2,M(RTC+2-<;B(*(M'N]?#@[>CR_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C<X"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BRNOE
M\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M-PIM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(M'NY^3@\OPB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM
M<V=S='(@(B(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>0HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,@HC+"!F=7IZ>0IM<V=I9"`B0V5R
M=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`BR/'JX/+\(.(@SO+BY?+Q\N+E[>W[
M]2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#
M97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G
M:60@(D-H860B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BSO+LY>WH\OP@Z.?L
MY>WE[>C_(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L
M(&9U>GIY"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("+/
MX/#NZ_PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*
M(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*
M;7-G<W1R("+-X/'R\.[IZN@@Z.SE[>@L(.#D\.7QX"P@[^[D[^CQZ"XB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H
M86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H
M92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B
M0VAA<B(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B
M0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,PIM<V=I9"`B
M0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T
M;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BSO+LY?+\\N4@].O@
MYNK@[.@@[N_E\.#VZ/XHZ.@I+"#J[O+N\/OE(,+[(/7N\NCRY2#N\?/YY?'R
MXNCR_"XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R("+'X./NZ^[B
M[NHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8W"B,L(&9U>GIY"FUS9VED(")#:&EN82(*;7-G<W1R(")V0V%R9"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM
M<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R("+"^^'E\.CR
MY2#O\.CK[N;E[>CE.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,C<P"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC
M+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@
M(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M(@IM<V=S='(@(M3N\.S@\B#N\N[A\.#FY>WH_R#DX/+[.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*
M;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]61E,N<&AP.CDQ-"!L:6(O3F5T+U--4RYP:'`Z,CDT
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH
M_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@
M(LK@Z^7MY.#P_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM<V=I
M9"`B0VQE87(@475E<GDB"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("+3Y.#KZ/+\
M(._@\/,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*
M(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`BRN#KY>WDX/#\
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*(RP@9G5Z
M>GD*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("+*X.OE[>3@\/PB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0HC
M+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("+"]>[D(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*
M(RP@9G5Z>GD*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(LW@
M\?+P[NGJZ"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(L?@ZO#[
M\OP@[NKM[B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B
MRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(LKN[._@
M[>C_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(M/A\.#R_"#LY>W^
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(M#@Y^+E\.WS\OP@XO'E(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B
M0V]L;VUB:6$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+T)L;V-K+V-O
M;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*(RP@9G5Z
M>GD*;7-G:60@(D-O;&]R(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4@;&EB+TAO<F1E+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,R-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3`Q('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#(*(RP@9G5Z>GD*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("+(
M[._N\/(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@S-0HC+"!F=7IZ>0IM
M<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBQ.7I\?+B
MZ.4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#,*(RP@9G5Z>GD*;7-G:60@(D-O;',Z(@IM<V=S='(@(LK@Z^7MY.#P
M_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@
M=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-C8*(RP@9G5Z>GD*;7-G:60@(D-O;6EC<R(*;7-G<W1R("+*X.OE[>3@
M\/PB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@
M(D-O;6UA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(LKN[._@[>C_(@H*(R!F=7IZ>0HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ>0IM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`BPN#XY2#H[/\Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(D-O
M;6]R;W,B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B
MRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V
M"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`BS>#Q\O#NZ>KH
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN
M9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("+*[NWTZ./S\.#V
MZ/\@\_'RX/#EZ^`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"B,L(&9U>GIY
M"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*(RP@
M9G5Z>GD*;7-G:60@(D-O;F=O(@IM<V=S='(@(LKN[/,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE
M[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS
M9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C@W-@HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H
M[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HQ,#$T"B,L(&9U>GIY"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("+/
M[NK@Y^#R_"#*[NWRX.KR^R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT
M<R!O9B!<(B5S7"(B"FUS9W-T<B`BT>[DY?#FX.WHY2`E<R(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
MS>#Q\O#NZ>KH(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R("+*[NSOX.WH_R(*
M"B,Z(&QI8B]61E,O<VUB+G!H<#HT-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(UQN(@HBSOCHX>K@(._PZ"#SY.#KY>WHZ%QN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LWE
M\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"Y<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB
M"B+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@HC+"!F
M=7IZ>0IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L3E
MZ?'RXNCE.B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-S`@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z.3<W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G93H@(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$P-34*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E.B`B"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN
M=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HS.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP
M="!M97-S86=E+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA
M:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C0V-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N
M(&UE<W-A9V4N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I
M;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\
M(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.CDV(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$R,0HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BS>7SY.#W
M[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("+-Y2#L[N/S
M(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BS>7SY.#W[>[E
M(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!
M4"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\
M[>X@[>#Q\O#NY>TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@
M(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3(S"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB
M"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]4
M87-K("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<R(*;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\[>X@[>#Q
M\O#NY>TB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")(;W)D92#MY2#O\.#B
MZ.O\[>X@[>#Q\O#NY>TB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DAO<F1E
M(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU,PHC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BS>4@
M[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@HC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SN
MY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB
M"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]4
M87-K("5S(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("+-Y2#L
M[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,3D*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!
M4"XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`BS>4@[.[C
M\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-R!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B`E<RXB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-
M86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`BS>4@[.[C\R#N
M\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HQ,3$@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HT-S@*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HV-38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0
M+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("+-Y2#L
M[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#,*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R
M("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D
M<F5S<R!B;V]K+B`E<R(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN(.W@\?+P
M[N7M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B2&]R9&4@[>4@[_#@
MXNCK_.WN(.W@\?+P[N7M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,B"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN(.W@\?+P[N7M(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D
M92#MY2#O\.#BZ.O\[>X@[>#Q\O#NY>TB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T
M<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S
M879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@
M8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H
M[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T
M<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT
M96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+-Y2#L
M[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#(S"B,L(&9U>GIY"FUS9VED(")#;W5N=&5D('1E
M>'0B"FUS9W-T<B`BPOOU[N0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,`HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBS>[B[N4@\>[NX?GE[>CE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("+3\>_E
M^.WN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BT>[GY.#R
M_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G
M<W1R("+1[N?DX/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM
M<V=S='(@(M'NY^3@\OP@[>[B^^D@[_#N].CK_"(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD
M97)S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
MT>[GY.#RY>O\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3D*(RP@9G5Z
M>GD*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("+([/\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0HC
M+"!F=7IZ>0IM<V=I9"`B0W)O871I82(*;7-G<W1R("+1[N?DX/+\(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0W5B82(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G
M<W1R("+2Y>KS^>#_(@H*(R!F=7IZ>0HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-3`*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B
MT>[GY.#RY>O\(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K
M+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`BTN7J
M\_GEY2#B\.7L_R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5
M4DP@:7,B"FUS9W-T<B`BTN7J\_GEY2#B\.7L_R(*"B,@9G5Z>GD*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S
M97)S(@IM<V=S='(@(M+EZO/YX/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C8T"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(&-O;F1I=&EO
M;CH@(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D-U<G)E
M;G0@<W1Y;&4B"FUS9W-T<B`BTN7J\_GEY2#B\.7L_R(*"B,@<&AP+69O<FUA
M=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(L?@Y.#WZ"P@Y^#O\_'JX.7L^^4@[_#H(.+U[N3E(.(@)7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D-U="(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B
M[N4@\>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-0HC+"!F=7IZ>0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#>7)I
M;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C
M:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4P('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")$1"(*;7-G<W1R("+$Q"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C<Y"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3D*;7-G
M:60@(D1A:6QY(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,Z(&%D;6EN+V1A=&%T
M<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-PIM<V=I9"`B1&%T86)A<V4@
M3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$
M871E(@IM<V=S='(@(L3@\N`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-@HC+"!F=7IZ>0IM<V=I9"`B
M1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S
M='(@(L7FY>3MY>+M[B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T
M92!#;VQU;6XB"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<V"B,L(&9U>GIY"FUS9VED(")$96-E;6)E<B(*;7-G
M<W1R("+'X.SE\NKH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B1&5C:6UA
M;"!N=6UB97)S(@IM<V=S='(@(LCL_R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N
M="(*;7-G<W1R("(B"@HC.B!L:6(O<')E9G,N<&AP.C$Q-R!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$X-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G
M<W1R("+3Y.#KZ/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*
M;7-G<W1R("+6XN7R(._N(//L[NOWX.WH_B(*"B,Z(&QI8B](;W)D92])9&5N
M=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B
MS_#N].CK_"#O[B#S[.[K]^#MZ/XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B
MT^3@Z^CR_"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY."!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T
M92(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@0V5L;"(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'
M<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`BT^3@
MZ^CR_"(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!097)M
M:7-S:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`BT>[NX?GE
M[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T
M<B`BT^3@Z^CR_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C;VQU
M;6XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@
M=C$N,2D@(",M(RTC+2,M(UQN(@HB\^'PX/+\(/'R[NOAY?8B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BS>#Q\O#NZ>KH
M(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T
M<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BT^3@Z^CR_"(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(M/DX.OH\OP@XOOA
M\.#M[?OI(._P[O3HZ_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB\^'PX/+\
M(/'R[NOAY?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!R;W<B"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
MS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(M/DX.OH\OPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C
M<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("+.[^CXZ/+E(._P[N'KY>SS(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$
M97-C<FEP=&EO;B(*;7-G<W1R("+/[NOM[N4@[N_H\>#MZ.4Z(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G
M<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#$*
M;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(L_NY/#NX>WN\?+H(.'[Z^@@Y^#OZ/'@[?L@
MXB#F\_#MX.L@Y.O_(.#D[.CMZ/'R\.#R[O#@+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@
M(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T
M('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T
M;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y
M"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BRN#RX.ONXR(*"B,@9G5Z>GD*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R
M-"UH;W5R('1I;65S/R(*;7-G<W1R("+.\N[A\.#FX/+\(.+PY>S_(.(@,C0M
M]^#Q[N+N["#T[O#LX/+E/R(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L3P
M\^/HY2#MX/'R\.[IZN@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0B"FUS9W-T<B`BS>#Q\O#NZ>KH(.[A[NON]^KH(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(X,#8*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T
M(@IM<V=S='(@(LW@\?+P[NGJZ"#NX>[K[O?JZ"(*"B,Z(&QI8B](;W)D92]-
M24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O
M(&YO="!D96QE=&4B"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`BS>4@XOOG^^+@Z?+E(&UA:6YT
M96YA;F-E+G!H<"#MY>_N\?#EY/'RXN7M[>XB"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("+"(._E
M\.+NZ2#Q\O#NZN4@\^K@Y^#M^R#H[.7MX"#O[NOEZ3\@Q?'KZ"#DX"P@[^[Q
M\N#B_/+E(./@Z^[WZO,Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(D1O;6EN:6-A(@IM
M<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U
M,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BQ^#C\//GZ/+\(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("+'X./P\^?H\OP@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,0IM<V=I9"`B1')O<"!D;W=N
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B24U0(@H*(SH@
M;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM
M=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O
M=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(M#EY.#J\NCP[N+@
M[>CE(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P"FUS
M9VED(")%9&ET($)L;V-K(@IM<V=S='(@(M#EY.#J\NCP[N+@\OPB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I
M9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P"B,L(&9U>GIY
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BS>#Q\O#NZ>KH(._N
MZ_SG[N+@\N7K_R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*
M(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`BS>#Q
M\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F
M=7IZ>2P@<&AP+69O<FUA=`HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(M/Q\N#M[N+JX"#O\.#B(.3K_R`E<R(*"B,@9G5Z>GDL
M('!H<"UF;W)M870*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(R!F
M=7IZ>2P@<&AP+69O<FUA=`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I
M;VYS(&9O<B`E<R(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM
M<V=S='(@(D5M86EL(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,L(&9U>GIY"FUS9VED
M(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DV-PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@
M=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`BS_#N]^#_(.CM].[P[.#VZ/\B
M"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%
M;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")%
M;6]T:6-O;G,B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y
M(&UE<W-A9V4N(@IM<V=S='(@(LWSZ^7B[ND@\.7G\^O\\N#R+B(*"B,Z(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR-#,@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C0X-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C8R(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(LWS
MZ^7B[ND@\.7G\^O\\N#R+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I
M;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E
M>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*
M;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S
M='(@(LKN[?+EZO'R[>[E(.SE[?X@[^X@[>#FX/+HZ"#O\.#B[ND@ZNWN[^KH
M(.S[^.@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@P,`HC+"!F=7IZ>0IM<V=I9"`B16YD('EE87(B"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(M#@Y^+E\.WS\OP@XO'E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET
M;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM
M<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@
M=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E
M(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HX.3`*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E
M;&]W.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT.`IM<V=I9"`B17)R;W(B"FUS9W-T<B`BSOCHX>K@
M(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W
M<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*
M"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B
M179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+*X.;D^^4@,34@[.CM\_(B"@HC
M(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V
M97)Y(#(@;6EN=71E<R(*;7-G<W1R("+*X.;D^^4@,B#LZ.WS\OLB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BRN#FY/OE
M(#,P(/'EZO/MY"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U
M(&UI;G5T97,B"FUS9W-T<B`BRN#FY/OE(#4@[.CM\_(B"@HC.B!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R("+*X.;D^^D@\.#G(._PZ"#B]>[DY2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+*
MX.;D^^4@[^[K]^#QX"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R
M>2!M:6YU=&4B"FUS9W-T<B`BRN#FY//^(.SH[?/R\R(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB
M"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN
M<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0W-2!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S
M='(@(M#@\?CH\.CR_"(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI
M;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M
M(RTC7&XB"B+0X.?BY?#M\_+\(.+QY2(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X
M<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,0HC+"!F=7IZ>0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`BR/'O[NO\Y^[B
MX/+\(.?MX/?E[>CE(._N(//L[NOWX.WH_B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BPN[Q\?+@
M[>[BZ^7MZ.4@[>#Q\O#NY>H@[>4@\^3@Z^[Q_"XB"@HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3@*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`BS>7S
MY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HW,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("+-Y?/DX/?M[N4@
M\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C<R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WH
MY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP
M:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ
M_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3`Q(&QI
M8B]61E,O9G1P+G!H<#HW-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`BS>7SY.#W[>[E
M(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HT-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!R971R:65V93H@)7,B"FUS9W-T<B`BU.#IZR#O\.CM__(Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"B,L(&9U>GIY
M"FUS9VED(")&86ER(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+.\B#J[N/N7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.\B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S
M"B,L(&9U>GIY"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(LKN[._@
M[>C_(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`BSOCHX>K@(.CL[^[P\N`Z("(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&
M87@B"FUS9W-T<B`BU.#J\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-3$*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(M3@ZO$B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A
M<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"B,L(&9U>GIY"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`HC+"!F=7IZ>0IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DT.`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S,R"FUS9VED(")&:6=L
M970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S,S-@IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ
M:2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R("+4X.GK(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC(&9U
M>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I
M;&4@36%N86=E<B(*;7-G<W1R("+5\.#MZ.OH^>`B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(LCL_R(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.#0*(RP@9G5Z>GD*;7-G
M:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(L_NZ^WNY2#N[^CQX.WHY2#O
M\.[AZ^7L^SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30Y,`HC+"!F=7IZ
M>0IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO
M<F1E+T)R;W=S97(N<&AP.C@X-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!U<&QO
M861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A
M^>7MZ.4B"@HC(&9U>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("+4Z.O\\O#[(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM
M<V=I9"`B1FEN;&%N9"(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($AA;&8B"FUS
M9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S`*;7-G:60@(D9L
M:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G
M:60@(D9O9R(*;7-G<W1R("(B"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C,W(&QI
M8B]61E,O;75S<6PN<&AP.C$P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(L#D\.7QX/(@
M\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*(RP@9G5Z>GD*;7-G:60@(D9O
M;G0@0V]L;W(B"FUS9W-T<B`BR/'O[NO\Y^[BX/+\(.?MX/?E[>CE(._N(//L
M[NOWX.WH_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`BPN#X(.'P
M[O/GY?`@[>4@[^[DY.7PYNCBX.7R(.[O]NC^(._E]^#RZ"X@Q.O_(._E]^#R
MZ"#MX.;LZ/+E($-44DPK4"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@
M=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,#(*(RP@9G5Z>GD*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W
M;W)D/R(*;7-G<W1R("+/X/#NZ_PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#8T"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*;7-G<W1R("+([/\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"B,L(&9U>GIY"FUS
M9VED(")&;W)U;7,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,3$*(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1S(@IM
M<V=S='(@(L_E\.7QZ^#R_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9R(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+.\B#J[N/N7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V
M,2XQ*2`@(RTC+2,M(RTC7&XB"B+.\B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@
M(D9R86UE<R(*;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&<F%N8V4B
M"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY
M;F5S:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D9R;VTB"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(L[R(.KNX^Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q
M+C$I("`C+2,M(RTC+2-<;B(*(L[R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*(RP@9G5Z>GD*
M;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBSO(@ZN[C[EQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB
MSO(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(L_NZ^WNY2#N
M[^CQX.WHY2#O\.[AZ^7L^SHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL
M($YA;64B"FUS9W-T<B`BPN#XY2#H[/\Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1V%B
M;VXB"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I
M9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I
M9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*
M;7-G:60@(D=H86YA(@IM<V=S='(@(G9#87)D(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<V
M"B,L(&9U>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(LCL_R(*"B,@
M9G5Z>GD*(R!F=7IZ>0HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R
M("+/[O#RX.LB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I
M9"`B1V\B"FUS9W-T<B`BS^7PY>GRZ"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3(Y"B,L(&9U>GIY"FUS9VED(")';V]G;&4@
M36%P<R(*;7-G<W1R("+/[NCQZB#B($=O;V=L92(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
MS^[H\>H@XB!';V]G;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,V"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*(RP@
M9G5Z>GD*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("+*X.OE[>3@\/PB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"B,L
M(&9U>GIY"FUS9VED(")'<F5N861A(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4Y(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("+/\.[AZ^7LX"#O\.@@
M[^[O^_+JY2#B^_?E\.KM\_+\("5S+B#1Y?#BY?`@\>K@Y^#K(@H*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,RXP+C,I("`C+2,M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@
M\2!344P@\>7PXN7P[NPN7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CM
MZ/+\\?\@\2!344P@\>7PXN7P[NPN7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A(;W)D92!V,RXP+C,I("`C+2,M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM
M<V=S='(@(L/P\^_O^R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U
M97)N<V5Y(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I
M9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`BP^[Q\OPB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(M+E[.`B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"B,L(&9U>GIY
M"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z
M,34W"B,L(&9U>GIY"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GD
MY>TN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@P"B,L(&9U>GIY"FUS9VED(")(86ET:2(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA
M<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(R"B,L(&9U>GIY"FUS9VED(")(87IE(@IM
M<V=S='(@(L_NY/'JX.?JX"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,C,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C$*(RP@9G5Z>GD*;7-G:60@(DAE861E
M<B(*;7-G<W1R("+/[N3QZN#GZN`B"@HC.B!L:6(O2&]R9&4O1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("+'X./N
MZ^[BZN@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PHC+"!F=7IZ>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*
M;7-G<W1R("+([._N\/(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM
M<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*
M(RP@9G5Z>GD*;7-G:60@(DAE:6=H="(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@
M;&EB+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP
M+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(L_NY/'JX.?JX"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*
M;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S<U"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS
M9W-T<B`BS^[D\>K@Y^K@(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`BS^[K\_C@\.CE(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`BS>CFY2#O\.7D\?+@XNOE[>`@Z.WT
M[O#LX/;H_R#HYR#QX.SNX^X@[>#WX.O@(/3@Z>O@.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"B,L(&9U>GIY"FUS9VED
M(")(:6=H(@IM<V=S='(@(LWHZN[CY.`B"@HC(&9U>GIY"B,Z('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`BS^[P\N#K(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM
M<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4N<&AP.C$U,SD*;7-G:60@(DAO;64B
M"FUS9W-T<B`BS^[P\N#K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+$[NS@^.WHZ2#@Y/#E
M\2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`BRN#RX.ONXR(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(L3N[.#X[>CI(/+EZ^7T[NTB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U
M<F%S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*
M"B,@9G5Z>GD*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED
M(")(;W)D92(*;7-G<W1R("+/[O#RX.LB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O
M;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L_P[N'KY>S@(._P
MZ"#O\.[Q[.[R\.4@Y^#O\.[XY>WM[N/N(._H\?SLX"XB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HU,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R
M:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,S,R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM
M<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X.0IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I
M='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,B!L:6(O2&]R9&4O075T
M:"]C>7)S<6PN<&AP.C(S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BP.3P
MY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C(Q-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C
M>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE
M[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,R
M,`HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("+`Y/#E\2(*
M"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"B,L(&9U>GIY"FUS
M9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D
M[O'R\^_M^_4@[>#Q\O#NY>HN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I
M8RYP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@
M[>#Q\O#NY>HN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@R"B,L(&9U>GIY"FUS9VED("))8V5L86YD(@IM<V=S='(@(LKN[._@[>C_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@
M3VYL>2(*;7-G<W1R("+2[NO\ZNX@Z.KN[>KH(@H*(R!F=7IZ>2P@<&AP+69O
M<FUA=`HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N
M<R!W:71H('1E>'0B"FUS9W-T<B`BR.KN[>KH(/$@\N7J\?+N["(*"B,@9G5Z
M>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I
M='DG<R!N86UE.B(*;7-G<W1R("+([/\@[_#N].CK_SHB"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@
M(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N
M(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(X"B,L(&9U>GIY"FUS9VED("));6%G92!0<F5V
M:65W.B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBS>#GX.0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G
M92!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V
M-0HC+"!F=7IZ>0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(LCL_R(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`BRN#P\NCMZN@B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(LCL[^[P\BP@^.#C("5D(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(LCL[^[P\NCP[N+@
M[>X@[^[KY3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U
M"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(LCL[^[P\NCP[N+@
M[?L@[^[K_SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(DEN7W-E<G0@4F]W
M($%F=&5R(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E
M(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#BXN7D
MZ/+E(,+@^.@@Z.S_(._NZ_SG[N+@\N7K_R#H(._@\.[K_"(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(DEN9&EA(@IM<V=S='(@(M+E
MZ^7T[NTB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R("+/[NO\Y^[BX/+EZ^@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DEN
M9&]N97-I82(*;7-G<W1R("+2Y>OE].[M(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(DEN9F\B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(LCC[>[PZ/#NXN#R_"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-3D*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(L_P[O?@_R#H[?3N\.S@]NC_7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBR.WT[O#LX/;H
M_R#N(/'E\.+E\.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$Y"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS
M9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`HC+"!F=7IZ>0IM<V=I
M9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`BT^3@Z^CR
M_"#OX/#S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C(*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<
M;B(*(O/A\.#R_"#Q\N[KX>7V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@869T97(B
M"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0HC+"!F=7IZ>0IM<V=I9"`B26YS
M97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*(RP@
M9G5Z>GD*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`BT>[N
MX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-O;'5M;B!B
M969O<F4B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S
M<V%G97,B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"B,L(&9U>GIY"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(M'N[N'YY>WH
MY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(')O=R!A9G1E
M<B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H
M92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED("));G-E<G0O36]D:69Y($EM86=E
M(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="]-
M;V1I9GD@3&EN:R(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"B,L(&9U>GIY"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT
M96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W.0HC+"!F=7IZ>0IM<V=I
M9"`B26YT96=E<B(*;7-G<W1R("+1[N?DX/+\(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$Q,S<*(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G
M<W1R("+1[N?DX/+\(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP
M.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(%I)4"!D871A(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.3$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S8*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S,#,@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM
M<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M9&)X+G!H<#HQ,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T,0HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B
M"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@
M(LWEZN[P\.7J\NWNY2#H[/\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U.0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`BT.#A
M[O?HZ2#@Y/#E\2(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM
M<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("+-X/'R\.[IZN@B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`BS>#Q\O#N
MZ>KH(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(LW@
M\?+P[NGJZ"(*"B,@9G5Z>GD*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`BS>7J
M[O#PY>KR[>[E(.CL_RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P-S4@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4X"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(M#@X>[W
MZ.D@X.3PY?$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM
M<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4Y"B,L(&9U>GIY"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B
MS>7J[O#PY>KR[>[E(.CL_RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<V"B,L(&9U>GIY"FUS9VED("));G9E<G0@<V5L96-T
M:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B27)E;&%N9"(*;7-G<W1R
M("+*[NSOX.WH_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G
M:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T
M;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DES<F%E;"(*;7-G
M<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C(V"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"B,L(&9U>GIY"FUS9VED("))
M=&%L:6,B"FUS9W-T<B`BQ>;EY.WEXNWN(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))
M=&%L>2(*;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"B,L(&9U>GIY"FUS9VED(")*87!A
M;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@V"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`HC+"!F=7IZ
M>0IM<V=I9"`B2G5N92(*;7-G<W1R("+2Y>S@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`HC+"!F=7IZ>0IM
M<V=I9"`B2G5S=&EF>2(*;7-G<W1R("+1[N?DX/+\(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*(RP@9G5Z
M>GD*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(M'NY^3@\OPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(M'N
MY^3@\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-`HC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2!,969T(@IM
M<V=S='(@(M'NY^3@\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R("+1[N?DX/+\(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"B,L(&9U>GIY"FUS9VED(")+
M87IA:VAS=&%N(@IM<V=S='(@(L3@\N`B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C8S"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y
M($QE;F=T:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DY"B,L(&9U>GIY"FUS9VED(")+97D@57-A
M9V4B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-PIM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M2W5W86ET(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA
M7WEO=70B"FUS9W-T<B`BT.#QZNO@Y.K@(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BW^?[ZB(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0HC+"!F=7IZ>0IM
M<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(DQA
M<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*(RP@9G5Z
M>GD*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBP?OQ\O#[
MZ2#Q\N#P\B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BS_#EY/OD\_GH
MZ2#B]>[D(.'[ZSH@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS
M9W-T<B`BS_#EY/OD\_GHZ2#B]>[D(.'[ZSH@)7,@\2#J[NSO_/[RY?#@("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I
M;CH@3F5V97(B"FUS9W-T<B`BS_#EY/OD\_GHZ2#B]>[D(.WE(.?@].CJ\>CP
M[N+@[2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(M'NY^3@
M\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(L+[]>[D
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS
M9VED("),969T(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+OY?#E[.7Q\NCR_"#BXN7P]2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`X"B,L(&9U>GIY"FUS9VED("),
M969T(&AE861E<B(*;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,#0*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L
M=65S(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R("+3Y.#KZ/+\(._@
M\/,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`BS>CJ[N/D
MX"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G
M:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED
M("),:6=H="!286EN(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DQI
M9VAT(%)A:6X@3&%T92(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(DQI
M9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`HC+"!F=7IZ>0IM<V=I9"`B
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"B,L(&9U>GIY
M"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@HC+"!F=7IZ>0IM<V=I
M9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#$X"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S
M='(@(L+U[N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W.0IM<V=I9"`B3&EN
M:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@
M9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O:'1M;#)T97AT+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(DQI;FMS(@IM
M<V=S='(@(L+U[N0B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),
M:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("+1
M[^CQ[NH@\.#GY.7K[N(@[^[D\>K@Y^KH(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*(RP@9G5Z>GD*
M;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("+(\>K@\OPB"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI
M<W0M2&5L<"(*;7-G<W1R("+1[^CQ[NH@\.#GY.7K[N(@[^[D\>K@Y^KH(@H*
M(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"B,L(&9U>GIY"FUS
M9VED("),:7-T+4ED(@IM<V=S='(@(M'OZ/'NZB#PX.?DY>ONXB#O[N3QZN#G
MZN@B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*(RP@9G5Z
M>GD*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`BT>_H\>[J(/#@Y^3EZ^[B
M(._NY/'JX.?JZ"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M,PHC+"!F=7IZ>0IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(M'OZ/'NZB#P
MX.?DY>ONXB#O[N3QZN#GZN@B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y,0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U3=6)S8W)I
M8F4B"FUS9W-T<B`BR/'JX/+\(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.3`*(RP@9G5Z>GD*;7-G:60@(DQI<W0M56YS=6)S
M8W)I8F4B"FUS9W-T<B`BR/'JX/+\(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(L[XZ.'JX"#O\.@@\^3@Z^7MZ.A<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+-Y?/DX/?M[N4@
M\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBS>7SY.#W
M[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(L_NZ/'J(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G
M:60@(DQI=&AU86YI82(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4
M:6UE(@IM<V=S='(@(LONZN#KZ.?@]NC_(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,@IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`BT.#Q[^[K[N;E[>CE(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM
M<V=S='(@(L+U[N0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T
M<B`B(@H*(R!F=7IZ>0HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(L+[]>[D(@H*(R!F=7IZ>0HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S
M='(@(M/WY?+MX/\@Y^#OZ/'\(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+"]>[D
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0HC+"!F=7IZ>0IM<V=I9"`B
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HBS^X@ZN#J
MZ.PM\NX@[_#H]^CMX.P@XO7NY"#B(/'H\?+E[/,@[>4@\^3@Z_'_+B#"Y?#N
M__+MY>4@XO'EX^XL(,+@^.@@Z.S_("(*(N_NZ_SG[N+@\N7K_R#HZ^@@[^#P
M[NO\(.'[Z^@@XN+EY.7M^R#MY>+E\.WN+B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY.3$*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T
M<B`B24U0(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD*(RP@9G5Z>GD*
M;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("+"^_7NY"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED("),;W<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3<*(RP@9G5Z>GD*;7-G:60@(DQO=V5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS.3D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B
MS,PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-
M3U1$(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3(*(RP@9G5Z>GD*;7-G:60@(DUA8V%O(@IM<V=S='(@(DE-4"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC
M(&9U>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B
M36%I;"(*;7-G<W1R("+/[O?RX"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q
M"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B36%L87=I(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B
M36%L87ES:6$B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS
M9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R("))
M35`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H
M;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(LW@\?+P[NGJX"#Q[^CQZN`@ZN#R
MY>/N\.CI(.@@]N+E\N[B(.CU(.[R[N'PX.;E[>C_(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-30*;7-G:60@(DUA<#(T(&UA
M<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`X-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$V.0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@
M<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B36%R8V@B"FUS9W-T<B`BS^[H\>HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`BPNWH[.#M
MZ.4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`BPNWH
M[.#MZ.4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(M'NXN_@Y.#^^>CE(._NZ_\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3,*(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`BPNWH[.#M
MZ.4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("+"[>CL
MX.WHY2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U
M"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"B,L(&9U>GIY"FUS
M9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`BT>[N
MX?GE[>CE(@H*(SH@;&EB+V%P:2YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`BS.#J\>CL
MX.O\[>[E(.KNZ^CWY?'RXNX@\?+PX.WH]B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,C$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"B,L(&9U>GIY"FUS
M9VED(")-87DB"FUS9W-T<B`BQ>;EY.WEXNWN(@H*(R!F=7IZ>0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U
M>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(L+[]>[D(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B
M365M8F5R<R(*;7-G<W1R("+'X.SE\NKH(@H*(R!F=7IZ>0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@
M(M#EYNCL(.SE[?XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BT>[NX?GE
M[>CE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@
M(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R
M("+1[N[A^>7MZ.4B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@='EP92(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C
M;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U)00R]X
M;6QR<&,N<&AP.C@Q(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D
M969I;F5D(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#I
MY.7M+B(*"B,Z(&QI8B](;W)D92]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C<*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC
M;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L
M92(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O
M<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,PHC+"!F=7IZ>0IM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(L[XZ.'JX"(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS-#`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(U
M,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED
M("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU
M.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM
M<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0HC+"!F=7IZ>0IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"B,L
M(&9U>GIY"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(M/DX.OH\OP@[^#P
M\R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T"B,L(&9U>GIY
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(M'VY>W@\.CI(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*(RP@9G5Z>GD*;7-G
M:60@(DUO;F%C;R(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUO
M;F=O;&EA(@IM<V=S='(@(LKN[/,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C4X.`HC+"!F=7IZ>0IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC
M+2-<;B(*(M#@Y^+E\.WS\OP@XO'E(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("+%YN7LY?'_]^WN
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O
M;B!0:&%S97,B"FUS9W-T<B`BU.#G^R#+\^W[(@H*(SH@;&EB+T9I;&4O0U-6
M+G!H<#HQ.38@;&EB+T9I;&4O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP"B,L(&9U>GIY"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@0VQE87(B
M"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-`HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY($-L;W5D
M>2(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@4W5N
M;GDB"FUS9W-T<B`BRN[L[^#MZ/\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C4P.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(N_E\.7L
MY?'RZ/+\(.+MZ.<B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C4Q,R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8U,@IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+K
MY>+N(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU
M,3<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G
M:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B[^7PY>SE\?+H\OP@XN_PX.+N(@H*
M(R!F=7IZ>0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#4@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@(DUO
M=F4@57`B"FUS9W-T<B`B[^7PY>SE\?+H\OP@XN+E\/4B"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@
M(DUO=F4@9&]W;B(*;7-G<W1R("+OY?#E[.7Q\NCR_"#B[>CG(@H*(R!F=7IZ
M>0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO
M=F4@=7`B"FUS9W-T<B`B[^7PY>SE\?+H\OP@XN+E\/4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#4V"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS
M9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-@HC
M+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(L_N
MZ^WNY2#N[^CQX.WHY2#O\.[AZ^7L^SHB"@HC(&9U>GIY"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T
M<B`BT_?E\NW@_R#GX._H\?PB"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G
M<W1R("+"X/C@(.CM].[P[.#VZ/\B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP.C0U"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T86P@3&%Y
M;W5T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B37EA;FUA<B(*;7-G
M<W1R("+*X.OE[>3@\/PB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R
M965M96YT7V)O='1O;2YI;F,Z-PHC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,2!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T
M<B`BR.S_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F%U<G4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M(RP@9G5Z>GD*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(LK@Z^7MY.#P
M_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A
M<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V
M"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P
M92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*
M;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4S"B,L(&9U>GIY"FUS9VED(").971W;W)K(@IM<V=S='(@(LWN
MXOOE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S
M='(@(LWNXN#_(.K@\N7C[O#H_R(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E
M<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N
M<&AP.C@W"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.CDW
M(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T
M<B`BS>[B^^4@\>[NX?GE[>C_(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V
M(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T
M"B,L(&9U>GIY"FUS9VED(").97<@36]O;B(*;7-G<W1R("+"Y?#M\_+\\?\@
MZB#MX/'R\.[IZN#L(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDX"B,L(&9U>GIY"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("+*
MX.OE[>3@\/PB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB
M"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F
M=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T
M<B`BPN#X($5M86EL.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS
M9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S
M='(@(LWNXN[Q\N@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W
M"B,L(&9U>GIY"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(M/DX.OH\OPB
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B
M3F5X="(*;7-G<W1R("+$X.OEY2(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S
M='(@(M'KY>3S_OG@_R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HS-C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE
M>'0@;W!T:6]N<R(*;7-G<W1R("+1Z^7D\_[YX/\@\?+PX.WH]N`B"@HC.B!L
M:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X
M=#XB"FUS9W-T<B`BQ.#KY>4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI8V%R86=U
M82(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S
M='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R:6$B"FUS9W-T
M<B`BS>CJ[N/DX"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-CD*(RP@9G5Z>GD*;7-G:60@(DYI9VAT(@IM<V=S='(@(LWHZN[CY.`B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M(RP@9G5Z>GD*;7-G:60@(DYI=64B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C0*;7-G:60@(DYO
M(@IM<V=S='(@(LWE\B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F
M+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T
M82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO
M(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HW.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR
M-#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C8W(&QI8B](;W)D
M92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[VY>3S\/L@X//RY>WR
MZ/3HZN#VZ.@@[^X@4U%,(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*
M(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`BSO+LY>WH\OP@
MZ.?LY>WE[>C_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z,38Y(&QI8B](;W)D
M92YP:'`Z-3`X(&QI8B](;W)D92]5=&EL+G!H<#HW-C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`BS>4@X?OK[B#SZN#GX.WN(/'N
M[O+BY?+Q\N+S_OGEZ2#H[?3N\.S@]NCH(.3K_R#JX/+EX^[PZ.D@4U%,+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R("+$Z_\@[>#Q\O#NY>H@3$1!4"#MY2#A^^ON(//JX.?@[>X@
M\>[N\N+E\O'RXO/^^>7I(.CM].[P[.#VZ.@N(@H*(SH@;&EB+U9&4R]S<6PN
M<&AP.C8W,@HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(LWE(.'[
MZ^X@\^K@Y^#M[B#Q[N[RXN7R\?+B\_[YY>D@Z.WT[O#LX/;HZ"#DZ_\@ZN#R
MY>/N\.CI(%-13"XB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,C4*(RP@
M9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(LWE(.'[Z^X@\^K@
MY^#M[B#Q[N[RXN7R\?+B\_[YY>D@Z.WT[O#LX/;HZ"#DZ_\@ZN#RY>/N\.CI
M(%-13"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*(RP@9G5Z>GD*;7-G:60@
M(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("+1[N[A^>7MZ.4B
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`S"B,L(&9U>GIY"FUS9VED
M(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(LCL_R(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B3F\@:6-O;G,@9F]U
M;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO
M;B!I<R!S970N(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,L(&9U>GIY"FUS9VED(").
M;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U>GIY"FUS
M9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`BP?OK[B#SZN#GX.WN
M(.WEZN[P\.7J\NWNY2#G[>#WY>WHY2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED(").;R!N=6UB97(@
M<W!E8VEF:65D+B(*;7-G<W1R("+!^^ON(//JX.?@[>X@[>7J[O#PY>KR[>[E
M(.?MX/?E[>CE+B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"B,L
M(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[V
MY>3S\/L@X//RY>WRZ/3HZN#VZ.@@[^X@4U%,(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:6UA<"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS>7R
M(.W@\?+P[N7J(.3K_R#O\.[VY>3S\/L@X//RY>WRZ/3HZN#VZ.@@[^X@4U%,
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-S(*(RP@9G5Z>GD*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[VY>3S\/L@
MX//RY>WRZ/3HZN#VZ.@@[^X@4U%,(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S
M;"YP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&QI8B](
M;W)D92]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[VY>3S\/L@X//RY>WRZ/3HZN#VZ.@@
M[^X@4U%,(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*(RP@
M9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N
M]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z(&QI8B](;W)D92]!
M=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LWE\B#M
MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N(%-13"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O5D93+G!H<#HW-C8*(RP@9G5Z>GD*;7-G:60@
M(DYO('%U;W1A('-E="XB"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z
M>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C0X,@HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R
M('-P96-I9FEE9"XB"FUS9W-T<B`BPOL@[>4@\^K@Y^#KZ"#OX._JZ"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(L?@[.7RZN@B
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3@W"B,L(&9U>GIY"FUS9VED(").;R!S
M=6-H(&9I;&4B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O
M<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,2!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BS^[FX.OSZ?'RX"P@XN+EY.CR
MY2#"X/CH(.CL_R#O[NO\Y^[BX/+EZ_\@Z"#OX/#NZ_PB"@HC.B!L:6(O2&]R
M9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T
M82!R971U<FYE9"(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-S(@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDX,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3DS"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#$P"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`BS>4@[N_P
MY>3EZ^7M[B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0R-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B+>WE(.+[X?#@[2TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS
M9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@
M(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("+1Y>+E\.WNY2#O[NOS^.#PZ.4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA
M<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0HC+"!F
M=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B
M3F]T($)E9F]R92(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HT,34*(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G
M<W1R("+*X/+@Z^[C(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T
M(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O5D93+G!H<#HQ.3,@;&EB+U9&
M4RYP:'`Z,C`X(&QI8B]61E,N<&AP.C(S-"!L:6(O5D93+G!H<#HR-3(*(SH@
M;&EB+U9&4RYP:'`Z,C8Y(&QI8B]61E,N<&AP.C(X-2!L:6(O5D93+G!H<#HS
M,#$@;&EB+U9&4RYP:'`Z,S$V"B,Z(&QI8B]61E,N<&AP.C,S,R!L:6(O5D93
M+G!H<#HS-C8@;&EB+U9&4RYP:'`Z-#(V(&QI8B]61E,N<&AP.C4P-0HC.B!L
M:6(O5D93+G!H<#HU-S0@;&EB+U9&4RYP:'`Z-3DQ(&QI8B]61E,N<&AP.C8V
M.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T-2!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C$W-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C$X.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C(S-@HC+"!F
M=7IZ>0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWN
MXN[E(/'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(L?@[.7RZN@B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*
M;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$P
M"B,L(&9U>GIY"FUS9VED(").;W1I8V4B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$P-3`*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R("+(
M[/\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R.0HC+"!F=7IZ>0IM<V=I
M9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BR.S_(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(DYU;6)E
M<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(O/A\.#R_"#Q\N[KX>7V
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*(RP@9G5Z>GD*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*(RP@9G5Z>GD*;7-G:60@(DYU
M;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T
M:6]N(&QI<W0N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I
M;G1E;F%N8V5?5&%S:R`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<Q"B,L(&9U>GIY
M"FUS9VED(")/8FIE8W0B"FUS9W-T<B`BTN7LX"(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$Q"B,L(&9U>GIY"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q,#@*(RP@9G5Z>GD*;7-G:60@(D]C=&%L(@IM
M<V=S='(@(L7FY>3MY>+M[B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C@*(RP@9G5Z>GD*;7-G:60@(D]F9FEC92(*
M;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E
M(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS
M9W-T<B`BS^#P[NO\(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*(RP@9G5Z
M>GD*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N(@IM<V=S='(@(L+@^"#A\.[SY^7P(.WE(._NY.3E\.;HXN#E\B#N
M[_;H_B#OY??@\N@N(,3K_R#OY??@\N@@[>#F[.CRY2!#5%),*U`N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-S4*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N
M97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H
M:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G
M<W1R("+-X/'R\.[IZN@B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL
M('!H<"UF;W)M870*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO
M;G,@9F]R("5S(@IM<V=S='(@(LW@\?+P[NGJZ"#DZ_\Z("5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B
M3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-38X"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS
M9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-38Y"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I
M;VYA;"!5;FET(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC
M(&9U>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@
M(D]R9V%N:7II;F<B"FUS9W-T<B`BSO#CX.W@Z>?E\"(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S
M='(@(B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM
M<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`BS_#N]^#_(.CM].[P
M[.#VZ/\B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"B,L(&9U
M>GIY"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("+-X/'R\.[I
MZN@@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW
M.0HC+"!F=7IZ>0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*
M(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,R,@IM
M<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-38*
M;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR
M,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")0
M32!,:6=H="!286EN(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4$T@
M4F%I;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")032!3:&]W
M97)S(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0P"B,L(&9U>GIY"FUS9VED(")032!3;F]W(@IM
M<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(E!-(%-U;B(*;7-G<W1R
M("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B
MR.SO[O#R(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B
M4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED
M(")086MI<W1A;B(*;7-G<W1R("+$X/+@(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@
M(E!A;F%M82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE
M=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B4&%R86=U
M87DB"FUS9W-T<B`B24U0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(E!A<G1L>2!#;&]U9'DB
M"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3@P(&QI8B](;W)D92]&;W)M+G!H<#HR,#(R
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$U,2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T
M<B`BS^#P[NO\(@H*(R!F=7IZ>0HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("+1[N[A^>7MZ.4@\_'OY?CM[B#N\N_PX.+K
MY>WN+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PHC+"!F
M=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(L_@\.[K
M_"(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"B,L(&9U>GIY
M"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@
M\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`U-PHC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`BS_#N]^#_(.CM].[P[.#VZ/\B"@HC(&9U>GIY"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z
M(@IM<V=S='(@(L_@\.[K_"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BS^#P
M[NO\(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#,X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R
M("+"X/@@16UA:6PZ(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*
M(RP@9G5Z>GD*;7-G:60@(E!A<W1E(@IM<V=S='(@(L3@\N`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")0
M87-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"B,L(&9U>GIY"FUS9VED
M(")0871H(@IM<V=S='(@(L3@\N`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.C8*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+.\?/YY?'RXNOE[>CE
M(.[OY?#@]NCI(._NY.3E\.;JZ"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R
M871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+"^^_NZ^WH\OP@[N_E\.#VZ.@@
M[N'QZ_/FZ.+@[>C_(._PZ"#B]>[DY2#B(/'H\?+E[/,_(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T
M<B`BS_#@XN`B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@
M9&5L971E9"XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@
M(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@*#(N,"XR*2D@(",M(RTC
M+2,M(PHC(&9U>GIY"B,@(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@
M*#(N,"XR*2D@(",M(RTC+2,M(PHC(&9U>GIY"B,@(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@
M*#(N,"XR*2D@(",M(RTC+2,M(PHC(&9U>GIY"B,@(RTC+2,M(RTC("!R=5]2
M52YP;R`H36YE;6\@2#,@*#(N,"XR*2D@(",M(RTC+2,M(PHC(&9U>GIY"B,@
M(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@*#(N,"XR*2D@(",M(RTC
M+2,M(PHC(&9U>GIY"B,@(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@
M*#(N,"XR*2D@(",M(RTC+2,M(PHC(&9U>GIY"B,@(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC"B,@(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@
M*#(N,"XR*2D@(",M(RTC+2,M(PHC(&9U>GIY"B,@(RTC+2,M(RTC("!R=5]2
M52YP;R`H36YE;6\@2#,@*#(N,"XR*2D@(",M(RTC+2,M(PHC(&9U>GIY"B,Z
M(&QI8B]61E,O<VUB+G!H<#HU.3`*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I
M;VX@1&5N:65D(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N
M-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0
M($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@*#(N,"XR*2D@(",M(RTC+2,M
M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H36YE;6\@2#,@*#(N,"XR*2D@(",M(RTC+2,M(UQN(@HBR.?L
MY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@
M(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP
M+C,I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A7:'5P<R`Q+C`M8W9S*2`@(RTC+2,M
M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A7:'5P<R`Q+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+-X/'R
M\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A7
M:'5P<R`Q+C`M8W9S*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?N
MXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A7:'5P<R`Q+C`M8W9S
M*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A7:'5P<R`Q+C`M8W9S*2`@(RTC+2,M(RTC
M7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC
M7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P
M[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U
M<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG
M[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N
M,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M
M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HB
MS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@
M[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,RXP+C8I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$UN
M96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@
M(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R
M+C`N,BDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC
M+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*
M(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R
M\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4
M=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\
MY^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R
M+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC
M+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(R!F=7IZ>0HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`@
MY.[Q\O/OX"(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA
M=&EO;B(*;7-G<W1R("++Z/?M^^4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS
M9W-T<B`BTN7KY?3N[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M.#`*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED
M(")0:71C86ER;B(*;7-G<W1R("+$X/+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C4V-@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BPN#X($5M86EL.B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R
M"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.B(*;7-G<W1R("+"XN7DZ/+E(.W@Y^+@[>CE(.WNXN[I(.K@\N7C[O#H
MZ#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-0HC+"!F=7IZ>0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
MPN#X($5M86EL.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0W"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R
M(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0U,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`BS^[FX.OS
MZ?'RX"P@\>[NX?GH\N4@\?/R_"#O\.[AZ^7L^RXB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(L_NYN#K\^GQ\N`L(.+BY>3H\N4@PN#XZ"#H[/\@
M[^[K_.?NXN#RY>O_(.@@[^#P[NO\(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V%G<F5E;65N=%]T;W`N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4
M(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&]L86YD(@IM
M<V=S='(@(LKN[._@[>C_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0X.0HC+"!F=7IZ>0IM<V=I9"`B4&]L;',B"FUS9W-T<B`BT>+E\.WS\OP@
MXO'E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*
M;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I
M9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(T"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R93H@(@IM<V=S
M='(@(L_@\.[K_"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(S"B,L(&9U>GIY"FUS9VED(")0<F5V:65W(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@
M(RTC+2,M(RTC7&XB"B+-X.?@Y"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,@9G5Z
M>GD*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-38@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T
M<B`BS_#EY/OD\_G@_R#Q\O#@[>CVX"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM
M<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O
M2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(L_P
M[N'KY>S@/R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B
M4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("+.[^CQX.WHY2#O\.[AZ^7L
M^R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R
M;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$U
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3DR(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C@S"B,L(&9U>GIY"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("+"^_7N
MY"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B
M;&EC($ME>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*(RP@9G5Z>GD*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("+"X/CE(._NZ^WNY2#H
M[/\Z(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R("))35`B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!F=7IZ>0IM<V=I
M9"`B475O=&$B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(V.`HC+"!F=7IZ>0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N
M(@IM<V=S='(@(L_NZ^WNY2#N[^CQX.WHY2#O\.[AZ^7L^SHB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`HC+"!F=7IZ>0IM
M<V=I9"`B4F%I;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"B,L(&9U>GIY"FUS9VED(")2
M86EN($5A<FQY(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!,
M871E(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B!3:&]W97(B
M"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")286EN(&%N9"!3;F]W(@IM
M<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S
M='(@(L+U[N0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@HC+"!F=7IZ>0IM
M<V=I9"`B4F%T:6\B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(R!F=7IZ>0HC.B!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G
M<W1R("+7Z/+@\OPB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
MT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"B,L(&9U>GIY"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*
M;7-G<W1R("+.X>WNXNCR_"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G
M<W1R("+.X>WNXNO_\OP@Y.CMX.SH]^7QZNCE(._S[>KR^R#LY>W^.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R
M=&%L(%9I97<Z(@IM<V=S='(@(L[A[>[BZ__R_"#H[?3N\.S@]NC^.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*(RP@9G5Z>GD*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(M'A\.[QZ/+\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R,S@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*
M;7-G<W1R("+/\.[WZ/+@[>W[Y2(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B
MS^[W\N[B^^4@\>7PXN7PX"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ(@IM<V=S='(@(L#D\.7Q(/'E\.+E\.`@*.W@[_#H[.7P
M(&AT='`Z+R]M86EL+G)U*2(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`BT^3@Z^CR_"(*"B,@
M9G5Z>GD*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED
M(")296UO=F4@0FQO8VLB"FUS9W-T<B`BT^3@Z^CR_"#AZ^[J(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+SX?#@\OP@
M\?+NZ^'E]B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM
M<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+3Y.#KZ/+\
M(._@\/,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@=&AE(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I
M9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L
M(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("+3Y.#KZ/+\(._@
M\/,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G
M<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP
M:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")297%U97-T
M960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(L#D\.7Q
MX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,3<V(&QI8B](;W)D92YP:'`Z-3$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-Y>[A]>[DZ.S[Z2#OX/#@[.7R\"`G
M=6ED)R#MY2#SZN#GX.T@XB#J[NWTZ./S\.#VZ.@@[>#Q\O#NY>HN(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C8W."!L:6(O5D93+V9T<"YP:'`Z.#8Q(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(LWE[N'U[N3H[/OI(._@\.#LY?+P("=U:60G
M(.WE(//JX.?@[2#B(.KN[?3HX_/PX/;HZ"#MX/'R\.[EZBXB"@HC.B!L:6(O
M2&]R9&4O571I;"YP:'`Z-S<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("+-Y>[A]>[DZ.S[Z2#OX/#@[.7R\"`G=6ED)R#MY2#S
MZN#GX.T@XB#J[NWTZ./S\.#VZ.@@[>#Q\O#NY>HN(@H*(SH@;&EB+TAO<F1E
M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,T,R!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
MT>'P[O'H\OPB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S
M=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M
M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS
M9W-T<B`BPN7P[?/R_/'_(.H@[>#Q\O#NZ>K@["(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED
M(")2975N:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+3Y.#KY>WM^^4B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(LW@\?+P[NGJZ"#BZ.?S
MX.O\[>[C[B#PY>3@ZO+N\.`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT
M(@IM<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q
M,`HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(L_PZ.SE
M\"#G[>#WY>WHZ3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-@HC+"!F
M=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(L_PZ.SE\"#G[>#W
MY>WHZ3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM
M<V=S='(@(M'VY>W@\.CI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B4F]M86YI82(*
M;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(T"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@,3@P(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@
M(RTC+2,M(RTC7&XB"B+OY?#E[.7Q\NCR_"#BXN7P]2(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@
M(E)O=&%T92!,969T(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+OY?#E[.7Q\NCR_"#BXN7P
M]2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C<*
M(RP@9G5Z>GD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
M[^7PY>SE\?+H\OP@XN+E\/4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"B,L(&9U>GIY"FUS9VED(")2;W<@
M4')O<&5R=&EE<R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S`*(RP@9G5Z>GD*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(LKK
MY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#$*(RP@9G5Z>GD*;7-G:60@(E)O=W,Z(@IM
M<V=S='(@(LK@Z^7MY.#P_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S
M(@IM<V=S='(@(M'VY>W@\.CI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*
M;7-G:60@(E)W86YD82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R
M87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,S(S"B,L(&9U>GIY"FUS9VED(")3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4B"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-
M86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP
M:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[E
MZBXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"B,L(&9U>GIY
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(L[R[_#@XNCR_"#Q[N[A
M^>7MZ.4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(X,0IM
M<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")3
M4T@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R
M("(B"@HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M
M(RTC"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B4V$B"FUS9W-T<B`B(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M'N
M]?#@[>CR_"#JX.I<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q
M+C$I("`C+2,M(RTC+2-<;B(*(M'N]?#@[>CR_"(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT
M($AE;&5N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.
M979I<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E-A:6YT($QU8VEA
M(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI
M<75E;&]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@
M*%]S96QF*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"B,L(&9U>GIY"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(L+MZ.S@
M[>CE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T
M96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R!F=7IZ>0HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`BT>[U
M\.#MZ/+\(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS
M9W-T<B`BT>[U\.#MZ/+\(.W@\?+P[NGJZ"(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E("5S(@IM<V=S='(@(M'N]?#@[>CR_"#MX/'R\.[IZN@B"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`BT>[U\.#MZ/+\(.W@\?+P[NGJZ"(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(LWE
M(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U
M>GIY"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`BR.SO[O#R
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G
M<W1R("+/[NCQZB(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R,@HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($5N
M9VEN97,B"FUS9W-T<B`BS^[H\>HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDV,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(L+[
MX>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.3@\OLZ(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@Y.#R
M^SHB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`BPOOAY?#H\N4@
M].[P[.#R(.3@\OLZ(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("+"
M^^'E\.CRY2#QY?#BY?`B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS
M9W-T<B`BPOOAY?#H\N4@].[P[.#R(.3@\OLZ(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-`IM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R("+"^^'PX/+\(.+QY2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C4P"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RXB"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.3@\OLZ(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,0HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@
MY.#R^SHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<U"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("+.\NSE[>CR_"#B^^'N
M\"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(L+[X>7PZ/+E
M(.WSYNW[Y2#"X.P@\>CLXN[K^R#HYR#T[O#L(.+MZ.?S+B#'X/+E["#"^R#L
M[N;E\N4@\>KN[^CP[N+@\OP@Z"`B"B+B\?+@XNCR_"#H]2#B(/+EZO'R+B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+"^^'E\.CRY2#PX.?DY>OH
M\N7K_"#O[NOEZ2#DX/+[.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+"
M^^'E\.CRY2#T[O#LX/(@Y.#R^SHB"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y
M('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`BPOOAY?#H\N4@[_#N].CK
M_"#DZ_\@[>#Q\O#NZ>KH.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.B(*;7-G<W1R("+"^^'E\.CRY2#PX.?DY>OH\N7K_"#O[NOEZ2#DX/+[.B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@
M=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("+"^^'E\.CRY2#N\N[A\.#FY>WH
M_R#T[O#LX/(@XO#E[.7MZ#HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS
M9W-T<B`BPOOAY?#H\N4@Y.+@(/'NXN_@Y.#^^>CU(._NZ_\N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+B(*;7-G<W1R("+"X/C@(/;BY?+NXN#_(/'UY>S@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("+?Y_OJ(.[R[N'PX.;E[>C_
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@
M(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BS^[QZ^#R_"#Q[N[A^>7M
MZ.4@[B#O\.[AZ^7LY2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#0P"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<S"B,L(&9U>GIY"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`BQ^#LY?+JZ"(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@HC+"!F=7IZ>0IM<V=I
M9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("+([/\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"B,L(&9U>GIY"FUS9VED(")397)V97(@
M9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q
M\O/O[?OU(.W@\?+P[N7J+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC
M+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N
M-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC
M+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE
M[>CR_"#O\.#BX"#D[O'R\^_@(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@240@97AP
M:7)E9"XB"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@;&EB+V%P:2YP:'`Z,30U
M"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R("+'X.SE[>CR_"#M
MX"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S$X"B,L(&9U>GIY"FUS9VED
M(")3970B"FUS9W-T<B`BTN7LX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HBQ.[O[NOMZ/+EZ_SM^^4@[^[W
M\N[B^^4@\>7PXN7PX"P@ZB#J[O+N\/OL(.+[(/7N\NCRY2#H[.7R_"#D[O'R
M\^\@Z.<@S^[P\N#KX"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*
M;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`BT_'RX.WNXNK@(/_G^^K@(.+[
MXN[DX"P@XO#E[.7M[>[I(.?N[?L@Z"#T[O#LX/+@(.[R[N'PX.;E[>C_(.+P
MY>SE[>@N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B
M(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO
M;G,N(@IM<V=S='(@(B(*(M/Q\N#M[N+JX"#O\.CK[N;E[>C_(._N(//L[NOW
MX.WH_BP@]N+E\N[B[ND@\?7E[/L@Z"#O\.[WZ/4@[N_VZ.D@[O+NX?#@YN7M
MZ/\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U
M<"(*;7-G<W1R("+/\.CK[N;E[>C_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,S<*(RP@9G5Z>GD*;7-G:60@(E-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\
M(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@<G5?
M4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`HC+"!F=7IZ>0IM<V=I9"`B4VAO<'!I
M;F<B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2-<;B(*(M'N]?#@[>CR_"#JX.I<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(M'N]?#@[>CR
M_"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BRO#@\NKNY2#NX>[A
M^>7MZ.4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M(@IM<V=S='(@(L[O\.7DY>OH\OP@X?OQ\O#[Y2#JZ^#BZ/CH(.3K_R#Q\?OK
M[NH_(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M.0IM<V=I9"`B4VAO=R(*;7-G<W1R("+/[NK@Y^#R_"(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("+/[NK@Y_OBX/+\(.CM].[P[.#V
MZ/X@[B#O\.7D^^3S^>7L(.+U[N3E/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-S8Y"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`R"B,L(&9U>GIY
M"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("+([._N\/(B"@HC(&9U>GIY
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BS^[JX.?@\OP@[.7M
M_B#N[^7PX/;HZ2#Q(/+@X>OH]N#LZ"(*"B,@<&AP+69O<FUA=`HC(&9U>GIY
M+"!P:'`M9F]R;6%T"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\B"FUS9W-T<B`BSO+NX?#@YN#R_"#LY>W^("5S(/'KY>+@/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C`*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!U
M<&QO860B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,B"FUS
M9W-T<B`BR.SO[O#R(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!%
M87)L>2(*;7-G<W1R("+*\.#RZN[E(.[A[N'YY>WHY3HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PHC+"!F=7IZ>0IM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S
M(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C0X,"!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(M'S
MY^CR_"(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<W-"!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z.3(R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDX
M-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3D@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,3(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I>F4B
M"FUS9W-T<B`BT.#G[.7P(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?8F]T=&]M+FEN8SHY"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM
M<V=S='(@(L_P[N_S\?+H\OP@[^[DY.7PYNKS(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*(RP@
M9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*(RP@9G5Z>GD*;7-G
M:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"B,L(&9U>GIY"FUS9VED
M(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`BR.SO[O#R(@H*(R!F=7IZ>0HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`HC+"!F=7IZ
M>0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(LKPX/+J[N4@
M[N'NX?GE[>CE.B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R
M<R!,871E(@IM<V=S='(@(LKPX/+J[N4@[N'NX?GE[>CE.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED
M(")3;VUA;&EA(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.3$U"B,L(&9U>GIY"FUS9VED(")3;W)T(&]R9&5R('-E;&5C
M=&EO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C$W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W
M"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-C8@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E
M<W,B"FUS9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F
M<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM
M<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(M[F[>[E(._NZ_/XX/#HY2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS
M9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$Y
M"B,L(&9U>GIY"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M'N]?#@[>CR
M_"#JX.I<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C
M+2,M(RTC+2-<;B(*(M'N]?#@[>CR_"(*"B,@(RTC+2,M(RTC("!R=5]252YP
M;R`H24U0('8S+C$I("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(RP@9G5Z>GD*
M;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M'N]?#@[>CR_"#JX.I<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<
M;B(*(M'N]?#@[>CR_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P86EN(@IM<V=S='(@
M(L+MZ.S@[>CE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`HC
M+"!F=7IZ>0IM<V=I9"`B4W!A;2(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T
M97(@26YP=70B"FUS9W-T<B`BT>_E]NC@Z_SM^^4@\>CLXN[K^R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*
M(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB
MY.[AX.+H\OP@\?+NZ^'E]B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*(RP@9G5Z>GD*;7-G:60@(E-P;&ET
M(&-O;'5M;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4
M=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+D[N'@XNCR_"#Q\N[KX>7V(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,0HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<
M;B(*(N3NX>#BZ/+\(/'R[NOAY?8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(E-R:2!,
M86YK82(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8V"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("+*
MX.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C<Y.`HC+"!F=7IZ>0IM<V=I9"`B4W1A<G0@>65A<B(*
M;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*
M(R!F=7IZ>0HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ
M,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(M'RX/+S\2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#`T"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA
M="(*;7-G<W1R("+"X/C@(.CM].[P[.#VZ/\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W,PHC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E
M<W,B"FUS9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U
M9V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S<*;7-G
M:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N
M[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+2Y>S@
M(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,V(&QI8B](;W)D
M92]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R
M("+(\>K@\OPB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U
M97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*(RP@
M9G5Z>GD*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("+(\>K@\OPB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3`T(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R
M("+3\>_E^.WN(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(.'[Z^`@\_'OY?CM
M[B#OY?#EZ.SE[>[BX.W@(.(@7"(E<UPB+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA
M=`HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`BQ^#LY?+JX"`G)7,G(//Q[^7X
M[>X@\>[U\.#MY>W@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@
M[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E
M<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RXB"FUS9W-T<B`BT?+@\.#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@XB#T
MX.GK.B`E<R(*"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O
M<FUA=`HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R
M("+'X.SE\NK@("<E<R<@\_'OY?CM[B#Q[O7PX.WE[>`B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`BS>[BX/\@ZN[M].CC\_#@]NC_(/'N]?#@[>7MX"#B.B`E<R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*
M(RP@9G5Z>GD*;7-G:60@(E-U9&%N(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-@HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+#Z^#B[>#_(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")3
M=6X@4FES92(*;7-G<W1R("+([/\@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"B,L(&9U>GIY"FUS9VED(")3=6X@4V5T(@IM
M<V=S='(@(M+E[.`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,`IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0HC+"!F=7IZ>0IM<V=I9"`B4W5N
M<FES92(*;7-G<W1R("+([/\@[^[K_.?NXN#RY>O_(@H*(R!F=7IZ>0HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(L+PY>S_(.+N\?7N
MY.`OY^#JX/+@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-`HC+"!F=7IZ>0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(LCL_R#O[NO\
MY^[BX/+EZ_\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X
M"B,L(&9U>GIY"FUS9VED(")3=6YS970B"FUS9W-T<B`BTN7LX"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*(RP@9G5Z>GD*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(M+E[.`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$S"B,L(&9U>GIY"FUS9VED(")3=7!E
M<G-C<FEP="(*;7-G<W1R("+/[NOM[N4@[N_H\>#MZ.4Z(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,X,`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R
M="(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M
M92(*;7-G<W1R("+([/\@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S4*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS
M9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N
M9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B4W=A
M>FEL86YD(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B
M4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("+/[NK@Y^#R_"#SY.#KY>WM^^4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*
M;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC(&9U>GIY
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"B,L
M(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("+*\.#RZN[E
M(.[A[N'YY>WHY3HB"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@HC
M+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*
M(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@
M(E1A8FQE(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G
M:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN
M\>+_Y_PB"@HC.B!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(L?@X^[K[N+N
MZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS
M9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0HC+"!F
M=7IZ>0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED
M(")486II:VES=&%N(@IM<V=S='(@(L3@\N`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*(RP@9G5Z>GD*;7-G
M:60@(E1A<F=E=#HB"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y
M"FUS9VED(")487-K<R(*;7-G<W1R("+'X.3@]^@B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B5&5L97!H;VYE
M($YU;6)E<B(*;7-G<W1R("+([/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C8Y-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E
M<R#MY2#MX.GDY>TN(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G
M:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HS,S,T
M"B,L(&9U>GIY"FUS9VED(")497AT(@IM<V=S='(@(L3@Z^7E(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N
M;'DB"FUS9W-T<B`BTN[K_.KN(/+EZO'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I
M9"`B5&5X="!A;&EG;B(*;7-G<W1R("+1Z^7D\_[YY?\@\?+PX.WH]N`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"B,L
M(&9U>GIY"FUS9VED(")497AT=&]P(@IM<V=S='(@(L3@Z^7E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B
M5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G
M:60@(E1H86EL86YD(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C@U,0HC+"!F=7IZ>0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R
M\.[EZBXB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H
M92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+TE-4U`O0F]O
M:RYP:'`Z,3(Y.`HC+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`BS^[D[^CQ_"#MY2#L[N;E
M\B#A^_+\(.?@[.7MY>W@+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD
M;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I
M9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B
M87-E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,38*
M;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,3<W(&QI8B](;W)D92YP:'`Z-3$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S`@;&EB+TAO<F1E+G!H<#HU
M,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HR,C8*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A
M+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I
M9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z-#<T"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(MWR[B#G
M[>#WY>WHY2#D[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@
M:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H
M<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS9VED(")4
M:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O1FEL92]#4U8N
M<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+1Y?#BY?`@)7,@
MX?OK(//DX.OE[2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N('-A=F5D+B(*;7-G<W1R("+1Y?#BY?`@)7,@X?OK(/'NY^3@[2(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-#<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D
M(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+`Y/#E\>#R(//B
MY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE
M[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@
M7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N
M[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S,P.0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C
M:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS
M9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-C(@;&EB+TAO<F1E
M+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P
M[N7J+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@
MZ>3E[2XB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X
M"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S
M='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*(R!F=7IZ>0HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`BT>[NX?GE[>CE(.(@[>7BY?#M[NP@].[P[.#RY2#H(.WE(.SNYN7R(.'[
M\OP@[O+NX?#@YN7M[B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R
M86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA
M<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G
M<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(L_P[N'KY>S@(._PZ"#O\.[Q[.[R\.4@Y^#O\.[XY>WM[N/N(._H\?SL
MX"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F
M;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(L_P[N'KY>S@(._PZ"#O\.[Q[.[R\.4@Y^#O\.[XY>WM[N/N(._H\?SL
MX"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+/\.[AZ^7LX"#O
M\.@@[_#N\>SN\O#E(.?@[_#N^.7M[>[C[B#OZ/'\[.`N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B
MS_#H(//DX.OE[>CH(.?@Y.#WZ"#B[N?MZ.KKZ"#N^.CAZN@N(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E
M<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`BSOCHX>K@
M(._PZ"#N\N[A\.#FY>WHZ"#]\N[I(/?@\?+H(/'N[N'YY>WH_R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G
M<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@
M(RTC+2,M(RTC7&XB"B+.^.CAZN`@[_#H(.CL[^[P\N4@Y.#M[?OU+B(*"B,Z
M(&QI8B](;W)D92]$871A+VEM8RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V
M,2XQ*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@[_#H(.CL[^[P\N4@Y.#M[?OU
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X
M"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R
M;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE
M87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCH
MX>K@(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@
M(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0U(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*
M(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A
M('8Q+C$I("`C+2,M(RTC+2-<;B(*(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM
M^_4N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`BPN#X(.'P[O/GY?`@[>4@
M[^[DY.7PYNCBX.7R(.[O]NC^(._E]^#RZ"X@Q.O_(._E]^#RZ"#MX.;LZ/+E
M($-44DPK4"XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HT
M.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`BW?+N(.?MX/?E[>CE(.3N
MZ^;M[B#A^_+\(/?H\>ON["XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`BW?+N(.?MX/?E
M[>CE(.3NZ^;M[B#A^_+\(/?H\>ON["XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$S-`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(MWR[B#G[>#WY>WH
MY2#D[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC
M;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@
M;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I
M;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDX
M,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`Y,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V,`HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,34V,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@T
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`P.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S,R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U,PHC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0U-`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$R-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S@Q,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@R,`IM<V=I9"`B5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T,C`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDY,PHC+"!F=7IZ>0IM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R
M("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#(U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@
M8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F
M;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE
M;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@
M1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*
M(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`BW?+N(/?H\>ON(.WE(.SN
MYN7R(.'[\OP@[.7M_/CE(.7DZ.WH]OLN(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES
M(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BXB"FUS9W-T<B`BW?+N(.?MX/?E[>CE(.3NZ^;M[B#A^_+\
M(/?H\>ON["XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N
M($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@
M(E1I8VME=',B"FUS9W-T<B`BQ^#O\.[Q^R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#(Y('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG
M(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W
M"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("+4[O#LX/(@[O+NX?#@YN7M
MZ/\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,U"B,L(&9U
M>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("+/[NOM[N4@[N_H
M\>#MZ.4@[_#NX>OE[/LZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(L?@X^[K[N+NZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G
M:60@(E1O(@IM<V=S='(@(LKN[/,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4R"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP
M;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("+7\N[A
M^R#B^^'PX/+\(.WE\>KNZ_SJ[B#]Z^7LY>WR[N(L(//DY?#FZ.+@Z?+E(.W@
MYN#R[ND@ZNO@XNCF\R!#=')L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,P,`HC+"!F=7IZ>0IM<V=I9"`B5&]D87DB"FUS9W-T<B`BRN[L
M\R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"B,L
M(&9U>GIY"FUS9VED(")4;V=O(@IM<V=S='(@(LKN[/,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(LK@
MZ^7MY.#P_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,CD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E1O;F=A(@IM<V=S='(@(LKN
M[/,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S<*(RP@9G5Z>GD*;7-G:60@(E1O<"(*;7-G<W1R("+*[NSS(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM
M<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*
M;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4=7)K;65N:7-T86XB"FUS
M9W-T<B`BS_'EXN3N[>CL(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C
M:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"B,L
M(&9U>GIY"FUS9VED(")59V%N9&$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@HC
M+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R("+([/\B"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C0Q.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H
M[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HS.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E
M\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,SDR(&QI8B]61E,O;75S
M<6PN<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HR,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("+-
MY>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-CDU(&QI8B]61E,O<W%L+G!H<#HQ,#(X(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C@W,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!3
M44P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,S(@;&EB+U9&
M4R]F:6QE+G!H<#HR,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`T"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR
M,3<*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS-S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-C$@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(V-`HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z
M(&QI8B]61E,O;75S<6PN<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7D
MZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M,CDP"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'N
MY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP
M.C<V(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M5D93+W-M8BYP:'`Z,C(X(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M(RTC
M+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C+2,M
M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P
M[NPN7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I("`C
M+2,M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C,I
M("`C+2,M(RTC+2-<;B(*(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@
M\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S@@;&EB+U9&4R]S
M<6PN<&AP.C,Y-2!L:6(O5D93+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,S0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U-B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HS-C`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`BS>7B[N?L
M[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C,T-"!L:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T,R!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS-3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7D
MZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M-#(P(&QI8B]61E,O<W%L+G!H<#HT,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,3`@;&EB+U9&4R]S<6PN<&AP.C(Y
M,2!L:6(O5D93+VUU<W%L+G!H<#HQ-C<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS.3$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDY"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HR-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C0P.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R
M("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HX,S0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(LWEXN[G
M[.[F[>X@\>[U\.#MZ/+\(//Q\N#M[N+JZ"#B(/'E\?'HZ"XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X
M=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!L:6(O
M3F5T+TE-4U`N<&AP.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+B(*;7-G<W1R("+-Y>+NY^SNYNWN(.?@X_#SY^CR_"#N[_#E
MY.7KY>WHY2`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,R!L:6(O5D93
M+V9I;&4N<&AP.C(P."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S0*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z.3,@
M;&EB+U9&4R]S;6(N<&AP.C$P-B!L:6(O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI
M8B]61E,O9G1P+G!H<#HY.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,C@T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S."!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("+-Y>+NY^SN
MYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S<@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,
M(/'E\.+E\.[L+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!3
M44P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4RYP:'`Z.#4V"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E
M\.+E\.[L+B(*"B,Z(&QI8B]61E,N<&AP.C@X-PHC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["XB"@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z
M,S@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G
M<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C<V"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,3`T"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A
M;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS,#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q
M(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S,R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_
M(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB
M+U9&4R]F='`N<&AP.C,T.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HV,3<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,C8@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,@HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*
M;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B
MS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA
M8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B
MW?+N\B#D[NKS[.7M\B!7;W)D(.WE(.SNYN7R(.'[\OP@[^7PY>+EY.7M+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-30@;&EB+U9&4R]F='`N<&AP.C$U-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ
M_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$X-@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q
M(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X."!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["XB"@HC.B!L:6(O5D93+G!H<#HX-C(*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E
M9"XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P"B,L(&9U>GIY"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`BQ^#C
M[NONXN[J(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(L[R[.7MZ/+\(.CG[.7MY>WH_R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*(RP@
M9G5Z>GD*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(M/DX.OH\OP@[^#P\R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BS_/Q\N[I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3
M=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(*;7-G:60@(E5N:71S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R.2!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@
M(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PHC+"!F
M=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3$*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(L_NYN#K\^GQ\N`L(.+BY>3H\N4@PN#XZ"#H
M[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"B,L(&9U>GIY"FUS
M9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC
M7&XB"B+SX?#@\OP@\?+NZ^'E]B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP
M:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(LCL_R#O
M[NO\Y^[BX/+EZ_\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(E5N<V5T(&-O
M;&]R(@IM<V=S='(@(LCQ[^[K_.?NXN#R_"#G[>#WY>WHY2#O[B#S[.[K]^#M
MZ/XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-R!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S
M='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T
M92(*;7-G<W1R("+/\.CLY>WH\OPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&4@)7,B"FUS9W-T<B`BT>[U\.#MZ/+\(.W@\?+P[NGJZ"(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z>GD*;7-G
M:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(L3NX>#BZ/+\(._@\/,B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(M'N]?#@[>CR
M_"#MX/'R\.[IZN@B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM
M<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")5<&QO860B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2-<;B(*(L_P[O?H\N#M[?OE7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@
M(",M(RTC+2,M(UQN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM
M<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM
M<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("+([/\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"B,L
M(&9U>GIY"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`BTN7J
M\_GEY2#B\.7L_R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@HBR/'O
M[NO\Y_/E\O'_(.7QZ^@@XN#XZ"#H[/\O[^#P[NO\(.3K_R!)35-0(/'E\.+E
M\.`@[O+KZ/?@_O+Q_R#N\B#RY>KS^>CU(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S
M='(@(L_NZ_SG[N+@\N7K_"(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z
M-S<T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO
M<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR
M,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N
M<R(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@<VEG;G5P
M+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS
M9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-CD*(RP@9G5Z>GD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`BSO+LY>WH\OP@Z.?LY>WE[>C_(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3@@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$U
M,`HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,R!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("+([/\@[^[K
M_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`BS^#OZN`@7"(E<UPB(//FY2#Q\_GE
M\?+B\^7R(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+([/\@[^[K_.?NXN#R
MY>O_(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5
M<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"B,L(&9U>GIY"FUS
M9VED(")5>F)E:VES=&%N(@IM<V=S='(@(L3@\N`B"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP.C(V,@HC+"!F=7IZ>0IM<V=I
M9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BP.3P
MY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$R,`HC+"!F=7IZ>0IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S
M.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO
M=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@V,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#@@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C`*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Y,3<@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E9A;'5E<R(*;7-G<W1R("+'X.SE\NKH
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q.3`*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*(RP@9G5Z>GD*;7-G:60@(E9A<FEA
M8FQE(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM
M<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"B,L(&9U>GIY"FUS9VED(")697)S
M:6]N(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(R.`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM
M<V=S='(@(L+MZ.S@[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC
M86P@86QI9VXB"FUS9W-T<B`BT>OEY//^^>7_(/'R\.#MZ/;@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`HC+"!F=7IZ
M>0IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("+1Z^7D\_[YY?\@
M\?+PX.WH]N`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B
MT>OEY//^^>7_(/'R\.#MZ/;@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E9E<GD@2&EG:"(*
M;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`BR.S_(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G
M:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(@IM<V=S='(@(L_P[O'L[O+P("5S(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M92(*;7-G<W1R("+/[NK@Y^#R_"#BY>$M\?+PX.WH]O,B"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(L_P[O'L[O+P("5S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET
M>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I
M9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A
M;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:'1M;"YP:'`Z,3(Q(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM
M<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM
M<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@
M<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("+"Y>$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X
M"FUS9VED(")7965K;'DB"FUS9W-T<B`BQ>;E[>7DY>O\[>XB"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R("+$[N'P[B#O[N;@Z^[BX/+\+"`E<R(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM
M<V=S='(@(L3NX?#N(._NYN#K[N+@\OP@XB`E<R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("+$
M[N'P[B#O[N;@Z^[BX/+\+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DT"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*
M;7-G<W1R("(B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF
M;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#0Q"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("+7\NX@[O+NX?#@YN#R_"#O
M[O'KY2#B]>[DX"#B(/'H\?+E[/,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#8R"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`BU.#GX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BXB"FUS9W-T<B`BRN#JZ.4@[N_VZ.@@X?/D\_(@Y.[Q
M\O/O[?L@XB#BZ.?SX.O\[>[L(/#EY.#J\N[PY2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*
M;7-G:60@(E=I9'1H(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,30*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G
M<W1R("(B"@HC('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("+8Z/#H[>`@[.7M_B`E<R#Q
MZ^7BX"`HX?/DY?(@[_#H[.7MY>W@(._PZ"#QZ^7D\_[YY>P@XO7NY.4I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*
M;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`HC+"!F=7IZ
M>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"B,L(&9U
M>GIY"FUS9VED(")7:61T:#HB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G
M:60@(E=I;F0B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B5VEN
M9"!%87)L>2(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S$*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G
M<W1R("+"[>CLX.WHY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B
MT.#A[O?HZ2#@Y/#E\2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(M#@X>[WZ.D@
M\N7KY?3N[2(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE+T-3
M5BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O
M9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,3(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@
M)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+NY^SN
MYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y
M=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED
M(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`BP\,B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-30*(RP@9G5Z>GD*;7-G:60@(EE965DB
M"FUS9W-T<B`BP\,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$P.0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS
M9W-T<B`BQ>;EX^[D[>XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"FUS9VED
M(")997,B"FUS9W-T<B`BQ.`B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M86=R965M96YT7V)O='1O;2YI;F,Z-@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP
M:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW.0HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@;&EB+TAO<F1E+T1A
M=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC
M(&9U>GIY"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H
M879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`BPOL@XOOXZ^@@Z.<@\>CQ
M\N7L^RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V-0IM<V=I9"`B(@HB
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN
M=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3DR"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("+"X/@@16UA:6PZ
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U
M(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG
M;G5P<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HT-C(*;7-G:60@
M(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B
M66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@
M<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*(L+[(.3NZ^;M
M^R#N[^CQX/+\(._P[N'KY>S[+"#O\.7FY.4@]^7L(/'L[N;E\N4@[O+N\>O@
M\OP@\>[NX?GE[>CE(.X@[>7I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*
M;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H
M;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("+"X/C@("5S
M(/'E\?'H_R#GX.KN[??HZ^#Q_"X@S^[FX.OSZ?'RX"P@XN[IY.CRY2#B(/'H
M\?+E[/,@Y^#M[N+N+B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G
M<W1R("+"X/@@16UA:6PZ(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(L+@^"#@Y/#E\2#N\N_PX.+H\N7K_SHB"@HC(&9U>GIY"B,@9G5Z>GD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(L+@^.`@Z.WT[O#LX/;H_R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`BPN#XY2#H[/\Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@
M>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z-34*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`BPN#X(.'P[O/GY?`@
M[>4@[^[DY.7PYNCBX.7R(.[O]NC^(._E]^#RZ"X@Q.O_(._E]^#RZ"#MX.;L
MZ/+E($-44DPK4"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ
M<SHT,@HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M
M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(L+@^"#A\.[SY^7P(.WE
M(._NY.3E\.;HXN#E\B#N[_;H_B#OY??@\N@N(,3K_R#OY??@\N@@[>#F[.CR
MY2!#5%),*U`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I
M9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`BU^#Q[N+NZ2#O
M[O_Q(@H*(R!F=7IZ>0HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA
M;F=E9"XB"FUS9W-T<B`BPN#X(._P[O3HZ_P@[^X@\^SNZ_?@[>C^.B(*"B,@
M9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("+"X/@@[_#N].CK_"#O[B#S
M[.[K]^#MZ/XZ(@H*(R!F=7IZ>0HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("+"
MX/CE(.CL_SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DY"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("+"X/CH
M(.W@\?+P[NGJZ"#A^^OH(.[A[>[BZ^7M^RXB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN(@IM<V=S='(@(L+@^.@@[>#Q\O#NZ>KH(.'[Z^@@[N'M
M[N+KY>W[+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED
M(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(L+@
M^.@@[>#Q\O#NZ>KH(.'[Z^@@[N'M[N+KY>W[+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS
M9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("+1\N[P[NWMZ.D@
M\>7PXN7P.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ
M>0IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R
M"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB
M"FUS9W-T<B`B6]'N[N'YY>WHY2#N(._P[N'KY>SE72(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(");
M;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6_'R\.[JX"`E<R#HYR`E<UTB"@HC
M(&9U>GIY"B,Z(&QI8B](;W)D92YP:'`Z,34T-2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MT^_PX.+KY>WHY2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*(RP@9G5Z>GD*;7-G:60@
M(E]$871A5')E92(*;7-G<W1R("+$X/+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS
M9VED(")?1&5L971E(%)O=R(*;7-G<W1R("+3Y.#KZ/+\(@H*(R!F=7IZ>0HC
M.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`BP_#S
M[^_[(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED
M(")?2&5L<"(*;7-G<W1R("+/[NSN^?PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*(RP@9G5Z>GD*;7-G
M:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(LKKY?+N]^W@_R#P
MX.3H[O'B_^?\(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ
M>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("+"]>[D(@H*(R!F=7IZ>0HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R
M("+"^_7NY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B7TUO9&EF>2!,:6YK
M+BXN(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,@9G5Z>GD*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`BS>#Q
M\O#NZ>KH(@H*(R!F=7IZ>0HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]0
M97)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM
M<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*
M"B,@9G5Z>GD*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS
M9W-T<B`BS_#HZ^[FY>WH_R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B7U1A
M8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_
MY_PB"@HC(&9U>GIY"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S
M(@IM<V=S='(@(L_NZ_SG[N+@\N7KZ"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3(P"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B
MP.3PY?'MX/\@ZNWHX^`B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S
M='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,3(*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(LK@Z^7MY.#P
M_"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N
M(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI
M;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM
M<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A
M=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R("+/
M\.#BZ/+\(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3@R"B,L
M(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`BSO+LY>WH
M\OP@Z.?LY>WE[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S(*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.C@X,0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*
M;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Y"B,L(&9U>GIY"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(EOQ
M\O#NZN`@)7,@Z.<@)7-=(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(T.`IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U-PIM<V=I9"`B:&@B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,X"FUS
M9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"B,L(&9U>GIY"FUS9VED(")L:6YE<UTB"FUS9W-T<B`BQ^#C[NONXN[J(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-C@*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,0HC
M+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R
M9&4O4E!#+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(FYO="!I;7!L96UE;G1E
M9"(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N
M,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"B,L(&9U>GIY"FUS9VED(")N;W0@
M>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7M
MZ.4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP-`HC+"!F=7IZ>0IM<V=I
M9"`B;F]T97!A9"(*;7-G<W1R("+'X.SE\NKH(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R
M8V5N="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N
M-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?N
MXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS
M*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC
M+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P
M:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S0*(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R("+"[>CLX.WHY2(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T,@HC+"!F=7IZ>0IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("+-Y?(@Y.[Q\O/O
M[?OU(.W@\?+P[N7J+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q
M"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ
M>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U,`HC+"!F=7IZ>0IM<V=I9"`B<WES
M=&5M(&5R<F]R(@IM<V=S='(@(N[P].[C\.#TZ/?E\>K@_R#N^.CAZN`B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR.`IM<V=I9"`B=&%S:R!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V-@HC
M+"!F=7IZ>0IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`BS^[H
M\>HB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(W,`HC+"!F=7IZ>0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@
M='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("+/\.[WX/\@Z.WT[O#LX/;H_R(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`B\N7J\?(@\>[NX?GE[>C_(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC
M+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,`IM<V=I9"`B
M=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M;R]G;%]%4RYP;P``````````````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P-C$S-3,P`#$P-3$U-#,Q,#8S`#`Q-C,V-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C($AO<F1E(#(N
M,BXT($=A;&EC:6%N('1R86YS;&%T:6]N+@HC"B,@5F5R<VEO;B!I;FEC:6%L
M(&1E.@HC"B,@4F%F865L(%9A<F5L82`\<F%F865L+G9A<F5L84!U<V,N97,^
M"B,@1W5I;&QE<FUO($UE;F1E>B`\9W5I;&QE0'5S8RYE<SX*(R!397)V:6-I
M;R!D92!A=&5N8VEO;B!A('5S=6%R:6]S(&4@<VES=&5M87,*(R!5;FEV97)S
M:61A9&4@9&4@4V%N=&EA9V\@9&4@0V]M<&]S=&5L80HC"B,@4F5V:7-A9&$@
M>2!C;W)R96=I9&$@<&]R.@HC(`HC(%-E<G9I8VEO(&1E(&YO<FUA;&EZ86-I
M;VX@;&EN9W5I<W1I8V$@/'-N;'5S8T!U<V,N97,^"B,@56YI=F5R<VED861E
M(&1E(%-A;G1I86=O(&1E($-O;7!O<W1E;&$*(PIM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,BXQ7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,RTP."TQ.2`Q,SHS-4=-5"LQ7&XB"B),87-T+51R
M86YS;&%T;W(Z(%-E<G9I8VEO(&1E($YO<FUA;&EZ86-I;VX@3&EN9W5I<W1I
M8V$@/'-N;'5S8T!U<V,N97,^7&XB"B),86YG=6%G92U496%M.B!'86QE9V]<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@HB6"U'96YE<F%T;W(Z($M"86)E;"`P+CDN
M-5QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI
M;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS
M9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G
M:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@
M=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G
M:7-T<GDN(@IM<V=S='(@(B<E<R<@;F]N(&5S=.$@8V]N9FEG=7)A9&\@;F\@
M<F5X:7-T<F\@9&4@2&]R9&4N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP
M:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO
M="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W
M;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O
M<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(D]P97)A
M8VGS;G,@9&4@;6%N=&5M96YT;R`E<R`M($-O;F9I<FUA8VGS;B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM
M<V=S='(@(B(*(DUA<G%U92!N82!C=6%D<NUC=6QA(&$@;W!E<F%C:?-N(&]U
M(&]P97)A8VGS;G,@<75E(&1E<V5X82!E>&5C=71A<B!A9V]R82XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(D-A9&$@-2!M:6YU=&]S(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(EML:?%A("5S(&1E("5S
M72(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R
M(")!>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M3F]T97!A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E
M<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM
M<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@
M:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N
M86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S
M96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P
M"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")!('/Z
M82!I;F9O<FUA8VGS;B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F
M=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B02!S^F$@:6YF
M;W)M86-I\VXB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I
M9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&]R87,B"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z
M>GD*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@
M(CQB/E!R;V1U8VEU<V4@=6X@97)R;R!G<F%V93H@/"]B/B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G
M:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P
M"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!
M32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P
M"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E
M9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O
M;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N
M="!);F9O<FUA=&EO;B(*;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*
M;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM
M<V=S='(@(D5N9&5R97IO(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M
M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL
M9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B
M16YD97)E>F\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U
M<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R
M;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D5N9V%D:7(@=6X@<&%R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*
M;7-G<W1R(")!>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!
M9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%X96YD82!D92!E;F1E
M<F5Z;W,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B
M061D('5S97(B"FUS9W-T<B`B16YG861I<B!U;B!P87(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED
M(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@
M(D5N9&5R97IO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0HC
M+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%X96YD82!D
M92!E;F1E<F5Z;W,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N
M<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@
M(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R(")%
M;F1E<F5Z;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS
M9W-T<B`B06QC=6UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG
M97)I82(*;7-G<W1R(")!;&-U;64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!
M;&-U;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R(")!
M;&-U;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S
M97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO
M9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM
M<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR
M96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N
M871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S
M='(@(D5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC;SHB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D\@=F%L
M;W(@<75E(&5S<&5C:69I8V]U(&YO;B#I(';A;&ED;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(CQB/E!R;V1U8VEU
M<V4@=6X@97)R;R!G<F%V93H@/"]B/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N
M9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS
M-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I
M9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*
M;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P
M<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*
M;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI
M=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E
M;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I
M9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@
M(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G
M:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B
M0V%M<&]S(&1I<W!O\6EB;&5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B
M86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P
M"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B
M0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D
M(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A
M:')A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*
M;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI
M8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG
M:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*
M;7-G<W1R(")!;FEV97)S87)I;R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(").;VX@<V4@871O<&]U(&\@87AE;G1E(&1E(&YO=&EF
M:6-A8VGS;B`E<RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ
M>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM
M<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@
M(D-A;&5N9&%R:6\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0V"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE
M<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<R(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0
M+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B0V%L96YD87)I;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U
M<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B0V%N
M8V5L87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<R(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G
M:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M
M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED
M(")#87!T:6]N(@IM<V=S='(@(D]P8VGS;G,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E
M;&P@4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@;?-B:6PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U
M>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B5&5LZ69O;F\@
M;?-B:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q
M"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E
M;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@
M(E1E;.EF;VYO(&WS8FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*
M;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*
M;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R
M=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L
M(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(E1A<GAE=&$@9&4@=FES:71A
M("AV0V%R9"DB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U>GIY"FUS9VED
M(")#:&%N9V4B"FUS9W-T<B`B1&5S9F%C97(@;W,@8V%M8FEO<R(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W
M;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U
M<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B"FUS9W-T<B`B5&%R
M>&5T82!D92!V:7-I=&$@*'9#87)D*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B0VAI;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4
M<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O
M<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED
M(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y
M-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3F]N('-E(&%T;W!O=2!O(&%X96YT92!D92!N;W1I9FEC86-I
M\VX@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(D-A;&5N9&%R
M:6\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*
M;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I
M9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#
M;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM
M<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E!E8VAA<B!A('AA;F5L82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L
M:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#
M;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED
M(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B
M"FUS9W-T<B`B0V]M<&'Q[6$B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*
M;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V
M"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM
M<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S
M='(@(D-O;7!A\>UA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS
M9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED
M(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N
M9FER;2!087-S=V]R9"(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*
M;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1I9&\@9&4@)R5S)R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#
M;VUP8?'M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B0V%M<&\@:6UP;W)T861O.B`E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM
M<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1F%L;&]U(/,@8V]N
M96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(D9A;&QO=2#S(&-O
M;F5C=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T
M+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(D9A;&QO(/,@86)R:7(@;R!M
M\V1U;&\@9&4@=&%R969A<R!D92!M86YT96UE;G1O("5S(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")&86QL;R#S
M(&%B<FER(&\@;?-D=6QO(&1E('1A<F5F87,@9&4@;6%N=&5M96YT;R`E<R(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1F%L;&]U(/,@
M8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92!N;VX@<V4@8V]N9FEG=7)O=2!C
M;W)R96-T86UE;G1E(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1F%L;&]U(/,@
M8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L
M9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O
M<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS
M9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE
M=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM
M<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N
M=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0
M:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS
M9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R
M<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!5
M4DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS
M9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#
M=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@
M<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B
M0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I
M9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA
M;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C
M:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&EA<FEA
M;65N=&4B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4
M<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G
M:60@(D1A>2(*;7-G<W1R(")$:6%R:6%M96YT92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B
M1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ
M,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B261E;G1I9&%D
M92!P<F5D971E<FUI;F%D82(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(E5S87(@;R!V86QO<B!P;W(@9&5F96-T;R(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U
M;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I9&%D92!P<F5D971E<FUI;F%D
M82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("))9&5N=&ED861E('!R961E=&5R
M;6EN861A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$
M969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B
M1&5L971E($=R;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@
M86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I
M9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R("))9&5N=&ED861E('!R961E=&5R;6EN861A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O
M=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B
M1&5L:79E<GD@=&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$
M96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")$97-C<FEC:?-N(&1O('!R;V)L96UA(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM
M<V=S='(@(D1E<V-R:6-I\VX@8V]M<&QE=&$Z(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E)E>&ES='+A<F]N
M<V4@;W,@9&5T86QL97,@<&%R82!O(&%D;6EN:7-T<F%D;W(N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@
M(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED
M(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED
M(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!C:?-N<R!D92!V:7-U86QI
M>F%C:?-N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S
M='(@(D]P8VGS;G,@9&4@=FES=6%L:7IA8VGS;B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B3W!C:?-N<R!D
M92!V:7-U86QI>F%C:?-N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN
M<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$
M;R!N;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`B3F]N(&%C8V5D82!D:7)E8W1A;65N=&4@
M82!<(FUA:6YT96YA;F-E+G!H<%PB(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I
M9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@
M(D4M36%I;"(*;7-G<W1R(")#;W)R96\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N
M<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B
M161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@
M)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G
M:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B0V]R<F5O(&5L96-T<O-N:6-O(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC
M;SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B3W5T<F$@:6YF;W)M86-I
M\VXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`HC
M+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D]P8VGS;G,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E-E
M;B!R97-U;'1A9&\N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R
M(")396X@<F5S=6QT861O+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`Q-2!M
M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ
M>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D-A9&$@-2!M:6YU
M=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(D-A9&$@,S`@<V5G=6YD;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y
M(#4@;6EN=71E<R(*;7-G<W1R(")#861A(#4@;6EN=71O<R(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V
M97)Y($QO9VEN(@IM<V=S='(@(D-A9&$@:6YI8VEO(&1E('-E<VGS;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@
M:&]U<B(*;7-G<W1R(")#861A(&UE9&EA(&AO<F$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G
M:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")#861A(&UI;G5T;R(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A
M;'5E<SHB"FUS9W-T<B`B17AE;7!L;R!D92!V86QO<F5S.B(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO
M<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%
M>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I
M9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@
M(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")&86QL
M;W4@\R!R96-U<&5R87(@87,@<')E9F5R96YC:6%S+B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED
M;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*
M(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R($Q$
M05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<
M(B5S7"(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R
M($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PHC
M+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+B(*;7-G<W1R(")&86QL;W4@\R!A8G)I<B!A(&-O;F5X:?-N($Q$
M05`@82`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R
M(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(D9A
M;&QO=2#S(')E8W5P97)A<B!O($1.(&1O('5S=6%R:6\Z(%LE9%T@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I
M9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB
M"FUS9W-T<B`B17)R;R!D92!I;7!O<G1A8VGS;CH@(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*
M(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R
M=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM
M<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%0
M5$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R(")4
M[71U;&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC
M+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;64B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT
M($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@
M=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED
M(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&
M;W)T=6YE<R(*;7-G<W1R(").;W1A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B
M1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(DYO;64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L
M:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I
M86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L
M>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC
M+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C
M<FEC:?-N(&-O;7!L971A.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@
M3F%M92(*;7-G<W1R(").;VUE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL
M97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R
M.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC+"!F=7IZ>0IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T
M<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX
M+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G
M:60@(DAE;'`B"FUS9W-T<B`B07AU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D
M:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B07AU9&$B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E
M;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS
M9VED(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G
M:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM
M<V=I9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(D5N9&5R97IO('!A<G1I8W5L87(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@<&%R=&EC
M=6QA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S
M<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS
M9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO
M;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@
M(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(
M=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(D5N9&5R
M97IO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W
M:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E
M(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*
M;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R(")#86UP;R!I;7!O
M<G1A9&\Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S
M='(@(D-A;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@
M(D-A;7!O<R!I;7!O<G1A9&]S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O
M<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(")!8VAE
M9W5E(&\@<V5U(&YO;64@9&4@=7-U87)I;R!E(&-H879E(&1E(&%C8V5S;R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B))
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E
M($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I
M=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PHC+"!F=7IZ>0IM<V=I
M9"`B26YF;W)M871I;VXB"FUS9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"
M969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*
M;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C
M96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL
M(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("))
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B
M26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U
M8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I9"`B26YV86QI9"!P87)T;F5R
M(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@
M;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O
M9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN
M=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F
M=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B1&EA<FEA;65N=&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P
M86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@
M8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M
M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R
M<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*
M;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED
M(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I
M9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN
M9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R
M(")-96YS87AE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@
M(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY
M<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(DQI;F=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI
M8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T
M(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@
M(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM
M<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E!E8VAA<B!A('-E<VGS;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@
M(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B
M3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A
M;'5E<R(*;7-G<W1R(")%>&5M<&QO(&1E('9A;&]R97,Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS
M9W-T<B`B3G5N8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA
M:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT
M96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")%;G1R87(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM
M<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@
M4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N
M;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G
M<W1R(")%;G1R87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS
M9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI
M;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@
M2&5L<"!4;W!I8W,B"FUS9W-T<B`B3&ES=&%R(&]S('1E;6%S(&1E(&%X=61A
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM
M<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1A<B!O<R!T96UA<R!D92!A
M>'5D82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV
M"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS
M"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ-S(@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R(")%;G1R87(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X
M-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")096-H87(@82!S97-I\VXB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO
M9VEN(@IM<V=S='(@(D5N=')A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(E1A
M<F5F87,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@
M(B(*(E!O<B!A;&=U;FAA(')A>O-N(&YO;B!S92!D974@:6YI8VEA9&\@82!S
M97-I\VXN(%!R;V)A8FQE;65N=&4@97-C<FEB:74@(@HB:6YC;W)R96-T86UE
M;G1E(&\@;F]M92!D92!U<W5A<FEO(&]U(&$@8VAA=F4@9&4@86-C97-O+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@
M9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B4&5C
M:&%R(&$@<V5S:?-N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS
M9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@
M(DU31R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM
M<V=S='(@(D-O<G)E;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX
M,0IM<V=I9"`B36%I;"(*;7-G<W1R(")#;W)R96\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")#
M;W)R96\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(D-O
M<G)E;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS
M9W-T<B`B0V]R<F5O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS
M9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B
M36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS
M9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T
M<B`B079I<V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS
M9W-T<B`B0V%M<&]S(&-O<G)E<W!O;F1E;G1E<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO
M=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B
M36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R(")-96UO<F%N9&]S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M365S<V%G92(*;7-G<W1R(")-96YS87AE(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@
M9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365N<V%X
M92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP
M92(*;7-G<W1R(")-96YS87AE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L
M(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R(")297AI<W1RX7)O;G-E(&]S(&1E=&%L;&5S('!A<F$@;R!A
M9&UI;FES=')A9&]R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED
M(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL
M<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A
M;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED
M(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY
M"FUS9VED(")-:61D;&4B"FUS9W-T<B`B0V]R<F5O(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I
M9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R
M;W(B"FUS9W-T<B`B17)R;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@
M(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES
M<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N
M;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E
M<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA
M:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM
M<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-96YS=6%L;65N=&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L
M('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@
M)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L
M96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS
M9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E
M(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E
M;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P
M(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C
M;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*
M(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA
M>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M
M92(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P
M;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G
M:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYU;F-A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").
M97<@0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE
M=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S
M<W=O<F0B"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A
M<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I
M;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G
M<W1R(").;W1A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*
M;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY
M"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B4F5G<F5S87(@X7,@;W!C
M:?-N<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED
M(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R
M86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(DYI9V5R(@IM<V=S='(@(DYU;F-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N
M('!A<F$@82!A=71E;G1I9FEC86-I\VX@<&]R(%-13"XB"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*
M;7-G<W1R(")$97-F86-E<B!O<R!C86UB:6]S(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").;VX@97-P
M96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@87,@8V%T96=O<NUA<R!3
M44PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C
M;VYF:6=U<F%C:?-N('!A<F$@87,@<')E9F5R96YC:6%S($Q$05`N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C
M:?-N('!A<F$@87,@8V%T96=O<NUA<R!344PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RXB"FUS9W-T<B`B3F]N(&5S<&5C:69I8V]U(&$@8V]N9FEG=7)A8VGS
M;B!P87)A(&%S(&-A=&5G;W+M87,@4U%,+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E
M9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S
M='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@
M:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S
M970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM
M<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P
M+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@82!A=71E
M;G1I9FEC86-I\VX@<&]R(%-13"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@82!A=71E;G1I
M9FEC86-I\VX@<&]R(%-13"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B!E<W!E8VEF
M:6-O=2!A(&-O;F9I9W5R86-I\VX@<&%R82!A(&%U=&5N=&EF:6-A8VGS;B!P
M;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N
M9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS
M9W-T<B`B3F]T87,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DYO=&%S
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO
M('-U8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED
M(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B
M06-H96=U92!O('-E=2!N;VUE(&1E('5S=6%R:6\@92!C:&%V92!D92!A8V-E
M<V\B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I
M9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@
M(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*
M;7-G<W1R(")496SI9F]N;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@
M(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B
M3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F
M=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS
M9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G
M:60@(DYO="!S970B"FUS9W-T<B`B3F]T87,B"@HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W
M,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R(").
M;W1A<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I
M9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U
M>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").=6YC82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E
M<B(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*
M;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").
M=6UB97(@;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N
M;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE
M8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")#
M:&%V92!D92!A8V-E<V\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS
M9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES
M=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T
M-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T
M82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U
M"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E
M<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P8VGS
M;G,B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]P=&EO
M;G,@9F]R("5S(@IM<V=S='(@(D]P8VGS;G,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G
M86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS
M9VED(")/=&AE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")/=71R
M82!I;F9O<FUA8VGS;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I
M9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L
M(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W
M,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO
M<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G
M:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@
M4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B
M4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M87!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(D-H879E(&1E(&%C
M8V5S;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I
M9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F
M=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(D-H879E
M(&1E(&%C8V5S;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(D-H879E(&1E
M(&%C8V5S;R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L
M(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(D-H879E(&1E(&%C
M8V5S;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*
M;7-G:60@(E!E;W!L92(*;7-G<W1R(")&=6YC:?-N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R(*;7-G<W1R(")296%L:7IA<B!O<&5R86-I\VYS(&1E(&UA;G1E
M;65N=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"B,L(&9U>GIY
M"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_(@IM<V=S='(@(E)E86QI>F%R(&]P97)A8VGS;G,@9&4@;6%N=&5M96YT
M;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S
M7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I
M;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B
M4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA
M;"!);F9O<FUA=&EO;B(*;7-G<W1R(")/=71R82!I;F9O<FUA8VGS;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED
M(")0:&]N92(*;7-G<W1R(")496SI9F]N;R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B
M4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0
M;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y
M"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M
M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")!8VAE9W5E
M('5N(')E<W5M;R!D;R!P<F]B;&5M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G
M:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M(@IM<V=S='(@(D%C:&5G=64@;R!S974@;F]M92!D92!U<W5A<FEO(&4@8VAA
M=F4@9&4@86-C97-O(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X
M"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO
M=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES
M=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G
M:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H
M<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E
M82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS
M9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@
M(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4F5G<F5S87(@X7,@;W!C:?-N
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+
M97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(");26YF
M;W)M92!D;R!0<F]B;&5M85TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ
M,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I
M8VGS;B!D;R!P<F]B;&5M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0
M<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@
M(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y
M($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D
M:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS
M9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O
M;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
M365N<V%X92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM
M<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$*(RP@9G5Z>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(D%C='5A;&EZ87(@82!V:7-T82!D;R!R97-U;6\Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I
M9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G
M:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM
M<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T
M<B`B4V%C87(@;R!P87(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@
M(E-A8V%R(&\@<&%R(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H
M92(*;7-G<W1R(")386-A<B!O('!A<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")386-A<B!O('!A<B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E-A8V%R
M(&\@<&%R(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*
M;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(D\@8V%M<&\@<F5Q=6ER:61O("=U:60G(&YO;B!F;VD@97-P96-I9FEC861O
M(&YA(&-O;F9I9W5R86-I\VX@9&%S("(*(G!R969E<F5N8VEA<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HB3R!C86UP;R!R97%U:7)I9&\@)W5I9"<@;F]N(&9O:2!E<W!E
M8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS;B!D87,@(@HB<')E9F5R96YC:6%S
M+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3R!C86UP;R!R97%U
M:7)I9&\@)W5I9"<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A
M8VGS;B!D87,@(@HB<')E9F5R96YC:6%S+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")#
M:&%V92!D92!A8V-E<V\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@
M475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D
M;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G
M:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED
M(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")296=R97-A<B#A<R!O<&-I
M\VYS(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED
M(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,B"FUS9W-T<B`B4F5G<F5S87(@X7,@;W!C:?-N<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W
M"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED
M(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*
M;7-G<W1R(")&=6YC:?-N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G
M:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I
M9"`B4G5L97,B"FUS9W-T<B`B1G5N8VGS;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G
M:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I
M9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B
M4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-96YS87AE(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L
M9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I
M;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A
M=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")'87)D
M87(@87,@;W!C:?-N<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*
M;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")'87)D87(@87,@;W!C:?-N
M<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N
M8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@
M(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*
M;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D871A.B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B
M4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")396QE8V-I;VYE
M(&\@9F]R;6%T;R!D82!D871A.B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4V5L96-C:6]N92!O<R!C
M87)A8W1E<F5S('%U92!N96-E<VET92!D87,@8W5A9'+M8W5L87,@<75E(&%T
M;W!A<N$@;6%I<R`B"B)A8F%I>&\N(%!O9&4@8V]P:6%L;W,@92!P96=A;&]S
M(&1E;F1E(&$@X7)E82!D92!T97AT;RXB"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB
M"FUS9W-T<B`B4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A(&1A=&$Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!F;W)M871O
M(&1A(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&$@9&%T
M83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O
M<FUA=&\@9&$@:&]R83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B4V5L96-C:6]N92!D;W5S(&-A;7!O<R!Q=64@8V]I;F-I9&%N+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R
M(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E.B(*;7-G<W1R(")396QE8V-I;VYE(&$@;&EN9W5A.B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(D5N=FEA<B!O(&EN9F]R;64@9&4@<')O8FQE
M;6%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")3
M97!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO
M;G,B"FUS9W-T<B`B1V%R9&%R(&%S(&]P8VGS;G,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@
M(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@HB17-T86)L96-E(&$@9G)E8W5E;F-I
M82!D92!A8W1U86QI>F%C:?-N(&1A<R!PX7AI;F%S(&4@;W5T<F%S(&]P8VGS
M;G,@9&4@(@HB=FES=6%L:7IA8VGS;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)%<W1A
M8FQE8V4@82!F<F5C=65N8VEA(&1E(&%C='5A;&EZ86-I\VX@9&%S('#A>&EN
M87,@92!O=71R87,@;W!C:?-N<R!D92`B"B)V:7-U86QI>F%C:?-N+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W
M"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G
M:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H
M96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T
M(%-U;6UA<GDB"FUS9W-T<B`B4F5S=6UO(&)R979E.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED
M("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@
M(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS
M9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P
M"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W
M97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW
M-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R
M92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@
M36%I;G1E;F%N8V4B"FUS9W-T<B`B3VUI=&ER(&\@;6%N=&5M96YT;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B
M4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E
M<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*
M;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0
M;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R
M(")%;F1E<F5Z;R!D;R!T<F%B86QL;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM
M<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G
M:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B
M4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B16YT<F%D82!D92!C
M87)A8W1E<F5S(&5S<&5C:6%I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*
M;7-G<W1R("));7!O<G1A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA
M;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3
M=&%N9&%R9"(*;7-G<W1R(")#86QE;F1A<FEO(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*(RP@9G5Z>GD*
M;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D$@<_IA(&EN9F]R;6%C
M:?-N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*
M(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D5N9&5R
M97IO(&1O('1R86)A;&QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3
M=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;VX@<V4@871O<&]U
M(&\@87AE;G1E(&1E(&YO=&EF:6-A8VGS;B`E<RXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U
M8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@
M(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I
M9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R
M(")#;W)R96-T86UE;G1E(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T
M960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D
M(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C
M:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(E)E<W5M;R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I
M9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@
M(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3
M=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<X"B,L(&9U>GIY"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(DEM
M<&]R=&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA
M;64B"FUS9W-T<B`B57-U87)I;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S
M='(@(E5S=6%R:6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A
M;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M=V5D96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L
M86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G
M:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@
M86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM
M<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I
M;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE
M+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E3M='5L
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM
M<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE
M('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G
M970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS
M9W-T<B`B5&%R969A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B
M5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U
M"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X
M="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*
M;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO
M=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1FEN86QI>F]U(&$@
M<V5S:?-N+CQB<B`O/D=R86-I87,@<&]R('5S87(@;R!S:7-T96UA+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10
M(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO
M9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS
M9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@
M(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O
M('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE
M(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I
M9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE
M(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T
M:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D
M(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T
M;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@
M(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N
M97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA
M<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS
M9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP
M;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD
M<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(D\@=F%L;W(@9&5B92!S97(@
M=6X@;OIM97)O+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B
M5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS
M9W-T<B`B3F]N(&AA:2!P<F5F97)E;F-I87,@9&ES<&_Q:6)L97,N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4
M:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB
M"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D
M9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*
M(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT
M.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM
M<V=S='(@(D\@=F%L;W(@9&5B92!S97(@=6X@;OIM97)O+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED
M(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")/('9A;&]R(&1E8F4@
M<V5R('5N(&[Z;65R;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G
M(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI
M;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B
M:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M
M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U
M<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI
M96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N
M=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D\@;OIM97)O
M(&1E8F4@<V5R('!O;&\@;65N;W,@=6X@,2XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X
M.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G
M<W1R(")/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RXB"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T
M<B`B5.UT=6QO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM
M<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G
M:60@(E1I=&QE(@IM<V=S='(@(E3M='5L;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L
M=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC
M:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE
M($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED
M(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*
M;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@
M(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").
M;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T
M;R`E<RXB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S
M97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P
M,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BXB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@
M\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E
M<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S
M97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I
M9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R
M(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A
M<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&UO9&EF:6-A<B!A<R!P<F5F
M97)E;F-I87,Z(%LE9%T@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E
M<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@P,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(')E>&ES
M=')A<B!A<R!P<F5F97)E;F-I87,@;F$@<V5S:?-N+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED
M;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92XB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@
M\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@
M8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z
M,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO
M;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X
M-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y
M"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M="(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@=')A9'5C:7(@97-T92!D;V-U
M;65N=&\@9&4@5V]R9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")$97-F
M86-E<B!O<R!C86UB:6]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@
M(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I
M9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S
M,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY
M"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R
M(")5<W5A<FEO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N
M;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R
M("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H
M;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@
M:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T
M960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*
M;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X
M"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X
M"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I
M9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(E5S97(B"FUS9W-T<B`B57-U87)I;R(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S
M97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")/<&-I\VYS(&1O
M('5S=6%R:6\B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")/<&-I\VYS(&1O('5S=6%R:6\B
M"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B57-U87)I;R(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N
M86UE.B`B"FUS9W-T<B`B57-U87)I;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C
M=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI
M9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T
M97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H
M<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N
M9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA
M8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED
M(")697)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")6
M97)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT
M97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM
M<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6
M;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A
M(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM
M<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R(")!=FES;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&
M;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED
M(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(E=E96ML>2(*;7-G<W1R(")396UA;F%L;65N=&4B"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R(")"96YV:61O+V$L("5S(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B
M0F5N=FED82!A("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)E;G9I9&\O82P@)7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R
M(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E
M<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS
M9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@
M(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A
M8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U
M"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS
M9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B16YD97)E
M>F\@9&\@=')A8F%L;&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E
M;.EF;VYO(&1O('1R86)A;&QO(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI
M;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E
M9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS
M"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@
M(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@
M97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB
M"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS
M9VED(")996%R;'DB"FUS9W-T<B`B06YU86QM96YT92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO
M=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S
M=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM
M<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@
M>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM
M<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I
M96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD
M:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D%C='5A;&EZX7)O;G-E(&%S('/Z
M87,@;W!C:?-N<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q
M"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N
M92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*
M(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T
M<B`B1&5S8W)I8F$@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!I;F9O
M<FUE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*
M;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*
M;7-G<W1R(")#861U8V]U(&$@<_IA('-E<VGS;B!E;B`E<R!E>'!I<F]U+B!)
M;FEC:64@=6YH82!N;W9A('-E<VGS;BXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC
M;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS
M9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(D5N9&5R97IO(&1E
M(&-O<G)E;R!E;&5C='+S;FEC;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B
M"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(DYO;64Z
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@
M(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E
M('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@
M9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B
M"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM
M<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN
M="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M(@IM<V=S='(@(D%C='5A;&EZX7)O;G-E(&%S('/Z87,@;W!C:?-N<RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(DED96YT:61A9&4@<')E
M9&5T97)M:6YA9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B3F]M93HB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")!8W1U86QI
M>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!8W1U86QI>N%R;VYS92!A<R!S
M^F%S(&]P8VGS;G,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB
M"FUS9W-T<B`B06-T=6%L:7KA<F]N<V4@87,@<_IA<R!O<&-I\VYS+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B
M6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@
M(EM);F9O<FUE(&1O(%!R;V)L96UA72(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X
M="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:?%A("5S(&1E
M("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4
M<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(D%X=61A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY
M"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(D5N=')A<B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],
M;V<@;W5T(@IM<V=S='(@(E!E8VAA<B!A('-E<VGS;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I
M9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I
M;VYS(@IM<V=S='(@(D]P8VGS;G,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*
M;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")386-A<B!O('!A<B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*
M;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!>&5N9&$@9&4@96YD97)E
M>F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*
M;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE
M;F1A<B(*;7-G<W1R(")#86QE;F1A<FEO(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR
M"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U
M>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(E3M='5L;R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I
M9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED
M(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I
M;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V
M.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W
M,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY
M"FUS9VED(")N86UE(@IM<V=S='(@(DYO;64B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI
M<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S
M"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B079I<V\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R
M=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM
M<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H
M(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G
M:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*
M(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R(")#861A(&EN:6-I
M;R!D92!S97-I\VXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM
M<V=S='(@(E1A<GAE=&$@9&4@=FES:71A("AV0V%R9"DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM
M<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O
M+V-A7T53+G!O````````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`W,3(V,S``,3`U,34T,S$P-C,`,#$V,S4P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@2&]R9&4@0V%T
M86QA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@
M4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($IO<F1I($=I
M<F%L="`\<')O:F5C=&4N:S)`=7!C;F5T+F5S/BP@,C`P-BX*(PIM<V=I9"`B
M(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP-5QN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`U+3$Q(#$R.C4Q*S`R,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#<M,30@,3$Z,#@K,#$P,%QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!*;W)D:2!':7)A;'0@/'!R;VIE8W1E+FLR
M0'5P8VYE="YE9'4^7&XB"B),86YG=6%G92U496%M.B!#871A;&%N(#QD979`
M;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB
M"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-#D*;7-G:60@(B(*(B`@+4TL("TM;65S<V%G93U-
M15-304=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H
M92!D969A=6QT(&]N97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HU,PIM<V=I9"`B(@HB("`M82P@+2UA9&0]1DE,12`@("`@("`@061D
M('1H:7,@4$\@9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O7&XB
M"B(@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU
M;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T;UQN(@HB("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP96YD:75M+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$S"FUS9VED("(B"B(@("UB
M+"`M+6)A<V4]+U!!5$@@($9U;&P@<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E
M(&1I<F5C=&]R>2!T:&%T('-H;W5L9"!B95QN(@HB("`@("`@("`@("`@("`@
M("`@("!U<V5D+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-CD*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!-97)G92!N
M97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N9&EU;2!F:6QE7&XB"B(@
M("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@9&5F875L
M="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE7&XB"B(@("`@("`@("`@("`@
M("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C,@<&\O=')A;G-L871I;VXN<&AP.C@Q
M('!O+W1R86YS;&%T:6]N+G!H<#HX-PIM<V=I9"`B(@HB("`M8RP@+2UC;VUP
M96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D
M(&]F('1H92!D969A=6QT7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@
M;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$T"FUS9VED
M("(@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O
M;2!T:&4@97AE8W5T960@8FEN87)I97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HU-`IM<V=I9"`B("`M9"P@+2UD:7)E8W1O<GD]1$E2
M("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,34*;7-G:60@(B`@+6@L
M("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0R('!O+W1R86YS;&%T:6]N
M+G!H<#HV-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-S4*;7-G:60@(B`@+6PL("TM
M;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W('!O+W1R86YS;&%T:6]N
M+G!H<#HV,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-SD*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C@U"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E
M('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-34*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES
M(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8X
M"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL
M97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C0S"FUS9VED("(@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#@*;7-G:60@(B(*(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM
M:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV,@IM<V=I9"`B
M("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL
M>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C@P"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@365R9V4@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO
M9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<V"FUS
M9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE;'`@
M9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V"FUS9VED("(@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4X"FUS9VED
M("(@("UM+"`M+6UO9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N
M;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HW,`IM<V=I9"`B(@HB("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AE
M(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(@<&\O=')A;G-L871I;VXN<&AP
M.C@X"FUS9VED("(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E
M(&$@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<Q"FUS9VED("(@("US+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T
M<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-@IM<V=I9"`B("`M="P@
M+2UT97-T("`@("`@("!3:&]W('1H92!E>&5C=71E9"!C;VUM86YD<R!B=70@
M9&]N)W0@<G5N(&%N>71H:6YG+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`U"FUS9VED("(B"B(@(&-L96%N=7`@("`@($-L96%N<R!T
M:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E
M(&5N=')I97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#@*;7-G:60@(B`@8V]M;6ET("`@("`@0V]M;6ET('1R86YS;&%T:6]N<R!T
M;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P.0IM<V=I9"`B("!C;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F
M:6QE<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.CDY"FUS9VED("(B"B(@(&-O;7!E;F1I=6T@(%)E8G5I
M;&0@=&AE(&-O;7!E;F1I=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I
M=&5S('1H95QN(@HB("`@("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I=6TN
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#`*;7-G:60@
M(B`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA=&4@*"YP;W0I(&9I
M;&5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3@*;7-G
M:60@(B`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,0IM<V=I9"`B(@HB
M("!I;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R
M(&$@;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<UQN(@HB("`@("`@("`@("`@
M("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO
M8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-@IM
M<V=I9"`B("!M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O
M;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`W"FUS9VED("(B"B(@(&UA:V4M:&5L<"`@($UA
M<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@=7`M
M=&\M9&%T92!A;F1<;B(*(B`@("`@("`@("`@("`@<')E<&%R92!T:&4@9FEL
M92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T92UH96QP+B!9;W5<
M;B(*(B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!
M1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE7&XB"B(@("`@("`@
M("`@("`@(&AE;'`@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P,@IM<V=I9"`B(@HB("!M97)G92`@("`@("!-97)G92!T:&4@
M8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,PIM
M<V=I9"`B("!U<&1A=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q
M=65N="XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-`IM
M<V=I9"`B(@HB("!U<&1A=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H
M86YG960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H(%A-3"!H96QP7&XB"B(@
M("`@("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI
M<W1I;F<@;VYE<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N(@IM<V=S='(@
M(B(*(DUA<G%U974@82!L82!C87-E;&QA(&PG;W!E<F%C:?,@;R!O<&5R86-I
M;VYS('%U92!D97-I=&=E=2!E>&5C=71A<B!E;B`B"B)A<75E<W1A(&]C87-I
M\RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(H9F$@)7,@9&EE<RDB
M"@HC.B!L:6(O2&]R9&4N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H0VQA=2!D)V%C8^ES("5S*2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<U"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B*&5N("5S(&1I97,I(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H=&]D87DI(@IM<V=S
M='(@(BAA=G5I*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("(H9&5MX"DB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,V.0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(BAA
M:&ER*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#,*;7-G
M:60@(B!A="`B"FUS9W-T<B`B96XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$U
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O
M<GDN(@IM<V=S='(@(EPB)7-<(B!N;R#I<R!U;B!D:7)E8W1O<FDN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@:2`E<R(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,3<V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&)Y=&5S('=R:71T96XN(@IM<V=S='(@(B5D(&)Y=&5S(&5S8W)I=',N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T92(*
M;7-G<W1R("(E9"!D92`E9"!E;G1R861E<R!M87)C861E<R!C;VT@86-T=6%L
M:71Z861E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@
M(G!R979I<VGS('!E<B!A;"!D:6$@)60B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;F]T:6-E7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R`M($YO=&EC92(*;7-G<W1R(")!=NUS("T@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,Z,S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S($%D;6EN
M:7-T<F%C:?,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R(")%
M;7!R96UT82!D86-T:6QA<B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HX,C8@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(D]P97)A8VEO;G,@9&4@;6%N=&5N:6UE
M;G0@)7,@+2!#;VYF:7)M86-I\R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,3@@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!3971U<"(*;7-G<W1R(")#;VYF:6=U<F%C:?,@9&4@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(D%L=&$@9&4@)7,B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS
M9W-T<B`B0V]N9&EC:6]N<R!D96P@8V]N=')A8W1E("5S(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C4V."!L:6(O5D93+V9T<"YP:'`Z-C,V(&QI8B]61E,O<VUB
M+G!H<#HT,S`*(SH@;&EB+U9&4R]S;6(N<&AP.C0Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@:F$@97AI
M<W1E:7@N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3<@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-C,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#,@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@
M96X@)7,@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,C@W('!O+W1R86YS
M;&%T:6]N+G!H<#HS,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(&YO="!W<FET86)L92XB"FUS9W-T<B`B)R5S)R!N;R#I<R!U;F$@;W!C
M:?,@=N!L:61A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S,X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(LES(&YE
M8V5S<V%R:2`E<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T
M<R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O
M=')A;G-L871I;VXN<&AP.C$S-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA('1R;V)A="`E<RXB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-3@U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F:7)S="XB
M"FUS9W-T<B`B)7,@;F\@=')O8F%T+B!%>&5C=71A("=T<F%N<VQA=&EO;B!E
M>'1R86-T)R!P<FEM97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*
M;7-G<W1R("(E<R!A;"`E<R!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K
M(@IM<V=S='(@(DQL:6)R971A(&0G861R96-E<R!D92`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.#@S"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`B06=E;F1A(&1E("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HX-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E
M<&%D(@IM<V=S='(@(D)L;V,@9&4@;F]T97,@9&4@)7,B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C@Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A
M<VML:7-T(@IM<V=S='(@(DQL:7-T82!D92!T87-Q=65S(&1E("5S(@H*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B
M"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B<E<R<@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R
M("(G)7,G(&YO(.ES('5N82!O<&-I\R!VX&QI9&$N(@H*(SH@;&EB+TAO<F1E
M+U)E9VES=')Y+G!H<#HU-30@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HY,CD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B<E<R<@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&YO
M(&5S=.`@8V]N9FEG=7)A="!E;B!E;"!R96=I<W1R92!D92!(;W)D92XB"@HC
M.B!L:6(O2&]R9&4O5')E92YP:'`Z,38T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(G)7,G('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R
M(").;R!S)VAA('1R;V)A="!E;"!G96YE<F%D;W(@9"=A<F)R97,@)R5S)RXB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(G)7,G('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB
M"FUS9W-T<B`B4R=H82!A9F5G:70@)R5S)R!A;"!S:7-T96UA(&1E(&=R=7!S
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HX-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B4R=H82!A9F5G:70@)R5S)R!A;"!S
M:7-T96UA(&1E(&QL:6/H;F-I97,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU
M-2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T
M<B`B)R5S)R!N;R!H82!E<W1A="!C<F5A=#H@)7,N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@=F5N
M=/-S("5S("5S("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DY"B,L('!H
M<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G
M<W1R("(L('9A<FEA8FQE(&1E("5S(&$@)7,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`V.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$R.`HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C@X"FUS9VED("(M+2!S96QE
M8W0@+2TB"FUS9W-T<B`B+2T@<V5L96-C:6]N87(@+2TB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3,R."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,S,`IM<V=I
M9"`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM(@IM<V=S='(@(BTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B9F]R;6%T(&1E
M(#$R(&AO<F5S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R
M-"!(;W5R($9O<FUA="(*;7-G<W1R(")F;W)M870@9&4@,C0@:&]R97,B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B
M"FUS9W-T<B`B,C0@:&]R97,B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP
M.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/$%N=&5R:6]R(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RY<;B(*(D]P
M96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$W"FUS9VED(")!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(E!E<B!A
M(&%Q=65S="!B;&]C(&5S(&YE8V5S<VET82!U;B!M;W1O<B!D92!B87-E<R!D
M92!D861E<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N
M(&5R<F]R(&ER<F5P87)A8FQE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.CDR,`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B17,@;F5C97-S:71A('5N
M82!C;&%U(%!'4"!P^F)L:6-A('!E<B!X:69R87(@=6X@;6ES<V%T9V4N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$T-0IM<V=I9"`B02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92XB"FUS9W-T<B`B17,@;F5C97-S:71A('5N82!C;&%U(%!'4"!P^F)L
M:6-A('!E<B!V97)I9FEC87(@=6X@;6ES<V%T9V4@<VEG;F%T+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-S<*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"B)%<R!N96-E<W-I=&5N('5N82!C;&%U(%!'4"!P^F)L:6-A+"!U;F$@8VQA
M=2!01U`@<')I=F%D82!I('5N82!C;VYT<F%S96YY82`B"B)P97(@9&5S>&EF
M<F%R('5N(&UI<W-A=&=E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDY-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5S(&YE8V5S<VET96X@=6YA(&-L874@
M4$=0('#Z8FQI8V$L('5N82!C;&%U(%!'4"!P<FEV861A(&D@=6YA(&-O;G1R
M87-E;GEA("(*(G!E<B!S:6=N87(@=6X@;6ES<V%T9V4N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("(B"B)%<R!N96-E<W-I=&5N('5N82!C;&%U(%,O34E-12!P^F)L:6-A+"!U
M;F$@8VQA=2!3+TU)344@<')I=F%D82!I('5N82`B"B)C;VYT<F%S96YY82!P
M97(@9&5S>&EF<F%R('5N(&UI<W-A=&=E+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB17,@;F5C
M97-S:71E;B!U;F$@8VQA=2!3+TU)344@</IB;&EC82P@=6YA(&-L874@4R]-
M24U%('!R:79A9&$@:2!U;F$@(@HB8V]N=')A<V5N>6$@<&5R('-I9VYA<B!U
M;B!M:7-S871G92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V
M-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%<R!N96-E<W-I=&$@=6YA(&-L
M874@4TU)344@</IB;&EC82!P97(@>&EF<F%R('5N(&UI<W-A=&=E+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<*;7-G:60@
M(D%-($-L;W5D<R(*;7-G<W1R(").^G9O;',@86P@;6%T[2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C@*;7-G:60@(D%-($QI
M9VAT(%)A:6XB"FUS9W-T<B`B4&QU:F$@9F5B;&4@86P@;6%T[2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-
M(%)A:6XB"FUS9W-T<B`B4&QU:F$@86P@;6%T[2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!3:&]W97)S
M(@IM<V=S='(@(E)U:7AA=',@86P@;6%T[2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B6.!F96-S(&1E(&YE=2!A;"!M873M+B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!
M32]032(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY
M"FUS9VED(")!4$D@240B"FUS9W-T<B`B240@9&4@05!)(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O
M=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B4V]B<F4@87%U97-T(&5D:71O<B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN
M+B(*;7-G<W1R(")%;B!Q=6%N="!A+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM
M<V=S='(@(D%L:6YE86-I\R!I;F9E<FEO<B!E>&%C=&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`B06QI;F5A8VGS(&%L(&UI9R!E>&%C=&$B"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B4R=H82!D96YE9V%T(&PG
M86-CZ7,@96X@8W)E87(@96P@9&ER96-T;W)I(%9&4RXB"@HC.B!L:6(O5D93
M+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N(@IM<V=S='(@(E,G:&$@9&5N96=A="!L)V%C8^ES(&5N(&-R
M96%R(&PG87)X:74@5D93+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")#;VYT<F%S96YY
M82!D96P@8V]M<'1E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3(*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")#;VUP
M=&4@8V]N9V5L870N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q
M-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")#;VUP=&%B:6QI='IA8VGS
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4T(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,3,R"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C$V('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`IM<V=I
M9"`B061D(@IM<V=S='(@(D%F96=I<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"FUS9VED(")!9&0@0VAI;&0@1W)O
M=7`B"FUS9W-T<B`B069E9VER('5N(&=R=7`@9&5S8V5N9&5N="(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.#0@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HX-0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B069E
M9VER('5N82!A=71O<FET>F%C:?,@9&5S8V5N9&5N="(*"B,Z('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B
M069E9VER(&$@8V]N=&EN=6%C:?,Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,#@@861M:6XO9W)O=7!S+G!H<#HR,#D*;7-G:60@(D%D9"!.97<@1W)O=7`B
M"FUS9W-T<B`B069E9VER('5N(&YO=2!G<G5P(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HW,R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<T"FUS9VED
M(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B069E9VER('5N82!N;W9A
M(&%U=&]R:71Z86-I\R`B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R`G)7,G(@IM<V=S='(@(D%F96=I<B!U;B!G<G5P
M(&1E<V-E;F1E;G0@82`G)7,G+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G
M)7,G(@IM<V=S='(@(D%F96=I<B!U;F$@875T;W)I='IA8VGS(&1E<V-E;F1E
M;G0@82`G)7,G+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@
M82!N97<@=7-E<CHB"FUS9W-T<B`B069E9VER('5N(&YO=2!U<W5A<FDZ(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I
M9"`B061D(&-O;'5M;B(*;7-G<W1R(")!9F5G:7(@=6YA(&-O;'5M;F$N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B
M061D(&YE=R!M96UB97)S(@IM<V=S='(@(D%F96=I<B!N;W5S(&UE;6)R97,N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D
M9"!P86ER(@IM<V=S='(@(D%F96=I<B!U;F$@<&%R96QL82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(D%F
M96=I<B!E;"!M96[Z("5S(&-O;2!U;F$@8F%R<F$@;&%T97)A;"!D92!-;WII
M;&QA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM
M<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B069E9V5I>"!A
M(&QA(&QL:6)R971A(&0G861R96-E<SHB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B
M;V]K(@IM<V=S='(@(D%F96=E:7@@82!L82!M979A(&QL:6)R971A(&0G861R
M96-E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*
M;7-G<W1R(")!9F5G:7(@=6X@=7-U87)I(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D("<E<R<@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("4B"B)S+B(*;7-G<W1R("(B"B)3)VAA(&%F
M96=I="`G)7,G(&%L('-I<W1E;6$L('!E<O(@;F\@<R=H82!P;V=U="!A9F5G
M:7(@;>ES(&1A9&5S('-O8G)E("(*(FPG86QT83H@)7,B"@HC.B!S:6=N=7`N
M<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"`G)7,G
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B
M4R=H82!A9F5G:70@)R5S)R!A;"!S:7-T96UA+B!!<F$@:F$@<&]T(&EN:6-I
M87(@;&$@<V5S<VGS+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY-C(*;7-G
M:60@(D%D9&EN9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R>3HB"FUS9W-T<B`B
M069E9VEN="!N;W5S(&9I='AE<G,@86P@<F5P;W-I=&]R:2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHT"FUS9VED(")!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(E,G:&$@:6YH86)I;&ET870@;"=O
M<&-I\R!D)V%F96=I<B!U<W5A<FES+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#0V(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS9VED(")!
M9&1R97-S(@IM<V=S='(@(D%D<F7G82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,S<*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("),;&EB
M<F5T82!D)V%D<F5C97,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F%D;W(@+2!D969I
M;F5I>"!L97,@875T;W)I='IA8VEO;G,@<&5R(&$@86QT<F5S('5S=6%R:7,B
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M
M:6YI<W1R86-I\R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*
M;7-G:60@(D%D<R(*;7-G<W1R(")!;G5N8VES(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.`IM<V=I9"`B069G:&%N:7-T
M86XB"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B06QBX&YI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S0*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QGZ')I82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED
M(")!;&EA<R(*;7-G<W1R("+`;&EE<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM
M<V=S='(@(D%L:6YE87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(D%L
M:6YE86-I\SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@
M(D%L;"(*;7-G<W1R(")4;W1S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3$X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!
M=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E1O=',@96QS('5S=6%R:7,@
M875T96YT:6-A=',B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E1O=',@
M96QS(&=R=7!S(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-S<*;7-G:60@(D%L;"!097)M:7-S:6]N
M<R(*;7-G<W1R(")4;W1S(&5L<R!P97)M:7-O<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L
M;"!F;W5R('-I9&5S(@IM<V=S='(@(E1O=',@<75A=')E(&-O<W1A=',B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S(@IM<V=S='(@(E!E<FUE="!M;VQT97,@861R96-E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C,*;7-G:60@(D%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(D5S('!E<FUE
M="!L82!C;VYF:6=U<F%C:?,@9&5L('1I<'5S(&1E(&QL:7-T97,@;W)D96YA
M9&5S/R(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C0P.`IM<V=I
M9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B2F$@97AI<W1E:7@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!,;V=I;B(*;7-G<W1R(")!8V/I<R!)35-0(&%L=&5R;F%T:74B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DV"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!087-S=V]R9"(*;7-G<W1R(")#;VYT<F%S96YY82!)35-0(&%L=&5R;F%T
M:79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X.`IM<V=I9"`B06QT
M97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B3F]M(&0G=7-U87)I($E-
M4U`@86QT97)N871I=2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!
M9')EYV$@96QE8W1R\FYI8V$@86QT97)N871I=F$B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G
M<W1R(")0;&%N=&EL;&5S(&%L=&5R;F%T:79E<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I
M9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E1E>'0@86QT97)N871I=3HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W
M"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")386UO82!!;65R:6-A
M;F$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N(@IM<V=S='(@(E,G:&$@97-P96-I9FEC870@=6X@=F%L;W(@
M<')O:&EB:70N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M.0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T
M<B`B4R=H82!P<F]D=>]T('5N(&5R<F]R(&1E<V-O;F5G=70N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-@IM<V=I9"`B
M06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(D%N9V]L82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I;&QA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N
M>6UO=7,@4')O>'DB"FUS9W-T<B`B4V5R=FED;W(@4')O>'D@86[R;FEM(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E
M<B(*;7-G<W1R(")297-P;W-T82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B06YTX')T:61A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.0IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G
M<W1R(")!;G1I9W5A(&D@0F%R8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U(&QI8B](;W)D92]";&]C:R]5
M22YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L:6-A8VGS(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(DQL:7-T82!D)V%P;&EC86-I;VYS(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$S.0IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A
M9'DN(@IM<V=S='(@(DPG87!L:6-A8VGS(.ES(&$@<'5N="XB"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI
M;&0@4VAA<F5S(@IM<V=S='(@(D%P;&EC87(@82!R96-U<G-O<R!C;VUP87)T
M:71S(&1E<V-E;F1E;G1S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D%P<F]V87(B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(V"FUS9VED(")!
M<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(DUI9&$@87!R;WAI;6%D82(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S<@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*
M;7-G<W1R(")!8G)I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS
M9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07+@8FEC("A7
M:6YD;W=S+3$R-38B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,0HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.0IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`B36ED82!D92!L)V%R>&EU(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C(@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3@*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(").;VT@9&4@;"=A
M<GAI=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G
M<W1R(")6;VQE=2!S=7!R:6UI<B!L82!S;VRW;&EC:71U9"!D)V%L=&$@82`E
M<S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T
M<B`B5F]L974@97-B;W)R87(@)R5S)R!I('1O=',@96QS('-U8F=R=7!S/R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8*
M;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!
M<FUE;FEA(@IM<V=S='(@(D%R;>AN:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M07)M96YI("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B07)T(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,`IM<V=I9"`B07)U8F$B"FUS
M9W-T<B`B07)U8F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G
M:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B26QL82!D92!L)T%S8V5N
M<VGS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I
M:2!!<G0B"FUS9W-T<B`B9W+@9FEC($%30TE)(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`B4F5G:?,@9&5L(%!A8^UF:6,@87-IX'1I8R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,34*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R
M(")6;VQE=2!C;VYF:7)M86-I\R!A8F%N<R!D)V5F96-T=6%R(&QE<R!O<&5R
M86-I;VYS(&1E(&UA;G1E;FEM96YT/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3$Q"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B0V]L
M=6UN97,@9"=A<W-I9VYA8VGS(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-0IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M(@IM<V=S='(@(E,G:&$@:6YT96YT870@<W5P<FEM:7(@=6X@9W)U<"!N;R!E
M>&ES=&5N="XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C,X"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")3)VAA(&EN=&5N=&%T('-U<')I;6ER('5N82!A=71O<FET
M>F%C:?,@;F\@97AI<W1E;G0N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M.3@*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R(")3)VAA(&EN=&5N=&%T(&5D:71A<B!U;F$@875T
M;W)I='IA8VGS(&YO(&5X:7-T96YT+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+B(*;7-G<W1R(")3)VAA(&EN=&5N=&%T(&5D:71A<B!U;B!R
M96-U<G,@8V]M<&%R=&ET(&YO(&5X:7-T96YT+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C@V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T
M"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T<FEB=71S(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G
M<W1R(")!9V]S="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,CD*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<N!L
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(X"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(L!U<W1R:6$B"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C>7)S<6PZ($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@:6UA<"!N
M96-E<W/@<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*
M;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@16P@;6]T
M;W(@;F\@=.D@;&5S(&-A<&%C:71A=',@;F5C97-SX')I97,N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7V-Y<G5S.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($E-05`@;F5C
M97-SX')I82XB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED
M("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET
M8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!.;R!S)VAA('1R;V)A="!L)V5X
M=&5N<VGS($944"!N96-E<W/@<FEA+B!#86P@8V]M<&EL87(@4$A0(&%M8B!E
M;"`B"B)C;VUM=71A9&]R("UE;F%B;&4M9G1P+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.
M;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($E-05`@;F5C97-SX')I82XB"@HC
M.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?:W)B-3H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!K<F(U(&YE
M8V5S<^!R:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-3@*;7-G
M:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($YO(',G:&$@=')O8F%T(&PG97AT
M96YS:?,@3$1!4"!N96-E<W/@<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@3F\@<R=H82!P;V=U="!A
M9F5G:7(@;"=U<W5A<FD@)7,N($%I>/(@Z7,@96P@<75E(&AA(&1I="!E;"`B
M"B)S97)V:61O<CHB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.;R!S)VAA('!O9W5T
M('-U<')I;6ER(&PG=7-U87)I("5S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71O7VQD87`Z($YO
M(',G:&$@<&]G=70@86-T=6%L:71Z87(@;"=U<W5A<FD@)7,N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71O
M7VUC86PZ($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@34-!3"!N96-E<W/@
M<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z($YO(',G:&$@=')O8F%T(&PG
M97AT96YS:?,@4TU"05542"!N96-E<W/@<FEA+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C@Y"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960B"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&PG
M875T96YT:6-A8VGS+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S
M(@IM<V=S='(@(E,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!L)V%U=&5N=&EC
M86-I\RX@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BXB"FUS9W-T<B`B16P@<V5R=FED;W(@4D%$2553(&AA(')E8G5T:F%T(&PG
M875T96YT:6-A8VGS+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C@*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@;"=A=71E;G1I8V%C:?,@86UB
M(&5L('-E<G9I9&]R($944"XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&PG875T96YT:6-A
M8VGS(&%M8B!E;"!S97)V:61O<B!334(N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHX,PIM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T
M<B`B0V%M<',@9&ES<&]N:6)L97,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS,0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G
M<W1R(")!>F5R8F%I9&IA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@17AC=7-E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B1F]N<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@
M(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0V]L;W(@9&5L(&9O;G,B"@HC
M.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+B(*;7-G<W1R(")#;VYT<F%S96YY82!+97)B97)O<R!I
M;F-O<G)E8W1A+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS
M9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(DYO;2!D)W5S
M=6%R:2!+97)B97)O<R!I;F-O<G)E8W1E+B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS
M9W-T<B`B0F%H86UE<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%I
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"X&QT:6,@*$E33RTX.#4Y+3$S*2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0*
M;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA($1E<V@B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,S"FUS9VED
M(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@
M(DYO(',G:&$@=')O8F%T(&5L(&1I<F5C=&]R:2!D92!G<N!F:6-S(&+@<VEC
M<R`G)7,G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("),[6YI82!B
M87-E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT.0IM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")":65L;W)R^G-I82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`B0NAL9VEC82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`*;7-G:60@(D)E;&EZ92(*
M;7-G<W1R(")"96QI>F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0P"FUS9VED(")"96YI;B(*;7-G<W1R(")"96[M;B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$*
M;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D97,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D%N:79E
M<G-A<FDB"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(W
M"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A
M=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA('1R;V)A
M="!E;"!B;&]C(%PB)7-<(B!D92!L)V%P;&EC86-I\R!<(B5S7"(@+B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@
M4V5T=&EN9W,B"FUS9W-T<B`B4&%RX&UE=')E<R!D96P@8FQO8R(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP
M92(*;7-G<W1R(")4:7!U<R!D92!B;&]C(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@
M(DYE9W)E=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0S"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;.UV:6$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")";V]K;6%R
M:W,B"FUS9W-T<B`B36%R8V%D;W)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM
M<V=S='(@(D-O;G1O<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G
M<W1R(")'<G5I>"!D96P@8V]N=&]R;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B
M"FUS9W-T<B`B0V]N=&]R;G,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,R"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V
M:6YA(@IM<V=S='(@(D+R<VYI82!I($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D%M8F3S
M<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#@*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS
M9VED(")";W1T;VTB"FUS9W-T<B`B26YF97)I;W(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(DEL;&$@9&4@0F]U=F5T(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-`IM<V=I9"`B0G)A>FEL
M(@IM<V=S='(@(D)R87-I;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$W"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GDB"FUS9W-T<B`B5&5R<FET;W)I(&]C9>!N:6,@9&4@;"?-
M;F1I82!B<FETX&YI8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G
M<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HV-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0G5I;&1I;F<@34\@9FEL97,@
M9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R(")#;VYT<G5I;G0@9FET>&5R<R!-
M3R!P97(@86P@;?)D=6P@)7,N+BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C<S"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD:6YG(&QO8V%L92`E<RXN
M+B`B"FUS9W-T<B`B0V]N<W1R=6EN="`E<RXN+B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<*;7-G:60@(D)U;&=A<FEA
M(@IM<V=S='(@(D)U;&?@<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R("),;&ES=&$@9&4@<&EC<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S8*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G
M<W1R(")"=7)K:6YA($9A<V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,Y"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U
M<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<T"FUS9VED
M(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S(*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',B"FUS9W-T<B`B4'5N=',@9&4@9&ES=')I8G5C:?,@9&4@
M0U),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(E!R;W!I971A=',@9&4@8V5LMVQA+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"XB"FUS9W-T<B`B3F\@<R=H82!F:6YA;&ET>F%T(&5L('!R
M;V/I<R!D)VEN:6-I86QI='IA8VGS(&1E(&QA(&UE;?)R:6$@8V%U(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,30V"FUS9VED(")#86QE;F1A<B(*;7-G<W1R
M(")#86QE;F1A<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,X"FUS9VED(")#86QM(@IM<V=S='(@(D-A;&UA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C@*;7-G:60@(D-A;6)O
M9&EA(@IM<V=S='(@(D-A;6)O9&IA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV,`IM<V=I9"`B0V%M97)O;VXB"FUS9W-T
M<B`B0V%M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+)<R!I
M;7!O<W-I8FQE(')E:6YI8VEA<B!L82!C;VYT<F%S96YY82!A=71O;>!T:6-A
M;65N="P@<&]S82=T(&5N(&-O;G1A8W1E("(*(F%M8B!L)V%D;6EN:7-T<F%D
M;W(@9&5L('-I<W1E;6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C(S-2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*
M;7-G<W1R("+)<R!I;7!O<W-I8FQE(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED
M;W(@24U!4#H@)7,N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU,0IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A;F%DX"(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ-PHC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z,3<@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D-A;F-E;+=L
M87(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I
M9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D-A;F-E;+=L87(@
M;"=I;F9O<FUE(&1E('!R;V)L96UE<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M,C4V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DYO(&5S('!O="!E<V)O<G)A<B!L)V%R>&EU(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F\@97,@<&]T('1R;V)A<B!U
M;B!D:7)E8W1O<FD@=&5M<&]R86PN(@H*(SH@;&EB+U9&4R])4T]7<FET97(N
M<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&
M:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DYO(&5S('!O="!C;VYT:6YU87(@
M<V5N<V4@96P@<&%RX&UE=')E("=T87)G971&:6QE)RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,C4R"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F\@97,@<&]T(&5S8F]R
M<F%R(&5L(&1I<F5C=&]R:2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4
M<F5E+G!H<#HQ,3(@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R(").;R!E<R!P;W0@97-B;W)R87(L(&-O;G3I(&1E
M<V-E;F1E;G1S("5D+B`B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H
M<#HU,3(*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B).;R!E<R!P;W0@<F5O<F1E;F%R
M+"!E;"!N;VUB<F4@9"=E;G1R861E<R!Q=64@<R=H86X@9&4@<F5O<F1E;F%R
M(&YO("(*(F-O:6YC:61E:7@@86UB(&QE<R!Q=64@:&D@:&$@96UM86=A='IE
M;6%D97,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#@*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N(@IM<V=S='(@(DYO(&5S('!O="!A9')EYV%R(&5L(&UI<W-A=&=E
M(&%L(&YO;6)R92!E<W!E8VEF:6-A="XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(D-A<"!697)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R
M("),;&5G96YD82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I
M9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(D-A=&5G;W)I97,@
M:2!E=&EQ=65T97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B
M26QL97,@0V%I;6%N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5LZ&9O;B!M
M\F)I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")0
M<F]P:65T871S(&1E(&-E;+=L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM
M<V=S='(@(D9A<F-I;65N="!D92!C96RW;&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL
M('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE=&%T<R!D92!L82!C96RW;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")%<W!A:6%T(&5N=')E
M(&-E;+=L97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(W-`IM<V=I9"`B
M0V5L;'!H;VYE(@IM<V=S='(@(E1E;.AF;VX@;?)B:6PB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"FUS9W-T<B`B0^AL=&EC("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#
M96YT97(B"FUS9W-T<B`B0V5N=')A<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30*;7-G:60@(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@0V5N=')E869R:6-A;F$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B175R;W!A(&-E;G1R86P@
M*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B1&5T86QL
M<R!D96P@8V5R=&EF:6-A="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")4:71U
M;&%R(&1E;"!C97)T:69I8V%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@
M(E!O;.UT:7%U97,@9&4@8V5R=&EF:6-A8VGS(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q"FUS9VED(")#:&%D(@IM
M<V=S='(@(E1X860B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW"FUS9VED(")#:&%N
M9V4B"FUS9W-T<B`B1&5S9NES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB0V%N=FEE=2!E;"!N;VT@:2!L)V%D
M<F7G82!Q=64@<_-N('9I<VEB;&5S('%U86X@97,@;&QE9V5I>&5N(&\@97,@
M<F5S<&]N96X@(@HB96QS('9O<W1R97,@;6ES<V%T9V5S(&1E(&-O<G)E=2!E
M;&5C='+R;FEC+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B0VAA<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B5F5R:69I
M8V$@;"=E;FQL8><N+BXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]T;W`N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+B(*;7-G<W1R("(B"B)-87)C82!A(&QA(&-A<V5L;&$@;"=O
M<&5R86-I\R!O(&]P97)A8VEO;G,@<75E(&1E<VET9VES(&5X96-U=&%R(&5N
M(&%Q=65S=&$@(@HB;V-A<VGS+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S='(@(EAI
M;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8Q"FUS9VED(")#:&EN82(*;7-G<W1R(")8:6YA(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*2(*;7-G<W1R(")8:6[H<R!S:6UP;&EF:6-A="`H1T(R,S$R*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*2(*;7-G<W1R(")8:6[H<R!T<F%D:6-I;VYA;"`H0FEG
M-2DB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B
M0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B5')I82!U;F$@8V]N=')A<V5N
M>6$B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B
M0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B5')I82!U;B!N;VT@9"=U<W5A
M<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@X"FUS9VED(")#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E1R:6$@8V]M('9O
M;',@=FES=6%L:71Z87(@;&5S(&1A=&5S.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R(")4<FEA('5N('1I<'5S(&0G97-T:6P@9&4@;&QI<W1A("AP97(@82!L
M;&ES=&5S(&]R9&5N861E<RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8V"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM
M<V=S='(@(DEL;&$@9&4@0VAR:7-T;6%S(@H*(SH@;&EB+U9&4RYP:'`Z.3$S
M(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G
M:&$@=')O8F%T(&QA(&1E9FEN:6-I\R!D92!C;&%S<V4@9&4@("5S+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HX-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#8W"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L96%N:6YG('5P(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G
M:60@(D-L96%R(@IM<V=S='(@(D5L:6UI;F%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/
M9F9I8V4@=&%G<R(*;7-G<W1R(")%;&EM:6YA(&QE<R!E=&EQ=65T97,@9&4@
M35-/9F9I8V4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS
M9W-T<B`B17-B;W)R82!L)W5S=6%R:3H@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,38*;7-G:60@(D-L96%R('5S97(B"FUS9W-T
M<B`B17-B;W)R82!L)W5S=6%R:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B
M17-B;W)R82!L97,@9&%D97,@9&4@;"=U<W5A<FDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B0VQE87)I;F<@
M3&%T92(*;7-G<W1R(")3)V%C;&%R:7+@(&-A<"!A;"!T87)D+B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?8F]T=&]M+FEN8SHV"FUS9VED
M(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")0<F5M:2!P97(@8V]N=&EN
M=6%R(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#,*
M;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L
M;"!P97(@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W
M(@IM<V=S='(@(E1A;F-A(&QA(&9I;F5S=')A(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#(*;7-G:60@(D-L;W5D<R(*;7-G<W1R(").^G9O;',B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I
M9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(D[Z=F]L<R!A('!R:6UE<F$@:&]R
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B16YN=79O;&%T(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,@IM<V=I9"`B0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B26QL97,@9&4@0V]C;W,@
M*$ME96QI;F<I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHT
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E)E9'7O=2!L82!B
M87)R82!L871E<F%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B
M"FUS9W-T<B`B36%R9V5S(')E9'7O=',B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8R"FUS9VED(")#;VQO;6)I82(*;7-G
M<W1R(")#;VSR;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R
M(")#;VQO<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-S(@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.`HC.B!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDY('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-3(*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-CD*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#8*;7-G:60@(D-O;&]R(%!I8VME<B(*
M;7-G<W1R(")396QE8W1O<B!D92!C;VQO<B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#0T"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E-E
M;&5C8VGS(&1E(&-O;&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D-O;'5M
M;F5S.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU
M;6X@=&ET;&5S(@IM<V=S='(@(E3M=&]L<R!D92!L97,@8V]L=6UN97,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@T"FUS9VED(")#;VUI8W,B
M"FUS9W-T<B`B0_)M:6-S(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(D]R9')E(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(D-O;G-O
M;&$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@
M(D-O;6UA;F0@;W!T:6]N<SHB"FUS9W-T<B`B3W!C:6]N<R!D92!L82!C;VQU
M;6YA(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDW"B,L(&9U>GIY"FUS9VED
M(")#;VUM86YD<SHB"FUS9W-T<B`B3W)D<F4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,#(*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B0V]M96YT
M87)I(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,#`*(RP@9G5Z>GD*;7-G
M:60@(D-O;6UI='1I;F<Z(@IM<V=S='(@(D-O;F1I8VEO;G,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`B3F]M(&-O;?HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S,`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")#
M;VUO<F5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B0V]M<&%N>6EA(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL
M<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;7!O<V4@365S<V%G
M92`H)7,I(@IM<V=S='(@(D5S8W)I=2!E;"!M:7-S871G92`H)7,I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS
M9W-T<B`B3W)D:6YA9&]R<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0W
M"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D-O;F1I8VEO;G,B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R(")$:69E<NAN8VEE<R!D92!C;VYF:6=U<F%C
M:?,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,T"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("),82!C;VYF:6=U
M<F%C:?,@;F\@97-TX"!A8W1U86QI='IA9&$N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E
M<R(*;7-G<W1R(")#;VYF:6=U<F$@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,W"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM
M<V=S='(@(D-O;F9I<FUA<B!L82!C;VYT<F%S96YY82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34*;7-G:60@(D-O;F=O
M(@IM<V=S='(@(D-O;F=O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,PIM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC
M(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")#;VYG;RP@4F5P^F)L:6-A($1E
M;6]C<N!T:6-A(&1E;"(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(DYO(.ES('!O<W-I
M8FQE(')E86QI='IA<B!L82!C;VYN97AI\RXB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T
M<B`B3F\@Z7,@<&]S<VEB;&4@<F5A;&ET>F%R(&QA(&-O;FYE>&GS.B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<W.0IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")3
M)VAA(')E8G5T:F%T(&QA(&-O;FYE>&GS(&%L('-E<G9I9&]R(&1E(&-L875S
M('#Z8FQI<75E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B
M4R=H82!R96)U=&IA="!L82!C;VYN97AI\R!A;"!S97)V:61O<B!D92!C;&%U
M<R!P^F)L:7%U97,N(%)A\SH@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW-C(*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(DYO(.ES('!O<W-I8FQE(')E86QI='IA<B!L82!C;VYN97AI
M\R!A;"!S97)V:61O<B!&5%`N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D5L<R!C
M;VYT86-T97,@<R=H86X@869E9VET(&-O<G)E8W1A;65N="!A(&QA('1E=F$@
M;&QI8G)E=&$@9"=A9')E8V5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B`G)7,G(@IM<V=S='(@
M(D-O;G1I;F=U="!D92`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT:6YU87(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X"FUS
M9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B26QL97,@0V]O:R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@
M(D=A;&5T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!I87(B
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("+)<R!I;7!O<W-I8FQE(&-O<&EA
M<CH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")#;W!I87(@
M<V5L96-C:?,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>6EN9R`E<R!T;R`E<R(*;7-G<W1R
M(");;.UN:6$@)7,@9&4@)7-=(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV,PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R
M(")#;W-T82!2:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU-PIM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")#
M;W-T82!D)TEV;W)I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34V
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M92XB"FUS9W-T<B`B3F\@97,@<&]T('AI9G)A<B!E;"!M:7-S871G92!A;6(@
M4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,S,*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R
M(").;R!E<R!P;W0@<VEG;F%R(&5L(&UI<W-A=&=E(&%M8B!01U`N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").;R!E<R!P;W0@
M>&EF<F%R(&5L(&UI<W-A=&=E(&%M8B!3+TU)344N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+B(*;7-G<W1R(").;R!E<R!P;W0@<VEG;F%R(&5L(&UI
M<W-A=&=E(&%M8B!3+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C$X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DYO(&5S('!O="!A9F5G:7(@96P@
M8V]N=&%C=&4N("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3$P
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B3F\@97,@<&]T(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED;W(@3$1!4"XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34U"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").
M;R!E<R!P;W0@8V]M<')O=F%R(&5L('-A;&1O+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E
M<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-O;FYE8W1A<B!A;6(@96P@<V5R
M=FED;W(@)R5S)R!M:71J86[G86YT($944#H@)7,N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C;W!Y("5S('1O("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@
M;V)R:7(@)7,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-R
M96%R('5N82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N("5S(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!L;V-A
M;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z(@IM<V=S='(@(DYO(',G:&$@
M<&]G=70@;V)R:7(@96P@9&ER96-T;W)I("<E<R<N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3$P-0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@9&5S
M>&EF<F%R(&QE<R!D861E<R!01U`N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E<WAI9G)A<B!L97,@9&%D
M97,@4R]-24U%+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C
M;VYT86-T+B`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&5S8F]R<F%R(&5L
M(&-O;G1A8W1E+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!E<V)O<G)A<B!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N("5S(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@)R5S)RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E<V)O<G)A<B!L82!S
M97'\Z&YC:6$@9"=A8W1U86QI='IA8VGS(&EN<W1A;+=L861A("<E<R<N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,X(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,S@Q"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!D971E<FUI;F%R(&PG861R9>=A(&5L96-T<O)N:6-A(&1E;"!D
M97-T:6YA=&%R:2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C@R"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S
M<R!B;V]K+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(')E8V]L;&ER('1O=&$@
M;&$@;&QI8G)E=&$@9"=A9')E8V5S+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.3(*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!R96-O;&QI<B!T;W1A(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I\RXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0U"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(')E8V]L;&ER('1O
M=&$@;&$@;&QI<W1A(&1E(&QE<R!L;&ES=&5S(&1E(&1I<W1R:6)U8VGS+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX
M-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A
M9"!S=')A=&5G>2`G)7,G+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-A<G)E
M9V%R(&PG97-T<F%TZ&=I82`G)7,G+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER("<E<R<N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8W)E87(@96P@9&ER96-T;W)I("<E
M<R<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S`X"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&]B=&5N:7(@=6YA(&-L874@</IB
M;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=7,N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#0@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B`E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B`E<RXB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N("<E<R<@9F]R('=R:71I;F<N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@
M;V)R:7(@)R5S)R!P97(@97-C<FEU<F4N(@H*(SH@;&EB+TAO<F1E+TUA:6YT
M96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!O8G)I<B!E;"!M\F1U;"!D92!T87-Q=65S(&1E(&UA;G1E
M;FEM96YT("5S+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RXB"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!O8G)I<B!E;"!D:7)E8W1O<FD@)R5S)RXB"@HC.B!L:6(O
M5D93+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R96%D("5S+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&QL96=I<B`E
M<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B
M(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(DYO(',G:&$@<&]G=70@<F5I;FEC:6%R(&QA(&-O;G1R87-E;GEA('!E
M<B!A(&PG=7-U87)I('-O;+=L:6-I=&%T+B!!;&=U;G,@(@HB9&5T86QL<R!O
M('1O=',@;F\@<_-N(&-O<G)E8W1E<RX@5&]R;F%R+6AO(&$@:6YT96YT87(@
M;RP@<&5R(&$@;>ES("(*(FEN9F]R;6%C:?,L('!O<V$G="!E;B!C;VYT86-T
M92!A;6(@;"=A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#,*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").;R!S)VAA('!O
M9W5T(')E8W5P97)A<B!L97,@04-,(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").;R!S)VAA
M('!O9W5T(')E8W5P97)A<B!L82!L;&EB<F5T82!D)V%D<F5C97,N("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<F5C=7!E<F%R(&QA
M(&QL:7-T82!D92!D:7-T<FEB=6-I\RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#,V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@<F5C=7!E<F%R(&QE<R!L;&ES=&5S(&1E(&1I
M<W1R:6)U8VGS+B`E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@<F5C=7!E<F%R(&QE<R!P;W-S:6)I;&ET871S
M(&1E;"!S97)V:61O<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*
M;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B3F\@<R=H82!P;V=U="!R97-T875R87(@;&$@8V]N9FEG=7)A8VGS+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<FUD:7(@)R5S)RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E;&EM:6YA<B!E
M;"!D:7)E8W1O<FD@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E<V%R(&QA
M(&-O;F9I9W5R86-I\R`E<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HU-R!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!D97-A<B!U;F$@8V]N9FEG=7)A8VGS(&1E('-E9W5R971A="XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E<V%R('5N82!C;VYF:6=U<F%C
M:?,@9&4@<V5G=7)E=&%T.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.CDR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RXB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!D97-A<B!L82!S97'\Z&YC:6$@9"=A8W1U86QI='IA
M8VGS(&EN<W1A;+=L861A(&5N.B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(B(*(DYO(',G:&$@<&]G=70@9&5S87(@;&$@8_)P:6$@9&4@<V5G=7)E=&%T
M(&1E(&PG87)X:74@9&4@8V]N9FEG=7)A8VGS("5S+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3F\@<R=H82!P;V=U="!D97-A<B!L
M)V%R>&EU(&1E(&-O;F9I9W5R86-I\R`E<RX@4&]T<R!U=&EL:71Z87(@=6YA
M(&1E(&QE<R`B"B)O<&-I;VYS('!E<B!T;W)N87(@82!D97-A<B!E;"!C;V1I
M(&5N("5S(&\@8ND@8V]P:6%R(&UA;G5A;&UE;G0@96P@8V]D:2`B"B)S96?\
M96YT(&5N("5S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$R,`IM
M<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@8V5R8V%R(&%L('-E<G9I9&]R($Q$05`N(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M;FQI;FL@)R5S)RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D97-E;FQL8>=A
M<B`G)7,G+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&%C='5A;&ET>F%R(&5L
M(&-O;G1A8W1E+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!A8W1U86QI='IA<B!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N("5S(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M)R5S)SH@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E<V-R:75R92!L82!C
M;VYF:6=U<F%C:?,@<&5R(&$@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G
M<W1R("(B"B).;R!S)VAA('!O9W5T(&QO8V%L:71Z87(@;&$@8F%R<F$@;&%T
M97)A;"!D92!-;WII;&QA+B!#;VUP<F]V82!Q=64@;&$@8F%R<F$@(@HB;&%T
M97)A;"!E<W1I9W5I(&]B97)T82XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9&XG="!G:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B`G)7,G.B`E<R(*;7-G<W1R("(B"B).;R!S)VAA('!O
M9W5T(&-O;F-E9&ER(&$@;"=U<W5A<FD@)R5S)R!E;',@9')E=',@<V5G_&5N
M=',@<&5R(&$@;&$@8V%R<&5T82`G)2(*(G,G.B`E<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#(T"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B
M5&5X="!C;VUP=&%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-C@*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M0W5R<V]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)E
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0W)E
M87(@=6X@96YL;&'G(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,PIM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")#
M<F5A<BUN92!U;B!D92!N;W4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R
M(")#<F5A<B!S=6)C87)P971E<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$S-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Q-`IM<V=I9"`B0W)E871O
M<B!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-O<R!D96P@8W)E861O<B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C(X"FUS9VED(")#<F5D:70@8V%R
M9"!N=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E(&QA('1A<F=E=&$@9&4@8W+H
M9&ET(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#D*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0W)OX&-I82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C0*;7-G:60@
M(D-U8F$B"FUS9W-T<B`B0W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(T(&9A<V5S(&%C
M='5A;',B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM
M92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")496UP<R!A
M8W1U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3,*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@
M(D5L(%523"!A8W1U86P@Z7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B5&5M<',@86-T=6%L
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,@IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")#;VYD:6-I\R!A8W1U86PZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")%<W1I;"!A8W1U86PB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B(@HB4&5R<V]N86QI='IE=2!L97,@=&%S<75E<R!Q=64@
M<R=H86X@97AE8W5T87(@<75A;B!S)VEN:6-I82!L82!S97-S:?,@82`E<RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")2971A;&QA<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@
M(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B4F5T86QL87(@;&$@<V5L96-C:?,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W
M"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B6&EP<F4B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T
M<B`B0VER[6RW;&EC("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@
M(D-I<NULMVQI8R`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB
M"FUS9W-T<B`B0VER[6RW;&EC+U5C<F'O;NAS("A+3TDX+54I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.`IM<V=I9"`B
M0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A(%1X96-A(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,R!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G
M<W1R(")$:>!R:6%M96YT(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS
M9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(DYA=F5G861O<B!D92!$
M871A5')E92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,SDW(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S
M='(@(D1A=&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")3)VAA(')E8G5T
M(&QA(&1A=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-0IM<V=I9"`B
M1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?,@9&4@9&%T82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#8*;7-G:60@(D1A>2(*
M;7-G<W1R(")$:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(E-U<')I;6ER(&-O;'5M;F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@U(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5S96UB
M<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B
M3F]M8G)E<R!D96-I;6%L<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G
M<W1R(")2961U[W4@96P@<V%G;F%T(@H*(SH@;&EB+W!R969S+G!H<#HQ,3$@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`B4')E9&5T97)M:6YA="(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0W"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@Q"FUS9VED(")$969A=6QT($-O;&]R(@IM
M<V=S='(@(D-O;&]R('!R961E=&5R;6EN870B"@HC.B!L:6(O2&]R9&4O261E
M;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@
M(DED96YT:71A="!P<F5D971E<FUI;F%D82(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$Q.2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-@HC+"!F=7IZ
M>0IM<V=I9"`B1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R(")3=7!R:6UI
M<B!P97)M[7,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="!P97)M:7-S:6]N<R(*;7-G<W1R(")3=7!R
M:6UI<B!P97)M[7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G
M:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:6-I;VYS(@H*(SH@;&%N
M9W1E<W0N<&AP.C(Q(&QA;F=T97-T+G!H<#HR,R!A9&UI;B]G<F]U<',N<&AP
M.C<R"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU,B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-0HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C,Q-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,S,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,2!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3,*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,@IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-U<')I;6ER
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR
M,3<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")3=7!R:6UI<B!G<G5P
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HV,R!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C@W"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R
M(")3=7!R:6UI<B!P97)M[7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B
M"FUS9W-T<B`B4W5P<FEM:7(@:2!B=6ED87(@;6ES<V%T9V5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM
M<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B4W5P<FEM:7(@8V5LMVQA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")3=7!R:6UI<B!C
M;VQU;6YA(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E
M;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B4W5P
M<FEM:7(@;&$@<&QA;G1I;&QA(&%L=&5R;F%T:79A(&5X:7-T96YT(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU,"!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C,Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`G)7,G(@IM<V=S='(@(E-U<')I;6ER('!E<FUI<V]S
M('!E<B!A("<E<R<B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3
M=7!R:6UI<B!P97)M:7-O<R!P97(@82`G)7,G(&D@=&]T<R!E;',@<W5B<&5R
M;6ES;W,_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3=7!R
M:6UI<B!F:6QA(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y
M+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S
M='(@(E-U<')I;6ER(&QA(&ED96YT:71A="!S96QE8V-I;VYA9&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C8*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B
M4W5P<FEM:7(@;&$@8V]L=6UN82!A8W1U86PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(D1E
M;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4W5P<FEM:7(@;&$@9FEL
M82!A8W1U86PB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0X"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3=7!R:6UI<B!P97)M:7-O<R!P97(@
M82`G)7,G(&D@=&]T<R!E;',@<W5B<&5R;6ES;W,_(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`B
M4R=H82!S=7!R:6UI="!L82!S97'\Z&YC:6$@9"=A8W1U86QI='IA8VGS(&EN
M<W1A;+=L861A("<E<R<N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C`@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-3(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DT"FUS9VED(")$96QI=F5R
M>2!T:6UE(@IM<V=S='(@(DAO<F$@9&4@;&QI=7)A;65N="(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$*;7-G:60@(D1E
M;FUA<FLB"FUS9W-T<B`B1&EN86UA<F-A(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3$P('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q-"!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C0*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM
M<V=S='(@(D1E<V-R:79I=2!E;"!P<F]B;&5M82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S
M8W)I<&-I\R(*"B,Z(&QI8B](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(D1E=&%L;',@
M*'1A;6+I(&%L(&9I='AE<B!D92!R96=I<W1R92!D92!(;W)D92DZ(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D5L<R!D971A
M;&QS(&AA;B!E<W1A="!R96=I<W1R871S('!E<B!A(&PG861M:6YI<W1R861O
M<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R(")$97-E;G9O;'5P86UE;G0B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@
M(E!U;G0@9&4@<F]S861A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3(*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4'5N
M="!D92!R;W-A9&$@9&4@;&$@9&%R<F5R82!H;W)A.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(D1E=R!P;VEN=#H@(@IM
M<V=S='(@(E!U;G0@9&4@<F]S861A.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R(")$)V5S<75E<G)A(&$@9')E=&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED
M(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")$92!D<F5T82!A
M(&5S<75E<G)A(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@
M(D1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W1O<FDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M(@IM<V=S='(@(E9O;',@=FES=6%L:71Z87(M:&\@96X@9F]R;6%T(&1E(#(T
M(&AO<F5S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B
M1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;G,@9&4@=FES=6%L:71Z
M86-I\R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#,*;7-G:60@(D1I<W!L
M87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B36]S=')A(&QA('!R979I<VGS
M("A4048I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,34*;7-G:60@(D1I
M<W!L87D@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!D92!V:7-U86QI='IA8VGS
M(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R(").;W1I9FEC86-I\R!D92!R
M96-E<&-I\R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S`*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)O=71I(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C,Q-0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").;R!H
M;R!S=7!R:6UI=2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-`IM
M<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B
M"FUS9W-T<B`B3F\@86-C961I=2!D:7)E8W1A;65N="!A(&UA:6YT96YA;F-E
M+G!H<"(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$Y('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$Y"FUS9VED(")$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z(@IM<V=S='(@(B(*(DQA('!R:6UE<F$@9FEL82!C;VYTZ2!E
M;',@;F]M<R!D96QS(&-A;7!S/R!%;B!C87,@869I<FUA=&EU+"!A8W1I=F$@
M87%U97-T82`B"B)C87-E;&QA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S(*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@
M(D1O;6EN:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW,PIM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(E)E</IB;&EC82!$;VUI;FEC86YA(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C@S-PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B1&5S8V%R
M<F5G87(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(D1E<V-A
M<G)E9V%R("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-0IM<V=I
M9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="XB"FUS9W-T<B`B1&5S8V%R<F5G87(@;&$@8V]N9FEG=7)A8VGS(&=E
M;F5R861A(&-O;2!U;F$@<V5Q_.AN8VEA(%!(4"XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B
M3&QI<W1A(&1E<W!L96=A8FQE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<F]G=65S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#`R"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B
M0V]R<F5U(&5L96-T<O)N:6,B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")%
M4E(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<U"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5Q=6%D;W(B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(Y-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8Y"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#$*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM
M<V=I9"`B161I="(*;7-G<W1R(")%9&ET82(*"B,Z(&QI8B](;W)D92]";&]C
M:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I
M9"`B161I="!";&]C:R(*;7-G<W1R(")%9&ET82!B;&]C(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.#@@861M:6XO9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`B161I=&$@9W)U<"(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-C(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-@IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(D5D:71A('!E<FWM<R(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B161I=&$@<&5R;6ES;W,B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D:71A('!E<FUI<V]S
M(&1E("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B
M161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B161I=&$@;W!C:6]N<R!D93HB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D
M:71A('!E<FUI<V]S(&1E("5S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,C`T(&QI8B](;W)D92]097)M<R]522YP:'`Z,C@P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`G)7,G(@IM<V=S
M='(@(D5D:71A('!E<FUI<V]S(&1E("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B161U8V%C:?,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W
M"FUS9VED(")%9WEP="(*;7-G<W1R(")%9VEP=&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<*;7-G:60@(D5L(%-A
M;'9A9&]R(@IM<V=S='(@(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")%
M;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS
M9W-T<B`B475A9')A=.TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@V.2!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA
M:6PB"FUS9W-T<B`B0V]R<F5U(&5L96-T<O)N:6,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C0P"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,3(*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B061R9>=A(&5L96-T
M<O)N:6-A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("),97,@861R96-E
M<R!E;&5C='+R;FEQ=65S(&AA;B!D92!C;VEN8VED:7(N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T
M:6]N(@IM<V=S='(@(D-O<G)E=2!E;&5C='+R;FEC(&%M8B!C;VYF:7)M86-I
M\R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR.#`*
M;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")%;6]T:6-O;F5S(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(D5M<'1Y
M(&UE<W-A9V4N(@IM<V=S='(@(DUI<W-A=&=E(&5N(&)L86YC+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C$R.`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R(")297-U;'1A="!E;B!B;&%N8RXB"@HC.B!L:6(O2&]R9&4O
M4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M
M<R(*;7-G<W1R(")"=6ED87(@96QS('1E<FUE<R!D92!C97)C82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S(*;7-G:60@(D5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM
M<V=S='(@(DAA8FEL:71A<B!L82!I;G-E<F-I\R!D92!I;6%T9V5S(&1E(&QE
M<R!G86QE<FEE<R!D92!F;W1O<R!E;B!E;"!T97AT/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_(@IM<V=S='(@(DAA8FEL:71A<B!E;"!M96[Z(&1E(&-O
M;G1E>'0@8VQI8V%N="!E;B!E;"!B;W3S(&1R970_(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U.38@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#D*;7-G:60@
M(D5N9"!Y96%R(@IM<V=S='(@(D%N>2!D92!F:6YA;&ET>F%C:?,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")!;7!L:6%R(&PG961I=&]R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,0IM<V=I9"`B(@HB16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(DEN
M=')O9'7O=2!U;F$@<')E9W5N=&$@9&4@<V5G=7)E=&%T('%U92!S92!U<R!F
M;W)M=6QA<N`@<VD@=7,@8V%L(')E:6YI8VEA<B`B"B)L82!C;VYT<F%S96YY
M82P@<&5R(&5X96UP;&4@)V-O;2!E<R!D:74@96P@=F]S=')E(&%N:6UA;"!D
M92!C;VUP86YY:6$_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I
M;6%G92!54DP@:&5R92(*;7-G<W1R("));G1R;V1U[W4@87%U[2!E;"!54DP@
M9&4@;&$@:6UA=&=E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O
M+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")'=6EN96$@
M17%U871O<FEA;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E82(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F]R(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B2&D@:&$@:&%G=70@=6X@97)R
M;W(@86UB(&5L(&UI<W-A=&=E(&5L96-T<O)N:6,N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG("<E<R<N(@IM
M<V=S='(@(DAI(&AA(&AA9W5T('5N(&5R<F]R(&5N(&5S8W)I=7)E("<E<R<N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-3(R('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<W"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ-#,X('!O+W1R86YS;&%T:6]N+G!H<#HQ-3`Q"B,L(&9U>GIY
M"FUS9VED(")%<G)O<CH@(@IM<V=S='(@(D5R<F]R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-@IM<V=I9"`B17-T;VYI
M82(*;7-G<W1R(")%<W3R;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B
M171I\G!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B
M171H;FEC(@IM<V=S='(@(LAT;FEC(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(Y"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN=71S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W.0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@
M(D-A9&$@,B!M:6YU=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(D5V97)Y(#,P('-E
M8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=O;G,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S(X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")#861A(#4@;6EN=71S(@H*
M(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@
M3&]G:6XB"FUS9W-T<B`B0V%D82!I;FEC:2!D92!S97-S:?,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B
M"FUS9W-T<B`B0V%D82!M:71J82!H;W)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")%
M=F5R>2!M:6YU=&4B"FUS9W-T<B`B0V%D82!M:6YU="(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C(X"FUS9VED(")%>&%M<&QE('9A;'5E<SHB
M"FUS9W-T<B`B5F%L;W)S(&0G97AE;7!L93HB"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B17AE8W5T82(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HR.3D@<&\O=')A;G-L871I;VXN<&AP.C,R
M,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,S8R"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HT-#$@<&\O=')A;G-L871I;VXN<&AP.C4T,2!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C`Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,#(@<&\O=')A;G-L871I
M;VXN<&AP.C<S-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-SDX"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HX-S4@<&\O=')A;G-L871I;VXN<&AP.CDY-"!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3`Q-@HC+"!F=7IZ>0IM<V=I9"`B17AE8W5T:6YG.B(*
M;7-G<W1R(")%>&5C=71A<B(*"B,Z(&QA;F=T97-T,BYP:'`Z,3<*(RP@9G5Z
M>GD*;7-G:60@(D5X:70B"FUS9W-T<B`B161I=&$B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HS.30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")%
M>'!A;F1E:7@B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")%>'!A;F1I<B!L82!B
M87)R82!L871E<F%L(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z
M,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B4R=E<W!E<F%V82`G
M*2<B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@
M(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS
M9W-T<B`B4R=E<W!E<F%V82!U;B!S;VP@;6]T(&\@=6X@=&5R;64@9&4@8V5R
M8V$@8VET870B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#$*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")$871A(&1E('9E;F-I;65N
M="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17AT<F%C=&EN9R!F<F]M
M("5S+BXN("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R(")#;VQO<B!D92!P<FEM97(@<&QA(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,`IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R
M(")#X')R96=A(&1E(&QA(&-O;F9I9W5R86-I\R!D96P@1E10(@H*(SH@;&EB
M+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!R96-U
M<&5R87(@;&5S('!R969E<NAN8VEE<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HQ,#`*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("+)<R!I;7!O<W-I8FQE(&-O;FYE8W1A<B!A;6(@
M96P@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R("+)<R!I;7!O<W-I8FQE(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED
M;W(@4TU"+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(LES(&EM<&]S<VEB;&4@8V]P:6%R(&1E(%PB)7-<(BXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z-C`X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!C;W!I87(@
M82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G
M:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`BR7,@:6UP;W-S:6)L92!C<F5A<B!U;F$@;F]V82!C;VYN97AI\R!3
M05-,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV-#$@;&EB+U9&4R]S;6(N<&AP
M.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<
M(B5S7"(N(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@=')A;G-F97)I<B!A(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#8S"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`BR7,@:6UP
M;W-S:6)L92!R96-U<&5R87(Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D9A:7(B"FUS9W-T<B`B0VQA
M<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#0*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R
M("));&QE<R!&86QK;&%N9"`H36%L=FEN97,I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-@IM<V=I9"`B1F%R;V4@27-L
M86YD<R(*;7-G<W1R("));&QE<R!&Z')O92(*"B,Z(&QI8B](;W)D92]#3$DN
M<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D5R<F]R(&ER
M<F5C=7!E<F%B;&4@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<U(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T
M<B`B1F5B<F5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3@*;7-G:60@
M(D9E96QS($QI:V4B"FUS9W-T<B`B4V4@<V5N="!C;VTB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")&965L<R!L:6ME.B`B
M"FUS9W-T<B`B4V4@<V5N="!C;VTZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S
M='(@(E!O<75E<R!P;'5G97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R(")0;V-S('C@9F5C<R!D92!N974B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(DUA=')I=2!D
M96P@8V%M<"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#,*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`B4F5C;VUP=&4@9"=A<GAI=7,Z(&%R>&EU("5S(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C0@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@
M)7,@9FEL97,B"FUS9W-T<B`B4F5C;VUP=&4@9"=A<GAI=7,Z("5S(&%R>&EU
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#0*;7-G:60@(D9I
M;&4@36%N86=E<B(*;7-G<W1R(")'97-T;W(@9"=A<GAI=7,B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HX-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV,PIM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;2!D92!L)V%R
M>&EU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.3,*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS(&0G87)X:75S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T.3$*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S
M='(@(D/@<G)E9V$@9&4@;"=A<GAI=2(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HX-3,*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R(").;R#I<R!P97)MZ',@<&5N:F%R(&%R>&EU<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HX-PIM<V=I9"`B1FEL=&5R<R(*;7-G<W1R
M(")&:6QT<F5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YLX&YD:6$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Q"FUS9VED(")&:7)S="!(86QF
M(@IM<V=S='(@(E!R:6UE<F$@;65I=&%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R(")0<FEM97(@<75A<G0B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Y"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B4F'S(&9I>&$C(R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,30*;7-G:60@(D9L:7`B"FUS9W-T<B`B26YV97)T:74B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")#;VUA(&9L;W1A;G0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F]G(@IM<V=S='(@(D)O:7)A(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$V
M,"!L:6(O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(DQA(&-A<G!E=&$@
M)7,@;F\@97AI<W1E:7@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D-O
M;&]R(&1E(&QA(&9O;G0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*
M;7-G:60@(D9O;V0B"FUS9W-T<B`B365N:F%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED
M(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G
M<W1R(")097(@86QS(&YA=F5G861O<G,@<75E(&YO(&%D;65T96X@;&5S(&EM
M871G97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,@IM<V=I9"`B1F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B4')E=FES:?,@*%1!1BDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S@*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB4')E
M=FES:?,@<&5R(&%L<R!D:65S("AT:6YG=65U('!R97-E;G0@<75E(&QA('!R
M979I<VGS(&9A8VEL:71A9&$@8V]M<'+H;B!E;"`B"B)D:6$@:2!L82!N:70Z
M('5N(&YO;6)R92!E;&5V870@<&]D<FEA('1E;FER(&-O;2!A(')E<W5L=&%T
M('5N(&)L;V,@86UP;&4N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY-@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(DAE
M=2!O8FQI9&%T(&QA(&-O;G1R87-E;GEA/R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,#`*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU;&%R
M:7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U
M;F4B"FUS9W-T<B`B1&ET82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1I<'5S(&1E(&1I=&5S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE
M<R(*;7-G<W1R(")$:71E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")$:71E<R`R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Y,0IM<V=I9"`B1F]R=6US(@IM<V=S
M='(@(D;R<G5M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#<*
M;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E)E96YV:6%M96YT<R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ-#4X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")&;W5N9"!A<'!L:6-A=&EO;G,Z("5S(@IM<V=S='(@(D%P;&EC86-I
M\R!N;R!VX&QI9&$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T-3(*(RP@
M9G5Z>GD*;7-G:60@(D9O=6YD(&1I<F5C=&]R:65S.B(*;7-G<W1R(").;R#I
M<R!U;B!D:7)E8W1O<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")$=BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"FUS9VED(")&<F%M97,B"FUS9W-T<B`B36%R8W,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W"FUS9VED(")&<F%N8V4B
M"FUS9W-T<B`B1G)A;N=A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(D9R86[G
M82!M971R;W!O;&ET86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,0IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R
M(")'=6%I86YA($9R86YC97-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#0*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B4&]L:6[H<VEA($9R86YC97-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B5&5R<FET;W)I<R!&<F%N
M8V5S;W,@9&5L(%-U9"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D1E<R!D92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#`*;7-G:60@(D9R;VT@=&AE
M("(*;7-G<W1R(")$97,@9&5L(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)I<&-I\R!C;VUP;&5T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3@Q"FUS9VED(")&=6QL($UO;VXB"FUS
M9W-T<B`B3&QU;F$@<&QE;F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,Y"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B3F]M(&-O
M;7!L970B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED(")&=7IZ
M>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@X"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS
M9W-T<B`B3&$@9V%L97)I82!D92!L82!Q=6%L(',G97AT<F5U(&QA(&EM871G
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L97)I
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.38*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'X&UB:6$B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R
M871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B17,@9V5N97)A(&QA(&-O
M;F9I9W5R86-I\R`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF
M:6<N:'1M;#HQ,`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B0V]D
M:2!G96YE<F%T(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'96YE<F%T:6YG('-T871U<R!F;W(@;6]D=6QE("5S
M+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.3`*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1V7R<F=I
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B06QE;6%N>6$B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B1V5T;W!T($5R
M<F]R.B`B"FUS9W-T<B`B17)R;W(@:7)R96-U<&5R86)L92`B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS"FUS9VED(")'
M:&%N82(*;7-G<W1R(")':&%N82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.30*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R
M(")':6)R86QT87(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W
M-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(").;VT@9&4@<&EL82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R
M(")!;F%R(&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@
M(D=O961E;"(*;7-G<W1R(")']F1E;"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B0V5R8V$@
M86P@1V]O9VQE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R,`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D5S8V%L82!D92!G
M<FES;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P,`IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RZ&-I82(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM
M-RDB"FUS9W-T<B`B1W)E8R`H25-/+3@X-3DM-RDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU"FUS9VED(")'<F5E;FQA
M;F0B"FUS9W-T<B`B1W)E;FS@;F1I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D*;7-G:60@(D=R96YA9&$B"FUS9W-T
M<B`B1W)A;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<P"FUS9VED(")'
M<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'97-T:?,@9&4@9W)U<',B
M"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4X"FUS9VED(")'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")%;',@;F]M<R!D92!G<G5P
M(&YO(&5S('!O9&5N(&1E:7AA<B!E;B!B;&%N8R(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C(P,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(W-PHC+"!F
M=7IZ>0IM<V=I9"`B1W)O=7`@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES
M;W,@9&5L<R!V:7-I=&%N=',B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-3`@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P<R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@*;7-G:60@(D=U861E;&]U<&4B
M"FUS9W-T<B`B1W5A9&%L=7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#,*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A
M;2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`R"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G
M<W1R(")'=65R;G-E>2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R-R!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R
M(")097)M:7-O<R!D96QS('9I<VET86YT<R(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$R."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-@HC+"!F=7IZ
M>0IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES;W,@
M9&5L<R!V:7-I=&%N=',B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`X"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B3&QI8G)E(&1E('9I<VET
M86YT<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3<*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN96$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0*;7-G:60@
M(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5A($)I<W-A=2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-0IM<V=I
M9"`B1W5Y86YA(@IM<V=S='(@(D=U>6%N82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!N;R!P97)M970@
M<W5P<FEM:7(@;&$@9&%R<F5R82!C96RW;&$@9&4@;&$@9FEL82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YO
M('!E<FUE="!S=7!R:6UI<B!L82!D87)R97)A(&-O;'5M;F$@9&4@;&$@=&%U
M;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,
M07)E82!N;R!P97)M970@<W5P<FEM:7(@;&$@9&%R<F5R82!F:6QA(&1E(&QA
M('1A=6QA+B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U-PIM<V=I
M9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO
M(',G:&$@=')O8F%T(&PG875T96YT:6-A8VGS($A45%`N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P"FUS9VED(")(
M86ET:2(*;7-G<W1R(")(86ET[2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0P,@IM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I
M<VUE(&1E(&AA<V@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,`IM<V=I9"`B2&%Z92(*;7-G<W1R(")#86QI=&IA(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDS
M,`IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D-A<.=A;&5R82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-PIM<V=I9"`B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DEL
M;&$@2&5A<F0@:2!I;&QE<R!-8T1O;F%L9"(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T
M<B`B2&5B<F5U("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(D%LYV%D82(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ-S@@
M;&EB+TAO<F1E+TAE;'`N<&AP.C$X-2!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L
M<"(*;7-G<W1R(")!:G5D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM
M<V=S='(@(D%J=61A('!E<B!U=&EL:71Z87(@;"=E9&ET;W(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,W-@IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%P
M;&EC86-I\R!D)V%J=61A(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDU"FUS
M9VED("(B"B)(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN
M=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D95QN(@HB9G)A;65W;W)K
M(&%N9"!I=',@87!P;&EC871I;VYS+EQN(@HB1F]R(&%N(&EN=')O9'5C=&EO
M;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI
M<W!H97)E(@IM<V=S='(@(DAE;6ES9F5R:2(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$W('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$W
M"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM
M<V=S='(@(D%Q=65S="#I<R!L)VEN:6-I(&1E;"!F:71X97(Z(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(DAI
M9V@B"FUS9W-T<B`B06QT(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C,R
M,0HC+"!F=7IZ>0IM<V=I9"`B2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E
M(&YO;BUE;7!T>2(*;7-G<W1R(")%;',@;F]M<R!D92!G<G5P(&YO(&5S('!O
M9&5N(&1E:7AA<B!E;B!B;&%N8R(*"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8SHT('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-@IM
M<V=I9"`B2&]?;64B"FUS9W-T<B`B26YI8VDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")L82!386YT82!3974@
M*$-I=71A="!%<W1A="!D96P@5F%T:6/@*2(*"B,Z(&QI8B](;W)D92YP:'`Z
M,30R-@IM<V=I9"`B2&]M92(*;7-G<W1R("));FEC:2(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T
M<B`B061R9>=A('!A<G1I8W5L87(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")4
M96SH9F]N('!A<G1I8W5L87(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#@*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(DAO;F1U<F5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`V"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+
M;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8S"FUS9VED(")(
M;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,S(Y"FUS9VED(")(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC
M;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M4R=H86X@=')O8F%T(&1A9&5S(%A-3"`E<R!N;R!VX&QI9&5S(&5N(&5L(&UI
M<W-A=&=E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!.
M;R!H:2!H82!C87`@;6ES<V%T9V4@<75E(&5S(&-O<G)E<W!O;F=U:2!A;6(@
M;"=O8FIE8W1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z($YO(',G:&$@=')O8F%T(&-A<"!O8FIE8W1E(&1E;"!T:7!U<R`E<R!E
M;B!E;"!M:7-S871G92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E
M<R!<(B5S7"(@:&$@97-T870@97AT<F5T(&-O<G)E8W1A;65N="(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@
M)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!<(B5S7"(@:&$@
M97-T870@97AT<F5T(&-O<G)E8W1A;65N="(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N
M(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@16P@;6]T;W(@9"=I;G1E9W)A8VGS(&YE
M8V5S<VET82!L)V5X=&5N<VGS(%!(4"`G9&]M>&UL)R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z-#@Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T(&-R96%R
M('5N(&YO=2!A<F)R92!834P@<&5R(&$@;"=O8FIE8W1E("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,C`U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z($YO(',G:&$@<&]G=70@97AT<F5U<F4@)7,@
M7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B
M"B)(;W)D92]+;VQA8CH@3F\@<R=H82!P;V=U="!R96-U<&5R87(@;"=I9&5N
M=&EF:6-A9&]R($U)344@<&5R(&$@;&$@<&%R="!D96P@(@HB=&EP=7,@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T
M('-I;F-R;VYI='IA<B`E<UPB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$R.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA<B!L97,@<75O
M=&5S.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S$X"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<
M(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@17-P86D@9&ES<&]N:6)L92!D97-C
M;VYE9W5T(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M(")296=L82!H;W)I='IO;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN
M9R(*;7-G<W1R(")&87)C:6UE;G0@:&]R:71Z;VYT86PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I
M>F]N=&%L.B(*;7-G<W1R(")(;W)I='IO;G1A;#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(D-O;2!H974@87)R:6)A="!F:6YS(&%Q=>T_("A&974M;F]S+6AO('-A
M8F5R(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N=&5S(&-O;'5M;F5S('9O
M;&5U(')E9F]N9')E/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C(X"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\B"FUS9W-T<B`B475A;G1S(&-A;7!S("AC;VQU;6YE<RD@:&D@:&$_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B475A;G1E<R!F:6QE<R!V;VQE=2!R969O;F1R93\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.`IM<V=I9"`B2'5M:61I='DB
M"FUS9W-T<B`B2'5M:71A="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#8*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B2'5M:71A=#HB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T
M<R(*;7-G<W1R(")(=6UO<FES=&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q"FUS9VED(")(=6YG87)Y(@IM<V=S
M='(@(DAO;F=R:6$B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R
M(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(LES(&EM<&]S<VEB;&4@8W)E87(@;&$@8OIS=&EA($E-05`Z("5S(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-"!L:6(O2&]R9&4O075T
M:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+)<R!I;7!O<W-I
M8FQE('-U<')I;6ER(&QA(&+Z<W1I82!)34%0.B`E<R(*"B,Z(&QI8B](;W)D
M92]!=71H+V-Y<G5S+G!H<#HQ-SD@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H
M<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!C
M<F5A<B!U;B!E<W!A:2!D:7-P;VYI8FQE('!E<B!A(&QA(&+Z<W1I82!)34%0
M.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S(P"FUS9VED("))4"!!
M9&1R97-S(@IM<V=S='(@(D%D<F7G82!)4"(*"B,Z(&QI8B](;W)D92]!=71H
M+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DPG861R9>=A($E0(&YO(&5S=.`@9&ES<&]N:6)L92XB
M"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T
M<B`B3"=A9')EYV$@25`@;F\@97,@=')O8F$@96X@96P@8FQO8R!#2412('!E
M<FWH<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-`IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")6:6]L
M86-I\R!D96P@8FQO<75E:6<@25`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T
M(%)O=R!"969O<F4B"FUS9W-T<B`B26YS97)I=2!U;F$@9FEL82!D86UU;G0B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C`*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-LX&YD:6$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S
M='(@(DYO;>ES(&EC;VYE<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B
M26-O;F5S(&1E("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM
M<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(DEC;VYE<R!A;6(@=&5X
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#`*;7-G:60@(DED96YT
M:71Y)W,@;F%M93HB"FUS9W-T<B`B3F]M(&0G:61E;G1I=&%T.B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")3:2!N;R!E<R!V
M:7-U86QI='IA(&-O<G)E8W1A;65N="P@;V)R:74@)7,@96X@=6YA(&YO=F$@
M9FEN97-T<F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-0IM<V=I
M9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O
M>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)3
M:2!N;R!V:7-U86QI='IE=2!C87`@:6-O;F$@;6ET:F%NYV%N="!L)TEN=&5R
M;F5T($5X<&QO<F5R+"#I<R!P;W-S:6)L92!Q=64@(@HB:.!G:74@9"=A8W1I
M=F%R(&%Q=65S="!Q=6%D<F4@<&5R(&1E<V%C=&EV87(@;&$@=')A;G-P87+H
M;F-I82!D92!03D<N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$U.`IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@
M8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A
M;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@
M(B(*(E-I('9E:65U(&%Q=65S="!M:7-S871G92!E;B!L;&]C(&1E(&QA(&EM
M871G92P@96P@=F]S=')E(&YA=F5G861O<B!N;R!P;W0@(@HB;6]S=')A<B!L
M82!I;6%T9V4@<75E('9O;&5U('!E;FIA<BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@
M(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E9I<W5A;&ET>F%C:?,@<'+H=FEA
M(&1E(&QA(&EM871G93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T
M<B`B55),(&1E(&QA(&EM871G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@
M55),.B(*;7-G<W1R(")54DP@9&4@;&$@:6UA=&=E.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM
M<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM871G92!D92!L
M82!G86QE<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(DEM871G92!D92!L82!G86QE<FEA.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED("));6%G92!U<&QO860B"FUS9W-T
M<B`B0^!R<F5G82!D92!L82!I;6%T9V4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DEM871G97,B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4W"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$P"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1A8VGS+"!P
M87,@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M0V%M<"!I;7!O<G1A=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C<S"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(D-A;7!S
M(&EM<&]R=&%T<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R
M(@IM<V=S='(@(DEN<V5R:74@=6YA(&9I;&$@82!S;W1A(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D5L(&-O9&D@9&4@;"=A8V-I\R!Q
M=64@<R=H82!F86-I;&ET870@Z7,@:6YC;W)R96-T92XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"FUS9VED("));F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(").;VT@9"=U<W5A
M<FD@:2]O(&-O;G1R87-E;GEE<R!I;F-O<G)E8W1E<RXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"B)3)VAA(&9A8VEL:71A="!U;B!N;VT@9"=U
M<W5A<FD@;R!U;F$@861R9>=A(&%L=&5R;F%T:79A(&EN8V]R<F5C=&5S+B!4
M;W)N974M(@HB:&\@82!I;G1E;G1A<B!O('!O<V5U+79O<R!E;B!C;VYT86-T
M92!A;6(@;"=A9&UI;FES=')A9&]R('!E<B!A(&WI<R!A:G5D82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B075G;65N=&%R(&5L('-A9VYA
M="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q-@IM<V=I9"`B26YD:6$B"FUS9W-T<B`BS6YD:6$B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ-#$@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B57-U87)I<R!I
M;F1I=FED=6%L<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N
MZ'-I82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R;6%C:?,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C0T"FUS9VED("));F9O<FUA=&EO;B(*;7-G
M<W1R("));F9O<FUA8VGS(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4X,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("));FET:6%L:7II;F<@;6]D=6QE("5S+BXN
M("(*;7-G<W1R("));FEC:6%L:71Z86YT(&WR9'5L("5S+BXN("(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-`IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B26YS97)E
M:7@@=6YA(&-O;'5M;F$@82!S;W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B26YS97)E:7@@=6YA(&EM871G92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R("));G-E<F5I>"!U;F$@=&%U;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS
M9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B26YS97)E:7@@96YL;&'G
M('=E8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,PIM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM
M<V=S='(@(DEN<V5R96EX(&QA(&-O;'5M;F$@9&%M=6YT(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("));G-E<F5I>"!U;F$@;F]V82!C;VQU;6YA(&$@<V]T82!D
M92!L)V%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R96EX('5N
M82!N;W9A(&-O;'5M;F$@82!S;V)R92!D92!L)V%C='5A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B26YS97)E:7@@=6YA(&YO=F$@9FEL82!A('-O=&$@9&4@;"=A
M8W1U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C`*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<F5I>"!U;F$@;F]V82!F
M:6QA(&$@<V]B<F4@9&4@;"=A8W1U86P@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M("));G-E<F5I>"!U;B!P87+@9W)A9B!A('-O=&$@9&5L(&YO9&4@86-T=6%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8X"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H
M92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS97)E:7@@=6X@<&%RX&=R868@
M82!S;V)R92!D96P@;F]D92!A8W1U86PB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R("));G-E<F5I>"!L)V%L=')A('!L86YT:6QL82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,CD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.B(*;7-G<W1R("(B"B));G-E<F5I>"!U;F$@861R9>=A(&1E(&-O<G)E=2!P
M97(@<F5B<F4@;&$@;F]V82!C;VYT<F%S96YY84EN<V5R:74@=6YA("(*(F%D
M<F7G82!E;&5C='+R;FEC82!A(&QA('%U86P@<&]D974@<F5B<F4@;&$@;F]V
M82!C;VYT<F%S96YY83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E
M<B(*;7-G<W1R("));G-E<F5I>"!U;F$@8V5LMVQA(&$@<V]T82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*
M;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("));G-E<F5I>"!U
M;F$@8V5LMVQA(&$@<V]B<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(DEN<V5R:74@=6YA(&-O;'5M;F$@82!S;W1A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YS
M97)I=2!U;F$@8V]L=6UN82!A('-O8G)E(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS
M9W-T<B`B26YS97)I=2!M:7-S871G97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B26YS97)I=2!U;B!P87+@9W)A
M9B!A('-O=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(DEN<V5R:74@=6X@<&%RX&=R868@82!S;V)R92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YS97)I=2!U
M;F$@9FEL82!A('-O=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R("));G-E<FEU('5N82!F:6QA(&$@<V]B<F4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C(P"FUS9VED("));G-E<G0@=&AE(')E<75I
M<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@
M(DEN<V5R:74@;&$@<F5S<&]S=&$@82!L82!P<F5G=6YT82!D92!S96=U<F5T
M870Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));G-E
M<FER+TUO9&EF:6-A<B!I;6%T9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI
M;FLB"FUS9W-T<B`B26YS97)I<B]-;V1I9FEC87(@96YL;&'G(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B3F\@9&ES<&]S974@9&4@<')O=2!C<NAD:70@<&5R(&5N
M=FEA<BUL;R!A(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I\RXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")#<NAD:70@:6YS=69I8VEE;G0N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS
M9W-T<B`B3F]M8G)E(&5N=&5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q
M,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("),;&ES=&$@9&4@;F]M
M8G)E<R!E;G1E<G,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2XB"FUS9W-T<B`B541((&YO(';@;&ED82X@*$-A<.=A;&5R82!D92!D861E
M<R!D)W5S=6%R:2DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM
M<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B07!L:6-A8VGS
M(&YO(';@;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B3"=I
M9&5N=&EF:6-A9&]R(&1E;"!L;W0@;F\@Z7,@=N!L:60B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`X-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U."!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(S,@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(Y
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B3&5S
M(&1A9&5S('%U92!S)VAA;B!T<F%MZ',@;F\@<_-N(';@;&ED97,N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B3"=A9')EYV$@
M9&4@9&5S=&EN86-I\R!N;R#I<R!VX&QI9&$N(@H*(SH@;&EB+TAO<F1E+T-O
M;7!R97-S+V1B>"YP:'`Z.#$@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z
M,3`P"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B
M26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")%;"!F;W)M870@9&4@;"=A
M<GAI=2!N;R#I<R!VX&QI9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38Y"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R
M("),82!C;&%U(&1E(&QA(&QL:6/H;F-I82!N;R#I<R!VX&QI9&$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI
M9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3&$@=6)I8V%C:?,@<75E
M(&AE=2!P<F]P;W)C:6]N870@;F\@Z7,@=N!L:61A+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R(")%;"!T:7!U<RUM<V<@;F\@Z7,@=N!L:60N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(DUA;F-A(&5L
M(&%P:5]I9"!O(&5L('%U92!S)VAA(&9A8VEL:71A="!N;R#I<R!VX&QI9"XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(DUA
M;G%U96X@<&%RX&UE=')E<R!O(&5L<R!Q=64@<R=H86X@9F%C:6QI=&%T(&YO
M('/S;B!VX&QI9',N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0S
M"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("),
M)V%U=&]R:71Z86-I\R!P871E<FYA(&YO(.ES(';@;&ED82XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED('!A
M<G1N97(@:60N(@IM<V=S='(@(D5L(&-O9&D@9"=I9&5N=&EF:6-A8VGS(&1E
M('-O8VD@;F\@Z7,@=N!L:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V-PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S
M='(@(D5L(&-O9&D@9&5L('!R;V1U8W1E(&YO(.ES(';@;&ED+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED("));G9A
M;&ED('!R;W1O8V]L+B(*;7-G<W1R(")%;"!P<F]T;V-O;"!N;R#I<R!VX&QI
M9"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B`G
M)7,G(@IM<V=S='(@(D5L(&1E<W1I;F%T87)I(&YO(.ES(';@;&ED.B`G)7,G
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#0S(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,3(R,`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T
M<B`B3"=O8FIE8W1E(&-O;7!A<G1I="!N;R#I<R!VX&QI9"(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED
M('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("),)V%D<F7G82!D)V]R:6=E;B!N
M;R#I<R!VX&QI9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3`*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M("),97,@9&%D97,@56YI8V]D92!N;R!S\VX@=N!L:61E<RXB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(S"FUS9VED("));G9E;G1O<GDB"FUS
M9W-T<B`B26YV96YT87)I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$Y"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DER86XL(%)E</IB;&EC82!)<VS@;6EC82!D)R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M.`IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%Q(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S"FUS9VED("))<F5L86YD
M(@IM<V=S='(@(DER;&%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("));&QA(&1E($UA;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")496UP97-T97,@8>]L
M;&%D97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)A96PB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM
M<V=S='(@(D5M:7-S;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R(")#=7)S:79A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(Q"FUS9VED("))=&%L>2(*;7-G<W1R("))=.!L:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,*;7-G:60@(DIA
M;6%I8V$B"FUS9W-T<B`B2F%M86EC82(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-S0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(D=E;F5R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U
M"FUS9VED(")*87!A;B(*;7-G<W1R(")*87#S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B2F%P;V[H<R`H25-/+3(P,#(M2E`I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M-`IM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F3@;FEA(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,"!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B
M2G5L:6]L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G
M:60@(DIU;F4B"FUS9W-T<B`B2G5N>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB
M"FUS9W-T<B`B2G5S=&EF:6-A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E
M;G1E<B(*;7-G<W1R(")*=7-T:69I8V%R(&%L(&-E;G1R92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS
M9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B2G5S=&EF:6-A<B!A('1O=',@
M9&]S(&UA<F=E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T
M<B`B2G5S=&EF:6-A<B!A(&PG97-Q=65R<F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S
M=&EF>2!2:6=H="(*;7-G<W1R(")*=7-T:69I8V%R(&$@;&$@9')E=&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8*
M;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86MH<W1A;B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME
M97`@;W)I9VEN86P_(@IM<V=S='(@(E9O;&5U(&-O;G-E<G9A<B!L)V]R:6=I
M;F%L/R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R-@IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N>6$B"@HC.B!L:6(O
M2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")%;"!S97)V:61O
M<B!+97)B97)O<R!H82!R96)U=&IA="!L)V%U=&5N=&EC86-I\RXB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S
M(@IM<V=S='(@(DME<FYE;"!.97=B:65S(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B0W)E
M86-I\R!D92!C;&%U<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P
M,PIM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(D5M<')E;71A(&1I
M9VET86P@9&4@;&$@8VQA=2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0P,0IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("),;VYG:71U9"!D92!L
M82!C;&%U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED
M(")+97D@5'EP92(*;7-G<W1R(")4:7!U<R!D92!C;&%U(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME>2!5<V%G92(*;7-G
M<W1R("+:<R!D92!L82!C;&%U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-S(Y"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(DIA(&5X:7-T96EX('5N82!C;&%U(&5N
M(&5L('-E<G9I9&]R(&1E(&-L875S('#Z8FQI<75E<RXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B3F]I<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M.0IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(D-O<F5A+"!297#Z8FQI8V$@1&5M;V-RX'1I8V$@4&]P=6QA<B!D92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M,PIM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(D-O<F5A+"!2
M97#Z8FQI8V$@9&4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I
M9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(D-O<F7@("A%54,M2U(I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T
M"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5W86ET(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W"FUS9VED(")+>7)G
M>7IS=&%N(@IM<V=S='(@(DMI<F=U:7II<W1A;B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")&;W)M
M870B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('!O+W1R86YS
M;&%T:6]N+G!H<#HV-3<*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DED:6]M
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B
M"FUS9W-T<B`B4F5P^F)L:6-A($1E;6]C<N!T:6-A(%!O<'5L87(@9&4@3&%O
M<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DQA<W0@2&%L
M9B(*;7-G<W1R(")$87)R97)A(&UE:71A="(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HX."!L:6(O0FQO8VLO;6]O;BYP:'`Z.3`*;7-G:60@(DQA<W0@475A
M<G1E<B(*;7-G<W1R(")$87)R97(@<75A<G0B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$T.0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")$87)R
M97)A(&%C='5A;&ET>F%C:?,Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8V
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R
M(")$87)R97)A(&-O;FYE>&GS.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HV-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<R(*;7-G<W1R(")$87)R97)A(&-O;FYE>&GS.B`E<R!D92`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HV-C,*;7-G:60@(DQA<W0@;&]G:6XZ($YE
M=F5R(@IM<V=S='(@(D1A<G)E<F$@8V]N;F5X:?,Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),871V
M:6$B"FUS9W-T<B`B3&5T\FYI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DQL96DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R(")$:7-S96YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R(")$96EX87(M:&\@96X@8FQA;F,@<&5R(&5L
M:6UI;F%R(&5L(&-O;G1O<FXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S@*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B
M3.UB86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B17-Q=65R<F$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B3&5F="!H96%D97(B
M"FUS9W-T<B`B0V%PYV%L97)A(&5S<75E<G)A(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,Q,3,*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9A;&]R
M<R!D92!L)V5S<75E<G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30S"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE
M<V]T:&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#(*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EBZ')I82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-PIM
M<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),[6)I82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*
M;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B4&QU9VEM(&9E8FQE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G
M:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B4&QU:F$@9F5B;&4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R(")0;'5J82!F96)L92!A('!R:6UE<F$@
M:&]R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(U"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B4&QU:F$@9F5B
M;&4@8V%P(&%L('1A<F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T
M<B`B4G5I>&%T(&9E8FQE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R
M(@IM<V=S='(@(E)U:7AA="!F96)L92!A;6(@=')O;G,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@
M4VYO=R(*;7-G<W1R(").979A9&$@9F5B;&4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4VYO=R!3
M:&]W97(B"FUS9W-T<B`B6.!F96,@9&4@;F5U(&9E8FQE(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),
M:6UE<FEC:R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$X"FUS9VED("),
M:6YK(@IM<V=S='(@(D5N;&QAYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B3&EN:R!P;VEN
M=',@=&\Z(@IM<V=S='(@(D5N;&QA8^=A<B!E;',@<'5N=',@86UB.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M(@IM<V=S='(@(D5N;&QAYV%R(&PG861R9>=A(&5L96-T<O)N:6-A(&$@;&$@
M<.!G:6YA(&1E(')E9&%C=&%T('%U86X@97,@;6]S=')I(@H*(SH@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK
M<R(*;7-G<W1R(")%;FQL8>=O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(D=A;&5T82!,:6YU
M>"(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I
M9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQL
M:7-T87(@+2!,)W5S=6%R:2!P;W0@=F5U<F4@;&$@8V%R<&5T82(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM
M<V=S='(@(DQL:7-T87(@;&5S(&)A<V5S(&1E(&1A9&5S(@H*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B
M"FUS9W-T<B`B3&QI<W1A(&1E;',@=&5M97,@9"=A:G5D82(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@
M(DQL:7-T87(@;&5S('1A=6QE<R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E
M<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W0M
M07)C:&EV92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0IM
M<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W0M2&5L<"(*"B,Z(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G
M<W1R("),:7-T+4ED(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI<W0M3W=N97(B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M
M4&]S="(*;7-G<W1R("),:7-T+5!O<W0B"@HC.B!L:6(O2&]R9&4O34E-12](
M96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@
M(DQI<W0M4W5B<V-R:6)E(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M
M56YS=6)S8W)I8F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C0*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(DQA(&QL:7-T82!D)W5S=6%R:7,@97-TX"!I;FAA8FEL:71A9&$N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E
M(@IM<V=S='(@(D)I8FQI;V=R869I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-`IM<V=I9"`B3&ET:'5A;FEA(@IM
M<V=S='(@(DQI='7@;FEA(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,S@*
M(RP@9G5Z>GD*;7-G:60@(DQO861I;F<@;&EB<F%R:65S+BXN(@IM<V=S='(@
M(E,G97-TX"!C87)R96=A;G0N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(")3
M)V5S=.`@8V%R<F5G86YT+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P,PIM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DAO<F$@
M;&]C86PZ("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B
M3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DED:6]M82!I(&AO<F$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI
M8B]";&]C:R]M971A<BYP:'`Z-C,*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@
M(E5B:6-A8VGS(@H*(SH@;&]G:6XN<&AP.C$U-2!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,38T('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#0*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(DEN:6-I
M82!L82!S97-S:?,B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34X"FUS9VED("),;V<@;W5T(@IM<V=S='(@(E-U<G0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R
M(")487-Q=65S(&0G:6YI8VD@9&4@<V5S<VGS(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDQ,0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB
M"FUS9W-T<B`B(@HB2&D@:&$@:&%G=70@=6X@97)R;W(@9&4@8V]N;F5X:?,@
M<&5R<77H(&AE=2!I;G1R;V1U[W0@:6YC;W)R96-T86UE;G0@96P@;F]M("(*
M(F0G=7-U87)I(&\@;&$@8V]N=')A<V5N>6$N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDP-PIM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")(82!F
M86QL870@;&$@8V]N;F5X:?,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-S`*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")497AT(&QL87)G(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@
M(D%M;W(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,PIM<V=I9"`B3&]W(@IM<V=S='(@(D)A:7@B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED
M("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(D%L9F%B970@9W)E8R!E
M;B!M:6[Z<V-U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(D%L9F%B970@;&QA=.T@96X@;6EN^G-C=6QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")8:69R
M97,@<F]M86YE<R!E;B!M:6[Z<V-U;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4*;7-G:60@(DQU>&5M8F]U<F<B
M"FUS9W-T<B`B3'5X96UB=7)G(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,W,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$P"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*
M;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*
M;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("),)V%R>&EU(&%D:G5N="!-
M4RU43D5&(&YO(&-O;G1E;FEA(&1A9&5S+B(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM
M<V=S='(@(DU31R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-PIM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C874B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,*
M;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9B(*;7-G<W1R(")-86-E9/)N:6$L($%N=&EG82!297#Z8FQI8V$@275G
M;W-L879A(&1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34Q"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G
M87-C87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA
M9VEC(@IM<V=S='(@(DW@9VEC(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C<Y"FUS9VED(")-86EL(@IM<V=S='(@(D-O<G)E=2!E;&5C='+R;FEC
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V.`IM<V=I9"`B36%I
M;"!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')A9&]R(&1E(&-O<G)E=2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")3)V5S=.`@8W)E
M86YT('5N(&5N;&QAYRXN+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S4W
M"FUS9VED(")-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE
M9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV-S@@<&\O=')A;G-L871I;VXN<&AP.C$P-S0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUA:VEN9R!D:7)E8W1O<GD@
M)7,B"FUS9W-T<B`B3F\@Z7,@=6X@9&ER96-T;W)I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U"FUS9VED(")-86QA
M=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38W"FUS9VED(")-86QA>7-I82(*;7-G<W1R
M(")-86S@:7-I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV
M97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-30*;7-G:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,@IM<V=I9"`B36%L
M=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO
M=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S
M;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D=E
M<W1I;VYE=2!L82!L;&ES=&$@9&4@8V%T96=O<FEE<R!A;6(@;&5S('%U86QS
M(&AE=2!D)V5T:7%U971A<B!E;',@(@HB96QE;65N=',L(&D@96QS(&-O;&]R
M<R!A<W-O8VEA=',@86UB(&%Q=65S=&5S(&-A=&5G;W)I97,N(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(DUA
M<#(T(&UA<"(*;7-G<W1R(")-87!A($UA<#(T(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-PHC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`U-`IM<V=I9"`B36%P475E<W0@;6%P(@IM
M<V=S='(@(DUA<&$@36%P475E<W0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S<V(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%RYR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*
M;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G92(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S(@IM<V=S='(@(DUA<F-A<B!A;6(@:6YD:6-A9&]R<R!V
M:7-I8FQE<R]I;G9I<VEB;&5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-87)C87(@86UB(&%L
M=')E<R!I;F1I8V%D;W)S("AP+B!E+BP@:6UP;W)T86YT+W)E<W!O<W0I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R
M"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DEL;&5S($UA<G-H
M86QL(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34Y"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEC82(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3$Q"FUS9VED(")-871C
M:&EN9R!F:65L9',B"FUS9W-T<B`B0V%M<',@<75E(&-O:6YC:61E:7AI;B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M,`IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:73@;FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S"FUS
M9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FEC:2(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(")-87@@86QL;W=E
M9"!C<F5D:70N(@IM<V=S='(@(D-RZ&1I="!MX'AI;2!P97)MZ',N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DUA
M>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")3)VAA('-U<&5R
M870@96P@;F]M8G)E(&W@>&EM(&1E('!A<G1S(&1E(&UI<W-A=&=E+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`T"FUS9VED(")-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>!X:6UA(&1E(&QE
M<R!D87)R97)E<R`R-"!H;W)E<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.38*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@
M(E1E;7!E<F%T=7)A(&W@>&EM82!D92!L97,@9&%R<F5R97,@-B!H;W)E<SH@
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU
M;2!L96YG=&@B"FUS9W-T<B`B3&]N9VET=60@;>!X:6UA(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W."!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-
M86EG(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G
M<W1R(")-961I8VEN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,3D*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B365M8G)E<R(*"B,Z
M(&QA;F=T97-T+G!H<#HW"FUS9VED(")-96UO<GD@97AH875S=&5D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(DUE
M;G4@;6]D93HB"FUS9W-T<B`B5&EP=7,@9&4@;65N^CHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED
M(")-97)G92!C96QL<R(*;7-G<W1R(")2969O;F%R(&QE<R!C96RW;&5S(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN
M+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0S.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-97)G:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<X.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-97)G:6YG('1H92!03R!F:6QE(&9O<B`E<R!T;R!T:&4@8V]M
M<&5N9&EU;2XN+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C0R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG('1R86YS;&%T:6]N
M(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*(SH@;&%N9W1E<W0N<&AP
M.C$W(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HS,`IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-:7-S871G92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB
M16P@;6ES<V%T9V4@:&$@97-T870@=F5R:69I8V%T(&-O<G)E8W1A;65N="P@
M<&5R\B!N;R!S)VAA('!O9W5T('9E<FEF:6-A<B!E;"`B"B)C97)T:69I8V%T
M(&5L('-I9VYA;G0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#D*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B36ES
M<V%T9V4@8V%D=6-A="XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38X(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#$*;7-G:60@(DUE<W-A9V4@
M='EP92(*;7-G<W1R(")4:7!U<R!D92!M:7-S871G92(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")4
M96UP<R!D92!-151!4B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G
M:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D5L(&)L
M;V,@345405(@;F\@97-TX"!D:7-P;VYI8FQE+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$P"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)%;"!B;&]C($U%5$%2(&YO(&5S=.`@9&ES
M<&]N:6)L92X@16QS(&1E=&%L;',@:&%N(&5S=&%T(')E9VES=')A=',@<&5R
M(&$@(@HB;"=A9&UI;FES=')A9&]R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B3&$@8F%S92!D92!D861E<R!-151!4B!N;R!E<W3@(&-O
M;FYE8W1A9&$N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<*;7-G:60@(DUE
M=&AO9"(*;7-G<W1R(")-Z'1O9&4B"@HC.B!L:6(O2&]R9&4O4E!#+W-O87`N
M<&AP.C$Q-R!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"`G)7,G(&ES(&YO="!D969I;F5D
M(@IM<V=S='(@(D5L(&WH=&]D92`G)7,G(&YO(&5S=.`@9&5F:6YI="XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,PIM<V=I9"`B365T<FEC(@IM<V=S='(@(DWH=')I8R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-@IM
M<V=I9"`B365X:6-O(@IM<V=S='(@(DWH>&EC(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4*;7-G:60@(DUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EC<F]NZ'-I82P@
M17-T871S($9E9&5R871S(&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T
M<B`B0V5N=')E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5&EP=7,@34E-12(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS9VED(")-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>UN:6UA(&1E(&QE
M<R!D87)R97)E<R`R-"!H;W)E<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,#`*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@
M(E1E;7!E<F%T=7)A(&WM;FEM82!D92!L97,@9&%R<F5R97,@-B!H;W)E<SH@
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-PIM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(E+H<&QI8V$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M36ES8V5LMVQA;FDB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,S.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<Q"FUS
M9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S
M='(@(D9A;'1A(&QA('-O;+=L:6-I='5D($A45%`@<&5R(&%L('!A<75E="!0
M14%2+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*
M(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"B)&86QT82!L82!C;VYF:6=U<F%C:?,N($PG:&5U(&1E
M(&=E;F5R87(@87)A('-I('9O;&5U('5T:6QI='IA<B!A<75E<W1A("(*(F%P
M;&EC86-I\RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,PIM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")&86QT
M82!L)VED96YT:69I8V%D;W(@9&5L(&UI<W-A=&=E+B(*"B,Z(&QI8B].970O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3<*;7-G:60@(DUI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(D9A;'1A(&5L
M(&-O<G)E=2!E;&5C='+R;FEC(&1E;"!P87%U970@4$5!4B!N96-E<W-A<FDN
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B1F%L=&$@;"=I9&5N
M=&EF:6-A9&]R(&1E('-E<W-I\RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")$;"XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S(*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(D-O<G)E=2!M\F)I;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")-;V1E<F%T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8*;7-G:60@(DUO9&EF
M:65D($1A=&4B"FUS9W-T<B`B1&%T82!M;V1I9FEC861A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")-;V1I9GD@55),(@IM<V=S='(@(DUO9&EF:6-A<B!L82!54DPB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"B,L(&9U>GIY"FUS9VED(")-;V1U
M;&4B"FUS9W-T<B`B3?)D=6PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-\F1U;"(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,`IM<V=I
M9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9.!V:6$L(%)E
M</IB;&EC82!D92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T.0IM<V=I9"`B36]N86-O(@IM<V=S='(@(DWR;F%C;R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9_)L:6$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C4Y,@IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS
M9W-T<B`B365S(&D@86YY(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-96YS=6%L;65N="(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,0IM
M<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R(")&87-E<R!L=6YA<G,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@*;7-G:60@
M(DUO<F]C8V\B"FUS9W-T<B`B36%R<F]C(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R(")-86IO<FETX')I86UE;G0@9&5S8V]B97)T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DUO<W1L
M>2!#;&]U9'DB"FUS9W-T<B`B36%J;W)I=.!R:6%M96YT(&5N;G5V;VQA="(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS
M9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B36%J;W)I=.!R:6%M96YT(&%S
M<V]L96QL870B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,C@*
M;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")-;W5R92!C87`@879A;&PB"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S(*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R(")-;W5R92!A(&PG97-Q=65R<F$B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S8*;7-G:60@(DUO=F4@4FEG:'0B"FUS
M9W-T<B`B36]U<F4@82!L82!D<F5T82(*"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C0R-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")-;W5R92!C
M87`@86UU;G0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#DV"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B36]U<F4@8V%P(&%V
M86QL(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y
M-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(DUO=7)E(&-A<"!A;75N="(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R(")-;^=A;6)I8R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B3&ES=&5S(&1E<W!L96=A8FQE<R!E;FQL8>=A9&5S(&5N
M(&1I=F5R<V]S(&YI=F5L;',B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T
M,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS
M(&WZ;'1I<&QE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.2!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,V"FUS9VED(")->2!!8V-O=6YT
M(@IM<V=S='(@(D5L(&UE=2!C;VUP=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C4P"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B16P@;65U
M('!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,C0*;7-G
M:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B1&ES<V5N>2!D96P@;65U
M('!O<G1A;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U-0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")->6%N;6%R(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC
M.C<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").3RP@3D\@
M:&D@97-T:6,@9"=A8V]R9"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DYA;64B
M"FUS9W-T<B`B3F]M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38Y"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;>UB
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S@*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W"FUS9VED(").
M97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W-0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS
M9W-T<B`B4&'O<V]S($)A:7AO<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S"FUS9VED(").971H97)L86YD<R!!;G1I
M;&QE<R(*;7-G<W1R(")!;G1I;&QE<R!.965R;&%N9&5S97,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B55),(&)A<V4@9&4@3F5T<V-A<&4B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E(')E=F]C86-I\R!D92!#
M02!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(E52
M3"!D92!P;VSM=&EQ=65S(&1E($-!(&1E($YE='-C87!E(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W
M86P@55),(@IM<V=S='(@(E523"!D92!R96YO=F%C:?,@9&4@3F5T<V-A<&4B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E(')E=F]C86-I
M\R!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M3F]M(&1E;"!S97)V:61O<B!34TP@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@8V]M;65N="(*;7-G<W1R(")#;VUE;G1A<FD@9&5L(&-E<G1I9FEC
M870@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R
M(")4:7!U<R!D92!C97)T:69I8V%T(&1E($YE='-C87!E(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(S-PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R
M(")887)X82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S8*;7-G:60@(DYE=F5R(@IM<V=S='(@(DUA:2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,`IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R(").;W9A($-A;&5D\FYI82(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(W"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`B3F]V82!C871E9V]R:6$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-SD*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DQL=6YA
M(&YO=F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U
M"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(").;W4@
M;F]M(&0G=7-U87)I("AO<&-I;VYA;"DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`*;7-G:60@(DYE=R!:96%L86YD
M(@IM<V=S='(@(DYO=F$@6F5L86YD82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B
M;&%N:RDB"FUS9W-T<B`B3F]V82!F:6YE<W1R82`H7V5N(&)L86YC*2(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(").
M97=S(@IM<V=S='(@(DUI<W-A=&=E<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.3,*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1W)U<',@
M9&4@9&ES8W5S<VGS(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,S(@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S<*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z-#8*;7-G:60@(DYE>'0B"FUS9W-T<B`B4V5G_&5N="(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R
M("(T(&9A<V5S('-E9_QE;G1S(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HS-C@@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S(*;7-G:60@(DYE>'0@
M;W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS('-E9_QE;G1S(@H*(SH@;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(E-E
M9_QE;G0^(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<T"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<Q"FUS9VED(").:6=E<B(*;7-G<W1R(").[6=E<B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,PIM<V=I9"`B3FEG
M97)I82(*;7-G<W1R(").:6?H<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q.`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3FET(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y"FUS
M9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#@U"FUS9VED(").;R(*;7-G<W1R(").;R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ,38*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(DYO(&5S(&1I<W!O<V5N(&1E(&1A9&5S
M(&1E(&-O;F9I9W5R86-I\R!P97(@;6]S=')A<B!L97,@9&EF97+H;F-I97,N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T
M<B`B3F\@97,@9&ES<&]S82!D)W5N82!E<W1R873H9VEA('!E<B!C<F5A<B!I
M;6%T9V5S($E33RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,@IM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(DYO
M(&AI(&AA('!L86YT:6QL82!D92!L;W1S+B(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C<Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(S
M,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-3(*;7-G:60@(DYO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S
M='(@(DYO(&5X:7-T96EX(&-A<"!B;&]C(&5N(&QA('!O<VEC:?,@<V]LMVQI
M8VET861A(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DYO(',G:&$@<')O<&]R8VEO;F%T('5N(&YO;2!D
M)V%G96YD82!P97(@82!L)V%U=&5N=&EC86-I\R!-0T%,+B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@
M(E-E;G-E(&-A;G9I<RXB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T
M,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O
M(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN(@IM<V=S='(@(DYO(&5S('!O
M9&5N(&%F96=I<B!D97-C96YD96YT<R!A(&%Q=65S="!P97)M[7,B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(DYO
M(&5S('!O9&5N(&%F96=I<B!D97-C96YD96YT<R!A(&%Q=65S="!P97)M[7,B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W-PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@8V]M;6%N9"!S<&5C:69I960N(@IM<V=S='(@(DYO(',G:&$@97-P96-I
M9FEC870@=6X@;F]M+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38W(&QI8B](;W)D
M92YP:'`Z-#<W(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R("5S+B(*;7-G<W1R(").;R!S)VAA(&5S<&5C:69I8V%T(&QE<R!D
M861E<R!D92!C;VYF:6=U<F%C:?,@<&5R(&$@)7,N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<T,0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(DYO(',G:&$@97-P
M96-I9FEC870@;&5S(&1A9&5S(&1E(&-O;F9I9W5R86-I\R!P97(@82!&5%`@
M<&5R(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-3DQ"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&
M4RXB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!L97,@9&%D97,@9&4@
M8V]N9FEG=7)A8VGS('!E<B!A(%-13"!P97(@5D93+B(*"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C<P-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B
M(@HB3F\@<R=H82!E<W!E8VEF:6-A="!L97,@9&%D97,@9&4@8V]N9FEG=7)A
M8VGS(&1E(%-13"!P97(@86P@9FET>&5R(%-13"XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8W)E9&ET(&QE
M9G0N(@IM<V=S='(@(DYO('%U961A(&-RZ&1I="XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`B3F\@<R=H82!F86-I;&ET870@=6YA(&1E
M<W1I;F%C:?,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@96YT<GD@=VET:"!T:&4@:60@)R5S)R!E>&ES
M=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@W,0IM<V=I9"`B3F\@9FEL92!U<&QO
M861E9"(*;7-G<W1R(").;R!S)VAA(&-A<G)E9V%T(&-A<"!A<GAI=2XB"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O
M=6YD+B(*;7-G<W1R(").;R!S)VAA('1R;V)A="!C87`@:6-O;F$N(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(R
M"B,L(&9U>GIY"FUS9VED(").;R!L;V-A;&4@<W!E8VEF:65D+B(*;7-G<W1R
M(").;R!S)VAA(&5S<&5C:69I8V%T('5N(&YO;2XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3(P(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT
M,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,0IM<V=I9"`B3F\@;&]C871I
M;VX@:7,@<V5T+B(*;7-G<W1R(").;R!S)VAA(&1E9FEN:70@=6YA('5B:6-A
M8VGS+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").;R!S)VAA(&9A
M8VEL:71A="!U;F$@=6)I8V%C:?,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB
M"FUS9W-T<B`B3F\@<R=H82!I;G1R;V1U[W0@=6X@;6ES<V%T9V4N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B3F\@
M;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@
M=6X@;F]M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S8*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYO(',G
M:&$@97-P96-I9FEC870@=6YA('AI9G)A+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(DYO(&5S('!E<FUE=&5N(&QE<R!D:71E<R!O9F5N<VEV97,N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E
M;G1I8V%C:?,@2%144"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ
M,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N
M=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@24U!4"XB"@HC.B!L:6(O
M2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E
M;G1I8V%C:?,@2V5R8F5R;W,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,1$%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&EN=')O
M9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@24U!
M4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O
M075T:"]P86TN<&AP.C<U"B,Z(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX
M-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N
M=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@9"=I;FEC:2XB"@HC.B!L
M:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3F\@<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG
M875T96YT:6-A8VGS(%!!4U-71"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N
M<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&EN=')O9'7O="!U;F$@
M8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@4TU"+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@HB3F\@<R=H82!I;F1I8V%T(&QA('9I82!D)V%C
M8^ES(&%L(&)I;F%R:2!/<&5N4U-,+B!#86P@96P@8FEN87)I($]P96Y34TP@
M<&5R("(*(G1R96)A;&QA<B!A;6(@;&5S(&1A9&5S(%!+0U,@,3(N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@
M<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").;R!H:2!H82!A;'1E<R!P96YD
M96YT<RXB"@HC.B!L:6(O5D93+G!H<#HW-C4*;7-G:60@(DYO('%U;W1A('-E
M="XB"FUS9W-T<B`B3F\@<R=H82!D969I;FET(&PG97-P86D@9&ES<&]N:6)L
M92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")396YS92!R96=L
M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")396YS92!C87)E
M<R(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#4*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R(").;R!E>&ES=&5I>"!A<75E<W0@87)X:74B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,P"FUS9VED(").;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(DYO
M(&5S(&1I<W!O<V$@9&4@8V%P(&1I<F5C=&]R:2!T96UP;W)A;"!P97(@82!L
M82!M96WR<FEA(&-A=2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,P"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@
M<V5N="XB"FUS9W-T<B`B3F\@:&5U(&5N=FEA="!E;"!N;VT@9"=U<W5A<FD@
M;FDO;R!L82!C;VYT<F%S96YY82(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C
M+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM
M<V=S='(@(DYO(',G:&%N(')E=&]R;F%T(&1A9&5S(%A-3"!VX&QI9&5S(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,R!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3`S"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HY,30@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDS,0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S
M='(@(E-E;G-E('9A;&]R<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,3D*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B).;R!S)VAA('1R;V)A="!L82!V97)S:?,@96X@;&$@8V]N9FEG=7)A8VGS
M(&]R:6=I;F%L+B!296=E;F5R974@;&$@(@HB8V]N9FEG=7)A8VGS+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(DYO(',G:&$@=')O8F%T(&QA('9E<G-I
M\R!E;B!L82!C;VYF:6=U<F%C:?,N(%)E9V5N97)E=2!L82!C;VYF:6=U<F%C
M:?,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$V('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,@IM<V=I9"`B3F]N
M92(*;7-G<W1R(")#87`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM
M<V=S='(@(D-A<"`H^G,@:6UP;.UC:70I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(D[R<F1I8R`H25-/+3@X-3DM,3`I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R"FUS9VED(").;W)F;VQK($ES;&%N
M9"(*;7-G<W1R("));&QA(&1E($YO<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9F5R:2!N;W)D(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X"FUS9VED
M(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B26QL97,@36%R
M:6%N;F5S(&1E;"!.;W)D(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<V"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R
M=65G82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@069T97(B"FUS9W-T<B`B3F\@9&5S<'+I<R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(DYO(&%B86YS(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S$*;7-G:60@
M(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(").;R#I<R!U;B!D:7)E8W1O<FDB
M"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*;7-G:60@(DYO="!I
M;7!L96UE;G1E9"XB"FUS9W-T<B`B3F\@:6UP;&5M96YT870N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B
M3F]T('-E="(*;7-G<W1R(").;R!D969I;FET(@H*(SH@;&EB+U9&4RYP:'`Z
M,3DS(&QI8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S,@;&EB+U9&4RYP
M:'`Z,C4Q"B,Z(&QI8B]61E,N<&AP.C(V."!L:6(O5D93+G!H<#HR.#0@;&EB
M+U9&4RYP:'`Z,S`P(&QI8B]61E,N<&AP.C,Q-0HC.B!L:6(O5D93+G!H<#HS
M,S(@;&EB+U9&4RYP:'`Z,S8U(&QI8B]61E,N<&AP.C0R-2!L:6(O5D93+G!H
M<#HU,#0*(SH@;&EB+U9&4RYP:'`Z-3<S(&QI8B]61E,N<&AP.C4Y,"!L:6(O
M5D93+G!H<#HV-C@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-#,@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@;&EB+TAO
M<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,@;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H
M<#HR,S0*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYO('!E<FWH
M<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38R"FUS9VED(").;W1E<R(*;7-G
M<W1R(").;W1E<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(DYO(&AI(&AA(')E<R!A('9I<W5A;&ET>F%R+"!R971R;V-E9&EU+B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*(RP@
M9G5Z>GD*;7-G:60@(DYO=&EC92(*;7-G<W1R(").;W1E<R(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R(").;W9E;6)R92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#0V"FUS
M9VED(").=6UB97(B"FUS9W-T<B`B3F]M8G)E(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,S`*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(DYO;6)R92!D92!C87+@8W1E<G,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3,W-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R."!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B
M3F]M8G)E(&1E(&-O;'5M;F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-S(@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C8@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(DYO;6)R92!D
M92!F:6QE<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#,*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*(DYO(',G:&%N(&5S
M<&5C:69I8V%T(&YO;6)R97,@<75E(&AA9VEN(&1E('-E<B!A8W1U86QI='IA
M=',@96X@;&$@;&QI<W1A(&1E("(*(F1I<W1R:6)U8VGS+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-"!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,30X"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S0X"FUS9VED
M(")/2R(*;7-G<W1R(")$)V%C;W)D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Q,0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B
M:F5C=&4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I
M9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B0W)E861O<B!D92!L)V]B:F5C
M=&4B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S<@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!C<F5A=&]R
M('!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<V]S(&1E;"!C<F5A9&]R(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S
M='(@(D]C=&%L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*
M;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3V-T=6)R92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T
M<B`B1FEL=')E(&0G:6YF<F%C8VEO;G,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,CDY"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B3V9I8VEN82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M,0IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(").;VWI<R!E;',@
M<V5R=FED;W)S($E-05`@<&5R;65T96X@;"?Z<R!D92!C87)P971E<R!C;VUP
M87)T:61E<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@
M(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYO;>ES(&UI<W-A
M=&=E<R!O9F5N<VEU<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4Q(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A
M9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DYO;>ES(.ES('!E<FUE<V$@=6YA
M(/IN:6-A(&%D<F7G82!E;&5C='+R;FEC82XB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(DYO
M;>ES(&5L('!R;W!I971A<FD@;R!L)V%D;6EN:7-T<F%D;W(@9&4@<VES=&5M
M97,@<&]T(&-A;G9I87(@;&$@<')O<&EE=&%T(&\@(@HB96QS('!E<FUI<V]S
M(&1E;"!P<F]P:65T87)I('!E<B!A(')E8W5R<V]S(&-O;7!A<G1I=',B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B3V)R:74@96X@=6YA(&YO=F$@9FEN97-T<F$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB17)R;W(@3W!E;E-33#H@;F\@
M<R=H86X@<&]G=70@97AT<F5U<F4@;&5S(&1A9&5S(&1E(&QA('!A<G0@4R]-
M24U%('-I9VYA9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]B<F4@87%U97-T(&5N;&QAYR!E
M;B!U;F$@;F]V82!F:6YE<W1R82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")3:7-T96UA
M(&]P97)A=&EU(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U
M,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C(Y('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P
M8VEO;G,@9"<E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3(*(RP@9G5Z
M>GD*;7-G:60@(D]P=&EO;G,Z(@IM<V=S='(@(D]P8VEO;G,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/
M<F1E<F5D($QI<W0B"FUS9W-T<B`B3&QI<W1A(&]R9&5N861A(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO
M;B(*;7-G<W1R(")/<F=A;FET>F%C:?,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G
M<W1R(")5;FET870@;W)G86YI='IA=&EV82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,S`*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B4R=E
M<W3@(&]R9V%N:71Z86YT(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*
M;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@
M(E!L86YT:6QL82!D)V%P;&EC86-I\R!O<FEG:6YA;"(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L
M('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B4&QA;G1I;&QE<R!O<FEG:6YA
M;',@96X@)7,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M06QT<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R.0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B
M06QT<F$@:6YF;W)M86-I\R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI
M<V]S(&1E;"!P<F]P:65T87)I(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DPG875T96YT:6-A8VGS(%!!32!N;R!E<W3@(&1I<W!O
M;FEB;&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(U,PIM<V=I
M9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA='5R82!D
M:6=I=&%L(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R.3D*
M;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")$861E<R!X:69R
M861E<R!A;6(@4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U
M,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B0VQA=2!01U`@</IB
M;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,S,*;7-G:60@
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%D97,@<VEG
M;F%D97,O>&EF<F%D97,@86UB(%!'4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B0V]D:2!02%`B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R
M("));G3H<G!R970@9"=O<F1R97,@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(E!-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B4&QU9VEM<R!D92!T87)D82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")032!3:&]W97)S(@IM
M<V=S='(@(E!L=6=E<R!D92!T87)D82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")032!3;F]W(@IM<V=S='(@
M(DYE=F%D97,@9&4@=&%R9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(EC@9F5C<R!D92!N974@82!L82!T87)D82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3=6XB"FUS
M9W-T<B`B4V]L(&1E('1A<F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(E1E;7!E<W1E<R!D92!T87)D82(*"B,Z(&QI8B]A<&DN<&AP.C$R.`IM<V=I
M9"`B4%](4"!3:&5L;"(*;7-G<W1R("));G3H<G!R970@9"=O<F1R97,@4%](
M4"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B4V5P87)A8VGS(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W
M"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30*;7-G:60@
M(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@
M5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")497)R:71O<FD@<&%L97-T
M[2P@;V-U<&%T(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@R"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86W@(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YO=F$@
M1W5I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-0IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U86DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM
M<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")087)C:6%L;65N="!E;FYU
M=F]L870B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@S(&QI8B](;W)D92]&;W)M+G!H<#HR,#$X"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S8*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<Q"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3,*;7-G:60@(E!A<W-W;W)D(@IM
M<V=S='(@(D-O;G1R87-E;GEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HQ,S(R"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B
M0V]N=')A<V5N>6$@:6YC;W)R96-T82(*"B,Z(&QI8B](;W)D92]!=71H+W)A
M9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")#86P@:6YT<F]D=6ER('5N
M82!C;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!2041)55,N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D-O;G1R87-E;GEA(&%M8B!C;VYF
M:7)M86-I\R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM
M<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(D-O;G1R87-E;GEA.B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@
M(@IM<V=S='(@(D-O;G1R87-E;GEA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(DQE<R!C;VYT<F%S96YY97,@:&%N(&1E(&-O:6YC:61I
M<BXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S
M=&4B"FUS9W-T<B`B16YG86YX87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B
M;V%R9"(*;7-G<W1R(")%;F=A;GAA<B!D96P@<&]R=&$M<F5T86QL<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G
M:60@(E!A=&@B"FUS9W-T<B`B0V%M[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHT"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@
M(D%L=&5S('!E;F1E;G1S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(D=E;G0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N
M="(*;7-G<W1R(")097)C96YT871G92(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z-@IM<V=I9"`B4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(E)E86QI='IA<B!O<&5R86-I
M;VYS(&1E(&UA;G1E;FEM96YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/R(*;7-G<W1R(")6;VQE=2!R96%L:71Z87(@;W!E<F%C:6]N<R!D
M92!M86YT96YI;65N="!E;B!I;FEC:6%R(&QA('-E<W-I\S\B"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C8T"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV-PIM<V=I9"`B
M4&5R;6ES<VEO;B(*;7-G<W1R(")097)M[7,B"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M
M:7-S:6]N("<E<R<@;F]T(&1E;&5T960N(@IM<V=S='(@(DYO(',G:&$@96QI
M;6EN870@96P@<&5R;>US("<E<R<N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4X
M.`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B4&5R;6ES(&1E
M;F5G870B"@HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.CDS"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R
M-"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C<T"FUS9VED(")097)M:7-S:6]N
M<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A9&]R(&1E('!E
M<FUI<V]S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#4@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B(*;7-G<W1R
M(")?4&5R;6ES;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D1A9&5S('!E<G-O
M;F%L<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X,PIM<V=I9"`B4&5R=2(*;7-G<W1R(")097+Z(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(D%N:6UA
M;',@9&4@8V]M<&%N>6EA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@V"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R
M(")&:6QI<&EN97,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5LZ&9O;B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,38*;7-G:60@(E!H;W1O<R(*;7-G
M<W1R(")&;W1O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A
M:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0[7AE;',B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T
M<B`B5/)P:6-S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL(@IM<V=S='(@(D-L:6-A<B!E;B!U;F$@8V5LMVQA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X
M"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(D-O;F9I<FUA<B!Q=64@=F]L974@
M<W5P<FEM:7(@87%U97-T(&5L96UE;G0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N(@IM<V=S='(@(D-O;F9I<FUA<B!Q=64@=F]L974@9&5S96YL;&'G87(@
M87%U97-T(&5L96UE;G0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-CD*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S
M='(@(DEN=')O9'7O=2!U;B!M97,@:2!U;B!A;GDN(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@
M(DEN=')O9'7O=2!U;B!N;VT@<&5R(&$@;&$@;F]V82!C871E9V]R:6$Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#<*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(DEN=')O9'7O=2!U;F$@
M861R9>=A($E0(';@;&ED82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U
M.`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B26YT<F]D
M=>]U('5N82!D871A(';@;&ED82P@8V]M<')O=F5U(&5L<R!D:65S('%U92!T
MZ2!E;"!M97,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-#D*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(DEN=')O9'7O
M=2!U;F$@:&]R82!VX&QI9&$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]P;W)C:6]N974@=6X@<F5S=6T@
M9&5L('!R;V)L96UA+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3@@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,@IM<V=I9"`B4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B
M4')O<&]R8VEO;F5U(&5L(&YO;2!D)W5S=6%R:2!I(&QA(&-O;G1R87-E;GEA
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC
M.C$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H
M92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3&QE
M9VEU(&5L('1E>'0@<V5G_&5N="X@2&5U(&0G86-C97!T87(@;&5S(&-O;F1I
M8VEO;G,@<&5R('!O9&5R('5T:6QI='IA<B!E;"`B"B)S:7-T96UA+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ-PIM<V=I9"`B4&QE87-E(')E<&]R="!A
M;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G
M:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T
M<B`B5&5C;&5G974@96P@;F]M(&1E(&QA(&YO=F$@8V%T96=O<FEA.B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.`IM
M<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;/)N:6$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;.UT
M:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B
M4&]L;',B"FUS9W-T<B`B16YQ=65S=&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,PIM<V=I9"`B4&]R='5G86PB
M"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B0V]LMVQO8V%C:?,@9"=A<75E
M<W1A(&EM871G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M(@IM<V=S='(@(D-O;+=L;V-A8VGS(&0G87%U97-T82!T875L82(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T
M;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@
M(D5N=FEA<B!A(&%Q=65S=&$@8V%R<&5T82`H;F\@:&D@;V)L:6=A($E-05`I
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F
M;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4')E8VEP:71A8VGS(&1U
M<F%N="!L82!D87)R97)A("5S(&AO<F$@;R!H;W)E<SH@(@H*(SH@;&EB+TAO
M<F1E+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7VQD87`Z($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@3$1!4"!S;VRW;&EC
M:71A9&$N(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS
M9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ($YO(',G:&$@
M=')O8F%T(&PG97AT96YS:?,@9&4@<V5S<VGS('-O;+=L:6-I=&%D82XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,PIM<V=I9"`B4')E<W-U<F4B"FUS
M9W-T<B`B4')E<W-I\R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4W"FUS
M9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R(")0<F5S<VGS
M(&%L(&YI=F5L;"!D96P@;6%R.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C<*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B4')E<W-I
M\SH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B5FES=6%L:71Z
M86-I\R!P<NAV:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")6:7-U86QI='IA<B!P<NAV
M:6%M96YT(&QA(&EM871G92!E;B!U;F$@;F]V82!F:6YE<W1R82(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,S4X(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,S8R"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D]P8VEO
M;G,@<'+H=FEE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(DEM
M<')I;6ER(&5L(&1O8W5M96YT(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$R"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")#;&%U('!R:79A
M9&$B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M
M(@IM<V=S='(@(E!R;V)L96UA(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R
M:7!C:?,@9&5L('!R;V)L96UA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(Q,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5C=&5S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q.#@*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E1E>'0@:6YD:6-A
M9&]R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(D-L874@</IB;&EC82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R
M:71H;2(*;7-G<W1R(")!;&=O<FES;64@9&4@8VQA=2!P^F)L:6-A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+
M97D@26YF;R(*;7-G<W1R("));F9O<FUA8VGS(&1E(&-L874@</IB;&EC82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(S,`IM<V=I9"`B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B3F\@<R=H82!G96YE<F%T(&-O<G)E8W1A;65N="!L82!P87)E
M;&QA(&1E(&-L875S('#Z8FQI8V$O<')I=F%D82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T
M;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-@IM<V=I9"`B46%T87(B
M"FUS9W-T<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C(*;7-G
M:60@(E%U97)Y(@IM<V=S='(@(D-O;G-U;'1A(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B0VQA=2!P^F)L:6-A(%)302`H
M)60@8FET*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8T"FUS9VED(")2
M861I;R!S96QE8W1I;VXB"FUS9W-T<B`B0F]T\R!D92!S96QE8V-I\R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED
M(")286EN(@IM<V=S='(@(E!L=6IA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`B4&QU:F$@82!P<FEM97)A(&AO<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4F%I;B!,871E(@IM<V=S
M='(@(E!L=6IA(&-A<"!A;"!T87)D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S
M='(@(E)U:7AA="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(E!L=6IA
M(&D@;F5W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#4*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")!:6=U86YE=2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R
M='5N92(*;7-G<W1R(")$:71A(&%L96%T\G)I82(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<S(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8X"FUS9VED(")2871I;R(*;7-G<W1R(")296QA8VGS(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS
M9W-T<B`B3&QE9VEU(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DQL96=I=2!E
M;',@;6ES<V%T9V5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")#
M;VYF:7)M974@<75E('9O;&5U('-U<')I;6ER("5S/R!!<75E<W1A(&]P97)A
M8VGS(&YO(&5S('!O="!D97-F97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)#;VYF:7)M974@<75E('9O
M;&5U('-U<')I;6ER(&QE<R!D861E<R!D92!L)W5S=6%R:2!P97(@82!L)W5S
M=6%R:2`E<S\@(@HB07%U97-T82!O<&5R86-I\R!N;R!E<R!P;W0@9&5S9F5R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E1O
M<FYA(&$@9F5R(&QA(&1A<G)E<F$@86-C:?,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SHB"FUS9W-T<B`B4F5F<F5S8V%R(&5L<R!E;&5M96YT<R!D96P@;65N
M^B!D:6[@;6EC<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*;7-G
M:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E)E9G)E<V-A<B!L
M82!V:7-U86QI='IA8VGS(&1E;"!P;W)T86PB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#DT(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$S(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")%>'!R97-S:?,@
M<F5G=6QA<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C0W"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(").879E9V%D;W(@9&4@<F5L
M86-I;VYS(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C0*;7-G:60@(E)E
M;6%R:W,B"FUS9W-T<B`B0V]M96YT87)I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E-E
M<G9I9&]R<R!R96UO=',B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AE;7!L92YE
M<R]H;W)D92DZ(@IM<V=S='(@(E523"!R96UO="`H:'1T<',Z+R]W=W<N97AE
M;7!L92YE<R]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q
M"FUS9VED(")296UO=F4B"FUS9W-T<B`B4W5P<FEM:7(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*
M;7-G<W1R(")3=7!R:6UI<B!B;&]C(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4R.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G
M<W1R(")3=7!R:6UI<B!C;VQU;6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I
M;F<B"FUS9W-T<B`B4W5P<FEM:7(@;&$@9F]R;6%T86-I\R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3,V"FUS9VED(")296UO=F4@<&%I<B(*
M;7-G<W1R(")3=7!R:6UI<B!L82!P87)E;&QA(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(P-0IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(E-U<')I
M;6ER(&QA('-E<?SH;F-I82!D97-A9&$@9&5L(&1I<F5C=&]R:2!T96UP;W)A
M;"!D96P@<V5R=FED;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")296UO=F4@=&AE(@IM
M<V=S='(@(E-U<')I;6ER(&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E-U<')I;6ER(&%Q
M=65S="!N;V1E(&1E;"!D;V-U;65N="(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,38*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@
M(E-U<')I;6ER(&PG=7-U87)I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R(")3=7!R:6UI<B!L)W5S=6%R:3H@)7,B"@HC.B!L:6(O
M2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(')E<W!O;F1R92!A(&QA('-O;+=L:6-I='5D+B!#
M;V1I(&0G97)R;W(@<F5T;W)N870Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B870@96P@<V5R
M=F5I('-O;+=L:6-I=&%T+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<T(&QI8B](
M;W)D92YP:'`Z-#@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!E;"`G)7,G(&YE8V5S<V%R
M:2!E;B!L82!C;VYF:6=U<F%C:?,@9&4@)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C<T-R!L:6(O5D93+W-Q;"YP:'`Z-3DW(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C<Q,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M)R5S)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(").;R!S)VAA(&5S<&5C:69I8V%T(&5L("<E<R<@;F5C97-S87)I('!E
M<B!A(&QA(&-O;F9I9W5R86-I\R!61E,N(@H*(SH@;&EB+TAO<F1E+U5T:6PN
M<&AP.C<X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(DYO(',G:&$@97-P96-I9FEC870@96P@)R5S)R!N96-E<W-A<FD@<&5R(&$@
M;&$@8V]N9FEG=7)A8VGS+B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R
M+G!H<#HS,C@*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(D-A;7`@
M<V]LMVQI8VET870B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S,Y(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,34*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-"!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS9VED(")297-E="(*;7-G<W1R
M(")296EN:6-I82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")296EN:6-I87(@;&$@
M8V]N=')A<V5N>6$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")296EN:6-I
M87(@;&$@8V]N=')A<V5N>6$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@
M861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-0IM
M<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")297-U;'1A=',B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#(Q"FUS9VED(")297-U;'1S("AI;F-L=61I;F<@2&]R
M9&4I.B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$Y"B,L
M(&9U>GIY"FUS9VED(")297-U;'1S.B(*;7-G<W1R(")297-U;'1A=',B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S
M='(@(E1O<FYA(&$@;W!C:6]N<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T
M<B`B4F5U;FGS(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")297-T875R87(@;&$@8V]N9FEG=7)A8VGS(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,`IM<V=I9"`B4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;G,@9&4@;"=E9&ET;W(@9&4@
M=&5X="!E;G)I<75I="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM
M<V=I9"`B4FED9&QE<R(*;7-G<W1R(")%;FEG;65S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2
M:6=H="(*;7-G<W1R(")$<F5T82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,3$Y"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B0V%PYV%L97)A(&1R
M971A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,34*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R(")686QO<G,@9&4@;&$@9')E=&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*
M;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P:65T871S
M(&1E(&QA(&9I;&$N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")&=6YC:?,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX"FUS
M9VED(")2;VUA;FEA(@IM<V=S='(@(E)O;6%N:6$B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`X"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(D=I<F%R(#$X,"(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,#4*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@
M(D=I<F%R(&$@;"=E<W%U97)R82(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,3$*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M(")':7)A<B!A(&QA(&1R971A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I
M97,B"FUS9W-T<B`B4')O<&EE=&%T<R!D92!L82!F:6QA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I
M9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE=&%T<R!D92!L82!F
M:6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(D9I;&5S.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G
M:60@(E)U;&5S(@IM<V=S='(@(E)E9VQE<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS
M9W-T<B`B07!A<F5I>&5R86X@<F5G;&5S(&5N=')E('1O=&5S(&QE<R!F:6QE
M<R!I(&-O;'5M;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B07!A<F5I>&5R86X@<F5G
M;&5S(&YO;>ES(&5N=')E(&-O;'5M;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B07!A<F5I
M>&5R86X@<F5G;&5S(&YO;>ES(&5N=')E(&9I;&5S(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(D5X96-U=&%R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M.0IM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(D9E9&5R86-I
M\R!2=7-S82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#`*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=V%N9&$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA='5R82!C
M<FEP=&]G<N!F:6-A(&%M8B!3+TU)344B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(DUI<W-A=&=E('AI9G)A="!A;6(@4R]-24U%(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=A=71E;G1I8V%C
M:?,@4T%33"!N;R!E<W3@(&1I<W!O;FEB;&4N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0U,`IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M(")-:7-S871G97)I82!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*
M;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("));G3H<G!R970@9"=O<F1R97,@
M4U%,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V,0IM<V=I9"`B
M4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R
M("+(6$E4(@H*(SH@;&EB+V%P:2YP:'`Z,3,R"FUS9VED(")37U%,(%-H96QL
M(@IM<V=S='(@(DEN=.AR<')E="!D)V]R9')E<R!344PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*
M;7-G<W1R(")$<RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`W"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B
M4V%I;G0@2&5L96YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,Q"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B4V%I;G0@0VAR:7-T;W!H97(@:2!.979I<R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.0IM<V=I9"`B
M4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y"FUS9VED(")3
M86EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT+5!I97)R
M92UE="U-:7%U96QO;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#0*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@:2!L97,@1W)E
M;F%D:6YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")-
M871E:7@@;6%R8R`H7W-E;&8I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M4V%M;V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$R"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I
M;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$V"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B
M4V%O(%1O;>D@:2!0<NUN8VEP92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E!R
M;W9E[V1O<B!D92!S873H;+=L:70B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D:2!!<F%B:6$B
M"FUS9W-T<B`B07+@8FEA(%-A=61I=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B1&5S82(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B1&5S82`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@)R5S)R(*;7-G<W1R(")$97-A("5S(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM
M<V=S='(@(D1E<V$@;&5S(&]P8VEO;G,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<P"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D1E<V5U(&QA(&-O;F9I9W5R
M86-I\R!G96YE<F%D82!C;VT@=6YA('-E<?SH;F-I82!02%`@96X@96P@9&ER
M96-T;W)I("(*(G1E;7!O<F%L(&1E;"!S97)V:61O<BXB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")3)VAA(&1E<V%T(&QA(&-O
M;F9I9W5R86-I\R!D92`E<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N(@IM<V=S='(@(E,G:&$@9&5S870@
M;&$@<V5Q_.AN8VEA(&%C='5A;&ET>F%D82!D92!C;VYF:6=U<F%C:?,@83H@
M)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-@IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(E1E;7!E
M<W1E<R!D:7-P97)S97,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*
M;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B0VGH;F-I82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B0V5R8V$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<V"FUS9VED(")396%R8V@@
M16YG:6YE<R(*;7-G<W1R(")-;W1O<G,@9&4@8V5R8V$B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30T.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<R(*;7-G<W1R(")/
M<&-I;VYS(&1E(&-E<F-A(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BXB
M"FUS9W-T<B`B3W!C:6]N<R!D92!C97)C82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3<Q"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B4V5L96-C
M:6]N87(@96QS(&%R>&EU<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-38*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
M4V5L96-C:6]N87(@=6YA(&1A=&$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S
M='(@(E-E;&5C8VEO;F%R('5N(&=R=7`@<75E('9U;&=U974@869E9VER(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T
M(&$@;F5W(&]W;F5R(@IM<V=S='(@(E-E;&5C8VEO;F5U('5N(&YO=2!P<F]P
M:65T87)I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS
M9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B4V5L96-C:6]N974@=6X@
M<V5R=FED;W(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM
M<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N
M974@=6X@=7-U87)I('%U92!V=6QG=65U(&%F96=I<B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-C8Q"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N
M96YT<RXB"FUS9W-T<B`B4V5L96-C:6]N974@=&]T<R!E;',@96QE;65N=',@
M9&4@;&$@9&%T82XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#$Q"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E-E
M;&5C8VEO;F5U('5N(&]B:F5C=&4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E
M9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD
M("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B
M"B)396QE8V-I;VYE=2!E;',@8V%RX&-T97)S('%U92!N96-E<W-I=&5U(&1E
M(&QE<R!C87-E;&QE<R!D92!S;W1A+B!0;V1E=2`B"B)C;W!I87(M;&]S(&D@
M96YG86YX87(M;&]S(&1E(&PGX')E82!D92!T97AT+B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.B(*;7-G<W1R(")396QE8V-I;VYA<B!E;"!D96QI;6ET861O<B!D
M92!L82!D871A.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I
M;VYA<B!E;"!F;W)M870@9&4@;&$@9&%T83HB"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.C@Y"FUS9VED(")396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B4V5L96-C:6]N
M87(@;&$@:61E;G1I=&%T('%U92!V;VQE=2!Q=64@8V%N=FEA<CHB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-C:6]N87(@96P@9&5L:6UI
M=&%D;W(@9&4@;"=H;W)A.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")3
M96QE8V-I;VYA<B!E;"!F;W)M870@9&4@;"=H;W)A.B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-C0*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+B(*;7-G<W1R(")396QE8V-I;VYA<B!D;W,@8V%M<',@<75E
M(&-O:6YC:61E:7AI;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDV
M"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E-E
M;&5C8VEO;F%R(&QA(&-O;6)I;F%C:?,@9&4@8V]L;W)S+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4V5L96-C:6]N87(@;"=I9&EO;6$@
M<')E9F5R:70Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B16YV:6%R
M(&PG:6YF;W)M92!D96QS('!R;V)L96UE<R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C$*;7-G:60@(E-E;F0@4TU3(@IM<V=S
M='(@(D5N=FEA<B!335,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$S"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E
M;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-`IM<V=I9"`B4V5N
M<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@R(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E=&5M
M8G)E(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I
M9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E/H<F)I82!I($UO
M;G1E;F5G<F\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM
M<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@<^AR:64B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),
M97,@9&%D97,@9&5L('-E<G9I9&]R('/S;B!I;F-O<G)E8W1E<R!O(&YO(&5S
M=&%N(&1I<W!O;FEB;&5S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDQ"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S
M='(@(DAA(&-A9'5C870@;"=I9&5N=&EF:6-A9&]R(&1E('-E<W-I\RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q,@IM<V=I9"`B4V5T(@IM<V=S='(@
M(D1E9FEN96EX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED
M(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(D1E9FEN
M96EX(&QE<R!O<&-I;VYS('%U92!U<R!P97)M971E;B!R96EN:6-I87(@;&$@
M8V]N=')A<V5N>6$@<VD@;6%I("(*(FPG;V)L:61E=2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB
M"FUS9W-T<B`B1&5F:6YI=2!E;',@<V5R=FED;W)S(')E;6]T<R!A('%UZ"!V
M;VQE=2!A8V-E9&ER(&1E<R!D96P@<&]R=&%L+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("(B"B)$
M969I;FEU(&5L('9O<W1R92!I9&EO;6$@<')E9F5R:70L(&QA('IO;F$@:&]R
MX')I82!I(&QE<R!O<&-I;VYS(&1E(&1A=&$N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB1&5F:6YI=2!L
M)V%P;&EC86-I\R!D)VEN:6-I+"!L82!C;VUB:6YA8VGS(&1E(&-O;&]R<RP@
M96P@<F5F<F5S8V%M96YT(&1E(&QE<R`B"B)PX&=I;F5S(&D@86QT<F5S(&]P
M8VEO;G,@9&4@=FES=6%L:71Z86-I\RXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<T"FUS9VED(")3971U<"(*;7-G<W1R(")#;VYF:6=U<F%C:?,B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS.0IM<V=I
M9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")(
M:2!H82!S97'\Z&YC:65S(&0G86-T=6%L:71Z86-I\R!D92!L82!C;VYF:6=U
M<F%C:?,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<X"FUS
M9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z("(*;7-G<W1R(")(:2!H82!D:79E<G-E<R!U8FEC86-I;VYS('!O
M<W-I8FQE<R!A;6(@96P@<&%RX&UE=')E.B`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S"FUS9VED(")397EC:&5L
M;&5S(@IM<V=S='(@(E-E>6-H96QL97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0R"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")#;VUP<F5S
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@
M(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4F5S=6T@8G)E=2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,S8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")6;VQE=2!D
M969I;FER(&QE<R!C;&%U<R!D)V%C8^ES('!E<B!A(&QA(&UA:F]R('!A<G0@
M9"=E;FQL8>=O<S\B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y,B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")-;W-T<F$B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,34X"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(DUO<W1R82!L97,@9&EF97+H
M;F-I97,@96YT<F4@;&$@8V]N9FEG=7)A8VGS(&1E<V%D82!I(&QA(&YO=F$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X,`IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")6;VQE
M=2!V:7-U86QI='IA<B!L)VAO<F$@9&4@;&$@9&%R<F5R82!S97-S:?,@96X@
M:6YI8VEA<C\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")-;W-T<F$@
M;"=O<&-I\R!D92!C;VYS97)V87(@;"=O<FEG:6YA;"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#$Q"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")-
M;W-T<F$@96P@8V%P='5R861O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,34*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B
M"FUS9W-T<B`B5F]L974@=FES=6%L:71Z87(@;&$@8F%R<F$@9&4@;65N^B!D
M)V]P97)A8VEO;G,@9&4@=&%U;&$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/R(*;7-G<W1R(")6;VQE=2!V:7-U86QI='IA<B!E;"!M
M96[Z("5S(&1E(&PG97-Q=65R<F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R
M82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!C96RW;&$@9&4@=&%U;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C,*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(DUO<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D
M92!T875L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R82!E;"!D:>!L96<@9&4@
M<')O<&EE=&%T<R!D92!F:6QA(&1E('1A=6QA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")-;W-T
M<F$@96P@9&G@;&5G(&1E('!R;W!I971A=',@9&4@:6UA=&=E(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$W-C<*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S
M='(@(DUO<W1R82!L82!CX')R96=A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B
M4G5I>&%T<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0X"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(E)U:7AA=',@
M82!P<FEM97)A(&AO<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.0IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(E)U
M:7AA=',@8V%P(&%L('1A<F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI
M='DB"FUS9W-T<B`B4G5I>&%T<R!A(&QA(')O9&%L:6$B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HS.3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R
M(")2961U[W4B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HV.3(@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S4T"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C@Q,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HX-S0*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3`Y(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.CDT-@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HY-S0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`P
M-`IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E!R:6UE<B!R961U[W4@
M;R!A<&%R=&5U(&5L*',I(&)L;V,H<RD@9&5L(&-O<W1A="(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R(")$;VYE=2UV;W,@9"=A;'1A(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY,`IM<V=I9"`B4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM
M<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA='5R82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG
M;W)I=&AM(@IM<V=S='(@(D%L9V]R:7-M92!D92!S:6=N871U<F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V"FUS
M9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P=7(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.#DV(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C,W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V
M(&QI8B](;W)D92]&;W)M+G!H<#HR.3(X(&QI8B](;W)D92]&;W)M+G!H<#HS
M,3(Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8Y(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8U"FUS9VED(")3:7IE(@IM<V=S='(@(DUI9&$B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VUE="!M86YT
M96YI;65N="(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S$@<&\O=')A;G-L
M871I;VXN<&AP.C0X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8V"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HX-C`@<&\O=')A;G-L871I;VXN<&AP.C$R,C,*;7-G
M:60@(E-K:7!P960N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,`IM<V=I9"`B4VQO=F%K:6$B
M"FUS9W-T<B`B17-L;W;@<75I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S
M='(@(D5S;&]VZ&YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"FUS9VED(")3;F]W(@IM<V=S='(@(DYE=F%D82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3;F]W(%-H;W=E<B(*;7-G<W1R(")8X&9E8R!D92!N974B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VYO
M=R!3:&]W97)S(@IM<V=S='(@(EC@9F5C<R!D92!N974B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R!3
M:&]W97)S($5A<FQY(@IM<V=S='(@(EC@9F5C<R!D92!N974@82!P<FEM97)A
M(&AO<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-0IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B6.!F96-S
M(&1E(&YE=2!C87`@86P@=&%R9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C<V"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B1W)U:7@@9&4@;F5U
M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B17%U:79A;&5N="!D92!L
M82!N974@96X@86EG=6$Z("(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#(*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*
M;7-G<W1R("));&QE<R!386QO;?,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA(@IM<V=S
M='(@(E-O;>!L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G
M:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B0V%NYV]N<R!I('!O96UE<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3(T"FUS9VED(")3;W)T(&]R9&5R
M('-E;&5C=&EO;B(*;7-G<W1R(")396QE8V-I\R!E;B!E;"!S96YT:70@9&4@
M;&$@8VQA<W-I9FEC86-I\R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C$V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C0V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3@@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.`IM<V=I9"`B4V]U<F-E
M(&%D9')E<W,B"FUS9W-T<B`B061R9>=A(&0G;W)I9V5N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-0IM<V=I9"`B
M4V]U=&@@069R:6-A(@IM<V=S='(@(E-U9"W@9G)I8V$B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX
M.#4Y+3,I(@IM<V=S='(@(E-U9"UE=7)O<&5U("A)4T\M.#@U.2TS*2(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,0IM
M<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',B"FUS9W-T<B`B1V7R<F=I82!D96P@4W5D(&D@;&5S(&EL;&5S(%-A
M;F1W:6-H(&1E;"!3=60B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(DAE;6ES9F5R:2!S=60B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")%<W!A:2!E;G1R92!C96RW;&5S
M(&%D:F%C96YT<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD
M(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(D5S<&%I(&5N=')E(&5L(&-O;G1I
M;F=U="!I(&5L(&-O;G1O<FX@9&4@;&$@8V5LMVQA(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D5S<&%I861O
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")%<W!A:6%T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")%<W!A:6%T
M(&D@9F%R8VEM96YT(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#`*;7-G:60@(E-P86EN(@IM<V=S='(@(D5S<&%N>6$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.38*;7-G:60@(E-P86TB
M"FUS9W-T<B`B0V]R<F5U(&)R;W-S82(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`B17-C<FEP='5R82!D92!C87+@8W1E<G,@97-P96-I86QS(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM
M<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")$:79I9&ER(&-E;+=L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")$:79I9&ER(&-O;'5M
M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B1&EV:61I<B!F
M:6QA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R
M=',B"FUS9W-T<B`B17-P;W)T<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S
M='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED(")3=&%N9&%R9"(*
M;7-G<W1R(")%<W3@;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P
M-PIM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!;GD@9"=I;FEC:2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O
M<B!0<F]V:6YC92(*;7-G<W1R(")%<W1A="!O('!R;W;M;F-I82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T
M=7,B"FUS9W-T<B`B17-T870B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E-T871U<R!F;W(@;&]C86QE("5S+BXN
M("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q,PIM<V=I
M9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R;6%T(&0G96UM86=A='IE
M;6%T9V4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I
M9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B061R9>=A('!A<G1I8W5L87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(D)A<G)A="(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G
M<W1R("),;&ES=&$@9&4@8V%D96YE<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*
M;7-G<W1R(")%;&EM:6YE=2!E;"!D;VUI;FD@9&4@;"=A9')EYV$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S
M"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")%<W1I;"!;0U-372(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G
M:60@(E-U(@IM<V=S='(@(D1G+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y
M("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA('1R;V)A="!E;"!S
M=6)D:7)E8W1O<FD@("<E<R<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B07-S=6UP
M=&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M
M+U)E;F1E<F5R+G!H<#HS,3(*;7-G:60@(E-U8FUI="(*;7-G<W1R(")%;G9I
M82(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(E,G:&$@=')A;>AS
M('5N82!S;VRW;&EC:71U9"!P97(@869E9VER("<E<R<@86P@<VES=&5M82X@
M3F\@<&]D974@:6YI8VEA<B!L82`B"B)S97-S:?,@9FEN<R!Q=64@<R=H86=I
M(&%P<F]V870@;&$@<V]LMVQI8VET=60N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM
M<V=S='(@(E-U8NUN9&5X(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-2!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*
M;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BR'AI="(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")3)VAA(&%F
M96=I="!C;W)R96-T86UE;G0@)R5S)R!A;"!S:7-T96UA+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B4R=H86X@96QI;6EN870@8V]R<F5C=&%M96YT
M(&1E;"!S:7-T96UA(&QE<R!D861E<R!D92!L)W5S=6%R:2`G)7,G+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O9&5L971E+G!H<#HV
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E
M;&5T960@)R5S)RXB"FUS9W-T<B`B4R=H82!S=7!R:6UI="!C;W)R96-T86UE
M;G0@)R5S)RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R(")3)VAA('-U<')I;6ET(&-O<G)E8W1A
M;65N="`G)7,G(&1E;"!S:7-T96UA+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U
M<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(E,G
M:&$@<F5S=&%U<F%T(&-O<G)E8W1A;65N="!L82!C;VYF:6=U<F%C:?,N($%C
M='5A;&ET>F5U('!E<B!V975R92!E;',@(@HB8V%N=FES+B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C4U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU
M.0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")3)VAA(&1E<V%T(&-O<G)E8W1A;65N="!L82!C;VYF
M:6=U<F%C:?,@9&4@8_)P:6$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(E,G
M:&$@9&5S870@8V]R<F5C=&%M96YT(&PG87)X:74@9&4@;&$@8V]N9FEG=7)A
M8VGS(&1E(&/R<&EA("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M)R5S)R(*;7-G<W1R(")3)VAA(&%C='5A;&ET>F%T(&-O<G)E8W1A;65N="`G
M)7,G(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('=R;W1E("5S(@IM<V=S='(@(E,G:&$@97-C<FET(&-O<G)E8W1A;65N
M="`G)7,G(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V
M"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E)E<W5M(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8V"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")3;W)T
M:61A(&1E;"!S;VPB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-S$*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`B4&]S=&$@9&5L('-O;"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3=6YN
M>2(*;7-G<W1R(")!<W-O;&5L;&%T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")3;W)T:61A
M(&1E;"!S;VPB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S
M='(@(E-O<G1I9&$@9&5L('-O;"]0;W-T82!D96P@<V]L(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<FES93H@(@IM
M<V=S='(@(E-O<G1I9&$@9&5L('-O;#H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(E!O<W1A
M(&1E;"!S;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$P
M"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")0;W-T82!D96P@<V]L.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G
M:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(E-U<&5R[6YD97@B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,T"FUS9VED(")3=7!P;W)T(@IM<V=S
M='(@(D%S<VES=.AN8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B
M4W5R:6YA;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS
M9VED(")3=7)N86UE(@IM<V=S='(@(D-O9VYO;2(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#D*;7-G:60@(E-V86QB
M87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@:2!*86X@36%Y
M96XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$Y"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FELX&YD:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`U"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W7H8VEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-38*;7-G:60@(E-W
M:71Z97)L86YD(@IM<V=S='(@(E-U[W-S82(*"B,Z(&QI8B](;W)D92]344PO
M2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H
M('1E<FUS(@IM<V=S='(@(D5R<F]R(&1E('-I;G1A>&D@96X@96QS('1E<FUE
M<R!D92!C97)C82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM
M<V=S='(@(E)E</IB;&EC82#`<F%B(%-I<FEA;F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B5"U3=&]R;2(*
M;7-G<W1R(")496UP97-T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G
M<W1R(")496UP97-T82!I('9E;G3S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R
M(")496UP97-T97,B"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM
M<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B07)X:74@5%-6(@H*(SH@;&EB+TAO
M<F1E+U5)+U1A8FQE+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM
M<V=S='(@(E1A=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*
M;7-G<W1R(")0<F]P:65T871S(&1E('1A=6QA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B
M;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P:65T871S(&1E('1A=6QA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S0*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486EW86XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A:7=A;BP@<')O=NUN
M8VEA(&1E(&QA(%AI;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(U"FUS9VED(")486II:VES=&%N(@IM<V=S='(@
M(E1A9&II:VES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S-0IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9B(*;7-G<W1R(")486YZX&YI82P@4F5P^F)L:6-A(%5N:61A(&1E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")/8FIE8W1I=3HB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<Q"FUS9VED(")487-K<R(*;7-G<W1R
M(")487-Q=65S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*
M;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E('1E
M;.AF;VXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.`IM<V=I9"`B5&5M
M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@9'5R86YT
M(&QA(&1A<G)E<F$@:&]R83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,3(*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B5&5M
M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5R83H@(@H*(SH@;&EB+TAO
M<F1E+U1E;7!L871E+G!H<#HR,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1E;7!L871E("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA
M('1R;V)A="!L82!P;&%N=&EL;&$@)R5S)RXB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B061M:6YI<W1R86-I\R!D92!P;&%N=&EL;&5S(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,3$*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C4*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R(").;VWI<R!T97AT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG
M;B(*;7-G<W1R(")!;&EN96%C:?,@9&4@=&5X="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B06QI;F5A="!A(&1A;'0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")$
M:BXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H
M5$E3+38R,"DB"FUS9W-T<B`B5&%I;&%N9.AS("A425,M-C(P*2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0*;7-G
M:60@(E1H86EL86YD(@IM<V=S='(@(E1A:6S@;F1I82(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HY,#,*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P
M-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE("5S(&AE;'`@9FEL92!F;W(@
M)7,@9&]E<VXG="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<S-PIM<V=I9"`B5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=E>'1E
M;G-I\R!&5%`@;F\@97-TX"!D:7-P;VYI8FQE+B(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+
M;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S
M7"(B"FUS9W-T<B`B16P@;6]T;W(@9"=I;G1E9W)A8VGS($AO<F1E+TMO;&%B
M(&YO('!E<FUE="!L)_IS(&1E(%PB)7-<(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("),82!C;&%S<V4@
M36%I;G1E;F%N8V4Z.B!N;R!S)VAA(&-A<G)E9V%T(&-O<G)E8W1A;65N=",C
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I
M9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(E,G:&$@=&%N8V%T(&QA(&9I;F5S=')A(&0G;W!C:6]N<RX@4V]R
M=&EN="!D96P@<VES=&5M82(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,34X
M(&QI8B](;W)D92]097)M<RYP:'`Z,38Y(&QI8B](;W)D92]097)M<RYP:'`Z
M,3@P"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3DR(&QI8B](;W)D92]097)M
M<RYP:'`Z,C`S(&QI8B](;W)D92]097)M<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,C,S(&QI8B](;W)D92]097)M<RYP:'`Z,C<R"FUS9VED
M("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(E-I('9O;&5U('5T:6QI
M='IA<B!E;',@<&5R;6ES;W,L(&PG861M:6YI<W1R861O<B!H82!D92!C;VYF
M:6=U<F%R('5N(&UO=&]R("(*(F1E('!E<FUI<V]S('!E<FUA;F5N="XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(").;VWI
M<R!E;"!C;VYT;W)N(&EN9F5R:6]R(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B)%;"!N^FUE
M<F\@:61E;G1I9FEC861O<B!D96P@8V]N=&%C=&4@;F\@<R=H82!E<W!E8VEF
M:6-A="P@<R=H82!D96EX870@96X@(@HB8FQA;F,@;R!N;R!S)VAA('1R;V)A
M="!A(&QA(&)A<V4@9&4@9&%D97,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M4R=H82!A9F5G:70@8V]R<F5C=&%M96YT(&5L(&-O;G1A8W1E(&$@;&$@;&QI
M8G)E=&$@9"=A9')E8V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$Q-#D*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(D5S(&YE8V5S<VET82!E;"!B;&]C(&1E('-I9VYA='5R
M97,@4$=0('-E<&%R870@<&5R('9E<FEF:6-A<B!E;"!M:7-S871G92`B"B)S
M:6=N870N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,`IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB
M:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B),)VED96YT:69I8V%D;W(@
M9&4@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS(&YO(',G:&$@97-P96-I9FEC
M870L(',G:&$@9&5I>&%T("(*(F5N(&)L86YC(&\@;F\@<R=H82!T<F]B870@
M82!L82!B87-E(&1E(&1A9&5S+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#$*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A
M="!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(DQE<R!C
M87)A8W1E<NUS=&EQ=65S(&1E;"!X:69R871G92!E>&EG96EX96X@=6YA(&-O
M;FYE>&GS('=E8B!F:6%B;&4N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S4@;&EB
M+TAO<F1E+G!H<#HT.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("),)V%R
M>&EU("5S(&AA=7)I82!D92!C;VYT96YI<B!U;B!P87+@;65T<F4@)7,N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-C@@;&EB+TAO<F1E+G!H<#HT-S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B3"=A<GAI=2`E<R!H875R:6$@9&4@
M8V]N=&5N:7(@86QG=6YS('!A<N!M971R97,@)7,N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@
M8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("),)V%R>&EU(&YO(&-O
M;G1E;FEA(&1A9&5S+B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-C`*;7-G
M:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("),)V%R
M>&EU(&YO(&-O;G1E;FEA(&1A9&5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T
M:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*
M;7-G<W1R("(B"B)!(&-O;G1I;G5A8VGS(&5S('!R97-E;G1E;B!L97,@8V%P
MYV%L97)E<R!D)V%Q=65S="!M:7-S871G92]M:7-S871G92!R9F,X,C(N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM
M<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y
M+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W
M<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+B(*;7-G<W1R("(B"B)3)VAA(&-O;G-T871A="!Q=64@96P@;6]D92!D92!P
M86YT86QL82!C;VUP;&5T82!D\VYA('!R;V)L96UE<R!A;6(@26YT97)N970@
M(@HB17AP;&]R97(@82!C875S82!D)V5R<F]R<R!E;B!E;"!N879E9V%D;W(@
M<75E(&YO(&AE;2!P;V=U="!R97-O;&1R92X@4&]T('-E<B`B"B)Q=64@=FES
M=6%L:71Z974@8G)O<W-A+"!U<R!M86YQ=6EN(&9U;F-I;VYS(&5N(&PG961I
M=&]R(&DO;R!Q=64@96P@;F%V96=A9&]R("(*(G5S(&9A;&QI(&1E(&UA;F5R
M82!A;&5A=/)R:6$N(%-I('1E;FEU(&5L('-I<W1E;6$@5VEN9&]W<R`Y>"#I
M<R!M;VQT("(*(G!R;V)A8FQE('%U92!E<R!P<F]D=65I>&D@=6X@)V5R<F]R
M(&1E('!R;W1E8V-I\R!G96YE<F%L)R!I(&AA9W5E=2!D92`B"B)R96EN:6-I
M87(@9&4@;F]U+B!3:2P@=&]T(&D@87%U97-T(&%D=F5R=&EM96YT+"!E;F-A
M<F$@=F]L974@<')O=F%R(&PG961I=&]R("(*(F1E('!A;G1A;&QA(&-O;7!L
M971A+"!P<F5M974@1"=A8V]R9"XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`Y-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R="!W:71H(#P_>&UL
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HX.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(E,G:&$@<W5P<FEM:70@;&$@:61E;G1I=&%T(%PB
M)7-<(BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R(").;VWI<R!E;"!C;W-T870@97-Q=65R<F4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ-#8*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+B(*;7-G<W1R("),82!U8FEC86-I\R!D96P@8FEN87)I
M($=N=5!'(',G:&$@9"=I;F1I8V%R(&$@;&$@8VQA<W-E($-R>7!T7W!G<"XB
M"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(E,G:&$@;6]S=')A="!E;"!M
M:7-S871G92!E;G9I870@96P@)7,@82`E<R!A;6(@;"=A<W-U;7!T92!<(B5S
M7"(N($%I>/(@;F\@(@HB9V%R86YT96EX('%U92!S)VAA9VD@;&QE9VET(&\@
M96YTZ',@96P@;6ES<V%T9V4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G92(*;7-G<W1R(")%;"!N;VT@<75E(',G:&$@9"=U=&EL
M:71Z87(@96X@96YL;&'G87(@86UB($-R96%R('#@9VEN82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!C;&%S<RXB"FUS9W-T<B`B17,@;F5C97-S:71A(&5L(&WR9'5L(&]P96YS
M<VP@<&5R(&$@;&$@8VQA<W-E($AO<F1E7T-R>7!T7W-M:6UE+B(*"B,Z(&QI
M8B](;W)D92]0<F5F<RYP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C
M875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ92(*;7-G<W1R("(B"B).;R!S)VAA('!O9W5T(&1E<V%R(&QA('!R
M969E<NAN8VEA(%PB)7-<(B!P97)Q=>@@;&$@:6YF;W)M86-I\R!Q=64@8V]N
M=&5N:6$@(@HB<W5P97)A=F$@;&$@;6ED82!MX'AI;6$@<&5R;65S82XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-R!L:6(O2&]R9&4O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N
M<&AP.C,U(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B(@HB3F\@<R=H82!T<F]B870@96X@96P@<VES=&5M82!E
M;"!P<F]G<F%M82!U<V%T('!E<B!V:7-U86QI='IA<B!A<75E<W0@=&EP=7,@
M(@HB9&4@9&%D97,@*"5S*2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(").;VWI<R!E;',@8V]S=&%T<R!D
M<F5T(&D@97-Q=65R<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B3F]MZ7,@96P@8V]S=&%T(&1R970B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R(")3)VAA('-U<')I;6ET(&5L('-E<G9I9&]R(%PB)7-<(BXB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B4R=H82!D97-A="!E;"!S97)V:61O<B!<(B5S7"(N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B4R=H
M82!E;&EM:6YA="!L82!S;VRW;&EC:71U9"!D)V%L=&$@9&4@)7,N(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,CDP"B,L(&9U>GIY"FUS9VED
M(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M3F\@97AI<W1E:7@@;&$@9FEL82!E<W!E8VEF:6-A9&$N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R
M87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(").;R!E
M>&ES=&5I>"!L)V%R>&EU('1E;7!O<F%L(%PB)7-<(BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(").;VWI
M<R!E;',@8V]S=&%T<R!S=7!E<FEO<B!I(&EN9F5R:6]R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I
M9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B3F]MZ7,@96P@8V]S=&%T
M('-U<&5R:6]R(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,P-PIM<V=I9"`B
M5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S
M('-T97`N(@IM<V=S='(@(E,G:&%N('!E<F1U="!L97,@9&%D97,@8V%R<F5G
M861E<R!D97,@9&5L('!A<R!A;G1E<FEO<BXB"@HC.B!L:6(O2&]R9&4O1&%T
M82]T<W8N<&AP.C$W,B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(T,`IM<V=I
M9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&1E<V%R(&PG87)X:74@8V%R<F5G870N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3`W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3$*;7-G
M:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")%;"!B;&]C('=E871H97(N8V]M(&YO(&5S=.`@9&ES<&]N:6)L
M92XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U
M;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&5L(&1I<F5C=&]R:2!4:&5M
M97,@)R5S)RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I
M9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").
M;R!H:2!H82!C87`@;W!C:?,@9&ES<&]N:6)L92XB"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z,S0P"FUS9VED(")4:&5R92!A<F4@;F\@<&%R
M=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3F\@
M:&D@:&$@8V%P('!A<G0@<75E(&5S('!U9W5I(&UO<W1R87(@96X@;.UN:6$B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB07%U97-T
M(&-A;7`@8V]N=.D@;6%S<V$@8V%RX&-T97)S+B!(974@:6YT<F]D=>]T("5S
M(&-A<N!C=&5R<R!I(&XG:&5U("(*(F0G:6YT<F]D=6ER(&UE;GES(&1E("5S
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8P"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E(&1O97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O
M<B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M)R5S)R!T;R!T:&4@<WES=&5M+B`E<RXB"FUS9W-T<B`B2&D@:&$@:&%G=70@
M=6X@<')O8FQE;6$@96X@869E9VER("<E<R<@86P@<VES=&5M83H@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES
M=&5M.B`E<R(*;7-G<W1R(")(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!A
M9F5G:7(@)R5S)R!A;"!S:7-T96UA.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B(@HB2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@
M96X@97-B;W)R87(@9&5L('-I<W1E;6$@;&5S(&1A9&5S(&1E(&PG=7-U87)I
M("<E<R<N("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`G
M)7,G(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DAI(&AA(&AA9W5T('5N
M('!R;V)L96UA(&5N('-U<')I;6ER("<E<R<@9&5L('-I<W1E;6$Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G.B`E<R(*;7-G
M<W1R(")(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!A8W1U86QI='IA<B`G
M)7,G.B`E<R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")(:2!H
M82!H86=U="!U;B!P<F]B;&5M82!E;B!C87)R96=A<B!L)V%R>&EU.B!N;R!S
M)VAA(&-A<G)E9V%T("5S+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS
M9W-T<B`B(@HB2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@96X@8V%R<F5G87(@
M;"=A<GAI=3H@96P@)7,@97)A('-U<&5R:6]R(&$@;&$@;6ED82`B"B)MX'AI
M;6$@<&5R;65S82`H)2!B>71E<RDN(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N
M<&AP.C@X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)(:2!H82!H86=U="!U
M;B!P<F]B;&5M82!E;B!C87)R96=A<B!L)V%R>&EU.B!N;VWI<R!S)VAA(&-A
M<G)E9V%T('!A<F-I86QM96YT("(*(F5L("5S+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")3
M)VAA('!R;V1U[W0@=6X@97)R;W(@96X@;6]S=')A<B!A<75E<W1A('!A<G0@
M9&5L(&UI<W-A=&=E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N(@IM<V=S='(@(E,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!I;7!O
M<G1A<B!L97,@9&%D97,@9&4@8V]N=&%C=&4N(@H*(SH@;&EB+TAO<F1E+T1A
M=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E,G:&$@<')O9'7O
M="!U;B!E<G)O<B!E;B!I;7!O<G1A<B!L97,@9&%D97,@:4-A;&5N9&%R+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R
M("(B"B)3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@96P@9F]R;75L87)I(&1E
M(&-O;F9I9W5R86-I\RX@4&]T<V5R('5S(&AE=2`B"B)D97-C=6ED870@9"=E
M;7!L96YA<B!U;B!C86UP(&YE8V5S<V%R:2XB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3$P-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3(T-0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;W!E;FEN
M9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I
M=&@@=&AE("(*(F9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F
M<F]M('1H92!X;6P@<&%R<V5R+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B(@HB4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&5X96-U=&%R(&QA(&9U
M;F-I\R!E<W!E8VEF:6-A9&$@9&4@;&$@;&QI8G)E=&$@(@HB9"=A9')E8V5S
M+B!4;W)N974M:&\@82!I;G1E;G1A<B!MZ7,@=&%R9"XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB4R=H82!P<F]D=>]T
M('5N(&5R<F]R(&5N(&%C='5A;&ET>F%R(&5L<R!D971A;&QS(&1E(&-O;G1A
M8W1E+B!4;W)N974M:&\@82`B"B)I;G1E;G1A<B!MZ7,@=&%R9"XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)3)VAA
M('!R;V1U[W0@=6X@97)R;W(@96X@86-T=6%L:71Z87(@;&$@;&QI<W1A(&1E
M(&1I<W1R:6)U8VGS+B!4;W)N974M:&\@82`B"B)I;G1E;G1A<B!MZ7,@=&%R
M9"XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS
M9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R(")!<75E<W0@<V5R=FED;W(@24U!4"!N;R!P
M97)M970@;"?Z<R!D92!C87)P971E<R!C;VUP87)T:61E<RXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T
M<B`B3F\@<V5M8FQA('%U92!S:6=U:2!U;B!A<GAI=2!R87(@=N!L:60N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM
M<V=S='(@(DYO('-E;6)L82!Q=64@<VEG=6D@=6X@87)X:74@>FEP(';@;&ED
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,30S"FUS9VED(")4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T
M<B`B3F\@<V5M8FQA('%U92!A<75E<W0@;OIM97)O(&1E('1A<F=E=&$@<VEG
M=6D@=N!L:60N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(D%Q=65S="!C;VYT<F]L861O<B!P97)M970@96YV:6%R(&UI
M<W-A=&=E<R!P97(@;6ET:N`@9&4@;&$@<&%S<V%R96RW;&$@(@HB0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2P@=71I;&ET>F%N="!L82!!
M4$D@2%144"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,30*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E
M;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"B)!<75E<W0@8V]N=')O;&%D;W(@<&5R;65T(&5N=FEA<B!M:7-S871G
M97,@<&5R(&UI=&K@(&1E(&QA('!A<W-A<F5LMVQA("(*(G-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI('5T:6QI='IA;G0@;&$@05!)($A45%`B
M"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@P"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E
M=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N
M(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)!<75E<W0@8V]N=')O;&%D;W(@
M<&5R;65T(&5N=FEA<B!M:7-S871G97,@<&5R('9I82!D92!33510(&$@=')A
M=NES(&1E(&QA("(*(G!A<W-A<F5LMVQA(%9O9&%F;VYE(&0G273@;&EA+"!N
M;VWI<R!A(&[Z;65R;W,@5F]D869O;F4N($-A;"!T96YI<B!U;B!C;VUP=&4@
M(@HB9&4@8V]R<F5U(&5L96-T<O)N:6,@86UB(%9O9&%F;VYE(&0G273@;&EA
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.CDW."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`X-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(U-@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,34V,@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@T,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`P-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`W."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$T.0HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(R,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0P."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0U,@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C8U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R-B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$S-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S<R,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S<S,`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB
M"FUS9W-T<B`BR7,@;F5C97-S87)I(&%Q=65S="!C86UP+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(D%Q=65S="!C86UP(&YO;>ES
M('!O="!C;VYT96YI<B!N;VUB<F5S(&5N=&5R<RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C0Q-@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B07%U97-T(&-A
M;7`@;F]MZ7,@<&]T(&-O;G1E;FER(&YO;6)R97,@:2!E;',@9&]S('!U;G1S
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")!
M<75E<W0@8V%M<"!N;VWI<R!P;W0@8V]N=&5N:7(@=F%L;W)S(&]C=&%L<RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@
M:6YT96=E<G,B"FUS9W-T<B`B(@HB07%U97-T(&-A;7`@:&$@9&4@<V5R('5N
M82!L;&ES=&$@9&4@;F]M8G)E<R!E;G1E<G,@<V5P87)A=',@<&5R(&-O;65S
M(&\@(@HB97-P86ES+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#D*;7-G
M:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T
M<B`B07%U97-T(&-A;7`@:&$@9&4@<V5R('5N(&[Z;65R;R!VX&QI9"XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@S-`IM<V=I9"`B(@HB5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)!
M<75E<W0@8V%M<"!H82!D92!C;VYT96YI<B!U;B!C;V1I(&1E(&-O;&]R(&1E
M(&9O<FUA="!21T(@:&5X861E8VEM86PL('!E<B`B"B)E>&5M<&QE("<C,3(S
M-&%F)RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(DIA
M(',G:&$@<')O8V5S<V%T(&%Q=65S="!F;W)M=6QA<FDN(@H*(SH@=&5M<&QA
M=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!I<R`E<RXB"FUS9W-T<B`B06EX\B#I<R`E<RXB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES
M(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C
M="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS
M9W-T<B`B(@HB06EX\B#I<R!U;B!O8FIE8W1E(&1E($MO;&%B($=R;W5P=V%R
M92X@4&5R('9I<W5A;&ET>F%R(&%Q=65S="!O8FIE8W1E+"!U<R`B"B)C86P@
M=6X@8VQI96YT(&1E(&-O<G)E=2!E;&5C='+R;FEC('%U92!A9&UE=&D@96P@
M9F]R;6%T(&1E($MO;&%B($=R;W5P=V%R92X@(@HB4&5R('1E;FER(&%C8^ES
M(&$@=6YA(&QL:7-T82!D)V%Q=65S=',@8VQI96YT<R!D92!C;W)R974@96QE
M8W1R\FYI8RP@=FES:71E=2`B"B(E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HU.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(D%Q=65S="!M:7-S871G92!V
M82!S97(@97-C<FET(&%M8B!U;B!J;V,@9&4@8V%RX&-T97)S("@E<RD@9&EF
M97)E;G0@9&5L("(*(G9O<W1R92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N(@IM<V=S='(@(D%Q=65S="!N^FUE<F\@:&$@9&4@<V5R(&-O;2!A(&WM
M;FEM('5N(#$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,#0*;7-G:60@
M(E1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP
M.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B07%U97-T('-E<G9I9&]R(&YO('!O
M="!D97-C;VUP<FEM:7(@87)X:75S('II<"!I(&=Z:7`N(@H*(SH@;&EB+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ-#<*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B07%U97-T('-I<W1E;6$@
M97-TX"!D97-A8W1I=F%T(&%C='5A;&UE;G0N(@H*(SH@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BXB"FUS9W-T<B`B07%U97-T('9A;&]R(&AA(&1E('-E<B!U;B!N^FUE
M<F\N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM
M<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=R(*;7-G<W1R(")!<75E<W1A(&9I;F5S=')A(',G:&$@9&4@
M8W)I9&%R(&1E<R!D)W5N82!F:6YE<W1R82!D)V]P8VEO;G,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5&AU
M;F1E<B(*;7-G<W1R(")4<F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(P"FUS9VED(")4:6-K971S(@IM<V=S='(@(E1I<75E=',B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0R-@IM<V=I9"`B5&EM92(*;7-G<W1R(")(
M;W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-@IM<V=I9"`B
M5&EM92!4<F%C:VEN9R(*;7-G<W1R(")#;VYT<F]L(&1E('1E;7!S(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G
M<W1R(")&;W)M870@:&]R87)I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U
M,S<*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS(&1E
M('1E;7!S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(@
M3W)I96YT86PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS
M9W-T<B`B5.UT;VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@
M(E3M=&]L("ARZ'1O;"!I;F1I8V%D;W(@9&4@9G5N8VGS*3HB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS
M9W-T<B`B02(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HV,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(E!E<B!S96QE8V-I;VYA
M<B!D:79E<G-O<R!E;&5M96YT<RP@;6%N=&EN9W5E=2!P:71J861A(&QA('1E
M8VQA($-O;G1R;VP@*%!#*2`B"B)O($-O;6UA;F0@*$UA8RD@;65N=')E(&-L
M:7%U974N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,`IM
M<V=I9"`B5&]D87DB"FUS9W-T<B`B079U:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,
M(%-O=7)C92(*;7-G<W1R(")#;VUM=71E=2!L82!F;VYT($A434PB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S"FUS
M9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM
M<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")$96W@(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.0IM<V=I
M9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G
M<W1R(")3=7!E<FEO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T
M<B`B36%R8R!S=7!E<FEO<B`H7W-U<&5R:6]R*2(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV-3<*(RP@9G5Z>GD*;7-G:60@(E1R86YS;&%T960B"FUS9W-T
M<B`B5')A9'5C8VEO;G,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*
M;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")4<F%D=6-C:6]N<R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(*
M;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;FET870@
M:2!4;V)A9V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B
M5')U92!O<B!F86QS92(*;7-G<W1R(")697)I=&%T(&\@9F%L<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@
M(E1U(@IM<V=S='(@(D1T+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C@*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M5'5N[7-I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)Q=6EA(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E3
M3RTX.#4Y+3DI(@IM<V=S='(@(E1U<F,@*$E33RTX.#4Y+3DI(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-PIM<V=I
M9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`*;7-G
M:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("));&QE<R!4
M=7)K<R!I($-A:6-O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S,*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A
M;'4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U
M<B!C:&]I8V4Z("(*;7-G<W1R(")496-L96=E=2!L82!V;W-T<F$@;W!C:?,Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38*;7-G:60@
M(E4N5BX@:6YD97@Z("(*;7-G<W1R("+-;F1E>"!55CH@(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30P"FUS9VED(")54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),
M(&1E;"!V;W-T<F4@:6YF;W)M92!D92!L)V5S=&%T(&1E('1R86UE<V$@9&4@
M;&$@<V5Q_.AN8VEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-PIM
M<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8*;7-G:60@(E5K<F%I
M;F4B"FUS9W-T<B`B56-R8>]N82(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,U
M"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@86-C961I<B!A;"!D:7)E8W1O<FD@5D93+B(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@869E9VER(&WI<R!D861E<R!D
M92!L)W5S=6%R:2!E;B!E9F5C='5A<B!L)V%L=&$N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!C86YV:6%R(&5L('!E<FWM<R!D92!L)V%R>&EU(%9&
M4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,#@@;&EB+U9&4R]M
M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(DYO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!P97)M[7,@9&4@;"=A<GAI=2!6
M1E,@)7,O)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(&-A;G9I87(@82`E<RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]S<6PN<&AP.C,W,0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C;VYN96-T87(@86P@
M<V5R=FED;W(@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-38*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(").;R!S)VAA
M('!O9W5T(&-O;FYE8W1A<B!A;6(@4U-,+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,34X(&QI8B]61E,O9FEL92YP:'`Z,38S(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$X.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ.3,@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Q"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C;W!I87(@;"=A<GAI=2!61E,N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&-R96%R(&5L(&1I<F5C=&]R:2!61E,@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C<W(&QI8B]61E,O;75S<6PN
M<&AP.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-#@*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F\@<R=H82!P
M;V=U="!C<F5A<B!E;"!D:7)E8W1O<FD@5D93+B(*"B,Z(&QI8B]61E,O;75S
M<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB
M"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C<F5A<B!L)V%R>&EU(%9&4RXB"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYO
M(',G:&$@<&]G=70@8W)E87(@;&$@8V%R<&5T82!61E,@7"(E<UPB+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,3DX"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-R96%R
M('5N(&%R>&EU(%9&4R!B=6ET+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]T
M87(N<&AP.C<V(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I
M9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!D97-C;VUP<FEM:7(@;&5S(&1A9&5S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HR,S8@;&EB+U9&4R]S;6(N<&AP.C(R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM
M:7(@7"(E<UPB+"!E;"!D:7)E8W1O<FD@;F\@97-TX"!B=6ET+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C4T(&QI8B]61E,O<W%L+G!H<#HS,30@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,R-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R(").;R!S)VAA('!O9W5T
M('-U<')I;6ER("5S+"!E;"!D:7)E8W1O<FD@;F\@97-TX"!B=6ET+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`G)7,G.B`E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S=7!R:6UI<B`G
M)7,G.B`E<RXB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#`@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@<W5P<FEM:7(@96P@9&ER96-T;W)I(%9&4R!D92!M86YE<F$@<F5C=7)S
M:79A+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C8P(&QI8B]61E,O;75S<6PN
M<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,S-@IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").;R!S)VAA
M('!O9W5T('-U<')I;6ER(&5L(&1I<F5C=&]R:2!61E,N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C,S.2!L:6(O5D93+W-Q;"YP:'`Z,S4Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@96P@9&ER96-T;W)I
M(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S=7!R:6UI<B!L)V%R>&EU(%9&4R!<
M(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8@;&EB+U9&4R]S<6PN
M<&AP.C(Q,"!L:6(O5D93+VUU<W%L+G!H<#HQ-C<*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS-S`*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<X"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(").;R!S)VAA
M('!O9W5T('-U<')I;6ER(&PG87)X:74@5D93+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S
M=7!R:6UI<B!L82!C87)P971A(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C,R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@<W5P<FEM:7(@5D93(&1E(&UA;F5R82!R96-U<G-I=F$Z("5S+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW,C`*;7-G:60@(E5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@
M9&5T97)M:6YA<B!E;"!D:7)E8W1O<FD@86-T=6%L+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C
M="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(DYO(',G:&$@<&]G=70@
M97AT<F5U<F4@96QS(&1E=&%L;',@9&5L(&-E<G1I9FEC870N(@H*(SH@;&EB
M+TYE="])35-0+G!H<#HT-3$@;&EB+TYE="])35-0+T%U=&@N<&AP.C$Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C87)R96=A<B!L
M82!D969I;FEC:?,@9&4@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,CD@
M;&EB+U9&4R]F:6QE+G!H<#HQ,S0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34X
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$V,PIM<V=I9"`B56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;6]U<F4@
M;"=A<GAI=2!61E,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V(&QI8B]61E,O
M<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`R"B,Z(&QI8B]61E,O<VUB
M+G!H<#HV-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&]B<FER
M(&PG87)X:74@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P
M-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,C(@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,3(U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B!L)V%R>&EU(%9&
M4R!P97(@97-C<FEU<F4M:&DN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV-R!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI
M=2!61E,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*
M;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS
M9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B!L)V%R>&EU(&-O;7!R:6UI="XB
M"@HC.B!L:6(O5D93+G!H<#HX-34*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*(DYO(',G
M:&$@<&]G=70@;&QE9VER(&PG87)X:74@5D93("AL82!M:61A(&1E(&PG87)X
M:74H*2!H82!D;VYA="!E<G)O<BDN(@H*(SH@;&EB+U9&4RYP:'`Z.#@V"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&QL96=I<B!L)V%R>&EU
M(%9&4R`H9V5T1FEL95-I>F4H*2!H82!D;VYA="!E<G)O<BDN(@H*(SH@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!L;&5G
M:7(@;"=A<GAI=3H@+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-3DR"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@;&QE9VER(&5L(&1I<F5C=&]R:2!A<G)E;"!D
M92!61E,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#8W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I
M;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"B).;R!S
M)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E("5S('!E<B`E<SH@;&$@8V%R
M<&5T82!D92!D97-T:6YA8VGS(&IA("(*(F5X:7-T96EX(@H*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C@U"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%N=FEA<B!E
M;"!N;VT@9&5L(&1I<F5C=&]R:2!61E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-A;G9I
M87(@96P@;F]M(&1E;"!D:7)E8W1O<FD@5D93.B`E<RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,C@Q(&QI8B]61E,O<VUB+G!H<#HR-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(DYO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&4@;"=A<GAI
M=2!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-3,S(&QI8B]6
M1E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").;R!S)VAA('!O
M9W5T(&-A;G9I87(@96P@;F]M(&1E(&PG87)X:74@5D93("5S+R5S+B(*"B,Z
M(&QI8B]61E,O<W%L+G!H<#HR-#4@;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI
M8B]61E,O;75S<6PN<&AP.C0U,@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR
M-S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-A;G9I
M87(@96P@;F]M(&1E(&PG87)X:74@5D93+B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E>&5C=71A<B`G;6MI<V]F
M<R<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*
M;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@=')A9'5I<B!A<75E<W0@9&]C=6UE
M;G0@9&4@5V]R9"(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ,C(@;&EB+U9&4R]F
M='`N<&AP.C$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&5S
M8W)I=7)E(&PG87)X:74@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C$Q,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@HB3F\@<R=H82!P;V=U="!E<V-R:75R
M92!L)V%R>&EU(%9&4R`H(W,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!C;W!I
M87(M;&\H*2`C*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P.2!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,U"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!E<V-R:75R92!L97,@9&%D97,@9&4@;"=A<GAI=2!6
M1E,N(@H*(SH@;&EB+U9&4RYP:'`Z.#8Q"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@
M(DYO(',G:&$@<&]G=70@97-C<FEU<F4@;"=A<GAI=2!61E,L('-E('-U<&5R
M87+@(&PG97-P86D@9&ES<&]N:6)L92XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS
M9W-T<B`B4W5B<F%T;&QA="(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")$97-FZ7,@96QS(&-A
M;G9I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(D1E<V;@(&QA(&1A<G)E<F$@86-C:?,B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(D5L('-E<G9I9&]R(&AA(&1O
M;F%T('5N82!R97-P;W-T82!I;F5S<&5R861A(&5N(&-O;FYE8W1A<BUS93H@
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@(@IM<V=S='(@(D5L('-E<G9I9&]R(&AA(&1O;F%T('5N
M82!R97-P;W-T82!I;F5S<&5R861A(&$Z("(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8T"FUS9VED(")5;F9I;&5D(@IM<V=S
M='(@(E-E;G-E(&-A=&5G;W)I82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H
M551&+3@I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@
M(E5N:?,@9&5L<R!%;6ER871S(,!R86)S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X"FUS9VED(")5;FET960@2VEN
M9V1O;2(*;7-G<W1R(")296=N92!5;FET(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T
M871E<R(*;7-G<W1R(")%<W1A=',@56YI=',B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y"FUS9VED(")5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B26QL97,@
M4&5R:6;H<FEQ=65S($UE;F]R<R!D96QS($5S=&%T<R!5;FET<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C8Y"FUS9VED(")5;FET<R(*;7-G<W1R(")5;FET871S(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$X(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q.0IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")$97-C;VYE9W5T(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M87!I;7-G:60@*&ED96YT:69I8V%D;W(@9&5L(&UI<W-A=&=E(&1E(&QA($%0
M22D@9&5S8V]N96=U="XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+B(*;7-G<W1R(")#;&EM<V=I9"!D97-C;VYE9W5T("AI9&5N
M=&EF:6-A9&]R(&1E;"!M:7-S871G92!D96P@8VQI96YT*2XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,34P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YK;F]W;B!C;VUM86YD.B`E<R(*;7-G<W1R(")$97-C87)R96=A<B`E
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(E,G:&$@<')O
M<&]R8VEO;F%T('5N82!U8FEC86-I\R!D97-C;VYE9W5D82XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M(&0G=7-U87)I
M(&\@8V]N=')A<V5N>6$@9&5S8V]N96=U=',N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED(")5
M;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")$97-E;FQL8>=A
M<B!L)V5L96UE;G0@86-T=6%L(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B4V5N<V4@;F]M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I
M9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B),
M97,@<V5Q_.AN8VEE<R!S96YS92!P97)M:7-O<R!N;R!P;V1E;B!A8V-E9&ER
M(&$@4F5T86QL87(O0V]P:6%R+T5N9V%N>&%R(&1E("(*(FUA;F5R82!P<F]G
M<F%MX'1I8V$@<&5R(')A;VYS(&1E('-E9W5R971A="X@0VQI<75E=2!E;B!$
M)V%C;W)D('!E<B`B"B)V:7-U86QI='IA<B!U;F$@;F]T82!TZ&-N:6-A(&$@
M;6]Z:6QL82YO<F<@<75E('5S(&UO<W1R82!C;VT@<&]D974@9F5R('%U92`B
M"B)U;F$@<V5Q_.AN8VEA(&%C8V5D96EX:2!A;"!P;W)T82UR971A;&QS+B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")%;&EM:6YA<B!E
M;"!C;VQO<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@V(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB
M"FUS9W-T<B`B17AT96YS:?,@;F\@:6UP;&5M96YT861A(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C8U-PHC+"!F=7IZ>0IM<V=I9"`B56YT<F%N<VQA=&5D
M(@IM<V=S='(@(E-E;G-E(&YO;2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$X,PHC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@
M(D%C='5A;&ET>F%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T
M<B`B06-T=6%L:71Z87(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C0S"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")!8W1U
M86QI='IA<B!L)W5S=6%R:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D("<E
M<R<N(@IM<V=S='(@(E,G:&$@86-T=6%L:71Z870@)R5S)RXB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`Y,B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4R=H
M82!S=7!R:6UI="!L82!S97'\Z&YC:6$@9"=A8W1U86QI='IA8VGS+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#$@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$X,@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(D-A
M<G)E9V%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X.0IM<V=I9"`B
M57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S
M97)V97(N(@IM<V=S='(@(B(*(E,G:&$@8V%R<F5G870@86P@<V5R=FED;W(@
M=&]T<R!E;',@87)X:75S(&1E(&-O;F9I9W5R86-I\R!D)V%P;&EC86-I;VYS
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B06QF86)E="!L;&%T[2!E;B!M86KZ<V-U;&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED
M(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(EAI9G)E<R!R;VUA;F5S
M(&5N(&UA:OIS8W5L82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#$*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U
M9W5A:2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.3(@<&\O=')A;G-L871I;VXN<&AP.CDS"B,L(&9U>GIY"FUS9VED
M(")5<V%G93HB"FUS9W-T<B`B3F]M(&0G=7-U87)I.B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")5=&EL:71Z87(@;"=A
M8W1U86PZ("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S-PIM<V=I9"`B57-E(%-33"(*;7-G<W1R(")5=&EL:71Z87(@4U-,(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS
M9W-T<B`B571I;&ET>F5U('-I(&5L(&YO;2!O(&QA(&-O;G1R87-E;GEA('/S
M;B!D:69E<F5N=',@86P@<V5R=FED;W(@24U34"XB"@HC.B!L:6(O2&]R9&4O
M4F5G:7-T<GDN<&AP.C8Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B3"=U<W5A<FD@
M)7,@;F\@97-TX"!A=71O<FET>F%T('!E<B!A("5S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES=')A8VGS(&0G=7-U87)I<R(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,C4P"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B3W!C
M:6]N<R!D)W5S=6%R:2(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E9VES=')E(&0G=7-U87)I<R(*"B,Z
M('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(D5L(')E9VES
M=')E(&0G=7-U87)I<R!D)V%Q=65S="!L;&]C(&5S=.`@:6YH86)I;&ET870N
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<R(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C0V"B,L(&9U>GIY"FUS9VED(")5<V5R('!E<FUI<W-I;VYS
M(@IM<V=S='(@(E!E<FUI<V]S(&1E;"!P<F]P:65T87)I(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y-R!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDS"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S4@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`B3F]M(&0G=7-U87)I(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE
M("<E<R<@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D5L(&YO;2!D)W5S=6%R
M:2`G)7,G(&IA(&5X:7-T96EX+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DYO;2!D)W5S
M=6%R:3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED
M(")5<V5R;F%M93H@(@IM<V=S='(@(DYO;2!D)W5S=6%R:3H@(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(E5S97)S
M(@IM<V=S='(@(E]5<W5A<FES(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T
M<B`B57-U87)I<R!D96P@<VES=&5M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES=&%N
M(@IM<V=S='(@(E5Z8F5K:7-T86XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$P
M,2!L:6(O5D93+V9I;&4N<&AP.C$X.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B16P@9&ER96-T;W)I(%9&4R!N;R!E
M>&ES=&5I>"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$V"FUS
M9VED(")686-A=&EO;B(*;7-G<W1R(")!8G/H;F-I82(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B`B"FUS9W-T<B`B3&5S('5B:6-A8VEO;G,@=N!L:61E<R!Q=64@
M<R=H86X@=')O8F%T('/S;CHB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B5F%L:61E<V$B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-"!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DV"FUS9VED(")686QU92!I;B!M
M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")686QO<B!E;B!M:6YU=',@82!P
M87)T:7(@9"=A<F$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M16P@=F%L;W(@<W5P97)A(&QA(&QO;F=I='5D(&W@>&EM82!D92`E<RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C(V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-`HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDR-@IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E9A;&]R<R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3`Y(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L
M;W)S('%U92!S)VAA;B!S96QE8V-I;VYA<B!D92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D*;7-G:60@(E9A;G5A
M='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S8*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A<FEA8FQE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F7G=65L82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"XB"FUS9W-T<B`B2&$@9F%L;&%T(&QA('9E<FEF:6-A8VGS
M.B#I<R!P;W-S:6)L92!Q=64@<R=H86=I(&%L=&5R870@96P@;6ES<V%T9V4N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E
M<G-I;VXB"FUS9W-T<B`B5F5R<VGS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(P,PIM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(D-O
M;G1R;VP@9&4@=F5R<VEO;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R(")!;&EN96%C:?,@=F5R=&EC86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(D9A<F-I;65N="!V97)T:6-A;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@
M(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6-A;#HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5F5R>2!(:6=H
M(@IM<V=S='(@(DUO;'0@86QT(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T
M<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED
M(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I971N86UI=&$@*%9)
M4T-)22DB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.34U"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5FES=6%L:71Z
M87(@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E9I<W5A;&ET>F%R('5N
M82!PX&=I;F$@=V5B(&5X=&5R;F$B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#$T"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B
M"FUS9W-T<B`B5FES=6%L:71Z87(@8V]M(&$@)7,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("));&QE<R!697)G97,@8G)I
M=.!N:7%U97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0W"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G
M<W1R("));&QE<R!697)G97,@;F]R9"UA;65R:6-A;F5S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#<*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B
M5FES:6)I;&ET870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4P"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I;&ET870Z
M("(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-SD*
M;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F
M;VYE(&0G273@;&EA('!E<B!V:6$@9&4@4TU44"(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%2
M3B(*;7-G<W1R(")!1%9%4E3(3D-)02(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")!5LU3(2!%
M3$E-24Y!4B!,02!315'<R$Y#24$@34%.54%,345.5"!$12`E<RXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@:2!&=71U
M;F$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B07;M<R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ-#4@<&\O=')A;G-L871I;VXN<&AP.C8X,2!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M,C4@<&\O=')A;G-L871I;VXN<&AP.C$P-C`@<&\O=')A;G-L871I;VXN<&AP
M.C$P-CD*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-S<@<&\O=')A;G-L871I
M;VXN<&AP.C$P.#<@<&\O=')A;G-L871I;VXN<&AP.C$P.3<*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$Q,#<@<&\O=')A;G-L871I;VXN<&AP.C$Q,3,@<&\O
M=')A;G-L871I;VXN<&AP.C$R,S4*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R
M-#4@<&\O=')A;G-L871I;VXN<&AP.C$R-3$@<&\O=')A;G-L871I;VXN<&AP
M.C$R-S$*(RP@9G5Z>GD*;7-G:60@(E=A<FYI;F<Z("(*;7-G<W1R(")!=NUS
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.`IM<V=I9"`B5V4B"FUS9W-T<B`B1&,N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S
M='(@(E!R979I<VGS(&1E;"!T96UP<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,S0*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B
M>2(*;7-G<W1R("));F9O<FUA8VGS(&UE=&5O<F]L\F=I8V$@<')O<&]R8VEO
M;F%D82!P97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")7
M96%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V-PIM<V=I9"`B5V5B(%-I=&4B
M"FUS9W-T<B`B3&QO8R!W96(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V5T;6%N86QM96YT(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O
M;64B"FUS9W-T<B`B0F5N=FEN9W5T<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-3`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)E;G9I
M;F=U=',@82`E<R(*"B,Z(&QA;F=T97-T,BYP:'`Z,30*;7-G:60@(E=E;&-O
M;64@=&\@37D@4$A0($%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G
M<W1R(")"96YV:6YG=71S+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")/8V-I
M9&5N=&%L("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V-C
M:61E;G1A;"`H25-/+3@X-3DM,34I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(E/@:&%R82!/8V-I9&5N=&%L(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R
M(")1=6EN82!A<&QI8V%C:?,@:&%U<FEA(&1E(&UO<W1R87(@)7,@96X@:6YI
M8VEA<B!L82!S97-S:?,_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C$*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M(@IM<V=S='(@(E%U:6X@Z7,@96P@8V%RX&-T97(@9&5L:6UI=&%D;W(_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C0*;7-G:60@(E=H870@
M:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B475I;B#I<R!E;"!C
M87+@8W1E<B!D92!C:71A8VGS/R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E%U:6YE<R!F87-E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$*;7-G:60@(E=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS
M9W-T<B`B4&QU9VEN<R!H86)I;&ET871S(&1E(&PG961I=&]R(&1E('1E>'0@
M96YR:7%U:70N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B06UP;&%D
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3(S"FUS9VED(")7:61T:"!I
M;B!#4U,@=6YI=',B"FUS9W-T<B`B06UP;&%D82!D92!L97,@=6YI=&%T<R!#
M4U,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0W"B,L('!H<"UF;W)M
M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R(")!;7!L861A
M(&1E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$@*&1I<W!O;FEB;&4@96X@;&$@
M<')O<&5R82!S97-S:?,I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`B06UP;&%D82!D92!L82!T875L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(E5N:71A="!D)V%M<&QA9&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(D%M<&QA9&$Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0U.0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E=I;F0B
M"FUS9W-T<B`B5F5N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8R"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E9E;G0@
M82!P<FEM97)A(&AO<F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS
M9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E9E;&]C:71A="!D
M96P@=F5N="!E;B!N=7-O<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34T
M"FUS9VED(")7:6YD.B(*;7-G<W1R(")696YT.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S0*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")6
M96YT.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I
M<V1O;2(*;7-G<W1R(")3879I97-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$X,`HC+"!F=7IZ>0IM<V=I9"`B5VES:&QI<W1S(@IM<V=S='(@
M(DQL:7-T97,@9&4@9&5S:71J;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B1F5I;F$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S
M='(@(D%D<F7G82!D92!L82!F96EN82(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@
M(E1E;.AF;VX@9&4@;&$@9F5I;F$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<FET:6YG('5P9&%T960@:&5L
M<"!F:6QE('1O("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(Y"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@
M0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B3&EM:71A8VEO;G,@8N!S:7%U
M97,@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3(*
M;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`BVG,@
M9&4@;&$@8VQA=2!E<W1E<V$@>#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64B"FUS9W-T<B`B3F]M(&%L=&5R;F%T:74@9"=A<W-U;7!T92!8
M-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B261E
M;G1I9FEC861O<B!D92!C;&%U(&0G87-S=6UP=&4@6#4P.78S(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(D5X=&5N<VEO;G,@6#4P.'8S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(W"FUS9VED(")965E9(@IM<V=S
M='(@(D%!04$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`P,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")-87!A(&1E(%EA
M:&]O(2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R(")!;G5A;&UE;G0B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R"FUS9VED(")996UE;B(*
M;7-G<W1R("))96UE;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HX.#4*;7-G:60@(EEE<R(*;7-G<W1R(")3[2(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHV"FUS9VED
M(")997,L($D@06=R964B"FUS9W-T<B`B4^TL(&AO(&%C8V5P=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED
M(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B4V]U(&5N(&5L
M($U/1$4@5$585"X@57-E=2!E;"!B;W3S(%L\/ET@<&5R('1O<FYA<B!A(%=9
M4TE764<N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,C@X"FUS9VED(")9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(").;R!E<W1E=2!A=71E;G1I
M8V%T<RXB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,@HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@
M:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(DYO('!O9&5U(&EN8VQO=7)E
M(&5L(&-A<N!C=&5R("=<7"<@96X@96P@;F]M(&-O;7!L970N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S4*
M;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S
M<RXB"FUS9W-T<B`B3F\@:&5U(&EN=')O9'7O="!U;F$@861R9>=A(&5L96-T
M<O)N:6-A(';@;&ED82XB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(DYO(&AE=2!A<W-O8VEA
M="!C87`@8V%M<"!D92!L)V%R>&EU(&EM<&]R=&%T(&%M8B!E;',@8V%M<',@
M8V]R<F5S<&]N96YT<R!D92`E(@HB<RXB"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3`S"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S
M='(@(DAE=2!S;W)T:70@9&4@;&$@<V5S<VGS+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T
M:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"XB"FUS9W-T<B`B(@HB2&5U(&0G:6YT<F]D=6ER('5N(&[Z;65R;R!D
M92!T96SH9F]N(&WR8FEL(';@;&ED+"!N;VWI<R!D[6=I=',@86UB('5N("<K
M)R`B"B)O<&-I;VYA;"!P97(@86P@<')E9FEX(&1E('1R=6-A9&$@:6YT97)N
M86-I;VYA;"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X.`IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B2&5U
M(&0G:6YT<F]D=6ER('5N('9A;&]R(';@;&ED+B(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(DAE
M=2!D92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E($1A=&%4<F5E('!E<B!U=&EL
M:71Z87(@06QT97,N(@H*(SH@;&EB+TAO<F1E+G!H<#HT,S$*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")(974@
M9&4@8V]N9FEG=7)A<B!U;B!M;W1O<B!D92!61E,N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+B(*;7-G<W1R(")(974@9&4@9&5S8W)I=7)E(&5L('!R;V)L
M96UA(&%B86YS(&0G96YV:6%R+6YE(&PG:6YF;W)M92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`B2&5U(&0G:6YT<F]D=6ER(&5L(%523"!Q=64@87%U97-T(&5N
M;&QAYR!I;F1I8V$N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`B2&5U(&1E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R
M('%U92!V=6QG=65U(&5L:6UI;F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q
M.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="XB"FUS9W-T<B`B2&5U(&0G97-P96-I9FEC87(@=6X@;F]M(&0G=7-U
M87)I('%U92!V=6QG=65U(&5S8F]R<F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92XB"FUS9W-T<B`B2&5U(&0G97-P96-I9FEC87(@=6X@;F]M(&0G=7-U
M87)I('%U92!V=6QG=65U('-U<')I;6ER+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R
M(")(974@9"=E<W!E8VEF:6-A<B!Q=6EN(&YO;2!D)W5S=6%R:2!V;VQE=2!A
M9F5G:7(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DAE
M=2!D)V5S<&5C:69I8V%R(&5L(&YO;2!D)W5S=6%R:2!Q=64@=F]L974@86-T
M=6%L:71Z87(N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(DAE=2!D)V5S<&5C:69I8V%R('%U:6YA(&%C8VGS('9O
M;&5U(&5X96-U=&%R+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<R"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N(@IM<V=S='(@(DAE=2!D92!T96-L96IA<B!U;B!N;W4@;F]M
M(&1E(&-A=&5G;W)I82XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.#DQ"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E
M9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B),82!V;W-T<F$@
M<V5S<VGS(&5N("5S(&AA(&5X<&ER870N(%-I('5S('!L874L(&EN:6-I974@
M=6YA(&YO=F$@<V5S<VGS+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B
M3&$@=F]S=')A(&%D<F7G82!E;&5C='+R;FEC82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#(*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS
M9W-T<B`B3&$@=&5V82!A9')EYV$@9&4@<F5S<&]S=&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B3&$@=F]S
M=')A(&EN9F]R;6%C:?,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.#DU"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB3&$@=F]S=')A(&%D<F7G82!D)TEN
M=&5R;F5T(&AA(&-A;G9I870@9&5S('%U92!H974@8V]M96[G870@;&$@<V5S
M<VGS("5S+B`B"B)097(@<F%O;G,@9&4@<V5G=7)E=&%T+"!H974@9&4@<F5I
M;FEC:6%R(&QA('-E<W-I\RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(D5L('9O<W1R
M92!N;VTB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z.0HC
M+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*(D5L('9O<W1R92!M;W1O<B!D)V%U=&5N=&EC86-I\R!N
M;R!P97)M970@<75E(&5S(&QL:7-T:6X@96QS('5S=6%R:7,L(&\@8ND@(@HB
M<&5R(&%L9W5N82!R8?,@87%U97-T82!C87)A8W1E<NUS=&EC82!E<W3@(&EN
M:&%B:6QI=&%D82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.CD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB
M"FUS9W-T<B`B(@HB16P@=F]S=')E(&UO=&]R(&0G875T96YT:6-A8VGS(&YO
M('!E<FUE="!Q=64@97,@;&QI<W1I;B!E;',@=7-U87)I<RP@;R!BZ2`B"B)P
M97(@86QG=6YA(')A\R!A<75E<W1A(&-A<F%C=&5R[7-T:6-A(&5S=.`@:6YH
M86)I;&ET861A+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HX.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B)396UB;&$@<75E(&5L(&YA=F5G861O
M<B!H82!C86YV:6%T(&1E<R!Q=64@=F%U(&-O;65NYV%R(&QA('-E<W-I\R`E
M<RX@4&5R("(*(G)A;VYS(&1E('-E9W5R971A="P@:&5U(&1E('1O<FYA<B!A
M(&5N=')A<B!A;"!S:7-T96UA+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N(@IM<V=S='(@(D5L('9O<W1R92!N879E9V%D;W(@;F\@86-C
M97!T82!A<75E<W1A(&-A<F%C=&5R[7-T:6-A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N
M=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB16P@
M=F]S=')E(&YA=F5G861O<B!N;R!P97)M970@87%U97-T82!O<&-I\R!D)VEM
M<')E<W-I\RX@4')E;6D@0V]N=')O;"`K(%`@(@HB<&5R(&EM<')I;6ER+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#<*;7-G:60@(EEO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(EIO;F$@:&]RX')I82!A8W1U86PZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T.`IM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("))9&5N=&ET870@<')E9&5T97)M
M:6YA9&$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(DYO;2!C;VUP;&5T.B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ-#4*;7-G:60@(B(*(EEO=7(@9V5T=&5X="!V
M97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA
M=&EV96QY+EQN(@HB3F]T(&%L;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S(@IM<V=S='(@(DQA(&YO=F$@8V]N=')A<V5N>6$@<&5R(&$@
M)7,@Z7,Z("5S(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B3&5S(&]P8VEO;G,@
M:&%N(&5S=&%T(&%C='5A;&ET>F%D97,@<&5R(&$@;&$@9'5R861A(&0G87%U
M97-T82!S97-S:?,N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T
M<B`B3&5S(&]P8VEO;G,@:&%N(&5S=&%T(&%C='5A;&ET>F%D97,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B4R=H82!R96EN:6-I870@
M;&$@=F]S=')A(&-O;G1R87-E;GEA(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@
M;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)3)VAA(')E:6YI8VEA="!L
M82!V;W-T<F$@8V]N=')A<V5N>6$L(')E=FES82!E;"!C;W)R974@96QE8W1R
M\FYI8R!I(&EN:6-I82`B"B)L82!S97-S:?,@86UB(&QA(&YO=F$@8V]N=')A
M<V5N>6$N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS
M9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")397)V:61O<G,@
M<F5M;W1S.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q."!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(DEU9V]S;.!V:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-@IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(EK@;6)I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-3<*;7-G:60@(EII;6)A8G=E(@IM<V=S
M='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS
M9VED(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&QI8B](;W)D92]497AT
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(EM/8W5L=&$@=&5X="!C:71A=%TB"@HC.B!S
M97)V:6-E<R]P<F]B;&5M+G!H<#HU-@IM<V=I9"`B6U!R;V)L96T@4F5P;W)T
M72(*;7-G<W1R(");26YF;W)M92!D96P@<')O8FQE;6%=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6TUO<W1R82!T97AT(&-I=&%T("TB
M"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UTB"FUS9W-T<B`B6TUO<W1R82!T97AT(&-I=&%T("T@)7,@
M;.UN:65S72(*"B,Z(&QI8B](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*
M;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");;.UN:6$@)7,@9&4@
M)7-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#,R('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?
M061M;FES=')A8VGS(@H*(SH@;&EB+V%P:2YP:'`Z,3,V"FUS9VED(")?0TQ)
M(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ,C0*;7-G:60@(E]$
M871A5')E92(*;7-G<W1R(")?07)B<F4@9&4@9&%D97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G
M:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]3=7!R:6UI<B!F:6QA(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$V"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P
M<R(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM
M<V=S='(@(E]!:G5D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B7U!R;W!I971A=',@9&4@;&$@:6UA=&=E+BXN(@H*
M(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G
M<W1R(")?26YI8VEA(&QA('-E<W-I\R(*"B,Z(&QI8B](;W)D92]-96YU+G!H
M<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]3=7)T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T
M"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TUO9&EF:6-A(&PG
M96YL;&'G+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B
M7T]P=&EO;G,B"FUS9W-T<B`B7T]P8VEO;G,B"@HC.B!L:6(O87!I+G!H<#HQ
M,C`*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4&5R;6ES;W,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?16QI;6EN
M82!L)V5N;&QAYRXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$P.`IM<V=I9"`B7U-E
M='5P(@IM<V=S='(@(E]#;VYF:6=U<F%C:?,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(E]4
M86)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]0<F]P:65T871S(&1E(&QA
M('1A=6QA+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3$R"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B7U5S=6%R:7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y
M,`IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(FQL:6)R971A(&0G861R
M96-E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,3$*(RP@9G5Z>GD*;7-G
M:60@(F%N(&5R<F]R(&AA<R!O8V-U<F5D.B(*;7-G<W1R(")3)VAA('!R;V1U
M[W0@=6X@97)R;W(@:7)R97!A<F%B;&4N(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HX.#(*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(F%G96YD82(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3<P(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8V%L;6$B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3@X"FUS9VED(")C
M;&EC:R!H97)E(@IM<V=S='(@(E!R96UI(&%Q=>TB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-#0U('!O+W1R86YS;&%T:6]N+G!H<#HU-3`@<&\O=')A;G-L
M871I;VXN<&AP.C8Q,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S0Y('!O+W1R
M86YS;&%T:6]N+G!H<#HX,3`@<&\O=')A;G-L871I;VXN<&AP.C@X-PHC+"!F
M=7IZ>0IM<V=I9"`B9&]N92(*;7-G<W1R(")F970B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-34R('!O+W1R86YS;&%T:6]N+G!H<#HU.#0@<&\O=')A;G-L
M871I;VXN<&AP.C8Q,PHC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S<X('!O+W1R
M86YS;&%T:6]N+G!H<#HX,3(@<&\O=')A;G-L871I;VXN<&AP.C@Y,`HC+"!F
M=7IZ>0IM<V=I9"`B9F%I;&5D(@IM<V=S='(@(F9A;&QI9&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B9F%L
M;&EN9R(*;7-G<W1R(")E<W3@(&-A:65N="(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HX-#D*;7-G:60@(F9I;&4B"FUS9W-T<B`B87)X:74B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")F;W5N9#H@
M(@IM<V=S='(@(E9E;G0Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S@T"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@
M)7,@)7,B"FUS9W-T<B`B9&5S(&1E;"`E<R`H)7,I(&$@;&5S("5S("5S(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I
M9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S,Q"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(R(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C0*;7-G:60@(FEM;65D:6%T92(*;7-G
M<W1R(")I;6UE9&EA="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
M:6YS97)E:7@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(FSM;FEE<UTB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RXB"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N(&-O9&D@9"=E<G)O<B`E9"!D
M96P@;6MI<V]F<R!E;B!C<F5A<B!)4T\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,T,@IM<V=I9"`B;6TB"FUS9W-T<B`B(VUM
M(R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C@W('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HR,#4*;7-G:60@(FYA;64B"FUS9W-T<B`B;F]M
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,W.`HC+"!F=7IZ>0IM<V=I9"`B
M;F]T(&-H86YG960B"FUS9W-T<B`B4V5N<V4@8V%N=FES+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,S$*(RP@9G5Z>GD*;7-G:60@(FYO="!F;W5N9"(*
M;7-G<W1R(").;R!S)VAA('1R;V)A="`E<RXB"@HC.B!L:6(O2&]R9&4O4E!#
M+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")N;R!S
M)VAA(&EM<&QE;65N=&%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(F5N
M8V%R82!N;R!S)VAA(&EM<&QE;65N=&%T(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HX-S0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B8FQO8R!D92!N;W1E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<&5R8V5N=&%T9V4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<.UX96QS(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R(")E<W3@('!U:F%N="(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z.3@*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B
M;6]S=')A<B!D:69E<NAN8VEE<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,3,*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G
M<W1R(")S;7,R96UA:6P@<&5R('9I82!D92!(5%10(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B<W,B"FUS9W-T
M<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(F-O;G-T86YT(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HX.3@*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M(")L;&ES=&$@9&4@=&%S<75E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(G1H92!(;W)D92!03R!F
M:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T.B(*;7-G<W1R
M(").;R!E>&ES=&5I>"!L)V%R>&EU('1E;7!O<F%L(%PB)7-<(BXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V
M.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*
M;7-G<W1R(")T96-L96=E=2!L82!C;VYT<F%S96YY82!D=65S('9E9V%D97,@
M<&5R(&-O;F9I<FUA<BUL82(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S
M='(@(G5N:69I8V%T(@H*(SH@;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*
M;7-G:60@(G5N;F%M960B"FUS9W-T<B`B<V5N<V4@;F]M(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C,W-0HC+"!F=7IZ>0IM<V=I9"`B=7!D871E9"(*;7-G
M<W1R(")!8W1U86QI='IA<B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(R(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C0*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(G-E;&5C8VGS(&1E(&PG
M=7-U87)I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED(")W.B(*;7-G<W1R
M(")W.B,C(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G
M:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O8G-?0D$N<&\`
M````````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#8U,#8S,0`Q,#4Q-30S,3`V,P`P,38S-#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!T<F%N<VQA=&EO;B!O9B!H;W)D
M92UB<RYP;R!T;R!";W-N:6%N"B,@0F]S;FEA;B!T<F%N<VQA=&EO;G,@9F]R
M(&EM<"!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@,C`P,R!(;W)D92!0<F]J
M96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE(&EM<"!P86-K86=E+@HC($%U=&]M871I8V%L;'D@
M9V5N97)A=&5D+"`R,#`S+@HC($%L96X@4V%R:VEN;W9I8R`\86QE;D!L:6YU
M>"YO<F<N8F$^+"`R,#`T+@HC(%9E9')A;B!,:G5B;W9I8R`\=FQJ=6)O=FEC
M0'-M87)T;F5T+F)A/BP@,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@:&]R9&4M8G-<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`U+3`W+3`Q(#$S.C,Q*S`R,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@5F5D<F%N($QJ=6)O=FEC(#QV;&IU8F]V:6-`<VUA<G1N970N8F$^7&XB
M"B),86YG=6%G92U496%M.B!";W-N:6%N(#QL;VMA;$!L:6YU>"YO<F<N8F$^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:71<;B(*(E@M1V5N97)A=&]R.B!+0F%B96P@,2XQ
M,%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*'!R:6IE
M("5S(&1A;F$I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AZ82`E<R!D
M86YA*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@
M(B`H=&]D87DI(@IM<V=S='(@(B`H9&%N87,I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B
M("AS=71R82DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS
M9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AJ=>AE*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#`W"FUS9VED("(@870@(@IM<V=S='(@(B!U("(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")0<F%V86,@
M<V]R=&ER86YJ82(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@;FEJ92!D;WIV;VQJ96X@:7IB;W(N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&YI
M:F4@<&]D9;EE;B!U(')E9VES=')Y+6IU(&%P;&EK86-I:F4N(@H*(SH@9G)A
M;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B5S(&YI:F4@<')O;F'P96XN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&IE('5S
M<&5S;F\@9&]D86X@=2!A9')E<V%R(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S
M(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!I("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S
M<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@
M9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S
M='(@(B5S("T@3F%P;VUE;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P
M<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B)7,@4V5R=FES;F4@;W!E<F%C:6IE("T@<&]T=G)D
M82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*
M;7-G<W1R("(E<R!P;V1EN6%V86YJ92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG
M;B!5<"(*;7-G<W1R("(E<R!P<FEJ879A(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F
M($%G<F5E;65N="(*;7-G<W1R("(E<R!U<VQO=FD@=6=O=F]R82(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!V9>8@<&]S
M=&]J:2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!U
M("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F
M;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N
M($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A
M;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B`F(S$U,3L@
M)7,@YF4@<V%D82!I>G9RN6ET:2!S97)V:7-N92!O<&5R86-I:F4@;F%V961E
M;F4@:7-P;V0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T82(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N:6IE('!R
M;VYA\&5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B
M)7,@>F$@)7,@;V0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*
M;7-G<W1R("(E<R!A9')E<V%R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*
M;7-G<W1R("(E<R!K86QE;F1A<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R("(E<R!B:6QJ9;YN:6-A(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES
M="(*;7-G<W1R("(E<R!Z861A8VDB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E
M(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I
M;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N
M9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(BP@
M9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(E<R!U("5S("5S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I
M86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB
M"FUS9W-T<B`B+2T@:7IA8F5R:71E("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUS871N
M:2!F;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T
M($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+7-A=&YI(&9O<FUA="(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G
M<W1R("(R-"!S871A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV
M.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(E!R971H;V1N
M82!S=')A;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B
M02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B
M1&^Y;&\@:F4@9&\@9F%T86QN92!G<F6Y:V4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@
M82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R
M(")+;W!I<F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*(RP@9G5Z
M>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B57!O>F]R96YJ92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!
M32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@
M(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B3R!O
M=F]M(&5D:71O<G4B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM
M<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3R!P<F]G<F%M=2XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*(RP@9G5Z
M>GD*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")$;F\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")6
M8;EE(&EN9F]R;6%C:6IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U
M"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(JEI9G)A(&MO<FES
M;FGH:V]G(&YA;&]G82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM
M<V=S='(@(DYA;&]G(&IE('IA;7)Z;G5T+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B4F'H
M=6YO=F]D<W1V;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S
M='(@(D1O9&%J(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O
M=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(DEZ;6EJ96YI(&1O>G9O;'4B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z
M(@IM<V=S='(@(D1O9&%J(&]V9&IE.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")!9&0@
M3F5W($=R;W5P(@IM<V=S='(@(DYE=W,M9W)U<&4B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*
M;7-G<W1R("))>FUI:F5N:2!D;WIV;VQU(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB
M(@IM<V=S='(@(DEZ;6EJ96YI(&1O>G9O;&4@>F$@)7,B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(D1O
M9&%J(&YO=F]G(&MO<FES;FEK83HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S
M='(@(D1O9&%J(&MO;&]N=2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*
M;7-G<W1R(")$;V1A:B!N;W9O9R!K;W)I<VYI:V$Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B
M"FUS9W-T<B`B1&]D86H@)7,@;65N:2!U($UO>FEL;&$@4VED96)A<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I
M9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B1&]D86H@=2!A9')E
M<V%R.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R(")$;V1A:B!U(&EM96YI:R`H)7,I(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D1O9&%J
M(&]V9&IE.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB
M)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*(RP@
M9G5Z>GD*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B3V0@861R97-E(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!"
M;V]K(@IM<V=S='(@(DEM96YI:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')I
M<F%N:F4@+2!P;V1EN6%V86YJ92!D;WIV;VQA(&1R=6=I:"!K;W)I<VYI:V$B
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B7T%D;6EN:7-T<F%C:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(D1O9&%J
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G
M86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
M06QB86YI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@
M(D%LOFER(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P-PHC+"!F=7IZ>0IM<V=I9"`B06QI87,B"FUS9W-T<B`B06R^:7(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE
M;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(E-V92(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*
M(RP@9G5Z>GD*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S
M='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B
M06QL($=R;W5P<R(*;7-G<W1R(")?1W)U<&4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A
M=')E92YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*
M;7-G<W1R(")?1&]Z=F]L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*
M;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")$;WIV;VQI('!R
M879L:F5N:F4@;G5M97)I<V%N:6@@;&ES=&D_(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"B,L(&9U>GIY"FUS9VED(")!
M;')E861Y(&5X:7-T<R(*;7-G<W1R("(E<R!V9>8@<&]S=&]J:2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=&EV;FD@24U34"!L;V=I;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%!A<W-W;W)D(@IM<V=S='(@(D%L=&5R;F%T:79N82!)35-0(+EI9G)A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N
M871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N871I=FYO($E-4U`@
M:V]R:7-N:>AK;R!I;64B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V
M82!U(&5M86EL(&%D<F5S:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T
M92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A
M;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS
M9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@
M(E5N9;EE;F$@:F4@:6QE9V%L;F$@=G)I:F5D;F]S="XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U
M;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")$;[EL;R!J92!D
M;R!F871A;&YE(&=R9;EK92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY
M;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(D]D
M9V]V;W)E;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"B,L(&9U
M>GIY"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!:V-I:F$B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`B06MC:6IA(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$T,`HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@:7,@
M<F5A9'DN(@IM<V=S='(@(D%K8VEJ82(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B26UE(&1A=&]T96ME(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B1&$@
M;&D@<W1E('-I9W5R;FD@9&$@OF5L:71E(&ES<')A>FYI=&D@9F]L9&5R(&MO
M<G!A/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM
M<V=S='(@(D1A(&QI('-T92!S:6=U<FYI(&1A(+YE;&ET92!O8G)I<V%T:2!O
M=F4@<&]R=6ME/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(D%R9V5N
M=&EN82(*;7-G<W1R(")!;+YI<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N
M:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G
M:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED
M(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/R(*;7-G<W1R(")0:71A:B!P<FEJ92!O8F%V;&IA;FIA('-E
M<G9I<VYI:"!O<&5R86-I:F$_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%U9W5S="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*(RP@9G5Z>GD*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=6=U<W0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")!=7-T<FEA(@IM<V=S='(@
M(D%U9W5S="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ
M-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D
M;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@
M(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP
M.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*
M(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E
M<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U
M=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S
M"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B3FEJ92!U<W!E;&\@<W!AN6%V86YJ
M92!N97IA=G*Y96YE('!O<G5K92X@3W9O(&IE('!O<G5K82!S97)V97)A.B`E
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#DY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(").:6IE('5S
M<&5L;R!S<&&Y879A;FIE(&YE>F%V<KEE;F4@<&]R=6ME+B!/=F\@:F4@<&]R
M=6MA('-E<G9E<F$Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV
M,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`HC+"!F=7IZ>0IM<V=I
M9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(E5S;6IE<F5N:F4@
M;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B57-M:F5R
M96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@U,0HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E5S;6IE<F5N:F4@
M;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO
M+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*(RP@9G5Z>GD*
M;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(DYA(')A<W!O;&%G
M86YJ=2!S=2!S;&IE9&7F:2!I;65N:6-I.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD
M($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I
M9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*(RP@
M9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0G)A>FEL(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(D)A;'1IZ&MI("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*
M(RP@9G5Z>GD*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(E9E;&GH:6YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"B,L(&9U>GIY"FUS9VED(")"96QG:75M(@IM<V=S='(@(E9E;&GH:6YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F5L:7IE(@IM<V=S='(@
M(E9E;&GH:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F5N:6XB
M"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4
M>7!E(@IM<V=S='(@(E9R<W1A(&)L;VMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@
M(DUA<VYO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")"
M;VQI=FEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R("):86)I;&IEN6ME(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I
M9"`B0F]R9&5R(@IM<V=S='(@(E)U8B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(D1E8FQJ:6YA(')U8F]V83HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")"
M;W)D97)S(@IM<V=S='(@(E)U8F]V:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O
M<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;F$@:2!(97)C96=O
M=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T
M:"(*;7-G<W1R(")/8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*
M;7-G<W1R(")";V-V86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M1&YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R
M(")";W5V970@;W-T<G9O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM
M<V=S='(@(D)R87II;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=&%N<VMA($EN9&EJ
M<VMO+4]K96%N<VMA(%1E<FET;W)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U9V%R<VMA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("),:7-T82!S82!T8>AK
M86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@
M(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS
M9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-#0*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B
M0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")/<V]B
M:6YE(.9?96QI:F4N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`B2V%L96YD87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0V"B,L(&9U>GIY"FUS9VED(")#86QM(@IM<V=S='(@(D]D=7-T86YI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O\&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<G5N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@
M;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E
M<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(").92!M;V=U('-E
M('-P;VII=&D@;F$@24U!4"!S97)V97(Z("5S(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G
M:60@(D-A;F%D82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*
M;7-G:60@(D-A;F-E;"(*;7-G<W1R(")/9'5S=&%N:2(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B3V1U<W1A;FD@;V0@<')I:F%V92!P<F]B;&5M
M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(T"B,L(&9U>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D]P8VEJ92(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P
M-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R(")+871E9V]R:6IE(&D@;WIN86ME(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*(RP@9G5Z
M>GD*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DUA<KEA;&]V82!O
M<W1R=F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(E1E
M;&5F;VX@*&MUYFDI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P
M97)T:65S(@IM<V=S='(@(D]S;V)I;F4@YE]E;&EJ92XN+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#
M96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@
M(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")/<V]B:6YE(.9?96QI:F4N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I
M8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1S:VD@*$E33RTX.#4Y+3$T
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")+<F5I
M<F%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D-E;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK82(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")#96YT<F%L;F\M979R;W!S:VD@
M*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G
M:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T
M92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*
M;7-G:60@(D-H860B"FUS9W-T<B`B5&]K('1E;64B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B4')O;6IE;FDB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB
M4')O;6EJ96YI=&4@:6UE(&D@861R97-U(&MO:F4@=FED92!D<G5G:2!K861A
M(.AI=&%J=2!I(&]D9V]V87)A:G4@;F$@=F&Y92`B"B)P;W)U:V4N(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H
M87(B"FUS9W-T<B`B5&]K('1E;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@
M(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E])>FUI:F5N:2!L:6YK+BXN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`BR&EL92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(DMI;F$B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'
M0C(S,3(I(@IM<V=S='(@(DMI;F5S:VD@<&]J961N;W-T879L:F5N:2`H1T(R
M,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")+:6YE<VMI('1R861I
M8VEO;F%L;FD@*$)I9S4I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B
M27IA8F5R:71E(+EI9G)U(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B
M27IA8F5R:71E(&MO<FES;FGH:V\@:6UE(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S
M.B(*;7-G<W1R("))>F%B97)I=&4@:V%K;R!S92!P<FEK87IU:F4@9&%T=6TZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I(@IM<V=S='(@(DEZ86)E<FET92!V<G-T=2!S=&EL
M82`H>F$@;G5M97)I<V%N92!L:7-T92DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M:')I<W1M87,@27-L86YD(@IM<V=S='(@(E5S:W*Y;FIE(&]S=')V;R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*
M;7-G<W1R(")/Z&ES=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM
M<V=S='(@(D_H:7-T:2!-4T]F9FEC92!T86=O=F4B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A<B!1=65R>2(*;7-G
M<W1R(")/Z&ES=&DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D_H:7-T
M:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"B,L(&9U
M>GIY"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B3V1A8F5R:2!K
M;V1N:2!R87-P;W)E9"!S;&]V83HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"B,L(&9U>GIY"FUS9VED(")#;&]U
M9',B"FUS9W-T<B`B2V]P:7)A:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R
M;'DB"FUS9W-T<B`B2V]P:7)A:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$W"B,L(&9U>GIY"FUS9VED(")#;&]U9'DB"FUS
M9W-T<B`B2V]P:7)A:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L
M:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E(%-I9&5B
M87(B"FUS9W-T<B`B4VMU<&D@9F]L9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I
M9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4VMU<&D@9F]L9&5R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B
M2V%M8F_P82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K
M+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")#;VQO<B(*;7-G
M<W1R(")+;VUO<FDB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R
M"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*
M;7-G<W1R("))>F)O<B!B;VIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M
M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(V-`HC+"!F=7IZ>0IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(DYO=F$@
M<&]R=6MA(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(DMO;7!A;FEJ82(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z
M>GD*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B6F%V<KEE;F\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@HC+"!F=7IZ>0IM<V=I
M9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B5F&Y92!I;64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")+;VUO<FDB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP
M86YY(@IM<V=S='(@(DMO;7!A;FEJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(DYO
M=F$@<&]R=6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(D]P8VEJ92!N
M87)E9&)E.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"B,L(&9U>GIY
M"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D]P8VEJ92!N87)E9&)E.B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@
M=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R
M9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*(RP@9G5Z>GD*;7-G
M:60@(D-O;F=O(@IM<V=S='(@(EIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0HC+"!F=7IZ>0IM
M<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*
M;7-G<W1R("),86\@3F%R;V1N82!$96UO:W)A='-K82!297!U8FQI:V$B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U
M>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B57-M:F5R
M96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A
M:6QE9#H@(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0HC+"!F=7IZ>0IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"B,L(&9U
M>GIY"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B7"(E<UPB(&IE('5S<&5S
M;F\@9&]D86X@=2!A9')E<V%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN
M=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(D)O=79E="!O<W1R=F\B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(D-O;VMI92(*;7-G
M<W1R(").;W9A('!O<G5K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R
M(")+;W!I<F%J(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*
M;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@
M<V5L96-T:6]N(@IM<V=S='(@(DMO<&ER86H@:7IA8G)A;F\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)
M1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V
M"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM
M<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED
M(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G
M:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES
M871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#
M;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES
M871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L
M9&%P('-E<G9E<B(*;7-G<W1R(").92!M;V=U('-E('-P;VII=&D@;F$@24U!
M4"!S97)V97(Z("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B3F4@;6]G
M=2!S92!S<&]J:71I(&YA($E-05`@<V5R=F5R.B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES
M871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3(U"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T82XB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I
M<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R
M(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO
M(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K
M92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO
M=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYI
M:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R
M:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I
M('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DYI:F4@8FEL;R!M
M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R
M:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(DYI:F4@8FEL;R!M
M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@
M(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*
M(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DYI:F4@
M8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B
M<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O
M<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B
M"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G
M<R!C87!A8FEL:71I97,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I
M<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I
M('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@
M<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R
M(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYI
M:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES
M871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S
M92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS
M9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C
M92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@
M<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3FEJ92!B
M:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T
M:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@
M;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"B,L(&9U>GIY"FUS9VED(")#;W5N=&5D
M('1E>'0B"FUS9W-T<B`B27-P<F%V;&IE;B!T96MS="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"B,L(&9U>GIY"FUS9VED(")#
M;W5N=')Y(@IM<V=S='(@(DYO=F$@<&]R=6MA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(W,PHC+"!F=7IZ>0IM<V=I9"`B0V]U<G-E<R(*;7-G
M<W1R(").;W9A('!O<G5K82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM
M<V=S='(@(DMR96ER86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB
M"FUS9W-T<B`B3F%P<F%V:2!L:6YK(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*
M;7-G<W1R(").87!R879I(&YO=FDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S
M(@IM<V=S='(@(E!R879L:F5N:F4@<&]D+69O;&1E<F$B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`HC+"!F=7IZ>0IM<V=I9"`B0W)E
M871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")$969A=6QT(&1O>G9O;&4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"B,L(&9U>GIY"FUS9VED
M(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B1&5C96UB87(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F5I
M<F%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@
M-"!0:&%S97,B"FUS9W-T<B`B27-P<F%V;&IE;B!T96MS="(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S
M:6]N<R(*;7-G<W1R("))<W!R879L:F5N('1E:W-T(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B27-P<F%V;&IE;B!T96MS="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T
M<B`B27-P<F%V;&IE;B!T96MS="(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("))<W!R
M879L:F5N('1E:W-T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0HC+"!F
M=7IZ>0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(DES<')A=FQJ
M96X@=&5K<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U
M"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B27-P<F%V;&IE;B!T
M96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+B(*;7-G<W1R(")0;V1E<VET92!Z861A=&ME(&MO:FD@YF4@<V4@
M:7IV<KEA=F%T:2!N86MO;B!P<FEJ879E(&YA("5S+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I
M9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S4*(RP@9G5Z>GD*;7-G:60@(D-U="!S96QE8W1I
M;VXB"FUS9W-T<B`B27IB;W(@8F]J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y
M<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM
M<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS
M9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS
M9W-T<B`B0V5N=')A;&YO+4%F<FGH:V$@4F5P=6)L:6MA(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G
M<W1R(")$;F5V;F\B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*(RP@9G5Z
M>GD*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B7T1A=&%4<F5E
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T
M86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"B,L(&9U>GIY"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(E!R:6UL:F5N82!N82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*(RP@9G5Z>GD*;7-G:60@(D1A
M=&4@<V5L96-T:6]N(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B
M36%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E($-O;'5M;B(*
M;7-G<W1R(")/8G)IN6D@9F]L9&5R*&4I(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(D1E8V5M8F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B1&5C:6UA
M;"!N=6UB97)S(@IM<V=S='(@(D1E8V5M8F%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@
M26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(E-T86YD87)D;F\B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G
M<W1R(")3=&%N9&%R9&YA(&)O:F$B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S
M='(@(D1E9F%U;'0@:61E;G1I=&5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@
M(E-T86YD87)D;F\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G
M:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:6-I:F4B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`B3V)R:;EI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@0V5L;"(*;7-G<W1R(")/8G)IN6DB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E($=R;W5P(@IM<V=S='(@(D]B<FFY:2(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO
M9R(*;7-G<W1R(")/8G)IN6DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")/8G)I
MN6D@<&]R=6ME(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B0G)I<V%N:F4@:2!I>F)A8VEV86YJ92!P;W)U:V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")/8G)IN6DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(D]B
M<FFY:2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE
M=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQE('IA("5S(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!R;W<B"FUS9W-T<B`B3V)R:;EI(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y(@IM<V=S='(@(D]B<FFY:2!I>F%B<F%N:2!I9&5N=&ET
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6XB"FUS9W-T<B`B4&]D97-I('9R96UE;G-K=2!Z;VYU+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*
M;7-G<W1R(")0;V1E<VD@=G)E;65N<VMU('IO;G4N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE
M(@IM<V=S='(@(D]B<FFY:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D]P:;EI
M=&4@<')O8FQE;64@=2!R861U('-A('=E8FUA:6QO;2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R(")/<&ES(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*
M;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*(RP@
M9G5Z>GD*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D]V82!P;W)U:V$@:F4@<')I:F%V
M;&IE;F$@:V%O('-P86T@<&]R=6MA(&%D;6EN:7-T<F%T;W)U('-I<W1E;6$N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V
M96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E
M8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5K=&]R
M:6HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P
M;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(E!R:6MAOFD@=G)I:F5M92!U
M(#(T+7-A=&YO;2!F;W)M871U/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P8VEJ92!P
M<FEK87IA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S
M='(@(E!R:6MAOFD@<')O9VYO>G4@*%1!1BDB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S
M='(@(E!R:6MAOFD@<')O9VYO>G4@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA
M="(*;7-G<W1R(")0<FEK8;YI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"B,L(&9U
M>GIY"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(E5N9&5L971E(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O
M;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")$;VUI;FEC86X@
M4F5P=6)L:6,B"FUS9W-T<B`B0V5N=')A;&YO+4%F<FGH:V$@4F5P=6)L:6MA
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N
M)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O
M=VYL;V%D(@IM<V=S='(@(D1O=VYL;V%D(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O
M=VYL;V%D("5S(@IM<V=S='(@(D1O=VYL;V%D("5S(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS
M9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R
M(")386YD=6-E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E
M<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E
M9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("))>FUI:F5N:2(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R
M-@HC+"!F=7IZ>0IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")/8G)IN6DB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B27IM:6IE;FD@9&]Z=F]L=2(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B27IM:6IE;FD@9&]Z=F]L92(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B27IM:6IE;FD@9&]Z=F]L92!Z82`E<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T
M:6]N<R!F;W(Z(@IM<V=S='(@(DEZ;6EJ96YI=&4@;W!C:6IE('IA.B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B
M"FUS9W-T<B`B27IM:6IE;FD@9&]Z=F]L92!Z82`E<R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(DEZ;6EJ96YI
M(&1O>G9O;&4@>F$@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*
M(RP@9G5Z>GD*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")!:V-I:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A4
M34P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*(RP@9G5Z>GD*;7-G:60@(D5M86EL
M(@IM<V=S='(@(E-A;F1U8V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G
M:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16UA:6P@861R97-A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PHC+"!F=7IZ>0IM<V=I9"`B
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D5M86EL(&%D
M<F5S82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z
M>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D]S
M=&%L92!I;F9O<FUA8VEJ92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B4VUA:FQI
M:FDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S
M='(@(E9AOFYE('!O<G5K92(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-3`*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(')E
M<W5L="XB"FUS9W-T<B`B27-P<F%Z;FD@:V]R<'4B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")%;7!T
M>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B27-P<F%Z;FD@9F]L9&5R(&MO<G!A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE
M(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@
M=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q
M.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS
M9W-T<B`B06MT:79I<F%J(&MO;G1E:W-T(&UE;FD@;F$@9&5S;F]M(&ML:6MU
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q,0HC+"!F=7IZ>0IM<V=I9"`B16YD('EE87(B
M"FUS9W-T<B`B4')ON6ER:2!F;VQD97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I
M86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W)I:F%L;F$@1W9I;F5J82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E:F$B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")'<F6Y:V$B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B
M17-T;VYI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M(")%=&EO<&EJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I
M9"`B171H;FEC(@IM<V=S='(@(D5T;FGH:VDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=G)O
M<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(E-V86MI:"`Q-2!M:6YU=&$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T
M97,B"FUS9W-T<B`B4W9A:VEH(#(@;6EN=71E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(E-V86MI:"`S,"!S96MU;F1I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B
M4W9A:VEH(#4@;6EN=71A(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
M2V]D('-V86ME('!R:6IA=F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B4W9A:VEH('!O
M;&$@<V%T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S
M='(@(E-V86MI(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")6<FEJ961N
M;W-T:2!P<FEM:F5R:3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M
M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G
M:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-#<U"B,L(&9U>GIY"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`B4')ON6ER:2!S=F4B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G
M<W1R(")0<F^Y:7)I(&9O;&1E<B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED
M(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L
M;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E
M9F5R96YC97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX
M"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3F4@;6]G=2!S92!S<&]J:71I(&YA($E-05`@<V5R
M=F5R.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC
M+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BXB"FUS9W-T<B`B3F4@;6]G=2!S92!S<&]J:71I(&YA($E-05`@<V5R=F5R
M.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"B,L
M(&9U>GIY"FUS9VED(")&86ER(@IM<V=S='(@(EIA:7(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1F%R;V4@27-L86YD<R(*
M;7-G<W1R(")";W5V970@;W-T<G9O(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@
M(D=R9;EK83H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM
M<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")&96)R=6%R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&
M:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T
M(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@
M9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B1FEL=&5R:2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P-PHC+"!F=7IZ>0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S
M='(@(DEM92!D871O=&5K92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B26UE(&1A
M=&]T96ME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0HC+"!F
M=7IZ>0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B;FEJ961N;R!P
M<F%V:6QO(&YI:F4@;V1A8G)A;F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#@V"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M(")0;VQJ92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL
M=&5R<R(*;7-G<W1R(")&:6QT97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM
M<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")4<F&^:2(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T
M<B`B4')V82!3=')A;F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<V"B,L(&9U>GIY"FUS9VED(")&:7)S="!1=6%R
M=&5R(@IM<V=S='(@(E!R=F$@4W1R86YA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B
M1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED(")&;VYT
M($-O;&]R(@IM<V=S='(@(E-T86YD87)D;F$@8F]J82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E9AN2!B<F]W<V5R(&YE('!O9'*^
M879A(&]V=2!M;V=UYFYO<W0N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,S0*(RP@9G5Z>GD*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(E!R
M:6MAOFD@<')O9VYO>G4@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA
M="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@
M;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN
M(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,#(*(RP@9G5Z>GD*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R("))>F%B97)I=&4@N6EF<G4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*
M;7-G<W1R(")/9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")&;VQD97)I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY
M"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")&;VQD97)I(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R`R
M(@IM<V=S='(@(D9O;&1E<FDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#4S"B,L(&9U>GIY"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]L9&5R
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*(RP@9G5Z>GD*
M;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E!R;W-L:6IE9&DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"B,L(&9U>GIY
M"FUS9VED(")&<B(*;7-G<W1R(")/9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@
M(D9R86UE<R(*;7-G<W1R("));64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS
M9VED(")&<F%N8V4B"FUS9W-T<B`B26UE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B3V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0P-@HC+"!F=7IZ>0IM<V=I9"`B1G)O;2!T:&4@
M(@IM<V=S='(@(D]D(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5T86QJ
M86X@;W!I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G
M<W1R("));64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1V%M8FEA(@IM<V=S
M='(@(EIA;6)I:F$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(E9R871I('-T87)U(&MO;F9I9W5R86-I:G4B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B
M1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=H86YA
M(@IM<V=S='(@(DMI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S4*(RP@9G5Z>GD*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B26UE
M(&1A=&]T96ME(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G
M:60@(D=O(@IM<V=S='(@(DMR96YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G
M:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!P<F5T<F%G82(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R
M8V@B"FUS9W-T<B`B1V]O9VQE('!R971R86=A(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K
M("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<NAK:2`H25-/+3@X-3DM-RDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B
M5&]K('1E;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")'<F5N861A
M(@IM<V=S='(@(E1O:R!T96UE(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*
M(RP@9G5Z>GD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B5S(&%D;6EN:7-T<F%C:6IA(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS
M9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B3FEJ92!U<W!E;&\@<W!AN6%V86YJ92!N97IA=G*Y96YE('!O
M<G5K92X@3W9O(&IE('!O<G5K82!S97)V97)A.B`E<R(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-S<*(RP@9G5Z>GD*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")?1W)U<&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"B,L(&9U>GIY"FUS9VED(")'=6%M(@IM<V=S='(@(DIU;FDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*(RP@9G5Z>GD*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ;6EJ96YI(&1O>G9O;&4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B
M1W5I;F5A(@IM<V=S='(@(DIU;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*(RP@9G5Z>GD*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B2G5N:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.`HC+"!F=7IZ>0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(DIU;FDB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E5S;6IE<F5N
M:F4@;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"B,L(&9U>GIY"FUS9VED(")(
M96%D97(B"FUS9W-T<B`B4&]M;^8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(E!O;6_F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)
M<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE
M879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(
M96)R96IS:VD@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"B,L(&9U>GIY"FUS9VED
M(")(96EG:'0B"FUS9W-T<B`B3F_F(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP
M:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E
M<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(E!O;6_F
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L
M<&5R(@IM<V=S='(@(E!O;6_F(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y
M"B,L(&9U>GIY"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(E!O;6_F(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B3F_F(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(
M;U]M92(*;7-G<W1R(")0;^A?971A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*
M;7-G<W1R(")0;^AE=&%K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
M061R97-A("AK=>9I*2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC
M+"!F=7IZ>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B1&ER96MT
M;W)I:B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L969O;B`H:W7F
M:2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO
M;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T
M<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U
M"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<
M(B(*;7-G<W1R("));64@9F]L9&5R82!<(B5S7"(@:F4@=7-P:F6Y;F\@<')O
M;6IE;FIE;F\@=2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R("));64@9F]L9&5R82!<(B5S7"(@:F4@
M=7-P:F6Y;F\@<')O;6IE;FIE;F\@=2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3$Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(E5S<&IEN6YO('-T92!P<FEJ879L:F5N:2!N82!<(B5S
M7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")5<W!J9;EN;R!S=&4@
M<')I:F%V;&IE;FD@;F$@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ
M;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*
M;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*
M;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")5
M<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")5<VUJ
M97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@861R97-A
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I
M9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A9')E
M<V$@;FEJ92!D;W-T=7!N82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP
M8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"!A9')E<V$@;FEJ92!D;WIV
M;VQJ96YA('5N=71A<B!#2412(&)L;VMA+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*(RP@9G5Z>GD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")0<FEM;&IE;F$@
M<')I:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
M27-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B
M26-O;G,@3VYL>2(*;7-G<W1R(")386UO(&EK;VYE(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O
M<B`E<R(*;7-G<W1R(")):V]N92!Z82`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("))
M:V]N92!S82!T96MS=&]M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("));64@:61E;G1I
M=&5T83HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED
M("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE
M="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X
M('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G
M:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@
M=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*
M(RP@9G5Z>GD*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!R971H
M;V1N82!S=')A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"B,L(&9U>GIY
M"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B4&]L:F4B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(").:6IE('!O<VQA;F\@:V]R
M:7-N:>AK;R!I;64@:2]I;&D@N6EF<F$N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0HC+"!F=7IZ>0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B
M;F]N92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L
M(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I
M9"`B26YD;VYE<VEA(@IM<V=S='(@(FYO;F4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,L(&9U>GIY"FUS9VED("))
M;F9O(@IM<V=S='(@(DEG;F]R:;EI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T
M<B`B4&5R<V]N86QN92!I;F9O<FUA8VEJ92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DYE;6$@9&]S='5P;FEH
M(&]P8VEJ82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M($EM86=E(@IM<V=S='(@(D]D9V]V;W)E;F4@<&]R=6ME(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(D]D9V]V;W)E;F4@<&]R=6ME
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@
M(E!R:6UL:F5N82!P<FEJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M(")0;V1E<VD@=G)E;65N<VMU('IO;G4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E
M<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T
M(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@
M869T97(B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E!R:6UL:F5N
M82!P<FEJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C;VQU;6X@
M869T97(B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B4')I;6QJ
M96YA('!R:6IE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R(")$;V1A
M=F%N:F4@<&]R=6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H
M(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G
M<W1R(")/9&=O=F]R96YE('!O<G5K92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G
M92(*;7-G<W1R(")/9&=O=F]R96YE('!O<G5K92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R(")?27IM:6IE;FD@;&EN:RXN
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B
M26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R
M(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS
M9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M
M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(").961O>G9O;&IE;F$@
M<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]D8G@N<&AP.C(R,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!F:6QE
M(&9O<FUA="(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@;&EC96YS92!K97DN(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U
M(&5M86EL(&%D<F5S:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E
M<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S
M:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P
M87)A;65T97)S+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I
M;"!A9')E<VDN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(").961O>G9O;&IE;F$@
M<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T
M(&-O9&4N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D
M<F5S:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN
M(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V
M82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V
M82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@=6YI8V]D92!D871A+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@
M=2!E;6%I;"!A9')E<VDN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*(RP@9G5Z>GD*;7-G
M:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B5G)E;65N<VMA('IO;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B27)E;&%N9"(*
M;7-G<W1R(")4;VL@=&5M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O
M;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U
M>GIY"FUS9VED("))<W)A96PB"FUS9W-T<B`B5&]K('1E;64B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B1&YE=FYO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED(")*86UA:6-A(@IM<V=S='(@
M(EIA;6)I:F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YU87(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I
M(@IM<V=S='(@(DIA<&%N<VMI("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H
M87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G
M92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B
M2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(DIU;&DB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N
M92(*;7-G<W1R(")*=6YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM
M<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*
M=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@
M(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+
M97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R(")/<&-I:F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@5'EP92(*;7-G
M<W1R(")-:6UE('1I<"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B
M4&]R=6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P
M"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0HC+"!F=7IZ>0IM
M<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B3&%O($YA<F]D;F$@1&5M;VMR871S:V$@4F5P=6)L:6MA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A
M;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU
M=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T
M86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX
M"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E)A7W-P;W)E9"(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S
M='(@(DIE>FEK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86\@3F%R;V1N82!$96UO
M:W)A='-K82!297!U8FQI:V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y
M"B,L(&9U>GIY"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B4')V82!3=')A
M;F$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G
M:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(E!A<W-W;W)D(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX
M.`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(E!R=F$@
M4W1R86YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B6F%D;FIA(&EZ;6IE;F$Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(EIA9&YJ82!P<FEJ879A.B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(EIA9&YJ
M82!P<FEJ879A.B`E<R!S82!A9')E<V4Z("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G
M<W1R("):861N:F$@<')I:F%V83H@3FEK860B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQA='9I82(*;7-G<W1R("),871V:6IA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B6F%K;VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*
M;7-G:60@(DQA>6]U="(*;7-G<W1R(")287-P;W)E9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E
M(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,L(&9U>GIY
M"FUS9VED("),969T(@IM<V=S='(@(E!R96)A8VDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("):861N:F$@<W1R86YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T;R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM
M<V=I9"`B3&5V96PB"FUS9W-T<B`B3FEK861A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R:6IA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FEJ
M<VMA($%R87!S:V$@1+YA;6%H:7)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EH=&5NN71A:FXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG
M:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I
M;B(*;7-G<W1R(")0<FEJ879I('-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I
M9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A
M:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(DQI
M;65R:6-K(@IM<V=S='(@(DQI8F5R:6IA(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("),
M:6YK;W9I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*
M;7-G<W1R("),:6YK;W9I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V
M"B,L(&9U>GIY"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3F]V82!P
M;W)U:V$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(DQI<W1A;FIE("T@:V]R:7-N:6L@;6^^92!V:61J971I(&9O;&1E
M<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(EIA9&YJ82!S=')A;F$B"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3&ES
M="!(96QP(%1O<&EC<R(*;7-G<W1R(")0;VUOYB(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S(*(RP@9G5Z>GD*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S
M='(@(EIA9&YJ82!S=')A;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y-`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U!<F-H:79E(@IM
M<V=S='(@(E-A:W)I:B!N975P:7-A;F4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP
M(@IM<V=S='(@(E!O;6_F(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B
M4&]M;^8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R(")0;VUOYB(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED
M("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@(DQI<W0M4W5B<V-R
M:6)E(@IM<V=S='(@(E-A:W)I:B!N975P:7-A;F4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`HC+"!F=7IZ>0IM<V=I9"`B3&ES
M="U5;G-U8G-C<FEB92(*;7-G<W1R(")386MR:6H@;F5U<&ES86YE(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B57-M
M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"B,L(&9U>GIY
M"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(E9AN2!P;W1P:7,Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET=F$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS
M9VED("),;V%D:6YG+BXN(@IM<V=S='(@(E7H:71A=F%M+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM
M93H@(@IM<V=S='(@(DQO:V%L;F\@=G)I:F5M93H@(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T
M<B`B3&]K86QN92!P;W-T879K92!I('9R:6IE;64B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DQO
M:V%C:6IA(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(E!R:6IA=FD@
M<V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@
M(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U
M="(*;7-G<W1R("))>FQA>B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B4')I:F%V:2!S92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A
M<VMS(@IM<V=S='(@(EIA9&%C:2!P<FEJ879E(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+B(*;7-G<W1R("(B"B)0<FEJ879A(&YI:F4@=7-P:F5L82X@3F%J=F5R
M;W9A=&YI:F4@:F4@<&]G<F6Y;F\@=6YE<V5N;R!K;W)I<VYIZ&MO(&EM92!I
M;&D@(@HBN6EF<F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR
M"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(E!R:6IA=F$@;FEJ92!U
M<W!J96QA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*;7-G
M:60@(DQO;F<@=&5X="(*;7-G<W1R(")$=6=I('1E:W-T(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0X"B,L(&9U>GIY"FUS9VED("),;W9E(@IM<V=S
M='(@(DYA<W1A=FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B3&]W(@IM<V=S='(@(EIA:V]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*(RP@9G5Z>GD*;7-G:60@(DQO=V5R(')O;6%N(&YU
M;6)E<G,B"FUS9W-T<B`B1&5C96UB87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5K<V5M8G5R9R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")-4T<B
M"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-
M86-A;R(*;7-G<W1R(")-87)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E
M9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I
M9"`B36%G:6,B"FUS9W-T<B`B36%R="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX,0HC+"!F=7IZ>0IM<V=I9"`B36%I;"(*;7-G<W1R(")386YD
M=6-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN
M7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`B4V%N9'5C92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY
M"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")&:6QT97)I('!ON71E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(E-A;F1U
M8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(E-A;F1U8V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G
M:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(DYA<')A=FET
M92!K871E9V]R:6IE('-T879K:2!I('IA('-V86MU(&]D(&YJ:6@@;V1R961I
M=&4@;V1G;W9A<F%J=>9U(&)O:G4N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@
M<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")5<&]Z;W)E
M;FIE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R
M(")/>FYAZ&%V86YJ92!K86\@<')OZ&ET86YO+VYE<')OZ&ET86YO(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@
M(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I(@IM<V=S='(@(D]Z;F'H879A;FIE(&1R=6=I;2!O>FYA:V%M82`H;G!R
M+B!V8;YN;R!I;&D@;V1G;W9O<F5N;RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@
M(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%RN6%L;W9A(&]S=')V82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T
M:6YI:R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B3V1G;W9A<F%J=>9A('!O;&IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA
M=7)I=&%N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS
M9W-T<B`B36%U<FEC:6IU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*(RP@9G5Z>GD*;7-G:60@(DUA>"!M97-S
M86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")0;VQJ82!P;W)U:V4B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@
M;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M
M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA:B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B
M36%J(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"B,L(&9U>GIY"FUS
M9VED(")-961I8VEN92(*;7-G<W1R(")/8G)I<V%N82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS
M9W-T<B`BR&QA;F]V:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*
M;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B5G)S=&$@;65N:6IA.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(E-P;VII('!O;&IA(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B4&]R=6MA(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`B4&]L:F$@<&]R=6ME(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM
M<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(D1A='5M('!O<G5K92(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"B,L(&9U>GIY
M"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").
M96UA(&1O<W1U<&YI:"!O<&-I:F$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(D]V82!P;W)U:V$@:F4@<')I:F%V;&IE;F$@
M:V%O('-P86T@<&]R=6MA(&%D;6EN:7-T<F%T;W)U('-I<W1E;6$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(DUE=&AO9"(*
M;7-G<W1R("),97-O=&\B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N
M<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D
M(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE
M=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G
M:60@(DUI9&1L92(*;7-G<W1R(")0<F5B86-I(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*
M;7-G<W1R(")-:6UE('1I<"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P
M"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA
M<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H
M87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R(")'<F6Y:V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P
M"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@
M(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#0*(RP@9G5Z>GD*;7-G:60@(DUI<W-I;F<@
M;65S<V%G92!)1"XB"FUS9W-T<B`B3W9A('!O<G5K82!U(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G
M:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-`HC+"!F=7IZ>0IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$
M+B(*;7-G<W1R(")/=F$@<&]R=6MA('4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"B,L(&9U>GIY"FUS9VED(")-;R(*
M;7-G<W1R(")0<F5B86-I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C<T"B,L(&9U>GIY"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(").;W9A
M('!ON71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B36]D:69Y(%523"(*;7-G
M<W1R(")?27IM:6IE;FD@;&EN:RXN+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C<S"B,L(&9U>GIY"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(E!R96)A8VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`HC+"!F=7IZ
M>0IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUA<G0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B36IE<V7H;F\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L
M('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@
M)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L
M96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM
M<V=S='(@(DMO<&ER86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0HC+"!F
M=7IZ>0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(G!O;6IE<FD@;FF^92(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PHC+"!F
M=7IZ>0IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(E!R96)A8VDB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0HC+"!F=7IZ>0IM<V=I
M9"`B36]V92!5<"(*;7-G<W1R(")0<F5B86-I(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`HC+"!F=7IZ>0IM<V=I9"`B
M36]V92!D;W=N(@IM<V=S='(@(G!O;6IE<FD@;FF^92(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`HC+"!F=7IZ>0IM<V=I
M9"`B36]V92!U<"(*;7-G<W1R(")P;VUJ97)I('9IN64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*(RP@9G5Z>GD*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36%R=&EN
M:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@
M(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!S96QE
M8W1I;VXB"FUS9W-T<B`B;FEJ961N;R!P<F%V:6QO(&YI:F4@;V1A8G)A;F\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"B,L(&9U>GIY"FUS
M9VED(")->2!!8V-O=6YT(@IM<V=S='(@(E)AZ'5N;W9O9'-T=F\B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y92!I;F9O<FUA8VEJ92(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*(RP@9G5Z>GD*;7-G
M:60@(DUY(%!O<G1A;"(*;7-G<W1R(")287-P;W)E9"!M;V<@<&]R=&%L82(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O
M<G1A;"!,87EO=70B"FUS9W-T<B`B4F%S<&]R960@;6]G('!O<G1A;&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@
M(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("));64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B
M6F%M8FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").97!A;"(*;7-G<W1R
M(").;W9A('!ON71A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").
M971H97)L86YD<R(*;7-G<W1R(").;W9I(%IE;&%N9"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T
M<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I
M9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(DUR9;YA(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM
M<V=I9"`B3F5V97(B"FUS9W-T<B`B3FEK861A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=F$@2V%L961O;FEJ82(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F]V82!K871E9V]R
M:6IA(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE
M<W-A9V4@=&\@)7,B"FUS9W-T<B`B3F]V82!P;W)U:V$@*"5S*2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B
M3F]V:2!M:F5S96,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M(").;W9O(&MO<FES;FGH:V\@:6UE("AN:6IE(&]B879E>FYO*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F]V:2!:96QA
M;F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z
M>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("*I:69R82(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@
M(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@
M(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]V:2!P<F]Z;W(@*%]P
M<F%Z86XI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]V;W-T:2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T
M<B`B3F5W<RUG<G5P92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(D1A;&IE(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S
M(@IM<V=S='(@(E-L:F5D9>9A(&9A>F$B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,W-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E-L:F5D9>9E(&]P
M8VEJ92(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"B,L(&9U
M>GIY"FUS9VED(").97AT/B(*;7-G<W1R(")$86QJ92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=V82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I:F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*
M;7-G<W1R(").;^8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T
M<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(DYE(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E
M9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG
M92XB"FUS9W-T<B`B4')O;6IE;FDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U>GIY"FUS9VED
M(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B3F]V92!P;W)U
M:V4B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*(RP@
M9G5Z>GD*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B4&]L:F4B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(E<R!N:6IE('!R;VYA\&5N+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS
M9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO
M(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").:6IE9&%N(&9O;&1E<B!N
M:6IE('-P96-I9FEC:7)A;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,L(&9U>GIY"FUS9VED(").;R!M97-S
M86=E('-U<'!L:65D+B(*;7-G<W1R(").;W9E('!O<G5K92(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U
M>GIY"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B;FEK86MA
M=B!T96MS="!N:6IE('-P96-I9FEC:7)A;B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED
M(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(")N:6MA:V%V('1E:W-T
M(&YI:F4@<W!E8VEF:6-I<F%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME
M<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I
M9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N
M=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(DYE(&EZ8G)I<V%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO
M(')U;&5S(@IM<V=S='(@(DYI:F5D;F$B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O<B!S
M<&5C:69I960N(@IM<V=S='(@(FYI:V%K878@=&5K<W0@;FEJ92!S<&5C:69I
M8VER86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R
M(").92!I>F)R:7-A;F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*
M;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G
M<W1R(").:6IE('!O<VQA;F\@:V]R:7-N:>AK;R!I;64@:2]I;&D@N6EF<F$N
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").
M;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B3FEJ
M961A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/
M+3@X-3DM,3`I(@IM<V=S='(@(DYO<F1I:G-K:2`H25-/+3@X-3DM,3`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").;W)F;VQK($ES;&%N9"(*
M;7-G<W1R(")-87*Y86QO=F$@;W-T<G9A(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@
M2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*
M;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(")-87*Y
M86QO=F$@;W-T<G9A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").
M;W)W87DB"FUS9W-T<B`B4')O<VQI:F5D:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED(").;W0@069T
M97(B"FUS9W-T<B`B3F]T($1R869T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,SD*(RP@9G5Z>GD*;7-G:60@(DYO="!"969O<F4B
M"FUS9W-T<B`B3F]T($1R869T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-#`X"B,L(&9U>GIY"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS
M9W-T<B`B4')A=F%C('-O<G1I<F%N:F$B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R
M(").92!I>F)R:7-A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S
M='(@(DYE(&EZ8G)I<V%N82(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-C8U"B,L(&9U>GIY"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R(").92!I>F)R:7-A;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*(RP@9G5Z>GD*;7-G
M:60@(DYO=&5S(@IM<V=S='(@(DYI:F5D;F$B"@HC.B!S97)V:6-E<R]O8G)O
M=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G
M;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V
M96UB87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U
M>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B3F]V96UB87(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-`HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F
M(&-O;'5M;G,B"FUS9W-T<B`B<&]M:F5R:2!N:;YE(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*(RP@9G5Z>GD*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(DYO=F5M8F%R(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G
M:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W
M,PHC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(E1E;6$B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B
M3V)J96-T($-R96%T;W(B"FUS9W-T<B`B5&5M82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED
M(")/8W1O8F5R(@IM<V=S='(@(D]K=&]B87(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC
M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B
MJ6EF<F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@
M9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS
M9W-T<B`B4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D
M(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3<Q"B,L(&9U>GIY"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S
M;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*
M(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A
M8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I
M9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R871I=FYI('-I<W1E
M;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`B3W!C:6IE(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P8VEJ92!Z82`E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3@*(RP@9G5Z>GD*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("),:7-T
M82!S82!T8>AK86UA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M(")296=I<W1R86-I:F$@:V]R:7-N:6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S
M,@HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")5<&]Z;W)E
M;FIE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I
M;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D]S=&%L;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM
M<V=S='(@(D]S=&%L92!I;F9O<FUA8VEJ92(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D]W;F5R(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(DMO<FES;FGH:V4@;W!C:6IE(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B57-M:F5R
M96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,C<S"B,L(&9U>GIY"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B
M"FUS9W-T<B`B6F%T86UN:2!P;W1P:7-E/R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(
M4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS
M9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ
M>0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")086YA;6$B
M"FUS9W-T<B`B2V%N861A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.
M97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*
M;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(DYI:V%R86=V82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"B,L(&9U>GIY"FUS
M9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(DMO<&ER86HB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")0
M87-S=V]R9"(*;7-G<W1R("*I:69R82(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R
M96-T(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PHC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@
M(E!A<W-W;W)D.B(*;7-G<W1R(")087-S=V]R9"(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@
M(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(D5M86EL(&%D<F5S82(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED(")087-T92(*
M;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3$*(RP@9G5Z>GD*;7-G:60@(E!A=&@B"FUS9W-T<B`B1&%T=6TB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N
M9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("),:G5D:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED
M(")097)C96YT(@IM<V=S='(@(E!R;V-E;F%T(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("))>G9RN6D@<V5R=FES
M;F4@;W!E<F%C:6IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM
M<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/R(*;7-G<W1R("))>G9RN6D@<V5R=FES;F4@;W!E<F%C:6IE('!R:6QI:V]M
M(&QO9VER86YJ83\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")$;WIV;VQE(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S
M='(@(D1O>G9O;&4@>F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`B1&]Z=F]L92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"B,L(&9U>GIY
M"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")?1&]Z=F]L92(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:6IA(&1O>G9O;&$@*'!R:79I;&5G
M:6IA*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R
M<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B3&GH;F4@:6YF;W)M86-I:F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@HC
M+"!F=7IZ>0IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B;F]N92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W
M"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM
M<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@
M=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3<Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!M
M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R(")-;VQI;2!T92!P;W!R879I(&1V
M;W-M:7-L96YE(&]D;F]S;F\@:6YV86QI9&YE(&%D<F5S92XB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0HC+"!F
M=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB
M"FUS9W-T<B`B36]L:6T@=&4@<&]P<F%V:2!D=F]S;6ES;&5N92!O9&YO<VYO
M(&EN=F%L:61N92!A9')E<V4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0HC+"!F=7IZ>0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B36]L
M:6T@=&4@<&]P<F%V:2!D=F]S;6ES;&5N92!O9&YO<VYO(&EN=F%L:61N92!A
M9')E<V4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM
M<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+B(*;7-G<W1R(")-;VQI;6\@9&%J=&4@:W)A=&%K(&]P:7,@=F&Y96<@<')O
M8FQE;6$@<V$@=V5B;6%I;&]M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@HC+"!F=7IZ
M>0IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`B3FEJ92!P;W-L86YO(&MO<FES;FGH:V\@:6UE(&DO
M:6QI(+EI9G)A+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U
M>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI
M<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI
M<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E-L86YJ92!U(&]V86H@
M9F]L9&5R("AN:6IE('!R:6YU\&5N;R!O9"!S=')A;F4@24U!4&$I(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A
M<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S
M<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM
M<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0HC+"!F=7IZ>0IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"B,L
M(&9U>GIY"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E!R971H;V1N82!S=')A
M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V
M-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0<F5T:&]D;F4@
M;W!C:6IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV
M871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96T_
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M
M($1E<V-R:7!T:6]N(@IM<V=S='(@(D]P:7,@<')O8FQE;6$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X-0HC+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T
M<B`B27-P<F%V;&IE;B!T96MS="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B
M4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@
M26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E
M;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*(RP@9G5Z>GD*;7-G:60@(E%A=&%R(@IM<V=S='(@(D1A='5M(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B
M:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-C0*(RP@9G5Z>GD*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")6
M<F5M96YS:V$@>F]N82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0S"B,L(&9U>GIY"FUS9VED(")286EN(@IM<V=S='(@(E5P
M;WIO<F5N:F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS
M9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E)A=&EO(@IM
M<V=S='(@(D]P8VEJ92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"B,L(&9U>GIY"FUS9VED(")296%D(@IM<V=S='(@(DYE('!R
M;^AI=&%N92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(LAI=&%N:F4@
M<&]R=6MA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"B,L
M(&9U>GIY"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M("));F9O<FUA8VEJ92!S97)V:7-A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E
M<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM
M<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@
M(D&^=7)I<F%J(&1I;F%M:>AK92!E;&5M96YT92!M96YI:F$Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@
M5FEE=SHB"FUS9W-T<B`B0;YU<FER86H@<&_H971N=2!S=')A;FEC=3HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U
M"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R(")0;VYIN71I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS
M:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC
M+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(DYE('!R;^AI=&%N92(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"B,L(&9U>GIY"FUS9VED(")2
M96UA<FMS(@IM<V=S='(@(EIA8FEL:F6Y:V4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")5
M9&%L:F5N:2!S97)V97)I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B561A;&IE;FD@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R(").87-T879I
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B56ML;VYI(&]D86)R86YI
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M-PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")P;VUJ
M97)I(&YIOF4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*
M;7-G<W1R("));F9O<FUA8VEJ92!S97)V:7-A(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,C@*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!P86ER
M(@IM<V=S='(@(G!O;6IE<FD@=FFY92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B56ML;VYI(&]D
M86)R86YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R
M(@IM<V=S='(@(FEZ8F%C:2!I>G9O<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(FEZ8F%C:2!I>G9O<B(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T
M(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W
M"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")0;VYIN71I
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*
M;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@
M(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E
M<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*(RP@9G5Z
M>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5Z=6QT871I('!R971R86=E
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*
M;7-G<W1R(").87IA9"!N82!O<&-I:F4B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")2975N:6]N(@IM<V=S='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@
M(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E9R871I('-T87)U(&MO
M;F9I9W5R86-I:G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"FUS
M9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B3W!C:6IE
M(&5D:71O<F$@=&5K<W1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X
M"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I
M9"`B4FEG:'0B"FUS9W-T<B`B3F_F(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*(RP@9G5Z>GD*;7-G:60@
M(E)I9VAT('9A;'5E<R(*;7-G<W1R("):861N:F$@<W1R86YA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X
M"B,L(&9U>GIY"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M3W-O8FEN92#F7V5L:6IE+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B4F]L92(*;7-G
M<W1R(").87-T879I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(U"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@
M(DQI<W1A(&MO;G1A:W1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B4F]T871E($QE9G0B
M"FUS9W-T<B`B3&ES=&$@:V]N=&%K=&$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"B,L(&9U>GIY"FUS9VED(")2;W1A
M=&4@4FEG:'0B"FUS9W-T<B`B3&ES=&$@:V]N=&%K=&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"B,L(&9U
M>GIY"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")/<V]B:6YE(.9?
M96QI:F4N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<P"B,L(&9U>GIY"FUS9VED(")2;W<@<')O<&5R=&EE
M<R(*;7-G<W1R(")/<V]B:6YE(.9?96QI:F4N+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T
M<B`B4F5Z=6QT871I('!R971R86=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")2=6XB"FUS9W-T
M<B`B4F5U;FEO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D
M97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS
M9VED(")2=V%N9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(E-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE
M('5S<&5L;RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L
M(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E!R96=L961A
M=F%N:F4@<&]R=6ME(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM
M<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*
M;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B
M4V$B"FUS9W-T<B`B4V'H=79A:B!K86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED
M(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S
M96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED
M(")386UO82(*;7-G<W1R(")+86UB;_!A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F
M=7IZ>0IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")5<&]Z;W)E;FIE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")3
M879E(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4V'H=79A:B!K86\B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")38>AU=F%J(&MA;R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*
M;7-G<W1R(")38>AU=F%J(&]P8VEJ92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9R871I('-T87)U(&MO;F9I
M9W5R86-I:G4B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O
M8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T
M;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*
M;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")4<F&^:2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C
M:"!%;F=I;F5S(@IM<V=S='(@(E)E>G5L=&%T:2!P<F5T<F%G92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!&:6QE<R(*;7-G<W1R(")/9&%B97)I('-V92(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B3V1A8F5R:2!I9&5N=&ET970B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(D]D86)E<FD@
M:V]D;FD@<F%S<&]R960@<VQO=F$Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R
M(@IM<V=S='(@(D]D86)E<FD@;F]N92(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@
M(DEZ86)E<FET92!S97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B
M"FUS9W-T<B`B3V1A8F5R:2!K;V1N:2!R87-P;W)E9"!S;&]V83HB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(D]D86)E<FD@<W9E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E!R:6QO
M9R!J92!O8G)I<V%N+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!O8FIE
M8W0B"FUS9W-T<B`B3V1A8F5R:2!N;VYE(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&YO;F4B"FUS9W-T<B`B3V1A8F5R:2!N;VYE(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S
M='(@(D]D86)E<FD@:V]D;FD@<F%S<&]R960@<VQO=F$Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(D]D86)E<FD@:V]D;FD@<F%S<&]R
M960@<VQO=F$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z(@IM<V=S='(@(DEZ86)E<FET92!I9&5N=&ET970@:V]J:2"^
M96QI=&4@<')O;6EJ96YI=&DZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z(@IM<V=S='(@(D]D86)E<FD@:V]D;FD@<F%S<&]R960@<VQO=F$Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(D]D86)E<FD@:V]D
M;FD@<F%S<&]R960@<VQO=F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N(@IM<V=S='(@(D]D9V]V87)A:G7F82!P;VQJ82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B27IA8F5R:71E(+EE;74@8F]J82XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(DEZ86)E<FET92"^96QJ96YI
M(&IE>FEK.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X
M"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E!ON6%L:FD@
M<')I:F%V=2!P<F]B;&5M82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R(")0
M;[EA;&II(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS
M9VED(")396YS;W(Z("(*;7-G<W1R(")396YZ;W(Z("(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB
M97(B"FUS9W-T<B`B4V5P=&5M8F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R
M;R(*;7-G<W1R(")3<F)I:F$@:2!#<FYA($=O<F$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E
M<B(*;7-G<W1R(")397)I:G-K:2!B<F]J(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@
M=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F5M82!D;W-T=7!N
M:6@@;W!C:6IA+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ
M>0IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')A8VEJ
M82!D;WIV;VQA("AP<FEV:6QE9VEJ82DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@
M240@97AP:7)E9"XB"FUS9W-T<B`B240@<V5S:6IE(&IE(&ES=&5K86\N(@H*
M(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R(")?1&]Z=F]L92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,30*;7-G:60@(E-E="(*;7-G<W1R(")/9&%B97)I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N(@IM<V=S='(@(B(*(E!O9&5S:71E(&]P8VEJ92!K;VIE('9A;2!O
M;6]G=>9U:G4@9&$@<&]N:;ET:71E(+EI9G)U(&%K;R!J92!Z86)O<F%V:71E
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B)0;V1E<VET92!U9&%L:F5N92!S
M97)V97)E(&MO:FEM82"^96QI=&4@<')I<W1U<&ET:2!P=71E;2!V8;EE9R!P
M;W)T86QA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+B(*;7-G<W1R(")/9&%B97)I=&4@OF5L:F5N:2!J97II:RP@
M=G)E;65N<VMU('IO;G4@:2!P;W-T879K92!Z82!D871U;2XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)0
M;V1E<VET92!S=&%R=&YU(&MO;7!O;F5N='4L(+EE;74@8F]J82P@;W-V:F6^
M879A;FIE('-T<F%N:6-E(&D@9')U9V4@;W!C:6IE("(*(FMO:F4@<V4@=&GH
M=2!P<FEK87IA+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G
M:60@(E-E='5P(@IM<V=S='(@(E!O<W1A=FME(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")396JY96QI
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO
M<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2W)A=&%K
M(&]P:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B
M"FUS9W-T<B`B1&$@;&D@9&5F:6YI<V%T:2!P<FES='5P;F4@=&EP:V4@>F$@
M;&EN:V]V93\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")0<FEK8;YI(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(E!R:6MAOFD@=G)I:F5M92!Z
M861N:F4@<')I:F%V92!N86MO;B!L;V=I<F%N:F$_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E!R:6MAOFD@;65N:2!Z82!M
M86YI<'5L86-I:F4@=&%B96QA;6$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/R(*;7-G<W1R(")0<FEK8;YI("5S(&UE;FD@;&EJ979O
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E!R
M:6MAOFD@;65N:2!Z82!M86YI<'5L86-I:F4@=&%B96QA;6$_(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P
M"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8S"B,L(&9U>GIY"FUS9VED(")3:&]W('5P;&]A9"(*;7-G
M<W1R(")$;W=N;&]A9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W97)S(@IM<V=S='(@
M(E!R:6MAOFDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R
M(")+<F%T86L@;W!I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR
M:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX
M,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I
M;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*(RP@9G5Z
M>GD*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B)7,@<')I:F%V82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"B,L(&9U>GIY"FUS
M9VED(")3:6=N871U<F4B"FUS9W-T<B`B5F&Y('!O='!I<SHB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0HC+"!F=7IZ>0IM<V=I
M9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")68;D@<&]T<&ES.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-I;F=A<&]R92(*;7-G
M<W1R(")68;D@<&]T<&ES.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B5F5L:>AI;F$B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B
M4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")0<F5S:V_H:2!S97)V:7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM
M<V=I9"`B4VYO=R(*;7-G<W1R(")0<FEK8;YI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@
M(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W
M97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-S@*(RP@9G5Z>GD*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(@5&5M
M83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@
M97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"B,L(&9U>GIY
M"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")0<F%V86,@
M<V]R=&ER86YJ82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A
M9&1R97-S(@IM<V=S='(@(E9AN6$@92UM86EL(&%D<F5S83HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R(")*=;YN;RUE=G)O<'-K:2`H25-/+3@X-3DM
M,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@
M(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"B,L(&9U>GIY
M"FUS9VED(")3<&%C97(B"FUS9W-T<B`B4V'H=79A:B!K86\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX
M"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP
M=70B"FUS9W-T<B`B4W!E8VEJ86QN:2!K87)A:W1E<FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"B,L(&9U
M>GIY"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(D]D86)E<FD@<W9E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(D]D
M86)E<FD@<W9E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@<F]W(@IM
M<V=S='(@(D]D86)E<FD@<W9E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z
M>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(DMA;&5N9&%R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P
M"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*
M(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(DEN9F]R
M;6%C:6IE('-E<G9I<V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B3V0@861R97-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"B,L(&9U>GIY
M"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")L:7-T82!Z861A=&%K82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G
M:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B5S(&YI:F4@<')O;F'P96XN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R(")496UA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PHC+"!F=7IZ
M>0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E1E;6$B"@HC.B!S:6=N=7`N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G
M(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@
M(E1E;6$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B57-P:F6Y;F\B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G
M<W1R(")<(B5S7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S87(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&IE('5S<&5S;F\@9&]D
M86X@=2!A9')E<V%R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(DEM92!F
M;VQD97)A(%PB)7-<(B!J92!U<W!J9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<
M(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O9&%N('4@
M861R97-A<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B
M4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B26UE(&9O;&1E<F$@7"(E
M<UPB(&IE('5S<&IEN6YO('!R;VUJ96YJ96YO('4@7"(E<UPB+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=W)O=&4@)7,B"FUS9W-T<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE('5S<&IE
MN6YO('!R;VUJ96YJ96YO('4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U
M;6UA<GDB"FUS9W-T<B`B2W)A=&%K(&]P:7,B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@
M(E1E;6$B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*(RP@9G5Z>GD*
M;7-G:60@(E-U;B!3970B"FUS9W-T<B`B5&5M82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"B,L
M(&9U>GIY"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E1E;6$B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*
M(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E1E;6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"B,L(&9U>GIY
M"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(%1E;6$Z("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(E-U
M;G-E="(*;7-G<W1R(")496UA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q.`HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B
M(%1E;6$Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@
M(E1E;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"FUS9VED
M(")3=7!P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*
M;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(DEM92!D871O=&5K92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS
M9VED(")3=7)N86UE(@IM<V=S='(@(E5S97)N86UE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T
M<B`B5')AOFDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=V5D
M96XB"FUS9W-T<B`B5FED:F5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET
M>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G
M<W1R(")5;F1E;&5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*
M;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(E-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B27-P<F%Z;FD@9F]L9&5R(&MO
M<G!A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-PHC+"!F=7IZ>0IM<V=I9"`B4WER:6%N($%R
M86(@4F5P=6)L:6,B"FUS9W-T<B`B0V5N=')A;&YO+4%F<FGH:V$@4F5P=6)L
M:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD
M(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R(*;7-G
M<W1R(")/9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S
M-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B6F%D;FIA('-T<F%N
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS
M9W-T<B`B3W-O8FEN92!?=&%B96QE+BXN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(E1A8FQE('!R;W!E<G1I
M97,B"FUS9W-T<B`B3W-O8FEN92!?=&%B96QE+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"B,L
M(&9U>GIY"FUS9VED(")487)G970Z(@IM<V=S='(@(E!O<G5K82(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X-PHC+"!F=7IZ>0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B3&]G:6X@
M>F%D86-I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*(RP@9G5Z>GD*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B
M4V5R:6IS:VD@8G)O:B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS
M9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I
M9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B5S(&YI:F4@<')O;F'P96XN(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E1E;7!L871E($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S(&%D;6EN:7-T<F%C:6IA(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(E1E:W-T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0HC+"!F=7IZ>0IM<V=I9"`B5&5X
M="!/;FQY(@IM<V=S='(@(E1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B
M5&5X="!A;&EG;B(*;7-G<W1R(")3;&IE9&5C82!S=')A;F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"B,L(&9U>GIY
M"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E:W-T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H
M86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z
M>GD*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1R8;YI(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN(@IM<V=S='(@(DAV86QA(+ET;R!K;W)I<W1I=&4@
M16YE<F=O9&%T82!W96)M86EL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(P"B,L(&9U>GIY"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A9')E<V$@;FEJ92!D;W-T
M=7!N82XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@
M(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RXB"FUS9W-T<B`B4')O>F]R('IA(&]P8VEJ92!S92!Z871V
M;W)I;RX@27IL87II;2XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM
M<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED
M(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B
M(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!C;VYT86-T('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O9&%N('4@861R97-A<B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC
M<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@
M)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<(B!J92!O
M8G)I<V%N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U
M>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R
M:6,N(@IM<V=S='(@(D]V82!V<FEJ961N;W-T(&UO<F$@8FET:2!B<F]J+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B
M96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W
M86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O
M=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@
M<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(DED96YT:71E="!<(B5S7"(@:F4@;V)R:7-A;BXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@
M(DED96YT:71E="!<(B5S7"(@:F4@<V'H=79A;BXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B
M261E;G1I=&5T(%PB)7-<(B!J92!S8>AU=F%N+B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE
M9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@
M(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@
M;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I
M9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO
M1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL
M92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED
M(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B3F5M82!D;W-T=7!N:6@@;W!C:6IA+B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DYE;6$@9&]S='5P;FEH
M(&]P8VEJ82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HS-#(*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(").96UA(&1O<W1U
M<&YI:"!O<&-I:F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB
M"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<VQA;FIA('!O<G5K93H@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<VQA;FIA('!O<G5K
M93H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E
M<UPB.B`E<R(*;7-G<W1R(")$97-I;&$@<V4@9W)EN6MA('1O:V]M('-L86YJ
M82!P;W)U:V4Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L
M;V%D960N(@IM<V=S='(@(B(*(DIA=FEO('-E('!R;V)L96T@<V$@9&]D879A
M;FIA(&1A=&]T96ME+B!-;V=UYFD@<')O8FQE;2P@9&%T;W1E:V$@:F4@=F7F
M82!O9"`B"B)M87@@9&]Z=F]L:F5N:6@@34(N(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L
M;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)*879I;R!S92!P
M<F]B;&5M('-A(&1O9&%V86YJ96T@9&%T;W1E:V4N($UO9W7F:2!P<F]B;&5M
M+"!V96QIZ&EN82!D871O=&5K92`B"B)J92!V9>9A(&]D(&UA>"X@9&]Z=F]L
M:F5N:6@@*"5D($U"*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(DIA=FEO
M('-E('!R;V)L96T@<V$@9&]D879A;FIA(&1A=&]T96ME+B!-;V=UYFD@<')O
M8FQE;2P@9&%T;W1E:V$@:F4@=F7F82!O9"`B"B)M87@@9&]Z=F]L:F5N:6@@
M34(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI
M<R!M97-S86=E('!A<G0B"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO
M;2!P<FEK87IA(&]V;V<@9&EJ96QA('!O<G5K92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB
M"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!S<&&Y879A;FIA(&YE
M>F%V<KEE;F4@<&]R=6ME+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC
M+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D1E<VEL82!S
M92!G<F6Y:V$@=&]K;VT@<W!AN6%V86YJ82!N97IA=G*Y96YE('!O<G5K92XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"B,L(&9U>GIY"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L
M9"XB"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2#H:71A;FIA(&]D
M86)R86YE('!O<G5K92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@Z&ET86YJ82!O9&%B<F%N
M92!P;W)U:V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$97-I;&$@<V4@9W)EN6MA('1O
M:V]M('!R:6MA>F$@;W9O9R!D:6IE;&$@<&]R=6ME(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*(RP@9G5Z>GD*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@Z&ET86YJ82!O9&%B<F%N92!P;W)U
M:V4N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,30X"B,L(&9U>GIY"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")68;D@8G)O=W-E
M<B!N92!P;V1ROF%V82!O=G4@;6]G=>9N;W-T+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M(@IM<V=S='(@(B5S(&YE(&EZ9VQE9&$@:V%O(&1O>G9O;&IE;B!T:7`@<V%N
M9'5C971A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B5S(&YE(&EZ9VQE9&$@
M:V%O(&1O>G9O;&IE;B!T:7`@<V%N9'5C971A+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(E
M<R!N92!I>F=L961A(&MA;R!D;WIV;VQJ96X@=&EP('-A;F1U8V5T82XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC
M:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B
M"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R
M,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B3W9A('9R
M:6IE9&YO<W0@;6]R82!B:71I(&)R;VHN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE
M;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@
M;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@
M2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M
M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C
M:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G
M:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R
M(")6<FEJ961N;W-T(&]V;V<@8G)O:F$@;6]R82!N86IM86YJ92!I>FYO<VET
M:2`Q+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I
M<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D]V82!V<FEJ961N;W-T(&UO
M<F$@8FET:2!B<F]J+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B3W9A:B!P<F]Z;W(@<V4@
M<VUI:F4@<&]Z:79A=&D@<V%M;R!I>B!P<F]Z;W)A($]P8VEJ92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4
M:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`B5G)E;65N<VMA
M('IO;F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
M5G)E;65N<VMA('IO;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3,Y"B,L(&9U>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")6
M<F5M96YS:V$@>F]N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE
M<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*(RP@9G5Z
M>GD*;7-G:60@(E1I=&QE(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I
M9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G
M<W1R("):82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@
M:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K
M97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(E1O9&%Y
M(@IM<V=S='(@(E1I:F5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4;V=O
M(@IM<V=S='(@(EIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S
M"B,L(&9U>GIY"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(@*'-U=')A*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E1O;F=A(@IM<V=S='(@
M(EIA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<W"B,L(&9U>GIY"FUS9VED(")4;W`B"FUS9W-T<B`B6F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS
M9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(D%K8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI
M9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W
M"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME
M>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I
M9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R<VMI("A)4T\M
M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN
M9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I
M9"`B55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B
M55),.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED
M(")59V%N9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F
M=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5;F1E;&5T92(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B56YA8FQE('1O
M(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+B(*;7-G<W1R(").92!M;V=U('-E('-P;VII=&D@;F$@24U!4"!S97)V
M97(Z("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED
M(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M96UP='D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M
M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*
M;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U
M,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF
M:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS
M.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I
M9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@
M(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`HC+"!F=7IZ>0IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E5N9&5L971E(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S
M='(@(E!O;FFY=&D@:7IM:F5N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS
M9VED(")5;F9I;&5D(@IM<V=S='(@(DYE:V%T96=O<FES86YO(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R(")5;FEK;V0@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5
M;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")5:F5D:6YJ96YI($%R87!S
M:VD@16UI<F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D
M;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B
M56YI=&5D(%-T871E<R(*;7-G<W1R(")5:F5D:6YJ96YI($%R87!S:VD@16UI
M<F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM
M<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R
M9"XB"FUS9W-T<B`B3F5P;WIN871O(&MO<FES;FGH:V\@:6UE(&EL:2"Y:69R
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(E!O9&5S:2!V<F5M96YS:W4@>F]N=2XB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B
M56YN86UE9"(*;7-G<W1R(")"97II;65N:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI
M8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@HC+"!F=7IZ>0IM
M<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X
M=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PHC
M+"!F=7IZ>0IM<V=I9"`B57!D871E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D1A='5M(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM
M<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B1&%T=6TB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(D1A='5M(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y
M.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P
M"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3@*(RP@9G5Z>GD*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B1&5C96UB87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*
M;7-G<W1R(")+;W)I<W1I=&4@;W9O(&%K;R!S92!I;64ON6EF<F$@<F%Z;&EK
M=6IU('IA($E-4U`@<V5R=F5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B
M57-E<FYA;64B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B2V]R:7-N:6L@)7,@;F5M82!D
M;WIV;VQU('IA("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PHC+"!F=7IZ
M>0IM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!A9&UI
M;FES=')A8VEJ82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B2V]R:7-N:>AK92!O
M<&-I:F4B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B(*;7-G<W1R(")296=I<W1R86-I:F$@:V]R:7-N:6MA(@H*(SH@<VEG
M;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0V.0HC+"!F=7IZ>0IM<V=I9"`B57-E<B!A8V-O
M=6YT(&YO="!F;W5N9"(*;7-G<W1R("(E<R!N:6IE('!R;VYA\&5N+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DMO
M<FES;FGH:V\@:6UE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")&;VQD97(@7"(E<UPB
M('9EYB!P;W-T;VII(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B57-E<FYA
M;64B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(E5S97)N86UE(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@
M=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS
M9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"B,L(&9U>GIY"FUS
M9VED(")686-A=&EO;B(*;7-G<W1R(")!:V-I:F$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N
M9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B
M5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`B3&GH;F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(V"B,L(&9U>GIY"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T
M<B`B3&GH;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R(")3;&IE9&5C82!S=')A;F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P
M861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM
M<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*(RP@
M9G5Z>GD*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(DEM92!D871O=&5K92(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E
M("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S
M(@IM<V=S='(@(E!R:6MA>B`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@
M(E!R:6MA>B`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I
M<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@
M271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM
M<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)
M3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")7
M86QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T
M<B`B57!O>F]R96YJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E
M8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"B,L(&9U>GIY
M"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B
M(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E-E9&UI
MZ&YO(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@
M(E=E;&-O;64B"FUS9W-T<B`B1&]B<F\@9&^Y;&DB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M(")$;V)R;R!D;[EL:2!N82`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")$;V)R;R!D;[EL
M:2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B6F%P861N:2`H25-/+3@X-3DM
M,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(EIA<&%D;FD@*$E33RTX.#4Y+3$U
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M("):87!A9&YA(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2V]J=2!K;VUP
M;VYE;G1U(.9E("5S('!R:6MA>F%T:2!N86MO;B!U;&%Z83\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@
M9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E
M(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A
M;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*
M;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DMO:F4@9&]D
M871K92"^96QI=&4@86MT:79I<F%T:2!Z82!E9&ET;W(@9F]R;6%T:7)A;F]G
M("AR:6-H*2!T96MS=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@B
M"FUS9W-T<B`B5')AOFDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F
M96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@HBJ6ER:6YA("5S(&UE
M;FEJ82!S82!L:6IE=F4@<W1R86YI8V4@*'-T=7!A(&YA('-N86=U(&MO9"!S
M;&IE9&7F92!P<FEJ879E*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"B,L(&9U>GIY"FUS9VED(")7:61T:"!U;FET(@IM<V=S
M='(@(DQI='9A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*(RP@9G5Z>GD*;7-G:60@(E=I9'1H.B(*;7-G<W1R(")4
M<F&^:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@
M(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-0HC+"!F=7IZ>0IM<V=I9"`B5VEN9"(*;7-G<W1R(")4<F&^:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"B,L(&9U>GIY
M"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E1R8;YI(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@HC+"!F=7IZ
M>0IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"B,L(&9U>GIY"FUS9VED(")7:6YD.B`B
M"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*
M(RP@9G5Z>GD*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")4<F&^:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0HC+"!F=7IZ
M>0IM<V=I9"`B5V]R:R(*;7-G<W1R(")I;&DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E=O
M<FL@061D<F5S<R(*;7-G<W1R(")/9"!A9')E<V4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"B,L(&9U>GIY"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@*&MUYFDI(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L
M9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*
M;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R
M86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"FUS9VED
M(")965E9(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")';V1IN6YJ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(EEE;65N(@IM<V=S='(@(E9I9&IE;F$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S
M"FUS9VED(")997,B"FUS9W-T<B`B1&$B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A
M=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T
M:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@
M(DYE(&UOOF4@<V%D<KYA=F%T:2`G7%PG(&MA<F%K=&5R('4@='9O;2!P=6YO
M;2!I;65N=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*
M;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B3V1J
M879L:FEV86YJ92!J92!U<W!J9;EN;R!I>G9RN65N;RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I
M=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D
M:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A
M('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S
M8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O
M8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R
M('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A=&D@:61E;G1I=&5T(&MO:FD@OF5L
M:71E(&)R:7-A=&DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@
M;W5T+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A=&D@:61E;G1I=&5T(&MO:FD@
MOF5L:71E(&)R:7-A=&DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A=&D@:61E;G1I=&5T(&MO:FD@
MOF5L:71E(&)R:7-A=&DN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"B,L(&9U>GIY"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@
M(DUO<F%T92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T
M:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET92!B<FES
M871I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C$S.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A=&D@:61E
M;G1I=&5T(&MO:FD@OF5L:71E(&)R:7-A=&DN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T
M<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET92!B<FES
M871I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET
M86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B("5S('-E<VEJ82!J92!I<W1E:VQA+B!-;VQI;6\@9&$@<V4@<&]N
M;W9O('!R:6IA=FET92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E9A
MN6$@92UM86EL(&%D<F5S82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,3(*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B5F&Y82!&
M<F]M.B!A9')E<V$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN
M9F]R;6%T:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-I:F4B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"B)68;EA($EN=&5R;F5T(&%D<F5S82!J92!P<F]M:6IE;FIE;F$@;F%K
M;VX@<')I:F%V;&II=F%N:F$@;F$@)7,N($1A(&)I('9AN6$@(@HB<VEG=7)N
M;W-T(&)I;&$@<V'H=79A;F$L(&UO<F%T92!S92!P;VYO=F\@<')I:F%V:71I
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED
M(")9;W5R($YA;64B"FUS9W-T<B`B5F&Y92!I;64B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U
M<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T
M:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B)68;EA($EN=&5R;F5T(&%D<F5S82!J92!P<F]M:6IE;FIE;F$@
M;F%K;VX@<')I:F%V;&II=F%N:F$@;F$@)7,N($1A(&)I('9AN6$@(@HB<VEG
M=7)N;W-T(&)I;&$@<V'H=79A;F$L(&UO<F%T92!S92!P;VYO=F\@<')I:F%V
M:71I+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S
M='(@(E9AN2!B<F]W<V5R(&YE('!O9'*^879A(&]V=2!M;V=UYFYO<W0N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O
M('!R:6YT+B(*;7-G<W1R("(B"B)68;D@8G)O=W-E<B!N92!P;V1ROF%V82!O
M<&-I:G4@N71A;7!A;FIA+B!0<FET:7-N:71E('1I<&ME($-O;G1R;VPK4"!I
M;&D@(@HB3W!T:6]N*U`@>F$@N71A;7!A;FIE+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z
M(@IM<V=S='(@(E1R96YU=&YA('9R96UE;G-K82!Z;VYA.B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT
M(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(E9AN2!D969A
M=6QT(&ED96YT:71E=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X
M"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E9AN2!D
M969A=6QT(&ED96YT:71E=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`Q"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B5F&Y92!I;64@
M:2!P<F5Z:6UE.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S
M='(@(D]P8VEJ92!S=2!S8>AU=F%N92XB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E9AN6$@;F]V82"Y:69R
M82!Z82`E<R!J93H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")6
M8;EE(&]P8VEJ92!S=2!S8>AU=F%N92!T;VMO;2!T<F%J86YJ82!O=F4@<V5S
M:6IE+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS
M9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@
M(D]P8VEJ92!S=2!S8>AU=F%N92XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="(*;7-G<W1R(")68;EA(+EI9G)A(&IE('!O;FFY=&5N82(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB5F&Y
M82"Y:69R82!J92!P;VYIN71E;F$L('!R;W9J97)I=&4@=F&Y(&4M;6%I;"!I
M('!R:6IA=FET92!S92!S82!N;W9O;2`B"B*Y:69R;VTN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,R"B,L(&9U>GIY"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")68;EA(+EI9G)A(&IE('!O
M;FFY=&5N82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM
M<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B5F&Y:2!U9&%L
M:F5N:2!S97)V97)I.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L879I:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):
M86ER(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA
M;6)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R
M(")::6UB86)V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I
M9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6U-A:W)I:B!C:71I<F%N:2!T96MS
M=%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L
M96T@4F5P;W)T72(*;7-G<W1R(");4')I:F%V82!P<F]B;&5M85TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");4')I:V&^:2!C:71I<F%N
M:2!T96MS="`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");4')I:V&^
M:2!C:71I<F%N:2!T96MS="`M("5S(')E9&]V85TB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)E9"`E<R!O9"`E<UTB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!
M9&UI;FES=')A8VEJ82(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,
M22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?
M1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?
M1&5L971E(%)O=R(*;7-G<W1R(")?3V)R:;EI(')E9"(*"B,Z(&QI8B]A<&DN
M<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<&4B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L
M<"(*;7-G<W1R(")?4&]M;^8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(E]/<V]B:6YE('-L:6ME+BXN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I
M;B(*;7-G<W1R(")?4')I:F%V:2!S92(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E])
M>FQA>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@
M(E])>FUI:F5N:2!L:6YK+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]P8VEJ
M92(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM
M<V=S='(@(E]$;WIV;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`B7U5K;&]N:2!L:6YK+BXN(@H*(SH@;&EB+V%P:2YP:'`Z
M,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7U!O9&5S:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM
M<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B3W-O8FEN92!?
M=&%B96QE+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B7TMO<FES;FEC:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(Q"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B:6UE;FEK
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*(RP@
M9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(FEM96YI
M:R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY
M"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")+86QE;F1A<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L
M('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN
M<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M
M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C
M;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(E9R871I('-T87)U(&MO;F9I
M9W5R86-I:G4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R
M-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G
M:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(E<R!N:6IE('!R;VYA\&5N
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q
M"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G
M<W1R(").96MA=&5G;W)I<V%N;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B5S('4@)7,@)7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED(")G
M=7-T:6YG(@IM<V=S='(@(D%U9W5S="(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*
M;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H
M<#HW.0HC+"!F=7IZ>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(FYO;F4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B
M:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B;&EN97-=(@IM
M<V=S='(@(FYO;F4B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ
M>0IM<V=I9"`B;F%M92(*;7-G<W1R("));64B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00RYP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")N;W0@:6UP;&5M96YT960B
M"FUS9W-T<B`B3F4@:7IB<FES86YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C$Y"B,L(&9U>GIY"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(DYE(&EZ8G)I<V%N82(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"B,L(&9U>GIY"FUS9VED(")N;W1E<&%D
M(@IM<V=S='(@(DYE('!R;^AI=&%N92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*(RP@9G5Z>GD*;7-G:60@
M(G!E<F-E;G0B"FUS9W-T<B`B4')O8V5N870B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B1&]Z=F]L92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I
M>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B57!O>F]R
M96YJ92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R
M"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B
M<W1E861Y(@IM<V=S='(@(DYE('!R;^AI=&%N92(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I
M<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(FQI<W1A('IA9&%T86MA(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U
M"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`B2V]D('-V86ME
M('!R:6IA=F4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY
M"FUS9VED(")U;FEF:65D(@IM<V=S='(@(DYE:V%T96=O<FES86YO(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R(")B97H@:6UE;F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@
M(G5S97(@<V5L96-T(@IM<V=S='(@(DEZ8F]R(&)O:F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D
M(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,0HC+"!F=7IZ>0IM<V=I9"`B=SHB"FUS9W-T<B`B
M1G=D.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:61?240N<&\`````
M````````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8W
M,#$S,P`Q,#4Q-30S,3`V,P`P,38S-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R!(;W)D92`M($EN9&]N97-I86X@3&%N
M9W5A9V4@5')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@
M4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($IA;65S(#QJ
M86UE<T!A8W1I;VYM97-S86=E+F-O;3XL(#(P,#4N"B,*(RP@9G5Z>GD*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(#(P,#4M,#@M
M,#-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3`X+3`T(#`Y.C$P*S`R
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F%M97,@/&IA;65S0&%C=&EO;FUE
M<W-A9V4N8V]M/EQN(@HB3&%N9W5A9V4M5&5A;3H@:60@/&ED0&QI+F]R9SY<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]55,M05-#24E<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#=B:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PHC+"!F=7IZ>0IM<V=I9"`B("AT;V1A
M>2DB"FUS9W-T<B`B2&%R:2!);FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<U"B,L(&9U>GIY"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R
M(")"97-O:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G
M:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I
M9"`B(&%T("(*;7-G<W1R("(@<&%D82`B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&)E;'5M
M(&1I8G5A=#H@)7,N(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$P-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@<W5D86@@9&ET86UB86AK86X@:V4@9&%L86T@
M<VES=&5M(&=R=7`N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE
M('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB('-U9&%H(&1I
M=&%M8F%H:V%N(&ME(&1A;&%M(&EZ:6X@<VES=&5M+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*
M;7-G<W1R(")<(B5S7"(@8F5L=6T@9&EB=6%T.B`E<RXB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR
M9DU"('-U9&%H(&1I9W5N86MA;B!D87)I("4N,F9-0B!Y86YG('-U9&%H(&1I
M:6II;FMA;B`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM
M<V=S='(@(B5D("5S(&1A;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N(@IM<V=S='(@(B5D(&AA<FD@<V%M<&%I('-A;F1I(&%N9&$@:&%B
M:7,@;6%S82!B97)L86MU;GEA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C
M87-T(@IM<V=S='(@(B5D+6AA<FD@<F%M86QA;B!C=6%C82(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(%!E;6)E<FET86AU86XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(DMO;F9I<FUA<VD@+2!/
M<&5R87-I(%!E;65L:6AA<F%A;B`E<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R!3971U<"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R
M;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(%-Y87)A="US>6%R870@4&5R
M:F%N:FEA;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!P
M861A("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE
M8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T
M;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@<VEA<"!U
M;G1U:R!M96QA:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@>6%N9R!S
M=61A:"!D:71A;F1A:2!D:2!B87=A:"`B"B)I;FDN($)E<FEL86@@=&%N9&$@
M<&%D82!K;W1A:R!T97)S96)U="!U;G1U:R!O<&5R87-I(&UA;F%P=6X@>6%N
M9R!A;F1A("(*(FEN9VEN:V%N('5N='5K(&1I;&%K<V%N86MA;B!P861A('=A
M:W1U(&EN:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;65N:70B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(E1I9&%K
M(&%D82!I:V]N('EA;F<@9&ET96UU:V%N+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B)7,@=6YT=6L@)7,@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B0G5K=2!!;&%M870@
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L
M96YD97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@
M(B5S("T@4&5M8F5R:71A:'5A;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I
M;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S
M;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#$P"B,L(&9U>GIY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@
M86YG:6X@:V5N8V%N9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&%N9VEN(&ME;F-A;F<@)7,@)7,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V87)I
M86)L92!D87)I("5S(&ME("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R
M;6%T(@IM<V=S='(@(D9O<FUA="`Q,B!*86TB"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA
M="`R-"!*86TB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I
M9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:F%M(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM
M<V=S='(@(DQI:&%T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G
M:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RXB"FUS9W-T<B`B1&%T86)A<V4@8F%C:V5N9"!D:7!E<FQU:V%N('5N
M='5K(&%R96$@:6YI+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R(")!32!-96YD=6YG(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B04T@1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(D%-
M($AU:F%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B04T@1V5R:6UI<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS
M9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B04T@1V5R:6UI<R!386QJ
M=2(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]0
M32(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(E1E;G1A;F<@
M961I=&]R(&EN:2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS
M9VED(")!8F]U="XN+B(*;7-G<W1R(")496YT86YG+BXN("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B
M<V)O='1O;2(*;7-G<W1R(")*87)A:R!A;G1A<F$@8F%G:6%N(&)A=V%H(&)A
M<FES(&1E;F=A;B!B86=I86X@8F%W86@@9V%M8F%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED
M9&QE(@IM<V=S='(@(DIA<F%K(&%N=&%R82!B86=I86X@=&5N9V%H(&)A<FES
M(&1E;F=A;B!B86=I86X@=&5N9V%H(&=A;6)A<B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B26YF;W)M87-I($%C8V]U;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B4V%N9&D@
M06-C;W5N="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!F<F]Z96XN
M(@IM<V=S='(@(DEN9F]R;6%S:2!!8V-O=6YT(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")!
M:W5N=&%N<VDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R
M(")486UB86@B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U
M<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(E1A
M;6)A:"!'<G5P($%N86LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(E5B86@@
M27II;B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!
M9&0@2&5R93HB"FUS9W-T<B`B5&%M8F%H($1I<VEN:3HB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D
M($YE=R!'<F]U<"(*;7-G<W1R(")486UB86@@1W)U<"!"87)U(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@X"B,L(&9U>GIY"FUS9VED(")!9&0@3F5W(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B56)A:"!)>FEN(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(E1A
M;6)A:"!G<G5P(&%N86L@:V4@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")486UB
M86@@9W)U<"!A;F%K(&ME("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM
M<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(E1A;6)A:"!P96YG9W5N
M82!B87)U.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-30*(RP@9G5Z>GD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M4&ES86AK86X@:V]L;VTB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B5&%M
M8F%H(&%N9V=O=&$@8F%R=2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E1A;6)A:"!P87-A;F=A
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M(@IM<V=S='(@(E1A;6)A:"!-96YU("5S('-E8F%G86D@4&%N96P@;F%V:6=A
M<VD@36]Z:6QL82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O
M:SHB"FUS9W-T<B`B0G5K=2!!;&%M870@(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@
M=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")4
M86UB86@@<&5N9V=U;F$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S
M>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN
M9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB("<E<R<@<W5D86@@9&ET
M86UB86AK86X@:V4@9&%L86T@<VES=&5M+"!T971A<&D@=&ED86L@9&%P870@
M;65N86UB86AK86X@(@HB:6YF;W)M87-I('!E;F1A9G1A<F%N('1A;6)A:&%N
M.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+B(*;7-G<W1R("(@)R5S)R`@<W5D86@@9&ET86UB86AK86X@
M:V4@9&%L86T@<VES=&5M+B!!;F1A(&1A<&%T(&QO9R!I;B!S96MA<F%N9RXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")096YA;6)A:&%N
M('!E;F=G=6YA('1I9&%K(&1I86MT:69K86XN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#$*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B
M0G5K=2!!;&%M870@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S
M.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"B,L
M(&9U>GIY"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")58F%H(&EZ:6X@=6YT=6L@)7,B"@HC
M.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI
M<W1R87-I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I
M9"`B061S(@IM<V=S='(@(DEK;&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G
M:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(D%L:6%S(@IM<V=S='(@(E)A=&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")2871A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM
M96YT.B(*;7-G<W1R(")097)A=&%A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E-E;75A(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS
M9W-T<B`B4V5M=6$@4&5N9V=U;F$@07-L:2(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B
M"FUS9W-T<B`B4V5M=6$@1W)U<"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H
M<#HW-0HC+"!F=7IZ>0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(DEZ:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")3
M96UU82!E;7!A="!S:7-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(DEZ:6YK
M86X@<&5N9V%T=7)A;B!D87)I('1I<&4@9&%F=&%R(&YO;6]R(&)E<G5R=70_
M(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T
M"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I
M;B(*;7-G<W1R(")096YG9V%N=&D@3&]G:6X@24U34"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(E!E;F=G86YT:2!386YD:2!)35-0(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E
M<FYA;64B"FUS9W-T<B`B4&5N9V=A;G1I($YA;6$@4&5N9V=U;F$@24U34"(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")096YG9V%N=&D@86QA;6%T
M(&5M86EL(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L
M=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B4&5N9V=A;G1I('1E;7!L871E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B
M4&5N9V=A;G1I('1E:W,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@
M4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I
M9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!
M;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E
M<B(*;7-G<W1R(")*87=A8F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C
M=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N
M9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L:6MA<VDB"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N
M($QI<W0B"FUS9W-T<B`B1&%F=&%R($%P;&EK87-I(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN
M(@IM<V=S='(@(D%P;&EK87-I('-U9&%H('-I87`N(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H
M87)E<R(*;7-G<W1R(")$:6=U;F%K86X@=6YT=6L@0F%G:6%N($%N86LB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B
M07!P<F]V92(*;7-G<W1R(")$:7-E='5J=6DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W
M<RTQ,C4V*2(*;7-G<W1R(")!<F%B("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P
M"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"B)!<&%K86@@86YD
M82!Y86MI;B!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N('!E<FUO:&]N86X@<&5N
M9&%F=&%R86X@=6YT=6L@)7,_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@
M<W5B+6=R;W5P<S\B"FUS9W-T<B`B07!A:V%H(&%N9&$@>6%K:6X@86YD82!I
M;F=I;B!M96YG:&%P=7,@)R5S)R!D86X@<W5B+6=R=7`@;6%N87!U;C\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS
M9W-T<B`B07)M96YI82`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(E-E;FDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C
M:6D@07)T(@IM<V=S='(@(DMO9&4@07-C:6DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I
M9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(DUE;6EN=&$@:V]N9FER;6%S:2!S
M96)E;'5M(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;C\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"B,L(&9U>GIY"FUS9VED
M(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B4&ES86AK86X@:V]L;VTB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B365N8V]B82!U
M;G1U:R!M96YG:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82XB"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")-96YC;V)A
M('5N='5K(&UE;F=H87!U<R!I>FEN('EA;F<@=&ED86L@861A+B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B365N8V]B82!U
M;G1U:R!M96YG=6)A:"!I>FEN('EA;F<@=&ED86L@861A+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")-96YC;V)A('5N='5K
M(&UE;F=U8F%H(&)A9VEA;B!Y86YG('1I9&%K(&%D82XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%G=7-T=7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B075S=')I82(*;7-G<W1R(")!9W5S='5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U
M"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM
M<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U
M-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E
M<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P
M9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A
M;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")396UU82!096YG9W5N82!!<VQI(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G
M:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(DMO;&]M('EA;F<@=&5R
M<V5D:6$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@
M17AC=7-E<R(*;7-G<W1R(")!;&%S86X@0D]&2"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A
M8VMG<F]U;F0B"FUS9W-T<B`B3&%T87(@0F5L86MA;F<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(E=A<FYA($QA=&%R($)E;&%K86YG(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E
M<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H<F%I
M;B(*;7-G<W1R(")-87)G:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S
M='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B1&%S87(@9&ER96MT;W)I(&=R869I
M:R`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE
M(@IM<V=S='(@(DIA<F%K(&%N=&%R82!B86=I86X@8F%W86@@9V%M8F%R(&1E
M;F=A;B!G87)I<R!D87-A<B!B87)I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B2F%R86L@86YT87)A(&)A9VEA;B!B87=A:"!G86UB87(@9&5N
M9V%N(&=A<FES(&1A<V%R(&)A<FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM
M<V=I9"`B0F5N:6XB"FUS9W-T<B`B2F%R86L@86YT87)A(&)A9VEA;B!B87=A
M:"!G86UB87(@9&5N9V%N(&=A<FES(&1A<V%R(&)A<FES(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC
M871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG
M<R(*;7-G<W1R(")096YG871U<F%N($%R96$B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B
M5&EP92!!<F5A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(DAU<G5F(%1E8F%L(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS
M9W-T<B`B4&5T=6YJ=6L@:&%L86UA;B!W96(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B0F]R9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB
M"FUS9W-T<B`B2V5T96)A;&%N($)O<F1E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E
M<G,B"FUS9W-T<B`B0F]R9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B2V5D=6%N>6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G
M:60@(D)O='1O;2(*;7-G<W1R(")"87=A:"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ
M>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y
M"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(D1A9G1A<B!"=6QL970B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B
M0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B4')O<&5R=&D@4U]E;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#
M86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B5&5N86YG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T
M('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)4:61A:R!D87!A="!M96YG871U<B!U;&%N
M9R!S86YD:2!S96-A<F$@;W1O;6%T:7,L('-I;&%K86X@:'5B=6YG:2`B"B)A
M9&UI;FES=')A=&]R(&%N9&$N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@
M=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I
M;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!T
M97)H=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E
M;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B0F%T86PB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R
M;V)L96T@4F5P;W)T(@IM<V=S='(@(D)A=&%L:V%N($QA<&]R86X@36%S86QA
M:"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")*=61U;"!486)E;"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM
M<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M(")+871E9V]R:2!D86X@3&%B96PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y
M;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0
M:&]N92(*;7-G<W1R(")0<F]P97)T:2!396PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL
M(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&5R=&D@4V5L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E
M;&P@<&%D9&EN9SHB"FUS9W-T<B`B2F%R86L@<W!A<VD@9&%R:2!B;W)D97(@
M9&5N9V%N('1E:W,@9&D@9&%L86T@<V5L.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@
M<')O<&5R=&EE<R(*;7-G<W1R(")P<F]P97)T:2!S96PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L
M;"!S<&%C:6YG.B(*;7-G<W1R(")*87)A:R!S<&%S:2!A;G1A<B!S96PN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H
M;VYE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS
M9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#96QT:6,@*$E3
M3RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")496YG
M86@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G
M:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5R
M;W!A(%1E;F=A:"`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@
M(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")+87)A:W1E<B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")58F%H
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#
M:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")58F%H(%-A;F1I($%N9&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R
M("(B"B)58F%H(&YA;6$@9&%N(&%L86UA="!S96AI;F=G82!O<F%N9R!D87!A
M="!M96QI:&%T;GEA(&ME=&EK82!M97)E:V$@;65M8F%C82`B"B)D86X@;65M
M8F%L87,@:V4@96UA:6P@86YD82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HB365N9W5B86@@<V%N9&D@86YD82!T:61A:R!D:61U:W5N9R!D96YG86X@
M:V]N9FEG=7)A<VD@>6%N9R!S96MA<F%N9RX@4VEL86MA;B`B"B)H=6)U;F=I
M(&%D;6EN:7-T<F%T;W(@86YD82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S
M='(@(DMA<F%K=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*
M;7-G<W1R(")097)I:W-A($QI;FLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY
M"FUS9VED(")#:&EL92(*;7-G<W1R(")*=61U;"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@
M9G5Z>GD*;7-G:60@(D-H:6YA(@IM<V=S='(@(DMA<F%K=&5R(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R(")#:6YA(%-E9&5R:&%N82`H1T(R,S$R*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")#:6YA(%1R861I<VEO;FEL("A"
M:6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*
M(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E-A
M;F1I($)A<G4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E!I;&EH(&-A<F$@=6YT=6L@;65N
M86UP:6QK86X@=&%N9V=A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B4&EL
M:6@@9&%F=&%R('1I<&4@9V%Y82`H=6YT=6L@9&%F=&%R(&YO;6]R(&)E<G5R
M=70I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T
M<B`B1&ER96MT;W)I($UO=&EF("<E<R<@=&ED86L@9&ET96UU:V%N+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED
M(")#;&5A<B(*;7-G<W1R(")"97)S:6AK86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F
M9FEC92!T86=S(@IM<V=S='(@(D)E<G-I:&MA;B!T86<@35-/9F9I8V4B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A
M<B!1=65R>2(*;7-G<W1R(")"97)S:6AK86X@<&5N9V=U;F$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B0F5R<VEH:V%N('!E
M;F=G=6YA.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")"97)S:6AK86X@<&5N
M9V=U;F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM
M<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D)E<G-I:&MA;B!D871A
M('!E;F=G=6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B0V5R86@@
M8F5B97)A<&$@<V%A="!L86=I(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E
M(@IM<V=S='(@(DML:6L@=6YT=6L@3&%N:G5T(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC
M:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I
M9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E1U='5P($IE;F1E;&$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@
M(DUE;F1U;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DUE;F1U;F<@
M9&D@<&%G:2!H87)I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")"97)A=V%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")097)B97-A<B!086YE
M;"!.879I9V%S:2`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*
M;7-G<W1R(")097)B97-A<B!B;W)D97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY
M"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")787)N82(*"B,Z(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R(")787)N82(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")0
M96UI;&EH(%=A<FYA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T
M-@HC+"!F=7IZ>0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")(
M87!U<R!P:6QI:&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(DMO;&]M(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN
M('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B0V]M:6-S(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O
M;6UA;F0B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA
M;F0@4VAE;&PB"FUS9W-T<B`B0V]M;6%N9"!3:&5L;"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M
M;65N="(*;7-G<W1R(")#;VUM86YD(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C8*(RP@9G5Z>GD*;7-G:60@(D-O;6UO;B!.86UE
M(@IM<V=S='(@(DYA;6$@06YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L(&9U>GIY"FUS
M9VED(")#;VUO<F]S(@IM<V=S='(@(D)E<V]K(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]M<&%N>2(*;7-G<W1R(")386QI;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(DMO;7!U=&5R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N
M9&ET:6]N(@IM<V=S='(@(DMO;F1I<VDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")+;VYD:7-I(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B4&5R8F5D86%N($MO;F9I9W5R87-I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N
M9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*
M;7-G<W1R(")+;VYF:6=U<F%S:2!S=61A:"!H86)I<R!M87-A(&)E<FQA:W5N
M>6$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B365N9V%T=7(@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED
M(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(DMO;F9I<FUA<VD@4V%N9&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")#;VYG;R(*;7-G<W1R(")7
M87)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T
M-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@
M(D-O;G1A8W1S(@IM<V=S='(@(DMO;G1A:R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@
M(DQA;FIU="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O
M;VMI92(*;7-G<W1R(")#;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS
M9W-T<B`B4V%L:6XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S
M(@IM<V=S='(@(DMO;&]M('EA;F<@9&EI;7!O<CH@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y
M('-E;&5C=&EO;B(*;7-G<W1R(")386QI;B!0:6QI:&%N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM
M<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED
M(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO
M;F9I9W5R87-I("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(E1I9&%K(&1A<&%T('1E<FEK870@9&5N9V%N('-E<G9E<B!L9&%P
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B5&ED86L@9&%P870@
M=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87`B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<R(*;7-G<W1R(")4:61A:R!D87!A="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD
M87`B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")4:61A:R!D
M87!A="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E
M<R(*;7-G<W1R(")4:61A:R!D87!A="!T97)H=6)U;F<@:V4@<V5R=F5R("<E
M<R<@9&5N9V%N(&UE;F=G=6YA:V%N($944#HE<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!M96YU;&ES(&MO;F9I
M9W5R87-I('5N='5K("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B5&ED
M86L@9&%P870@:V5M8F%L:2!K92!K;VYF:6=U<F%S:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@;65N9VAA<'5S
M('-C<FEP="!S971U<"!U<&=R861E("<E<R<N("(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B5&ED86L@9&%P870@;65N9VAA<'5S('-C<FEP="!S971U<"!U
M<&=R861E("<E<R<N("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B5&ED86L@9&%P870@=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87`B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM
M<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N("5S+B(*;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG
M=7)A<VD@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5&ED86L@9&%P870@=&5R
M:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<#HR,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(")<(B5S7"(@8F5L=6T@9&EB=6%T
M.B`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I
M9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A
M<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(E1I9&%K(&1A<&%T(&UE;F=A='5R('5L86YG('5N='5K('!E;F=G
M=6YA('EA;F<@9&EM:6YT82X@0F5B97)A<&$@871A=2!S96UU82`B"B)D971I
M;"!T:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@<VEL86MA;B!H=6)U;F=I
M(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA("(*(F%N9&$@;65M97)L=6MA;B!B
M86YT=6%N(&QE8FEH(&QA;FIU="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&ME;6)A
M;&D@:V4@:V]N9FEG=7)A<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&ME;6)A;&D@:V4@:V]N9FEG=7)A
M<VDN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I
M97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM
M<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")4:61A:R!D87!A="!K96UB86QI(&ME(&MO;F9I9W5R87-I+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")4:61A:R!D87!A="!M
M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2!B
M86-K=7`N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A
M;B!K;VYF:6=U<F%S:2!B86-K=7`Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!S8W)I<'0@<V5T=7`@=7!G
M<F%D92!K93HG)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T
M(&UE;GEI;7!A;B!F:6QE(&MO;F9I9W5R87-I(&)A8VMU<"`E<RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(E1I9&%K(&1A<&%T(&UE
M;GEI;7!A;B!F:6QE(&MO;F9I9W5R87-I("5S+B!!;F1A(&1A<&%T(&UE;F=G
M=6YA:V%N('-A;&%H('-A='4@(@HB9&%R:2!P:6QI:&%N('5N='5K(&UE;GEI
M;7!A;B!K;V1E('1E<G-E8G5T(&ME;6)A;&D@:V4@)7,@871A=7!U;B!M96YY
M86QI;B`B"B)K;V1E(&1I(&)A=V%H(&EN:2!S96-A<F$@;6%N=6%L(&ME("5S
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG
M=7)A<VD@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(E1I9&%K(&1A<&%T(&UE;G5L:7,@:V]N9FEG=7)A<VD@=6YT=6L@)R5S)SH@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N
M(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;G5L:7,@
M:V]N9FEG=7)A<VD@=6YT=6L@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G
M<W1R("(B"B)4:61A:R!D87!A="!M96YE;75K86X@4&%N96P@3F%V:6=A<VD@
M36]Z:6QL82X@4&%S=&EK86X@<&%N96P@;F%V:6=A<VD@<W5D86@@(@HB=&5R
M8G5K82XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U
M<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")+;VUP=71E<B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T
M<B`B2W5R<W5S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B
M0G5A="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")"
M=6%T(&QI;FLB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D)U870@
M8F%R=2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*(RP@9G5Z>GD*;7-G
M:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B27II;B!T86UU(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`HC+"!F=7IZ>0IM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(D%N9VMA($1E<VEM86PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B0W)O871I82(*;7-G<W1R
M(")"=6%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E
M;G0@-"!0:&%S97,B"FUS9W-T<B`B1F%S92!396MA<F%N9R(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S
M:6]N<R(*;7-G<W1R("))>FEN('1A;74B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM
M92(*;7-G<W1R(")786MT=2!396MA<F%N9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R
M<F5N="!54DP@:7,B"FUS9W-T<B`B55),(%-E:V%R86YG(&%D86QA:"(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="!5<V5R<R(*;7-G<W1R(")&87-E(%-E:V%R86YG(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@
M(D-U86-A(%-E:V%R86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")+
M;VYD:7-I(%-E:V%R86YG.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T
M<B`B1V%Y82!396MA<F%N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")+;W-T=6UI<V%S:2!T=6=A
M<R!U;G1U:R!D:6IA;&%N:V%N('-E8F5L=6T@;&]G;VX@:V4@)7,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(P"FUS9VED(")#=70B"FUS9W-T<B`B2&%P=7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L
M96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-Y<FEL
M;&EC("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G
M:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")#
M>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B1&%I;'DB
M"FUS9W-T<B`B2&%R:2(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I
M9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!"<F]W<V5R
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T
M86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Y.0HC+"!F=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R(")386QI;B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(E1A;F=G86P@1&ET97)I;6$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"B,L(&9U>GIY"FUS9VED
M(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S(R"FUS9VED(")$87DB"FUS9W-T<B`B2&%R:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B2&%P=7,@
M2V]L;VTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5S96UB97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B06YG:V$@1&5S
M:6UA;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")-96YG=7)A
M;F=I($EN9&5N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B
M1&5F875L="(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D1E9F%U
M;'0@5V%R;F$B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.CDQ"B,L(&9U>GIY"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@
M(D1E9F%U;'0@:61E;G1I=&%S(&%N9&$Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(D1E9F%U
M;'0@4VAE;&PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:7-I(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM
M<V=S='(@(DAA<'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G
M<W1R(")(87!U<R!396PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI
M;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@
M(DAA<'5S($=R=7`B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B2&%P=7,@
M8F%R:7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("))>FEN('1A;74B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS
M9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")(87!U<R!S96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS
M9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(DAA<'5S(&MO;&]M(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B2&%P=7,@<&5N9V=A;G1I
M('1E;7!L871E('EA;F<@<W5D86@@861A(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5B86@@
M:7II;B!U;G1U:R`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(DAA<'5S(&)A
M<FES(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ
M-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(DAA
M<'5S(&ED96YT:71A<R!Y86YG('1E<G!I;&EH(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$
M96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(DAA<'5S(&MO;&]M
M('EA;F<@<V5K87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!R;W<B"FUS9W-T<B`B2&%P=7,@8F%R:7,@>6%N9R!S96MA<F%N9R(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB
M)7-<(BXB"FUS9W-T<B`B2&%P=7,@<V-R:7!T('-E='5P('5P9W)A9&4@)R5S
M)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T
M:6UE(@IM<V=S='(@(DAA<'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0HC+"!F=7IZ>0IM<V=I
M9"`B1&5N;6%R:R(*;7-G<W1R(")$:71A;F1A:2(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R(")*96QA<VMA;B!-87-A;&%H(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(D1E<VMR:7!S:2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY
M"B,L(&9U>GIY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")!<F5A($UE=&%R('1I9&%K
M(&1I<V5D:6%K86XN($1E=&EL('1E;&%H(&1I8V%T870@=6YT=6L@861M:6YI
M<W1R871O<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS
M9VED(")$979E;&]P;65N="(*;7-G<W1R(")097)K96UB86YG86XB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S
M='(@(E1I=&EK($5M8G5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&ET
M:6L@16UB=6X@=6YT=6L@:F%M('1E<F%K:&ER.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(E1I=&EK($5M8G5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0B"FUS9W-T<B`B07)A:"!K:7)I(&ME(&MA;F%N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B07)A:"!K86YA;B!K92!K:7)I
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R
M>2(*;7-G<W1R(")$:7)E:W1O<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@
M(E1A;7!I;&MA;B!W86MT=2`R-"!J86T_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5&%M
M<&EL:V%N(%!I;&EH86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z.38*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T
M<B`B5&%M<&EL:V%N(&1E=&EL(')A;6%L86X@8W5A8V$B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I
M(@IM<V=S='(@(E1A;7!I;&MA;B!R86UA;&%N(&-U86-A("A4048I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B
M1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5&%M<&EL:V%N(')A;6%L86X@8W5A
M8V$@*%1!1BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP
M"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B2&%P=7,B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DIA;F=A;B!L86YG<W5N9R!M
M96YG86MS97,@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*
M;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@HB07!A
M:V%H(&)A<FES('EA;F<@<&5R=&%M82!T97)D:7)I(&1A<FD@:V]L;VT@;F%M
M83\@:FEK82!Y82P@8F5R:2!T86YD82!P861A("(*(FMO=&%K(&EN:3HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V
M92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R(")4:61A:R!M96UI;&EK
M:2!A8V-O=6YT/R!3:6QA:V%N(&UE;F1A9G1A<BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*
M;7-G<W1R(")$;W=N;&]A9"!K;VYF:6=U<F%S:2!Y86YG(&1I:&%S:6QK86X@
M<V5B86=A:2!S8W)I<'0@4$A0+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T
M<B`B3V)A="UO8F%T86XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")3=7)A
M="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B56)A:"(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN
M8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")58F%H($)L;VMI<B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V
M"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(E5B86@@1W)U<"(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;B(*;7-G<W1R(")58F%H($EZ:6XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(E5B86@@27II;B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B56)A:"!)>FEN('5N='5K("5S(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T
M<B`B56)A:"!P:6QI:&%N('5N='5K.B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B56)A:"!I>FEN
M('5N='5K("5S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R(")58F%H(&EZ:6X@=6YT=6L@)7,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")096YD:61I
M:V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B
M87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I
M9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96XN+BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB
M"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*(RP@
M9G5Z>GD*;7-G:60@(D5M86EL(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%L
M86UA="!%;6%I;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*
M(RP@9G5Z>GD*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R(")386YD:2!H87)U<R!C;V-O:RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")+;VYF:6=U<F%S:2`E<R!S=61A:"!D:7-I
M;7!A;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y
M.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(DMO;F1I<VDB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G
M:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*
M;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(D%K=&EF:V%N('!E;GEI<VEP
M86X@9V%M8F%R+6=A;6)A<B!D87)I($=A;&5R:2!&;W1O(&1I(&1A;&%M('1E
M:W,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B06MT:69K
M86X@:VQI:R!K86YA;B!M96YU(&MO;G1E:W,_(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q
M"B,L(&9U>GIY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")097)B97-A<B!0
M86YE;"!.879I9V%S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(E!E<F)E<V%R($5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B
M"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.B(*;7-G<W1R("(B"B)-87-U:VMA;B!P97)T86YY86%N(&ME86UA;F%N
M(&1I;6%N82!A;F1A(&%K86X@9&ET86YY86MA;B!A<&%B:6QA(&%N9&$@<&5R
M;'4@(@HB=6YT=6L@;65N9V%T=7(@=6QA;F<@<V%N9&D@86YD82P@(&-O;G1O
M:"`G87!A:V%H(&YA;6$@8FEN871A;F<@:V5S87EA;F=A;B`B"B)A;F1A/R<Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B
M"FUS9W-T<B`B36%S=6MK86X@55),(&=A;6)A<B!D:7-I;FDB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%
M;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O
M<B(*;7-G<W1R(")+97-A;&%H86XB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O
M5&5M<&QA=&4N<&AP.C0V,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(DME<V%L86AA;B!S
M86%T(&UE;7!E<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")+97-A
M;&%H86X@<V%A="!M96UP97)B86AA<G5I('-A;F1I.B`E<R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B
M2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R(")+97-A;&%H86X@<V%A="!M96UP97)B86AA<G5I('-A;F1I.B`E
M<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS
M9W-T<B`B2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`HC+"!F=7IZ>0IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")3=6MU(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B
M4W5K=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B4V5T:6%P
M(#$U(&UE;FET(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I
M9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(E-E=&EA<"`R(&UE;FET(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(E-E
M=&EA<"`S,"!D971I:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(E-E=&EA<"`U(&UE;FET(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B
M179E<GD@3&]G:6XB"FUS9W-T<B`B4V5T:6%P(&UE;FET(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM
M<V=S='(@(E-E=&EA<"!S971E;F=A:"!J86TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@
M(D5V97)Y(&UI;G5T92(*;7-G<W1R(")3971I87`@;65N:70B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU
M97,Z(@IM<V=S='(@(D-O;G1O:"!N:6QA:2UN:6QA:3HB"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B2F%L86YK
M86XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*
M(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")097)B97-A<B!086YE
M;"!.879I9V%S:2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(E!E<F)E<V%R(%!A
M;F5L($YA=FEG87-I(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$V.`HC+"!F=7IZ>0IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@
M(DIA;&%N:V%N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I
M9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B
M"FUS9W-T<B`B5V%R;F$@1D<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D944"!U
M<&QO860@=6YT=6L@<V5T=7`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@;&1A
M<"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ
M>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS
M9W-T<B`B5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I
M9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")4
M:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&
M86ER(@IM<V=S='(@(D-E<F%H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.#<*(RP@9G5Z>GD*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")&87AE<R(*;7-G<W1R
M(")&87@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<FDB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R(")397!E<G1I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E-E<&5R=&DZ(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G
M:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D=E<FEM:7,@4V5B86=I86XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")'97)I;6ES(%-A;&IU(%-E
M8F%G:6%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I
M9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I
M9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(D9I;'1E<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D9I
M;&4@36%N86=E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L
M(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B3F%M82!,96YG:V%P
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0HC+"!F=7IZ>0IM
M<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@
M=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U.0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S
M=7!P;W)T960N(@IM<V=S='(@(D944"!U<&QO860@=6YT=6L@<V5T=7`B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B1FEL=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B
M1FEN;&%N9"(*;7-G<W1R(")M87-I:"!D:2!D86QA;2!A;G1R:6%N(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R(")&87-E('!E<G1A;6$@9&%R:2!397!A<G5H($)U;&%N(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I
M9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")&87-E('!E<G1A;6$@9&%R:2!3
M97!A<G5H($)U;&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G
M:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T
M<B`B1FQO870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(D)E<FMA8G5T(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R(")787)N82!4=6QI<V%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(DUA:V%N86XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S(@IM<V=S='(@(E5N='5K(&)R;W=S97(@>6%N9R!T:61A:R!D87!A="!M
M96YD=6MU;F<@9V%M8F%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*
M;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(E)A;6%L86X@8W5A8V$@
M*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G
M:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB
M"FUS9W-T<B`B(@HB2&%R:2!286UA;&%N($-U86-A("AC871A=&%N(&)A:'=A
M(')A;6%L86X@8W5A8V$@>6%N9R!D:6ME;6)A;&EK86X@86MA;B`B"B)M96YG
M96UB86QI:V%N(&)A:6L@<VEA;F<@871A=2!M86QA;2!H87)I+"!S96IU;6QA
M:"!A;F=K82!D87!A="!D:6AA<VEL:V%N("(*(G!A9&$@87)E82!I;FDI(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O
M="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("),=7!A(&1E;F=A;B!S86YD:2!A
M;F1A/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(D9O<FUU;&ER(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(E)A;6%L86XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP
M92(*;7-G<W1R(")4:7!E(%)A;6%L86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(E)A;6%L86XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B
M"FUS9W-T<B`B4F%M86QA;B`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS
M9W-T<B`B1&ET97)U<VMA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(DIM="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")&<F%M92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%M92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-
M971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E
M;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,L(&9U
M>GIY"FUS9VED(")&<F]M(@IM<V=S='(@(DIM="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS
M9VED(")&<F]M('1H92`B"FUS9W-T<B`B1&%R:2(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N
M(@IM<V=S='(@(D1E<VMR:7!S:2!,96YG:V%P(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@
M36]O;B(*;7-G<W1R(")"=6QA;B!0=7)N86UA(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").86UA($QE;F=K87`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*
M;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A
M;&5R:2!U;G1U:R!M96YG86UB:6P@9V%M8F%R(&1A<FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*
M;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B365N9VAA<VEL:V%N("5S($MO;F9I9W5R
M87-I("(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")+;V1E('EA;F<@9&EH
M87-I;&MA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O
M(@IM<V=S='(@(DIA;&%N:V%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*
M;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(E!E;F-A<FEA;B!';V]G;&4B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@
M4V5A<F-H(@IM<V=S='(@(E!E;F-A<FEA;B!';V]G;&4B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y
M<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B
M1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(EEU;F%N:2`H25-/+3@X-3DM
M-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B061M:6YI<W1R87-I($=R=7`B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U
M<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS
M9W-T<B`B1W)U<"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")'
M=65R;G-E>2(*;7-G<W1R(")1=65R>2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*
M;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6X@=&%M=2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T
M8F]O:R(*;7-G<W1R(")"=6MU('1A;74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B2G5N:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U>6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*(DA434Q!<F5A(&1E;F=A;B!R
M86=U(&UE;F]L86L@=6YT=6L@;65N9VAA<'5S('-E;"!Y86YG('1E<F%K:&ER
M(&1I(&1A;&%M("(*(F)A<FES+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T
M86)L92XB"FUS9W-T<B`B(@HB2%1-3$%R96$@9&5N9V%N(')A9W4@;65N;VQA
M:R!U;G1U:R!M96YG:&%P=7,@:V]L;VT@>6%N9R!T97)A:VAI<B!D:2!D86QA
M;2`B"B)T86)E;"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S
M='(@(B(*(DA434Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L86L@=6YT=6L@;65N
M9VAA<'5S(&)A<FES('EA;F<@=&5R86MH:7(@9&D@9&%L86T@(@HB=&%B96PN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B0F5R:V%B=70B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDS,@HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R(@IM<V=S
M='(@(D)A8V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S
M='(@(DAU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A;F=I;B!R:6)U="(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E3
M3RTX.#4Y+3@M22DB"FUS9W-T<B`B66%H=61I("A)4T\M.#@U.2TX+4DI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(E1I;F=G:2(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*
M;7-G<W1R(")"86YT=6%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B0F%N='5A;B!M96YG9W5N86MA;B!E9&ET;W(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B
M"FUS9W-T<B`B0F%N='5A;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM
M<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")"96QA:&%N($)U;6DB"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.B(*;7-G<W1R("));FD@861A;&%H('!E<FUU;&%A;B!D87)I
M(&9I;&4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B5&EN9V=I(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")(;U]M92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(;U]M92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0HC+"!F
M=7IZ>0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%L86UA="!%;6%I
M;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$
M:7)E8W1O<GDB"FUS9W-T<B`B1&ER96MT;W)I($AO;64B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE
M(%!H;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R
M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS
M9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A
M9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*
M;7-G<W1R(")<(B5S7")S=61A:"!B97)H87-I;"!D:6AA<'5S+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B5&ED
M86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(D=A<FES($AO<FES
M;VYT86P@9&D@9&%L86T@2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN
M9R(*;7-G<W1R(")*87)A:R!G87)I<R!H;W)I>F]N=&%L(&1A<FD@8F]R9&5R
M(&1E;F=A;B!T96MS(&1I(&1A;&%M('-E;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ
M(@IM<V=S='(@(DAO<FEZ;VYT86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")"86=A
M:6UA;F$@8V%R82!A;F1A(&)I<V$@<V%M<&%I(&1I<VEN:3\@*%-I;&%K86X@
M;65L87!O<B$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B0F5R87!A(&)A;GEA:R!K
M;VQO;2!Y86YG(&EN9VEN(&%N9&$@9V%B=6YG:V%N/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B0F5R87!A(&)A;GEA:R!K
M;VQO;2!Y86YG(&%D82!D:7-A;F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B0F5R87!A
M(&)A;GEA:R!B87)I<R!Y86YG(&EN9VEN(&%N9&$@9V%B=6YG:V%N/R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DME;&5M8F%B
M86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED
M(")(=6UI9&ET>3H@(@IM<V=S='(@(DME;&5M8F%B86XZ(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B
M4&5L87=A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(D%L
M86UA="!%;6%I;"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP
M:'`Z-S<*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G
M<W1R(")-87-U:VMA;B!"87)I<R!396)E;'5M;GEA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B2&%N>6$@
M:6MO;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26MO;B!U;G1U:R`E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS
M('=I=&@@=&5X="(*;7-G<W1R(")):V]N(&1E;F=A;B!T96MS(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE
M.B(*;7-G<W1R(").86UA($ED96YT:71A<SHB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN(@IM<V=S='(@(B(*(DII:V$@86YD82!T:61A:R!M96QI:&%T(&EK
M;VX@;6%N87!U;B!D96YG86X@;65N9V=U;F%K86X@26YT97)N970@17AP;&]R
M97(L("(*(F%N9&$@;75N9VMI;B!P97)L=2!U;G1U:R!M96YA;F1A:2!K;W1A
M:R!I;FD@=6YT=6L@;65N;VXM86MT:69K86X@:V5L96UA:&%N("(*(E!.1RXB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S
M"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("),:6AA="!'86UB
M87(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"!'86UB
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B55),
M($=A;6)A<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R(")'86UB87(@9&%R:2!G86QE<FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B1V%M8F%R(&1A<FD@
M9V%L97)I.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G
M:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D=A;6)A<BUG86UB
M87(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<BP@
M3&%N9VMA:"`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G
M<W1R(")+;VQO;2!Y86YG(&1I:6UP;W(Z("5S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G
M<W1R(")+;VQO;2!Y86YG(&1I:6UP;W(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R(")-87-U:VMA;B!"87)I<R!"97)I:W5T
M;GEA(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(")3:6QA:V%N(&UA<W5K:V%N(&YA
M;6$@<&5N9V=U;F$@9&%N('-A;F1I(&%N9&$B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+B(*;7-G<W1R("(B"B).86UA('!E;F=G=6YA(&%T874@86QA;6%T(&5M86EL
M('!E;F=G86YT:2!T:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@(@HB<VEL
M86MA;B!H=6)U;F=I(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@;65M
M97)L=6MA;B!B86YT=6%N(&QE8FEH(&QA;FIU="XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S
M92!);F1E;G0B"FUS9W-T<B`B365N86UB86@@26YD96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E!E;F=G=6YA
M(%!R:6)A9&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3<*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(DEN9F]R;6%S:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM
M<V=S='(@(DEN9F]R;6%S:2!S=61A:"!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B36%S
M=6MK86X@2V]L;VT@0F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS
M97)T($EM86=E(@IM<V=S='(@(DUA<W5K:V%N($=A;6)A<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN
M<V5R="!486)L92(*;7-G<W1R(")-87-U:VMA;B!486)E;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN
M<V5R="!796(@3&EN:R(*;7-G<W1R(")-87-U:VMA;B!796(@3&EN:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DUA
M<W5K:V%N($MO;&]M(%-E8F5L=6UN>6$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(DUA<W5K:V%N(&MO;&]M('EA;F<@8F%R=2!S971E;&%H(&MO;&]M('EA;F<@
M<V5K87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")-87-U:VMA;B!K;VQO
M;2!Y86YG(&)A<G4@<V5B96QU;2!K;VQO;2!Y86YG('-E:V%R86YG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")-87-U:VMA;B!B87)I<R!Y86YG(&)A<G4@<V5T96QA
M:"!B87)I<R!Y86YG('-E:V%R86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B36%S
M=6MK86X@8F%R:7,@>6%N9R!B87)U('-E8F5L=6T@:V]L;VT@>6%N9R!S96MA
M<F%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B36%S=6MK86X@<&%R86=R868@
M<V5T96QA:"!P87)A9W)A9B!Y86YG('-E:V%R86YG(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`B36%S=6MK86X@<&%R86=R868@<V5B96QU;2!P87)A9W)A9B!Y
M86YG('-E:V%R86YG(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G
M:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B36%S=6MK
M86X@=&5M<&QA=&4@<&5N9V=A;G1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(DUA<W5K:V%N(&%L86UA="!E;6%I;"!D:6UA;F$@86YD82!D87!A="!M96YE
M<FEM82!S86YD:2!Y86YG(&)A<G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E
M;&P@869T97(B"FUS9W-T<B`B36%S=6MK86X@<V5L(&)E<FEK=71N>6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B36%S=6MK
M86X@<V5L('-E8F5L=6UN>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(DUA<W5K:V%N(&MO;&]M(&)E<FEK=71N>6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")-87-U
M:VMA;B!K;VQO;2!S96)E;'5M;GEA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M
M97-S86=E<R(*;7-G<W1R(")-87-U:VMA;B!'86UB87(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B36%S=6MK86X@
M<&%R86=R868@8F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B36%S=6MK86X@<&%R86=R868@<V5B
M96QU;6YY82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`B36%S=6MK86X@8F%R:7,@8F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN
M<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N(&)A<FES('-E8F5L
M=6UN>6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("))
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ(@IM<V=S='(@(DUA<W5K:V%N(&IA=V%B86X@>6%N9R!D:7!E<FQU
M:V%N('5N='5K('!E<G1A;GEA86%N(&ME86UA;F%N.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R
M="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B36%S=6MK86XO56)A:"!'86UB87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y
M"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B36%S=6MK86XO
M56)A:"!,:6YK(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U
M"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"B,L(&9U>GIY"FUS9VED("))
M;G1E9V5R(@IM<V=S='(@(E1E;F=A:"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC
M871I;VXN(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A;&ED+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM
M<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B07!L:6MA<VD@=&ED
M86L@=F%L:60N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G
M<W1R(")&;W)M870@5V%K='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y
M+B(*;7-G<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!<&QI:V%S:2!T:61A
M:R!V86QI9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M(&%P:5]I9"XB"FUS9W-T<B`B27II;B!I;F1U:R!T:61A:R!V86QI9"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.38*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+B(*;7-G<W1R("))>FEN(&EN9'5K('1I9&%K('9A;&ED+B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B27II;B!I;F1U:R!T:61A:R!V86QI
M9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DEZ:6X@
M:6YD=6L@=&ED86L@=F%L:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O
M9&4N(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A;&ED+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B07!L:6MA
M<VD@=&ED86L@=F%L:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS
M9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@
M(DEZ:6X@:6YD=6L@=&ED86L@=F%L:60N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B07!L:6MA<VD@=&ED
M86L@=F%L:60N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM
M<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&]R:7,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U>GIY
M"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B
M27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS
M(@IM<V=S='(@(DAU:F%N('!E=&ER(&1I<V5R=&%I(&%N9VEN(')I8G5T(&1I
M(&1A97)A:"!Y86YG('1E<G!E;F-I;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M27-R865L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))
M=&%L:6,B"FUS9W-T<B`B2'5R=68@36ER:6YG(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L
M(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R(")(=7)U9B!-:7)I;F<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA
M;G5A<GDB"FUS9W-T<B`B2F%N=6%R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*
M;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F5P86YG
M("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O
M;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I
M<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*
M=6QY(@IM<V=S='(@(DIU;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")2871A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G
M:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(E)A=&$@5&5N9V%H(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")2871A($MI<FD@9&%N
M($MA;F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")2
M871A($MI<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R
M(")2871A($MA;F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B
M:65S(@IM<V=S='(@(DME<FYE;"!.97=B:65S(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@0W)E
M871I;VXB"FUS9W-T<B`B2G5D=6P@5&%B96PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B
M06YA:RUA;F%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC
M(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB
M"FUS9W-T<B`B2V]R96$@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y
M>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E1A;7!I;&%N(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B0F%H87-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B1F%S
M92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86XB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM
M<V=S='(@(E!E<G5B86AA;B!386YD:2!497)A:VAI<B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA
M<W0@475A<G1E<B(*;7-G<W1R(")&87-E('1E<F%K:&ER(&1A<FD@4V5P87)U
M:"!"=6QA;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),
M87-T(%5P9&%T960Z(@IM<V=S='(@(E!E<G5B86AA;B!497)A:VER.B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B)7,@=6YT=6L@)7,@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA
M<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DAU:W5M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),
M87EO=70B"FUS9W-T<B`B5&%M<&EL86XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R(@IM<V=S='(@(E1I;F=G86QK86X@:V]S;VYG('1A;G!A
M(&)O<F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B2VER:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@
M9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(D1A9G1A<B!486)E
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G
M:60@(DQE=F5L(@IM<V=S='(@(D-I;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"B,L(&9U
M>GIY"FUS9VED("),:6)E<FEA(@IM<V=S='(@(E!A;G1U;B!*96YA:V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(D=E<FEM:7,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM
M<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")'97)I;6ES(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT
M(%)A:6X@16%R;'DB"FUS9W-T<B`B1V5R:6UI<R!D:2!P86=I(&AA<FDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I
M9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(D=E<FEM:7,@8F5B97)A<&$@
M<V%A="!L86=I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(D=E
M<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B
M1V5R:6UI<R!D:7-E<G1A:2!P971I<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(D)E<G-A;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@
M(D=E<FEM:7,@4V%L:G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*
M;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(E!A;G1U;B!*96YA:V$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),
M:6YK(@IM<V=S='(@(DQO9VEN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT
M<R!T;SHB"FUS9W-T<B`B3&EN:R!M96YU;FIU:R!K93HB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ.#,*(RP@9G5Z>GD*;7-G:60@(DQI;FMS(@IM<V=S='(@
M(E1U9V%S($QO9VEN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS
M9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@@0V]O:VEE(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@
M(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E
M<R(*;7-G<W1R(")$869T87(@1&%T86)A<V4B"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R
M(")$869T87(@5&]P:6L@0F%N='5A;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(D1A9G1A<B!486)E
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS
M9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M
M2&5L<"(*;7-G<W1R(")$869T87(@5&]P:6L@0F%N='5A;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S
M='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@9&EB87=A:"!G
M87)I<R!B87)I<R!T96MS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B1&%F=&%R('!E;F=G=6YA(&1I;F]N+6%K=&EF:V%N+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(D1A9G1A<B!P96YG
M9W5N82!D:6YO;BUA:W1I9FMA;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(D1A9G1A<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`B1&%F=&%R($)A8V%A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0HC+"!F
M=7IZ>0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQE8F%R('5N:70B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS
M9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R
M(")786MT=2!L;V-A;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*
M;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R(")496UP870@4&5R:7-T
M:7=A(&1A;B!786MT=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV
M-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&]K87-I(@H*(SH@;&]G:6XN
M<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I
M9"`B3&]G(&EN(@IM<V=S='(@(DQO9VEN(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S
M97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3&]G(&]U="(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`B3&]G:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED
M("),;V=I;B!487-K<R(*;7-G<W1R(")4=6=A<R!,;V=I;B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3DR"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(E1I9&%K(&1I87)S:7!K86XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B
M3&]G(&]U="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B
M3&]V92(*;7-G<W1R(")#:6YT82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B4F5N9&%H
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R
M(")3:6UB;VP@2'5R=68@:V5C:6P@>75N86YI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B
M3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")3:6UB;VP@2'5R=68@:V5C
M:6P@;&%T:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(E-I;6)O;"!(=7)U9B!K96-I;"!R;VUA=VDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B
M34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(RP@9G5Z>GD*;7-G
M:60@(DU31R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(DQI8G5R86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C
M87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS
M9VED(")-86=I8R(*;7-G<W1R(")3=6QA<"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")3=7)A="(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B4W5R870@061M:6XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@
M;&EN7VLN+BXB"FUS9W-T<B`B0G5A="!L:6YK+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B4W5R870B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")3=7)A="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E
M('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E
M;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB365N9V%T=7(@9&%F=&%R(&MA=&5G
M;W)I('EA;F<@:&%R=7,@9&EB97)I(&QA8F5L(&ET96TL(&1A;B!W87)N82!Y
M86YG("(*(F)E<FAU8G5N9V%N("!D96YG86X@:V%T96=O<FD@=&5R<V5B=70N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E
M<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I
M9"`B36%R8V@B"FUS9W-T<B`B36%R970B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB
M"FUS9W-T<B`B36%R9VEN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-
M87)G:6XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(DUE;F-O8V]K:V%N(&MO;&]M
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(DUA<F=I;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM
M<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B!3=6AU
M(&UA:W-I;75M('EA;F<@8F5R;&%N9W-U;F<@<V5L86UA(#(T(&IA;3HB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B4W5H=2!M86MS:6UU;2!Y86YG(&)E<FQA
M;F=S=6YG('-E;&%M82`V(&IA;3HB"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")*
M=6UL86@@;6%K<VEM=6T@9&%R:2!P;W)T86P@>6%N9R!D:6)L;VMI<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*
M;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS
M9W-T<B`B365I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B36%Y
M;W1T92(*;7-G<W1R(")486UP:6QA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B3V)A="UO8F%T86XB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(D%N9V=O=&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE;G4@
M;6]D93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")'86)U
M;F=K86X@<V5L(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`B4&5S86X@4TU3(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A
M9V4@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B
M365S<V%G92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(@0W5A8V$@365T
M87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A($UE=&%R('1I9&%K
M(&1I<V5D:6%K86XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G
M:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(D%R96$@365T87(@=&ED86L@9&ES961I86MA;BX@1&5T:6P@=&5L86@@9&EC
M871A="!U;G1U:R!A9&UI;FES=')A=&]R+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*(RP@9G5Z>GD*;7-G:60@(DUE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B4V%N9&D@;&%M82!T:61A:R!B96YA
M<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L
M;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@
M(DUE=')I8R(*;7-G<W1R(")-971R:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z
M>GD*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-971R:6LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")496YG86@B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I
M9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B4W5H=2!M:6YI;75M('EA;F<@8F5R;&%N9W-U;F<@<V5L86UA(#(T(&IA
M;3HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E
M;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B4W5H=2!M:6YI;75M('EA;F<@
M8F5R;&%N9W-U;F<@<V5L86UA(#8@:F%M.B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G
M:60@(DUI<G)O<B(*;7-G<W1R(")+97-A;&%H86XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M3&%I;BUL86EN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%S:2!T
M:61A:R!D:71E;75K86XN($%N9&$@:&%R=7,@;65N9VAA<VEK86X@:V]N9FEG
M=7)A<VD@<V5K87)A;F<@(@HB:FEK82!A;F1A(&EN9VEN(&UE;F=G=6YA:V%N
M(&%P;&EK87-I(&EN:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)
M1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@
M4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R
M(")396XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@
M(DUO8FEL92!-86EL(@IM<V=S='(@(DUO8FEL92!-86EL(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R
M871E(@IM<V=S='(@(E-E9&%N9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@X"B,L(&9U>GIY"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(E-E9&%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")5
M8F%H(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC
M+"!F=7IZ>0IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")3961A;F<B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*
M;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(D9A<V4@0G5L86XB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E-E8F%G:6%N(&)E<V%R
M($-E<F%H(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4V5B86=I86X@
M8F5S87(@0F5R87=A;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B4V5B
M86=I86X@8F5S87(@0V5R86@B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(RP@9G5Z
M>GD*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")+:7)I(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"B,L(&9U>GIY"FUS9VED
M(")-;W9E(%)I9VAT(@IM<V=S='(@(DMA;F%N(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*
M;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*(RP@9G5Z>GD*;7-G:60@(DUU;'1I
M<&QE('-E;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*
M;7-G<W1R(")!8V-O=6YT+6MU(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN
M9F]R;6%S:2!!8V-O=6YT+6MU(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(E!O<G1A;&MU(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R
M=&%L($QA>6]U="(*;7-G<W1R(")486UP:6QA;B!0;W)T86QK=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L
M($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(E1)1$%++"!387EA(%1)1$%+(%-E
M='5J=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"B,L(&9U>GIY
M"FUS9VED(").86UE(@IM<V=S='(@(FYA;6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL
M;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I
M9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE
M='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E
M;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS
M9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB
M"FUS9W-T<B`B3F5T=V]R:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(E1I
M9&%K('!E<FYA:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R(")+871E9V]R:2!"87)U(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@
M(DYE=R!#871E9V]R>2(*;7-G<W1R(")+871E9V]R:2!"87)U(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N
M(@IM<V=S='(@(D)U;&%N($)A<G4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L
M*2(*;7-G<W1R(").86UA(%!E;F=G=6YA($)A<G4@*'!I;&EH86XI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S
M=V]R9"(*;7-G<W1R(")386YD:2!"87)U(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D
M<R!D;VXG="!M871C:"XB"FUS9W-T<B`B4V%N9&D@8F%R=2!T:61A:R!C;V-O
M:RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(E=I;F1O
M=R!"87)U("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`B0F5R:71A(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P
M<R(*;7-G<W1R(")'<G5P($)E<FET82(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(D)E<FEK=71N
M>6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@
M(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B1F%S92!"97)I:W5T;GEA(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R(")+96UB86QI(&ME(%!I;&EH86XB"@HC.B!F<F%M97=O
M<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB
M"FUS9W-T<B`B0F5R:6MU=&YY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC
M87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I
M9"`B3FEG97(B"FUS9W-T<B`B36%L86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B36%L86TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PHC+"!F=7IZ>0IM<V=I
M9"`B3F\B"FUS9W-T<B`B5&ED86L@861A(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG
M=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R
M("(B"B)4:61A:R!A9&$@9&%T82!K;VYF:6=U<F%S:2!Y86YG('1E<G-E9&EA
M('5N='5K(&UE;G5N:G5K:V%N('!E<F)E9&%A;B!U;G1U:RXB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@
M8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I
M9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B5&ED86L@861A('!E<G5B
M86AA;BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B7"(E<UPB('-U9&%H(&1I=&%M8F%H
M:V%N(&ME(&1A;&%M(&EZ:6X@<VES=&5M+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R
M961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G
M<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO
M(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")4:61A:R!A9&$@:6MO;B!Y86YG(&1I
M=&5M=6MA;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(")4
M:61A:R!A9&$@;&]K87-I('EA;F<@9&EA='5R+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")4:61A:R!A9&$@;&]K87-I('EA;F<@
M9&EA='5R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R(")4:61A:R!A9&$@<F%M86QA;B!Y86YG
M('1I9&%K('-O<&%N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B
M3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")4:61A:R!A9&$@<&5N9&%F
M=&%R86X@>6%N9R!D:71U;F1A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HW-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E
M="XB"FUS9W-T<B`B0F5L=6T@9&EA='5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L
M97,B"FUS9W-T<B`B5&ED86L@861A(&%T=7)A;B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I
M9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T
M<B`B5&ED86L@861A('-I<VDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C4X,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@
M(E1I9&%K(&%D82!S:7-I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")4:61A:R!A9&$@9&ER96MT;W)I('-E
M;65N=&%R82!Y86YG('1E<G-E9&EA('5N='5K(&-A8VAE(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*
M;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G
M<W1R(")3:6QA:V%N(&UA<W5K:V%N(&YA;6$@<&5N9V=U;F$@9&%N('-A;F1I
M(&%N9&$B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM
M<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*(RP@
M9G5Z>GD*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")4:61A:R!A9&$@871U
M<F%N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E1I9&%K(&%D82!V
M97)S:2!Y86YG(&1I=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!Y86YG
M(&%S;&DN($UE;F=H87-I;&MA;B`B"B)K;VYF:6=U<F%S:2!K96UB86QI+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E1I9&%K(&%D82!V97)S:2!Y86YG
M(&1I=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!A;F1A+B!-96YG:&%S
M:6QK86X@(@HB:V]N9FEG=7)A<VD@:V5M8F%L:2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@
M(E1I9&%K(&%D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T
M<B`B5&ED86L@861A("AD:6=U;F%K86X@<V5L96YG:V%P;GEA*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y
M+3$P*2(*;7-G<W1R(")38V%N9&EN879I82`H25-/+3@X-3DM,3`I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P
M"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(D)E;&%H86X@
M0G5M:2!5=&%R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED(").;W0@069T97(B"FUS9W-T
M<B`B0F5L=6T@9&EA='5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"B,L(&9U>GIY"FUS9VED
M(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B1&ER96MT;W)I($AO;64B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D)E;'5M(&1I
M871U<B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P
M-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS
M9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*
M;7-G:60@(DYO=&5S(@IM<V=S='(@(D-A=&%T86XB"@HC.B!S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+B(*;7-G<W1R(")4:61A:R!A9&$@>6%N9R!D87!A="!D:6)R
M;W=S92P@<VEL86MA;B!K96UB86QI+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R
M(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*
M(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*(RP@9G5Z>GD*;7-G:60@
M(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(DIU;6QA:"!B87)I<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T
M"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")*=6UL86@@:V]L
M;VTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B2G5M;&%H(&)A
M<FES(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T
M<B`B4&5N8VEP=&$@3V)J96LB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B4&5N8VEP
M=&$@3V)J96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"B,L
M(&9U>GIY"FUS9VED(")/8W1A;"(*;7-G<W1R(")496YA;F<B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R(")/:W1O8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT97(@
M4&5L86YG9V%R86XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2V%N=&]R(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(E-A;F1I(&QA;6$@
M9&%N(&)A<G4@:&%R=7,@8F5R8F5D82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")3
M86YD:2!L86UA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@
M(E-A;F1I(&QA;6$@=&ED86L@8F5N87(N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(DAA;GEA(')A;6%L86X@>6%N9R!T:61A:R!S;W!A;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW,0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")096YG9V%N=&D@86QA;6%T(&5M
M86EL(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B
M"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@
M82!S:&%R92(*;7-G<W1R("(B"B)(86YY82!P96UI;&EK(&%T874@<VES=&5M
M(&%D;6EN:7-T<F%T;W(@<V%J82!Y86YG(&1A<&%T(&UE;F=U8F%H(&ME<&5M
M:6QI:V%N("(*(F%T874@<&5M:6QI:R!I>FEN('5N='5K(&)A9VEA;B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R(")"=6MA(&1I(&IE;F1E;&$@>6%N9R!B87)U(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@
M(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")"=6MA
M(&QI;FL@:6YI(&1I(&IE;F1E;&$@>6%N9R!B87)U(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S
M='(@(E-I<W1E;2!/<&5R87-I(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")0:6QI:&%N(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM
M<V=S='(@(E!I;&EH86X@=6YT=6L@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B
M"FUS9W-T<B`B1&%F=&%R($YO;6]R($)E<G5R=70B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ>0IM<V=I9"`B3W)G
M86YI<V%T:6]N(@IM<V=S='(@(E1R86YS;&%S:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA
M;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B365N9V%T=7(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B07!L:6MA<VD@=&5M<&QA=&4@
M87-L:2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B
M5&5M<&QA=&4@87-L:2!D:2!D86QA;2`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM
M<V=I9"`B3W1H97(B"FUS9W-T<B`B3&%I;BUL86EN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS
M9W-T<B`B26YF;W)M87-I($QA:6XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("))
M>FEN(%!E;6EL:6LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")!<F5A(&ME('=E871H97(N8V]M('1I9&%K
M(&1I<V5D:6%K86XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W
M,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'
M4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B2V]D92!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@4VAE;&PB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@
M3&EG:'0@4F%I;B(*;7-G<W1R(")032!'97)I;6ES(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E
M<G,B"FUS9W-T<B`B4$T@1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@
M(E!-($)E<G-A;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0
M32!'97)I;6ES(%-A;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")032!#97)A
M:"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")032!(=6IA;B!P971I<B!D
M:7-E<G1A:2!D96YG86X@86YG:6X@<FEB=70B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9R(*;7-G<W1R(")%:W-T96YS:2!03U-)6"!T:61A:R!D:71E;75K86XB"@HC
M.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B
M4$A0(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")*87)A
M:R!S<&%S:2!D87)I(&)O<F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM
M<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4V%L:6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S='(@
M(FYA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4V5B86=I86X@
M0F5R87=A;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E-A;F1I(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4V%N9&D@8F5R:&%S
M:6P@9&EU8F%H+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM
M<V=S='(@(E-A;F1I(&QA;6$@=&ED86L@8F5N87(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PHC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2V5T:6L@
M<V%N9&D@9'5A(&MA;&D@=6YT=6L@;65N9VMO;F9I<FUA<VDB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*
M;7-G<W1R(")386YD:3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")386YD:3HB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S
M-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED
M(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B4V%N9&D@:&%R=7,@
M8V]C;VLN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@
M(E!A<W1E(@IM<V=S='(@(E-A;&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP
M8F]A<F0B"FUS9W-T<B`B3&5K871K86X@9&%R:2!C;&EP8F]A<F0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED
M(")0871H(@IM<V=S='(@(E!A=&@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")0
M96YD869T87)A;B!Y86YG(&1I='5N9&$Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B3W)A;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I
M9"`B4&5R8V5N="(*;7-G<W1R(")097)S96XB"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(DUE;&%K<V%N86MA;B!/
M<&5R87-I(%!E;65L:6AA<F%A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,#8*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\B"FUS9W-T<B`B365L86MS86YA:V%N(&]P97)A<VD@<&5M96QI
M:&%R86%N('!A9&$@=V%K='4@;&]G:6X_(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VXB
M"FUS9W-T<B`B27II;B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E
M;&5T960N(@IM<V=S='(@(DEZ:6X@=6YT=6L@7"(E<UPB('1I9&%K(&1A<&%T
M(&1I:&%P=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*
M(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DEZ
M:6XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B27II;B(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M
M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(DEZ:6X@061M:6YI<W1R87-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O
M<FUA<VD@4')I8F%D:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E
M=',B"FUS9W-T<B`B0FEN871A;F<@2V5S87EA;F=A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`B5&ED86L@861A(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM
M<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I>&5L(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(DMA=&$M
M:V%T82!K;&ES92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O
M;64@8V5L;"(*;7-G<W1R(")3:6QA:V%N(&ML:6L@:V4@9&%L86T@8F5B97)A
M<&$@<V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(E-I;&%K
M86X@:V]N9FER;6%S:2!B86AW82!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N(&5L
M96UE;B!I;FDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E-I
M;&%K86X@:V]N9FER;6%S:2!B86AW82!A;F1A(&EN9VEN(&UE;F=H87!U<R!L
M:6YK('5N='5K(&5L96UE;B!I;FDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4W,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B4VEL86MA;B!M87-U:VMA;B!N86UA
M('5N='5K(&MA=&5G;W)I('EA;F<@8F%R=3HB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B4VEL
M86MA;B!M87-U:VMA;B!N86UA('5N='5K(&MA=&5G;W)I('EA;F<@8F%R=3HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@
M=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW
M"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK86X@<FEN9VMA<V%N('5N='5K
M(&UA<V%L86@N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")3:6QA
M:V%N(&UA<W5K:V%N(&YA;6$@<&5N9V=U;F$@9&%N('-A;F1I(&%N9&$B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*
M(E-I;&%K86X@;65M8F%C82!T96MS(&)E<FEK=70@:6YI+B!!;F1A($A!4E53
M('-E='5J=2!D96YG86X@<WEA<F%T+7-Y87)A="`B"B)U;G1U:R!M96YG9W5N
M86MA;B!S:7-T96TN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4VEL86MA;B!M87-U
M:VMA;B!N86UA('5N='5K(&MA=&5G;W)I('EA;F<@8F%R=3HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")#;VUM86YD
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC
M<R(*;7-G<W1R(")0;VQI=&EK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B4&]L;&EN9R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O
M<G1A;&MU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E(@IM<V=S='(@(E!O<VES:2!U;G1U:R!G86UB87(@:6YI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:7-I
M('5N='5K('1A8F5L(&EN:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R
M*',I.B`B"FUS9W-T<B`B2'5J86X@<V%L:G4@=6YT=6L@)7,@:F%M('1E<F%K
M:&ER.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G
M:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B2V5M=6YG
M:VEN86X@/&)R+SY(=6IA;B!S86QJ=2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(E1E:V%N86XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B
M"FUS9W-T<B`B5&5K86YA;B!P861A('!E<FUU:V%A;B!L875T.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E
M.B`B"FUS9W-T<B`B5&5K86YA;CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE
M=R(*;7-G<W1R("),:6AA="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(DQI:&%T(&=A;6)A
M<B!D:2!D86QA;2!J96YD96QA('EA;F<@8F%R=2(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM
M<V=S='(@(DME;6)A;&D@:V4@4&EL:6AA;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(D-E=&%K(&1O:W5M96XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*
M(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B3W)A;F<B"@HC.B!S
M97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B1&5S:W)I<'-I($UA<V%L86@B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R
M(")0<F]J96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X-0HC+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS
M9W-T<B`B1&%R:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME
M>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*
M;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z
M>GD*;7-G:60@(E%A=&%R(@IM<V=S='(@(DMU;W1A(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")1=65R>2(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T
M<B`B2W5O=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@
M8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C8T"B,L(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B
M4V%L:6X@4&EL:6AA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(DAU:F%N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@
M(E)A:6X@16%R;'DB"FUS9W-T<B`B2'5J86X@9&D@<&%G:2!H87)I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@
M(E)A:6X@3&%T92(*;7-G<W1R(")(=6IA;B!B96)E<F%P82!S86%T(&QA9VDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM
M<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(DAU:F%N(&1A;B!"97)S86QJ=2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")2
M86EN('1O(%-N;W<B"FUS9W-T<B`B2'5J86X@8F5R8V%M<'5R(&1E;F=A;B!S
M86QJ=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD
M;VT@1F]R='5N92(*;7-G<W1R(")286UA;&%N($%C86LB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(DAU:F%N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B0F%C82(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")2
M96%D(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R(")986MI;B!U;G1U:R!M96YG:&%P=7,@)7,_($]P97)A<VD@:6YI
M('1I9&%K(&1A<&%T(&1I8F%T86QK86XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(EEA:VEN('5N='5K(&UE
M;6EN9&%H:V%N(&1A=&$@<&5N9V=U;F$@=6YT=6L@<&5N9V=U;F$@)7,_($]P
M97)A<VD@:6YI('1I9&%K("(*(F1A<&%T(&1I8F%T86QK86XN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B56QA;F=I(&%K<VD@
M=&5R86MH:7(@86YD82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")2969R97-H
M($5L96UE;B!-96YU($1I;F%M:7,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B
M4F5F<F5S:"!,:6AA="!0;W)T86PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`B071U<B!K96UB86QI("(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@
M(E)E;&]A9"(*;7-G<W1R(")"86-A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B1&ET86YD86DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R
M<R(*;7-G<W1R(")296UO=&4@4V5R=F5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")0:6YD86AK86XB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E
M;6]V92!";&]C:R(*;7-G<W1R(")0:6YD86AK86X@0FQO:VER(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")(87!U<R!K;VQO;2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*
M;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E!I;F1A:&MA;B!#
M87)A($9O<FUA="(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X
M"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")0:6YD86AK86X@<&%S86YG
M86XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B4&EN9&%H:V%N('-C<FEP="!Y86YG('-U9&%H(&1I
M<VEM<&%N(&1A<FD@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A<F$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E!I;F1A:&MA;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R(")0:6YD86AK86X@;F]D92!I;FD@9&%R:2!D;VMU;65N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B
M4F5M;W9E('5S97(B"FUS9W-T<B`B4&EN9&%H:V%N('!E;F=G=6YA(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")0:6YD86AK86X@
M<&5N9V=U;F$Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I("5S
M+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&ED86L@9&%P870@;65N
M>6EM<&%N(&MO;F9I9W5R87-I("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N
M<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T
M(@IM<V=S='(@(D%T=7(@:V5M8F%L:2`B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B
M071U<B!K96UB86QI(%-A;F1I(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M071U<B!K96UB86QI(%-A;F1I($%N9&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS
M9W-T<B`B1F%S92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86XB"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D
M;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")(
M87-I;"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO
M;G,B"FUS9W-T<B`B2V5M8F%L:2!K92!0:6QI:&%N(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W
M;W)D(@IM<V=S='(@(DME=&EK('5L86YG('-A;F1I(&)A<G4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")2975N:6]N(@IM<V=S='(@(DIA;&%N
M:V%N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R(")+96UB86QI(&ME($MO;F9I9W5R87-I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS(@IM<V=S='(@(E!I;&EH86X@161I=&]R(%)I8V@@5&5X="(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R
M(")496MA+71E:VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(DMA;F%N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3<*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R
M(")$869T87(@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R(")0<F]P97)T:2!"87)I<RXN+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*(RP@9G5Z>GD*;7-G
M:60@(E)O;&4B"FUS9W-T<B`B071U<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O
M=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R
M=&EE<R(*;7-G<W1R(")0<F]P97)T:2!"87)I<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O
M=R!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!E<G1I(&)A<FES(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@
M(E)O=W,Z(@IM<V=S='(@(D)A<FES.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM
M<V=S='(@(D%T=7)A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B071U<F%N
M(&%K86X@9&ET86UP:6QK86X@9&EA;G1A<F$@<V5M=6$@8F%R:7,@9&%N(&MO
M;&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'DB"FUS9W-T<B`B071U<F%N(&%K86X@9&ET86UP:6QK86X@
M:&%N>6$@9&EA;G1A<F$@:V]L;VTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")!='5R86X@86MA
M;B!D:71A;7!I;&MA;B!H86YY82!D:6%N=&%R82!B87)I<R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R(")*86QA;FMA
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2=V%N
M9&$B"FUS9W-T<B`B0F%C82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q
M"B,L(&9U>GIY"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D%R96$@:V4@=V5A=&AE<BYC;VT@=&ED86L@
M9&ES961I86MA;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E!E<V%N(%--4R(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S
M='(@(E-13"!3:&5L;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I
M9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@
M(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED
M(")37U%,(%-H96QL(@IM<V=S='(@(E-?44P@4VAE;&PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*
M;7-G<W1R(")38G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T
M<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"B,L(&9U>GIY
M"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")(=6IA;B!B96)E<F%P82!S
M86%T(&QA9VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")&<F%M92!Y86YG
M('-A;6$@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@
M(E-A;6]A(@IM<V=S='(@(E-P86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY
M"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(DUA<F=I;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3
M871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R(")3:6UP
M86XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R
M(")3:6UP86X@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E-I;7!A
M;B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A
M=F4@3W!T:6]N<R(*;7-G<W1R(")3:6UP86X@4&EL:6AA;B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R
M)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB4VEM<&%N
M(&MO;F9I9W5R87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!0
M2%`@:V4@9&%L86T@9&ER96MT;W)I("(*(G-E<G9E<B!S96UE;G1A<F$@86YD
M82XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+
M;VYF:6=U<F%S:2`E<R!S=61A:"!D:7-I;7!A;BXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B4V-R:7!T('-E='5P('5P9W)A9&4@<W5D86@@9&ES:6UP86X@:V4Z("<E
M<R<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")396)A9VEA
M;B!(=6IA;B!P971I<B!D:7-E<G1A:2!A;F=I;B!R:6)U="(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("))
M;&UU(%!E;F=E=&%H=6%N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")096YC87)I86XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G
M<W1R(")-97-I;B!096YC87)I86XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")0:6QI:"!S97)V
M97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E!I;&EH(&=R=7`@=6YT
M=6L@9&ET86UB86@B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S
M"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4&EL:6@@<&5M
M:6QI:R!B87)U(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P
M"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B4&EL:6@@<V5R=F5R
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E
M;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E!I;&EH('!E;F=G=6YA('5N
M='5K(&1I=&%M8F%H(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G
M<W1R(")(87!U<R!S96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C8S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RXB"FUS9W-T<B`B4&EL:6@@9F]R;6%T('1A;F=G86PZ(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")0:6QI:"!P96UI;&EK
M(&)A<G4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")0
M:6QI:"!P96UI;&EK(&)A<G4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F
M<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*
M(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)0
M:6QI:"!K87)A:W1E<B!Y86YG(&%N9&$@<&5R;'5K86X@9&%R:2!K;W1A:RUK
M;W1A:R!D:6)A=V%H(&EN:2X@06YD82!D87!A="`B"B)M96YY86QI;B!D86X@
M;65L96MA=&MA;FYY82!K92!D86QA;2!A<F5A('1E:W,N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(E!I;&EH(&)A=&%S('1A;F=G86PZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!F;W)M870Z(@IM<V=S='(@(E!I;&EH(&9O<FUA="!T86YG9V%L.B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G
M:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*
M;7-G<W1R(")0:6QI:"!I9&5N=&ET87,@>6%N9R!I;F=I;B!D:75B86@@;VQE
M:"!A;F1A.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")0:6QI:"!B
M871A<R!W86MT=3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4&EL:6@@
M9F]R;6%T('=A:W1U.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R
M(")0:6QI:"!D=6$@:V]L;VT@>6%N9R!C;V-O:RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N(@IM<V=S='(@(E!I;&EH('=A<FYA('-C:&5M92!A;F1A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4&EL:6@@8F%H87-A('EA;F<@
M86YD82!I;F=I;FMA;CHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")+
M:7)I;2!,87!O<F%N($UA<V%L86@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B
M"FUS9W-T<B`B4V5N<V]R.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P
M=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0HC+"!F=7IZ
M>0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")!;F=K82!$97-I;6%L
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC+"!F=7IZ
M>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!
M9&UI;B(*;7-G<W1R("))>FEN($%D;6EN:7-T<F%S:2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B
M4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(DEZ:6XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"B,L(&9U>GIY"FUS
M9VED(")3970B"FUS9W-T<B`B4V5T=7`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@HB071U<B!P:6QI:&%N('5N='5K(&UE;F=I>FEN:V%N(&%N9&$@
M9&%P870@;65N9V%T=7(@=6QA;F<@:V5M8F%L:2!S86YD:2!A;F1A("(*(F%P
M86)I;&$@86YD82!L=7!A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")!='5R(')E
M;6]T92!S97)V97(@>6%N9R!I;F=I;B!A;F1A(&%K<V5S(&1A<FD@<&]R=&%L
M(&%N9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N(@IM<V=S='(@(D%T=7(@8F%H87-A+"!Z;VYA('=A:W1U(&1A
M;B!P:6QI:&%N('1A;F=G86PL('EA;F<@86YD82!I;F=I;FMA;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B
M"B)!='5R(&%P;&EK87-I(&%W86P@86YD82P@=V%R;F$@<V-H96UE+"!H86QA
M;6%N(')E9G)E<V@@9&%N('!I;&EH86X@=&%M<&EL86X@(@HB;&%I;FYY82XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*
M;7-G<W1R(")3971U<"(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE(@IM<V=S='(@(E-C<FEP="!S971U<"!U<&=R861E('1E<G-E9&EA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`B0F5B97)A<&$@;&]K87-I('EA;F<@;75N9VMI;B!D96YG86X@
M<&%R86UE=&5R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM
M<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B0F5L86YJ82(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y
M(@IM<V=S='(@(E)I;F=K87-A;B!096YD96LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B4&5R;'5K86@@:W5N8VD@
M86MS97,@9&ED969I;FES:6MA;B!U;G1U:R!K96)A;GEA:V%N(&QI;FL_(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@
M(E-H;W<B"FUS9W-T<B`B5&%M<&EL:V%N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)486UP:6QK86X@<&5R8F5D86%N
M(&1I86YT87)A(&MO;F9I9W5R87-I('EA;F<@8F%R=2!D:7-I;7!A;B!D86X@
M>6%N9R!B87)U("(*(F1I:&%S:6QK86XN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/R(*;7-G<W1R(")486UP:6QK86X@=V%K='4@;&]G:6X@=&5R
M86MH:7(@:V5T:6MA(&%N9&$@;&]G:6X_(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$S"B,L(&9U>GIY"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")'97)I
M;6ES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")486UP:6QK
M86X@<&%N96P@;65N=2!T86)E;"!O<&5R87-I/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B5&%M<&EL:V%N($UE;G4@
M)7,@9&D@<V5B96QA:"!K:7)I/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486UP:6QK
M86X@9&EA;&]G(%!R;W!E<G1I(%-E;"!486)E;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%M
M<&EL:V%N(&1I86QO9R!0<F]P97)T:2!486)E;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(E1A;7!I;&MA;B!D:6%L;V<@4')O<&5R=&D@0F%R:7,@5&%B96PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(E1A;7!I;&MA;B!D:6%L;V<@<')O<&5R=&D@9V%M8F%R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO
M860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B1V5R:6UI<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(D=E<FEM:7,@9&D@<&%G:2!H
M87)I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")'97)I;6ES(&)E8F5R
M87!A('-A870@;&%G:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*
M;7-G<W1R(")'97)I;6ES(&1I('-E:VET87(@9&%E<F%H(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG
M;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,@HC+"!F=7IZ>0IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@
M(D1A9G1A<B!"86-A86XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M("),97=A=&D@4&5M96QI:&%R86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B4V%L:G4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I
M9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W
M(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B1V5R:6UI<R!386QJ=2!D:2!P86=I
M(&AA<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B1V5R:6UI
M<R!386QJ=2!B96)E<F%P82!S86%T(&QA9VDB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(DME9&%L
M86UA;B!386QJ=3HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4&5R8F%N
M9&EN9V%N('-A;&IU(&1I("AD86QA;2D@86ER.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("),
M86=U("8@4V%J86LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V
M"B,L(&9U>GIY"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R
M(")(87!U<R!P:6QI:&%N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U
M<F-E(&%D9')E<W,B"FUS9W-T<B`B06QA;6%T($5M86EL($%N9&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*2(*;7-G<W1R(")%<F]P82!396QA=&%N("A)4T\M.#@U
M.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I
M9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")"96QA:&%N($)U;6D@
M4V5L871A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M(@IM<V=S='(@(DIA<F%K(&%N=&%R82!S96P@>6%N9R!B97)D96MA=&%N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*
M;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&PB"FUS9W-T<B`B2F%R86L@86YT87)A(&ES:2!D86X@8F]R9&5R(&1I(&1A
M;&%M('-E;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0HC+"!F
M=7IZ>0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(DIA<F%K('-P87-I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(DIA<F%K('-P87-I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM
M<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")*87)A:R!S<&%S
M:2!D86X@:F%R86L@<W!A<VD@9&%R:2!B;W)D97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC
M+"!F=7IZ>0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B2F%R86L@<W!A<VDB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS
M9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I
M9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B36%S=6MK86X@
M2V%R86MT97(@4W!E<VEA;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS
M9W-T<B`B4&ES86AK86X@4V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN
M(@IM<V=S='(@(E!I<V%H:V%N(&MO;&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(E!I<V%H:V%N(&)A<FES(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B3VQA:')A9V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K
M(@IM<V=S='(@(E!E<FIA;&%N86X@0FEN=&%N9R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P
M.0HC+"!F=7IZ>0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")097)J86QA
M;F%N($)I;G1A;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@
M(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*
M;7-G<W1R(")&;W)M870@5V%K='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")!;F=K82]H=7)U
M9B]S:6UB;VP@>6%N9R!D:6)E<FD@=&%N9&$@9V%R:7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED
M(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")'87EA(%M#4U-=(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM
M<V=I9"`B4W4B"FUS9W-T<B`B36EN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4W5B9&ER96MT;W)I("<E
M<R<@=&ED86L@9&ET96UU:V%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`B06YG:V$O:'5R=68O<VEM8F]L('EA;F<@9&ET=6QI<R!D:6)A
M=V%H(&=A<FES(&)A<FES('1E:W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W
M"B,L(&9U>GIY"FUS9VED(")3=6)M:70B"FUS9W-T<B`B06YG:V$O:'5R=68O
M<VEM8F]L('EA;F<@9&ET=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,B
M"@HC.B!S:6=N=7`N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(B!097)M:6YT86%N
M('EA;F<@9&ES86UP86EK86X@=6YT=6L@;65N86UB86AK86X@)R4@<R<@:V4@
M9&%L86T@<VES=&5M+B!!;F1A("(*(G1I9&%K(&1A<&%T(&QO9R!I;B!S86UP
M86D@<&5R;6EN=&%A;B!A;F1A('1E;&%H(&1I<V5T=6IU:2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3
M=6)S8W)I<'0B"FUS9W-T<B`B06YG:V$O:'5R=68O<VEM8F]L('EA;F<@9&ET
M=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B
M"FUS9W-T<B`B0F5R:&%S:6PB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G('-U9&%H(&)E<FAA
M<VEL(&1I=&%M8F%H:V%N(&ME(&1A;&%M('-I<W1E;2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B1&%T82!U;G1U:R!P96YG9W5N82`G)7,G('-U
M9&%H(&)E<FAA<VEL(&1I8F5R<VEH:V%N(&1A<FD@<VES=&5M+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S
M7"(N(@IM<V=S='(@(EPB)7-<(G-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R("(G)7,@<W5D86@@8F5R:&%S:6P@9&EP:6YD86AK86X@
M9&%R:2!S:7-T96TN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM
M<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E
M;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A<VD@
M<W5D86@@8F5R:&%S:6P@9&EK96UB86QI:V%N+B!5;&%N9VD@=6YT=6L@;65L
M:6AA="!P97)U8F%H86XN("(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU
M.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"86-K
M=7`@:V]N9FEG=7)A<VD@<W5D86@@8F5R:&%S:6P@9&ES:6UP86XN(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(D9I;&4@0F%C:W5P($MO;F9I9W5R87-I("5S
M('-U9&%H(&)E<FAA<VEL(&1I<VEM<&%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B<E<R<@<W5D86@@8F5R:&%S:6P@
M9&EP97)B86AA<G5I(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B<E<R<@<W5D86@@8F5R
M:&%S:6P@9&ET=6QI<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@
M(E-U9&%N(@IM<V=S='(@(D-E<F%H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*
M;7-G<W1R(")2:6YG:V%S86XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(DUA=&%H87)I(%1E<F)I="(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*
M;7-G<W1R(")-871A:&%R:2!497)B96YA;2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R
M(")#97)A:"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*
M;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B36%T86AA<FD@5&5R8FET(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")-871A:&%R:2!4
M97)B:70O36%T86AA<FD@5&5R8F5N86TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B36%T
M86AA<FD@5&5R8FET.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R(")-871A:&%R:2!497)B96YA
M;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(DUA=&%H87)I(%1E<F)E;F%M.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG
M(&1I='5L:7,@9&EA=&%S(&)A<FES('1E:W,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D1U:W5N
M9V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B
M"FUS9W-T<B`B;F%M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(FYA
M;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B2'5J86X@<&5T:7(@9&ES97)T86D@9&5N
M9V%N(&%N9VEN(')I8G5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S
M='(@(DAU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!B861A:2!A;F=I;B!R
M:6)U="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")(=6IA;B!P971I<B!D:7-E
M<G1A:2!D96YG86X@86YG:6X@<FEB=70B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R
M;7,@16%R;'DB"FUS9W-T<B`B1V5R:6UI<R!D:2!P86=I(&AA<FDB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED
M(")44U8@9FEL92(*;7-G<W1R(")*=61U;"(*"B,Z(&9R86UE=V]R:R]522]5
M22]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R
M(")$869T87(@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S
M(@IM<V=S='(@(E!R;W!E<G1I(%1A8F5L(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B
M;&4@4V5T(@IM<V=S='(@(E!R;W!E<G1I(%1A8F5L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B
M5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P97)T:2!T86)E;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1A:7=A;B(*;7-G
M<W1R(")(=6IA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@
M(E1A<F=E=#HB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@
M(E1U9V%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(E-U:'4@=6YT=6L@:F%M('1E<F%K:&ER.B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G
M<W1R(")3=6AU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")3=6AU.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<R(*;7-G<W1R(")3=6AU/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B1&ER96MT;W)I($UO=&EF("<E<R<@=&ED86L@9&ET
M96UU:V%N+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")4
M96UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")496UP;&%T92!!9&UI
M;FES=')A<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*(RP@9G5Z>GD*;7-G:60@(E1E
M>'0B"FUS9W-T<B`B0F5R:6MU=&YY82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")(86YY82!496MS
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")097)A=&%A;B!4
M96MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")496MS($)A9VEA;B!!=&%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.0IM<V=I9"`B5&@B"FUS9W-T<B`B2VUS(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86D@
M*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED
M(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"B,L(&9U>GIY"FUS
M9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K86XN(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U3
M4"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS
M9W-T<B`B4&5M96QI:&%R86%N.CH@8VQA<W,@=&ED86L@8F5R:&%S:6P@9&EP
M86YG9VEL(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR
M.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(E=I;F1O=R!0:6QI:&%N('-U9&%H(&1I='5T=7`N(%-I
M;&%K86X@2V5L=6%R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ
M.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G
M:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT
M('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B
M5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B2&%N>6$@<VES:2!B86=I
M86X@8F%W86@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S
M<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B
M5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N
M('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB
M36]D92!,87EA<B!096YU:"!D:6ME;F%L(&1A<&%T(&UE;GEE8F%B:V%N(&UA
M<V%L86@@9&5N9V%N($EN=&5R;F5T($5X<&QO<F5R+"`B"B)J=6=A('5N='5K
M(&UE;F-A<FD@:V5S86QA:&%N('EA;F<@;65N>65B86)K86X@86YD82!T:61A
M:R!M86UP=2!B96ME<FIA("(*(F1E;F=A;B!B86EK+B!!;F1A(&UU;F=K:6X@
M<&5R;F%H(&UE;F=A;&%M:2!T86UP:6QA;B!Y86YG(&)U<G5K+"!K96MU<F%N
M9V%N("(*(F1A<FD@9G5N9W-I(&5D:71O<B!D86XO871A=2!B<F]W<V5R('EA
M;F<@<V5R:6YG(&MA;&D@<G5S86L@9&%N(&AA<G5S(&1I=6QA;F<@(@HB:V5M
M8F%L:2X@2FEK82!S:7-T96T@86YD82!A9&%L86@@5VEN9&]W<R`Y>"!A9&$@
M:V5M=6YG:VEN86X@86YD82!A:V%N("(*(FUE;F1A<&%T:V%N("=+97-A;&%H
M86X@4&5R;&EN9'5N9V%N(%5M=6TG(&1A;B!P97)L=2!U;G1U:R!M92UR97-T
M87)T("(*(FMO;7!U=&5R(&%N9&$N7%QN7%QN($%N9&$@<W5D86@@9&EP97)I
M;F=A=&DN(%-I;&%K86X@:VQI:R!/2R!J:6MA(&%N9&$@:6YG:6X@(@HB;65N
M8V]B82!E9&ET;W(@;&%Y87(@<&5N=6@N(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&%S(%PB)7-<
M(B!S=61A:"!D:6AA<'5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(DAA;GEA('-I<VD@8F%G:6%N(&MI<FDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*
M(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV
M96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0IM<V=I9"`B5&AE(&YU;6)E<B!O
M9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D
M96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R
M:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O
M=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI
M9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*
M;7-G<W1R(")(86YY82!S:7-I(&)A9VEA;B!K86YA;B!D86X@:VER:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")(
M86YY82!S:7-I(&)A9VEA;B!K86YA;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")397)V
M97(@7"(E<UPB('-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(E-E
M<G9E<B!<(B5S7"(@<W5D86@@8F5R:&%S:6P@9&ES:6UP86XN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B
M4&5R;6EN=&%A;B!P96YD869T87)A;B!U;G1U:R`E<R!S=61A:"!B97)H87-I
M;"!D:7!I;F1A:&MA;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I
M;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(DAA;GEA('-I<VD@8F%G:6%N(&%T87,@9&%N
M(&)A=V%H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T
M<B`B2&%N>6$@<VES:2!B86=I86X@871A<R(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O
M1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%R96$@:V4@
M=V5A=&AE<BYC;VT@=&ED86L@9&ES961I86MA;BXB"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B1&ER
M96MT;W)I($UO=&EF("<E<R<@=&ED86L@9&ET96UU:V%N+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(D%R96$@
M365T87(@=&ED86L@9&ES961I86MA;BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B061A(&UA<V%L86@@:V5T
M:6MA(&UE;F%M8F%H:V%N("<E<R<@:V4@9&%L86T@<VES=&5M.B`E<R`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B061A(&UA<V%L
M86@@:V5T:6MA(&UE;6)E<G-I:&MA;B!D871A('5N='5K('!E;F=G=6YA("<E
M<R<@9&%R:2!S:7-T96TZ(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")!9&$@
M;6%S86QA:"!K971I:V$@;65M:6YD86AK86X@)R5S)R!D87)I('-I<W1E;3HB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E
M<R(*;7-G<W1R(")!9&$@;6%S86QA:"!K971I:V$@;65M<&5R8F%H87)U:2`G
M)7,G.B5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*
M(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)!9&$@:V5S86QA:&%N(&1I
M(&1A;&%M(&9O<FUU;&ER(&MO;F9I9W5R87-I+B!-=6YG:VEN(&%N9&$@=&ED
M86L@;65N9VES:2`B"B)K;VQO;2!Y86YG(&1I<&5R;'5K86XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C
M:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I
M;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D%D82!K
M97-A;&%H86X@9&D@9&%L86T@9F]R;75L:7(@:V]N9FEG=7)A<VDN($UU;F=K
M:6X@86YD82!T:61A:R!M96YG:7-I("(*(FMO;&]M('EA;F<@9&EP97)L=6MA
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(R,@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@HB061A(&ME<V%L86AA;B!D:2!D86QA;2!F
M;W)M=6QI<B!K;VYF:6=U<F%S:2X@375N9VMI;B!A;F1A('1I9&%K(&UE;F=I
M<VD@(@HB:V]L;VT@>6%N9R!D:7!E<FQU:V%N+B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B0G)O=W-E<B!A;F1A('1I9&%K(&UE;F1U:W5N9R!U
M;G1U:R!F:71U<B!I;FDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H
M92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE
M(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B
M"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("));FD@861A;&%H("5S
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J
M96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA
M:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE
M;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4
M:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")7:6YD;W<@:6YI(&AA
M<G5S(&1I<&%N9V=I;"!D87)I(%!I;&EH86X@5VEN9&]W(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD
M97(B"FUS9W-T<B`B4&5T:7(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(E1I:V5T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`B2G5D
M=6PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4
M:6UE(%1R86-K:6YG(@IM<V=S='(@(DUE;F=I:W5T:2!786MT=2(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T
M<B`B1F]R;6%T(%=A:W1U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4S.0HC+"!F=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B
M2&%P=7,@<&EL:6AA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE
M<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@
M(E1I=&QE(@IM<V=S='(@(DIU9'5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R(")*=61U;"`H0V%T871A;B!P971U;FIU:RDB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"B,L(&9U>GIY
M"FUS9VED(")4;R(*;7-G<W1R(")!=&%S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I
M9"`B5&]D87DB"FUS9W-T<B`B2&%R:2!);FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-
M3"!3;W5R8V4B"FUS9W-T<B`B1V%N=&D@4V]U<F-E($A434PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B0F5S
M;VLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G
M<W1R(")(87)I($EN:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(D%T87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS
M"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(D9R86UE($%T87,@
M*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4
M<F%N<VQA=&EO;G,B"FUS9W-T<B`B5')A;G-L87-I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(E-E;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G
M<W1R(")4=7)K:2`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4=7)K;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V
M.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(DEN9&5K<R!5+E8Z(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E52
M3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")5
M4DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T
M<B`B1V%R:7,@8F%W86@B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B5&ED
M86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z.#,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B5&ED86L@
M9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B5&ED86L@
M9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T
M('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A
M<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS
M9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U
M<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A
M<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N
M<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E
M<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U
M:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")4
M:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")4:61A:R!D87!A
M="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")4
M:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@
M7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT
M=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B
M5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T
M;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5
M;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB
M)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@
M;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&
M:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(E1I
M9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")4
M:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B5&ED
M86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD
M97)L:6YE(@IM<V=S='(@(D=A<FES(&)A=V%H(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D)A
M=&%L:V%N(%!E<G5B86AA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(D)A=&%L:V%N(&%K<VD@=&5R86MH:7(@86YD82(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@
M(E1I9&%K(&1I87)S:7!K86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%54
M1BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG
M9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3
M=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T
M87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R(")5;FET(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(E1I9&%K(&%D82!L;VMA<VD@
M>6%N9R!D:6%T=7(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R
M('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(D)A=&%L:V%N(&QI;FL@<&%D
M82!E;&5M96X@>6%N9R!S96MA<F%N9R(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM
M<V=S='(@(FYA;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO
M=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A
M<F0N(@IM<V=S='(@(B(*(E-C<FEP="!Y86YG('1I9&%K(&UE;7!U;GEA:2!H
M86L@:7-T:6UE=V$@=&ED86L@9&%P870@;65N9V%K<V5S($AA<'5S+U-A;&EN
M+R(*(DQE:V%T:V%N('-E<W5A:2!R96YC86YA('5N='5K(&%L87-A;B!K96%M
M86YA;BY+;&EK($]+('5N='5K(&UE;&EH870@8V%T871A;B`B"B)T96MN:7,@
M<&%D82!M;WII;&QA+F]R9R!D:6UA;F$@86YD82!A:V%N(&1I<&5R;&EH871K
M86X@8V%R82!B86=A:6UA;F$@=6YT=6L@(@HB;65N9VEZ:6YK86X@<V-R:7!T
M('5N='5K(&1A<&%T(&UE;F=A:W-E<R!K92!C;&EP8F]A<F0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM
M<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B5V%R;F$@8F5L=6T@9&EA='5R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D
M($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M,PIM<V=I9"`B57!D871E(@IM<V=S='(@(E!E<F)A:&%R=6DB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")097)B86AA<G5I("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D
M871E('5S97(B"FUS9W-T<B`B4&5R8F%H87)U:2!P96YG9W5N82(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@<W5D86@@9&EP
M97)B86AA<G5I+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS
M9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")38W)I<'0@
M=7!G<F%D92!S=61A:"!D:6AA<'5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(E5P;&]A9"(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")3
M96UU82!F:6QE('-E='5P(&%P;&EK87-I('-U9&%H(&1I=7!L;V%D(&ME('-E
M<G9E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(E-I;6)O;"!H=7)U9B!B97-A<B!L871I;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G
M:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4VEM8F]L(&AU<G5F
M(&)E<V%R(')O;6%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S
M92!#=7)R96YT.B`E<R(*;7-G<W1R(")&87-E(%-E:V%R86YG(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G
M:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B1W5N86MA;FQA:"!J:6MA
M(&YA;6$O<V%N9&D@86YD82!B97)B961A('5N='5K('-E<G9E<B!)35-0+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z
M>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B4&5N9V=U;F$B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%S:2!096YG9W5N82(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"B,L(&9U>GIY
M"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B4VEM<&%N(%!I;&EH86XB
M"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*
M;7-G<W1R(")096YD869T87)A;B!096YG9W5N82(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(E!E;F1A9G1A<F%N(%!E;F=G=6YA
M('-U9&%H(&1I;F]N+6%K=&EF:V%N('5N='5K('-I=&4@:6YI+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N
M;W0@9F]U;F0B"FUS9W-T<B`B06-C;W5N="!096YG9W5N82!T:61A:R!D:71E
M;75K86XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*
M;7-G<W1R(").86UA(%!E;F=G=6YA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M
M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM
M<V=S='(@(DYA;6$@4&5N9V=U;F$Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(").86UA(%!E
M;F=G=6YA.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*
M;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E!E;F=G=6YA
M(&1I(&1A;&%M('-I<W1E;3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*(RP@9G5Z
M>GD*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(E-U8F1I<F5K=&]R:2`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*
M;7-G<W1R("),:6)U<F%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C,X"B,L(&9U>GIY"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")+96QE;6)A
M8F%N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS
M9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED
M(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R
M(")687)I86)L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"B,L(&9U>GIY
M"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<G-I($MO;G1R;VPB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O
M;G1R;VPB"FUS9W-T<B`B5F5R<VD@2V]N=')O;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L(&%L:6=N(@IM<V=S='(@(DIA<F%K('!O<VES:2!V97)T:6MA;"!A
M;G1A<F$@9V%R:7,@9&%S87(@9&5N9V%N(&=A;6)A<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I
M8V%L('!A9&1I;F<B"FUS9W-T<B`B2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N
M=&%R82!B;W)D97(@9&5N9V%N(&=A;6)A<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*
M;7-G<W1R(")697)T:6MA;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(E-A
M;F=A="!4:6YG9VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M("A625-#24DI
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G92(*;7-G<W1R("),:6AA="!W96(@<&%G92!E:W-T97)N86PB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I
M9"`B5FES:6)I;&ET>2(*;7-G<W1R(")*87)A:R!086YD86YG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET
M>3H@(@IM<V=S='(@(DIA<F%K(%!A;F1A;F<Z(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O
M9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E!%
M4DE.1T%404XA(2$@4$E.1$%(2T%.(%-#4DE05"!)3DD@4T5#05)!($U!3E5!
M3"!$05))("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS
M9VED(")787)N:6YG(@IM<V=S='(@(E!E<FEN9V%T86XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*
M;7-G<W1R(")286)U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(E)A;6%L86X@
M0W5A8V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS
M9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B1&%T82!#
M=6%C82!D:7-E9&EA:V%N(&]L96@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.3(*(RP@9G5Z>GD*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@
M(G=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G
M:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R(")796(@4VET92(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(E=E96ML>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")396QA;6%T
M($1A=&%N9R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE('1O("5S(@IM<V=S='(@(E-E;&%M870@9&%T86YG(&ME("5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O
M;64L("5S(@IM<V=S='(@(E-E;&%M870@9&%T86YG+"`E<R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M*2(*;7-G<W1R(")797-T97)N("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB
M"FUS9W-T<B`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS
M9W-T<B`B07!A:V%H(&%P;&EK87-I("5S('!E<FQU(&1I=&%M<&EL:V%N('-E
M=&5L86@@;&]G:6X_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM
M<V=S='(@(D%P86MA:"!Y86YG(&UE<G5P86MA;B!B871A<R!K87)A:W1E<C\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")!<&%K86@@>6%N
M9R!M97)U<&%K86X@:V%R86MT97(@:6YD96YT87-I/R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R
M96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B1F%S92!Y
M86YG(&UA;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(E!L=6=I;B!M86YA:V%H('EA;F<@9&%P870@9&EA
M:W1I9FMA;B!U;G1U:R!E9&ET;W(@4FEC:"!497AT+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(DQE8F%R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R-0HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S
M(@IM<V=S='(@(DQE8F%R('5N:70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.B(*;7-G<W1R("(B"B),96)A<B!M96YU("5S('!A9&$@8F%G:6%N(&MI<FD@
M*&%K86X@8F5R<&5N9V%R=6@@<&%D82!L;V=I;B!B97)I:W5T;GEA*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS
M9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B3&5B87(@=&%B96PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("),96)A<B!U;FET(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G
M:60@(E=I9'1H.B(*;7-G<W1R("),96)A<CHB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S
M='(@(D%N9VEN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B06YG:6X@9&D@
M<&%G:2!H87)I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")+96-E<&%T86X@86YG:6X@
M9&D@9&%L86T@:VYO="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS
M9VED(")7:6YD.B(*;7-G<W1R(")!;F=I;CHB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B06YG
M:6XZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D
M;VTB"FUS9W-T<B`B2V%T82!":6IA:W-A;F$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")$869T
M87(@2V5I;F=I;F%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS
M9VED(")7;W)K(@IM<V=S='(@(E!E:V5R:F%A;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B
M5V]R:R!!9&1R97-S(@IM<V=S='(@(D%L86UA="!%;6%I;"!!;F1A(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I
M9"`B5V]R:R!0:&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@
M:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@
M)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B
M"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I
M9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS
M9VED(")965E9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(EEA+"!305E!(%-%
M5%5*52(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R
M("(B"B)!;F1A(&)E<F%D82!D:2!D86QA;2!-3T1%(%1%2U,N($=U;F%K86X@
M=&]M8F]L(%L\/ET@=6YT=6L@;65N9V=A;G1I(&ME;6)A;&D@(@HB:V4@9&%L
M86T@;6]D92!765-)5UE'+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")!;F1A
M('1I9&%K(&1I:7II;FMA;B!U;G1U:R!M96UB=6%T(&QE8FEH(&1A<FD@)60@
M87)E82XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9
M;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY
M"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N(@IM<V=S='(@(E!E;F=G86YT:2!A;&%M870@96UA:6PB"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E
M9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)!;F1A(&AA<G5S
M(&UE;FIE;&%S:V%N(&UA<V%L86@@<V5B96QU;2!A;F1A(&1A<&%T(&UE;F=I
M<FEM:V%N(&QA<&]R86X@(@HB;6%S86QA:"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B06YD82!H87)U<R!M96UA<W5K:V%N(%523"!D:6UA;F$@;&EN:R!I;FD@
M;65N=6YJ=6L@:V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX
M,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R(")!;F1A(&AA<G5S(&UE;6EL:6@@<V5R=F5R('5N='5K
M(&1A<&%T(&1I:&%P=7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*
M;7-G<W1R(")!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!Y
M86YG(&EN9VEN(&1I8F5R<VEH:V%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`B06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U
M;F$@>6%N9R!I;F=I;B!D:7!I;F1A:&MA;BXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T
M<B`B06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@=6YT=6L@
M9&ET86UB86@N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(D%N9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('5N='5K(&1I
M<&5R8F%H87)U:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B06YD82!H87)U<R!M
M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@>6%N9R!I;F=I;B!D:7!I;F1A:&MA
M;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+B(*;7-G<W1R(")!;F1A(&AA<G5S(&UE;F5T87!K86X@
M;F%M82!P96YG9W5N82!Y86YG(&EN9VEN(&1I<&EN9&%H:V%N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S
M"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@
M16UA:6P@061D<F5S<R(*;7-G<W1R(")!;&%M870@16UA:6P@06YD82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@
M861D<F5S<SHB"FUS9W-T<B`B06YD82!$87)I.B!A;&%M870Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN
M9F]R;6%S:2!!;F1A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(").
M86UA($%N9&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S
M+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@
M8F%C:V5N9"XB"FUS9W-T<B`B(@HB0F%C:V5N9"!A<VQI(&%N9&$@=&ED86L@
M9&%P870@;65N9'5K=6YG('!E;F%M8F%H86X@<&5N9V=U;F$L(&%T874@9FET
M=7(@:6YI("(*(G-U9&%H(&1I;F]N+6%K=&EF:V%N('5N='5K(&)E8F5R87!A
M(&%L87-A;B!L86EN+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+B(*;7-G<W1R("(B"B)"86-K96YD(&%S;&D@86YD82!T:61A:R!D87!A="!M
M96YD=6MU;F<@<&5N9&%F=&%R86X@<&5N9V=U;F$L(&%T874@9FET=7(@:6YI
M("(*(G-U9&%H(&1I;F]N+6%K=&EF:V%N('5N='5K(&)E8F5R87!A(&%L87-A
M;B!L86EN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92XB"FUS9W-T<B`B0G)O=W-E<B!A;F1A('1I9&%K(&UE;F1U
M:W5N9R!U;G1U:R!F:71U<B!I;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)"
M<F]W<V5R(&%N9&$@=&ED86L@;65N9'5K=6YG('!I;&EH86X@=6YT=6L@;65N
M8V5T86LN(%1E:V%N($-O;G1R;VPO4&EL:6AA;B`K("(*(E`@=6YT=6L@;65N
M8V5T86LN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B
M66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B6F]N82!786MT=2!!
M;F1A(%-E:V%R86YG.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@IM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM
M<V=S='(@(D1E9F%U;'0@:61E;G1I=&%S(&%N9&$@<W5D86@@9&EU8F%H+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`B1&5F875L="!I9&5N=&ET87,@86YD
M83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9;W5R
M(&9U;&P@;F%M93HB"FUS9W-T<B`B3F%M82!L96YG:V%P(&%N9&$Z(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`IM<V=I9"`B66]U<B!L;V=I
M;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")386YD:2!B87)U(&%N
M9&$@=6YT=6L@)7,@861A;&%H.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N(@IM<V=S='(@(D1E9F%U;'0@:61E;G1I=&%S(&%N9&$@<W5D86@@9&EU
M8F%H+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E-A;F1I
M(&%N9&$@<W5D86@@9&EA='5R('5L86YG(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)386YD:2!A;F1A('-U
M9&%H(&1I871U<B!U;&%N9RP@<&5R:6MS86QA:"!E;6%I;"!A;F1A(&1A;B!L
M;V=I;B!D96YG86X@(@HB;65N9V=U;F%K86X@<V%N9&D@8F%R=2!A;F1A(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"B,L(&9U>GIY"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")386YD:2!A
M;F1A('-U9&%H(&1I871U<B!U;&%N9R(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS
M9W-T<B`B4F5M;W1E('-E<G9E<B!A;F1A.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B6F%I<F4B
M"FUS9W-T<B`B0V5R86@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED("):
M:7!P>2(*;7-G<W1R(")#97)I82(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U
M;W1E9"!497AT72(*;7-G<W1R(");4V5M8G5N>6EK86X@26YD96YT87-I(%1E
M:W-=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B
M;&5M(%)E<&]R=%TB"FUS9W-T<B`B6TQA<&]R86X@36%S86QA:%TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");5&%M<&EL86X@26YD96YT
M87-I(%1E:W,@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@
M(EM486UP:6QA;B!);F1E;G1A<VD@5&5K<R`M(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(EML:6YE("5S(&]F("5S72(*;7-G<W1R("(E<R!U;G1U:R`E<R`E<R(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B7T%D;6EN:7-T<F%S:2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R(")(87!U<R!"87)I<R(*"B,Z(&QI8B]A
M<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<"(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*
M;7-G:60@(E](96QP(@IM<V=S='(@(D)A;G1U86XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@
M(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!E<G1I($=A;6)A
M<BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B3&]G:6XB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS
M9VED(")?3&]G(&]U="(*;7-G<W1R("),;V<@;W5T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED
M(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B56)A:"!,:6YK+BXN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM
M<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B4&EL:6AA;B(*"B,Z(&QI8B]A<&DN
M<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")0:6YD86AK
M86X@3&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P
M(@IM<V=S='(@(E]3971U<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B4')O<&5R=&D@5&%B96PN+BXB"@HC.B!L:6(O
M87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")096YG9W5N82(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS
M9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B0G5K=2!!;&%M870@(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D
M9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G
M<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A
M;&TB"FUS9W-T<B`B5&5N86YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R
M<F]R(@IM<V=S='(@(E!E<F)E9&%A;B!+;VYF:6=U<F%S:2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A
M;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA
M="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD
M(@IM<V=S='(@(D%C8V]U;G0@4&5N9V=U;F$@=&ED86L@9&ET96UU:V%N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(F9A;&QI;F<B"FUS9W-T<B`B:F%T=6@B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS
M9W-T<B`B5&ED86L@9&EA<G-I<&MA;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,B"FUS9W-T<B`B1&%R:2`E<R`H)7,I('!A9&$@)7,@)7,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G
M=7-T:6YG(@IM<V=S='(@(F%N9VEN(&ME;F-A;F<B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")M87-I:"!D:2!D
M86QA;2!A;G1R:6%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I
M9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI
M;F5S72(*;7-G<W1R(")B87)I<UTB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S
M,@IM<V=I9"`B;F%M92(*;7-G<W1R(")N86UA(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM
M<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0HC+"!F=7IZ>0IM<V=I9"`B;F]T
M97!A9"(*;7-G<W1R(")T971A<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS
M9W-T<B`B<&5R<V5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(DEZ:6X@=6YT=6L@7"(E<UPB('1I9&%K(&1A<&%T(&1I:&%P=7,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T
M92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM
M<V=S='(@(FYA:6LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$T,@HC+"!F=7IZ>0IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*
M;7-G<W1R(")!<F5A($UE=&%R('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E
M<R(*;7-G<W1R(")T86UP:6QK86X@<&5R8F5D86%N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M
M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G1E=&%P(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C
M<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"FUS9VED(")T<GD@
M86=A:6XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")+971I:R!S86YD
M:2!D=6$@:V%L:2!U;G1U:R!M96YG:V]N9FER;6%S:2(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(FUE;GEA='5K86XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U!A<G0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")U;FYA;65D
M(@IM<V=S='(@(FYA;6$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(G5S97(@
M<V5L96-T(@IM<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@
M(G9#87)D(@IM<V=S='(@(DMA<F%K=&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E
M871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]R;U]23RYP;P``````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C$Q
M-3(Q`#$P-3$U-#,Q,#8S`#`Q-C0Q,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C($AO<F1E(%)O;6%N:6%N('1R86YS;&%T
M:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,B!(;W)D92!0<F]J96-T+@HC($-O
M<FYE;&EU($U54T%4(#QC;75S871`:V5Y<WES+G)O/BP@,C`P,BX*(PIM<V=I
M9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2$]21$4@,BXQ
M7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P
M,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP."TP,2`P.3HS-"LP,CHP
M,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!#;W)N96QI=2!-55-!5"`\8VUU<V%T
M0&ME>7-Y<RYR;SY<;B(*(DQA;F=U86=E+51E86TZ(%)/34%.24%.(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS
M9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E
M<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S
M='(@(B<E<R<@;G4@97-T92!C;VYF:6=U<F%T(&EN($AO<F1E(%)E9VES=')Y
M(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E
M+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($]P97)A=&EU;FD@9&4@;65N=&5N
M86YT82`M($-O;F9I<FUA<F4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C
M:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")":69A=&D@;W!E<F%T
M:75N*&5A+VEL92D@<&4@8V%R92!D;W)I=&D@<V$@;&4@9F%C971I(&%C=6TN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;6EN=71E<R(*;7-G<W1R("),82!F:65C87)E(#4@;6EN=71E(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(EML
M:6YI82`E<R!D:6X@)7-=(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S
M<R!";V]K(@IM<V=S='(@(D%G96YD82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.
M;W1E<&%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S
M.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US
M('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I
M="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA
M;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E
M;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*
M(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(DEN9F]R
M;6%T:6D@9&5S<')E('1I;F4B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*
M(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(DEN9F]R
M;6%T:6D@9&5S<')E('1I;F4B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@9&4@;W)E(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED
M(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38P"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E
M9"(*;7-G<W1R("(\8CY!(&%P87)U="!O(&5R;V%R92!F871A;&$Z/"]B/B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED
M(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S
M"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-
M+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O
M=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@
M(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I
M9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA=&EI(&1E
M<W!R92!T:6YE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"B,L(&9U
M>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!
M9&0B"FUS9W-T<B`B061R97-A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@
M861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T
M<B`B061R97-A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O
M=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M
M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")!9&%U9V$@<&5R96-H96$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ
M(@IM<V=S='(@(D%G96YD82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R(")!9V5N9&$B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,0HC+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B061A=6=A
M('!E<F5C:&5A(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B
M"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM
M<V=I9"`B061D<F5S<R(*;7-G<W1R(")!9')E<V$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`B06=E;F1A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S
M"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS
M9W-T<B`B061R97-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI
M82(*;7-G<W1R(")!;&EA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@
M(D%L9V5R:6$B"FUS9W-T<B`B06QI87,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R
M(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S='(@
M(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*
M;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R
M;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U
M"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G
M<W1R(")!9')E<V$@=&$@9&4@16UA:6PZ(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")3+6$@<W!E8VEF:6-A="!O
M('9A;&]A<F4@:6YC;W)E8W1A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N(@IM<V=S='(@(CQB/D$@87!A<G5T(&\@97)O87)E(&9A
M=&%L83H\+V(^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R
M;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO
M;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@
M=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM
M<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@
M(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G
M:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A
M;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N
M:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G
M:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED
M(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P
M,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*
M;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS
M9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#:6UP=7)I(&1I<W!O
M;FEB:6QE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(
M($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A
M9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S
M97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I
M8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R
M8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H
M=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")::75A
M(&1E(&YA<W1E<F4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C
M:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B3F]T:69I8V%T:6]N(&QI<W1E;F5R("5S(&YO="!F;W5N9"X@+2!D
M92!T<F%D=7,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC
M+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B
M0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM
M<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM
M<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM
M<V=I9"`B0G)A>FEL(@IM<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@
M(D-64R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S4*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0
M;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G
M<W1R(")#86QE;F1A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A
M;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T
M(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E
M($Q$05`N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*
M;7-G<W1R(")#86QE;F1A<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI
M;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B
M4F5N=6YT82!L82!287!O<G0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R
M9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D
M;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R
M9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*
M;7-G<W1R(")/<'1I=6YI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE
M<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM
M<V=S='(@(E1E;&5F;VX@36]B:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#
M96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B5&5L969O;B!-;V)I;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED
M(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@
M<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"B,L
M(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5&5L969O;B!-;V)I
M;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@
M*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y
M.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R
M=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B
M0VAA9"(*;7-G<W1R(")V0V%R9"`M(&1E('1R861U<R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R(")!;G5L
M96%Z82!38VAI;6)A<FEL92(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*
M;7-G:60@(D-H87(B"FUS9W-T<B`B=D-A<F0@+2!D92!T<F%D=7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM<V=S='(@(E1I=&QU(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM
M<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B
M0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA
M;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM
M<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F]T:69I8V%T:6]N(&QI<W1E;F5R
M("5S(&YO="!F;W5N9"X@+2!D92!T<F%D=7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE
M87(B"FUS9W-T<B`B0V%L96YD87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G
M:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R
M(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@
M(D-L96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@
M(DEN8VAI9&4@9F5R96%S=')A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L
M;&%P<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S
M960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO
M;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI
M8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B
M0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F
M=7IZ>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#;VUP86YI82(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*
M;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B0V]M<&%N:6$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"FUS9VED(")#
M;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M
M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U
M="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q
M"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!A
M<F]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B0V]N=&EN=71U
M;"!L=6D@)R5S)R`M(&1E('1R861U<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM
M<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F
M=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;VUP86YI82(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B0VEM<"!I;7!O<G1A
M=#H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S
M="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U
M,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R
M,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E
M($Q$05`N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B
M0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA
M;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P
M('-E<G9E<B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U
M;"!D92!,1$%0+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@
M7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I
M8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS
M9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<R(*;7-G<W1R(").=2!P;W0@9&5S8VAI9&4@;6]D=6QU;"!D92!-96YT
M96YA;G1A("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(").=2!P;W0@9&5S8VAI9&4@;6]D=6QU;"!D92!-96YT
M96YA;G1A("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&YU(&5S
M=&4@8V]N9FEG=7)A="!C;W)E<W!U;GIA=&]R(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O
M<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F
M;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I
M9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O
M=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*
M;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS
M9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE
M+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED
M(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("):6B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H
M<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I
M;'DB"FUS9W-T<B`B6FEL;FEC(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U
M"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G
M:60@(D1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R
M"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B6FEL;FEC(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V
M"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E
M9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R("))
M9&5N=&ET871E($EM<&QI8VET82(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT
M($-O;&]R(@IM<V=S='(@(E5T:6QI>F5A>F$@5F%L;W)I($EM<&QI8VET92(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@
M(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I=&%T92!);7!L:6-I
M=&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B261E;G1I=&%T92!);7!L:6-I
M=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN
M:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE
M=&4@1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R
M;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT
M:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y(@IM<V=S='(@(DED96YT:71A=&4@26UP;&EC:71A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@
M=&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y
M"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")$97-C<FEE
M('!R;V)L96UA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*
M(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:65R
M92!C;VUP;&5T83HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM
M<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B1&5T86QI:2!I;G)E9VES=')A=&4@:6X@3$]'
M('!E;G1R=2!A9&UI;FES=')A=&]R+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V
M"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(D]P=&EU;FD@9&4@069I<V%R92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA
M>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")/<'1I=6YI(&1E($%F:7-A
M<F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y
M(&9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T
M(@IM<V=S='(@(D]P=&EU;FD@9&4@069I<V%R92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF
M:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T
M:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(E1E(')O9R!N=2!A
M8V-E<V$@9&ER96-T(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H
M879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO
M860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@
M(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I
M<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED
M(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W
M:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@
M(D5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS
M(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N
M86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I
M;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A
M;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R(")%;6%I;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")!9')E<V$@=&$@9&4@16UA:6PZ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S
M<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N
M9FER;6%T:6]N(@IM<V=S='(@(D%L=&4@:6YF;W)M871I:2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%
M;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"B,L(&9U>GIY"FUS9VED
M(")%;6]T:6-O;G,B"FUS9W-T<B`B3W!T:75N:2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM
M<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B16UP='D@<F5S=6QT+B`M
M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B
M16UP='D@<F5S=6QT+B`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS
M9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N
M9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*
M(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@
M87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN
M96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<F]A<F4B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O
M;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN
M9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W
M:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R
M(")/(&1A=&$@;&$@,34@;6EN=71E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S
M='(@(DQA(&9I96-A<F4@-2!M:6YU=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B3R!D871A(&QA(#,P('-E8W5N9&4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("),
M82!F:65C87)E(#4@;6EN=71E(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`B3&$@9FEE8V%R92!#;VYE8W1A<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B3R!D
M871A(&QA(#,P(&UI;G5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(DEN(&9I96-A<F4@;6EN=70B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM
M<V=S='(@(D5X96UP;&4@9&4@=F%L;W)I.B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN
M<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM
M<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(").=2!P;W0@8VET:2!P
M<F5F97)I;G1E;&4N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").
M=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B3G4@
M;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T
M<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(DYU(&UA('!O
M="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B3G4@<&]T(&-I
M=&D@<')E9F5R:6YT96QE+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*(RP@9G5Z>GD*
M;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%<F]A<F4@9&4@:6YT<F%R
M93HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T
M<B`B1F%X(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E
M96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*
M;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED
M(")&:6QE(@IM<V=S='(@(E1I=&QU(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS
M9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G
M<W1R(").=6UE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM
M<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS
M9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@
M2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED
M(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S
M-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U
M<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC
M+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B3F]T92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED
M(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S
M='(@(DYU;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@
M(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO
M;B(*;7-G<W1R(")$97-C<FEE<F4@8V]M<&QE=&$Z(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ
M>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DYU;65L92!T874Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS
M9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S
M($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I
M9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")'
M;V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<P"B,L(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B06=E;F1A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I
M=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B
M2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/
M+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W
M.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN
M8SHS"FUS9VED(")(96QP(@IM<V=S='(@(DAE;'`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S
M:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&5L
M<"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I
M<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B
M2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z
M>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"B,L(&9U
M>GIY"FUS9VED(")(;VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D
M9')E<W,B"FUS9W-T<B`B061R97-A(&1E(&%C87-A(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VYU;"!D92!A
M8V%S82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S
M<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS
M9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO
M;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@
M(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(
M=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(D%D<F5S
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G
M:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/
M;FQY(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M
M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O
M;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO
M=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0
M<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS
M9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B0VEM<"!I;7!O<G1A
M=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M0VEM<"!I;7!O<G1A=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(D-I;7!U
M<FD@:6UP;W)T871E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(")492!R;V<@:6YT
M<F]D=2!U;B!N=6UE(&1E('5T:6QI>F%T;W(@<VD@;R!P87)O;&$B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R
M96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A
M;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@9G5Z>GD*;7-G:60@(DEN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%T:6D@9&5S<')E('1I;F4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"
M969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*
M;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C
M96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL
M(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("))
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B
M26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U
M8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I9"`B26YV86QI9"!P87)T;F5R
M(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@
M;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O
M9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN
M=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F
M=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B6FEL;FEC(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E
M("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@
M9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO
M="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED
M(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S
M=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE
M9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R
M:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B365S
M86HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G
M:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS
M9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER
M:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N
M("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W
M86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*
M;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B3&EM8F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO
M9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R(")$96-O;F5C=&%R92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),
M969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R
M(")%>&5M<&QE(&1E('9A;&]R:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE
M<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(").:6-I;V1A
M=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ
M>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")#;VYE8W1A<F4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B
M3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM
M<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R(")#
M;VYE8W1A<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED
M("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I
M9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L
M<"!4;W!I8W,B"FUS9W-T<B`B3&ES=&$@<W5B:65C=&5L;W(@9&EN($AE;'`B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS
M9VED("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES=&$@<W5B:65C=&5L;W(@9&EN
M($AE;'`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A
M9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U
M"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3<R
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@
M:6XB"FUS9W-T<B`B0V]N96-T87)E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B1&5C;VYE8W1A<F4B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO
M9VEN(@IM<V=S='(@(D-O;F5C=&%R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@
M(E-A<F-I;FDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*(RP@
M9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S
M='(@(B(*(E!R;V)L96UA(&-U($-O;F5C=&%R96$N(%!R;V)A8FEL(&YU;65L
M92!D92!5=&EL:7IA=&]R('-A=2]S:2!087)O;&$@<VEN="`B"B)G<F5S:71E
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B
M1&5C;VYE8W1A<F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G
M:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("),3"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS
M9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!
M9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA
M=VDB"FUS9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QD:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G
M:60@(DUA;&DB"FUS9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B0V]R97-P;VYD96YT
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN
M9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(D%T96YT:64B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM
M<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS
M9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H
M86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-
M87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B0VEM
M<'5R:2!P;W1R:79I=&4@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E
M9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUE;6)E
M<G,B"FUS9W-T<B`B3F]T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B
M365R9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B
M"FUS9W-T<B`B365S86HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S
M9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@
M8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")-97-A:B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")-
M97-A:B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B
M(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B1&5T
M86QI:2!I;G)E9VES=')A=&4@:6X@3$]'('!E;G1R=2!A9&UI;FES=')A=&]R
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@
M(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F
M<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D
M;&4B"FUS9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(D5R;V%R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN
M9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@
M:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I
M;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I
M9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I
M9"`B36]N=&AL>2(*;7-G<W1R("),=6YA<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W
M,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H
M92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L
M>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@
M(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G
M:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM
M<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA
M=&EI(&1E<W!R92!T:6YE(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS
M9W-T<B`B3G5M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E
M(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(").979E<B(*;7-G<W1R(").:6-I;V1A=&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE
M=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W
M(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S
M=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O
M;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA
M;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@(DYO=&4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S
M9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I9"`B3F5X
M="!O<'1I;VYS(@IM<V=S='(@(DEN87!O:2!L82!O<'1I=6YI(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS9W-T
M<B`B3FEC:6]D871A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*
M;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL
M86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F
M;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@
M(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(").=2!E<W1E(&-O;F9I9W5R871A(&%U=&5N=&EF:6-A<F5A(%-13"(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").
M;R!C:&%N9V4N(@IM<V=S='(@(D%N=6QE87IA(%-C:&EM8F%R:6QE(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T
M:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G
M<W1R(").=2!E<W1E(&-O;F9I9W5R871A($-A=&5G;W)I82!344PB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(DYU('-I;G0@8V]N9FEG=7)A=&4@4')E9F5R:6YT
M96QE($Q$05`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(DYU(&5S=&4@8V]N9FEG
M=7)A=&$@0V%T96=O<FEA(%-13"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,3<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM
M<V=S='(@(DYU(&5S=&4@8V]N9FEG=7)A=&$@0V%T96=O<FEA(%-13"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED
M(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE
M('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").
M;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").
M;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").=2!E<W1E(&-O;F9I9W5R871A(&%U=&5N=&EF
M:6-A<F5A(%-13"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYU(&5S=&4@8V]N
M9FEG=7)A=&$@875T96YT:69I8V%R96$@4U%,(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C@T"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M=2!E<W1E(&-O;F9I9W5R871A(&%U=&5N=&EF:6-A<F5A(%-13"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B3F]T92(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B3F]T92(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I
M9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(E1E(')O9R!I;G1R;V1U('5N
M(&YU;64@9&4@=71I;&EZ871O<B!S:2!O('!A<F]L82(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@
M9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDS"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(E1E;&5F;VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y
M+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@
M27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-
M87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").;W)W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B
M3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N
M=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S
M='(@(DYO=&4B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V
M-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3<X"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1E(@H*(SH@<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R
M(@IM<V=S='(@(DYI8VEO9&%T82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").=6UE
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M
M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O
M9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS
M9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C
M="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*
M;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S
M=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O
M;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W
M;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S
M:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/
M<'1I;VYS(@IM<V=S='(@(D]P=&EU;FDB"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P=&EU
M;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/
M<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")!;'1E(&EN9F]R;6%T:6DB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0
M($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")0
M2%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H
M="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I
M9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R(")087)O;&$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R(")087)O;&$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")087)O;&$B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")087)O;&$B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S
M=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@
M(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*
M;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS
M9W-T<B`B4F]L92`M(&1E('1R861U<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B
M"FUS9W-T<B`B17AE8W5T82!/<&5R871I=6YI;&4@9&4@365N=&5N86YT82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@9G5Z>GD*;7-G:60@
M(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS
M9W-T<B`B17AE8W5T82!/<&5R871I=6YI;&4@9&4@365N=&5N86YT82(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T
M(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP
M:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!);F9O
M<FUA=&EO;B(*;7-G<W1R(")!;'1E(&EN9F]R;6%T:6DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B
M4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED
M(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ
M,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU
M;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM
M87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")492!R;V<@<W!E8VEF:6-A
M('5N('-U;6%R(&%L('!R;V)L96UE:2XB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G
M:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M(@IM<V=S='(@(E1E(')O9R!I;G1R;V1U('5N(&YU;64@9&4@=71I;&EZ871O
M<B!S:2!O('!A<F]L82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9
M;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y
M<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS
M9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP
M:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S
M96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM
M<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED
M(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(DEN87!O:2!L82!O<'1I=6YI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(EM287!O
M<G0@4')O8FQE;6%=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS
M9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:65R96$@
M<')O8FQE;65I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM
M<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T
M97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC
M($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR
M-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E%A=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A
M:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM
M<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N
M;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<V"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC
M+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(")-97-A:B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G
M:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@
M9G5Z>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E)E
M:6UP<F]S<&%T96%Z82!3=6UA<G5L("T@9&4@=')A9'5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B
M4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@
M(E)E;6]T92!397)V97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S
M='(@(E-T97)G92!P97)E8VAE82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S
M='(@(E-T97)G92!P97)E8VAE82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS
M9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E-T97)G
M92!P97)E8VAE82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G
M:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(E-T
M97)G92!P97)E8VAE82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S
M97(Z("5S(@IM<V=S='(@(E-T97)G92!P97)E8VAE82(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED
M(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G=6ED)R!N97-P96-I9FEC870@:6X@
M8V]N9FEG=7)A=&EA(&1E('!R969E<FEN=&4N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B=U:60G
M(&YE<W!E8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@<')E9F5R:6YT92XB
M"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B=U:60G(&YE<W!E8VEF:6-A
M="!I;B!C;VYF:6=U<F%T:6$@9&4@<')E9F5R:6YT92XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D
M($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS
M9VED(")297-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS
M9W-T<B`B4&%R;VQA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U
M97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED
M(")297-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B
M4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B26YA<&]I(&QA(&]P=&EU;FDB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E
M='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E
M=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<R(*;7-G<W1R("));F%P;VD@;&$@;W!T:75N:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED
M(")2:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R
M(")2;VQE("T@9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M
M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*
M;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2
M:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM
M<V=I9"`B4G5L97,B"FUS9W-T<B`B4F]L92`M(&1E('1R861U<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D
M97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N
M9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G
M:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F
M=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-97-A:B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@
M(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N
M="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F
M<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-
M87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O
M;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX
M"FUS9VED(")3879E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS
M9W-T<B`B4V%L=F%Z82!/<'1I=6YI(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E-A;'9A>F$@
M3W!T:75N:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@
M(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*
M;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE
M8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R(")&;W)M871U;"!D92!A9FES87)E(&$@9&%T96DZ(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C
M="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS
M9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@
M861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(D9O<FUA
M='5L(&1E(&%F:7-A<F4@82!D871E:3HB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J
M96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B
M(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O
M>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE
M;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(D%L96=E(&-A<F%C
M=&5R96QE(&1E(&-A<F4@86D@;F5V;VEE(&1I;B!C87-U=&5L92!D92!M86D@
M:F]S+B!696D@<'5T96$@87!O:2`B"B)S82!L92!C;W!I97II(&EN('IO;F$@
M9&4@=&5X="XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B1&5L:6UI
M=&%T;W(@9&4@9&%T83HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B1F]R
M;6%T=6P@9&4@869I<V%R92!A(&1A=&5I.B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B1&5L:6UI=&%T;W(@9&4@
M9&%T83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B
M4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B1F]R;6%T=6P@9&4@
M869I<V%R92!A(&]R96DZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S
M='(@(E-E;&5C=&5A>F$@9&]U82!C:6UP=7)I('!O=')I=FET92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93HB"FUS9W-T<B`B4V5L96-T96%Z82!L:6UB82!P<F5F97)A=&$Z(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`B5')I;6ET92!287!O<G0@9&4@17)O
M87)E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")3
M97!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO
M;G,B"FUS9W-T<B`B4V%L=F%Z82!/<'1I=6YI(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N(@IM<V=S='(@(D%L96=E('1I;7!U;"!D92!R96EM<')O<W!A
M=&%R92!A('!A9VEN:6D@<VD@86QT92!O<'1I=6YI(&1E(&%F:7-A<F4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B06QE9V4@=&EM<'5L(&1E(')E:6UP<F]S<&%T87)E(&$@
M<&%G:6YI:2!S:2!A;'1E(&]P=&EU;FD@9&4@869I<V%R92XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I
M9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*
M;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(E-U;6%R('-C=7)T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED
M(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM
M<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN
M('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM
M<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R
M"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E
M;F%N8V4B"FUS9W-T<B`B4V%R:2!P97-T92!-96YT96YA;G1A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*
M;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D%D
M<F5S82!L82!397)V:6-I=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H
M($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B
M4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P
M86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B0V%R86-T97)E(%-P96-I86QE
M("XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R("));7!O<G0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B
M0V%L96YD87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@
M(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@
M(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M
M870B"FUS9W-T<B`B26YF;W)M871I:2!D97-P<F4@=&EN92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED
M(")3=')E970@061D<F5S<R(*;7-G<W1R(")!9')E<V$@;&$@4V5R=FEC:74B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(DYO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N;W0@
M9F]U;F0N("T@9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T
M<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5C8V5S(@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM
M<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E
M;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E-U;6%R=6P@
M365U(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@
M4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*
M;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@
M(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U
M;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G
M:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@
M9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B26UP;W)T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B571I
M;&EZ871O<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E5T:6QI>F%T
M;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3
M=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T
M<B`B5&ET;'4B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC
M+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&ET;'4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE
M(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(E-A<F-I
M;FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM
M<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@
M(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S
M*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]4
M96UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X
M="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG
M('1H92!S>7-T96TN(@IM<V=S='(@(D%I(&9O<W0@9&5C;VYE8W1A="X\8G(@
M+SY-=6QT=6UE<V,@8V$@9F]L;W-E<W1I('-I<W1E;75L+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U3
M4"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L
M9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!0
M97)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O
M;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B
M87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I
M;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H
M<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F
M;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS
M9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B
M"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!'
M;G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@
M8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.
M+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@
M<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N
M(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4
M:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T
M(&)E(&YU;65R:6,N(@IM<V=S='(@(D%C96%S=&$@=F%L;V%R92!T<F5B=6EE
M('-A(&9I92!N=6UE<FEC82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C
M:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS
M9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T
M97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*
M;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(DYU(&5X:7-T82!P<F5F97)I;G1E(&1I<W!O;FEB:6QE
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E
M<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C
M="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM
M8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O
M=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+B(*;7-G<W1R(")!8V5A<W1A('9A;&]A<F4@=')E8G5I92!S82!F:64@
M;G5M97)I8V$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z
M+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@
M;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*
M(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM
M<V=S='(@(D%C96%S=&$@=F%L;V%R92!T<F5B=6EE('-A(&9I92!N=6UE<FEC
M82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B
M"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE
M(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I
M9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@
M=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(E9A;&]A<F5A(&UI;FEM82!E<W1E
M(#$B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z
M-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N
M9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@
M8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")!8V5A<W1A('9A;&]A<F4@=')E
M8G5I92!S82!F:64@;G5M97)I8V$N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E1I=&QU(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4
M<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*
M;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM
M<V=S='(@(E1I=&QU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<U"FUS9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED
M(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O
M;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@
M(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED
M(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYU(&UA('!O="!C;VYE
M8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3G4@;6$@
M<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HX,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYU(&UA('!O="!C
M;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@S.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=VET:"!34TPN(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E
M<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@
M4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYU(&UA('!O
M="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DYU
M(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@
M4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R(").=2!P;W0@:6YR96=I<W1R82!P<F5F97)I;G1E
M;&4@:6X@<V5S:75N92`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C
M="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-
M4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S
M='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S
M='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM
M<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV
M-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-1
M3"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P
M,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0B"FUS9W-T<B`B3G4@<&]T('1R861U8V4@86-E<W0@9&]C=6UE
M;G0@5V]R9"`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R
M(")!;G5L96%Z82!38VAI;6)A<FEL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z
M-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED
M(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Y"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B
M"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@
M(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(E5T:6QI>F%T;W(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T
M<B`B3W!T:75N:2!5=&EL:7IA=&]R(@H*(SH@<VEG;G5P+G!H<#HV,@HC+"!F
M=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B3W!T:75N
M:2!5=&EL:7IA=&]R(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I
M9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5=&EL:7IA
M=&]R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E5T
M:6QI>F%T;W(B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L
M(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(E5T:6QI>F%T;W(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5
M<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G
M:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U
M"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N
M($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI
M9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y
M"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B071E;G1I92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G
M:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T
M:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R
M(")387!T86UI;F%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0FEN92!A:2!V
M96YI="P@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")":6YE(&%I('9E;FET(&EN('-I
M<W1E;75L("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)I;F4@86D@=F5N:70L("5S(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E
M<B!L;V=I;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM
M<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E
M>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED
M(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T
M86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM
M<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R
M"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S
M82!L82!397)V:6-I=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L
M969O;B!L82!397)V:6-I=2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE
M("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM
M<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X
M=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM
M<V=S='(@(D%!(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I
M9"`B665A<FQY(@IM<V=S='(@(D%N=6%L(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B665M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS
M9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9
M;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="XB"FUS9W-T<B`B3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T92XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I
M9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED
M(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B5')E8G5I92!S
M82!D97-C<FEI('!R;V)L96UA(&EN86EN=&4@9&4@82!T<FEM:71E(')A<&]R
M='5L+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*
M;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*
M;7-G<W1R(")397-I=6YE82!T82!D92`E<R!A(&5X<&ER870N(%1E(')O9R!S
M82!F86-I($QO9R!);B!D:6X@;F]U+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D
M9')E<W,B"FUS9W-T<B`B061R97-A('1A(&1E($5M86EL.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O
M;3H@861D<F5S<SHB"FUS9W-T<B`B061R97-A('1A(&1E($5M86EL.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R
M("));F9O<FUA=&EI(&1E<W!R92!T:6YE(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R(").=6UE;&4@=&%U.B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A
M=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS
M9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")/<'1I
M=6YI;&4@874@9F]S="!S86QV871E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>3HB"FUS9W-T<B`B261E;G1I=&%T92!);7!L:6-I=&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@
M;F%M93HB"FUS9W-T<B`B3G5M96QE('1A=3HB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")/<'1I=6YI;&4@874@9F]S="!S86QV871E
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-30*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T
M<B`B3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T92XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")/<'1I=6YI;&4@874@9F]S="!S
M86QV871E+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9
M;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O
M<G1=(@IM<V=S='(@(EM287!O<G0@4')O8FQE;6%=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6VQI
M;FEA("5S(&1I;B`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM
M<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE
M=&4@4F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B
M7T=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")?2&5L<"(*;7-G<W1R(")(
M96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT
M"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(D-O;F5C=&%R92(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z
M>GD*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(D1E8V]N96-T87)E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I
M9"`B7T]P=&EO;G,B"FUS9W-T<B`B3W!T:75N:2(*"B,Z(&QI8B]A<&DN<&AP
M.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC
M+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E-T97)G
M92!P97)E8VAE82(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!9V5N
M9&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM
M<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@
M9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*
M;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N
M;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U>GIY
M"FUS9VED(")F:6QE(@IM<V=S='(@(E1I=&QU(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*
M;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H
M;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM
M;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV
M-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R
M"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R
M;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@
M97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS
M9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G
M:60@(FYA;64B"FUS9W-T<B`B3G5M92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@
M(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P
M"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@
M9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")!=&5N=&EE(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I
M8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G
M:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O
M9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED
M(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L
M(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`B3&$@9FEE8V%R92!#
M;VYE8W1A<F4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U
M;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R
M="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S
M='(@(G9#87)D("T@9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H
M97(N8V]M(@IM<V=S='(@(B(*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O<VM?
M4TLN<&\`````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#<P,#`W,``Q,#4Q-30S,3`V,P`P,38T,#,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!(;W)D92!3;&]V86L@
M=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`R($QE;R!-<F%F:V\@
M/&QE;T!O96PN<VL^("AO<FEG:6YA;"!T<F%N<VQA=&]R*0HC("A#*2`R,#`R
M+"`R,#`S($EV86X@3F]R:7,@/'9I>$!V87IK82YS:SX*(PIM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#$M,#8@,30Z,3`K,#$P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,2TS,"`R,3HR-BLP,C`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($EV86X@3F]R:7,@/'9I>$!V87IK82YS:SY<;B(*
M(DQA;F=U86=E+51E86TZ(%-L;W9A:R`\=FEX0'9A>FMA+G-K/EQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X+6)I=%QN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AP
M<F5D("5S(&3R86UI*2(*"B,Z(&QI8B](;W)D92YP:'`Z,3,W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A+;.%V
M97-O=N$@<VMR871K82`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,X
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@
M(B`H;R`E<R!D;NTI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*;7-G
M:60@(B`H=&]D87DI(@IM<V=S='(@(BAD;F5S*2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*'IA
M:G1R82DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AY
M97-T97)D87DI(@IM<V=S='(@(B`H=NAE<F$I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G
M:60@(B!A="`B"FUS9W-T<B`B('+]8VAL;W.[("(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&YI92!J92!A9')E<^%R+B(*
M"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S
M7"(@;FEE(&IE('!L871NX2!V;[5B82XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T
M<GDN<&AP.C8U,B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&YI92!J92!N86MO
M;F9I9W5R;W9A;ND@=B!R96=I<W1R:2!(;W)D92XB"@HC.B!L:6(O2&]R9&4O
M5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B>F]B<F%Z;W9AZ"!S=')O
M;74@7"(E<UPB(&YE8F]L(&[A:F1E;OTN(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")3:W5P:6YA(%PB)7-<(B!B
M;VQA('!R:61A;N$@9&\@<WES=.EM=2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")0<N%V
M;R!<(B5S7"(@8F]L;R!P<FED86[I(&1O('-Y<W3I;74N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N
M(@IM<V=S='(@(EPB)7-<(B!N96)O;&\@;6^^;ND@=GET=F]R:;LZ("5S+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*
M;7-G<W1R(")0;W6^:73]8V@@)2XR9DU"('H@9&]V;VQE;OUC:"`E+C)F34(@
M*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E
M9"`E<R!A("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C8X(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@
M(B5D(&1N[2!D;R!V>7!RN6%N:6$@<&QA=&YO<W1I(%;AN6AO(&AE<VQA+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(G!R961P;W9E
M[R!N82`E9"!D;NTB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@
M+2!0;WINX6UK82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@
M(D]D=&QAZ&]K("5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C@T,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T
M<B`B3W!E<N%C:64@^F1ROF)Y('!R92!A<&QI:^%C:74@)7,@+2!0;W1V<F1E
M;FEE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P
M(@IM<V=S='(@(DYA<W1A=F5N:64@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P
M(@IM<V=S='(@(E)E9VES=')O=F%N:64@9&\@87!L:6OA8VEE("5S(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R(")0;V1M:65N:WD@
M<&]UOFET:6$@)7,B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#,R(&QI8B]61E,O
M<VUB+G!H<#HT.30@;&EB+U9&4R]F='`N<&AP.C8W,0HC.B!L:6(O5D93+V9T
M<"YP:'`Z-S,Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R("(E<R!UOB!E>&ES='5J92XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO
M8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L
M:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A="`E<R`E<R(*;7-G<W1R("(E<R!V;R!V_;EK92`E<R`E<R(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N(@IM<V=S='(@(B(*(D%P;&EKX6-I82`E<R!J92!P<FEP<F%V96[A
M(&YA('9Y:V]N86YI92!O<&5RX6-I[2#Z9'*^8GDN3WIN8>AT92"Y='9O<NAE
M:R!P<FD@(@HB;W!E<N%C:>%C:"P@:W1O<ND@8VAC971E('9Y:V]N8;L@=&5R
M87HN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B4&^^861U:F4@<V$@
M)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;OIT(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&YE8F]L(&[A:F1E
M;OTN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!A
MOB`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B061R
M97/A<B!P;W6^[79A=&6U82`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`B2V%L96YDX7(@<&]UONUV871EM6$@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B
M"FUS9W-T<B`B4&]Z;N%M:WD@<&]UONUV871EM6$@)7,B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDR.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A
M<VML:7-T(@IM<V=S='(@(EIO>FYA;2#Z;&]H('!O=;[M=F%T9;5A("5S(@H*
M(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@
M)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@HB)7,Z(%3A=&\@<W!RX79A(&YE;75S[2!B>;L@;V0@;V1O<VEE;&%T
M9;5A+"!K=&]R_2!S82!Z;V)R87IU:F4@86MO("(*(F]D;W-I96QA=&6U('-P
M<N%V>2X@6F%C:&]V86IT92!O<&%T<FYO<[L@<')I(&ML:6MA;NT@;F$@;&EN
M:WD@=B!S<'+A=F4@86QE8F\@(@HB<&]S:WET;W9A;NT@;W-O8F[]8V@@:6YF
M;W)MX6-I[2!O9&]S:65L871EM6]V:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!NX7)A>F]V_2`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS
M9W-T<B`B+"!V(&[A<F%Z;V-H("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M
M("5S('1O("5S(@IM<V=S='(@(BP@<')E;65N;N$@=B!R;WIS86AU("5S(&&^
M("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S,@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q,S(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.30*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C<T-0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@
M(BTM('9Y8F5R=&4@<VD@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*
M;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R+6AO9&EN;W;](&9O
M<FWA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U
M<B!&;W)M870B"FUS9W-T<B`B,C0M:&]D:6YO=OT@9F]R;>%T(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S
M='(@(C(T(&AO9.UN(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ0<F5D8VCA9'IA:OIC82(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(E!R
M92!T96YT;R!B;&]K(&IE('!OOF%D;W9A;OT@9&%T86+A>F]V_2!B86-K96YD
M+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")6>7-K>71L82!S82!ZX79AOF[A(&-H
M>6)A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R(").82!Z8;EI9G)O=F%N:64@<W!RX79Y(&IE('!OOF%D
M;W9A;OT@=F5R96IN_2!02%`@:[7ZZ"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(").82!O
M=F5R96YI92!P;V1P[7-A;F5J('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J
M;OT@4$=0(&NU^N@N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y
M.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*(DYA(&1EN6EF<F]V86YI92!S<'+A=GD@
M<_H@<&]T<F5B;NDZ('9E<F5J;OT@4$=0(&NU^N@L('!R:7;A=&YY(%!'4"!K
MM?KH(&$@(@HB:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*(DYA('!O9'#M<V%N:64@<W!RX79Y('/Z
M('!OOF%D;W9A;NDZ('9R96IN_2!01U`@:[7ZZ"P@<')I=N%T;GD@4$=0(&NU
M^N@@82`B"B)H97-L;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(DYA(&1EN6EF<F]V86YI
M92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@=F5R96IN_2!3+TU)344@:[7ZZ"P@
M<')I=N%T;GD@4R]-24U%("(*(FNU^N@@82!H97-L;RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(DYA('!O9'#M<V%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@
M4R]-24U%(&NU^N@L('!R:7;A=&YY(%,O34E-12`B"B)KM?KH(&$@:&5S;&\N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@
M<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B3F$@>F&Y:69R;W9A;FEE('-P<N%V>2!J92!P;[YA
M9&]V86[]('9E<F5J;OT@4TU)344@:[7ZZ"XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS
M9W-T<B`B4')E9'!O;'5D;NUM(&]B;&'H;F\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I
M;B(*;7-G<W1R(")0<F5D<&]L=61N[6T@M6%H:_T@9.&^[R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!2
M86EN(@IM<V=S='(@(E!R961P;VQU9&[M;2!DX;[O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E
M<G,B"FUS9W-T<B`B4')E9'!O;'5D;NUM('!R96CA;FMY(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")0<F5D<&]L=61N[6T@<VYE:&]VZ2!P<F5H
MX6YK>2(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!
M32]032(*;7-G<W1R("(Q,B!H;V3M;B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)
M($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B3R!T;VUT
M;R!E9&ET;W)E(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G
M:60@(D%B;W5T+BXN(@IM<V=S='(@(D\N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB
M"FUS9W-T<B`B06)S;VSZ=&YY('-P;V1O:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*
M;7-G<W1R(")!8G-O;/IT;GD@<W1R960B"@HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B4')I('9Y=';A<F%N[2!61E,@861R97/A<F$@8F]L
M('IA;6EE=&YU=/T@<'+M<W1U<"XB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ
M,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM
M<V=S='(@(E!R:2!V>71VX7)A;NT@5D93('/Z8F]R=2!B;VP@>F%M:65T;G5T
M_2!P<NUS='5P+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED
M(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;>%C:64@;R#Z
MZ'1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O
M=6YT(%!A<W-W;W)D(@IM<V=S='(@(DAE<VQO('!R92#ZZ&5T(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U
M;G0@9G)O>F5N+B(*;7-G<W1R("+:Z&5T('IA8FQO:V]V86[]+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B
M"FUS9W-T<B`BVNAT;W9A;FEE(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS
M9W-T<B`B4')I9&&[(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO
M9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R
M(")0<FED8;L@<&]D<FEA9&5N^B!S:W5P:6YU(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDY"FUS9VED
M(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")0<FED8;L@<&]D<FEA
M9&5NZ2!P<N%V;R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`B4')I9&&[.B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@
M3F5W($=R;W5P(@IM<V=S='(@(E!R:61ANR!S:W5P:6YU(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@X
M"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B4')I9&&[(&YO
M=ND@<'+A=F\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P
M('1O(%PB)7-<(B(*;7-G<W1R(")0<FED8;L@9&/I<G-K=2!S:W5P:6YU(&1O
M(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30W"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E
M<UPB(@IM<V=S='(@(E!R:61ANR!D8^ER<VME('!RX79O(&1O(%PB)7-<(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB
M"FUS9W-T<B`B4')I9&&[('!O=;[M=F%T9;5A.B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU-3,*;7-G:60@(D%D9"!C;VQU;6XB
M"FUS9W-T<B`B4')I9&&[('-TY7!E8R(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G
M<W1R(")0<FED8;L@Z&QE;F]V(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B4')I9&&[('#A<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM
M<V=S='(@(E!R:61ANR!M96YU("5S(&%K;R!";^AN_2!P86YE;"!-;WII;&QY
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I
M9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B4')I9&&[(&1O(&%D
M<F5SX7)A.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B4')I
M9&&[(&1O(&WT:FAO(&%D<F5SX7)A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*
M;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(E!R:61ANR!P;W6^[79A=&6U82(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S
M='(@(B(*(EPB)7-<(B!B;VP@<')I9&%N_2!D;R!S>7-TZ6UU+"!A;&4@;F5M
M;[YN;R!P<FED8;L@[V%LN6EE('!R:6AL87-O=F%C:64@(@HB:6YF;W)MX6-I
M93H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+B(*;7-G<W1R(")<(B5S7"(@8F]L('!R:61A;OT@9&\@<WES=.EM=2X@
M5&5R87H@<V$@;?2^971E('!R:6ALX7-INRXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")0<FEDX79A;FEE('!O=;[M=F%T9;5O=B!J92!Z
M86OA>F%NZ2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-2!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*;7-G<W1R
M(")!9')E<V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS
M9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97/A<B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B
M061M:6YI<W1RX6-I82`M(&YA<W1A=F5N:64@<'+A=B!P<F4@:6[]8V@@<&]U
MONUV871EM6]V(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D%D;6EN:7-T<N%C:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`B4F5K;&%M>2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A
M;FEA(@IM<V=S='(@(D%L8N%N<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R
M(")!;+[M<G-K;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G
M:60@(D%L:6=N(@IM<V=S='(@(EIA<F]V;F&[(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT
M.B(*;7-G<W1R("):87)O=FYA;FEE.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E:Y971K>2(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(E:Y971C:2!A=71E;G1I9FEK;W9A;NT@<&]UONUV871E;&EA(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B
M06QL($=R;W5P<R(*;7-G<W1R(")6N65T:WD@<VMU<&EN>2(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E
M+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E:Y971K
M>2!P<N%V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(E:Y971K>2"Y='ER:2!S=')A;GDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@W-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@
M(E!O=F]L:;L@=FEA8V5RZ2!A9')E<WDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/R(*;7-G<W1R(")0;W9O;&F[(&YA<W1A=F5N:64@='EP=2!Z;W)A
M9&5NZ6AO('IO>FYA;74_(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")5OB!E>&ES
M='5J92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L
M=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T[79N92!P<FEH
M;&%S;W9A8VEE(&UE;F\@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@
M(D%L=&5R;F%T[79N92!H97-L;R!)35-0(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B06QT97)N873M=FYE('!O=;[M=F%T9;5S:^D@;65N;R!)35-0(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L=&5R;F%T[79N82!E+6UA
M:6QO=N$@861R97-A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N873M=FYE
M(+EA8FSS;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*
M;7-G<W1R(")!;'1E<FYA=.UV;GD@=&5X=#HB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!3
M86UO82(*;7-G<W1R(")!;65R:6-KX2!386UO82(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G
M:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B
M0F]L82!Z861A;N$@;F5P;&%T;N$@:&]D;F]T82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N(@IM<V=S='(@(DYA<W1A;&$@;F5Z;N%M82!C:'EB82XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B
M06YG=6EL;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6UNZ2!P<F]X>2(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W
M97(B"FUS9W-T<B`B3V1P;W9E[R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B06YT87)K=&EK82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS
M9W-T<B`B06YT:6=U82!A($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O2&]R9&4O0FQO8VLO
M54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P;&EKX6-I82(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@
M3&ES="(*;7-G<W1R("):;WIN86T@87!L:6OA8VGM(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN
M(@IM<V=S='(@(D%P;&EKX6-I82!J92!P<FEP<F%V96[A+B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL
M9"!3:&%R97,B"FUS9W-T<B`B07!L:6MO=F&[(&YA('!O9')I861E;ND@>F1I
M9;5A;ND@<')I9>AI;FMY(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B4V-H=N%L:;LB
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED(")!
M<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(E!R:6)L:;YNX2!V9;5K;W.[(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL
M(@IM<V=S='(@(D%P<NUL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S$*
M;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B
M5F6U:V]SNR!A<F-H[79U(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI
M=F4@3F%M92(*;7-G<W1R(")-96YO(&%R8VCM=G4B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(DYA;WIA:B!C:&-E=&4@
M=GEM87IANR"^:6%D;W.[(&\@<')I:&SA<V5N:64@)R5S)S\B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<
M(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(DYA;WIA:B!C:&-E=&4@
M=GEM87IANR!<(B5S7"(@82!VN65T:WD@<&]D<VMU<&EN>3\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT[6YA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*
M;7-G<W1R(")!<FWI;G-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<R
M"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")5
M;65N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*
M;7-G<W1R(")/<W1R;W8@07-C96YS:6]N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@=6UE
M;FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S
M:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`BP7II82]086-I9FEC:_T@<F5G
M:?-N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_(@IM<V=S='(@(E9YOF%D;W9ANR!P;W1V<F1E;FEE('!R960@
M=GEK;VYA;NUM(&]P97+A8VGM(/ID<KYB>3\B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S$P,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")0;VMU<R!O
M('9Y;6%Z86YI92!N965X:7-T=6KZ8V5J('-K=7!I;GDN(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&]K=7,@;R!V
M>6UA>F%N:64@;F5E>&ES='5J^F-E:&\@<'+A=F$N(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0;VMU<R!O(/IP<F%V=2!N
M965X:7-T=6KZ8V5H;R!P<N%V82XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92XB"FUS9W-T<B`B4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J^F-E
M:&\@>F1I9;5A;NEH;R!O8FIE:W1U+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED
M(")!='1R:6)U=&5S(@IM<V=S='(@(D%T<FEB^G1Y(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!
M=6=U<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S='+A;&EA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B075S=')I82(*;7-G<W1R(")286OZ<VMO(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M8WER<W%L.B!0;[YA9&]V86[I(')O>KGM<F5N:64@:6UA<"!N96)O;&\@;N%J
M9&5NZ2XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED
M(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z(&)A8VME;F0@;F5M
MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!P
M;[YA9&]V86[I(')O>KGM<F5N:64@:6UA<"!N96)O;&\@;N%J9&5NZ2XB"@HC
M.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*(D%U=&A?9G1P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@1E10(&YE8F]L
M;R!NX6ID96[I+B!3:V]M<&EL=6IT92!02%`@<R`B"B)P<F5P[6YAZ&]M("TM
M96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV-`IM
M<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@<&^^861O=F%NZ2!R;WJY[7)E
M;FEE($E-05`@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z('!OOF%D
M;W9A;ND@<F]ZN>UR96YI92!K<F(U(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!
M9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z('!R:63A=F%N:64@<&]UONUV
M871EM6]V(&YI92!J92!P;V1P;W)O=F%NZ2!P<F4@06-T:79E($1I<F5C=&]R
M>2(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T
M:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@=GEM87KA
M=F%N:64@<&]UONUV871EM6]V(&YI92!J92!P;V1P;W)O=F%NZ2!P<F4@06-T
M:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C8S
M"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!P;[YA9&]V86[I(')O>KGM
M<F5N:64@3$1!4"!N96)O;&\@;N%J9&5NZ2XB"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($YE<&]D87)I;&\@<V$@
M<')I9&&[('!O=;[M=F%T9;5A("5S+B!397)V97(@;V1P;W9E9&%L.B`B"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.B!N97!O9&%R:6QO('-A(&]D<W1RX6YINR!P;W6^
M[79A=&6U82`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(&YE<&]D87)I;&\@<V$@
M86MT=6%L:7IO=F&[('!O=;[M=F%T9;5A("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM
M<V=S='(@(B(*(D%U=&A?;&1A<#H@86MT=6%L:7KA8VEA('!O=;[M=F%T9;5O
M=B!N:64@:F4@<&]D<&]R;W9A;N$@<')E($%C=&EV92!$:7)E8W1O<GDB"@HC
M.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?;6-A;#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($U#04P@;F5B;VQO
M(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@<&^^861O=F%NZ2!R
M;WJY[7)E;FEE('-M8F%U=&@@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB+TAO
M<F1E+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@
M870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I9FEKX6-I
M82!P;VUO8V]U($E-05`@<V5R=F5R82!Z;'EH86QA+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A
M=&EO;B!F86EL960B"FUS9W-T<B`B075T96YT:69I:^%C:6$@>FQY:&%L82(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D%U=&5N
M=&EF:6OA8VEA('IL>6AA;&$N("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D
M:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N(@IM<V=S='(@(E-E<G9E<B!2041)55,@>F%M:65T
M;VP@875T96YT:69I:^%C:74N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@W,0IM
M<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(D%U=&5N=&EF:6OA8VEA('!O;6]C;W4@1E10('-E<G9E<F$@>FQY
M:&%L82XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T
M96YT:69I:^%C:6$@<&]M;V-O=2!334(@<V5R=F5R82!Z;'EH86QA+B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L
M92!F:65L9',Z(@IM<V=S='(@(D1O<W1U<&[I('!O;&^^:WDZ(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%J9+YA;B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@
M(D)/1D@@17AC=7-E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`B4&]Z861I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B
M1F%R8F$@<&]Z861I82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q
M"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(EILZ2!H
M97-L;R!P<F4@:V5R8F5R;W,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B
M6FSI('!O=;[M=F%T9;5S:^D@;65N;R!P<F4@:V5R8F5R;W,N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F%H86UA<R(*;7-G<W1R(")"86AA;7DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S
M='(@(D)A:')A:FXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W,PIM<V=I
M9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N
M9VQA9&5S:"(*;7-G<W1R(")"86YG;&%DZ;DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*
M;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")0<FEEZ&EN;VL@<R!G<F%F
M:6MO=2!<(B5S7"(@;F5B;VP@;N%J9&5N_2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L
M:6YE(@IM<V=S='(@(EKA:VQA9&[](')I861O:R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B
M"FUS9W-T<B`B0FEE;&]R=7-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
M0F5L9VEC:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(D)E<FUU9'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B0G5TX6XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B
M0FER=&AD87DB"FUS9W-T<B`B3F%R;V1E;FEN>2(*"B,Z(&QI8B](;W)D92]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D)L;VL@7"(E<UPB(&%P;&EKX6-I92!<(B5S7"(@;F5B;VP@
M;N%J9&5N_2XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(DYA<W1A=F5N:6$@8FQO
M:W4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@
M(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5'EP(&)L;VMU(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM
M<V=S='(@(E1UZ&[I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VSM=FEA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(EKA;&^^:WDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B
M"FUS9W-T<B`B3VMR86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G
M<W1R("*I[7)K82!O:W)A:F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G
M<W1R(")/:W)A:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM
M<V=S='(@(D)O<VYA(&$@2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B3V)E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O
M;2(*;7-G<W1R(")";W1T;VTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(D)O=79E="!)<VQA;F0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A
M>NUL:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(@IM<V=S='(@(D)R:71S:^D@^GIE;6EE('8@26YD:6-K;VT@;V-EX6YE(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S
M<V%L86TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QH87)S:V\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS
M9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(EIO>FYA;2!S(&]D<N&^:V%M
M:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@
M(D-20R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T
M<B`B1&ES=')I8G7H;ND@8F]D>2!#4DPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5FQA<W1N;W-T:2!?8G5N:WDN+BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("));F-I86QI
M>N%C:6$@=GER;W9NX79A8V5J('!A;>1T:2!N96)O;&$@9&]K;V[H96[A+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#(@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F3A<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A
M;&TB"FUS9W-T<B`B0F5Z=F5T<FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S
M='(@(DMA;6)O9+YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U
M;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).97!O9&%R:6QO('-A
M(&%U=&]M871I8VMY(&]B;F]V:;L@:&5S;&\L(&MO;G1A:W1U:G1E('-V;VIH
M;R!A9&UI;FES='+A=&]R82XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F%P[7-ANR!D;R!S^F)O<G4@
M7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S
M='(@(DYE;6^^;F\@861M:6ES=')O=F&[(&5X=&5R;ND@;W9LX61AZ&4@<V5D
M96[M+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!S<&]J:;L@<R!)34%0('-E<G9E<F]M.B`E<R(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V
M;W)INR!S^F)O<B!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA
M;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@
M(EIR=;EINR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y
M"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B6G)UN6F[
M('-P<N%V=2!O('!R;V)LZ6UE(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@<_IB;W(@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&[A:G.[(&1O
MZ&%S;OT@861R97/A<BXB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*
M;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A
M<F%M971E<BXB"FUS9W-T<B`B3F5M;[YN;R!P;VMR8>AO=F&[(&)E>B!P87)A
M;65T<F$@)W1A<F=E=$9I;&4G+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&]D<W1RX6YINR!A9')E
M<^%R(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R."!L
M:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S
M='(@(DYE;6^^;F\@;V1S='+A;FF[+"!E>&ES='5J92`E9"!N87-L961O=F[M
M:V]V+B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I
M9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R
M960N(@IM<V=S='(@(B(*(DYE;6^^;F\@<')E=7-P;W)I861ANRP@<&_H970@
M<&]L;[YI96L@<')E('!R975S<&]R:6%D86YI92!N97/Z:&QA<^T@<R!P;^AT
M;VT@(@HB=6QOOF5N_6-H('!O;&^^:65K+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('-M97)O=F&[('-P<N%V=2!N82!U<NAE;ND@Z.US;&\N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0V%P92!697)D92(*;7-G<W1R(")+87!V97)D<VOI(&]S=')O=GDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E1I='5L;VLB"@HC.B!L:6(O3F5T
M+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A
M=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9_-R:64@82!P;W!I
M<VMY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DMA:FUA;G-K
MZ2!O<W1R;W9Y(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QN_2!T96QE
M9O-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E9L
M87-T;F]S=&D@8G5N:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R
M(")6>7!L;F5N:64@8G5N:WDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T
M:65S(@IM<V=S='(@(E9L87-T;F]S=&D@8G5N:WDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S
M<&%C:6YG.B(*;7-G<W1R(")2;WIO<W1U<"!B=6YI96LZ(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-
M;V)I;&[]('1E;&5F\VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-`IM
M<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM
M<V=I9"`B0V5N=&5R(@IM<V=S='(@(D1O('-T<F5D=2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R
M86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")3=')E9&]A9G)I8VOA(')E
M<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")0;V1R;V)NZ2!I;F9O<FWA8VEE(&\@8V5R
M=&EF:6OA=&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B5FQA<W1N[6L@8V5R
M=&EF:6OA='4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM
M<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]L:71I:WD@
M<')E(&-E<G1I9FEKX71Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(LAA9"(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("):
M;65N:;LB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G
M:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(EIM96YINR!68;EE
M(&AE<VQO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B
M"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB
M"FUS9W-T<B`B(@HB3F%S=&%V96YI92!M96YA(&$@861R:65S+"!K=&]RZ2!V
M:61I82"U=61I82P@:V7O(.CM=&%J^B!A(&]D<&]V961A:OH@;F$@5F&Y92`B
M"B)E+6UA:6QY+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR
M-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P
M<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B):;65N82!H
M97-L82!N:64@:F4@=B!A:W1UX6QN96H@:V]N9FEG=7+A8VEI('!O9'!O<F]V
M86[A+B`@2V]N=&%K='5J=&4@<W9O:FAO("(*(F%D;6EN:7-T<N%T;W)A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B6FYA:R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I
M9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B4U]K;VYT<F]L;W9ANR!L:6YK
M=2XN+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`BR.UN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V
M"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D-H:6YE<V4@
M5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS
M9W-T<B`B5GEB97)T92!A<&QI:^%C:74Z(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S
M='(@(EIV;[5T92!S:2!H97-L;R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("):
M=F^U=&4@<VD@<&]UONUV871EM7-KZ2!M96YO(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R(")6>6)E<G1E('-P]'-O8B!Z;V)R87IO=F%N:6$@9.%T
M=6UO=CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B5GEB97)T92!T>7`@N73]
M;'4@>F]Z;F%M=2`H<')E('IO<F%D96[I('IO>FYA;7DI(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR
M:7-T;6%S($ES;&%N9"(*;7-G<W1R(")6:6%N;^AN_2!O<W1R;W8B"@HC.B!L
M:6(O5D93+G!H<#HY,3,@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B1&5F:6[M8VEA('1R:65D>2`E<R!N96)O;&$@;N%J9&5NX2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM
M<V=I9"`B0VQE87(B"FUS9W-T<B`B2F%S;F\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F
M9FEC92!T86=S(@IM<V=S='(@(D]D<W1RX6YINR!P<NUK87IY($U33V9F:6-E
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E
M<GDB"FUS9W-T<B`B5GEM87IANR!D;W1A>B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R
M(&]U="!U<V5R.B`E<R(*;7-G<W1R(")/9'-T<N%N:;L@<&]UONUV871EM6$Z
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS
M9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D]D<W1RX6YINR!P;W6^[79A=&6U
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED
M(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B5GEM87IANR!P;W6^[79A=&6U
M<VOI(/ID86IE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B3F5S:_1R
M('9Y:F%S;F5N:64B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T
M<B`B2VQI:VYI=&4@<')E('!O:W)AZ&]V86YI92(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I
M82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@8V5Z($A45%`B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("):871V;W)INR!O
M:VYO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D
M<R(*;7-G<W1R(")/8FQA:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@
M(E+A;F\@;V)L8>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B3V)L8>AN;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(D-O8V]S
M("A+965L:6YG*2!)<VQA;F1S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E
M8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("):
M8F%L:;L@0F_H;OT@<&%N96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R
M9&5R<R(*;7-G<W1R("):8F%L96[I(&]K<F%J92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA
M(@IM<V=S='(@(DMO;'5M8FEA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ
M."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM
M<V=S='(@(D9A<F)A(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,R-2!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC
M:V5R(@IM<V=S='(@(E;]8F5R(&9A<F)Y(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(X,S4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B5OUB
M97(@9F%R8GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B4W3E<&-E.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@=&ET;&5S
M(@IM<V=S='(@(DYA9'!I<WD@<W3E<&-O=B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")+;VUI:W,B
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`B4'+M:V%Z(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED
M(")#;VUM86YD(%-H96QL(@IM<V=S='(@(E!R[6MA>F]V_2!I;G1E<G!R971E
M<B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M
M;65N="(*;7-G<W1R(")+;VUE;G3A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(")"9;YN
MZ2!M96YO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)Y(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O
M;7!A;GDB"FUS9W-T<B`B4W!O;&_H;F]SNR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(E!OZ.UT8>AE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B
M0V]N9&ET:6]N(@IM<V=S='(@(E-T878B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")3=&%V(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`B4F]Z9&EE;'D@=B!K;VYF:6=U<N%C:6DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U
M<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD
M($]U=&QO;VLN(@IM<V=S='(@(B(*(DMO;F9I9W5RX6-I82!P<F4@<WEN8VAR
M;VYI>N%C:74@<R!01$$L(&EN=&5L:6=E;G1N_6UI('1E;&5F\VYM:2!A($]U
M=&QO;VMO;2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")+;VYF
M:6=U<N%C:6$@<&]T<F5B=6IE(&%K='5A;&EZX6-I=2XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I
M9W5R92`E<R(*;7-G<W1R(")+;VYF:6=U<F]V8;L@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A
M<W-W;W)D(@IM<V=S='(@(E!O='9R[W1E(&AE<VQO(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B
M"FUS9W-T<B`B2V]N9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D1E;6]K<F%T:6-KX2!R97!U8FQI
M:V$@2V]N9V\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")3<&]J96YI92!Z;'EH86QO
M+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960Z("(*;7-G<W1R(")3<&]J96YI92!Z;'EH86QO.B`B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M2[7ZZ"!B;VP@>F%M:65T;G5T_2!S97)V97)O;2!V97)E:F[]8V@@:[7ZZ&]V
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")+M?KH(&)O;"!Z
M86UI971N=73]('-E<G9E<F]M('9E<F5J;OUC:"!KM?KH;W8N($3T=F]D.B`E
M<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@V-0IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4W!O:F5N:64@
M<R!&5%`@<V5R=F5R;VT@>FQY:&%L;RXB"@HC.B!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B2V]N=&%K='DB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED
M(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K='D@8F]L:2#Z<W!EN6YE('9L
M;[YE;N$@9&\@5N&Y:&\@861R97/A<F$N(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP
M<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4>7`@:V]M<')I;6]V86[I:&\@<_IB
M;W)U.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")/8G-A:"!<(B5S7"(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(E!O:W)A
MZ&]V8;LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:V]V92!O
M<W1R;W9Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#
M;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM
M<V=S='(@(DMO<.UR;W9ANR(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(DMO
M<.UR;W9A;FEE('IL>6AA;&\Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB
M"FUS9W-T<B`B2V]P[7)O=F&[(';]8F5R(@H*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C$W,"!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS
M9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS
M9W-T<B`B2V]S=&%R:6MA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R
M(")0;V)R9;YI92!S;&]N;W9I;GDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E
M.B`B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z8;EI9G)O=F&[('-P<N%V=2!P
M;VUO8V]U(%!'4#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`U
M-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R
M(").97!O9&%R:6QO('-A('!O9'#M<V&[('-P<N%V=2!P;VUO8V]U(%!'4#H@
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('IAN6EF<F]V8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!P;V1P[7-ANR!S<'+A=G4@<&]M;V-O=2!3+TU)344N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@<')I9&&[(&MO;G1A:W0N("5S+B(*"B,Z(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ
M,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(").97!O9&%R:6QO('-A('!R:7!O:FF[(&L@3$1!4"!S97)V97)U+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M<')I<&]J:;L@:R!,1$%0('-E<G9E<G4B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A(&]V97)INR!Z
M;W-T871O:R!N82#ZZ'1E+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R
M(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@3$1!4"!S
M97)V97)U(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S
M7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('!R:7!O
M:FF[(&L@<V5R=F5R=2!<(B5S7"(@<&]M;V-O=2!&5%`Z("5S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[('IO>FYA;2!P<NUJ
M96UC;W8N("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R.`IM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R(").
M97!O9&%R:6QO('-A(&1EN6EF<F]V8;L@4$=0(/ID86IE.B`B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@9&6Y
M:69R;W9ANR!3+TU)344@^F1A:F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M=GEM87IANR!K;VYT86MT+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!V>6UA>F&[('IO>FYA;2!P<NUJ96UC;W8N("5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!S:W)I<'0@;F$@=7!G
M<F%D92!K;VYF:6=U<N%C:64@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=7+H:;L@92UM
M86EL;W;Z(&%D<F5S=2!P<NUJ96UC=2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-T
M:6%H;G6[(&-E;/T@861R97/A<BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@<'+M:F5M8V]V+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS:V&[(&MO;7!L971N_2!Z
M;WIN86T@>F]Z;F%M;W8@<'+M:F5M8V]V+B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!N8>CM=&&[('-T<F%TZ6=I=2!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<W!U<W1I
MNR!M:V1I<B!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!V
M97)E:F[](&NU^N@@>F\@<V5R=F5R82!KM?KH;W8N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[(%PB)7-<(B!P
M<F4@>N%P:7,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8W-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M(&]T=F]R:;L@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT
M,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O
M='9O<FF[(&UO9'5L($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&]T=F]R:;L@861R97/A<B!<
M(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M('!R:7!O:FF[(&YA($Q$05`@<V5R=F5R+B(*"B,Z(&QI8B]61E,O3V)J96-T
M+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@
M)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')EZ.UT8;L@)7,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).97!O
M9&%R:6QO('-A(&]B;F]V:;L@:&5S;&\@>F%D86[I:&\@<&]UONUV871EM6$N
M($YI96MT;W+I(&%L96)O(':Y971K>2`B"B)P;V1R;V)N;W-T:2!N:64@<_H@
M<W!RX79N92X@4VOZ<W1E('1O('IN;W9U(&%L96)O(&MO;G1A:W1U:G1E(%;A
MN6AO("(*(F%D;6EN:7-T<N%T;W)A+"!A:R!P;W1R96)U:F5T92!P;VUO8RXB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@S"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M3F5M;[YN;R!Z[7-K8;L@04-,(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").97!O9&%R:6QO
M('-A('KM<VMANR!A9')E<^%R+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").
M97!O9&%R:6QO('-A('KM<VMANR!Z;WIN86T@<'+M:F5M8V]V+B`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T<RX@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z[7-K8;L@>F]Z;F%M
M>2!P<NUJ96UC;W8@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G
M<W1R(").96UOOFYO('KM<VMANR!I;F9O<FWA8VEE(&\@=FQA<W1N;W-T:6%C
M:"!S97)V97)A(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I
M9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A('9RX71INR!K;VYF:6=U<N%C:74N(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!S<'5S=&F[(')M9&ER(%PB)7-<(BXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(").97!O9&%R:6QO('-A('5L;[YINR!K;VYF:6=U<N%C:74@)7,N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K
M;VYF:6=U<N%C:64N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!U;&^^:;L@
M>N%L;VAU(&MO;F9I9W5RX6-I93H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A('5L;[YINR!S:W)I<'0@;F$@=7!G<F%D92!N87-T879E
M;NT@9&\Z(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A8VEE("5S+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3F5P;V1A<FEL;R!S82!Z87#M
M<V&[(&MO;F9I9W5R8>AN_2!S^F)O<B`E<RX@3?2^971E('!O=;YINR!N:65K
M=&]R^B!Z("(*(FUOOFYO<W3M(&YA('KA<&ES(&OS9'4@;F$@)7,@86QE8F\@
M<VMO<.UR;W9ANR!R=>AN92!K\V0@=79E9&5N_2!N:;ZY:64@9&\@)7,N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!HM6%D8;L@;F$@3$1!4"!S97)V97)I+B(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M(").97!O9&%R:6QO('-A('9Y;6%Z8;L@7"(E<UPB+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").97!O
M9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!K;VYT86MT+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@>F]Z;F%M('!R
M[6IE;6-O=BX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I
M;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z87#M
M<V&[(&MO;F9I9W5RX6-I=2!P<F4@7"(E<UPB.B`E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M(@IM<V=S='(@(DYE;6^^;F\@;N%J<[L@0F_H;OT@<&%N96P@36]Z:6QL>2X@
M4VMO;G1R;VQU:G1E+""^92!J92!P86YE;"!O='9O<F5N_2XB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"B)0;W6^[79A=&6U;W9I(%PB)7-<(B!S82!N97!O9&%R:6QO('!R:61A
MNR!P<N%V82!P<F4@<')I9>AI;F]K(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@
M(E!OZ.UT86[]('1E>'0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")+<F%J:6YA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G
M<W1R(")+=7)Z>2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@
M(E9Y='9O<FF[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(E9Y='9O<FF[(&QI;FMU(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G
M<W1R(")6>71V;W)INR!N;W;](@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T
M<B`B5GET=F]R:;L@<&]D<')I9>AI;F]K(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4'+A=F$@='9O<F-U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3D*
M;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("+([7-L;R!K<F5D
M:71N96H@:V%R='DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")#:&]R=N%T
M<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(D%K='7A;&YE(#0@9N%Z>2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM
M<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")!:W1UX6QN92!S961E
M;FEA(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N
M<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B06MT=>%L;GD@
MZ&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")!
M:W1UX6QN82!54DP@:F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G
M:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B06MT=>%L;FD@<&]UONUV871E
M;&EA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N
M="!796%T:&5R(@IM<V=S='(@(D%K='7A;&YE('!OZ&%S:64B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(D%K='7A;&YE('!O9&UI96YK>3H@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I
M9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")!:W1UX6QN>2"Y=/UL(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(DYA<W1A=F5N:64@^FQO:"P@:W1O<ND@<V$@<W#ZN;MA:OH@<')I
M('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B
M0W5T(@IM<V=S='(@(E9Y<W1R:6AN^KLB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N
M(@IM<V=S='(@(E9Y<W1R:6AN^KL@=OUB97(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS
M9W-T<B`B0WEP<G5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I
M9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(LAE<VOA(')E<'5B;&EK82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S`*;7-G:60@(B(*(D133B`H<V5E
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("AP;WIR:2!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E
M+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&5N;F4B"@HC.B!A9&UI
M;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS
M9W-T<B`B4')E>F5R8>@@9.%T;W;I:&\@<W1R;VUU("A$871A5')E92DB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(V.`IM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(E9Y:+5A9.%V86YI92!V(&1A=&%BX7IE(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(T,#(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`B1.%T=6TB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")$X71U;2!P<FEJ871I82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-SDV"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R(")6_6)E<B!DX71U;74B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G
M:60@(D1A>2(*;7-G<W1R(")$9?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@
M0V]L=6UN(@IM<V=S='(@(D]?9'-T<N%N:;L@<W3E<&5C(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(D1E8V5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S
M(@IM<V=S='(@(D1E<VEA=&MO=ND@Z.US;&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!)
M;F1E;G0B"FUS9W-T<B`B6FUE;KEINR!O9'-A9&5N:64B"@HC.B!L:6(O<')E
M9G,N<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B
M1&5F875L="(*;7-G<W1R(")0<F5D;F%S=&%V96[I(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U
M;'0@0V]L;W(B"FUS9W-T<B`B4')E9&YA<W1A=F5NX2!F87)B82(*"B,Z(&QI
M8B](;W)D92])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I
M='DB"FUS9W-T<B`B5F&Y82!P<F5D;F%S=&%V96[A(&ED96YT:71A(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL
M(@IM<V=S='(@(E!R961N87-T879E;OT@<'+M:V%Z;W;](&EN=&5R<')E=&5R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET
M:6]N<R(*;7-G<W1R(")$969I;NUC:64B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<Q(&QI8B](;W)D92]097)M<RYP:'`Z,S(V(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-#(R"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#,Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B5GEM87IANR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM
M<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B5GEM87IANR!B=6YK=2(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B5GEM87IANR!S:W5P:6YU(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE
M=&4@3&]G(@IM<V=S='(@(E9Y;6%Z8;L@>N%Z;F%M(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B5GEM87IANR!P<N%V
M;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I
M9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")6>6UA>F&[
M(&$@;V1S='+A;FF[('-P<N%V>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL
M(@IM<V=S='(@(E9Y;6%Z8;L@8G5N:W4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@
M8V]L=6UN(@IM<V=S='(@(E9Y;6%Z8;L@<W3E<&5C(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B5GEM87IANR!E>&ES='5J^F-U(&%L=&5R
M;F%T[79N=2"Y86)L\VYU(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B5GEM87IANR!P<N%V82!P<F4@7"(E<UPB(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(D-H8V5T92!V>6UA>F&[(%PB)7-<
M(B!A(':Y971K>2!J96AO('!O9'!RX79A/R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T
M92!R;W<B"FUS9W-T<B`B5GEM87IANR!R:6%D;VLB"@HC.B!T96UP;&%T97,O
M<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L
M96-T960@:61E;G1I='DB"FUS9W-T<B`B5GEM87IANR!V>6)R86[Z(&ED96YT
M:71U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M(@IM<V=S='(@(E9Y;6%Z8;L@86MT=>%L;GD@<W3E<&5C(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E9Y;6%Z8;L@
M86MT=>%L;GD@<FEA9&]K(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E
M('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E-K<FEP="!N82!U<&=R861E(&MO
M;F9I9W5RX6-I92!<(B5S7"(@8F]L('9Y;6%Z86[]+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("+(87,@9&]R=>AE;FEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$X6YS:V\B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE
M(%!R;V)L96TB"FUS9W-T<B`B4&]P[;ET92!P<F]B;.EM(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M(")0;W!I<R(*"B,Z(&QI8B](;W)D92YP:'`Z,3DW"FUS9VED(")$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(E!O9')O8FYO
M<W1I("AT:66^('8@;&]G;W9A8V]M('/Z8F]R92!(;W)D92DB"@HC.B!L:6(O
M2&]R9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B1&5T86EL>2!B;VQI
M('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G
M<W1R(")6_79O:B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED
M(")$97<@4&]I;G0B"FUS9W-T<B`B4F]S;OT@8F]D(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B4F]S;OT@8F]D('IA('!O<VQE9&[Z(&AO9&EN=3H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W
M('!O:6YT.B`B"FUS9W-T<B`B4F]S;OT@8F]D.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3;65R('JU879A(&1O<')A=F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y
M"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")3;65R
M('-P<F%V82!D;[5A=F$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D%D<F5SX7(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_(@IM<V=S='(@(EIO8G)A>F]V8;L@Z&%S('8@,C0M:&]D:6YO=F]M(&9O
M<FWA=&4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B
M1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DYA<W1A=F5N:64@>F]B<F%Z96YI
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B
M1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("):;V)R87IINR!P
M;V1R;V)N^B!P<F5D<&]V9>\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U
M"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(EIO8G)A
M>FF[('!R961P;W9E[R`H5$%&*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.#`V"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")&;W)MX70@>F]B
M<F%Z96YI82(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B4&]T=G)D96YI
M92!O(&1O<G7H96[M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1+YI8G5T
M<VMO(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O
M(&YO="!D96QE=&4B"FUS9W-T<B`B3F5V>6UA>F&[(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").97!O=;[M=F%J=&4@<')I
M86UO(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED
M(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(D]B<V%H=6IE('!R
M=OT@<FEA9&]K(&[A>G9Y('!O;.T_($%K(.%N;RP@>F&Y:W)T;FET92!P;VSM
MZ&MO.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEKX6YS:V$@
M<F5P=6)L:6MA(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM
M<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R
M(").96WA=&4@^NAE=#\@6F%R96=I<W1R=6IT92!S82XB"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N;&]A9"(*;7-G
M<W1R(")3=&EA:&YUNR(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HX-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T
M<B`B4W1I86AN=;L@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R
M"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+B(*;7-G<W1R(")3=&EA:&YUNR!V>6=E;F5R;W9A;OH@:V]N
M9FEG=7+A8VEU(&%K;R!02%`@<VMR:7!T+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("):;WIN
M86T@<R!V_6)E<F]M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS
M9VED(")$<G5G<R(*;7-G<W1R(")$<F]G>2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(D4M;6%I;"(*
M"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@
M(D524B(*;7-G<W1R(")%4E(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5K
M=N%D;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R(")5<')A=FF[(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(E5P<F%V
M:;L@8FQO:R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(E5P<F%V:;L@
M<VMU<&EN=2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*
M;7-G<W1R(")5<')A=FF[('!RX79O(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")5
M<')A=FF[('!RX79A(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R(")5<')A=FF[('!RX79A('!R92`E<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM
M<V=S='(@(E5P<F%V:;L@;F%S=&%V96YI82!P<F4Z(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5P<F%V:;L@<'+A=F$@
M<')E(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B57!R879INR!P<N%V82!P<F4@)7,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")6>F1E
M;.%V86YI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G>7!T(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")%;"!386QV861O<B(*;7-G<W1R(")386QVX61O<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I
M9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M
M(@IM<V=S='(@(D5M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL
M(@IM<V=S='(@(D5M86EL(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D5M86EL;W;A(&%D<F5S83HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DV-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(D4M;6%I;&]VZ2!A9')E<WD@;75S:6$@8GF[
M(')O=FYA:^DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3,*;7-G:60@
M(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D4M;6%I;"!S('!O
M='9R9&5N[6TB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")"<N%N82!%
M;6%I;"UN82U335,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,CDW"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B16UO=&EK;VYY
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G
M:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E!RX7ID;F$@<W!RX79A+B(*
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR-#,@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C0X-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M-C8R(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S
M='(@(E!RX7ID;GD@=OUS;&5D;VLN(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`B4'+A>F1N92!P;V1M:65N:WD@:+5A9&%N:6$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")0
M;W9O;&F[('9L;[YE;FEE(&]B<N%Z:V]V('H@1V%LZ7)I[2!D;R!T97AT=3\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@
M<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")0;W9O;&F[(&MO
M;G1E>'1O=ND@;65N=2!P<F4@<')A=ND@=&QAZ&ED;&\_(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#`*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(DMO;FEE8R!R;VMA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`B6G;DZ+EINR!E9&ET;W(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@
M=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB6F%D86IT92!B
M97IP9>AN;W-T;OH@;W3A>FMU+"!N82!K=&]R^B!B=61E=&4@;75S:66[(&]D
M<&]V961ANR!A:R!Z86)U9&YE=&4@(@HB:&5S;&\L(&YA<'(N("=A:V\@<V$@
M=F]LX2!M;VIE('IV:65R871K;S\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT
M97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(EIA9&%J=&4@55),(&]B
M<N%Z:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#@Y"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M6F%D86IT92!P[7-M96[A('5V961E;ND@;FF^N6EE.B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T
M;W)I86P@1W5I;F5A(@IM<V=S='(@(E)O=F[M:V]VX2!'=6EN96$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%<FET<F5A(@IM<V=S='(@(D5R:71R96$B"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*
M(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B
M"FUS9W-T<B`B0VAY8F$B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,B"FUS9W-T<B`B0VAY8F$@<')I('9Y=';A<F%N[2!B;&]K=3H@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T
M<B`B0VAY8F$@<')I('9Y;6%ZX79A;NT@=6MO='9E;FEA('-Y;F-H<F]N:7KA
M8VEE.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E
M<R(*;7-G<W1R(")#:'EB82!P<FD@=GEM87KA=F%N[2!ZX7IN86UU('-Y;F-H
M<F]N:7KA8VEE.B`E<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@
M)7,B"FUS9W-T<B`B0VAY8F$@<')I('KM<VMA=F%N[2!O8G-A:'4Z("5S(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R
M(")#:'EB82!P<FD@86MT=6%L:7KA8VEI(&AE<VQA.B`E<R(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W
M:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D-H>6)A('8@92UM86EL;W9E
M:B!S<'+A=F4N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")#:'EB82!P<FD@>F%P:7-O=F%N
M[2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W3S;G-K;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:?-P:6$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI
M8VOI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U
M<F]P92(*;7-G<W1R(")%=7+S<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMAOF3]
M8V@@,34@;6EN^G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS
M9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2V&^9.D@,B!M:6[Z='DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B
M2V&^9/UC:"`S,"!S96OZ;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@
M;6EN=71E<R(*;7-G<W1R(")+8;YD_6-H(#4@;6EN^G0B"@HC.B!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R(")0<FD@:V&^9&]M('!R:6ALX7-E;NTB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B
M2V&^9/H@<&]L:&]D:6YU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B2V&^9/H@;6EN^G1U(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(").87!R[6ML860Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED
M(")%>&5C=71E(@IM<V=S='(@(E-P=7-T:;LB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")2;WIB
M86QINR(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G
M:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(E)O>F)A;&F[($)OZ&[]('!A
M;F5L(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED
M(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B3^AA:^%V82!S82`G*2<B"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B3^AA
M:^%V82!S82!S;&]V;R!A;&5B;R!P;V1M:65N:V$@:+5A9&%N:6$@=B#Z=F]D
M>F]V:^%C:"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D3A='5M(&5X<&ERX6-I92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O
M;F5N="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R
M(@IM<V=S='(@(D9A<F)A('1E>'1U(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(").
M86AR8;L@:V]N9FEG=7+A8VEU(&YA($944"(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]S<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS:V&[(&YA<W1A=F5N
M:6$N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@<W!O
M:F5N[2!S($Q$05`@<V5R=F5R;VTN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB
M+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BXB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@<'+M<W1U<&4@:R!334(@
M<V5R=F5R=2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S`V"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M(").97!O9&%R:6QO('-A(&MO<.UR;W9ANR!Z(%PB)7-<(BXB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-S$Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!K;W#M
M<F]V8;L@9&\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP
M.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I
M;VXN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GET=F]R:;L@;F]VZ2!305-,
M('-P;VIE;FEE+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU,#$@;&EB+U9&4R]F
M='`N<&AP.C<T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V
M92!T;R!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E<W5N^KL@
M9&\@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(").
M97!O9&%R:6QO('-A('KM<VMANSH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")$
M;V)RZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G
M<W1R(")&86QK;&%N9'-KZ2!O<W1R;W9Y("A-86QV[6YY*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`B1F%E<G-KZ2!O<W1R;W9Y(@H*(SH@;&EB
M+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T
M<B`B6N%V8;YNX2!C:'EB83HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S
M='(@(D9A>'DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM
M<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G7A<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(E!O
M8VET('1E<&QO='DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B4&]C:70@=&5P;&]T
M>3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(DUA;.D@>G+AOFMY(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G
M:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B36%LZ2!S;F5H;W;I('!R
M96CA;FMY(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R(")-871I8V$@<&]L[2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S(S"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-PIM<V=I9"`B1FEG;&5T
M(&9O;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:62^:2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL
M92(*;7-G<W1R(")3^F)O<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B4&_H970@
M<_IB;W)O=CH@)7,@<_IB;W(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")0;^AE
M="!S^F)O<F]V.B`E<R!S^F)O<F]V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(E-P<N%V
M8V$@<_IB;W)O=B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B
M"FUS9W-T<B`B365N;R!S^F)O<G4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDX-`IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B5OUB97(@<_IB
M;W)U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T.3`*;7-G:60@(D9I;&4@
M=7!L;V%D(@IM<V=S='(@(DYA:')A=&EE('/Z8F]R=2(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HX.#4*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(").86ARX79A;FEE('/Z8F]R;W8@;FEE(&IE('!O
M9'!O<F]V86[I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM
M<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD
M(@IM<V=S='(@(D;M;G-K;R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*
M;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B4')VX2!P;VQO=FEC82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*
M;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B4')VX2"Y='9RNR(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-34*;7-G:60@
M(D9I>"!R871I;R(*;7-G<W1R(")0979N_2!P;VUE<B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S`*;7-G:60@(D9L:7`B"FUS
M9W-T<B`B3W1OZ&F[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B4&SA
M=F%J^F-I('1E>'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(DAM;&$B"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z,C,W(&QI8B]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T
M<B`B4')I9>AI;F]K("5S(&YE97AI<W1U:F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R
M(@IM<V=S='(@(D9A<F)A('#M<VUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(E!O=')A=F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S(@IM<V=S='(@(E!R92!P<F5H;&EA9&'H92P@:W1O<ND@;F5P;V1P;W)U
M:OH@;V)RX7IK>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED
M(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<F5D<&]V9>\@*%1!1BDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B
M(@HB4')E9'!O=F7O(&YA('5V961E;OT@<&_H970@9&[M("AP86WD=&%J=&4@
M;F$@=&\L(+YE('!R961P;W9E[R!J92!P<F4@9&YI(&%J("(*(FYO8VD@82!T
M86L@;?2^92!V9;5KZ2#H[7-L;R!V>71V;W)INR!V9;5M:2"Y:7)O:_T@8FQO
M:RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B
M1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(EIA8G5D;&D@<W1E(&AE
M<VQO/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(D9O<FUU;.%R92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")&;W)T=6YA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y
M<&4B"FUS9W-T<B`B5'EP(&9O<G1U;GDB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D9O<G1U;GDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B
M"FUS9W-T<B`B1F]R='5N>2`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D;S<F$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G
M<W1R(")0<F5S;65R;W9A;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B4&EA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(E+A;6-E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E(@IM<V=S='(@(D9R86YC^GIS:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T
M<B`B1G)A;F/Z>G-K;R`H175R\W!A*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B
M"FUS9W-T<B`B1G)A;F/Z>G-K82!'=6%Y86YA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B1G)A;F/Z>G-K82!0;VQY;NEZ:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N
M8_IZ<VME(&IUOF[I('1E<FET\W)IX2(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D]D(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("):;R!S;65R
M=2`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I
M9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("+:<&QN_2!P;W!I<R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V
M"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B4W!L;B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B0V5LZ2!M96YO.B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8G5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED
M(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86SI<FEA
M+"!Z(&MT;W)E:B!C:&-E=&4@=GII8;L@;V)RX7IO:R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM
M<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%LZ7)I83HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB
M:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(D=E;F5R;W9ANR!K;VYF:6=U<N%C:74@<')E(&%P
M;&EKX6-I=2`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N
M:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'96YE<F]V
M86[](&OS9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1V5O<F=I82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D=E<FUA;GDB"FUS9W-T<B`B3F5M96-K;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM
M<V=S='(@(D=H86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A
M;'3A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED
M(")':79E;B!.86UE(@IM<V=S='(@(DMR<W1NZ2!M96YO(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(D]D;W-L
M8;LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E
M;"(*;7-G<W1R(")';V5D96PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M1V]O9VQE($UA<',B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS
M9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(DBU861ANR!N82!';V]G;&4B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,V"FUS
M9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B3V1T:65N92"Y961E:B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B1W+I8VMO(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#$*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W+S;G-K;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R
M96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI
M;FES='+A8VEA('-K=7#M;B(*"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3D@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B365NX2!S:W5P[6X@;F5S
M;?H@8GF[('!RX7ID;F4B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(*;7-G<W1R(")'<F]U<%]L9&%P.B!.97!O9&%R:6QO('-A('!R:61ANR!S
M:W5P:6YU("5S+B!397)V97(@;V1P;W9E9&%L.B`B"@HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z,3$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ
M,C0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P
M("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z(&YE<&]D87)I;&\@<V$@=GEM87IA
MNR!S:W5P:6YU("5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,S
M."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B
M"FUS9W-T<B`B1W)O=7!?;&1A<#H@;F5P;V1A<FEL;R!S82!A:W1U86QI>F]V
M8;L@<VMU<&EN=2`E<R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$T
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B4VMU<&EN>2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L;W5P92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(D=U871E;6%L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,@IM
M<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")0<N%V82!A
M;F]N>6UN_6-H('!O=;[M=F%T9;5O=B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")'=65S=&)O
M;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U":7-S874B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@;F5D;W9O;.T@=GEM
M87IANR!P;W-L961N^B!B=6YK=2!V(')I861K=2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YE9&]V;VSM('9Y
M;6%Z8;L@<&]S;&5D;OT@<W3E<&5C('8@=&%B=;5K92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YE9&]V;VSM('9Y
M;6%Z8;L@<&]S;&5D;OT@<FEA9&]K('8@=&%B=;5K92XB"@HC.B!L:6(O2&]R
M9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10(&%U=&5N=&EF:6OA8VEA(&YE
M8F]L82!NX6ID96[A+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M
M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M=7,@:&%S:&]V86-E:B!F=6YK
M8VEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B3W!A<B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C$*;7-G:60@(DAE
M861E<B(*;7-G<W1R(")(;&%V:>AK82(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(DAL
M879IZ&MY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES
M;&%N9',B"FUS9W-T<B`B2&5A<F1O=B!O<W1R;W8@82!-8T1O;F%L9&]V92!O
M<W1R;W9Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B4VEL;N$@8OIR
M:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B2&5B<F5W
M("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H
M="(*;7-G<W1R(")6_;EK82(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ.#0@
M;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L
M<"(*;7-G<W1R(")0;VUO8V[M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R
M(@IM<V=S='(@(E!O;6]C;NUK('!R92!P;W6^[79A;FEE(&5D:71O<F$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W-0IM<V=I9"`B2&5L<&5R(@IM<V=S
M='(@(E!O;6]C;NUK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED
M(")(96UI<W!H97)E(@IM<V=S='(@(E!O;&]G=;5A(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB"FUS9W-T<B`B5'4@:F4@>F'H:6%T;VL@<_IB;W)U.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H
M(@IM<V=S='(@(E9Y<V]KX2(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I
M9"`B2&]?;64B"FUS9W-T<B`B1&]?;6]V(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B5F%T:6OA;B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,34S.0IM<V=I9"`B2&]M92(*;7-G<W1R(")$;VUO=B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D
M9')E<W,B"FUS9W-T<B`B1&]MX6-A(&%D<F5S82(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B
M1&]MX6-I('!R:67H:6YO:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F
M\VX@9&]M;W8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D
M871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z('8@<W!RX79E("5S(&)O;&D@;N%J9&5NZ2!N97!L871NZ2`E<R!8
M34P@^F1A:F4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P
M;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(',@;V)J
M96MT;VT@)7,@;F5K;W)EN7!O;F1U:F4@OFEA9&YA('-P<N%V82XB"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S
M<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@=B!S<'+A=F4@)7,@;F5B
M;VP@;N%J9&5N_2"^:6%D96X@;V)J96MT('1Y<'4@)7,B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@^G-P9;EN92!O9'-T<N%N96[I("5S(%PB)7-<(B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@:6YT96=R
MX6-I82!V>;YA9'5J92!02%`@<F]ZN>UR96YI92`G9&]M>&UL)R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@
M;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A
M('9Y='9O<FF[(&YO=OT@6$U,('-T<F]M('!R92!O8FIE:W0@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@
M)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#<S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!Z[7-K8;L@34E-12!)1"!P
M<F4@Z&%SNR!T>7!U("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3DR
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O;FEZ;W9ANR`E<R!<(B5S7"(Z("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,S,R"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S
M>6YC:')O;FEZ;W9ANR!Z9&EEM6%NZ2!O8FIE:W1Y.B`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@;F5Z;N%M>2!Z9&EEM6%N_2!O8FIE:W0@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DAO<FEZ;VYTX6QN82#H:6%R82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*
M;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I>F]N=.%L
M;F4@=GEP;&YE;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R
M:7IO;G3A;&YE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B06MO('-T92!S82!S96T@
M9&]S=&%L:3\@*%!R;W/M;2!N86ALX7-T92$I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B2V^U:V\@<W3E<&-O=B!C:&-E=&4@>FSZZ&F[/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B6F%D86IT92!P;^AE="!P
M;VSM("AS=.5P8V]V*3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+;[5K;R!R:6%D:V]V
M(&-H8V5T92!Z;/KH:;L_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B5FQH:V]SNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B5FQH:V]S
MNSH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO
M<FES=',B"FUS9W-T<B`B2'5M;W)I<W1I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM
M<V=S='(@(DUA[V%R<VMO(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[($E-05`@<V-H<N%N:W4Z
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-"!L:6(O2&]R
M9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(").97!O
M9&%R:6QO('-A('9Y;6%Z8;L@24U!4"!S8VARX6YK=3H@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@=GET=F]R:;L@24U!4"!K=O-T=3H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!A9')E
M<V$B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A9')E<V$@
M;FEE(&IE(&1O<W1U<&[A+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N
M<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+B(*;7-G<W1R("))4"!A9')E<V$@;FEE(&IE('8@<N%M8VD@
M9&]V;VQE;NEH;R!#2412(&)L;VMU+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I
M;VXN(@IM<V=S='(@(E!O<G6Y96YI92!P<F%V:61L82!O('!E=FYE:B!)4"!A
M9')E<V4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS
M9W-T<B`B5FQOOFF[(&NU^N@@7W!R960B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS
M9W-T<B`B27-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM
M<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("))8F$@:6MO;GDB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O
M;G,@9F]R("5S(@IM<V=S='(@(DEK;VYY('!R92`E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G
M<W1R(")):V]N>2!A('1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(D[A>F]V(&ED
M96YT:71Y.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G
M<W1R(")!:R!S82!N97IO8G)A>NT@:V]R96MT;F4L("5S(&$@;W1V;W+M('-A
M('8@;F]V;VT@;VMN92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y
M"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@
M(B(*(D%K(&YE=FED[71E('!R:2!P;W6^:73M($EN=&5R;F5T($5X<&QO<F5R
M82"^:6%D;F4@:6MO;GDL('!O=')E8G5J971E("(*(GIAN6MR=&[ZNR!T^G1O
M('9OM6)U('!R92!V>7!N=71I92!P<FEE<W9I=&YO<W1I(%!.1R!O8G+A>FMO
M=BXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R
M"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB06L@=FED
M[71E('3Z=&\@<W!RX79U(&$@;F5V:63M=&4@;V)RX7IO:RP@;V)RX7IO:RP@
M:W1O<OT@<W1E(&-H8V5L:2!N86AR8;LL("(*(FYE;?2^92!B>;L@>F]B<F%Z
M96[]('9O(%9AN6]M('!R96AL:6%D8>AI+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B56OAOFMA(&]B<N%Z:V$Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"!O8G+A>FMA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!O8G+A>FMA
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S
M='(@(D]B<N%Z;VL@>B!G86SI<FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G
M92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(D]B<N%Z;VL@>B!G86SI<FEE.B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED("));6%G92!U<&QO
M860B"FUS9W-T<B`B3F%H<F%T:64@;V)RX7IK=2(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B3V)RX7IK>2(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R="P@:W)O
M:R`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("))
M;7!O<G1O=F%NZ2!P;VQE.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP
M;W)T;W9A;ND@<&]L:6$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R(")6;&^^:;L@:[7ZZ"!?>F$B"@HC.B!L:6(O2&]R9&4O
M0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BXB"FUS9W-T<B`B0F]L('IA9&%N_2!N97-P<N%V;GD@:_-D
M(&%K8VEE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(DYE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@82]A;&5B
M;R!H97-L;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS
M9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE<W!R
MX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@86QT97)N873M=FYA(&%D
M<F5S82X@4VOZ<W1E('1O('IN;W9U("(*(F%L96)O(&MO;G1A:W1U:G1E('-P
M<N%V8W4@5N&Y:&\@<WES=.EM=2P@86L@<&]T<F5B=6IE=&4@<&]M;V,N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM
M<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(EIVY.BY:;L@;V1S861E
M;FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("));F1I82(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(DIE9&YO
M=&QI=NT@<&]UONUV871E;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T
M<B`B26YD;V[I>FEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM
M<V=S='(@(DEN9F]R;>%C:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+B(*;7-G<W1R("));F9O<FWA8VEE('6^(&YI92!S^B!D;W-T=7!NZ2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@
M(E9L;[YINR!?<W3E<&5C('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@
M26UA9V4B"FUS9W-T<B`B5FQOOFF[(&]B<N%Z;VLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@
M5&%B;&4B"FUS9W-T<B`B5FQOOFF[('1A8G6U:W4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@
M5V5B($QI;FLB"FUS9W-T<B`B5FQOOFF[(&QI;FMU(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED
M("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B5FQOOFF[(%]S=.5P
M96,@<')E9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFF[(&YO=OT@<W3E
M<&5C('IA(&%K='7A;&YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFF[
M(&YO=OT@<W3E<&5C('!R960@86MT=>%L;GDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(E9L;[YINR!N;W;](')I861O:R!Z82!A:W1UX6QN>2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(E9L;[YINR!N;W;](')I861O:R!P<F5D(&%K='7A;&YY(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R(")6;&^^:;L@;V1S=&%V96,@>F$@86MT=>%L;GD@
M8F]D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B5FQOOFF[(&]D<W1A=F5C('!R
M960@86MT=>%L;GD@8F]D(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*
M;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B5FQO
MOFF[(&%L=&5R;F%T[79N=2"Y86)L\VYU(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@
M=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S
M='(@(EIA9&%J=&4@92UM86EL;W;Z(&%D<F5S=2P@;F$@:W1O<OH@9&]S=&%N
M971E(&YO=ND@:&5S;&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T
M97(B"FUS9W-T<B`B5FQOOFF[(&)U;FMU('IA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS
M97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E9L;[YINR!B=6YK=2!P<F5D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")6;&^^
M:;L@<W3E<&5C('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O
M<F4B"FUS9W-T<B`B5FQOOFF[('-TY7!E8R!P<F5D(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`B5FQOOG1E('-P<N%V>2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R(")6;&^^:;L@;V1S=&%V96,@
M>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM
M<V=S='(@(E9L;[YINR!O9'-T879E8R!P<F5D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS
M97)T(')O=R!A9G1E<B(*;7-G<W1R(")6;&^^:;L@<FEA9&]K('IA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B5FQOOFF[(')I
M861O:R!P<F5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I
M9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y
M('%U97-T:6]N.B(*;7-G<W1R("):861A:G1E('!OOF%D;W9A;OH@;V1P;W9E
M[R!N82!B97IP9>AN;W-T;OH@;W3A>FMU.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I
M9GD@26UA9V4B"FUS9W-T<B`B5FQOOFF[+W5P<F%V:;L@;V)RX7IO:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G
M:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R(")6;&^^:;LO=7!R879I
MNR!L:6YK=2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYA(&]D;W-I96QA;FEE('!R
M92!Z;WIN86T@<'+M:F5M8V]V(&YE;>%T92!D;W-T871OZ&[](&MR961I="XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(").961O<W1A=&_H;OT@
M:W)E9&ET+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<Y"FUS9VED("))
M;G1E9V5R(@IM<V=S='(@(D-E;.D@Z.US;&\B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(EIO>FYA
M;2!C96S]8V@@Z&ES96PB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"FUS9W-T<B`B3F5P;&%D;ND@541(("A5<V5R($1A=&$@2&5A9&5R
M+"!(;&%V:>AK82!P;W6^[79A=&6U<VO]8V@@^F1A:F]V*2XB"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S
M+WII<"YP:'`Z,3DT"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q
M,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R(").97!L871NZ2#Z
M9&%J92!F;W)MX71U(%I)4"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(").97!L
M871NX2!A<&QI:^%C:6$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@
M(DYE<&QA=&[I($E$(&3A=FMY+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#DQ(&QI8B](;W)D92]&;W)M+G!H<#HR,38R(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C,V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S`S(&QI8B](;W)D92]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+B(*;7-G<W1R(")";VQI(&]D;W-L86[I(&YE<&QA=&[I(/ID
M86IE+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(DYE<&QA=&[A(&-I9;5O=N$@861R97-A+B(*"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]D8G@N<&AP.C$P.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ
M,SD*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("))
M;G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(DYE<&QA=&[](&9O<FWA="!S
M^F)O<G4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS
M9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(").97!L871N_2!L
M:6-E;NAN_2!KM?KH+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(D)O;&$@>F%D86[A(&YE<&QA=&[A(&QO:V%L:71A+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED
M(&US9U]T>7!E+B(*;7-G<W1R(").97!L871NX2!H;V1N;W1A(&US9U]T>7!E
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(").97!L
M871NX2!A;&5B;R!C:/UB86KZ8V$@:&]D;F]T82!A<&E?:60N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(").97!L871NZ2!A
M;&5B;R!C:/UB86KZ8V4@<&%R86UE=')E+B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B3F5P;&%T;ND@<F]D:>AO=G-KZ2!P<N%V;RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED
M('!A<G1N97(@:60N(@IM<V=S='(@(DYE<&QA=&[I(&ED('!A<G1N97)A+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN
M=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(").97!L871N_2!K\V0@<')O
M9'5K='4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(DYE<&QA=&[]
M('!R;W1O:V]L(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI
M9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(").97!L871N_2!P<NUJ96UC
M83H@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#<U(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE
M8W0B"FUS9W-T<B`B3F5P;&%T;OT@;V)J96MT('ID:66U86YI82(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A
M;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(").97!L871NX2!Z9')O:F]V
MX2!A9')E<V$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(").
M97!L871NZ2#Z9&%J92!U;FEC;V1E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G3A
M<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S4*
M;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B26YV97)T;W9ANR!V
M_6)E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G
M<W1R("))<N%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER86LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DER96QA;F0B"FUS9W-T<B`BS7)S:V\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("))<VQE
M(&]F($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")/:F5D
M:6YE;.D@8OIR:WDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))>G)A96PB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(E9Y9&%V871EM2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@
M(DMU<GKM=F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(E1A;&EA;G-K;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:FMA(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y.2!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T
M<B`B2F%N=>%R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!O;G-K;R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIO<F1A;B(*;7-G<W1R(")*;W)DX6XB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*^FPB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*
M;7-G<W1R(")*^FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(EIA
M<F]V;F&[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@
M(EIA<F]V;F&[(&1O('-T<F5D=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U
M;&PB"FUS9W-T<B`B6F%R;W9N8;L@9&\@8FQO:W4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B
M2G5S=&EF>2!,969T(@IM<V=S='(@(EIA<F]V;F&[(':U879O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*
M;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B6F%R;W9N8;L@=G!R879O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%C:'-T86XB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8S"FUS9VED
M(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")0;VYE8VAANR!O<FEG:6[A;#\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME\F$B"@HC.B!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!S97)V97(@
M>F%M:65T;VP@875T96YT:69I:^%C:74N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")+97)N
M96PM;F]VX>AI:V]V:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")6>71V;W)E;FEE(&NU
M^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+
M97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B1&EG:73A;&YY(&]D=&QAZ&]K(&NU
M^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(D3EOFMA(&NU^NAA(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4
M>7`@:[7ZZ&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM
M<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E!O=;YI=&EE(&NU^NAA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(DNU
M^N@@=;X@97AI<W1U:F4@;F$@<V5R=F5R:2!V97)E:F[]8V@@:[7ZZ&]V+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G
M<W1R(")$971I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T
M:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`BI75D;W9O9&5M;VMR871I8VOA(')E<'5B;&EK82!+
M\W)E82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DOS
M<F5J<VOA(')E<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T
M"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`B2W5V86IT(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM
M<V=S='(@(DMI<F=IN7-K;R(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")6>E]HM6%D(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B2F%Z>6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B4&]S;&5D;N$@<&]L
M;W9I8V$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA
M<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(E!O<VQE9&[A('IM96YA(&AE
M<VQA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N
M+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(E!O<VQE9&[A
M(+ET=G*[(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B4&]S;&5D;N$@86MT=6%L:7KA8VEA.B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B4&]S;&5D;ND@<')I:&SA<V5N
M:64Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E!O
M<VQE9&[I('!R:6ALX7-E;FEE.B`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B
M4&]S;&5D;ND@<')I:&SA<V5N:64Z(&YI:V1Y(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B
M"FUS9W-T<B`B3&]T>;ES:V\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R(")0<N%V;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(E9Z:+5A9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B3F5C:&%J=&4@<'+A>F1N92!P<F4@OFEA9&5N
M(&]K<F%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B5K5A=F\B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B2&QA
M=FGH:V$@=K5A=F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-`IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B2&]D;F]T>2!VM6%V;R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R("+:<F]V
M9?(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EBZ7)I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),[6)Y82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:6-H=&5NN71A:FYS:V\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM
M<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("*E86AKZ2!M<FAO;&5N:64B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM
M<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("*E86AK_2!DX;[O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B4N%N;R"U86AK_2!DX;[O(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@
M(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(").97-K]'(@M6%H:_T@9.&^[R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("*E86AKZ2!D8;[O;W;I
M('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S
M='(@(J5A:&O](&3AON\@<R!H<FUE;NUM(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS
M9W-T<B`BI6%H:^D@<VYEOF5N:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B
M"FUS9W-T<B`BI6%H:^D@<VYE:&]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM
M97)I8VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN
M:R(*;7-G<W1R("),:6YK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@
M=&\Z(@IM<V=S='(@(DQI;FMA('5K87IU:F4@;F$Z(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B
M4')E<&]J:;L@92UM86EL;W;Z(&%D<F5S=2!S;R!S='+A;FMO=2!N82!P[7-A
M;FEE('!ON71Y(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X
M="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("),:6YK>2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM
M<V=S='(@(DQI;G5X($-O;VMI92(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@
M9F]L9&5R(@IM<V=S='(@(EIO>FYA;2`M('!O=;[M=F%T9;4@=79I9.T@<')I
M9>AI;F]K(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES
M="!$871A8F%S97,B"FUS9W-T<B`B5GEP[7-ANR!Z;WIN86T@9&%T86+A>B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE
M;'`@5&]P:6-S(@IM<V=S='(@(EIO>FYA;2!TZ6T@4&]M;V-N[6MA(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS
M9W-T<B`B5GEP[7-ANR!Z;WIN86T@=&%B=6QI96LB"@HC.B!L:6(O2&]R9&4O
M34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G
M<W1R("),:7-T+4%R8VAI=F4B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T+4AE;'`B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI
M<W0M260B"FUS9W-T<B`B3&ES="U)9"(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T
M+4]W;F5R(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS
M9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB
M92(*;7-G<W1R("),:7-T+5-U8G-C<FEB92(*"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G
M<W1R("),:7-T+55N<W5B<V-R:6)E(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("):;V)R87IE;FEE('-E9&5N[2!Z;'EH86QO.B`E
M<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B6F]B<F%Z
M96YI92!P;W6^[79A=&6U;W8@>FQY:&%L;SH@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(EIO8G)A>F]V86YI92!Z;WIN86UU('!O
M=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A=/IR
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='9A(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I
M;F<N+BXB"FUS9W-T<B`B3F'H[71A=F$@<V$N+BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS
M9W-T<B`B36EE<W1N>2#H87,Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQO:V%L:7KA
M8VEA(&$@Z&%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R("),;VMA;&ET82(*"B,Z(&QO9VEN+G!H<#HQ.#8@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R(")0<FEH;.%S96YI92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S
M<VEO;B(*;7-G<W1R("):X7IN86UY('!R961C:.%D>F%J^F-E:B!S>6YC:')O
M;FEZX6-I92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*
M;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3V1H;.%S:;LB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(E!R:6AL
MX7-E;FEE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B
M3&]G:6X@5&%S:W,B"FUS9W-T<B`BVFQO:'D@<')I('!R:6ALX7-E;NTB"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)0<FEH;.%S96YI92!Z;'EH86QO
M+"!P<F5T;[YE('-T92!Z861A;&D@;F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@
M;65N;R!A;&5B;R`B"B)H97-L;RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3@X"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(E!R:6ALX7-E;FEE
M('IL>6AA;&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD*;7-G:60@
M(DQO;F<@=&5X="(*;7-G<W1R(")$;&C]('1E>'0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B3.%S:V$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B3&]W(@IM<V=S='(@(D[M>FMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@
M9W)E96L@;&5T=&5R<R(*;7-G<W1R(")-86SI(&=RZ6-K92!P[7-M96[A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")-
M86SI(&QA=&EN<VOI('#M<VUE;N$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(DUA;.D@<NUM<VME(.CM<VQI8V4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)S:V\B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,SDX(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,S8*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R(")3<'+A
M=F$@9/)A(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V
M"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(E!R[6QO:&$@35,M5$Y%1B!N96]B<V%H;W9A;&$@OFEA9&YE
M(/ID86IE+B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86-E
M9/-N<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-K
M87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(DWA9VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C@S"FUS9VED(")-86EL(@IM<V=S='(@(E!ON71A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R
M(")0;W-L8;L@92UM86EL(&%D;6EN:7-T<N%T;W)O=FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G
M:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B5GET=F]R:;L@;&EN7VMU+BXN
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M86QA>7-I82(*;7-G<W1R(")-86QA:GII82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B
M"FUS9W-T<B`B36%L961I=GDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B36%L
M:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N
M(@IM<V=S='(@(B(*(E-P<F%V;W9ANR!Z;WIN86T@:V%T96?S<FGM+"!S(&MT
M;W+];6D@;WIN8>AU:F5T92!P;VQOOFMY(&$@9F%R8GD@87-O8VEO=F%NZ2`B
M"B)S('3];6ET;R!K871E9_-R:6%M:2XB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S
M='(@(DUA<&$@36%P,C0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`X-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<&$@
M36%P475E<W0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*
M;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B36%P;W9A;FEA('5L
M;[YE;NDN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G
M:60@(DUA<F-H(@IM<V=S='(@(DUA<F5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(D]K<F%J(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B
M"FUS9W-T<B`B3WIN8>AINR!P<NUZ;F%K;6D@4')EZ.UT86[I+TYE<')EZ.UT
M86[I(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS
M9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*2(*;7-G<W1R(")/>FYAZ&F[(&EN_6UI('!R[7IN86MM:2`H;F%P
M<BX@1/1L9;YI=.DO6F]D<&]V961A;NDI(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL;W9E(&]S=')O=GDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6LB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM
M<V=S='(@(EIH;V1NZ2!P;VQI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G
M<W1R(")-875R973A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B
M36%U<NUT:75S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X
M:6WA;&YY('!O=F]L96[](&MR961I="XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N(@IM<V=S='(@(D)O;"!P<F5K<F_H96[](&UA>&EMX6QN>2!P
M;^AE="#H87-T[2!S<'+A=GDN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(").
M86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#(T(&AO9.UN.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B3F%J=GFYN6EA('1E<&QO=&$@>F$@<&]S
M;&5D;OUC:"`V(&AO9.UN.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-87AI
M;>%L;GD@<&_H970@8FQO:V]V('!O<G3A;'4B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.3`R(&QI8B](;W)D92]&;W)M+G!H<#HQ,C(Q(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")-
M87AI;>%L;F$@9.6^:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DWA:B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T
M=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:6/M;F$B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB
M97)S(@IM<V=S='(@(LAL96YO=FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("):;V)R87IE;FEE
M(&UE;G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B6FSZ
MZ&F[(&)U;FMY(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")3<'+A=F$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E-P
M<N%V82!B;VQA(/IS<&6Y;F4@;W9E<F5NX2P@86QE(&-E<G1I9FEKX70@<&]D
M<&ES=2!S82!N97!O9&%R:6QO(&]V97)INRXB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D
M+B(*;7-G<W1R(")0;&%T;F]SNR!S<'+A=GD@=GEP<KEA;&$N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B5'EP('-P<N%V
M>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A
M=&AE<B(*;7-G<W1R(")0;^AA<VEE($UE=&%R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`BVF1A:F4@365T87(@;FEE('/Z(&1O<W1U<&[I+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B+:9&%J92!-971A<B!N:64@
M<_H@:R!D:7-P;WKM8VEI+B!$971A:6QY(&)O;&D@>F%Z;F%M96YA;ND@<')E
M(&%D;6EN:7-T<N%T;W)A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS
M9W-T<B`B4WES=.EM($UE=&%R1$(@;FEE(&IE('!R:7!O:F5N_2XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DUE
M=/-D82(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R
M9&4O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H
M;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=/-D82!<(B5S
M7"(@;FEE(&IE(&1E9FEN;W9A;N$B"@HC.B!L:6(O2&]R9&4O4E!#+W)E<W0N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B3F5D969I;F]V86[A(&UE
M=/-D82X@5F]L86[I('H@;65T\V1Y.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED
M(")-971R:6,B"FUS9W-T<B`B365T<FEC:^DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*
M;7-G<W1R(")-97AI8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;V[I>G-K92!F961E<F%T[79N92"Y
M=.%T>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(E-T<F5D(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE
M(%1Y<&4B"FUS9W-T<B`B5'EP($UI;64B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(DYA:FYIOKEI82!T97!L;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(").86IN:;ZY:6$@=&5P;&]T82!Z
M82!P;W-L961N_6-H(#8@:&]D[6XZ("(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9"(*;7-G<W1R(")-:6YI;>%L;F$@9&]B82!P;&%T;F]S
M=&D@:&5S;&$@9;ET92!N979Y<'*Y86QA(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S,PIM<V=I9"`B36ER<F]R(@IM<V=S='(@
M(EIR:V%D;&]V;R!O8G+A=&F[(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(E+T>FYE(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%10
M7U)E<75E<W0N(@IM<V=S='(@(D-H_6)A(&)A;.UK(%!%05(@2%144%]297%U
M97-T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*
M(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"B)#:/UB82!K;VYF:6=U<N%C:6$N($%K(&-H8V5T92!P
M;W6^[79ANR!T^G1O(&%P;&EKX6-I=2P@;75S[71E('1E<F%Z("(*(G9Y9V5N
M97)O=F&[(&MO;F9I9W5RX6-I=2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*
M;7-G<W1R(")#:/UB82!)1"!S<'+A=GDN(@H*(SH@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B0VC]8F$@<&^^861O=F%N
M_2!014%2(&)A;.UK($UA:6PN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS
M9W-T<B`B0VC]8F$@240@<F5LX6-I92XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")0
M;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO
M8FEL92!-86EL(@IM<V=S='(@(DUO8FEL;OT@;6%I;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T
M92(*;7-G<W1R(")-:65R;GDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D
M:69I960@1&%T92(*;7-G<W1R(")$X71U;2!P;W-L961N96H@>FUE;GDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B57!R879INR!54DPB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D
M=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U
M8FQI8R!O9B(*;7-G<W1R(")-;VQD879S:V\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*
M;7-G<W1R(")-;VYA:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO
M;F=O;'-K;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@X"FUS9VED(")-
M;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-97-I86,@82!R;VLB"@HC.B!L:6(O
M2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S
M='(@(DUE<V'H;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N
M='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B365S8>AN
MZ2!FX7IY(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O0U-6
M+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M3F$@<FEA9&MU("5D(&)O;&\@;N%J9&5N_6-H('9I86,@<&]L[2!A:V\@;^AA
M:^%V86[]8V@@)60N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]K
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S
M"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B4')E=F&^;F4@:F%S;F\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM
M<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")0<F5V8;YN92!O8FQAZ&YO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")0<F5V8;YN92!S;&YEZ&YO
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-
M;W9E($1O=VXB"FUS9W-T<B`B4')E<W5N^KL@9&]L=2(*"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S
M='(@(E!R97-U;OJ[(':U879O(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E!R97-U;OJ[
M('9P<F%V;R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P-0IM
M<V=I9"`B36]V92!5<"(*;7-G<W1R(")0<F5S=6[ZNR!H;W)E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PIM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(E!R97-U;OJ[(&1O;'4B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(R(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C,*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
M4')E<W5N^KL@:&]R92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-
M;WIA8FUI:R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B5FEA8_IR;W;R
M;W;I('9Y8F5R86-I92!Z;WIN86UY(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-@IM<V=I9"`B
M375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E9I86-NX7-O8F[](';]8F5R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@
M06-C;W5N="(*;7-G<W1R(")-;VIE(&MO;G1O(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(DEN9F]R;>%C:64@;R!M;VIO;2#ZZ'1E(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@
M(DWT:B!P;W)TX6PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V
M"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(E9Z:+5A9"!M]&IH
M;R!P;W)TX6QU(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DYI92P@3D53
MVDA,05/-32XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@
M(DUE;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M[6)I82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM
M<V=S='(@(DYE<.%L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(")(
M;VQA;F1S:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T
M<B`B2&]L86YD<VOI($%N=&EL>2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("):
MX6ML861NX2!54DP@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B55),('!R92!Z;F5P;&%T;F5N:64@8V5R=&EF:6OA=&]V($-!
M($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B55),('!R
M92!P;VQI=&EK=2!#02!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G
M<W1R(")54DP@<')E(&]B;F]V96YI92!P;&%T;F]S=&D@8V5R=&EF:6OA=&]V
M($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*
M;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(E523"!P
M<F4@>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O=B!.971S8V%P92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!3
M4TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B365N;R!34TP@<V5R=F5R82!.971S
M8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED
M(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(DMO;65N
M=.%R(&-E<G1I9FEKX71U($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4B"FUS9W-T<B`B5'EP(&-E<G1I9FEKX71U($YE='-C87!E(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G
M<W1R(")3:66[(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(U(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3FEK9'DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]VX2!+86QE9/-N:6$B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B
M3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=N$@:V%T96?S<FEA(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL
M<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(DYO=N$@<W!RX79A('!R92`E<R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3F]V(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B
M3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]VZ2!P;W6^[79A
M=&6U<VOI(&UE;F\@*&YE<&]V:6YNZ2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD
M(@IM<V=S='(@(DYO=OT@6NEL86YD(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B3F]V
MZ2!H97-L;R(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H
M<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E
M>"XB"FUS9W-T<B`B4&QA=&YO<[L@;F]VZ6AO(&AE<VQA('9Y<'*Y[2`E>"XB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DYO=ND@:&5S;.$@
M;FEE('/Z(')O=FYA:^DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*
M;7-G<W1R(").;W;I(&]K;F\@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").
M97=S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B
M3F5W<V=R;W5P<R(*;7-G<W1R(")$:7-K=7-NZ2!S:W5P:6YY(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS
M9W-T<B`BSV%L96HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@
M(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B3F%S;&5D=6KZ8V4@-"!FX7IY(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S(@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("+/86RY
M:64@;F%S=&%V96YI82(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z,3`S
M"FUS9VED(").97AT/B(*;7-G<W1R(").87-L961U:OIC83XB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G=6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M(@IM<V=S='(@(DYI9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI
M9^ER:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS
M9VED(").:6=H="(*;7-G<W1R(").;V,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T
M<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(DYI92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS
M9W-T<B`B(@HB3FEE('/Z(&1O<W1U<&[I(+YI861N92!K;VYF:6=U<F'H;ND@
M^F1A:F4L('!R92!K=&]RZ2!B>2!S82!D86QI('IO8G)A>FF[("(*(G)O>F1I
M96QY+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM
M<V=S='(@(E!R92!V>71VX7)A;FEE($E33R!O8G)A>F]V(&YI92!J92!K(&1I
M<W!O>NUC:6D@OFEA9&YA('-T<F%TZ6=I82XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA
M=&4N(@IM<V=S='(@(DYE97AI<W1U:F4@N6%B;/-N82!P<F4@9.%V:W4N(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-SD@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`B3F$@<&^^861O=F%N96H@<&]Z[6-I:2!N
M965X:7-T=6IE(+YI861E;B!B;&]K+B(*"B,Z(&QI8B](;W)D92]!=71H+VUC
M86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0<F4@34-!3"!A=71E
M;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&UE;F\@:V%L96YDX7)A+B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(JYI861N82!Z;65N82XB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B2R!T;VUU=&\@<'+A=G4@;F5M;[YN
M;R!P<FED8;L@OFEA9&YE('!O9')I861E;ND@<'+A=F$N(@H*(SH@;&EB+TAO
M<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H<#HU,#@@;&EB+TAO<F1E+U5T:6PN
M<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(E!R92`E
M<R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82XB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z.#0T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B4')E($944"!61E,@
M;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N(@H*(SH@;&EB+U9&4R]S<6PN
M<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(E!R92!344P@5D93(&YE
M8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+B(*"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B4')E(%-1
M3"U&:6QE(%9&4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@
M8W)E9&ET(&QE9G0N(@IM<V=S='(@(JYI861E;B!K<F5D:70N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DYE8F]L;R"Y<&5C:69I:V]V
M86[I(&UI97-T;R!U<NAE;FEA+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HY,#,*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B4_IB;W(@
M;F5B;VP@;F%H<F%N_2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*
M;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(").96)O;&D@;N%J9&5N
MZ2"^:6%D;F4@:6MO;GDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS
M9W-T<B`B3FEE(&IE(&YA<W1A=F5NX2!L;VMA;&ET82XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B3F5B;VQA('IA9&%NX2!L;VMA;&ET82XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").
M;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(").96)O;&$@>F%D86[A(+YI
M861N82!S<'+A=F$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYE
M8F]L;R"Y<&5C:69I:V]V86[I(+YI861N92!M96YO+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S
M<&5C:69I960N(@IM<V=S='(@(DYE8F]L;R"Y<&5C:69I:V]V86[I(.CM<VQO
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(JYI861N92!U<N&^;&EVZ2!F;W)T
M=6YY(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")0<F4@2%144"!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I
M(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(E!R92!)34%0(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z
M861A;ND@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-S(*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E($ME<F)E<F]S(&%U=&5N=&EF:6OA
M8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<V%S;"YP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&QI
M8B](;W)D92]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E
M($QO9VEN(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(E!R92!005-35T0@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%N
MZ2!H97-L;RXB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")0<F4@4TU"(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A
M;ND@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W
M"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B).96)O;&$@>F%D
M86[A(&-E<W1A(&L@<')O9W)A;74@3W!E;E-33"X@4')O9W)A;2!/<&5N4U-,
M(&IE('!O=')E8F[](&YA('!RX6-U("(*(G,@^F1A:FUI(%!+0U,@,3(N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B
M3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("*N:6%D;F4@<')E8FEE:&%J
M^F-E('!R:6ALX7-E;FEA+B(*"B,Z(&QI8B]61E,N<&AP.C<V-0IM<V=I9"`B
M3F\@<75O=&$@<V5T+B(*;7-G<W1R(")+=O-T82!N:64@:F4@;F%S=&%V96[A
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(D)E>B#H:6%R(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S
M<&5C:69I960N(@IM<V=S='(@(DYE8F]L(+EP96-I9FEK;W9A;OT@;V1D9;5O
M=F'H+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(D)E>B!S='+A
M;B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R(")3^F)O<B!N96[A:F1E;OTB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(E!R92!V>7)O=F[A
M=F%C:74@<&%MY+L@;FEE(&IE(&1O<W1U<&[](+YI861E;B!D;^AA<V[]('!R
M:67H:6YO:RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").96)O;&\@
M;V1O<VQA;ND@<&]UONUV871EM7-KZ2!M96YO(&$O86QE8F\@:&5S;&\N(@H*
M(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B3F5B;VQI('9RX71E;ND@
M<&QA=&[I(%A-3"#Z9&%J92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-S$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDX,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3DR"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y
M"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`BKFEA9&YE(&AO9&YO='DB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB5B!P]'9O9&YE:B!K;VYF:6=U
M<N%C:6D@;F5B;VQA(&[A:F1E;N$@OFEA9&YA('9E<GII82X@5GEG96YE<G5J
M=&4@>FYO=G4@(@HB:V]N9FEG=7+A8VEU+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(E8@:V]N9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A(+YI861N82!V
M97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I9W5RX6-I=2XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@
M(JYI861E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B
MKFEA9&YE("AP;W6^:;L@:6UP;&EC:71N^B!H;V1N;W1U*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@
M(D]S=')O=B!.;W)F;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI
M8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R
M92(*;7-G<W1R(")3979E<F[A('!O;&]G=;5A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R
M;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B4V5V97)NZ2!-87)IX6YS:V4@
M;W-T<F]V>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(D[S<G-K;R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T
M97(B"FUS9W-T<B`B3F5P;&%T[2!P;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYE<&QA
M=.T@<')E9"(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$R"FUS9VED(").;W0@
M82!D:7)E8W1O<GDB"FUS9W-T<B`B3FEE(&IE(&%D<F5SX7(B"@HC.B!L:6(O
M5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E
M9"XB"FUS9W-T<B`B3FEE(&IE(&EM<&QE;65N=&]V86[I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO
M="!S970B"FUS9W-T<B`B3F5N87-T879E;NDB"@HC.B!L:6(O5D93+G!H<#HQ
M.3,@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP.C(S,R!L:6(O5D93+G!H
M<#HR-3$*(SH@;&EB+U9&4RYP:'`Z,C8X(&QI8B]61E,N<&AP.C(X-"!L:6(O
M5D93+G!H<#HS,#`@;&EB+U9&4RYP:'`Z,S$U"B,Z(&QI8B]61E,N<&AP.C,S
M,B!L:6(O5D93+G!H<#HS-C4@;&EB+U9&4RYP:'`Z-#(U(&QI8B]61E,N<&AP
M.C4P-`HC.B!L:6(O5D93+G!H<#HU-S,@;&EB+U9&4RYP:'`Z-3DP(&QI8B]6
M1E,N<&AP.C8V.`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-2!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$X.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3FEE(&IE('!O
M9'!O<F]V86[I+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(E!O
M>F[A;6MY(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS
M9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3FGH
M(&YA('!R97IE<F%N:64L('9RX;MT92!S82!S<.2[+B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R
M(").;W9E;6)E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4P"FUS9VED
M(").=6UB97(B"FUS9W-T<B`BR.US;&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B
M4&_H970@>FYA:V]V(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*
M;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(E!OZ&5T('-TY7!C
M;W8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M
M8F5R(&]F(')O=W,B"FUS9W-T<B`B4&_H970@<FEA9&MO=B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@
M;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(E!R92!A:W1U86QI>N%C:74@>F]Z;F%M=2!P<NUJ96UC
M;W8@;F5B;VQI(+EP96-I9FEK;W9A;ND@Z.US;&$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G
M<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HX-S`*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE:W0B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T
M;W(B"FUS9W-T<B`B075T;W(@;V)J96MT=2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R(")/<VUIZ&MO=OTB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E
M<B(*;7-G<W1R(")/:W3S8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT97(@;F$@
M;F%DX79K>2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G
M:60@(D]F9FEC92(*;7-G<W1R(")0<F%C;W9I<VMO(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(E-T87+I(&$@;F]V
MZ2!H97-L;R!M=7-I82!B>;L@;V1L:;ENZ2XB"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R
M(")3=&%RZ2!H97-L;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G
M<W1R(")3=&%RZ2!H97-L;R!N96)O;&\@>F%D86[I('-P<N%V;F4N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(D]MX6XB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(DEB82!)34%0('-E<G9E
M<GD@<&]D<&]R=6KZ('ID:66U86[I('!R:67H:6YK>2XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S(@IM<V=S='(@(DEB82!U<N&^;&EVZ2!F;W)T=6YY(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S4*;7-G
M:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B
M2F4@<'+M<'5S=&[A(&EB82!J961N82!E+6UA:6QO=N$@861R97-A+B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B
M"FUS9W-T<B`B(@HB5FQA<W1N[6MA(&%L96)O('!RX79A('9L87-T;NUK82!P
M<F4@>F1I9;5A;OT@;V)J96MT(&WTOF4@>FUE;FF[(&EB82!V;&%S=&[M:R`B
M"B)A;&5B;R!S>7-TZ6UO=OT@861M:6YI<W1RX71O<B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C0P"FUS9VED
M(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")/='9O<FF[('8@;F]V
M;VT@;VMN92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C0U"FUS
M9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R
M;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R(")#:'EB82!/<&5N4U-,
M.B!N97!O9&%R:6QO('-A('KM<VMANR#Z9&%J92!Z('!O9'#M<V%N96H@Z&%S
M=&D@4R]-24U%+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R(")/='9O<FF[('3Z=&\@;&EN:W4@=B!N
M;W9O;2!O:VYE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED
M(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P97)AZ&[]('-Y<W3I;2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P
M=&EO;G,B"FUS9W-T<B`B3F%S=&%V96YI82(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(").87-T879E;FEA
M("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(EIO<F%D96[]('IO
M>FYA;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED
M(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI>N%C:6$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N
M86P@56YI="(*;7-G<W1R(")/<F=A;FEZ8>ANX2!J961N;W1K82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B
M"FUS9W-T<B`B3W)G86YI>F]V86YI92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*
M;7-G<W1R(")0]'9O9&[A(+EA8FSS;F$@87!L:6OA8VEE(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")0]'9O9&[I(+EA8FSS;GD@
M=B`E<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("));NDB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R("+/86RY:64@:6YF;W)MX6-I92(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(E!RX79A('9L87-T;NUK82(*"B,Z(&QI8B](;W)D
M92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")004T@875T96YT:69I:^%C:6$@
M;FEE(&IE(&1O<W1U<&[A+B(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B
M4$5!4CI-86EL(&)A8VME;F0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M1&EG:73A;&YY('!O9'!I<R!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
MVF1A:F4@>F&Y:69R;W9A;ND@<&]M;V-O=2!01U`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G
M<W1R(")01U`@=F5R96IN_2!KM?KH(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*
M;7-G<W1R("+:9&%J92!P;V1P[7-A;NDO>F&Y:69R;W9A;ND@<&]M;V-O=2!0
M1U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E
M(@IM<V=S='(@(E!(4"!K\V0B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@4VAE;&PB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@
M3&EG:'0@4F%I;B(*;7-G<W1R(")0;W!O;'5D;NT@M6%H:_T@9.&^[R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED
M(")032!3:&]W97)S(@IM<V=S='(@(E!O<&]L=61N[2!P<F5HX6YK>2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(E!O<&]L=61N[2!S;F6^96YI92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")0
M32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4&]P;VQU9&[M('-N96AO=ND@<')E
M:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E!O<&]L=61N[2!S;F6^96YI
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")0;W!O;'5D;NT@8OIR:WDB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E
M>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")#:/UB82!R;WJY[7)E;FEE
M(%!/4TE8(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL
M(@IM<V=S='(@(E!?2%`@4VAE;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM
M<V=S='(@(E9Y<&QN96YI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B
M4&%K:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")086QA=7-KZ2!O
M<W1R;W9Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9"(*;7-G<W1R(")086QE<W3M;G-K92#Z>F5M:64B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A
M;F%M82(*;7-G<W1R(")086YA;6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN
M96$B"FUS9W-T<B`B4&%P=6$@3F]VX2!'=6EN96$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A
M9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM
M<V=S='(@(LAI87-T;^AN92!O8FQAZ&YO(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`R,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&QI8B].
M970O4TU3+W=I;E]H='1P+G!H<#HQ-3$@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D
M(@IM<V=S='(@(DAE<VQO(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B2&5S;&\@8F]L;R#Z<W!EN6YE('IM96YE;NDN(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I
M;F-O<G)E8W0B"FUS9W-T<B`B3F5S<'+A=FYE(&AE<VQO(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R92!A
M=71E;G1I9FEKX6-I=2!2041)55,@:F4@=GF^861O=F%NZ2!H97-L;RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U-PIM<V=I9"`B4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2&5S;&\@<R!P;W1V<F1E;NUM(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S
M=V]R9#HB"FUS9W-T<B`B2&5S;&\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B2&5S;&\Z
M("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS
M9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B2&5S;.$@;75S
M:6$@8GF[(')O=FYA:^DN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(E9L;[YINR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E
M(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E9L;[YINR!Z;R!S8VARX6YK>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*
M;7-G:60@(E!A=&@B"FUS9W-T<B`B0V5S=&$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G
M<W1R(")0<F5B:65H86KZ8V4@<F5G:7-T<N%C:64Z(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`BI75D:6$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")097)C96YT(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")6>6MO;F&[
M(&]P97+A8VEE(/ID<KYB>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\B"FUS9W-T<B`B5GEK;VYANR!O<&5RX6-I92#Z9'*^8GD@<')I('!R
M:6ALX7-E;NT_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4'+A=F\B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I
M;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")0<N%V;R!<(B5S7"(@
M;F5B;VQO('9Y;6%Z86[I+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.3`*;7-G
M:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!R[7-T=7`@>F%M:65T
M;G5T_2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,38Q(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M(")0<N%V82(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<N%C:6$@<'+A
M=B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N
M86P@26YF;W)M871I;VXB"FUS9W-T<B`B3W-O8F[I(&EN9F]R;>%C:64B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")$;VWA8V4@>G9I97)A
M=.$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP[6YY(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@
M(E!H;VYE(@IM<V=S='(@(E1E;&5F\VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;V=R869I
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G
M:60@(E!I>&5L<R(*;7-G<W1R(")";V1O=B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W
M"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B
M2VQI:VYI=&4@<')O<^UM(&1O(&YE:F%K96H@8G5N:WDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#HB"FUS9W-T<B`B4&]T=G+O=&4@<')O<^UM+""^92!C:&-E
M=&4@;V1S='+A;FF[('1E;G1O(&5L96UE;G0Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(E!O='9R[W1E('!R;W/M;2P@OF4@8VAC971E(&]D
M<W1RX6YINR!L:6YK=2!Z('1O:'1O(&5L96UE;G1U+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-38V"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+B(*;7-G<W1R("):861A:G1E('!R;W/M;2!M97-I86,@82!R
M;VLN(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ(@IM<V=S='(@(EIA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO
M=OH@:V%T96?S<FEU.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`U"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M("):861A:G1E('!R;W/M;2!P;&%T;OH@25`@861R97-U+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-C0W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+B(*;7-G<W1R("):861A:G1E('!R;W/M;2!P;&%T;OT@9.%T=6TL('-K;VYT
M<F]L=6IT92!P;^AE="!D;NT@=B!M97-I86-I+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+B(*;7-G<W1R("):861A:G1E('!R;W/M;2!P;&%T;OT@Z&%S+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B4')O
M<^UM('5V9>]T92!Z:')N=71I92!P<F]B;.EM=2XB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(E!R;W/M;2!Z861A:G1E('-V;VIE('!O=;[M=F%T
M9;5S:^D@;65N;R!A(&AE<VQO(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@
M(@HB<WES=&5M+B(*;7-G<W1R("(B"B)0<F7H[71A:G1E('-I('!R;W/M;2!N
M87-L961U:OIC:2!T97AT+B!-55/-5$4@<_IH;&%S:;L@<R!P;V1M:65N:V%M
M:2`B"B)P;W6^[79A;FEA('-Y<W3I;74N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B6F%D86IT92!P<F]S[6T@
M;65N;R!P<F4@;F]V^B!K871E9_-R:74Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS
M9W-T<B`B4&^U<VMO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS
M9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EK82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(D%N
M:V5T>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L<VMO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E
M(@IM<V=S='(@(E5M:65S=&YE;FEE('1O:'1O(&]B<N%Z:W4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")5;6EE<W1N96YI
M92!T96IT;R!T86)UM6MY(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF
M;W)C960@8GD@24U!4"DB"FUS9W-T<B`B3V1O<VQANR!D;R!T;VAT;R!P<FEE
MZ&EN:V$@*&YE=GEN=6-U:F4@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*
M;7-G<W1R("):<N&^:WD@>F$@<&]S;&5D;OUC:"`E<R!H;V3M;CH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP
M:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")0<F%V9&5P;V1O8FYO<[L\
M8G(@+SYZ<N&^;VLB"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z.3@*
M;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@<&^^861O=F%NZ2!R;WJY
M[7)E;FEE($Q$05`@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E+U!R
M969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R
M969S7W-E<W-I;VXZ('!OOF%D;W9A;ND@<F]ZN>UR96YI92!S97-S:6]N(&YE
M8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS
M9VED(")0<F5S<W5R92(*;7-G<W1R(")4;&%K(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(E1L86L@;F$@^G)O=FYI(&UO<F$Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T
M<B`B5&QA:SH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B56OA
MOFMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B6F]B<F%Z:;L@=6OAOFMU(&]B<N%Z:W4@
M=B!N;W9O;2!O:VYE(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C(@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8*;7-G:60@(E!R979I;W5S(&]P
M=&EO;G,B"FUS9W-T<B`B4')E9&-HX61Z86KZ8V4@;F%S=&%V96YI82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G
M:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(E9Y=&QAZ&F[(&1O:W5M96YT
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV
M871E($ME>2(*;7-G<W1R(")0<FEVX71N>2!KM?KH(@H*(SH@;&EB+TAO<F1E
M+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;.EM
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M
M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!O<&ES('!R;V)LZ6UU(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS
M9W-T<B`B4')O:F5K='DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W
M-`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5OUZ=F$@;F$@>F%D86YI
M92!T97AT=2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4'5B;&EC($ME>2(*;7-G<W1R(")697)E:F[](&NU^N@B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!
M;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UU<R!V97)E:F[I:&\@:[7ZZ&$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R;>%C:64@;R!V97)E:FYO;2!K
MM?KH:2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B5F5R96IN_2]P<FEVX71N>2!KM?KH;W;]('#A<B!N
M96)O;"#Z<W!EN6YE('9Y9V5N97)O=F%N_2XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@
M4FEC;R(*;7-G<W1R(")0;W)T;W)I:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G
M<W1R(")+871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B
M475E<GDB"FUS9W-T<B`B1&]T87HB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMV\W1A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!('9E<F5J;OT@
M:[7ZZ"`H)60@8FET;W8I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C@*
M;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")0<F5P[6YAZ"!S(';]
M8F5R;VTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")$X;[O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R
M;'DB"FUS9W-T<B`B4N%N;R!DX;[O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R
M(").97-K]'(@9.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")$8;[O
M;W;I('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B1.&^
M[R!S;R!S;F5H;VTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(D3AON\@
M<')E8VCA9'IA:OIC:2!V('-N9;YE;FEE(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(D[A:&]D
M;N$@9F]R='5N82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2
M871I;R(*;7-G<W1R(")0;VUE<B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(LCM=&&[(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE
M<W-A9V5S(@IM<V=S='(@(LCM=&&[('-P<N%V>2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R(").86]Z86H@=GEM87IANR`E<S\@5/IT;R!O<&5RX6-I
M=2!N96UOOFYO('9RX71INR!S<.2[+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B).86]Z86H@=GEM87IANR!P
M;W6^[79A=&6U<VOI(/ID86IE('!R92!P;W6^[79A=&6U82`E<S\@5/IT;R!O
M<&5RX6-I=2!N96UOOFYO("(*(G9RX71INR!S<.2[+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E9RX71I('-PY+L@5F&Y=2!P
M;W-L961N^B!A:V-I=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(D]B;F]V:;LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS
M9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B
M3V)N;W9INR!E;&5M96YT>2!D>6YA;6EC:^EH;R!M96YU.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I
M97<Z(@IM<V=S='(@(D]B;F]V:;L@>F]B<F%Z96YI92!P;W)TX6QU.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM<V=S
M='(@(E)E9W5LX7)N>2!V_7)A>B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C,X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(")0<F5H
M;&EA9&'H('9ZNV%H;W8B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")2
M96QO860B"FUS9W-T<B`B6FYO=G4@;F'H[71ANR(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(E!O<W1R96AY
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E
M(%-E<G9E<G,B"FUS9W-T<B`B5GID:6%L96[I('-E<G9E<GDB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")6>F1I
M86QE;N$@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G
M<W1R(")/9'-T<N%N:;LB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")/9'-T<N%N:;L@
M8FQO:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-38*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B3V1S='+A;FF[('-T
MY7!E8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D]D<W1R
MX6YINR!F;W)MX71O=F%N:64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B3V1S='+A;FF[
M('#A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E
M;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+B(*;7-G<W1R(")/9'-T<N%N:;L@=6QOOF5N_2!S:W)I<'0@>B!D
M;^AA<V[I:&\@<')I9>AI;FMA(&YA('-E<G9E<FDN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED
M(")296UO=F4@=&AE(@IM<V=S='(@(D]D<W1RX6YINR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I
M9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R
M(")/9'-T<N%N:;L@=&5N=&\@8F]D('H@9&]K=6UE;G1U(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S
M97(B"FUS9W-T<B`B3V1S='+A;FF[('!O=;[M=F%T9;5A(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")/9'-T<N%N:;L@<&]UONUV
M871EM6$Z("5S(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM
M<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B`B"FUS9W-T<B`B3F$@<&^^:6%D879K=2!N96)O;&\@;6^^
M;ND@;V1P;W9E9&&[+B!.X79R871O=OT@:_-D(&-H>6)Y.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(E!OOF%D;W9A
M;OH@<VQUOF)U('-A(&YE<&]D87)I;&\@;N%J<[LN(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-S8@;&EB+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B5B!K;VYF:6=U<N%C:6D@)7,@;FEE(&IE(+EP
M96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA(%PB)7-<(B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HV-S@@;&EB+U9&4R]F='`N<&AP.C@U,"!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E8@:V]N9FEG=7+A8VEI(%9&4R!N:64@:F4@N7!E8VEF:6MO
M=F%NX2!P;[YA9&]V86[A('!O;&^^:V$@7"(E<UPB(@H*(SH@;&EB+TAO<F1E
M+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")6(&MO;F9I9W5RX6-I:2!N:64@:F4@N7!E8VEF:6MO=F%NX2!P;[YA9&]V
M86[A('!O;&^^:V$@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R
M97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B4&]V
M:6YNZ2!P;VQE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,T,R!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
M5GEM87IANR!F;W)M=6SA<B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")/8FYO=FF[
M(&AE<VQO(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G
M:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B3V)N;W9INR!68;EE
M(&AE<VQO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S
M=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(D]B;F]V:;L@<&]S;&5D;OT@9&]T
M87HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN
M<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*
M;7-G<W1R(")6_7-L961K>2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T
M=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B3N%V<F%T(&YA(&YA<W1A=F5N:6$B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E
M='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B6F%D86IT92!N;W;I(&AE<VQO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")6<N%T
M:;L@:V]N9FEG=7+A8VEU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(DYA
M<W1A=F5N:6$@<F]ZN>UR96[I:&\@=&5X=&]VZ6AO(&5D:71O<G4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T
M<B`B2.%D86YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B5G!R879O
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3`*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R(")(;&%V:>AK82!V<')A=F\B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$P-@IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(DAO
M9&YO='D@=G!R879O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B5FQA<W1N;W-T:2!?<FEA9&MA+BXN(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS
M9W-T<B`B4F]L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4G5M=6YS
M:V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T
M"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D]T;^AINR!O(#$X,"(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C$*;7-G:60@
M(E)O=&%T92!,969T(@IM<V=S='(@(D]T;^AINR!VM6%V;R(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C<*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R(")/=&_H:;L@=G!R879O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B
M4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2!R:6%D:V$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO<W1I
M(')I861K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")2:6%D:WDZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`BR&EA<GDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(@IM<V=S='(@(LAI87)Y('-A('IO8G)A>FEA(&UE9'II(':Y971K_6UI(')I
M861K86UI(&$@<W3E<&-A;6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("+(:6%R>2!S82!Z
M;V)R87II82!I8F$@;65D>FD@<W3E<&-A;6DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("+(:6%R
M>2!S82!Z;V)R87II82!I8F$@;65D>FD@<FEA9&MA;6DB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B4W!U<W1INR(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-KX2!F
M961E<N%C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-
M12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@:W)Y
M<'1O9W)A9FEC:_T@<&]D<&ES(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R(")3<'+A=F$@>F&Y:69R;W9A;N$@<&]M;V-O=2!3+TU)344B"@HC.B!L
M:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,(&%U=&5N
M=&EF:6OA8VEA(&YI92!J92!D;W-T=7!NX2XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@
M(E!O<VEE;&%N:64@4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS
M9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,(%-H96QL(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,R-S(*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A
M;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,('!R[6MA>B!P<F4@:+5A9&%N:64@
M:&]D;O1T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I
M9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G
M<W1R("+:4U!%0T@B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@
M4VAE;&PB"FUS9W-T<B`B4U]13"!3:&5L;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@
M(E-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-VY'3A($AE
M;&5N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(E-VY'3]($MI='1S(&$@3F5V:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM
M<V=S='(@(E-VY'3A($QU8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;B(*;7-G<W1R(")3=BX@4&EE<G)E(&$@36EQ=65L;VXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G
M<W1R(")3=N1T_2!6:6YC96YT(&$@1W)E;F%D:6YY(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F
M<F%M92`H7W-E;&8I(@IM<V=S='(@(E1E;B!I<W3]('+A;65C("A?<V5L9BDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A
M;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4
M;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!A(%!R:6YC:7!E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QI=&[]('!O<VMY=&]V871E
MM2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")3875D<VOA($%R
MX6)I82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I
M9"`B4V%V92(*;7-G<W1R(")5;&^^:;LB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M7"(E<UPB(@IM<V=S='(@(E5L;[YINR!<(B5S7"(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M("5S(@IM<V=S='(@(E5L;[YINR`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")5;&^^:;L@
M;F%S=&%V96YI82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G
M:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@HB56QOOFF[('9Y9V5N97)O=F%N^B!K;VYF:6=U<N%C
M:74@86MO(%!(4"!S:W)I<'0@9&\@9&_H87-NZ6AO('!R:67H:6YK82!6X;EH
M;R`B"B)S97)V97)A+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DMO;F9I9W5RX6-I82`E<R!B;VQA('5L;[YE;N$N(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS
M9W-T<B`B4VMR:7!T(&YA('5P9W)A9&4@;F%S=&%V96[M(&)O;"!U;&^^96[]
M(&1O.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R
M(")/:F5D:6YE;.D@8OIR:WDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B5F5D82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B2+5A9&&[(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H
M($5N9VEN97,B"FUS9W-T<B`B5GEHM6%DX79AZ&4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,CDV,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(E9Y
M8F5R=&4@<_IB;W)Y(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X,@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")6>6)E
M<G1E(&3A='5M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*
M;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")6>6)E<G1E
M('-K=7!I;G4@;F$@<')I9&%N:64B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B
M5GEB97)T92!N;W;I:&\@=FQA<W1N[6MA(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T
M<B`B5GEB97)T92!S97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B
M5GEB97)T92!P;W6^[79A=&6U82!N82!P<FED86YI92(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S,*;7-G:60@(E-E;&5C="!A
M;&PB"FUS9W-T<B`B5GEB97)T92!VN65T:WDB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C8U,`IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M(@IM<V=S='(@(E9Y8F5R=&4@=KEE=&MY(&MO;7!O;F5N='D@9.%T=6UU(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,`IM<V=I
M9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")6>6)E<G1E(&]B:F5K="(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S0*;7-G
M:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(EIR=;EINR!V_6)E<B(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(B(*(E9Y8F5R=&4@>FYA:WDL(&MT;W+I('!O=')E
M8G5J971E+"!Z(&]K:65N;VL@;FF^N6EE+B!0;W1O;2!I8V@@;?2^971E("(*
M(G-K;W#M<F]V8;L@82!V;&^^:;L@>B!T97AT;W;I:&\@<&^U82XB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5GEB97)T92!O9&1EM6]V8>@@=F\@
M9F]R;>%T92!DX71U;74Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E9Y
M8F5R=&4@9F]R;>%T(&3A='5M=3HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y
M('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B5GEB97)T92!I9&5N=&ET
M=2P@:W1O<OH@8VAC971E('IM96YINSHB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB
M"FUS9W-T<B`B5GEB97)T92!O9&1EM6]V8>@@=F\@9F]R;>%T92#H87-U.B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@
M=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")6>6)E<G1E(&9O<FWA="#H87-U
M.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")6>6)E<G1E(&1V
M92!Z:&]D;ND@<&]L:6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q
M,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")6
M>6)E<G1E('-I(&9A<F5B;OH@<V-HZ6UU(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E.B(*;7-G<W1R(")6>6)E<G1E(&IA>GEK.B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(E!O<VQANR!S<'+A=G4@;R!P<F]B;.EM92(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")3
M96YD(%--4R(*;7-G<W1R(")0;W-L8;L@4TU3(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A
M;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;GIO<CH@(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*
M;7-G<W1R(")397!T96UB97(B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B4W)B<VMO(&$@R&EE<FYA(&AO<F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")3
MZ7)I;W;I(.CM<VQO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`BVF1A:F4@>F\@<V5R=F5R82!S^B!N97-P<N%V;F4@86QE
M8F\@;FEE('/Z(&1O<W1U<&[I+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!9&UI;FES='+A8VEA
M('-E9&5N[2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(E!L871N
M;W.[($E$('-E9&5N:6$@=GEP<KEA;&$N(@H*(SH@;&EB+V%P:2YP:'`Z,30U
M"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")3961E;FEA(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S,3@*;7-G:60@(E-E="(*;7-G<W1R(")-;F^^:6YA
M(&AO9&[T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R(").87-T879T92!M
M;[YN;W-T:2!N82!O8FYO=F5N:64@5N&Y:&\@:&5S;&$@86L@:&\@>F%B=61N
M971E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B).87-T879E;FEE('9Z9&EA
M;&5N_6-H('-E<G9E<F]V+"!K=2!K=&]R_6T@8VAC971E('!R:7-T=7!O=F&[
M('H@5N&Y:&\@(@HB<&]R=.%L=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM
M97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B5GEB97)T92!J87IY
M:RP@Z&%S;W;Z('KS;G4@82!N87-T879E;FEA(&3A='5M=2XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB
M3F%S=&%V96YI92!A<&QI:^%C:64@<W#ZN;MA;F5J('!R:2"Y=&%R=&4L(&9A
M<F5B;F5J('-C:.EM>2P@:6YT97)V86QU("(*(F]B;F]V;W9A;FEA('-T<N%N
M:WD@82!I;OUC:"!V;&%S=&YO<W3M('IO8G)A>F5N:6$N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B3F%S
M=&%V96YI92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM
M<V=S='(@(E/Z(&1O<W1U<&[I('-K<FEP='D@;F$@=7!G<F%D92!N87-T879E
M;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED
M(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z("(*;7-G<W1R(")$;R#Z=F%H>2!P<FEC:.%D>F$@;FEE:V^U:V\@;&]K
M86SM="!P;VUO8V]U('!A<F%M971R83H@(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE
M<R(*;7-G<W1R(")397EC:&5L>2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(E-H;W!P:6YG(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`B2W+A=&MY('/Z:')N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(DUA:OH@<V$@
M<')E(';DZ+EI;G4@;&EN:65K('9Y='9O<FF[('-K<F%T:V]VZ2!K;.%V97-Y
M/R(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3
M:&]W(@IM<V=S='(@(EIO8G)A>FF[(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U
M<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"B):;V)R87IINR!R;WID:65L>2!M961Z
M:2!P<N%V92!U;&^^96YO=2!A(&YO=F]V>6=E;F5R;W9A;F]U(&MO;F9I9W5R
MX6-I;W4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R
M(")-X2!S82!P<FD@<')I:&SA<V5N[2!Z;V)R87IINR#H87,@<&]S;&5D;NEH
M;R!P<FEH;.%S96YI83\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V.0IM
M<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("):
M;V)R87IINR!M;[YN;W.[(&YA('!O;F5C:&%N:64@;W)I9VENX6QU(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#(*;7-G:60@(E-H;W<@<&EC:V5R(@IM
M<V=S='(@(EIO8G)A>FF[(&[A<W1R;VH@;F$@=OUB97(@9F%R:65B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("):;V)R87IINR!M96YU('!R
M92!O<&5RX6-I92!S('1A8G6U:V%M:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(EIO8G)A>FF[(&UE;G4@)7,@;F$@
MM6%V96H@<W1R86YE/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):;V)R87IINR!D:6%L
M\V<@<R!V;&%S=&YO<[MA;6D@8G5N:WD@=&%B=;5K>2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI('1A8G6U:WDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("):;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@<FEA
M9&MU('1A8G6U:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(EIO8G)A>FF[(&1I86SS9R!S('9L
M87-T;F]SNV%M:2!O8G+A>FMU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W
M-C<*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(EIO8G)A>FF[(&YA:')A
M;NDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")0<F5HX6YK>2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W
M97)S($5A<FQY(@IM<V=S='(@(E+A;F\@<')E:.%N:WDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R
M<R!,871E(@IM<V=S='(@(DYE<VOT<B!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S
M(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("):<N&^:WD@=B!O:V]L[2(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK
M(@IM<V=S='(@(EIM96ZY:;LB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HW-S0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.CDR,B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M,3`T-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C$Q,38@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(DYA
M:G!R=B!M=7/M=&4@>FUE;KEINR!A;&5B;R!P<F5S=6[ZNR!S=7-E9&[](&)L
M;VLH>2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A
M($QE;VYE(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G
M:60@(E-I9VX@=7`B"FUS9W-T<B`B6F%R96=I<W1R;W9ANR!S82(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B
M"FUS9W-T<B`B4&]D<&ES(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QG
M;W)I=&UU<R!P;V1P:7-U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@
M(E-I;F=A<'5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDP,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(Q.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,0HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C(U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q,@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`IM<V=I
M9"`B4VEZ92(*;7-G<W1R(")69;5K;W.[(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E
M;F%N8V4B"FUS9W-T<B`B4')E<VMOZ&F[(/ID<KYB=2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(E-L;W9E;G-K;R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(E-L;W9I;G-K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(E-N9;YE
M;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(E-N96AO=N$@<')E:.%N
M:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N96AO=ND@<')E:.%N
M:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(E+A;F\@<VYE
M:&]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R
M(").97-K]'(@<VYE:&]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B2.5B:V$@
M<VYE:'4Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")-;F^^<W1V;R!V
M;V1Y(&5K=FEV86QE;G1NZ2!S;F5H=3H@(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)
M<VQA;F1S(@IM<V=S='(@(JEA;&%M^FYO=F4@;W-T<F]V>2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-O;6%L:6$B"FUS9W-T<B`B4V]MX6QS:V\B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B4&EE
M<VYE(&$@8N%S;F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-0IM<V=I
M9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B5OUB97(@<VUE<G4@
M=')I961E;FEA(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4U.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ-C8@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I
M9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B6F1R;VIO=N$@861R97-A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(DIUOF[A($%F<FEK82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R
M(")*=;YNX2!'96]R9VEA(&$@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*
M;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2G6^;N$@<&]L
M;V=UM6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*
M;7-G<W1R(")-961Z97)A(&UE9'II('-U<V5D;OUM:2!B=6YK86UI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G
M:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB
M"FUS9W-T<B`B365D>F5R82!M961Z:2!O8G-A:&]M(&$@;VMR86IO;2!B=6YK
M>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*
M;7-G<W1R(")/9&1EM6]V8>@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T
M<B`B3V1S='5P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*
M;7-G<W1R(")/9'-T=7`@82!V>7!L;F5N:64B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS
M9W-T<B`BJ7!A;FEE;'-K;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP
M=70B"FUS9W-T<B`B5FQOOF5N:64@N7!E8VGA;&YY8V@@>FYA:V]V(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")2;WID96QINR!B=6YK=2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")2;WID96QINR!S
M=.5P96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B4F]Z9&5L
M:;L@<FEA9&]K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED
M(")3<&]R=',B"FUS9W-T<B`BJ7!O<G1Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B
M"FUS9W-T<B`B4W+M($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G:60@(E-T86YD
M87)D(@IM<V=S='(@(JET86YD87)D;NDB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C<Y.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")0;^AI871OZ&[]
M(')O:R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED
M(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("*I=.%T(&%L96)O('!R;W9I
M;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R
M"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A=B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#`T"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")&
M;W)MX70@=6QOOF5N:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B0GED;&ES:V\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(E!R9;EK<G1N=73I(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L:7-T
M(@IM<V=S='(@(EIO>FYA;2!R9;MA>F-O=B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<R(*;7-G<W1R(")/9'-T<N%N:;L@9&]MZ6YU('H@861R97-Y(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`BJ73];"!;0U-372(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@
M(E-U(@IM<V=S='(@(DYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0;V1P<FEEZ&EN;VL@7"(E<UPB(&YE8F]L(&[A
M:F1E;OTN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B4')E9&UE="(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP
M.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(D]D;W-L8;LB"@HC.B!S:6=N
M=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO
M="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O
M=F5D+B(*;7-G<W1R("(B"B)0;[YI861A=FMA(&YA('!R:61A;FEE(%PB)7-<
M(B!D;R!S>7-TZ6UU(&)O;&$@;V1O<VQA;N$N($YE;?2^971E('-A("(*(G!R
M:6ALX7-INRP@:_UM(&YE8G5D92!68;EA('!OOFEA9&%V:V$@<V-H=N%L96[A
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")$;VQN_2!I;F1E>"(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S
M='(@(MIS<&5C:"(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B4')I9&%N:64@7"(E<UPB(&1O('-Y<W3I;74@8F]L
M;R#Z<W!EN6[I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E9Y;6%Z86YI92#Z
M9&%J;W8@>F\@<WES=.EM=2!P<F4@<&]UONUV871EM6$@7"(E<UPB(&)O;&\@
M^G-P9;ENZ2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")6>6UA>F%N:64@7"(E<UPB
M(&)O;&\@^G-P9;ENZ2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B5GEM87IA;FEE(%PB)7-<(B!Z;R!S
M>7-TZ6UU(&)O;&\@^G-P9;ENZ2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A
M=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B).X79R
M870@:W4@:V]N9FEG=7+A8VEI(&)O;"#Z<W!EN6[]+B!0<F4@>F]B<F%Z96YI
M92!Z;6EE;B!Z;F]V=2!N8>CM=&%J=&4@(@HB<W1RX6YK=2XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B6N%L;VAA(&MO;F9I9W5RX6-I92!B;VQA('5L;[YE
M;N$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(EKA;&^^;OT@:V]N9FEG=7)A
MZ&[]('/Z8F]R("5S(&)O;"#Z<W!EN6YE('5L;[YE;OTN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")!:W1U86QI>N%C:6$@7"(E<UPB
M(&)O;&$@^G-P9;ENX2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B6N%P:7,@)7,@8F]L
M(/IS<&6Y;OTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=63A;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4_IH<FXB"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E;]
M8VAO9"!S;&YK82(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I
M9"`B4W5N(%-E="(*;7-G<W1R("):X7!A9"!S;&YK82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*
M;7-G<W1R(")3;&YEZ&YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")6_6-H;V0@<VQN:V$B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E;]8VAO
M9"]ZX7!A9"!S;&YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")6_6-H;V0@<VQN:V$Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@
M(E-U;G-E="(*;7-G<W1R("):X7!A9"!S;&YK82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@
M(EKA<&%D('-L;FMA.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")(
M;W)N_2!I;F1E>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*
M;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B4&]D<&]R82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U
M<FEN86UE(@IM<V=S='(@(E-U<FEN86TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")0<FEE>G9I
M<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M(")3=F%L8F%R9"!A($IA;B!-87EE;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R(")3=F%Z:6IS:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B
MJ7;I9'-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("*I=F%JZ&EA
M<G-K;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(EKA>FYA;7D@;R!S>6YC:')O
M;FEZX6-I:2!V>6UA>F%NZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!L:6(O2&]R
M9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(*;7-G<W1R(")3>6YT86MT:6-KX2!C:'EB82!V('!O
M9&UI96YK86-H(&BU861A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P
M=6)L:6,B"FUS9W-T<B`B4_UR:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")"
M^G)K82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")"^G)K82!A
M('9E=&5R;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B0OIR:WDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B
M5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B4N%N;R!B^G)K>2(*"B,Z(&QI8B](
M;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R
M(")44U8@<_IB;W(B"@HC.B!L:6(O2&]R9&4O54DO5&%B;&4N<&AP.C$S-`IM
M<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&%B=;5K82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A
M8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2!T86)UM6MY(@H*
M(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@
M(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P
M97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@=&%B=;5K>2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V
M:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL('!R;W9I;F-I82#([6YY
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4862^:6MI<W1A;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B5&%N>N%N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(D-I9;4Z(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R("+:;&]H>2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO
M;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F\VYN92#H[7-L;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R(")497!L;W1A('IA('!O<VQE9&[Z(&AO9&EN=3H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM
M<V=S='(@(E1E<&QO=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E<&QO=&$Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<R(*;7-G<W1R(")497!L;W1A/&)R("\^*"5S36%X)7,O)7--
M:6XE<RD@)F1E9SLE<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-C@W
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(JEA8FSS;F$@7"(E<UPB(&YE8F]L82!NX6ID96[A+B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")3<'+A=F$@N6%B;/-N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C4*
M;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("))8F$@=&5X
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B6F%R;W9N86YI
M92!T97AT=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5X="!H;W)E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM
M<V=I9"`B5&@B"FUS9W-T<B`BJ70B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-PIM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:G-K;R(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HX-#`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(E)O>KGM<F5N:64@1E10(&YI92!J92!D;W-T=7!N
MZ2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DEN=&5G<N%C:6$@2&]R
M9&4O2V]L86(@;F5P;V1P;W)U:F4@7"(E<UPB(@H*(SH@;&EB+TYE="])35-0
M+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`@>N%Z;F%M('-A(&YE<&]D
M87)I;&\@=6QOOFF[+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS
M,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D
M('-U8V-E<W-F=6QL>2(*;7-G<W1R(")4<FEE9&$@36%I;G1E;F%N8V4Z.B!S
M82!N96YAZ.UT86QA(/IS<&6Y;F4B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B3VMN;R!S(&YA<W1A=F5N:6%M
M:2!S82!Z871V;W)I;&\N($MO;FEE8RXB"@HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,"!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R,R!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(U,@HC.B!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C,P
M,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG
M=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*
M(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)!9&UI;FES
M='+A=&]R(&UU<^T@;F%K;VYF:6=U<F]V8;L@<&5R;6%N96YT;OT@8F%C:V5N
M9"!P<F4@4'+A=F$L(&%K(&-H8V5T92`B"B)P;W6^[79ANR!0<N%V82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("))8F$@
M<W!O9&[A('-T<F%N82(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB240@Z.US;&\@:V]N=&%K
M='4@;F5B;VQO(+EP96-I9FEK;W9A;NDL(&)O;&\@<&]N96-H86[I('!RX7ID
M;F4@86QE8F\@;F5B;VQO("(*(F[A:F1E;ND@=B!D871A8N%Z92XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT(&)O;"#Z<W!EN6YE('9L;[YE;OT@
M9&\@5N&Y:&\@861R97/A<F$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92XB"FUS9W-T<B`B(@HB3F$@;W9E<F5N:64@<&]D<.US86YE:B!S<'+A=GD@
M:F4@<&^^861O=F%N_2!O9&1E;&5N_2!B;&]K(',@4$=0('!O9'!I<V]M+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@
M(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D
M871A8F%S92XB"FUS9W-T<B`B(@HB240@>F]Z;F%M=2!P<NUJ96UC;W8@8G7O
M(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!A;&5B;R!B;VQO('!O;F5C:&%NZ2!P
M<N%Z9&YE("(*(F%L96)O(&YE8F]L;R!NX6ID96[I('8@9&%T86+A>F4N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G
M<W1R(").96)O;"!U<NAE;OT@>F]Z;F%M('!R[6IE;6-O=BXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`BJ6EF<F]V86YI92!V>;YA9'5J92!B97IP9>ANZ2!P<FEP;VIE;FEE("AH
M='1P<RDN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S<@;&EB+TAO<F1E+G!H<#HU
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")3^F)O<B`E<R!B>2!M86P@
M;V)S86AO=F&[(&YA<W1A=F5N:64@)7,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-S`@;&EB+TAO<F1E+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS
M9W-T<B`B4_IB;W(@)7,@8GD@;6%L(&]B<V%H;W9ANR!N:65K=&]RZ2!N87-T
M879E;FEA("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(S"FUS9VED(")4
M:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R
M("):9')O:F]V_2!A(&-I9;5O=OT@<_IB;W(@;75S:6$@8GF[(&]D;&FY;NDN
M(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(E/Z8F]R(&YE;V)S86AO=F%L
M(+YI861N92#Z9&%J92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B
M3F%S;&5D=6KZ(&AL879IZ&MY('1E:G1O('-P<N%V>2!V;R!F;W)MX71E(&UE
M<W-A9V4O<F9C.#(R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*
M(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T
M96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL
M(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S
M92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB0V5L;V]B<F%Z;W9K;W;]
M(')EOFEM('-P]'-O8G5J92!P<F]B;.EM>2!V($EN=&5R;F5T($5X<&QO<F5R
M:2!K=O1L:2!C:'EBX6T@(@HB<')E:&QI861AZ&$L(&MT;W+I('-A(&[A;2!N
M97!O9&%R:6QO(&]B[7.[+B!-]+YU('-A('!R96IA=FF[(&YE<W!RX79N>6T@
M(@HB>F]B<F%Z96[M;2P@8VC]8F%J^F-I;6D@9G5N:V-I86UI(&5D:71O<F$@
M82]A;&5B;R!NX6AO9&[];6D@<.%D;6D@(@HB<')E:&QI861AZ&$N($%K(&IE
M(%;AN2!S>7-TZ6T@5VEN9&]W<R`Y>"P@:F4@=F6U;6D@<')A=F1E<&]D;V)N
MZ2P@OF4@<V$@(@HB>F]B<F%Z[2!C:'EB82`G1V5N97)A;"!0<F]T96-T:6]N
M($9A=6QT)R!A(&)U9&5T92!M=7-I9;L@<F6Y=&%R=&]V8;L@<&_H[71AZ"XB
M"B)<7&Y<7&Y687)O=F%L:2!S;64@5N%S+B!3=&QAZ'1E('!R;W/M;2!/2R!A
M:R!N86]Z86H@8VAC971E('!O=;YINR!E9&ET;W(@=B`B"B)C96QO;V)R87IO
M=FMO=F]M(')EOFEM92XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET82!<(B5S7"(@8F]L82!V>6UA
M>F%NX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R("))8F$@M6%VX2!S=')A;F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU
M4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L
M87-S+B(*;7-G<W1R(")4<FEE9&$@0W)Y<'1?<&=P.CH@<&]T<F5B=6IE('!O
M>FYANR!U;6EE<W1N96YI92!P<F]G<F%M=2!';G501RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S
M7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT
M964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O
M;V0N(@IM<V=S='(@(B(*(E-P<N%V82!O9&]S;&%NX2`E<R!P<F4@)7,@<R!P
M<F5D;65T;VT@7"(E<UPB(&)O;&$@>F]B<F%Z96[A+EQN(@HB3F5E>&ES='5J
M92!VN6%K('KA<G5K82P@OF4@<W!RX79A(&)O;&$@<')EZ.UT86[A(&%L96)O
M('!O8VAO<&5NX2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@X,0IM<V=I
M9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E(@IM<V=S='(@(DUE;F\L(&MT;W+I('-A(&WA('!O=;YINR!P<FD@
M;&EN:V]V86[M(&YA('-T<N%N:W4@;F$@<.US86YI92!S<'+A=B`B"@HC.B!L
M:6(O1FEL92]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L
M9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")0;^AE="!P;VSM(&UU<^T@
M8GF[(.CM<VQO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S
M,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B5')I961A
M($AO<F1E7T-R>7!T7W-M:6UE.CH@=GF^861U:F4@;6]D=6P@;W!E;G-S;"XB
M"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@
M86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3F%S=&%V96YI92!<(B5S7"(@
M<V$@;F5P;V1A<FEL;R!U;&^^:;LL('!R971OOF4@:F5H;R#Z9&%J92!P<F5K
M<F'H=6KZ("(*(FUA>&EMX6QN=2!P;W9O;&5N^B!V9;5K;W.[(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H
M<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M(@IM<V=S='(@(B(*(E!R;V=R86T@<&]UONUV86[](&YA('IO8G)A>F5N:64@
M=&]H=&\@^F1A:F]VZ6AO('1Y<'4@*"5S*2!N96)O;"!NX6ID96[]+B(*"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(EIN
M86L@8VETX6-I92!M=7/M(&)YNR!J961E;B!Z;F%K+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@
M(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(DEB82!P
M<F%VX2!A(+5A=N$@<W1R86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA
M;F0@<VED92!O;FQY(@IM<V=S='(@(DEB82!P<F%VX2!S=')A;F$B"@HC.B!L
M:6(O1FEL92]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")/9&1EM6]V8>@@
M;75S[2!B>;L@:F5D96X@>FYA:RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")397)V97(@7"(E<UPB
M(&)O;"!V>6UA>F%N_2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R(%PB)7-<(B!B;VP@=6QO
MOF5N_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("*N:6%D;W.[(&\@<')I:&SA<V5N:64@)7,@8F]L82!V
M>6UA>F%NX2XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS,S`*
M;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("*I<&5C:69I:V]V86[](')I861O:R!N965X:7-T=6IE+B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E
M;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M1&_H87-N_2!S^F)O<B!<(B5S7"(@;F5E>&ES='5J92XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S,P,`IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@
M9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R
M("):861A;OT@=&5X="!N:64@:F4@<F]V;F%K_2!A:V\@=&5X="!N82!O8G)A
M>F]V:V4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'DB"FUS9W-T<B`B26)A(&AO<F[A(&$@<W!O9&[A('-T<F%N82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(DEB82!H;W)N
MX2!S=')A;F$B"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,S(W"FUS9VED(")4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"XB"FUS9W-T<B`B3F%H<F%NZ2#Z9&%J92!S82!O9"!P<F5D8VCA9'IA
M:OIC96AO(&MR;VMU('-T<F%T:6QI+B(*"B,Z(&QI8B](;W)D92]$871A+V-S
M=BYP:'`Z,C8R(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@
M(DYA:')A;OT@<_IB;W(@<V$@;F5P;V1A<FEL;R!U;&^^:;LN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]K('=E871H97(N8V]M(&YI
M92!J92!D;W-T=7!N_2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(")0<FEEZ&EN;VL@=.EM(%PB)7-<(B!N96)O
M;"!NX6ID96[]+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS
M9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@
M(JYI861N92!N87-T879E;FEA(&YI92!S^B!D;W-T=7!NZ2XB"@HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`BKFEA9&YE(&%L=&5R;F%T[79N92#H87-T:2!N96UOOFYO('IO8G)A>FF[
M('8@=&5L92!S<'+A=GDN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM
M<V=S='(@(B(*(E8@=&]M=&\@<&]L:2!J92!P<NUL:;D@=F6U82!Z;F%K;W8N
M(%IA9&%L:2!S=&4@)7,@>FYA:V]V.R!M=7/M=&4@>F%D8;L@;65N96H@(@HB
M86MO("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(DYA<W1A;&$@
M8VAY8F$@<')I('!R:63A=F%N[2!<(B5S7"(@9&\@<WES=.EM=3H@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B).87-T86QA(&-H>6)A
M('!R:2!O9'-T<F'R;W9A;NT@<&]UONUV871EM7-K_6-H(/ID86IO=B!<(B5S
M7"(@>F\@<WES=.EM=3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DYA<W1A;&$@8VAY
M8F$@<')I(&]D<W1R8?)O=F%N[2!<(B5S7"(@>F\@<WES=.EM=3H@(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(").
M87-T86QA(&-H>6)A('!R:2!A:W1U86QI>N%C:6D@7"(E<UPB.B`E<R(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")6>7-K>71O;"!S82!P<F]B
M;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z(*YI861E;B`E<R!N96)O;"!N86AR
M86[]+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB5GES
M:WET;VP@<V$@<')O8FSI;2!S(&YA:'+A=F%N[6T@<_IB;W)U.B`E<R!B;VP@
M=N3HN>T@86MO(&YA:G;DZ+GM('!O=F]L96[]("(*(FQI;6ET("@E9"!B86IT
M;W8I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"XB"FUS9W-T<B`B5GES:WET;VP@<V$@<')O8FSI;2!S('5K;&%D86[M;2!S
M^F)O<G4Z("5S(&)O;"!N86AR86[](&QE;B#H:6%S=&_H;F4N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM
M<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('IO8G)A>F]V86[M('1E:G1O(.AA
M<W1I('-P<N%V>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,SD@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+B(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!I;7!O<G1E(/ID86IO
M=B!O(&MO;G1A:W1E+B(*"B,Z(&QI8B](;W)D92]$871A+VEM8RYP:'`Z,S$*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!I;7!O<G1E
M(/ID86IO=B!I0V%L96YD87(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q
M=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@=B!K;VYF
M:6=U<F'H;F]M(&9O<FUU;.%R:2X@4')A=F1E<&]D;V)N92!S=&4@;F5V>7!L
M;FEL:2`B"B)P;[YA9&]V86[I('!O;&4N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(DYA<W1A;&$@8VAY8F$@<')I('9Y:V]NX79A;NT@=7+H96YE:B!F=6YK8VEE
M(&%D<F5SX7)A+B!0<F]S[6T@<VOZ<W1E('1O("(*(FYE<VOT<BXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL
M<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB3F%S=&%L
M82!C:'EB82!P<FD@86MT=6%L:7KA8VEI(&1E=&%I;&]V(&MO;G1A:W1U+B!0
M<F]S[6T@<VOZ<W1E('1O(&YE<VOT<BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0U(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR
M,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!Z;WIN
M86UU('!R[6IE;6-O=BX@4')O<^UM('-K^G-T92!T;R!Z;F]V=2XB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+B(*;7-G<W1R(")496YT;R!)34%0('-E<G9E<B!N97!O9'!O<G5J92!Z9&EE
MM6%N:64@<')I9>AI;FMO=BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B5&]T;R!P<F%V9&5P;V1O
M8FYE(&YI92!J92!P;&%T;OT@87)C:.UV(')A<BXB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B5&]T;R!P
M<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV('II<"XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$S-`IM<V=I9"`B5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(E1O=&\@
M<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[I(.CM<VQO(&MA<G1Y+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)496YT
M;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z(&)RX6YU
M($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@<&]M;V-O
M=2!(5%10($%022(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)496YT;R!O
M=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z(&)RX6YU(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(G!O;6]C;W4@2%144"!!4$DB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&5N=&\@
M;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B<N%N=2!S
M;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!P;VUO8V]U($A4
M5%`@05!)(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HB5&5N=&\@;W9LX61A
MZ"!U;6^^\G5J92!P;W-I96QANR!S<'+A=GD@8V5Z(%--5%`@8V5Z(&)RX6YU
M(%9O9&%F;VYE($ET86QY("(*(BAI8F$@;F$@Z.US;&$@5F]D869O;F4I+B!6
M>;YA9'5J92!E+6UA:6QO=OT@^NAE="!6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+R(*(G=W=RXQ.3`N:70I+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C`*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3,*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#0@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,C8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R.34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,X,#,@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,3$*;7-G:60@(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(E1O=&\@<&]L92!J92!P;W9I
M;F[I+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(E1O
M=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,C`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(E1O=&\@
M<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$@82!D=F]J8F]D:W4N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(E1O=&\@
M<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@;W-M:>AK;W;I(&AO9&YO='DN(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S(@IM<V=S='(@(E1O=&\@<&]L92!M=7/M(&)YNR!Z;WIN86T@Z.US
M96P@;V1D96QE;OUC:"#H:6%R:V]U(&%L96)O(&UE9'IE<F]U(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")4;W1O('!O;&4@;75S[2!B>;L@
M<&QA=&[I(.CM<VQO+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#(U"FUS
M9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A
M9B<N(@IM<V=S='(@(B(*(E1O=&\@<&]L92!M=7/M(&]B<V%H;W9ANR!K\V0@
M9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA=&4@4D="+"!N87!R[6ML860@
M(@HB)R,Q,C,T868G+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU-C4*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B5&5N=&\@9F]R;75LX7(@=;X@8F]L('-P<F%C;W9A;OTN(@H*(SH@
M=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B5&]T;R!J92`E<RXB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,B"FUS9W-T<B`B(@HB5&]T;R!J92!O8FIE:W0@2V]L86(@1W)O=7!W87)E
M+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE:W1U('!O=')E8G5J971E(&4M
M(@HB;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O>G5M:64@9F]R;>%T=2!+
M;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@(@HB=&%K_6-H=&\@:VQI96YT
M;W8@;F%VN73M=G1E('!R;W/M;2`E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(E3A=&\@<W!RX79A(&)O;&$@
M;F%P[7-A;N$@=B!I;F5J(&%K;R!686UI('!O=;[M=F%N96H@>FYA:V]V96H@
M<V%D92`H)7,I+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(V"FUS
M9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T
M<B`B5&]T;R#H[7-L;R!M=7/M(&)YNR!N86IM96YE:B`Q+B(*"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@
M(E1E;G1O('-E<G9E<B!N961O:^&^92!D96MO;7!R:6UO=F&[('/Z8F]R>2!Z
M:7`@82!G>FEP+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3@R"FUS
M9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM
M<V=S='(@(E-Y<W3I;2!J92!M;VUE;G3A;&YE(&1E86MT:79O=F%N_2XB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")4X71O(&AO9&YO=&$@;75S
M[2!B>;L@Z.US96QNX2XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(E1O=&\@;VMN;R!M=7/M
M(&)YNR!Z879O;&%NZ2!Z(&]K;F$@3F%S=&%V96[M(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B
M"FUS9W-T<B`B2')M96YI92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B5&EC:V5T<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#(Y('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("+(87,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM
M<V=S='(@(E1I;64@5')A8VMI;F<B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O<FWA="#H87-U(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*;7-G:60@(E1I;64@<V5L96-T
M:6]N(@IM<V=S='(@(E;]8F5R(.AA<W4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T
M92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS
M9VED(")4:71L92(*;7-G<W1R(")4:71U;&]K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O
M;VQT:7`I.B(*;7-G<W1R(").861P:7,@*&)U8FQI;F]V_2!V_7!I<RDZ(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(E!R92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-3$*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(E!R92!V
M_6)E<B!V:6%C97+]8V@@<&]L;[YI96L@9'*^=&4@<&_H87,@:VQI:V%N:6$@
M:VSA=F5S=2!#;VYT<F]L("A00RD@86QE8F\@(@HB0V]M;6%N9"`H36%C*2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4
M;V1A>2(*;7-G<W1R(")$;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E
M(@IM<V=S='(@(E!R97!N^KL@>F]B<F%Z96YI92!Z9')O:F]VZ6AO(&OS9'4@
M2%1-3"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(EIA
M:G1R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS
M9VED(")4;W`B"FUS9W-T<B`B5G)C:"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O
M<"DB"FUS9W-T<B`B5G)C:&[]('+A;65C("A?=&]P*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@
M(E!R96ML861Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G
M<W1R(")4<FEN:61A9"!A(%1O8F%G;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E!R879D82!A
M;&5B;R!N97!R879D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(E5T(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<VMO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y
M(@IM<V=S='(@(E1U<F5C:V\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.`IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K
M<R!A($-A:6-O<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B
M"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C
M:&]I8V4Z("(*;7-G<W1R("):861A:G1E(%9AN74@=F^U8G4Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD
M97@Z("(*;7-G<W1R(")5+E8N(&EN9&5X.B`B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ
M-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@5N&Y:&\@
M<VMR:7!T=2!P<F4@<W!RX79U(&\@9&]R=>AE;NTB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM
M<V=S='(@(E523#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:FEN82(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-#$V"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=7-K=71OZ&YI
MNR!P<NUS='5P(&L@5D93(&%D<F5SX7)U+B(*"B,Z(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*(DYE
M<&]D87)I;&\@<V$@<')I9&&[(.]A;+EI92!I;F9O<FWA8VEE(&\@<&]UONUV
M871EM6]V:2!P<FD@<F5G:7-T<N%C:6DN(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!Z;65N:;L@<'+A=F\@<')E(%9&4R!S^F)O<B!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HS.#D@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@>FUE;FF[('!RX79O('!R92!61E,@<_IB;W(@)7,O)7,N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C<W-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('IM96YI
MNR!N82`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-K;VYT<F]L;W9ANR!V9;5K;W.[
M('/Z8F]R=2!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV.3(@;&EB
M+U9&4R]S<6PN<&AP.C$P,3D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#0R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<R\E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-K;VYT<F]L
M;W9ANR!V9;5K;W.[('/Z8F]R=2!<(B5S+R5S7"(N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<W!O:FF[(',@
M4U%,('-E<G9E<F]M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-3D*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A('-P;VIINR!P;VUO8V]U(%-33"XB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C(R.2!L:6(O5D93+V9I;&4N<&AP.C(S-"!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HR,#0*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<VMO<.UR;W9ANR!61E,@<_IB
M;W(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!A9')E<^%R(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,U."!L:6(O5D93+VUU<W%L
M+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@=GET=F]R:;L@5D93(&%D<F5SX7(N(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!S^F)O<BXB"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('!R:67H:6YO:R!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR-CD*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GET
M=F]R:;L@<'+A>F1N>2!61E,@<_IB;W(N(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A(&1E:V]M<')I;6]V8;L@^F1A:F4N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA
M>F&[(%PB)7-<(BP@861R97/A<B!N:64@:F4@<'+A>F1N>2XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@7"(E<UPB.B`E<RXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S-2!L:6(O5D93+W-Q;"YP:'`Z,SDU
M(&QI8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!V>6UA>F&[("5S+"!A9')E<^%R(&YI92!J92!P<N%Z9&YY(@H*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R(").97!O9&%R:6QO('-A(')E:W5R>NUV
M;F4@=GEM87IANR!61E,@861R97/A<BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C,T,2!L:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T,R!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!A9')E<^%R
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C`@;&EB+U9&4R]S<6PN<&AP.C0S
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@
M5D93(&%D<F5SX7(Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB
M;W(@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S`W(&QI8B]61E,O
M<W%L+G!H<#HR.3$@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]61E,O
M;75S<6PN<&AP.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,SDQ"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O<BXB"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M=GEM87IANR!61E,@<')I9>AI;F]K(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-Q
M;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S
M82!R96MU<GKM=FYE('9Y;6%Z8;L@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z.#(S"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5RZ&F[(&%K='7A
M;&YY(&%D<F5SX7(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I
M;',B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z:7-T:;L@<&]D<F]B;F]S=&D@
M;R!C97)T:69I:^%T92XB"@HC.B!L:6(O3F5T+TE-4U`N<&AP.C0S-R!L:6(O
M3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(").
M96UOOF[I(&YA:')ANR!D969I;NUC:74@)7,N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR,#`@;&EB+U9&4R]F:6QE+G!H<#HR,#4@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@<')E<W5N^KL@5D93('/Z8F]R+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HY
M,R!L:6(O5D93+W-M8BYP:'`Z,3`V(&QI8B]61E,O<VUB+G!H<#HV-3(*(SH@
M;&EB+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!O='9O<FF[(%9&4R!S^F)O<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR.#$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)I
MNR!61E,@<_IB;W(@;F$@>N%P:7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HX
M,R!L:6(O5D93+V9I;&4N<&AP.C$S-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW
M-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O
M='9O<FF[(&MO;7!R:6UO=F%N_2!A<F-H[78N(@H*(SH@;&EB+U9&4RYP:'`Z
M.#4U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R9>CM=&&[(%9&
M4R!S^F)O<B`H9G5N:V-I82!F:6QE<VEZ92@I('IL>6AA;&$I+B(*"B,Z(&QI
M8B]61E,N<&AP.C@X-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S
M82!P<F7H[71ANR!61E,@<_IB;W(@*&9U;FMC:6$@9V5T1FEL95-I>F4H*2!Z
M;'EH86QA*2XB"@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP
M:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(").
M97!O9&%R:6QO('-A('!R9>CM=&&[('/Z8F]R.B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z-C<S"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@Z.UT8;L@861R97/A
M<B!V9G-R;V]T+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$P-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!P<F5M96YO=F&[("5S(&YA("5S.B!C:66U;W;]('!R:67H
M:6YO:R!UOB!E>&ES='5J92(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P
M,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(").97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93(&%D<F5SX7(N(@H*
M(SH@;&EB+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93(&%D<F5SX7(Z("5S+B(*"B,Z
M(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S
M^F)O<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV,30@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@<')E;65N;W9ANR!61E,@<_IB;W(@)7,O)7,N(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C,R-B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q
M;"YP:'`Z-#4R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,R!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@
M<_IB;W(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*
M;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('-P=7-T:;L@)VUK:7-O9G,G+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(").97!O9&%R:6QO
M('-A('!R96QOOFF[('1E;G1O(&1O:W5M96YT(%=O<F0B"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S^F)O<B!<(B5S7"(N
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.#,*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@>F%P[7-ANR!61E,@<_IB;W(@*&9U;FMC:6$@8V]P>2@I('IL
M>6AA;&$I+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@U(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$T-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('IA<.US8;L@^F1A:F4@5D93('/Z8F]R=2XB"@HC.B!L:6(O
M5D93+G!H<#HX-C$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S
M82!Z87#M<V&[(%9&4R!S^F)O<BP@:W;S=&$@:F4@<')E:W)OZ&5NX2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS
M9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4&]DZ&EA<FMN=73I(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM
M<V=S='(@(EIR=;EINR!Z;65N>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(EIR=;GM('!O<VQE9&[Z(&%K8VEU(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,R!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(").96_H
M86OA=F%NX2!O9'!O=F7O(&]D('-E<G9E<F$@<&_H87,@<W!O:F5N:6$Z("(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S<X(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\Z("(*;7-G<W1R(").96_H86OA=F%NX2!O9'!O=F7O(&]D('-E
M<G9E<F$@;F$Z("(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYE;F%S=&%V96[A
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E5N:6-O9&4@
M*%541BTX*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B4W!O:F5NZ2!A<F%B<VOI(&5M:7+A='DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E9EM6OA($)R:73A;FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")3<&]J96[I(+ETX71Y($%M
M97)I8VOI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET
M<R(*;7-G<W1R(")*961N;W1K>2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0R.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS
M9W-T<B`B3F5Z;N%M92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(DYE>F[A;64@87!I;7-G:60@*$%022!-97-S86=E
M($E$*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+B(*;7-G<W1R(").97INX6UE(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I
M9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B0F]L82!Z
M861A;N$@;F5P;&%T;N$@;&]K86QI=&$N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE>F[A;64@<&]UONUV871EM7-KZ2!M
M96YO(&%L96)O(&AE<VQO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B3V1S='+A;FF[(&QI;FMU('H@86MT
M=>%L;F5H;R!E;&5M96YT=2(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z
M,S`Q"FUS9VED(")5;FYA;65D(@IM<V=S='(@(DYE<&]M96YO=F%NX2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G
M:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T
M+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R
M96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@
M;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB
M3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M86KZ('H@8F5Z<&7H;F]S=&[]
M8V@@9/1V;V1O=B!P<NUS='5P(&L@=F^U8N%M("(*(E9Y<W1R:6AN^KLO2V]P
M[7)O=F&[+U9L;[YINRX@2VQI:VYI=&4@;F$@3TL@82!Z;V)R87KM('-A('1E
M8VAN:6-KX2`B"B)I;F9O<FWA8VEA(&YA('-T<N%N:V4@;6]Z:6QL82YO<F<L
M(&MT;W+A(%;A<R!I;F9O<FUU:F4L(&%K;R!U;6^^;FF[('-K<FEP='4@(@HB
M<'+M<W1U<"!K('-C:'+A;FME+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R
M(@IM<V=S='(@(D]D<W1RX6YINR!F87)B=2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U
M<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B3F5P;V1P;W)O=F%NZ2!R;WJY
M[7)E;FEE(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G
M<W1R(")!:W1U86QI>N%C:6$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*
M;7-G<W1R(")!:W1U86QI>F]V8;L@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M(")!:W1U86QI>F]V8;L@<&]UONUV871EM6$B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B06MT=6%L:7KA8VEA(%PB)7-<(B!B;VQA(/IS
M<&6Y;N$N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E-K<FEP="!N82!U
M<&=R861E(&)O;"!V>6UA>F%N_2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*
M;7-G:60@(E5P;&]A9"(*;7-G<W1R(").86AR8;LB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B5KEE=&MY
M('/Z8F]R>2!S(&MO;F9I9W5RX6-I;W4@8F]L:2!N86AR86[I(&YA('-E<G9E
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S
M='(@(E9EM6OI(&QA=&EN<VOI('#M<VUE;N$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5
M<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(E9EM6OI('+M;7-K92#H[7-L
M:6-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(E!O=;YI
MNR!A:W1UX6QN93H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(E!O=;YINR!34TPB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*
M;7-G<W1R(")0;W6^:71E('8@<'+M<&%D92P@OF4@:F4@;65N;R]H97-L;R!O
M9&QIN6[I('!R92!)35-0('-E<G9E<BXB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(E!O=;[M
M=F%T9;4B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E
M<RXB"FUS9W-T<B`B4&]UONUV871EM2`E<R!N:64@:F4@875T;W)I>F]V86[]
M(&YA("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")3<'+A=F$@<&]UONUV871EM6]V(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T
M:6]N<R(*;7-G<W1R(")0;W6^[79A=&6U<VOI(&YA<W1A=F5N:6$B"@HC.B!S
M:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R
M(")296=I<W1RX6-I82!P;W6^[79A=&6U82(*"B,Z('-I9VYU<"YP:'`Z,C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N(@IM<V=S='(@(E)E9VES='+A8VEA('!O=;[M=F%T9;5O
M=B!B;VQA('!R92!T96YT;R!S>7-TZ6T@>F%KX7IA;N$N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F
M;W5N9"(*;7-G<W1R(")0;W6^[79A=&6U<VO](/KH970@;F5B;VP@;N%J9&5N
M_2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`B4&]UONUV871EM7-KZ2!M96YO(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")0;W6^[79A=&6U<VOI
M(&UE;F\@7"(E<UPB('6^(&5X:7-T=6IE+B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E!O
M=;[M=F%T9;5S:^D@;65N;SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(E!O=;[M=F%T9;5S
M:^D@;65N;SH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B4&]UONUV
M871E;&EA('-Y<W3I;74Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R
M(")5>F)E:VES=&%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-C<@;&EB+U9&
M4R]F:6QE+G!H<#HR-3D*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(E9&4R!A9')E<^%R(&YE97AI<W1U:F4N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B1&]V;VQE;FMA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@W
M,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G
M<W1R(")0;&%T;ND@=6UI97-T;F5N:6$@>F%HX/)A:OHZ("(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G
M<W1R(")0;&%T;F]SNR(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E!L
M871N;W.[('8@;6EN^G1A8V@@;V1T97)A>BXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#8P(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+B(*;7-G<W1R(")(;V1N;W1A('!R96MR;^AI;&$@;6%X:6WA;&YU(&3E
MOFMU("5S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3$W(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B2&]D;F]T>2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$S(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3DP"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B
M2&]D;F]T>2P@>B!K=&]R_6-H('-I(&WTOF5T92!V>6)R8;LB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")0
M<F5M96YNX2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E
M;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(D]V97)E;FEE('IL>6AA;&\@
M+2!TX71O('-P<N%V82!M;VAL82!B>;L@<V9A;+EO=F%NX2XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G
M<W1R(")697)Z:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X
M"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B36%N8;YM96YT('9E
M<GII[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(E9E
M<G1I:^%L;F4@>F%R;W9N86YI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B
M"FUS9W-T<B`B5F5R=&EKX6QN92!V>7!L;F5N:64B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;#HB"FUS9W-T<B`B5F5R=&EKX6QN93HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S
M='(@(E9EM6UI('9Y<V]KX2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@
M(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B6F]B<F%Z:;L@)7,B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM
M<V=S='(@(EIO8G)A>FF[(&5X=&5R;OH@=W=W('-T<N%N:W4B"@HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B6F]B<F%Z:;L@86MO("5S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B0G)I='-K
MZ2!086YE;G-KZ2!O<W1R;W9Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M(%4N4RXB"FUS9W-T<B`B06UE<FEC:^D@4&%N96YS:^D@;W-T<F]V>2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM
M<V=S='(@(E9I9&ET9;5N;W.[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E9I9&ET
M9;5N;W.[.B`B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R
M(")6;V1A9F]N92!)=&%L>2!C97H@4TU44"(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*
M;7-G<W1R(")605)/5D%.244B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!3
M0U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B55!/6D]23D5.244A
M(2$@3T135%+!TE1%(%-+4DE05"!:("5S(%)5R$Y%+B(*"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G
M<W1R(")724X@8V5Z($A45%`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R(")786QL:7,@82!&=71U;F$B"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-"!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5F%R;W9A;FEE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I
M9"`B5V4B"FUS9W-T<B`B4W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B4')E
M9'!O=F7O('!OZ&%S:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T
M<B`BVF1A:F4@;R!P;^AA<^T@<&]S:WET=6IE(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE
M<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B
M(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=75R!S='+A;FMA(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM
M<V=S='(@(E3]OF1E;FYE(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5FET86IT92(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S
M(@IM<V=S='(@(E;M=&$@5N%S("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E9I=&%J=&4L
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DR"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(EKA<&%D;N$@
M4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")+=&]R^B!A<&QI:^%C:74@;>$@
M)7,@>F]B<F%Z:;L@<&\@<')I:&SA<V5N[3\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\B"FUS9W-T<B`B06O](&IE('IN86L@<')E(&]D9&6U;W9A
MZ#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B
M5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")!:_T@:F4@
M>FYA:R!P<F4@^G9O9'IO=FMU/R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M
M87`B"FUS9W-T<B`B36%P82!!=7-T<N%L:64@<')E('-L=;YB=2!7:&5R96ES
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`B2W1O<ND@9N%Z>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B2W1O<ND@>N%S=79NZ2!M
M;V1U;'D@<&]V;VQINR!P<F4@<F]ZN>UR96[]('1E>'1O=OT@961I=&]R+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(JGM<FMA(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,30*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*
M;7-G<W1R("*I[7)K82!V(&IE9&YO=&OA8V@@0U-3(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3HB"FUS9W-T<B`BJ>UR:V$@;65N=2`E<R!VM6%V;R`H<')E
M:F%V[2!S82!P<FD@[V%LN6]M('!R:6ALX7-E;NTI.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T
M:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BJ>UR:V$@=&%B=;5K>2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED
M(")7:61T:"!U;FET(@IM<V=S='(@(DIE9&YO=&MA(+GM<FMY(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@
M(E=I9'1H.B(*;7-G<W1R("*I[7)K83HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@
M(E9I971O<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E+A;F\@=FEE=&]R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R(")2_6-H;&]SNR!V971R82!V('5Z;&]C:"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G
M<W1R(")6:65T;W(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9I971O<CH@(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B
M3?ID<F]SNR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G
M:60@(E=I<VAL:7-T(@IM<V=S='(@(E=I<VAL:7-T(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(E!RX6-A(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D
M<F5S<R(*;7-G<W1R(")!9')E<V$@9&\@<'+A8V4B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*
M;7-G<W1R(")496QE9O-N(&1O('!RX6-E(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(DYE<W!RX79N>2!P;^AE="!P;VSM
M(&YA(')I861K=2`E9"X@3^AA:^%V82!S82`E9"P@;F&Y;&\@<V$@)60N(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R(").97-P<N%V;GD@<&_H970@<&]L[2X@3^AA:^%V82!S82`E
M9"P@;F&Y;&\@<V$@)60N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I
M;F<@82!61E,@9FEL92XB"FUS9W-T<B`B6FS](&]F9G-E="`E9"!P<FD@Z.UT
M86[M(%9&4R!S^F)O<G4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC($-O
M;G-T<F%I;G1S(@IM<V=S='(@(EKA:VQA9&[I(&]B;65D>F5N:6$@6#4P.78S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B4&]UOFET:64@<F]Z
MN>UR96[I:&\@:[7ZZ&$@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64B"FUS9W-T<B`B06QT97)N873M=FYE(&UE;F\@<W5B:F5K='4@6#4P
M.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(DED96YT
M:69I:^%T;W(@:[7ZZ&$@<W5B:F5K='4@6#4P.78S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS
M(@IM<V=S='(@(E@U,#EV,R!R;WJY[7)E;FEA(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(EE9(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4S"FUS9VED(")965E9(@IM<V=S='(@(EE9
M65DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P
M.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R$@;6%P(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM
M<V=S='(@(E)OZ&YE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B2F5M96XB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS
M9VED(")997,B"FUS9W-T<B`B06YO(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*
M;7-G<W1R(")3^FAL87/M;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RXB"FUS9W-T<B`B(@HB4W1E('8@5$585$]63TT@4D6N24U%+B!0;W6^
M:71E('1L8>AI9&QO(%L\/ET@;F$@<')E<&YU=&EE(&YA<W#DNR!D;R!765-)
M5UE'+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(").96WTOF5T92!V>71V;W)I
MNR!V:6%C(&%K;R`E9"!B;&]K;W8N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#$U
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(").
M:64@<W1E(&%U=&5N=&EF:6MO=F%N_2XB"@HC.B!L:6(O2&]R9&4O261E;G1I
M='DN<&AP.C,P-PIM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B5F\@5F&Y;VT@
M<&QN;VT@;65N92!N96WTOF5T92!P;W6^:;L@>FYA:R`G7%PG+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#4Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Y
M"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N(@IM<V=S='(@(DYE>F%D86QI('-T92!P;&%T;OH@92UM86EL;W;Z(&%D
M<F5S=2XB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*(DYE=7+H:6QI('-T92!V>KMA:"!M961Z
M:2"^:6%D;GEM:2!P;VQI86UI('H@:6UP;W)T;W9A;NEH;R!S^F)O<G4@82`B
M"B)Z;V1P;W9E9&%J^F-I;6D@<&^U86UI('8@)7,N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.CDX-`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+B(*;7-G<W1R(")";VQI('-T92!O9&ALX7-E;OTN(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+B(*;7-G<W1R("(B"B)-=7/M=&4@>F%D8;L@<&QA=&[I(.CM<VQO
M(&UO8FEL;NEH;R!T96QE9O-N=2P@:W1O<ND@;V)S86AU:F4@:6)A(.CM<VQA
M(',@(@HB=F]L:71EM6[];2!P<F5F:7AO;2`G*R<@<')E(&UE9'II;N%R;V1N
M_2!F;W)MX70N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.3(*;7-G:60@
M(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(DUU
M<^UT92!Z861ANR!P;&%T;OH@:&]D;F]T=2XB"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B)!
M8GD@<W1E(&UO:&QI('!O=;[M=F&[(%)E9VES='+A8VEE+"!M=7/M=&4@;F%J
M<VOT<B!N86MO;F9I9W5R;W9ANR!$871A5')E92`B"B)B86-K96YD+B(*"B,Z
M(&QI8B](;W)D92YP:'`Z-#8R"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B375S[71E(&YA:V]N9FEG=7)O=F&[
M(%9&4R!B86-K96YD+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T
M<B`B375S[71E('!O<.US8;L@<')O8FSI;2!P<F5D=/UM+"!A:V\@;V1ON6QE
M=&4@<W!RX79U(&\@<')O8FSI;64N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(DUU
M<^UT92!Z861ANR!54DP@861R97-U+"!N82!K=&]R^B!TX71O(&QI;FMA('5K
M87IU:F4B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*
M;7-G<W1R(")-=7/M=&4@=GEB<F&[('-E<G9E<BP@:W1O<OT@;>$@8GF[('9Y
M;6%Z86[]+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B
M375S[71E('5RZ&F[(&UE;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC971E
M('9Y;6%Z8;LN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")-
M=7/M=&4@=7+H:;L@;65N;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@
M=GEM87IANRXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B375S[71E('5RZ&F[(&UE
M;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC971E('!R:61ANRXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B375S[71E('5RZ&F[('!O
M=;[M=F%T9;5A+"!K=&]R_2!S82!MX2!A:W1U86QI>F]V8;LN(@H*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DUU<^UT
M92!U<NAINR!A:V-I=2P@:W1O<N$@<V$@;>$@=GEK;VYANRXB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")-=7/M
M=&4@>F%D8;L@;65N;R!N;W9E:B!K871E9_-R:64N(@H*(SH@;&EB+TYE="]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")-
M=7/M=&4@>F%D8;L@=&%L:6%N<VME('1E;&5F\VYN92#H[7-L;R(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*(E!L871N;W.[(%9AN65J(')E;.%C:64@<')E(&%P;&EK
MX6-I=2`E<R!V>7!RN6%L82X@4')O<^UM('!R:6ALX7-T92!S82!Z;F]V=2XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B
M66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E9AN6$@16UA:6QO=N$@861R
M97-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")68;EA($5M86EL;W;A(&%D<F5S
M82!P;W6^:73A('!R92!O9&-HX61Z86KZ8W4@<&^Y='4Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AN64@
M:6YF;W)MX6-I92(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+B(*;7-G<W1R("(B"B)68;EA(&EN=&5R;F5T;W;A(&%D<F5S82!S
M82!Z;65N:6QA(&]D('IAZ&EA=&MU(%9AN65J(')E;.%C:64@)7,N(%!R92!6
M8;EU("(*(F)E>G!EZ&YO<[L@<V$@;75S[71E('IN;W9U('!R:6ALX7-INRXB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(E9AN64@;65N;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H
M96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)6X;D@875T96YT:69I
M:V'H;OT@;6]D=6P@;F5P;V1P;W)U:F4@<')I9.%V86YI92!P;W6^[79A=&6U
M;W8N($%K('-I(+YE;.%T92`B"B)P;W6^:;L@2&]R9&4@;F$@<W!RX79U('!O
M=;[M=F%T9;5S:_UC:"#ZZ'1O=BP@;75S[71E('!O=;YINR!I;OT@(@HB875T
M96YT:69I:V'H;OT@8F%C:V5N9"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BXB"FUS9W-T<B`B(@HB5N&Y(&%U=&5N=&EF:6MAZ&[](&UO9'5L
M(&YE<&]D<&]R=6IE('IO8G)A>F]V86YI92!Z;WIN86UU('!O=;[M=F%T9;5O
M=BP@(@HB86QE8F\@8F]L82!TX71O(&UOOFYO<[L@>B!N96IA:^EH;R!D]'9O
M9'4@>F%KX7IA;N$N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(EIDX2!S82P@OF4@5N&Y('!R96AL
M:6%D8>@@<V$@>FUE;FEL(&]D('IAZ&EA=&MU(%9AN65J(')E;.%C:64@)7,N
M(%!R92!68;EU("(*(F)E>G!EZ&YO<[L@<V$@;75S[71E('IN;W9U('!R:6AL
MX7-INRXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G
M<W1R(")6X;D@<')E:&QI861AZ"!N97!O9'!O<G5J92!T^G1O(&9U;FMC:74N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT
M+B(*;7-G<W1R("(B"B)6X;D@<')E:&QI861AZ"!N97!O9'!O<G5J92!T^G1O
M(&9U;FMC:74@=&QAZ&4N(%-T;&'H=&4@0V]N=')O;"]#;VUM86YD("L@4"`B
M"B)P<F4@=&QAZ"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS
M9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")68;EA(&%K
M='7A;&YA(.AA<V]VX2!Z\VYA.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY
M.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG
M960N(@IM<V=S='(@(E9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET82!B;VQA
M('IM96YE;N$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")0<F5D;F%S=&%V
M96[A(&ED96YT:71A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*
M;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")68;EE(&UE;F\Z(@H*
M(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-@IM<V=I9"`B66]U<B!L;V=I;B!H
M87,@97AP:7)E9"XB"FUS9W-T<B`B4&QA=&YO<[L@5N&Y:&\@^NAT=2!V>7!R
MN6%L82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S(@IM<V=S='(@(E9AN64@;F]VZ2!H97-L;R!P<F4@)7,@:F4Z("5S(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B5F&Y92!N87-T879E;FEA(&)O;&D@86MT
M=6%L:7IO=F%NZ2!P<F4@=&]T;R!S961E;FEE+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N(@IM<V=S='(@(E9AN64@;F%S=&%V96YI82!B;VQI(&%K='5A
M;&EZ;W9A;NDN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B
M5F&Y92!H97-L;R!B;VQO(&]B;F]V96[I(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)68;EE(&AE<VQO(&)O
M;&\@;V)N;W9E;NDL('-K;VYT<F]L=6IT92!S:2!P;[ET=2!A('!R:6ALX7-T
M92!S82!S(%9AN>UM(&YO=OUM("(*(FAE<VQO;2XB"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z-S,P"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+B(*;7-G<W1R(")0;&%T;F]SNR!6X;EH;R!H97-L82!V>7!RN6%L82XB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@
M<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9AN64@=GID:6%L96[I('-E<G9E
M<GDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B
M2G5H;W-LX79I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*
M;7-G<W1R("):86UB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("):
M:6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B
M6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R(");4VMR>;L@8VET;W9A;OT@=&5X=%TB"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*
M;7-G<W1R(");4W!RX79A(&\@<')O8FSI;65=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E
M9"!497AT("TB"FUS9W-T<B`B6UIO8G)A>FF[(&-I=&]V86[]('1E>'0@+2(*
M"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP
M.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M
M("5S(&QI;F5S72(*;7-G<W1R(");6F]B<F%Z:;L@8VET;W9A;OT@=&5X="`M
M("5S(')I861K;W9=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EMR:6%D;VL@
M)7,@>B`E<UTB"@HC.B!L:6(O2&]R9&4N<&AP.C$U-#4@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(E]!9&UI;FES='+A8VEA(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED
M(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G
M:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]6>6UA>F&[(')I861O:R(*"B,Z
M(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?4VMU
M<&EN>2(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP
M(@IM<V=S='(@(E]0;VUO8V[M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B5FQA<W1N;W-T:2!?;V)RX7IK=2XN+B(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS
M9W-T<B`B7U!R:6ALX7-INR!S82(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ
M.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]/9&ALX7-INR!S82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]5<')A=FF[
M(&QI;FMU+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B
M7T]P=&EO;G,B"FUS9W-T<B`B7TYA<W1A=F5N:6$B"@HC.B!L:6(O87!I+G!H
M<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4'+A=F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")/9'-T7W+A
M;FF[(&QI;FMU+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T
M=7`B"FUS9W-T<B`B3F%?<W1A=F5N:64B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E9L87-T;F]S=&D@7W1A8G6U:WDN
M+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M(")0;U]UONUV871E;&EA(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C`*
M;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")A9')E<^%R(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R(")A9')E<^%T(&YE>F[A;7DB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L
M96YDX7(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S
M='(@(F)E>G9E=')I92(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R
M(")N97!O9&%R:6QO('-A('9Y='9O<FF[(';]<W1U<&[]('/Z8F]R(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@
M;W!E;B!I;G!U="(*;7-G<W1R(")N97!O9&%R:6QO('-A(&]T=F]R:;L@=G-T
M=7`B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"FUS9VED
M(")C;&EC:R!H97)E(@IM<V=S='(@(FML:6MN:71E('-E;2(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE
M('5S86=E(&5R<F]R(@IM<V=S='(@(F-H>6)A('!R:2!P;W6^:73M('!R[6MA
M>F]VZ6AO(')I861K=2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")C:'EB
M82!K;VYF:6=U<N%C:64B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B8VC]8F$@9/1L9;YI=/T@<WES=.EM;W;]('/Z8F]R(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA
M="!E<G)O<B(*;7-G<W1R(")C:'EB82!F;W)MX71U(/ID86IO=B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T
M(&9O=6YD(@IM<V=S='(@(G!O;&^^:V$@;F5NX6ID96[A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI
M;F<B"FUS9W-T<B`B:VQE<^$B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.#@Q"FUS9VED(")F:6QE(@IM<V=S='(@(G/Z8F]R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")Z;R!S;65R=2`E<R`H)7,I
M('+]8VAL;W.[;W4@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(F[A<F%Z;W;](@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.`IM<V=I
M9"`B:#HB"FUS9W-T<B`B=CHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE
M('5N:VYO=VXB"FUS9W-T<B`B;F5Z;N%M92!M96YO(&AO<W1I=&6U82(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*
M;7-G<W1R(")O:V%MOFET92(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`B=B!S<'+A=F4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")C:'EB82!V
M<W1U<'4O=OUS='5P=2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B
M:6YT97)NX2!C:'EB82!S;V9T=NER=2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B
M<FEA9&MO=ETB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B<&_H87,@=GET=N%R86YI82!)
M4T\@;F%S=&%L82!C:'EB82!M:VES;V9S("5D(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.`IM<V=I9"`B;6TB"FUS9W-T<B`B
M;6TB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B;65N;R(*"B,Z(&QI
M8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM
M<V=S='(@(FYE:6UP;&5M96YT;W9A;NDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS
M9W-T<B`B>F%T:6&U(&YE:6UP;&5M96YT;W9A;NDB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDP-`IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")P;WINX6UK
M;W;](&)L;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!E<F-E
M;G0B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@
M(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(G!R[7-T=7`@>F%M:65T;G5T
M_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")B;V1O=B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(G9Z9&EA;&5NX2!C:'EB82!V('!R
M;W1O:V]L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<W3Z<&$B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B<VQUOF)A(&YI92!J92!D;W-T=7!NX2(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R
M96YC97,B"FUS9W-T<B`B>F]B<F%Z:;L@<F]Z9&EE;'DB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@
M=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL(&-E>B!(5%10(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-`IM<V=I9"`B<W,B
M"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G5S=.%L96[](@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T
M96T@97)R;W(B"FUS9W-T<B`B<WES=.EM;W;A(&-H>6)A(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")Z
M;WIN86T@^FQO:"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V
M-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B9&_H87-NX2!C
M:'EB82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M(@IM<V=S='(@(G!R92!P;W1V<F1E;FEE('IA9&%J=&4@:&5S
M;&\@9'9A:W+A="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N
M:69I:V]V86[I(@H*(SH@;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G
M:60@(G5N;F%M960B"FUS9W-T<B`B;F5P;VUE;F]V86[A(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T
M<B`B9&5F:6YU:F4@<&]UONUV871EM2(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,`IM
M<V=I9"`B=SHB"FUS9W-T<B`BN3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE
M<BYC;VTB"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O+FAT
M86-C97-S````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`Q-@`Q,#4Q-30S,3`V,P`P,38V,C``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1&5N>2!F<F]M(&%L;`H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VQT7TQ4+G!O````````
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`W,C$W
M-S8`,3`U,34T,S$P-C,`,#$V-#(W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@3&ET:'5A;FEA;B!T<F%N<VQA=&EO;G,@
M9F]R($AO<F1E('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!$87)I=7,@
M36%T=6QI875S:V%S(#QD87)I=7-`;&YK+FQT/BP@,C`P,BX*(R!6:6QI=7,@
M4W5M<VMA<R`\=FEL:75S0&QN:RYL=#XL(#(P,#,L(#(P,#0N"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC
M=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`T+3$Q+3(Y(#$R.C4R*S`R
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@5FEL:75S(%-U;7-K87,@/'9I;&EU
M<T!L;FLN;'0^7&XB"B),86YG=6%G92U496%M.B!,:71H=6%N:6%N(#QV:6QI
M=7-`;&YK+FQT/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ,UQN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S
M(&1A>7,@86=O*2(*;7-G<W1R("(@*'!R:67P("5S(&1I96YA<RDB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H;7EG='5K87,@)7,I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*'!R
M:67P("5S(&1I96YA<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*/!I86YD:65N*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*(RP@9G5Z>GD*;7-G:60@
M(B`H=&]M;W)R;W<I(@IM<V=S='(@(E)Y=&]J(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@
M(B`H=F%K87(I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B
M("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y
M+B(*;7-G<W1R(").92!K871A;&]G87,B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G('ER82!N96QE
M:7-T:6YA(')E:6OP;>LN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*
M;7-G<W1R("(G)7,G(&YE<W5K;VYF:6?[<G5O=&%S($AO<F1E(')E9VES=')E
M+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O
M=6YD+B(*;7-G<W1R(").ZW)A("<E<R<@;65D_FEO(&=E;F5R871O<FEA=7,N
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2XB"FUS9W-T<B`B1W)U<.L@)R5S)R!S=6MU<G1A+B(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")496ESZR`G)7,G('-U:W5R=&$N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z
M("5S+B(*;7-G<W1R("(G)7,G(&YE8G5V;R!S=6MU<G1A.B`E<RXB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@
M:7(@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UD
M:65N^"!P<F]G;F]ZZR(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E
M<R`M('!A<W1A8F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*
M;7-G<W1R("(E<R!A;G1S<&%U9&%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R
M("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S('!R;V9I;&%K=&EK;W,@=F5I:W-M
M86D@+2!P871V:7)T:6YI;6%S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R(")?2V]N9FEG^W)A8VEJ
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!R96=I
M<W1R86-I:F$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B5S(&YU;W-T871O<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R("(E<R!J874@96=Z:7-T=6]J82XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O
M0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T
M-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R`E<R`E<R(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+B(*;7-G<W1R(")08?YY;>MK:71E+"!K=7)I87,@;W!E<F%C:6IA
M<R!N;W)I=&4@871L:6MT:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM
M<V=S='(@(B5S('ER82!P<FEV86QO;6%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G
M<W1R("(E<R!M:6YU=.MS(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B5S(&YE<F%S=&%S+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B;G5O("5S(&EK:2`E<R!I\"`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S(&%D<F5S^"!K
M;GEG96SK(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<R!K
M86QE;F1O<FEU<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E
M<R!U_G)A\/@@:VYY9V5LZR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS
M9W-T<B`B)7,@9&%R8O@@<^!R8?!A<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S
M96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`HC+"!F=7IZ>0IM<V=I9"`B+"!G
M=7-T:6YG("(*;7-G<W1R("(L(&?[<VEA:2`E<R`E<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&?[
M<VEA:2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G
M<W1R("(L(&MI;G1A(&YU;R`E<R!I:VD@)7,B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM
M<V=S='(@(BTM('!A<VER:6YK:71E("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,B!V86QA
M;F3X(&9O<FUA=&%S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED
M("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"!V86QA;F3X(&9O<FUA=&%S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO
M=7)S(@IM<V=S='(@(C(T('9A;&%N9&]S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S
M='(@(D%N:W-T97-N:7,@<'5S;&%P:7,B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("+0:6%M(&)L;VMU:2!R96EK86QI
M;F=A('9I971A(&1U;VUE;O@@8F%ZZVIE+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R("+!=GEK;R!R:6UT82!K;&%I9&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(DYO<NMD86UI('7^:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT
M:2!V:67PX&KA(%!'4"!R86MTX"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B
M"B).;W+K9&%M:2!P871I:W)I;G1I('!A<VER8?!Y=.`@;&%I\&O@('!R:79A
M;&]T92!T=7+K=&D@=FEE\.!JX2!01U`@<F%K=.`N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M(DYO<NMD86UI(&%T:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V
M:67PX&KA(&ER('-L87!TX&KA(%!'4"!R86MT=7,L("(*(F)E:2#^:6YO=&D@
M<VQA<'3@:N`@9G)A>N8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DYO<NMD86UI('!A<VER8?!Y
M=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!J
MX2!01U`@<F%K='5S+"`B"B)B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@HB3F]RZV1A;6D@871K;V1U;W1I(&QA:?!K
MX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%
M("(*(G)A:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(DYO<NMD86UI('!A<VER8?!Y=&D@;&%I\&O@('!R:79A
M;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!3+TU)344@(@HB<F%K
M='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(DYO<NMD86UI('7^:V]D=6]T:2!L86GP:^`@<')I=F%L;W1E('1U
M<NMT:2!V:67PX&KA(%,O34E-12!R86MTX"XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U>GIY"FUS9VED(")!32!#
M;&]U9',B"FUS9W-T<B`B1&5B97-U;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-($QI
M9VAT(%)A:6XB"FUS9W-T<B`B4$T@;&5N9W9A<R!L:65T=7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0HC+"!F=7IZ>0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R("),:65T=7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R
M<R(*;7-G<W1R(")!32!R;V1Y;6%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3,*(RP@9G5Z>GD*;7-G:60@(D%-(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")0^V=A(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS
M9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI
M<R!E9&ET;W(B"FUS9W-T<B`B07!I92#PX2!R961A:W1O<FGX(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S
M='(@(D%P:64N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B5FES:?!K
M86D@87!AZ&EO:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B5FES:?!K
M86D@<&5R('9I9'5RX2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B4VES=&5M82!N971U<FD@=&5I<VGX('-U:W5R=&D@
M5D93(&MA=&%L;V?@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M(@IM<V=S='(@(E-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!F
M86ELX"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM
M<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VEJ
M82!A<&EE($IU<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I
M9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")3;&%P=&'^;V1I<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(E/@<VMA:71A('7^
M\&%L9'ET82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS
M9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(D%P<VMA:71A(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B4W5K=7)T:2(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B4W5K=7)T:2!P;V=R=7#A(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO
M;B(*;7-G<W1R(")3=6MU<G1I('!O=&5I<V5S(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")";&]K
M;R#A=&5R<&EM87,Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO
M9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B
M4W5K=7)T:2!N875JX"!G<G5PYB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM
M<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(E-U:W5R=&D@;F%U
M:F%S('1E:7-E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")0;V=R=7!I;R!G<G5P96D@
M)R5S)R!S=6O[<FEM87,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B4&]T96ESZW,@=&5I
M<V5I("<E<R<@<W5K^W)I;6%S(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G
M:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(").875J;R!V87)T;W1O:F\@
M<W5K^W)I;6%S.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B4')I9.MT
M:2!S='5L<&5LX2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(").875J^"!N
M87)I^"!P<FEDZVII;6%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B4W5K=7)T:2!P;W+@(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS
M9W-T<B`B4')I9.MT:2`E<R!M96YI=2!P<FEE($UO>FEL;W,@X7)A;FMI^"!J
M=6]S=&]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("+!
M=')A=6MT:2#A(&%D<F5S^"!K;GEG96SF.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R("+!=')A=6MT:2#A(&UA;F\@861R97/X(&MN
M>6=E;.8Z(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R
M(@IM<V=S='(@(E-U:W5R=&D@=F%R=&]T;VK@(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(E9A
M<G1O=&]J87,@)R5S)R!S=6MU<G1A<RP@=&'H:6%U('!A<&EL9&]M82!R96=I
M<W1R86-I:F]S(&EN9F]R;6%C:6IA(&YE8G5V;R`B"B)I\'-A=6=O=&$Z("5S
M+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(E9A<G1O=&]J87,@)R5S)R!S=6MU<G1A<RX@1V%L
M:71E('!R:7-I:G5N9W1I+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(E9A<G1O=&]J^"!K^W)I;6%S(&GP:G5N9W1A<RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!
M9')E<V%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S86DB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B061M:6YI<W1R=6]T:2`M(&=A;&D@;G5S=&%T>71I('1E:7-E<R!K:71I
M96US('9A<G1O=&]J86US(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(E9A;&1Y;6%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(D)A;F5R:6%I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G86YI<W1A
M;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A
M;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06S^
M>7)A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(E!R879A<F3K(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B06QI9VXB"FUS9W-T<B`B3'EG:75O=&DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE
M;G0Z(@IM<V=S='(@(DQY9VEA=FEM87,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B5FES;W,B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*
M;7-G<W1R(")6:7-I('!R:7-I:G5N9^8@=F%R=&]T;VIA:2(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L
M;"!'<F]U<',B"FUS9W-T<B`B5FES;W,@9W)U<.MS(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B5FES;W,@=&5I<^MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`B5FES;W,@:V5T=7)I;W,@<'5SZW,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,B"FUS9W-T<B`B3&5I<W1I(&ME;&5TX"!A9')E<_@B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("),96ES=&D@;F%U9&]T:2!S
M=7+[\&EU;W3@('/@<F'PX#\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S
M='(@(DIA=2!E9WII<W1U;VIA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT
M97)N871Y=G5S($E-4U`@<')I<VEJ=6YG:6UA<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M(@IM<V=S='(@(D%L=&5R;F%T>79U<R!)35-0('-L87!T8?YO9&ES(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-
M4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N871Y=G5S($E-4U`@=F%R=&]T
M;VIO('9A<F1A<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U
M"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E
M<FYA='EV=7,@96PN('!A\'1O(&%D<F5S87,B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R
M(")!;'1E<FYA='EV^W,@\&%B;&]N86DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L
M=&5R;F%T92!T97AT.B(*;7-G<W1R(")!;'1E<FYA='EV=7,@=&5K<W1A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M
M97)I:V]S(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("+!=F5D
MZW1E(&YE;&5I<W1I;N`@<F5I:_!MYBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R
M<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("+!=GEK;R!R:6UT82!K;&%I9&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=I;&%I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO
M;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYI;6EN:7,@<')O>'D@<V5R=F5R
M:7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B
M06YS=V5R(@IM<V=S='(@(D%T<V%K>6UA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&ED82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!I
M<B!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED
M(")!<'!L:6-A=&EO;B(*;7-G<W1R(")-;V1U;&ES(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(DUO9'5L:7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B
M36]D=6QI<R!V96EK:6$@9V5R86DN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G
M<W1R(")0<FET86EK>71I(&ER('!O\&%K:6%M<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S
M='(@(E!A='9I<G1I;G1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X
M"FUS9VED(")!<')I;"(*;7-G<W1R(")"86QA;F1I<R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB
M"FUS9W-T<B`B07)A8FGP:V$@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B
M"FUS9W-T<B`B07)C:'EV;R!F86EL;R!D>61I<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B
M07)C:'EV;R!F86EL;R!P879A9&EN:6UA<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B07(@=&EK<F%I(&YO<FET92!I
M\'1R:6YT:2`E<R!R96=I<W1R86-I:F]S('!R8?!Y;>`_(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B07(@=&EK<F%I
M(&YO<FET92!I\'1R:6YT:2`G)7,G(&ER('9I<W5S('!O9W)U<&EU<S\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FWK;FEJ
M82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA
M;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FWK;FGP:V$@*$%235-#24DM."DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G
M<W1R(")-96YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@
M(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I
M9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")+<FES=&%U<R#^96YG:6UO
M(.$@9&%N9_@@<V%L82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM
M<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%C<VEI(&UE;F%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF
M:6,@4F5G:6]N(@IM<V=S='(@(D%Z:6IA+U)A;6EO:F\@=F%N9&5N>6YO(')E
M9VEO;F%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_(@IM<V=S='(@(D%R('!R8?!Y=&D@<&%T=FER=&EN=&D@
M<')O9FEL86MT:6MO<R!V96EK<VUU<S\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T
M<B`B4')I<VMY<FEM;R!S='5L<&5L:6%I(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N(@IM<V=S='(@(D)A;F1O=&4@:?!T<FEN=&D@;F5E9WII<W1U;VIA
M;NAIX"!G<G5PYBXB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R(")"86YD;W1E(&GP=')I;G1I(&YE96=Z:7-T=6]J86[H
M:6%S('1E:7-E<RXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(D)A;F1O=&4@<F5D86=U;W1I(&YE96=Z:7-T=6]J86[H:6%S
M('1E:7-E<RXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS
M9W-T<B`B0F%N9&]T92!R961A9W5O=&D@;F5E9WII<W1U;VIA;G3A(&5L96UE
M;G3@+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!
M='1R:6)U=&5S(@IM<V=S='(@(D%T<FEB=71A:2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS
M9W-T<B`B4G5G<&K[=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA
M(@IM<V=S='(@(D%U<W1R86QI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T
M<FEA(@IM<V=S='(@(D%U<W1R:6IA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S
M<6PZ(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-05`@;6]D=6QI<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@8WER=7,@;F5T=7)I(')E:6MI
M86WX(&=A;&EM>6)I^"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@;F5R87-T
M87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H
M7V9T<#H@;F5R87-T87,@<F5I:V%L:6YG87,@1E10(&UO9'5L:7,N(%-U:V]M
M<&EL:75O:VET92!02%`@<W4@+2UE;F%B;&4M(@HB9G1P+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VEM87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-05`@;6]D=6QI<RXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]K<F(U.B!N97)A<W1A<R!R96EK86QI;F=A<R!K<F(U
M(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A
M<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!N97)A
M<W1A<R!R96EK86QI;F=A<R!,1$%0(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z('-U:W5R
M=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO+B!397)V97)I;R!P<F%N9?!I;6%S
M.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(&GP=')I;G1I('9A<G1O=&]J
MX"`E<R!N97!A=GEK;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@871N875J
M:6YT:2!V87)T;W1O:N`@)7,@;F5P879Y:V\B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!N97)A<W1A<R!R96EK
M86QI;F=A<R!-0T%,(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A
M=71H.B!N97)A<W1A<R!R96EK86QI;F=A<R!S;6)A=71H(&UO9'5L:7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B4')I
M<VEJ=6YG=&D@;F5P879Y:V\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(E!R:7-I:G5N
M9W1I(&YE<&%V>6MO+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N(@IM<V=S='(@(E)!1$E54R!S97)V97)I<R!N96QE
M:63^:6$@875T96YT:69I:W5O=&ES+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R
M=F5R:6\@;F5P879Y:V\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HW,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--
M0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")0<FES:6IU;F=T:2!P<FEE($94
M4"!S97)V97)I;R!N97!A=GEK;RXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")'
M86QI;6D@;&%U:V%I.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB
M"FUS9W-T<B`B07IE<F)A:63^86YA<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@871S
M:7!R8?!Y;6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")&
M;VYA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B1F]N;R!S
M<&%L=F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS
M9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(DYE=&5I<VEN
M9V%S(&ME<F)E<F]S('-L87!T8?YO9&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B3F5T96ES:6YG87,@:V5R8F5R;W,@=F%R=&]T;VIO('9A
M<F1A<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A
M:&%M86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A
M:')E:6YA<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"
M86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:?!K82`H25-/+3@X
M-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R
M(")"86=L861E\&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS
M9W-T<B`B0F%R8F%D;W-A<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B2VQA<^MS("5S
M(&[K<F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")086=R+B!L
M:6YI:F]J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B
M0F%L=&%R=7-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S
M='(@(D)E;&=I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T
M<B`B0F5L:7IA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@
M(D)E;FEN87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@
M(D)E<FUU9&%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(D)U=&%N87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")':6UT861I96YI
M<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O
M9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S
MZW,@)7,@;NMR82XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;VMO('!A<F%M
M971R86DB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G
M:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B0FQO:V\@=&EP87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`B4&%S=&]R:6YT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O
M;&EV:6$B"FUS9W-T<B`B0F]L:79I:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B073^>6UO
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")+<F'P=&%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B2W)A\'1O('-T;W)U;6%S
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B2W)A\'1A:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T
M<B`B0F]S;FEJ82!I<B!(97)C96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")6:7-O<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-V86YA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U
M"FUS9VED(")";W1T;VTB"FUS9W-T<B`B07!AZ&EO:F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(D)U=F5T('-A;&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>FEL:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I
M=&]R>2(*;7-G<W1R(")"<FET^"!);F1I:F]S('9A;F1E;GEN;R!T97)I=&]J
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S
M='(@(D)R=6[K:F%U<R!D87)U<V%L96UA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEJ82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B4W7^>6WK=&%S('/@<F'P87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN87,@1F%S87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&EJ
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--
M4R(*;7-G<W1R(")45E,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"!P87-K:7)S='EM;R!P
M=6YK=&%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E]#96SK<R!N=7-T871Y;6%I+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PHC+"!F=7IZ>0IM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B3F7A<F'PZW1E(&1I<W1R
M:6)U8VEJ;W,@<^!R8?!O+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1O<FEU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B4F%M=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;V3^82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R^VYA
M<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).979E:6MI82!A=71O
M;6%T:6YI<R!S;&%P=&'^;V3^:6\@<&%K96ET:6UA<RP@<W5S:7-I96MI=&4@
M<W4@(@HB861M:6YI<W1R871O<FEU;6DN(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(DYE9V%L:74@
M:?!T<FEN=&D@9F%I;&\@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N
M(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R(").96=A;&EU('!R:7-I:G5N9W1I('!R
M:64@24U!4"!S97)V97)I;SH@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE9V%L:74@:?!T<FEN=&D@
M9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G
M<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E
M<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R(")!=/!A=6MT:2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B073P875K=&D@<')O8FQE;6]S('!R86YE\&EMX"(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE9V%L:74@:?!T
M<FEN=&D@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DYE9V%L:74@<F%S=&D@;&%I
M:VEN;VIO(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B3F5G86QI=2!A
M<&1O<F]T:2`G=&%R9V5T1FEL92<@<&%R86UE=')O+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5G86QI
M=2!I\'1R:6YT:2!K871A;&]G;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").96=A;&EU
M(&GP=')I;G1I+B!%9WII<W1U;VIA("5D('!O\&%K:6%I+B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*(DYE9V%L:74@<&5R<OOP:75O=&DN(,%V97-T87,@X7)A\/@@
M<VMA:>AI=7,@;F5S=71A;7!A('-U(.%R8?#X('-K86GH:75M:2`B"B)D=6]M
M96[X(&)A>NMJ92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DYE9V%L:74@;G5K<F5I
M<'1I(/YI;G5TZW,@X2!N=7)O9'ETX"!N=6UE<N$N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")+96EP=F5R9&ES(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM
M<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")0879A9&EN:6UA<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E
M9V]R:6IO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*
M;7-G<W1R(")+86EM86[X('-A;&]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G
M<W1R(")-;V)I;'5S('1E;&5F;VYA<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R(")#96SK<R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E
M;&P@<&%D9&EN9SHB"FUS9W-T<B`B5&%R<&%I(&-E;.MS93HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS
M9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B0V5LZW,@;G5S=&%T>6UA
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(E1A<G!A:2!T87)P
M(&-E;&GX.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G
M:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I;'5S:7,@=&5L969O;F%S(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/
M+3@X-3DM,30I(@IM<V=S='(@(DME;'3X("A)4T\M.#@U.2TQ-"DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V
M"FUS9VED(")#96YT97(B"FUS9W-T<B`B0V5N=')E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D-E;G1R
M:6[K<R!!9G)I:V]S(%)E<W!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB
M"FUS9W-T<B`B0V5N=')I;NMS($5U<F]P;W,@*$E33RTX.#4Y+3(I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E
M<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B4V5R=&EF:6MA=&\@9&5T86SK
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"B,L
M(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")397)T
M:69I:V%T;R!D971A;.MS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S
M='(@(E-E<G1I9FEK871O('1E:7/K<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B
M0VAA9"(*;7-G<W1R("+(861A<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G
M:60@(D-H86YG92(*;7-G<W1R(")086ME:7-T:2(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A_F]D_FEO(&ME:71I;6%S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B
M(@HB2OMS^"!V87)D;R!I<B!A9')E<V\L(&MU<FEU;W,@;6%T>7,@_FUO;NMS
M+"!S:V%I=&%N='ES(&ER(&%T<V%K:6[K:F%N='ES(.$@(@HB2OMS^"!L86GP
M:W5S+"!K96ET:6UA<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B
M"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")3:6UB;VQI<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I
M9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B4&%?=&EK<FEN=&D@;G5O<F]D
MX"XN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(LAI;.LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R(")+:6YI:F$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(DMI;FEE=&GP:V$@<&%P<F%S=&$@
M*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B
M0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B2VEN:65T:?!K
M82!T<F%D:6-I;NL@*$)I9S4I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T
M<B`B4&%S:7)I;FMI=&4@<VQA<'1A_F]DX2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE
M(@IM<V=S='(@(E!A<VER:6YK:71E('9A<G1O=&]J;R!V87)DX"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@:V%I<"!V86EZ
M9'5O=&D@9&%T87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E!A<VER:6YK
M:71E('-U<OOP:75O=&\@<^!R8?!O('-T:6QI^"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B2V%LZV3X('-A;&$B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%SZW,@)7,@;NMR
M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B1VEE9')A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@
M35-/9F9I8V4@=&%G<R(*;7-G<W1R("))\'1R:6YT:2!-4R!/9F9I8V4@_GEM
M97,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED
M(")#;&5A<B!1=65R>2(*;7-G<W1R("))\'9A;'ET:2!V87)T;W1O:F\@9'5O
M;65N:7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T
M<B`B5F%R=&]T;VIO(&1U;VUE;O@@=F%L>6UA<SH@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B
M"FUS9W-T<B`B2?!V86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S
M97(@9&%T82(*;7-G<W1R("))\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N:7,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0HC
M+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("),:65T=7,@
M=F%K87)E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(E3F
M<W1I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@
M(D-L:6-K871E;&P@<&5R($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L
M;W-E(%=I;F1O=R(*;7-G<W1R(")5_F1A<GET:2!L86YGX"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B1&5B
M97-U;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")$
M96)E<W5O=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D1E8F5S=6]T82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S
M='(@(DMO:V]S;R`H2WEL:6YG;RD@<V%L;W,B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")#;VQL87!S92!3
M:61E8F%R(@IM<V=S='(@(E1U\.AI^"!C96QI^"!K<F'P=/@@<F]D>6UA<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(E1U\.AI
M^"!C96QI^"!K<F'P=/@@<F]D>6UA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEJ82(*"B,Z(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#
M;VQO<B(*;7-G<W1R(")3<&%L=F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4&%S:7)I
M;FMI=&4@<W!A;';@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T
M-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")3<&%L=F]S('!A
M<VER:6YK:6UA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")3='5L<&5L:6%I
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O
M;'5M;B!T:71L97,B"FUS9W-T<B`B4W1U;'!E;&GX('!A=F%D:6YI;6%I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S
M(@IM<V=S='(@(DMO;6EK<V%I(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U
M"FUS9VED(")#;VUM86YD(@IM<V=S='(@(DMO;6%N9&$B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
M2V]M86YD:6[K(&5I;'5TZR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUE;G1A<F%S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G
M:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(E9A<F1A<R]P879A<F3K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)A:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G
M:60@(D-O;7!A;GDB"FUS9W-T<B`B2V]M<&%N:6IA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B2V]M
M<&EU=&5R:6%I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(E/@;'EG;W,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N
M<R(*;7-G<W1R(")3X&QY9V]S(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B
M3G5S=&%T>6WX('!A:V5I=&EM86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@
M4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(E)E:6MI82!A
M=&YA=6II;G1I(&MO;F9I9_MR86-I;N$@9F%I;.`N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U
M<F4@)7,B"FUS9W-T<B`B2V]N9FEG^W)U;W1I("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S
M=V]R9"(*;7-G<W1R(")3;&%P=&'^;V1I<R!D87(@:V%R=.`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U
M"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M(@IM<V=S='(@(D1E;6]K<F%T:6[K($MO;F=O(%)E<W!U8FQI:V$B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B4')I<VEJ=6YG=&D@;F5P879Y
M:V\N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q
M,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")0<FES:6IU
M;F=T:2!N97!A=GEK;SH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(E!R:7-I:G5N9W1I('!R:64@=FEE
M\/AJ^"!R86MT^"!S97)V97)I;R!N97!A=GEK;RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RDB"FUS9W-T<B`B4')I<VEJ=6YG=&D@<')I92!V:67P
M^&KX(')A:W3X('-E<G9E<FEO(&YE<&%V>6MO+"!N97,Z("5S("@E<RDB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4')I<VEJ=6YG
M=&D@<')I92!&5%`@<V5R=F5R:6\@;F5P879Y:V\N(@H*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM
M<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;FMA:W1A:2!SZVMM:6YG86D@
MX71R875K=&D@X2!*^W/X(&%D<F5S^"!K;GEG96SF(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(G)7,G('1U<FEN>7,B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(E3F
M<W1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@
M(DMU:V\@<V%L;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G
M:60@(D-O;VMI92(*;7-G<W1R("),86EMZW,@_FEN=73K<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM
M<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!I:G5O=&DB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(E!R:7-I:G5N9W1I(&YE<&%V
M>6MO.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W!I:G5O
M=&D@<&%S:7)I;FMI;>`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO<W1A(%)I:V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D1R86UB
M;&EO($MA=6QO($MR86YT87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R(").97!A=GEK;R!U_FMO9'5O=&D@4$=0(&QA:?!K;RXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED
M(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B3F5P879Y
M:V\@<&%S:7)A\'ET:2!01U`@;&%I\&MO+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3F5P879Y:V\@=?YK;V1U;W1I
M(%,O34E-12!L86GP:V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+B(*;7-G<W1R(").97!A=GEK;R!P87-I<F'P>71I(%,O34E-12!L86GP
M:V\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<R(*;7-G<W1R(").97!A=GEK;R!P<FEDZW1I(&MO;G1A:W1O
M+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE<&%V>6MO(&%U
M=&5N=&EF:6MU;W1I<R#A($Q$05`@<V5R=F5RX2XB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN
M9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(").97!A=GEK;R!A=71E;G1I9FEK
M=6]T:7,@X2!,1$%0('-E<G9E<N$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").
M97!A=GEK;R!P871I:W)I;G1I(&)A;&%N<V\N("5S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F5P879Y:V\@<')I<VEJ
M=6YG=&D@<')I92!334(@<V5R=F5R:6\N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS
M9W-T<B`B3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92`G)7,G('-E<G9E<FEO
M('!E<B!&5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@<W5K=7)T:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B3F5P879Y:V\@871K
M;V1U;W1I(%!'4"!D=6]M96[X+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82XB"FUS9W-T<B`B3F5P879Y:V\@871K;V1U;W1I(%,O34E-12!D
M=6]M96[X+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@
M:V]N=&%K=&\N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@:?!T<FEN=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!A=&YA=6II
M;FEM;R!S:W)I<'1O("<E<R<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F5P879Y:V\@;G5S=&%T>71I
M(&=A=NMJ;R!E;"X@<&'P=&\@861R97-O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")0879Y
M:V\@9V%U=&D@=FES;W,@861R97/X(&MN>6=E;.MS+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(DYE<&%V>6MO(&=A=71I('9I<V\@9&ES=')I8G5C:6IO<R!SX')A
M\&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DYE<&%V>6MO
M(&=A=71I('9I<V\@9&ES=')I8G5C:6IO<R!SX')A\/@@<^!R8?!O+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<
M(BXB"FUS9W-T<B`B3F5P879Y:V\@=?YK<F%U=&D@<W1R871E9VEJ;W,@)R5S
M)RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T
M+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@<W5K=7)T:2!K871A
M;&]G;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@9V%U=&D@=FEE\&]J
M;R!R86MT;R!I\"!R86MT^"!S97)V97)I;RXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DYE<&%V>6MO(&%T
M:61A<GET:2`G)7,G(')A\'EM=6DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").97!A=GEK;R!A=&ED
M87)Y=&D@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F5P879Y
M:V\@871I9&%R>71I($UA:6YT96YA;F-E7U1A<VL@;6]D=6QI;R`E<R(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M3F5P879Y:V\@871I9&%R>71I(&MA=&%L;V=O("<E<R<N(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").97!A=GEK;R!P86EE\&MA($Q$
M05`@<V5R=F5R>6IE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP
M:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S
M+B(*;7-G<W1R(").97!A=GEK;R!S:V%I='ET:2`E<RXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E
M<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE
M(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE<&%V>6MO('!A
M:V5I<W1I('-L87!T8?YO9/YI;R#P:6%M('9A<G1O=&]J=6DN($MA:2!K=7)I
M(&%R8F$@=FES82`B"B)I;F9O<FUA8VEJ82!Y<F$@;F5T:6MS;&DN(%!A8F%N
M9'EK:71E(&1A<B!K87)TX"!A<F)A('-U<VES:65K:71E('-U('-A=F\@(@HB
M861M:6YI<W1R871O<FEU;6D@:F5I9W4@<F5I:V%L:6YG82!P86=A;&)A+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3F5P879Y:V\@9V%U=&D@
M04-,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B3F5P879Y:V\@9V%U=&D@
M861R97/X(&MN>6=E;.MS+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B3F5P879Y:V\@9V%U
M=&D@9&ES=')I8G5C:6IO<R!SX')A\/@N("5S(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B3F5P879Y:V\@
M;G5S=&%T>71I('-E<G9E<FEO(&=A;&EM>6)I^"(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B3F5P879Y:V\@871K96ES=&D@;G5S=&%T>6WX
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B3F5P
M879Y:V\@:?!T<FEN=&D@:V%T86QO9V\@)R5S)RXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").97!A=GEK;R!I
M\'-A=6=O=&D@)7,@;G5S=&%T>6WX+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").
M97!A=GEK;R!P861A<GET:2!A='-A<F=I;NMS(&YU<W1A='EM^"!K;W!I:F]S
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<R(*;7-G<W1R(").97!A=GEK;R!P861A<GET:2!A='-A<F=I
M;NMS("5S(&YU<W1A='EM^"!K;W!I:F]S+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R(").97!A=GEK;R!I\'-A=6=O=&D@871N875J:6YI;6\@<VMR:7!T
M(.$Z("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DYE<&%V>6MO
M('!A9&%R>71I(&%T<V%R9VENZW,@)7,@;G5S=&%T>6WX(&MO<&EJ;W,N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3F5P
M879Y:V\@=?YR8?!Y=&DN($K[<R!G86QI=&4@87)B82!N875D;W1I<R!A=&YA
M=6II;FEM;R!S:W)I<'1U(&%R8F$@<&%T>7,@(@HB;G5K;W!I:G5O=&D@:V]D
MX"!A<&'H:6]J92#A("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@<&%I9?!K82!,1$%0('-E<G9E<GEJ
M92XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").
M97!A=GEK;R!N=71R875K=&D@<GGPX2`G)7,G+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B3F5P879Y:V\@871N875J:6YT:2!K;VYT86MT;RX@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(").97!A=GEK;R!A=&YA=6II;G1I(&1I<W1R
M:6)U8VEJ;W,@<^!R8?!O+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R
M:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F5P
M879Y:V\@=?YR8?!Y=&D@)R5S)R!N=7-T871Y;?@Z("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B(@HB3F5P879Y:V\@<F%S=&D@36]Z:6QO<R#A<F%N:VGX
M(&IU;W-T;W,N(,%S:71I:VEN:VET92P@:V%D(&II(&%T:61A<GET82XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E
M<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M7"(E<UPB.B`E<R(*;7-G<W1R(").97!A=GEK;R!S=71E:6MT:2#P:?@@=&5I
M<VGX('9A<G1O=&]J=6D@)R5S)R!K871E;&]G92`G)7,G.B`E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X
M="(*;7-G<W1R(")2:6)O=&%S('1E:W-T87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R
M(")686QS='EBZR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*
M;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B2W5R<V%I(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`B4W5K=7)T:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B
M0W)E871E(&$@;&EN:R(*;7-G<W1R(")3=6MU<G1I(&YU;W)O9.`B"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#
M<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(E-U:W5R=&D@;F%U:N`@87!R8?#@
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*
M;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")3=6MU<G1I('!A
M:V%T86QO9VEU<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E-A=FEN
M:6YK;R!T96ESZW,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B2W)E9&ET:6[K
M<R!K;W)T96SK<R!N=6UE<FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T
M:6$B"FUS9W-T<B`B2W)O871I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A
M(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@
M9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B1&%B87)T
M:6[K(&9A>NLB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B4V%V:6YI;FMO('1E
M:7/K<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE
M+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D1A8F%R=&EN
M:7,@;&%I:V%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G
M<W1R("+0:75O(&UE='4@55),('ER82(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")$
M86)A<G1I;NL@9F%ZZR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G
M:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")$86)A<G1I;NMS(&]R;R!S
MX&QY9V]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM
M<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")$86)A<G1I;NMS
M('/@;'EG;W,Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B1&%B
M87)T:6YI<R!S=&EL:75S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E9E:6MS;?@L(&%T;&EE:V%M
M^"!P<FES:6IU;F=U<R!P<FEE("5S+"!N=7-T871Y;6%S+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM
M<V=I9"`B0W5T(@IM<V=S='(@(E!E<FME;'1I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C
M=&EO;B(*;7-G<W1R(")097)K96QT:2!P87-I<FEN:VEMX"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")+:7!R87,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS
M9W-T<B`B2VER:6QI8V$@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T
M<B`B2VER:6QI8V$@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M(@IM<V=S='(@(DMI<FEL:6-A+U5K<F%I;FEE=&GP:V$@*$M/23@M52DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("+(96MI
M:F]S(%)E<W!U8FQI:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B2V%S9&EE;B(*"B,Z
M(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E
M<B(*;7-G<W1R(")$=6]M96[X(&UE9/YI;R!N87+P>6MLZR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G
M:60@(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S
M='(@(D=A=71A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM
M<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B1&%T;W,@<&%S:7)I;FMI
M;6%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"FUS9VED(")$87DB"FUS9W-T
M<B`B1&EE;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(DGP=')I;G1I(%]S='5L<&5LX2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R
M(")'<G5O9&ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM
M<V=S='(@(D1E\&EM=&%I;FEA:2!S:V%IZ&EA:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R(")3=6UA_FEN=&D@871I=')A=6MI;>`B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP
M.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")3=&%N9&%R
M=&ENZR!S<&%L=F$B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")3
M=&%N9&%R=&ENZR!S<&%L=F$B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@
M(E-T86YD87)T:6YI<R!A<')A\&%S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@
M(E-T86YD87)T:6[K('-P86QV82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B07!I8G+K_FEM86DB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B2?!T<FEN=&DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(DGP=')I;G1I(&-E;.8B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R
M-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(DGP=')I;G1I(&=R=7#F
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(DGP=')I;G1I(&5I;'5TYB(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S
M:6]N(@IM<V=S='(@(DGP=')I;G1I('1E:7/F(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5FES:?!K86D@:?!T<FEN=&D@;&%I
M\&MU<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(DGP=')I
M;G1I(&-E;.8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@
M(DGP=')I;G1I('-T=6QP96SA(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B2?!T<FEN=&D@96=Z:7-T=6]J86YTX2!A;'1E<FYA='EV^"#P
M86)L;V[@(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(B<E<R<@=&5I<VGX('1R>6YI;6%S(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")!<B!T:6MR
M86D@;F]R:71E(&GP=')I;G1I("<E<R<@=&5I<V5S(&ER('9I<V%S('!O=&5I
M<V5S/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B2?!T<FEN
M=&D@96EL=73F(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y
M+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S
M='(@(DGP=')I;G1I('!A<VER:6YK=.`@87!R8?#@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(DGP=')I;G1I
M(/#A('-T=6QP96SA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W(@IM<V=S='(@(DGP=')I;G1I(/!IX"!E:6QU=.8B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(D%T;F%U:FEN:6UO('-K<FEP=&%S("<E<R<@:?!T<FEN=&%S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B
M4')I<W1A='EM;R!L86EK87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K
M(@IM<V=S='(@(D1A;FEJ82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")0<F]B;&5M;W,@87!R8?!Y;6%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D%P<F'P
M>6UA<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED
M(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@
M(D1E=&%L:6%U("AT86EP('!A="#^:?MRZVMI=&4@2&]R9&4@;&]G(&9A:6QE
M*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B061M:6YI<W1R871O<FEU:2!I\'-I^'-T87,@9&5T86QU
M<R!A<')A\'EM87,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q
M.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B5GES='EM87,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S
M='(@(D1RZV=N=6UA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS
M9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(D1RZV=N
M=6UA<R!P87-K=71I;N8@=F%L86YDX#H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B
M1'+K9VYU;6%S.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*
M;7-G<W1R(")+<GEP=&ES(&GP(&MA:7+K<R#A(&1E\&ENYB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I
M<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(DMR>7!T:7,@:?`@9&7P
M:6[K<R#A(&MA:7+F(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G
M:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G87,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_(@IM<V=S='(@(E)O9'ET:2`R-"UI^"!V86PN(&9O<FUA=.`_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B5F%I>F1A=FEM;R!N=7-T871Y;6%I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P
M;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(E)O9'ET:2!P<F]G<F]N
MYB`H5$%&*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I
M<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4F]D>71I('!R;V=R;V[F
M("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I
M9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5F%I>F1A=FEM;R!F;W)M871A
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@
M(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("),86GP:V\@<')I
M<W1A='EM;R!P<F%N9?!I;6%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U
M=&DB"FUS9W-T<B`B1/YI8G5T:7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").
M971R:6YT:2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I
M9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS
M9W-T<B`B3F5S:6MR96EP:VET92!T:65S:6]G:6%I(.$@;6%I;G1E;F%N8V4N
M<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#HB"FUS9W-T<B`B07(@<&ER;6%S(.%R8?!A<R!Y<F$@;&%U:V\@
M=F%R9&%I/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@
M(D1O;6EN:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D1O;6EN:6MO<R!297-P=6)L:6MA(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S
M='(@(D%T<VES:?AS=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B
M"FUS9W-T<B`B071S:7-I^'-T:2`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(D%T<VES:?AS=&D@<W5G96YE
M<G5O='5S(&YU<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES
M="(*;7-G<W1R("))\'-I<VML96ED_FEA;G1I<R!SX')A\&%S(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")6
M86ES=&%I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B16PN('!A\'1O(&%D<F5S87,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM
M<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE
M<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5K=F%D;W)A<R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D
M:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(DME:7-T:2(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")+96ES
M=&D@8FQO:V\@<&%R86UE=')U<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(E)E9&%G=6]T:2!G<G5PYB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")2961A9W5O=&D@=&5I
M<V5S(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B
M161I="!097)M:7-S:6]N<R(*;7-G<W1R(")2961A9W5O=&D@=&5I<V5S(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!T
M96ES:?@@<F5D86=A=FEM87,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")+96ES=&D@
M;G5S=&%T>6UU<SHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B5S('1E:7-I^"!R961A9V%V:6UA
M<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M)7,@=&5I<VGX(')E9&%G879I;6%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B56=D>6UA<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G:7!T87,B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A
M<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B4V%L=F%D;W)A<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT87,N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D5L+B!P8?!T87,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS
M9W-T<B`B16PN('!A\'1O(&%D<F5S87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`B16PN('!A\'1O(&%D<F5S86D@='5R:2!S=71A<'1I+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL
M('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D5L+B!P8?!T;R!A9')E<V%S
M('-U('!A='9I<G1I;FEM=2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BT'EP<V5N
MZVSK<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`BWFEN
M=73K('1U\.AI82XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@
M(E)E>G5L=&%T87,@='7PZ&EA<RXB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B3F5N=7)O9.MT92!P86EE\&MO<R!T97)M:6[X(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T
M<B`B3&5I<W1I('1E:W-T92#A=&5R<'1I('!A=F5I:W-LZVQI=7,@:?`@3G5O
M=')A=6OX(&=A;&5R:6IO<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R("+!:G5N9W1I(&1E\&EN:6]J;R!P96SK<R!M>6=T=6MO(&UE;FEU
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B
M1V%L:6YI86D@;65T86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R
M("))\'!LZW-T:2!R961A:W1O<FGX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*(L%R8?!Y:VET92!K;&%U<VEMX"P@:W5R
M:7,@:G5M<R!B=7,@=?YD=6]T87,@:F5I9W4@<&%M:7+P:71E('-A=F\@<VQA
M<'1A_F]DX2P@(@HB<'9Z+CH@)VMO:W,@>7)A($K[<_@@9WEV^VYO('9A<F1A
M<S\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H
M97)E(@IM<V=S='(@(L%V97-K:71E('!A=F5I:W-LZVQI;R!54DPB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED
M(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B16MV871O
M<FENZR!'=FENZVIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G
M<W1R(")%<FET<NMJ82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O
M<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(DML86ED
M82(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C
M:SH@)7,B"FUS9W-T<B`B2VQA:61A('-I=6[H:6%N="!A='-A:WEMX#H@)7,N
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,B"FUS9W-T<B`B2VQA:61A('-I=6[H:6%N="!A='-A:WEMX#H@
M)7,N(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,B"FUS9W-T<B`B2VQA:61A('-I=6[H:6%N="!A='-A:WEMX#H@
M)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,B"FUS9W-T<B`B2VQA:61A('-I=6[H:6%N="!A='-A:WEMX#H@)7,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S
M='(@(DML86ED82!L86GP:V4N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S
M7"(N(@IM<V=S='(@(DML86ED82!R8?!A;G0@)R5S)RXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&EJ82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]P:6IA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171N
M:6[K<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B
M2V%S(#$U(&UI;G7H:?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y
M"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2V%S(#(@;6EN=71E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R
M(")+87,@,S`@<V5K=6YD_FGX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U
M(&UI;G5T97,B"FUS9W-T<B`B2V%S(#4@;6EN=71E<R(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y
M($QO9VEN(@IM<V=S='(@(DMI96MV:65N;R!P<FES:6IU;F=I;6\@;65T=2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R(")+87,@<'5S=F%L86YDX2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM
M<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(DMA<R!M:6YU=.8B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V
M86QU97,Z(@IM<V=S='(@(E!A=GEZ9/YI=6DZ(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(E9Y:V1Y=&DB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("))\'-K;&5I<W1I(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]S:61E8F%R+FEN8SHS,@HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(%-I
M9&5B87(B"FUS9W-T<B`B1V%L:6YI86D@;65T86DB"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`B4F5I:V%L:6YG87,@)RDG(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D
M(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")296EK86QI;F=A<R#^
M;V1I<R!A<F)A(&MA8G5TZW-E(.%R8?!Y=&%S('!A:67P:V]S(&MR:71E<FEJ
M=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")'86QI;VII;6\@9&%T82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED
M(")%>'!O;F5N="(*;7-G<W1R(")%:W-P;VYE;G3K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B
M1D<@0V]L;W(B"FUS9W-T<B`B5&5K<W1O('-P86QV82(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B
M"FUS9W-T<B`B3G5S=&%T>6WX('-I=6YT:6UA<R!P97(@1E10+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DML86ED82!N=7-K
M86ET86YT(&YU<W1A='EM=7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(").97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE($Q$05`@<V5R=F5R:6\N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(").97!A
M=GEK;R!P<FES:6IU;F=T:2!P<FEE(%--0B!S97)V97)I;RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y
M:V\@;G5K;W!I:G5O=&D@:?`@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@;G5K;W!I:G5O
M=&D@X2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+B(*;7-G<W1R(").97!A=GEK;R!S=6MU<G1I(&YA=6IO(%-!4TP@<GGP
M:6\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!P
M97)K96QT:2#A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(')E=')I979E.B`E<R(*;7-G<W1R(").97!A=GEK;R!P97)K96QT:2#A(%PB
M)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("+0=F5L;G5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@
M(D9O;&ML86YD^"!S86QO<R`H36%L=FEN86DI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")&87)E<O@@<V%L;W,B"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A
M;"!%<G)O<CHB"FUS9W-T<B`B2W)I=&ENZR!K;&%I9&$A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(D9A:W-A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A:W-A<R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS
M9VED(")&96)R=6%R>2(*;7-G<W1R(")687-A<FES(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B071R
M;V1O(&QY9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*
M;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")!=')O9&\@;'EG.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B5')U;7!A;&%I:VES(&QI971U<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"B,L
M(&9U>GIY"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(E#[9V$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L
M9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R
M(")&:63^:7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B9F%I;&%S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")&86EL^"!S:V%IZ&EU<SH@
M)7,@9F%I;&%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T
M<B`B1F%I;/@@<VMA:>AI=7,Z("5S(&9A:6QA:2CX*2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G
M<W1R(")&86EL^"!T=F%R:WEM87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D9A:6QO('!A=F%D
M:6YI;6%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B1F%I;&\@<&%S:7)I;FMI;6%S
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL
M92!U<&QO860B"FUS9W-T<B`B1F%I;&\@<VEU;G1I;6%S(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F%R\'EK;.L@;F5P86QA:6MO
M(&9A:6SX('-I=6YT:6UO+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<F%I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")3=6]M:6IA(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R
M(")0:7)M;VII('!U<^LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S
M='(@(E!I<FUA<VES(&ME='9I<G1I<R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R(").=7-T871Y=&%S(&MO969I8VEE;G1A<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS
M9W-T<B`B071V:7)K\.AI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M("))\&3K<W1Y;6%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")2^VMA<R(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(DMA=&%L;V=A<R`E<R!N965G>FES
M='5O:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(E1E:W-T;R!S<&%L
M=F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B
M"FUS9W-T<B`B36%I<W1A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B3F%R\'EK
M;.MM<RP@:W5R:6]S(&YE<&%L86EK;R!P879E:6MS;.ML:?@B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B3W+X('!R;V=N;WKK("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D]R^"!P<F]G;F]ZZW,@
M87!I;71I<R`HX7-I9.MMZVMI=&4L(&MA9"#P:2!F=6YK8VEJ82!G<F'^:6YA
M(&ER(&1I96YO<R!I<B`B"B)N86MT:65S('!R;V=N;WKF.R!P97(@9&ED96QI
M<R!S:V%IZ&EU<R!G86QI('-U9&%R:WET:2!D:7IA:6[@*2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P
M87-S=V]R9#\B"FUS9W-T<B`B4&%M:7+P;W1E('-A=F\@<VQA<'1A_F]DX3\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M
M<R(*;7-G<W1R(")&;W)M;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1G)A>NLB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R
M(")&<F%Z:?@@=&EP87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D9R87KK<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")&
M<F%ZZW,@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G
M:60@(D9O<G5M<R(*;7-G<W1R(")$:7-K=7-I:F]S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B
M4&5R<VEU;G1I;6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B4&5N:RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"FUS9VED(")&<F%M97,B"FUS9W-T<B`B2W)A\'1I;NMS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(E!R86YC^WII:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T
M<F]P;VQI=&%N(@IM<V=S='(@(E!R86YC^WII:F$L($UE=')O<&]L:7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(E!R86YC
M^WII:F]S($=V:6%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L
M>6YE<VEA(@IM<V=S='(@(E!R86YC^WII:F]S(%!O;&EN97II:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*
M;7-G<W1R(")0<F%N8_MZ:6IO<R!P:65T:6[K<R!T97)I=&]R:6IO<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G
M:60@(D9R;VTB"FUS9W-T<B`B3G5O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R
M;VT@=&AE("(*;7-G<W1R(").=6\@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B4&EL;F%S(&%P<F'P>6UA<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS
M9W-T<B`B4&EL;F%T:7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L
M;"!.86UE(@IM<V=S='(@(E!I;&YA<R!V87)D87,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")'86)O;B(*;7-G<W1R(")'86)O;F%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED
M(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QE<FEJ
M82!I\"!K=7)I;W,@:?`@:W5R:6]S(&)U<R!R;V1O;6%S('!A=F5I:W-LZVQI
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L97)I
M:F$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I
M:F$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
M1V5N97)U;W1I("5S(&YU<W1A='EM=7,B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`B4W5G96YE<G5O=&%S(&MO9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1V5O<F=I82(*;7-G<W1R(")'<G5Z:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1V5R;6%N>2(*;7-G<W1R(")6;VMI971I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':&%N82(*;7-G<W1R(")'86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB
M<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<F%S(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS
M9W-T<B`B5F%R9&%S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*
M;7-G:60@(D=O(@IM<V=S='(@(E)O9'ET:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=A9&5L:7,B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`HC
M+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE('!A
M:67P:V$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")'
M;V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92!P86EE\&MA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B
M1W)A>7-C86QE(@IM<V=S='(@(DYE<W!A;'9O=&%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=R965C92(*;7-G<W1R(")'<F%I:VEJ82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS
M9W-T<B`B1W)A:6MI\&MA("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F5N;&%N9&EJ82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")'<G5P:?@@861M:6YI<W1R879I;6%S(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>2(*;7-G<W1R(")'<G5PZW,@=F%R9&%S('1U<FD@8OMT:2!N971U\.AI87,B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B075T:%]L9&%P.B!S=6MU<G1I('9A<G1O=&]JX"`E<R!N97!A
M=GEK;RX@4V5R=F5R:6\@<')A;F7P:6UA<SH@(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P
M.B!A=&YA=6II;G1I('9A<G1O=&]JX"`E<R!N97!A=GEK;R(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R=&]T;VK@("5S(&YE<&%V
M>6MO(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5PZW,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=V861E;'5PZR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86UA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=F%T96UA;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R
M;G-E>2(*;7-G<W1R(")'97)N<VES(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM
M<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4W9EZ&GX('1E:7/K
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R(")3=F7H:?@@:VYY9V$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'=6EN96$B"FUS9W-T<B`B1W9I;NMJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")":7-S874M1W9I;NMJ82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=A:F%N82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*
M;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S
M='(@(DA434Q!<F5A(&YE9V%L:2!I\'1R:6YT:2!P87-K=71I;NMS(&-E;.MS
M(&5I;'5TZVIE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS
M9W-T<B`B2%1-3$%R96$@;F5G86QI(&GP<FEN=&D@<&%S:W5T:6YI;R!S='5L
M<&5L:6\@;&5N=&5LZVIE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB
M"FUS9W-T<B`B2%1-3$%R96$@;F5G86QI(&GP=')I;G1I('!A<VMU=&ENZW,@
M96EL=73K<R!L96YT96SK:F4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H
M='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")296EK86QI;F=A($A45%`@875T96YT:69I:V%C:6IA
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&ES
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")(87-H+4%L9V]R:71M87,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I
M9"`B2&%Z92(*;7-G<W1R(")-:6=L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B06YT<F'P=.LB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(
M96%D97)S(@IM<V=S='(@(D%N=')A\'3K(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B
M2&5R9&\@<V%L82!I<B!-86MD;VYA;&1O('-A;&]S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@
M(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B5"UA=61R82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB
M"FUS9W-T<B`B2&5B<F%J^"`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@
M(DAE:6=H="(*;7-G<W1R(")!=6OP=&ES(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L
M<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L
M871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(E!A
M9V%L8F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")2961A
M:W1O<FEA=7,@;F%U9&]J:6UO<VD@<&%G86QB82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")086=A
M;&)I;FEN:V%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9F5R82(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M(@IM<V=S='(@(M!T86D@Z&EA('ER82!F86EL;R!P<F%D_FEA.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(
M:6=H(@IM<V=S='(@(E-V87)B=2(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM
M<V=I9"`B2&]?;64B"FUS9W-T<B`B7U!O<G1A;&%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T
M<B`BT'9E;G1A<VES(%-O<W1A<R`H5F%T:6MA;F\@=F%L<W1I:F$I(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED(")(;VUE(@IM
M<V=S='(@(E!O<G1A;&%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
M3F%M^"!A9')E<V%S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L
M(&9U>GIY"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G
M87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(DYA;?@@=&5L969O;F%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD
M^W)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@
M(DAO;FMO;F=A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM
M<V=I9"`B2&]R9&4B"FUS9W-T<B`B4&]R=&%L87,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N971E:7-I;F=I("5S
M(%A-3"!D=6]M96YY<R#^:6YU=.MJ92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@;V)J96MT;R`E<R!N96%T:71I;FMA(&IO:VEA
M(/YI;G5TZR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!O8FIE:W1O('1I<&%S("5S(&YE<F%S=&%S(/YI;G5TZVIE("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S(%PB)7-<(B!SZVMM
M:6YA:2!I\'1R:6YT82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@:6YT96=R86-I:F]S('9A<FEK;&EU:W5I(')E:6MA
M;&EN9V%S("=D;VUX;6PG(%!(4"!M;V1U;&ES(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U:W5R=&D@
M;F%U:F\@6$U,(&UE9/YI;R!O8FIE:W1U:2`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!N97!A=GEK;R!I\'1R:6YT:2`E<R!<(B5S7"(Z
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!N97!A=GEK;R!G875T:2!-24U%($E$(&1A;&EA:2`E<R!T
M:7!O(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P
M879Y:V\@<W5S:6YC:')O;FEZ=6]T:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC:')O
M;FEZ=6]T:2!E;&5M96YT^#H@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE
M_FEN;VUA<R!E;&5M96YT87,@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2
M=6QE(@IM<V=S='(@(DAO<FEZ;VYT86QI(&QI;FEJ82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I>F]N=&%L=7,@=&%R<&%S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM
M<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A;&EA:3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E
M<&]R="$I(@IM<V=S='(@(DMA:7`@Z&EA('!A=&5K;W1E/R`H4')A;F7P:VET
M92$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2VEE:R!S='5L<&5L:?@@;F]R:71E
M('-U:G5N9W1I/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M"FUS9W-T<B`B2VEE:R!L875K^"`H<W1U;'!E;&GX*2!T96X@>7)A/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_(@IM<V=S='(@(DMI96L@96EL=>AI^"!N;W)I=&4@<W5J=6YG=&D_(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B1'+K9VYU
M;6%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I
M9"`B2'5M:61I='DZ("(*;7-G<W1R(")$<NMG;G5M87,Z("(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@
M(DIU;6]R97-K;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS
M9W-T<B`B5F5N9W)I:F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R(").97!A=GEK;R!S=6MU<G1I($E-05`@<&'P=&\@
M9.O^=73K<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!)34%0('!A\'1O(&3K
M_G5TZW,Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B3F5P879Y:V\@;G5S=&%T>71I($E-05`@<&'P
M=&\@9.O^=73K<R!D>63^:6\Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!A9')E
M<V%S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").97!A
M=GEK;R!G875T:2!)4"!A9')E<V\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@861R97-A<R!N971E
M:7-I;F=A;64@0TE$4B!B;&]K92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B25`@=?YR86MI;G1A<RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")?P71E<G!T:2!E
M:6QU=.8@=FER\'5J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*
M;7-G<W1R("))<VQA;F1I:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E1I:R!P:6MT;V=R86UO
M<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B5S(&YU<W1A
M='EM86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))
M8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B4&EK=&]G<F%M;W,@<W4@=&5K<W1U
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I
M='DG<R!N86UE.B(*;7-G<W1R(")!<')A\&\@<&%V861I;FEM87,Z(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF
M;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B2F5I
M(&YE9V%L:71E('!E<G-K86ET>71I(/!I;R!L86GP:V\L("5S+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'
M('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N(@IM<V=S='(@(B(*(DIE:6=U(&UA=&]T92#P:>`@_FEN=73F('9I
M971O:B!P879E:6MS;.ML:6\L(&MU<N$@;F]R:71E(.%K96QT:2P@=&%I($K[
M<_@@(@HB;F%R\'EK;.L@;F5G86QI(&IO(&%T=F%I>F1U;W1I+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B4&%V96EK<VSK
M;&EO('!E<OYI^W)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@
M(E!A=F5I:W-LZVQI;R!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%52
M3#HB"FUS9W-T<B`B4&%V96EK<VSK;&EO(%523#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")0879E:6MS;.ML:7,@
M:?`@9V%L97)I:F]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDZ(@IM<V=S='(@(E!A=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@
M=7!L;V%D(@IM<V=S='(@(E!A=F5I:W-LZVQI;R#A:^ML:6UA<R(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B
M5F%I>F1A:2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(L%K
MZVQI;6%S+"`E9"#^:6YG<VYI<R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD
M.B`E<R(*;7-G<W1R("),875K87,@X6ME;'1A<SH@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z
M(@IM<V=S='(@(L%K96QT:2!L875K86DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R("+!7W1E<G!T:2!E:6QU=.8@87!AZ&EO
M:F4B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T
M<B`B3F5T96ES:6YG87,@=F5I:W-M;R!K;V1A<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5T
M96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B
M"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE:71E:7-I;F=A
M<R!V87)T;W1O:F\@=F%R9&%S(&%R8F$@86QT97)N871Y=G5S(&5L+B!P8?!T
M;R!A9')E<V%S+B!"86YD>6MI=&4@(@HB9&%R(&MA<G3@(&%R8F$@<W5S:7-I
M96MI=&4@<W4@<V%V;R!A9&UI;FES=')A=&]R:75M:2!J96EG=2!R96EK86QI
M;F=A("(*(G1O;&5S;NL@<&%G86QB82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E
M;G0B"FUS9W-T<B`B4&%D:61I;G1I(&%T:71R875K:6W@(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED("));F1I82(*;7-G<W1R("));F1I:F$B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("))
M;F1I=FED=6%L^W,@=F%R=&]T;VIA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N97II:F$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(DEN9F]R;6%C:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I
M:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"B,L(&9U
M>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*
M;7-G<W1R(").=7-T871Y;?@@;NMR82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R
M="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(L%T<F%U:W1I('-T=6QP96SA(%]D
M9?!I;NMJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S
M='(@(L%T97)P=&D@<&%V96EK<VSK;.$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B
M"FUS9W-T<B`BP71E<G!T:2!L96YT96SF(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(L%T97)P=&D@;G5O<F]DX"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B
M26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(L%T97)P=&D@<W1U;'!E
M;.$@7VMA:7+K:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L%T97)P=&D@;F%U
M:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&1E\&ENZVIE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`BP71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S
M='5L<&5L:6\@:V%I<NMJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BP71E<G!T:2!N
M875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@87!AZ&EO:F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("+!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K
M<R!V:7+P=6IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("+!=&5R<'1I('!A<F%G
M<F%FX"!E;&5M96YT;R!A<&'H:6]J92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(L%T97)P=&D@<&%R86=R86?@(&5L96UE;G1O('9I<O!U:F4B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R("+!=&5R<'1I(&%L=&5R;F%T>7;X(/!A8FQO;N`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`BP7)A\'EK:71E(&5L+B!P8?!T;R!A
M9')E<^`L(.$@:W5RX2!N;W)I=&4@9V%U=&D@;F%U:N`@<VQA<'1A_F]DX3HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("+!=&5R
M<'1I(&-E;.8@<&\@=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O
M<F4B"FUS9W-T<B`BP71E<G!T:2!C96SF('!R:67P('1A:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`BP71E<G!T:2!S='5L
M<&5LX2!D9?!I;NMJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F
M;W)E(@IM<V=S='(@(L%T97)P=&D@<W1U;'!E;.$@:V%I<NMJ92(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("))
M;G-E<G0@;65S<V%G97,B"FUS9W-T<B`BP71E<G!T:2!L86GP:W5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(L%T
M97)P=&D@<&%R86=R86;@('!O('1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("+!=&5R<'1I('!A<F%G<F%FX"!P
M<FEE\"!T86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S
M='(@(L%T97)P=&D@96EL=73F('!O('1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T
M(')O=R!B969O<F4B"FUS9W-T<B`BP71E<G!T:2!E:6QU=.8@<')I9?`@=&%I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.B(*;7-G<W1R("+!<F'P>6MI=&4@<F5I:VEA;>`@871S86MY;>`@X2!K;&%U
M<VEMX"!V:7+P=6IE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS
M9W-T<B`BP71E<G!T:2]R961A9W5O=&D@<&%V96EK<VSK;.$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`BP71E<G!T:2]2961A9W5O=&D@
M;G5O<F]DX"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")$:7-T<FEB
M=6-I:F]S('/@<F'P=6D@;G5S:?AS=&D@;F5U_G1E;FMA(&MR961I=&\N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(DYE=?YT
M96YK82!K<F5D:71O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B4VMA:>AI=7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B
M"FUS9W-T<B`B4VMA:>AI^"!SX')A\&%S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(").971E:7-I;F=A
M<R!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!:25`@9&%T82(*;7-G<W1R(").971E:7-I;F=I('5N:6MO9&\@9'5O;65N
M>7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV
M86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B3F5T96ES:6YG87,@;6]D=6QI
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DYE
M=&5I<VEN9V%S($E$+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`BP79E
M<W1I(&YE=&5I<VEN9VD@9'5O;65N>7,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DYE=&5I<VEN9V%S(&%D
M<F5S87,N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R
M,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(").971E:7-I
M;F=A<R!F86EL;R!F;W)M871A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS92!K
M97DN(@IM<V=S='(@(DYE=&5I<VEN9V%S(&UO9'5L:7,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F5T96ES:6YG87,@
M;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S
M='(@(DYE=&5I<VEN9V%S(&US9U]T>7!E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B3F5T96ES:6YG87,@87)B
M82!NZW)A(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+B(*;7-G<W1R(")087)A;65T<F%I(&YE=&5I<VEN9VD@
M87)B82!J^"!NZW)A+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR
M-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M3F5T96ES:6YG;W,@<&%V96QD:6UO<R!T96ESZW,N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!P87)T;F5R(&ED+B(*;7-G<W1R(").971E:7-I;F=O<R!P879E;&1I;6]S
M('1E:7/K<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B3F5T96ES:6YG87,@<')O=&]K;VQA<RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(DYE=&5I<VEN9V%S('!R;W1O:V]L87,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S
M7"(B"FUS9W-T<B`B3F5T96ES:6YG87,@9V%VZVIA<SH@)R5S)R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM
M<V=S='(@(DYE=&5I<VEN9V%S(&]B:F5K=&%S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A
M;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(").971E:7-I;F=A<R!S:75N
M=.MJ;R!A9')E<V%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A
M=&$N(@IM<V=S='(@(DYE=&5I<VEN9VD@=6YI:V]D;R!D=6]M96YY<RXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O
M<GDB"FUS9W-T<B`B26YV96YT;W)I=7,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U>GIY"FUS9VED("));G9E
M<G0@<V5L96-T:6]N(@IM<V=S='(@(E!E<FME;'1I('!A<VER:6YK:6W@(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DES;&%M:?!K82!)<F%N;R!297-P=6)L:6MA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER86MA<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R(")!:7)I:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB
M"FUS9W-T<B`B365N;R!S86QA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM
M<V=S='(@(DEZ;VQI=6]T;W,@5"UA=61R;W,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DES<F%E;"(*;7-G<W1R("))>G)A96QI<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T
M<B`B2?!D87;K:F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B2W5R<WEV87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DET86QI:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EK
M82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U
M"FUS9VED(")*86YU87)Y(@IM<V=S='(@(E-A=7-I<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P;VYI:F$B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0
M*2(*;7-G<W1R(")*87!O;FGP:V$@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T
M(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P
M86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED
M(")*97)S97DB"FUS9W-T<B`B1/YE<G-I<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A;FEJ82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S
M='(@(DQI97!A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B0FER_F5L:7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X
M"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(E!I;&YA:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED
M(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("),>6=I=6]T:2!C96YT<F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(DQY9W5O=&D@<&EL
M;F%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("),>6=I
M=6]T:2!K86ERZVIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`B3'EG:75O=&D@9&7P:6[K:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86MS=&%N87,B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R("))\'-A=6=O=&D@;W)I9VEN86S@/R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N:6IA(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE($ME<F)E<F]S('-E<G9E<FEO+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE
M=V)I97,B"FUS9W-T<B`B0G)A;F1U;VQI;R!N875J;VMA:2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T
M:6]N(@IM<V=S='(@(E)A:W1O(&O[<FEM87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*
M;7-G<W1R(")286MT;R!A='-P875D87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B
M4F%K=&\@:6QG:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E)A:W1O('1I<&%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@
M(DME>2!5<V%G92(*;7-G<W1R(")286MT;R!P86YA=61O:FEM87,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B4F%K=&%S(&IA=2!Y<F$@=FEE\/AJ^"!R86MT^"!S97)V97)Y:F4N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S
M='(@(E9A:6MA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS
M9W-T<B`B2VER:6)A=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")$96UO
M:W)A=&ENZR!+;W+K:F]S($QI875D:65S(%)E<W!U8FQI:V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+;W+K
M:F]S(%)E<W!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(DMO<NMJ:65T:?!K82`H
M155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@
M(DMU=F5I=&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM
M<V=S='(@(DMI<F=I>FEJ82(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?2?!DZW-T>6UA<R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E
M(@IM<V=S='(@(DMA;&)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S;R!$96UO
M:W)A=&ENZR!,:6%U9&EE<R!297-P=6)L:6MA(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(D%N=')A('!U
M<^LB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G
M:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(E!A:V5I<W1I('-L
M87!T8?YO9.$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B4&%S
M:W5T:6YI<R!K971V:7)T:7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U
M,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")!=&YA=6II;G1A.B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")087-K=71I;FES('!R
M:7-I:G5N9VEM87,Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`B4&%S:W5T:6YI<R!P<FES:6IU;F=I;6%S.B`E<R!I\"!A
M9')E<V\@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G
M:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E!R:7-I:G5N9^MT92!P
M:7)MX"!K87)TX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S
M='(@(DQA='9I:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G
M:60@(DQA=R(*;7-G<W1R(")496ESZR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM
M<V=S='(@(DGP9.MS='EM87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R(@IM<V=S='(@(DIE:6=U(&YE;F]R:71E(&YE;F%U9&]T:2!K<F'P
M=/@L('!A;&EK:71E('1U\.AIX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B
M86YO;B(*;7-G<W1R("),:6)A;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S
M='(@(DMA:7+K:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y
M"FUS9VED("),969T(&AE861E<B(*;7-G<W1R(")+86ER:6]J:2!A;G1R8?!T
MZR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(DMA:7)I;W-I;W,@<F5I:_!MZW,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1A<R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5V96PB"FUS9W-T<B`B365I;.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB:6IO<R!!
M<F%B^"!%;7ER871A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS
M=&5I;B(*;7-G<W1R("),:6-H=&5N\'1E:6YA<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(E-M=6QK=7,@;&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB
M"FUS9W-T<B`B3F5D:61E;&ES(&QI971U<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A
M<FQY(@IM<V=S='(@(DYE9&ED96QI<R!L:65T=7,@<GET92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H
M="!286EN($QA=&4B"FUS9W-T<B`B3F5D:61E;&ES(&QI971U<R!V86MA<F4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM
M<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B3F5D:61E;.L@;&G[
M=&ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(DYE
M9&ED96QI<R!L:65T=7,@<W4@<&5R:_MN:6IA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B3F5D:61E;&ES('-N:65G87,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3
M:&]W97(B"FUS9W-T<B`B3F5D:61E;.L@\&QA<&1R:6)A(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),
M:6UE<FEK87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"FUS
M9VED("),:6YK(@IM<V=S='(@(DYU;W)O9&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R(").=6]R;V1A(.$Z(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@
M861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*
M;7-G<W1R(")0861A<GET:2!E;"X@<&'P=&\@861R97/@(&YU;W)O9&$@X2!L
M86GP:V\@<F'P>6UO('!U<VQA<.$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G
M<W1R(").=6]R;V1O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X(&QA:6WK<R#^:6YU
M=.MS(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G
M<W1R(")2;V1Y=&D@+2!V87)T;W1O:F%S(&=A;&D@;6%T>71I(&MA=&%L;V=O
M('1U<FENX2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@1&%T86)A<V5S(@IM<V=S='(@(E)O9'ET:2!D=6]M96[X(&)A>FGX('/@
M<F'PX"(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),
M:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(E)O9'ET:2!P86=A;&)O<R!T96UA
M<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B
M;&5S(@IM<V=S='(@(E)O9'ET:2!L96YT96QI^"!SX')A\.`B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!
M<F-H:79E(@IM<V=S='(@(DMO;F9E<F5N8VEJ;W,@87)C:'EV87,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES
M="U(96QP(@IM<V=S='(@(DMO;F9E<F5N8VEJ;W,@<&%G86QB82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T
M+4ED(@IM<V=S='(@(DMO;F9E<F5N8VEJ;W,@240B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*
M;7-G<W1R(")+;VYF97)E;F-I:F]S('-A=FEN:6YK87,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T
M(@IM<V=S='(@(E)A\'ET:2#A(&MO;F9E<F5N8VEJX"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C
M<FEB92(*;7-G<W1R(")0<FES:6IU;F=T:2!P<FEE(&MO;F9E<F5N8VEJ;W,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I
M9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R(")!='-I:G5N9W1I(&YU;R!K
M;VYF97)E;F-I:F]S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B5F%R=&]T;VKX('/@<F'P87,@=?YD<F%U<W1A<RXB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")6
M87)T;W1O:O@@<^!R8?!A<R!U_F1R875S=&%S+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B5F%R=&]T;VKX('/@<F'P87,@=?YD<F%U
M<W1A<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI
M=&5R871U<F4B"FUS9W-T<B`B3&ET97)A=/MR82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI971U=F$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(DMR875N82XN+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R
M(")6:65T:6YI<R!L86EK87,Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQO:V%LZR!I
M<B!L86EK87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(E9I971A(@H*(SH@;&]G:6XN<&AP.C$W
M,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G
M(&EN(@IM<V=S='(@(E!R:7-I:G5N9W1I(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S
M97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B071S:6IU;F=T:2(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B
M3&]G:6XB"FUS9W-T<B`B4')I<VEJ=6YG=&DB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")0<FES
M:6IU;F=I;6\@9&%R8F%I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"B)0<FES:6IU;F=T:2!N97!A=GEK;RX@3F5T96ES:6YG87,@2OMS^"!N
M=7)O9'ET87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<B`B"B)S;&%P=&'^;V1I
M<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO
M9VEN(&9A:6QE9"XB"FUS9W-T<B`B4')I<VEJ=6YG=&D@;F5P879Y:V\N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T
M97AT(@IM<V=S='(@(DEL9V%S('1E:W-T87,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B365I;.LB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B
M3&]W(@IM<V=S='(@(DYE<W9A<F)U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@
M9W)E96L@;&5T=&5R<R(*;7-G<W1R(")-8?YO<VEO<R!G<F%I:VGP:V]S(')A
M:63K<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS
M9W-T<B`B36'^;W-I;W,@;&]T>6YI\&MO<R!R86EDZW,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DUA_FEE:FD@<F]M
MZVYI\&MI('-K86GH:6%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O
M=7)G(@IM<V=S='(@(DQI=6MS96UB=7)G87,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G
M:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B4')I:V%B:6YT86UE($U3+51.148@9F%I;&4@;NMR82!D=6]MZV[X
M+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA:V%O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%K961O;FEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S:V%R
M87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(DUA9VEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")08?!T87,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S
M='(@(E!A\'1O('9A;&1Y;6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K
M+BXN(@IM<V=S='(@(E-U:W5R=&D@7VYU;W)O9.`N+BXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=FES(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA:7II:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1Y=F%I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&ES(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RXB"FUS9W-T<B`B(@HB2V%T96=O<FEJ^"!SX')A\&\L(&MU<FEO;7,@
M<')I<VMI<FEA;6D@;V)J96MT86DL(&ER('-U(&IO;6ES('-U<VEJ=7-I^"`B
M"B)S<&%L=O@@:V5I=&EM87,N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M(")-87`R-"#^96WK;&%P:7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S
M='(@(DUA<%%U97-T(/YE;>ML87!I<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B2V]V87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-
M87)G:6XB"FUS9W-T<B`B4&%R8?!TZR(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5
M;G-E96X@9FQA9W,B"FUS9W-T<B`B4&'^>6WK=&D@:V%I<"!S:V%I='ET=7,O
M;F5S:V%I='ET=7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N
M($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B4&'^>6WK=&D@:VET86ES
M(&%T<FEB=71A:7,@*'!V>BX@<W9A<F)U+V%T<V%K>71A*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87+P86QO
M('-A;&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S
M='(@(DUA<G1I;FEK82(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B4W5J=6YG=&D@
M;&%U:V%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S
M='(@(DUA=7)I=&%N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I
M=7,B"FUS9W-T<B`B36%U<FEC:6IU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W
M960@8W)E9&ET+B(*;7-G<W1R(")-86MS:6UA;'5S(&MR961I=&%S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@
M(DUA:W-I;6%L=7,@_FEN=>AI^"!D86QI^"!K:65K:7,@:?!E:6MV;W1A<RXB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DUA:W,N('1E;7`N('!A<VLN(#(T
M('9A;#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DUA:W,N('1E;7`N('!A
M<VLN(#8@=F%L.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED
M(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")-86MS:6UA;'5S(&EL9VES(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G
M:60@(DUA>2(*;7-G<W1R(")'96=U_NLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")-87EO='1E(@IM<V=S='(@(DUO:F]TZR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:6-I;F$B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(DYA<FEA:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N:74@
M<F7^:6UA<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")3
M=6IU;F=T:2!C96QE<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@
M(MYI;G5TZR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V
M97)I9FEE9"XB"FUS9W-T<B`B(@HB3&%I\&MA<R!P879I<G1I;G1A<RP@=&'H
M:6%U(&YE<&%T=FER=&EN=&%S('!A<VER8?!I=7-I;R!A<VUE;G,@<V5R=&EF
M:6MA=&%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R
M("+>:6YU=.L@;F5I\'-I^'-T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-
M97-S86=E('1Y<&4B"FUS9W-T<B`BWFEN=73K<R!T:7!A<R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R
M(")/<F\@<V%L>6=O<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G
M:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D]R;R!S
MX&QY9_@@8FQO:V\@;NMR82XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q
M,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B3W)O('/@;'EG^"!B;&]K;R!NZW)A+B!!9&UI;FES=')A=&]R:75I
M(&GP<VGX<W1A<R!D971A;'5S(&%P<F'P>6UA<RXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C
M;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DUE=&]D87,B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]2
M4$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-971O
M9&%S("<E<R<@;F5A<')A\'ET87,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R
M97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP
M.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B36%T86DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-96MS:6MA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS
M9W-T<B`B36EK<F]N97II:F]S($9E9&5R86-I;NMS(%9A;'-T:6IO<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(E9I9'5R>6IE(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@
M5'EP92(*;7-G<W1R(")-24U%('1I<&%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R(")-:6XN('1E;7`N('!A<VLN(#(T('9A;#H@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(DUI;BX@=&5M<"X@<&%S:RX@-B!H;W5R<SH@(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`IM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(D%T<W!I;F1Y<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R
M(")+:71O<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+B(*;7-G<W1R(").97)A<W1A<R!014%2($A45%!?4F5Q=65S
M="!P86ME=&%S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G
M:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI
M8V%T:6]N+B(*;7-G<W1R("(B"B).=7-T871Y;?@@;NMR82X@2F5I9W4@;F]R
M:71E(&YA=61O=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K;VYF:6?[<G5O
M=&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@
M(D[K<F$@_FEN=73K<R!)1"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B3F5R87-T87,@<F5I
M:V%L:6YG87,@4$5!4B!-86EL('!A:V5T87,N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S
M:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D[K<F$@<V5S:6IO<R!)1"XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS
M9VED(")-;R(*;7-G<W1R(")0:7)M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B36]B:6QU
M<R!P8?!T87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B5FED=71I;FES(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D
M($1A=&4B"FUS9W-T<B`B4F5D86=A=FEM;R!D871A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED
M(")-;V1I9GD@55),(@IM<V=S='(@(DME:7-T:2!54DPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*
M;7-G<W1R(")-;V1U;&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A
M+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9O<R!297-P=6)L:6MA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86MA<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L
M:6IA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B
M36]N=&@@86YD('EE87(B"FUS9W-T<B`B3>MN97-I86D@:7(@;65T86DB"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS
M9VED(")-;VYT:&QY(@IM<V=S='(@(DMA<R!MZVYE<^$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N<V5R871A<R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM
M<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B3>MN=6QI;R!F87KK<R(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F
M:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S
M='(@(DUA<F]K87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(D1A=6=I
M875S:6$@9VEE9')A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B1&%U
M9VEA=7-I82!A<'-I;F%U:^8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@
M(D1A=6=I875S:6$@<V%U;.MT82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(E!E
M<FME;'1I(/YE;6EA=2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(E!E<FME;'1I
M(&MA:7)I874B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B4&5R:V5L=&D@9&7P
M:6YI874B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B4&5R:V5L=&D@875K\.AI874B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T
M"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B4&5R:^ML:6UA<R#^96UY;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM
M<V=I9"`B36]V92!U<"(*;7-G<W1R(")097)KZVQI;6%S(&%U:_!T>6XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB
M:6MA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@
M(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R(")+96QE=&\@
M;'EG:?@@:?!S:7-K;&5I9/YI86YT:7,@<^!R8?!A<R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT
M:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@
M(DME;&5T87,@<&%S:7)I;FMI;?@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUA;F\@<^!S
M:V%I=&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*
M;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M86-I:F$@87!I92!*=7,B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36%N;R!P;W)T86QA<R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O
M<G1A;"!,87EO=70B"FUS9W-T<B`B36%N;R!P;W)T86QO(&GP9.MS='EM87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B36%I;FUA
M<F%S(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").12P@
M3D53551)3DM5(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G
M:60@(DYA;64B"FUS9W-T<B`B5F%R9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").86UI8FEA(@IM<V=S='(@(DYA;6EB:6IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").875R=2(*;7-G<W1R(").875R87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYY9&5R;&%N9&%I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(DYY
M9&5R;&%N9/@@06YT:6QA:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M(").971S8W!A<&4@8F%Z:6YI<R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-P864@<V5R:69I:V%T;R!A=/!A=6MI
M;6\@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T
M<V-P864@<V5R=&EF:6MA=&\@=&5I<VGX(%523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE
M=V%L(%523"(*;7-G<W1R(").971S8V%P92!A=&YA=6II;F]M;R!54DPB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B
M3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@873P
M875K:6UO(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T
M<B`B3F5T<V-A<&4@4U-,('-E<G9E<FEO('9A<F1A<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E('-E<G1I9FEK
M871O(&%P<F'P>6UA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM
M<V=S='(@(DYE='-C87!E('-E<G1I9FEK871O('1I<&%S(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R
M(")4:6YK;&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3FEE:V%D82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").
M875J;VII($MA;&5D;VYI:F$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM
M<V=S='(@(DYA=6IA(&MA=&5G;W)I:F$B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R(")28?!Y
M=&D@;&%I\&O@("@E<RDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G
M:60@(DYE=R!-;V]N(@IM<V=S='(@(DYA=6IA<R!MZVYU;&ES(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S
M97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F%U:F%S('9A<G1O=&]J;R!V
M87)D87,@*&YE8OMT:6YA<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:
M96%L86YD(@IM<V=S='(@(DYA=6IO:FD@6F5L86YD:6IA(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@
M<&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A_F]D:7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE
M=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED
M(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(")3;&%P=&'^
M;V3^:6%I('1U<FD@<W5T87!T:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA
M;FLI(@IM<V=S='(@(DYA=6IA;64@;&%N9V4@*%]B;&%N:RDB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B3F5W<R(*
M;7-G<W1R(").875J:65N;W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(DYA=6II96[X(&=R
M=7#K<R(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS
M9VED(").97AT(@IM<V=S='(@(E-E:V%N=&ES(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S
M='(@(E-E:V%N=&D@9F%ZZR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"FUS
M9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B4V5K86YT>7,@;G5S=&%T>6UA
M:2(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"B,L(&9U>GIY
M"FUS9VED(").97AT/B(*;7-G<W1R(")396MA;G1I<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=V82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97)I<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEJ82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT
M(@IM<V=S='(@(DYA:W1I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*
M;7-G<W1R(").:75JZR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(DYE(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I
M;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@
M9F]R+B(*;7-G<W1R(").977^=&5N:V$@9'5O;65N^"!S:VER='5M^"!P87)O
M9'EM=6DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N(@IM<V=S='(@(DYE;G5R;V1Y=&$@<W1R871E9VEJ
M82!)4T\@<F'P>6UU:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E
M+B(*;7-G<W1R(").ZW)A('-U9.MT:6YI;R#P86)L;VYO+B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T
M:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(DYU<F]D>71O:F4@<&]Z
M:6-I:F]J92!B;&]K;R!NZW)A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F7A=F5DZW1E(&MA
M;&5N9&]R:6%U<R!V87)D;R!-0T%,(&%U=&5N=&EF:6MA8VEJ;VIE+B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(E-K:7)T=6WX(&[K<F$N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E
M9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(M!I;W,@=&5I<^MS(&YE
M9V%L:2!T=7+K=&D@<&]T96ES:?@N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@
M9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RXB"FUS9W-T<B`B3NMR82!I;F9O<FUA8VEJ;W,@87!I92`E<R!K;VYF
M:6?[<F%C:6K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B3NMR82!I;F9O<FUA8VEJ;W,@87!I
M92!&5%`@5D93(&MO;F9I9_MR86-I:N`N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").ZW)A(&EN
M9F]R;6%C:6IO<R!A<&EE(%-13"!61E,@:V]N9FEG^W)A8VEJX"XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+B(*;7-G<W1R(").ZW)A(&EN9F]R;6%C:6IO<R!A<&EE(%-13"U&
M:6QE(%9&4R!K;VYF:6?[<F%C:6K@+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(DMR961I=&%S(&GP96EK=F]T87,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G
M:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").9>%V97-T
M87,@9V%VZVIA<RXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B1F%I;&%S
M(&YE;G5S:?AS=&%S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"B,L
M(&9U>GIY"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B)7,@;F5R
M87-T87,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B3F5N
M=7-T871Y=&$@=FEE=&]VZRXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B3F5N=7-T871Y=&$@=FEE=&]VZRXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B
M3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F7A<F'PZW1E(/YI;G5T
MZW,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").
M9>%R8?#K=&4@=F%R9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I
M960N(@IM<V=S='(@(DYEX7)A\.MT92!N=6UE<FEO+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(DYE<F]D>71I(.'^96ED_FEA;NAI^"!F<F%Z:?@B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3F7A=F5DZW1E('-L87!T8?YO9/YI;R!(5%10(&%U=&5N=&EF:6MA8VEJ
M86DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").9>%V963K=&4@<VQA<'1A_F]D_FEO($E-05`@875T
M96YT:69I:V%C:6IA:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYEX79E9.MT92!S;&%P=&'^
M;V3^:6\@2V5R8F5R;W,@875T96YT:69I:V%C:6IA:2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").9>%V963K=&4@<VQA<'1A_F]D_FEO($QO
M9VEN(&%U=&5N=&EF:6MA8VEJ86DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F7A=F5DZW1E
M('-L87!T8?YO9/YI;R!005-35T0@875T96YT:69I:V%C:6IA:2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DYEX79E9.MT92!S;&%P=&'^;V3^:6\@4TU"(&%U=&5N=&EF:6MA8VEJ86DN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS
M9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B).9>%V97-T87,@:V5L
M:6%S(&EK:2!/<&5N4U-,('!A9W)I;F1I;FGX(&9A:6SX+B!/<&5N4U-,(')E
M:6MA;&EN9V$@9&%R8G5I('-U("(*(E!+0U,@,3(@9'5O;65N:6UI<RXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").
M;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(DYE<&%T=FER=&EN=/@@<F5G
M:7-T<F%C:6KX(&[K<F$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*
M;7-G<W1R(").96YU<F]D>71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS
M9W-T<B`B3F5N875D;W1I('-K:7)T=6OX(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@
M<W!E8VEF:65D+B(*;7-G<W1R(").9>%R8?#K=&4@;G5M97)I;RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R(").ZR!V:65N;VIE('!U<^MJ92(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"B,L(&9U>GIY"FUS
M9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B3NL@=FEE;F]J92!P=7/K:F4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(E-P87)T:6YI;75I(&[K<F$@;&%I:VEN;VIO(&MA=&%L;V=O+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q
M"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS
M9W-T<B`B5F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES(&YE
M;G5S:?AS=&%S+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R
M(")496ES:6YG^"!834P@9'5O;65N^"!NZW)A(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*
M;7-G<W1R(").ZW)A(')E:6OP;6GX(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DMO;F9I9_MR86-I;FEA;64@9F%I;&4@;NMR82!V97)S:6IO<RX@4&5R
M9V5N97)U;VMI=&4@;G5S=&%T>6UU<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")+;VYF:6?[<F%C:6YI86UE(&9A:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E
M;F5R=6]K:71E(&YU<W1A='EM=7,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R(").96YU<F]D
M>71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(").ZW)A
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H
M25-/+3@X-3DM,3`I(@IM<V=S='(@(M!I875RZW,@*$E33RTX.#4Y+3$P*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B
M3F]R9F]L:V\@<V%L;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(M!I875R:6[K(&AE;6ES9F5R82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(M!I875R
M:6[K<R!-87)I:F%N^"!S86QO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R
M=V%Y(@IM<V=S='(@(DYO<G9E9VEJ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M3F4@<&\@=&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(").92!P<FEE\"!T86DB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*;7-G:60@(DYO
M="!A(&1I<F5C=&]R>2(*;7-G<W1R(").92!K871A;&]G87,B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G
M<W1R(").97)E86QI>G5O=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").
M96YU<F]D>71A(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V
M,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV
M-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYE<&%L86EK;VUA
M<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(E7^<F'P
M86DB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@
M(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").ZW)A(&O@
M('!E<OYI^W+K=&DL(&5I:VET92!A=&=A;"XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`B3&%P:W)I=&ES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(DYU;65R:7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R(")3:6UB;VQI^"!S:V%IZ&EU<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")3='5L<&5L:?@@<VMA:>AI=7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B16EL=>AI^"!S:V%I
MZ&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").9>%V97-T
M:2!D:7-T<FEB=6-I:F]S('/@<F'P;R!A=&YA=6II;FEM;R!S:V%IZ&EA:2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*
M;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@
M(D]B:F5K=&%S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*
M;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K=&\@<V%V:6YI
M;FMA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(D'P='5N=&%I;FES(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B4W!A;&ES(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS
M9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("+>:6%U<G5M;R!F:6QT<F%S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F
M:6-E(@IM<V=S='(@(D]F:7-A<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*
M;7-G<W1R(")3;&%P=&'^;V1I<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO
M="!C;W)R96-T+B(*;7-G<W1R(")3;&%P=&'^;V1I<R!N971E:7-I;F=A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N87,B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`B2V%T86QO9_@@9&%L:6II;>!S:2!P86QA:6MO('1I:R!)34%0
M('-E<G9E<FEA:2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E1I:R#A_F5I
M9/YI86[H:6]S(&9R87KK<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("),96ED_FEA
M;6%S('1I:R!V:65N87,@96PN('!A\'1O(&%D<F5S87,N(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R
M("(B"B)%;&5M96YT;R!S879I;FEN:V\@=&5I<V5S(&=A;&D@:V5I<W1I('1I
M:R!J;R!S879I;FEN:V%S(&%R8F$@<VES=&5M;W,@(@HB861M:6YI<W1R871O
M<FEU<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!=&ED87)Y=&D@;F%U:F%M92!L
M86YG92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U
M"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A
M(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*
M;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B071I9&%R>71I(/!IX"!N=6]R;V3@(&YA=6IA;64@;&%N9V4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`B3W!R86-I;NMS('-I<W1E;6]S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R
M(").=7-T871Y;6%I(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P
M=&EO;G,@9F]R("5S(@IM<V=S='(@(B5S(&YU<W1A='EM86DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/
M<F1E<F5D($QI<W0B"FUS9W-T<B`B4W5R^_!I=6]T87,@<^!R8?!A<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")/
M<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI>F%C:6IA(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A
M=&EO;F%L(%5N:70B"FUS9W-T<B`B4&%D86QI;GES(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R
M(")3:7-T96UI;FEM87,B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM
M<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B
M3W)I9VEN86QU<R!A<&QI:V%C:6IO<R#P86)L;VYA<R(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L
M('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B3W)I9VEN86SX<R#P86)L;VYA
M:2`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M2VET82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DMI=&$@:6YF;W)M86-I:F$B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!0
M97)M:7-S:6]N<R(*;7-G<W1R(")3879I;FEN:6MO('1E:7/K<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D[K<F$@4$%-
M(&%U=&5N=&EF:6MA8VEJ;W,@;65C:&%N:7IM;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z
M.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U
M<F4B"FUS9W-T<B`B4$=0('-K86ET;65N:6YI<R!P87)A\&%S(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!U_FMO9'5O=&$@:6YF;W)M86-I
M:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS
M9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@=FEE\&%S:7,@<F%K
M=&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@
M<&%S:7)A\'ET:2]U_FMO9'5O=&D@9'5O;65N>7,B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!K;V1A
M<R(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL
M(@IM<V=S='(@(E!(4"!#3$DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R
M(")032!L96YG=F%S(&QI971U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@
M(E!-(&QI^W1I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")032!3;F]W(@IM<V=S='(@(E!-
M(&QI^W1I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0P"B,L(&9U>GIY"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B4/MG82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(E!-(%0M875D<F$B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE
M;&PB"FUS9W-T<B`B4%](4"!#3$DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM
M<V=S='(@(E1A<G!A:2!C96SK<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A
M:VES=&%N(@IM<V=S='(@(E!A:VES=&%N87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
M5?YI;71O:FD@4&%L97-T:6YO<R!T97)I=&]R:6IA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YA=6IO
M:FD@1W9I;NMJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(E!A<F%G=F%J=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M(")$86QI;F%I(&1E8F5S=6]T82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@
M(E-L87!T8?YO9&ES(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,S(R"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4VQA<'1A
M_F]D:7,@;F5T96ES:6YG87,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")2041)55,@875T96YT:69I
M:V%C:6IA:2!R96EK:6$@<VQA<'1A_F]D_FEO+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N(@IM<V=S='(@(E-L87!T8?YO9&ES('-U('!A='9I<G1I;FEM=2(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S
M<W=O<F0Z(@IM<V=S='(@(E-L87!T8?YO9&ES.B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@
M(E-L87!T8?YO9&ES.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB
M"FUS9W-T<B`B4VQA<'1A_F]D_FEA:2!T=7)I('-U=&%P=&DN(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@
M(L%K96QT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@
M(L%K96QT:2!I\"!L86EK:6YO<VEO<R!S875G>6ML;W,@*&-L:7!B;V%R9"DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"FUS9VED(")0871H(@IM<V=S='(@(DME;&EA<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM
M<V=S='(@(DYE<&%T=FER=&EN=&]S(')E9VES=')A8VEJ;W,Z(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B
MWFUO;NMS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4')O8V5N=&%I(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*
M;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R
M(")!=&QI:W1I('!R;V9I;&%K=&EN:75S('9E:6MS;75S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")!<B!A=&QI:W1I('!R
M;V9I;&%K=&EN:75S('9E:6MS;75S('!R:7-I:G5N9VEM;R!M971U/R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(E1E:7/K<R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I
M;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")496ESZW,@)R5S)R!N
M96GP=')I;G1O<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B
M5&5I<^MS(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G
M:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E]496ESZW,B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")496ES:?@@861M:6YI<W1R879I;6%S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*
M;7-G<W1R(")!<VUE;FENZR!I;F9O<FUA8VEJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(D=Y=OMN86DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YA
M:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VYA<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R
M(").=6]T<F%U:V]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB
M"FUS9W-T<B`B4&ET:W)A;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0
M:6MS96QI86DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@
M(E!L871I='5D97,B"FUS9W-T<B`B0F%N86QY8NMS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(DGP<VER:6YK
M:71E(&MU<FG@(&YO<G,@8V5LYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*
M;7-G<W1R(")0871V:7)T:6YK:71E+"!A<B!T:6MR86D@;F]R:71E(&GP=')I
M;G1I(/#A(&5L96UE;G3@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G
M<W1R(")0871V:7)T:6YK:71E+"!A<B!T:6MR86D@;F]R:71E(&GP=')I;G1I
M(/!I;R!E;&5M96YT;R!N=6]R;V3@+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N(@IM<V=S='(@(L%V97-K:71E(&WK;F5SX2!I<B!M971U<RXB"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R
M>3HB"FUS9W-T<B`BP79E<VMI=&4@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D
M:6YI;>`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
MP79E<VMI=&4@=&5I<VEN9^`@25`@861R97/@+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M(@IM<V=S='(@(L%V97-K:71E('1E:7-I;F?@(&1A=.`L('!A=&EK<FEN:VET
M92!D:65N^"!S:V%IZ&GX(&WK;F5S>6IE+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N(@IM<V=S='(@(L%V97-K:71E('1E:7-I;F?@(&QA:6O@+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B07!R
M8?!Y:VET92!P<F]B;&5MX"XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(DYU<F]D>6MI=&4@<V%V;R!V87)T;W1O:F\@=F%R9.`@8F5I('-L87!T
M8?YO9.$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*(RP@9G5Z
M>GD*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*(E!R8?!O;64@<&5R<VMA:71Y=&D@\.$@=&5K
M<W3@+B!*^W,@4%))5D%,3U1%('-U=&EK=&D@<W4@<^!L>6=O;6ES+"!J96D@
M(@HB;F]R:71E(&YA=61O=&ES('-I<W1E;6$N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`BP79E<VMI
M=&4@;F%U:N`@:V%T96=O<FEJ;W,@<&%V861I;FEMX#HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("),96YK:6IA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VQI=&EK86DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS
M9VED(")0;VQL<R(*;7-G<W1R(")"86QS879I;6%I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QI:F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B4&%V96EK<VSK;&EO('!O>FEC:6IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B3&5N=&5LZW,@<&]Z:6-I:F$B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I
M9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M(@IM<V=S='(@(DGP<V%U9V]T:2#P:6%M92!K871A;&]G92`H;F5G86QI;VIA
M($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B2W)I='5L:6%I
M('!A<VLN("5S('9A;&%N9.`H87,I.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA
M;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P
M+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!N97)A<W1A
M<R!R96EK86QI;F=A<R!,1$%0(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(E!R969S7W-E<W-I;VXZ(&YE<F%S=&%S(')E:6MA;&EN9V%S('-E<VEJ
M^"!M;V1U;&ES+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED
M(")0<F5S<W5R92(*;7-G<W1R(")3;.MG:7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS
M9W-T<B`B4VSK9VES(&K[<F]S(&QY9WEJ93H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R
M(")3;.MG:7,Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@
M(E!E<OYI^W)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B4&5R_FG[<NMT:2!P879E:6MS
M;.MLX2!N875J86UE(&QA;F=E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B06YK<W1E<VYI(&YU
M<W1A='EM86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")!='-P
M875S9&EN=&D@9&]K=6UE;G3@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")3;&%P
M=&%S:7,@<F%K=&%S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M82(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C
M<FEP=&EO;B(*;7-G<W1R(")0<F]B;&5M;W,@87!R8?!Y;6%S(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS
M9W-T<B`B4')O:F5K=&%I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S
M='(@(E!R8?!Y;6%S('1E:W-T=6DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B5FEE
M\&%S:7,@<F%K=&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@
M(E9I9?!O:F\@<F%K=&\@86QG;W)I=&UA<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@
M2V5Y($EN9F\B"FUS9W-T<B`B5FEE\&%S:7,@<F%K=&%S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")6:67P;VIO+W-L87!T;VIO(')A:W3X('!O<F$@;F5S=6=E;F5R=6]T
M82XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R
M(")0=65R=&\@4FEK87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*
M;7-G<W1R(")+871A<F%S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS
M9VED(")1=65R>2(*;7-G<W1R(")386MI;GES(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")1=6]T82(*;7-G<W1R(")+
M871A<F%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I
M="DB"FUS9W-T<B`B4E-!('9I9?!A<VES(')A:W1A<R`H)60@8FET86DI(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@
M<V5L96-T:6]N(@IM<V=S='(@(B=2861I;R<@<&%S:7)I;FMI;6%S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@
M(E)A:6XB"FUS9W-T<B`B3&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`B3&EE='5S(')Y=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(DQI971U
M<R!V86MA<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B3&G[=&ES(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*(RP@
M9G5Z>GD*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B3&EE='5S+U-N
M:65G87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(DQI
M971U<R]3;FEE9V%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(D%T<VET:6MT:6[K(&9R87KK
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2
M871I;R(*;7-G<W1R(")386YT>6MI<R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(E-K86ET
M>71I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B4&5R<VMA:71Y=&D@
M;&%I\&MA:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")4:6MR86D@
M:?!T<FEN=&D@)7,_($=R8?YI;G1I(&%T9V%L(&YE8F5G86SK<VET92XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B
M5&EK<F%I(&GP=')I;G1I('9A<G1O=&]J;R`E<R!D=6]M96YI<S\@1W)A_FEN
M=&D@871G86P@;F5B96=A;.MS:71E+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(E!A:V%R=&]T:2!A;FMS=&5S;N$@=F5I:W-M
MX"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")!=&YA=6II;G1I(&MA:7)I;VIO
M(&UE;FEU(&5L96UE;G1U<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!=&YA
M=6II;G1I('!O<G1A;&\@=F%I>F3@.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S
M='(@(E)E9V5X(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM
M<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B4^!R>?!I^"!N
M87+P>6MLZR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@
M(E)E;&]A9"(*;7-G<W1R(")3:V%I='ET:2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(E!A<W1A8F]S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E
M<G9E<G,B"FUS9W-T<B`B3G5T;VSF('-E<G9E<FEA:2(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(DYU=&]LYG,@
M55),("AH='1P.B\O=W=W+G!A=GEZ9'ES+F-O;2]H;W)D92DZ(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`B
M2?!T<FEN=&DB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*
M;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")08?!A;&EN=&D@8FQO:^`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E!A;F%I:VEN=&D@<W1U
M;'!E;.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")086YA
M:6MI;G1I(&9O<FUA=&%V:6W@(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(DGP=')I;G1I
M('!O<N`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B2?!T<FEN=&D@871N875J:6YI;6\@<VMR:7!T
MX"!I\"!S97)V97)I;R!L86EK:6YO:F\@:V%T86QO9V\N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS
M9VED(")296UO=F4@=&AE(@IM<V=S='(@(E!A\&%L:6YT:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R(")08?!A;&EN=&D@\.$@96QE;65N=.`@:?`@9&]K=6UE;G1O(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`B2?!T<FEN=&D@=F%R=&]T;VK@(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")687)T;W1O:F\@=')Y
M;FEM87,Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ
M,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R
M;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(DYE9V%L:74@871S86MY=&D@X2!U
M_FML875SX"X@2VQA:61O<R!K;V1A<SH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(").96=A;&EU(&GP
M<V%U9V]T:2!N=7-I^'-T;R!F86EL;RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&%R
M86UE=')A<R`G)7,G(&YE;G5R;V1Y=&%S("5S(&MO;F9I9_MR86-I:F]J92XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B4&%R86UE=')A<R`G)7,G(&YE;G5R;V1Y=&%S(%9&4R!K
M;VYF:6?[<F%C:6IO:F4N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z
M-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0
M87)A;65T<F%S("<E<R<@;F5N=7)O9'ET87,@:V]N9FEG^W)A8VEJ;VIE+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(DGP(&YA=6IO(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A
M<W-W;W)D(@IM<V=S='(@(E!A:V5I<W1I('-L87!T8?YO9.$B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!0
M87-S=V]R9"(*;7-G<W1R(")3;&%P=&'^;V3^:6\@:V5I=&EM87,B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")297-T;W)E
M($QA<W0@475E<GDB"FUS9W-T<B`B4&%S:W5T:6YI<R!K971V:7)T:7,B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R
M(")297IU;'1A=&%I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R(")'<N'^=&D@X2!N=7-T871Y;75S(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E!A:V5I<W1I('-L87!T
M8?YO9.$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@
M(E)E:OMN:6IA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")!='-T871Y=&D@:V]N9FEG^W)A8VEJX"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<R(*;7-G<W1R(")(5$U,(')E9&%K=&]R:6%U<R!N=7-T871Y
M;6%I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D
M;&5S(@IM<V=S='(@(DWA<VSK<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T
M<B`B1&7P:6[K:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q
M"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B1&7P:6YI;VII(&%N=')A
M\'3K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B
M4FEG:'0@=F%L=65S(@IM<V=S='(@(D1E\&EN:6]S:6]S(')E:6OP;>MS(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T5I
M;'5TZW,@;G5S=&%T>6UA:2XN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L
MZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4G5M
M=6YI:F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(E!A<W5K=&D@,3@P
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B4&%S=6MT:2!K86ERZVXB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X
M"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B4&%S=6MT:2!D9?!I;NMN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B16EL=73K
M<R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS
M9W-T<B`B16EL=73K<R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S
M='(@(D5I;'5TZW,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B4VMI
M<G1U:V%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")3:VER='5K86D@=&%R
M<"!V:7/X(&5I;'7H:?@@:7(@<W1U;'!E;&GX(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B
M4VMI<G1U:V%I('1I:R!T87)P('-T=6QP96QI^"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(E-K
M:7)T=6MA:2!T:6L@=&%R<"!E:6QUZ&GX(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(E9Y:V1Y=&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S
M:6IO<R!&961E<F%C:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A
M(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4B"FUS9W-T<B`B4R]-24U%('!A<F'P87,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-12!U_FMO9'5O=&%S(&QA:?!K
M87,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED
M(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D[K<F$@4T%33"!A=71E;G1I9FEK86-I:F]S(&UE8VAA;FEZ;6\N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3($UE
M<W-A9VEN9R(*;7-G<W1R(")335,@_FEN=73K<R(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!#3$DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@
M<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R
M(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S
M='(@(E!!5EE+3R(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3
M:&5L;"(*;7-G<W1R(")37U%,($-,22(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(M!E
M\'0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S
M='(@(M!V96YT;VII($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I
M;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='-A<R!I<B!.
M979I<V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G
M<W1R(")386EN="!,:75C:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I
M;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("+0=F5N=&%S:7,@4&5T
M<F%S(&ER($UI9V5L;VYA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I
M;F-E;G1A<R!I<B!'<F5N861I;F%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E
M;&8I(@IM<V=S='(@(E1A;64@<&'H:6%M92!L86YG92`H7W-E;&8I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I
M;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC
M:7!E(@IM<V=S='(@(E-A;R!4;VUE(&ER(%!R:6YC:7#K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(E!A;'ED;W9A<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E-A=61I($%R86)I82(*;7-G<W1R(")3875D;R!!<F%B:6IA(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM
M<V=S='(@(DGP<V%U9V]T:2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M7"(E<UPB(@IM<V=S='(@(DGP<V%U9V]T:2`E<R(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M)7,B"FUS9W-T<B`B2?!S875G;W1I("5S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(DGP<V%U
M9V]T:2!N=7-T871Y;75S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A
M(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"B))\'-A=6=O=&D@<W5G96YE<G5O='5S(&YU
M<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"!J^W/X('-E<G9E<FEO(&QA:6MI
M;F%J86UE("(*(FMA=&%L;V=E+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B5S(&YU<W1A='EM86D@:?!S875G;W1I+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E
M<UPB+B(*;7-G<W1R(")!=&YA=6II;FEM;R!S:W)I<'1A<R!I\'-A=6=O=&%S
M(.$Z("<E<R<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*
M;7-G<W1R("))>F]L:75O=&]S(%0M875D<F]S(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(DUO:W-L87,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(DEE\&MO=&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P
M"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")086EE\&MA(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I
M;&5S(@IM<V=S='(@(E!A<VER:6YK:71E(&9A:6QU<R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C
M="!A(&1A=&4B"FUS9W-T<B`B4&%S:7)I;FMI=&4@9&%TX"(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U
M<"!T;R!A9&0B"FUS9W-T<B`B4&%S:7)I;FMI=&4@9W)U<.8B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@
M;W=N97(B"FUS9W-T<B`B4&%S:7)I;FMI=&4@;F%U:N`@<V%V:6YI;FO@(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`B4&%S:7)I;FMI=&4@<V5R=F5RX2(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@
M82!U<V5R('1O(&%D9"(*;7-G<W1R(")087-I<FEN:VET92!V87)T;W1O:N`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E!A<VER:6YK
M:71E(&9A:6QU<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*
M;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")0
M87-I<FEN:VET92!V:7-U<R!D871O<R!K;VUP;VYE;G1U<RXB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")3
M96QE8W0@86X@;V)J96-T(@IM<V=S='(@(E!A<VER:6YK:71E(&]B:F5K=.`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")087-I<FEN
M:VET92!N875JX"!S879I;FEN:^`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E
M9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD
M("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B
M"B))\"#^96UI874@97-A;NAI^"!SX')A\/@@<&%S:7)I;FMI=&4@<F5I:VEA
M;75S('-I;6)O;&EU<RX@5NML:6%U(&=A;&ET92!J=6]S("(*(FYU:V]P:6IU
M;W1I(.$@;&%I\&O@+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T
M"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")0
M87-I<FEN:VET92!D871O<R!S:VER='5KX#HB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB
M"FUS9W-T<B`B4&%S:7)I;FMI=&4@9&%T;W,@9F]R;6%TX#HB"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B
M4&%S:7)I;FMI=&4@87!R8?#@(&MU<N$@;F]R:71E(')E9&%G=6]T:3HB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4&%S:7)I;FMI=&4@;&%I:V\@
M<VMI<G1U:^`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E!A<VER:6YK
M:71E(&QA:6MO(&9O<FUA=.`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM
M<V=S='(@(E!A<VER:6YK:71E(&1U(&%T:71I;FMA;NAI=7,@;&%U:W5S+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y
M;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4&%S:7)I;FMI=&4@<W!A;';X
M(&1E<FENX2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E!A
M<VER:6YK:71E(&YO<FEMX"!K86QBX#HB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R(")3:?AS=&D@<')O8FQE;6]S('!R86YE\&EMX"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")3
M96YD(%--4R(*;7-G<W1R(")3:?AS=&D@4TU3(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L87,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N
M<V]R:75S.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E)U9W/K:FES(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@
M(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")397)B:6IA(&ER($UO
M;G1E;F5G<F%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4V5R:6IO<R!N
M=6UE<FES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC
M+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B3W)O('/@;'EG^"!B;&]K;R!NZW)A+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!
M9&UI;B(*;7-G<W1R(")496ES:?@@861M:6YI<W1R879I;6%S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS
M9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(E-E<VEJ;W,@240@
M<&%S:6)A:6?K+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I
M9"`B4V5S<VEO;G,B"FUS9W-T<B`B7U1E:7/K<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R(")2:6YK:6YY
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P
M=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@
M>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B).=7-T871Y;6%I(&QE
M:63^:6%N='ES($IU;7,@<&%S:6ME:7-T:2!S;&%P=&'^;V3A+"!J96EG=2!J
MX2!K861A(&YO<G,@(@HB<&%M:7+P:71E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R
M(").=71O;'5S:?@@<V5R=F5R:?@L(&MU<FEU;W,@;F]R:71E(&UA='ET:2!I
M\"!P;W)T86QO+"!N=7-T871Y;6%I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")+86QB;W,L(&QA
M:6MO('IO;F]S(&ER(&1A=&]S(&YU<W1A='EM86DN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4'5S;&%P
M:6\@<W!A;';X+"!A='-I;F%U:FEN:6UO(&1A_FYU;6\@:7(@:VET^"!V86EZ
M9&%V:6UO('!A<F%M971R^"`B"B)N=7-T871Y;6%I+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(E-E='5P(@IM<V=S
M='(@(E]+;VYF:6?[<F%C:6IA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4B"FUS9W-T<B`B4F%S=&%S(&%T;F%U:FEN:6UO('-K<FEP=&%S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B
M4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R
M.B`B"FUS9W-T<B`B4W4@\&EU;R!P87)A;65T<G4@9V%L:6UO<R!K96QI;W,@
M=FEE=&]VZW,Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`B4V5I\&5L86DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")087)D=6]T=7;K(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`B5')U;7!A<R!A<')A\'EM87,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B07(@
M;F%U9&]T:2!K;&%V:6%T^W)O<R!M>6=T=6MU<R!V86QD>6UU:3\B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO
M=R(*;7-G<W1R(")2;V1Y=&DB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*(E!A<F]D>71I('-K:7)T=6UU<R!T87)P(&GP
M<V%U9V]T;R!I<B!KX"!T:6L@<W5G96YE<G5O=&\@:V]N9FEG^W)A8VEN:6\@
M9F%I;&\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R
M(")2;V1Y=&D@<&%S:W5T:6YI;R!P<FES:6IU;F=I;6\@;&%I:^`_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")2;V1Y=&D@9V%L:6UY8N8@
M<&%L:6MT:2!O<FEG:6YA;.`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")2;V1Y=&D@<&%R
M:7-I;FMI;>`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED
M(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E)O
M9'ET:2!L96YT96SK<R!O<&5R86-I:O@@;65N:74_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")2;V1Y=&D@)7,@;65N
M:74@:V%I<NMJ93\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E
M;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B4F]D>71I(&-E;.MS(&YU
M<W1A='EM^"!L86YGX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B4F]D>71I(&QE;G1E;.MS(&YU
M<W1A='EM^"!L86YGX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E)O9'ET:2!E:6QU=.MS
M(&YU<W1A='EM^"!L86YGX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B4F]D>71I('!A=F5I:W-L
MZVQI;R!N=7-T871Y;?@@;&%N9^`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")2;V1Y=&D@
M9F%I;/@@X6OK;&EMX"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(DQI^W1I<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(DQI^W1I<R!R>71E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R("),:?MT:7,@=F%K87)E(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H
M;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM
M<V=S='(@(E-U;6'^:6YT:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O
M=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B
M4W5M8?YI;G1I(&%R8F$@<&%S='5M=&D@:V%I;7EN:6YI=7,@8FQO:W5S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I
M97)A($QE;V[K(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")296=I<W1R86-I:F$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B
M4VEG;F%T=7)E(@IM<V=S='(@(E!A<F'P87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R
M:71H;2(*;7-G<W1R(")087)A\&\@86QG;W)I=&UA<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87#[<F%S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G
M<W1R(")$>61I<R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@
M(E!R86QE:7-T:2!P<F]F:6QA:W1I:^`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3;&]V86MI82(*;7-G<W1R(")3;&]V86MI:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]VZVYI:F$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM
M<V=I9"`B4VYO=R(*;7-G<W1R(")2;V1Y=&DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B
M"FUS9W-T<B`B4/MG82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B4/MG82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B3&G[=&ES(')Y=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W
M97)S($QA=&4B"FUS9W-T<B`B3&G[=&ES('9A:V%R92(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B
M4VYI96=O(&=Y;&ES.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM
M<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4VYI
M96=O(&MI96MI<R!V86YD96YI=3H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O;&]M;VYO('-A;&]S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&EA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O
M96US(@IM<V=S='(@(D1A:6YO<R!I<B!%:6SK<F'PZ&EA:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L
M96-T:6]N(@IM<V=S='(@(E+[\&EA=FEM;R!T=F%R:V]S('!A<VER:6YK:6UA
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(E-I
M=6YTZVIO(&%D<F5S87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B4&EE=/@@069R:6MA(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*2(*;7-G<W1R(")0:65T^"!%=7)O<&]S("A)4T\M.#@U.2TS*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4&EE=/@@1/YO<F3^:6IO<R!I<B!0
M:65T^"!386YD=FGH;R!S86QO<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B4&EE=&ENZR!H96UI<V9E<F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")487)P87,@=&%R
M<"!C96QI^"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(E1A<G!A<R!T87)P(&-E;.MS('1U<FEN
M:6\@:7(@:W)A\'1I;NMS(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B5&%R<&%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED
M(")3<&%C:6YG(@IM<V=S='(@(E1A<G!A:2!T87)P(&-E;&GX(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM
M<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")487)P86DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B27-P86YI:F$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS
M9W-T<B`B4W!A;6%S(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS
M9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")3<&5C:69I
M;FGX('-I;6)O;&GX(.%T97)P:6UA<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B4&5R<VME;'1I(&-E;.8B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI
M="!C;VQU;6XB"FUS9W-T<B`B4&5R<VME;'1I('-T=6QP96SA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM
M<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(E!E<G-K96QT:2!E:6QU=.8B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G
M<W1R(")3<&]R=&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B
M"FUS9W-T<B`BT')I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G:60@(E-T86YD
M87)D(@IM<V=S='(@(E-T86YD87)T87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LG
M87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T
M<B`B4')A9&EN:6%I(&UE=&%I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S
M='(@(E)A:F]N87,@87)B82!P<F]V:6YC:6IA(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R
M(")"^W-E;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS
M9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")3875G;VII;6\@9F]R;6%T
M87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM
M<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B1V%T=NMS(&%D<F5S87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(E7^8G)A=6MT:2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L
M:7-T(@IM<V=S='(@(MYO9/YI^"!SX')A\&%S(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE
M(&%D9')E<W,B"FUS9W-T<B`B3G5I;71I(&1O;65NX"!N=6\@861R97-O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I;&EU<R!;0U-3
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C(*;7-G:60@(E-U(@IM<V=S='(@(E-E:VTN(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F5R87-T
M87,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")496UA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(L%V97-T:2(*
M"B,Z('-I9VYU<"YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S
M="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB5F%R=&]T;VIA<R`G
M)7,G('-U:W5R=&%S('-I<W1E;6]J92X@2V]L(&II<R!N97!A='9I<G1I;G1A
M<RP@<')I<VEJ=6YG=&D@(@HB;F5G86SK<VET92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I
M<'0B"FUS9W-T<B`B26YD96MS87,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B
M4^MK;6EN9V$B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G('/K:VUI;F=A:2!S=6MU<G1A<R!S
M:7-T96UO:F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E9A<G1O
M=&]J;R`G)7,G(&1U;VUE;GES('/K:VUI;F=A:2!I\'1R:6YT:2!I\"!S:7-T
M96UO<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!SZVMM:6YG
M86D@:?!T<FEN=&$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G('/K:VUI;F=A:2!I
M\'1R:6YT87,@:?`@<VES=&5M;W,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB2V]N
M9FEG^W)A8VEJ82!A='-T871Y=&$@<^MK;6EN9V%I+B!097)K<F%U:VET92!P
M=7-L87#A+"!K860@<&%M871Y='5MZW1E("(*(G!A:V5I='5M=7,N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(D%T<V%R9VENZR!K;VYF:6?[<F%C:6IO<R!K
M;W!I:F$@<^MK;6EN9V%I(&GP<V%U9V]T82XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(D%T<V%R9VENZR!K;VYF:6?[<F%C:6IO<R!K;W!I:F$@
M<^MK;6EN9V%I(&GP<V%U9V]T82#A("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B<E<R<@<^MK;6EN9V%I(&%T;F%U
M:FEN=&%S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(G)7,G('/K:VUI;F=A:2!U_G)A
M\'ET87,N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M4W5D86YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B5'5R:6YY
M<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I
M<V4B"FUS9W-T<B`B4V%U;.MT96MI<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")3875LZVQY9VES(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G
M:60@(E-U;FYY(@IM<V=S='(@(E-A=6SK=&$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E-A
M=6SK=&5K:7,B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S
M='(@(E-A=6SK=&5K:7,O4V%U;.ML>61I<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")3
M875LZW1E:VES.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V%U;.ML>6=I<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(E-A=6SK;'EG:7,Z("(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM
M<V=S='(@(DQA:7!S;FES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,W.`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")!<'1A<FYA=FEM87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M
M87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM
M<V=I9"`B4W5R;F%M92(*;7-G<W1R(")0879A<F3K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L
M8F%R9&%S(&ER($3^86YM86EN87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3
M=V%Z:6QA;F0B"FUS9W-T<B`B4W9A>FEL86YD87,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")3=V5D96XB"FUS9W-T<B`BT'9E9&EJ82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("+0=F5I8V%R:6IA(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@
M(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B3F5T<FEN=&DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED
M(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(E-I;G1A
M:W/K<R!K;&%I9&$@<&%I9?!K;W,@:W)I=&5R:6IU:F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3:7)I
M:F]S($%R86+X(%)E<W!U8FQI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")4
M+6%U9')A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED
M(")4+5-T;W)M<R(*;7-G<W1R(")4+6%U9')O<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4
M+5-T;W)M<R!%87)L>2(*;7-G<W1R("),:?MT:7,@<GET92(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM
M<V=S='(@(E135B!F86EL87,B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N
M<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B3&5N=&5LZR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*
M;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B3&5N=&5LZW,@;G5S
M=&%T>6UA:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("),
M96YT96SK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R
M("),96YT96SK<R!N=7-T871Y;6%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:79A;F%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%I=F%N87,L($MI;FEJ;W,@<')O
M=FEN8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B5&%D_FEK:7-T86YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2G5N9W1I;NL@
M5&%N>F%N:6IO<R!297-P=6)L:6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M(")486EK:6YY<SHB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S
M='(@(D1A<F)A:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F
M;VYO(&YU;65R:7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I
M9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<"X@<&%S:RX@
M=F%L86YDX#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@
M(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T^W)A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z
M("(*;7-G<W1R(")496UP97)A=/MR83H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(").97)A<W1A<R`G)7,G(/!A8FQO;F%S+B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("+086)L;V[X(&%D;6EN:7-T<F%V:6UA<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS=&%S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY
M(@IM<V=S='(@(E1I:R!T96MS=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG
M;B(*;7-G<W1R("),>6=I=6]T:2!T96MS=.`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM
M<V=S='(@(E1E:W-T;R!V:7+P=6IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B2V5T
M=BXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H
M5$E3+38R,"DB"FUS9W-T<B`B5&%I;&%N9&EE=&GP:V$@*%1)4RTV,C`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&%I;&%N
M9&%S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(D'H:?L@
M:V%D(&YA=61O:F%TZW,@<VES=&5M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B3NMR82!&5%`@;6]D=6QI;RXB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B(&EN=&5G
M<F%C:6IO<R!V87)I:VQI=6MA<R!N97!A;&%I:V\@7"(E<UPB(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@HC+"!F=7IZ>0IM
M<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB
M"FUS9W-T<B`B3F5G86QI=2!I\'-A=6=O=&D@;G5S:?AS=&\@9F%I;&\N(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(DYE<&%V>6MO('7^:W)A=71I($UA:6YT96YA;F-E.CH@:VQA<^MS
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I
M9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(DYU<W1A='EM^"!L86YG87,@=?YD87)Y=&%S+B!)\&5I;G4N(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S
M:6]N<RXB"FUS9W-T<B`B(@HB2F5I9W4@;F]R:71E(&YA=61O=&D@;G5S=&%T
M>6UU<RP@<&%P<F'P>6MI=&4@:V%D(&%D;6EN:7-T<F%T;W)I=7,@(@HB<W5K
M;VYF:6?[<G5O=/@@<&%S=&]V:>`@9'5O;65N^"!B87KF(&YU<W1A='EM86US
M('-A=6=O=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB
M"FUS9W-T<B`B5&EK(&%P871I;NMJ92!P=7/K:F4B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB
M5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*
M;7-G<W1R(").9>%R8?#K=&4@8V]N=&%K=&\@240@;G5M97)I;R!A<F)A(&II
M<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T
M('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(DMO;G1A:W1A<R!SZVMM:6YG86D@X71R875K=&%S(.$@2OMS
M^"!A9')E<_@@:VYY9V5LYBXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+B(*;7-G<W1R(").;W+K9&%M:2!P871I:W)I;G1I(&QA:?!KX"!P
M<FEV86QO=&4@='5RZW1I(&%T<VMI<N`@4$=0('!A<F'P;R!B;&]KX"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB
M:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R(").9>%R8?#K=&4@9&ES=')I8G5C
M:6IO<R!SX')A\&\@240@87)B82!J:7,@;F5R87-T87,@9'5O;65N^"!B87KK
M:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T
M('-P96-I9FEE9"XB"FUS9W-T<B`B3F7A<F'PZW1E(&1I<W1R:6)U8VEJ;W,@
M<^!R8?!O+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS
M9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)01U`@=?YK;V1A=FEM;R!G
M86QI;7EBZR!R96EK86QA=6IA('-A=6=A=7,@<')I<VEJ=6YG:6UO+B!"86YD
M>6MI=&4@<F'P>71I("(*(FAT='!S.B\O(&%D<F5S;R!P<F%D_FEO:F4N(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")&
M86EL87,@)7,@<')I=F%L;R!T=7+K=&D@)7,@<&%R86UE='+@+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(D9A
M:6QA<R`E<R!P<FEV86QO('1U<NMT:2!K86D@:W5R:75O<R`E<R!P87)A;65T
M<G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I
M9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM
M<V=S='(@(D9A:6QA<R!N96=A;&D@8OMT:2!N=6MO<&EJ=6]T87,@86YT('-A
M=N9S+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D9A:6QE(&[K
M<F$@9'5O;65N^"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R
M(")21D,X.#(@;&%I\&MO(&%N=')A\'3K<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H
M870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@
M97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R
M(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF
M("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L
M>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(DIE
M:6=U(&1I<F)A=&4@26YT97)N970@17AP;&]R97(@;F%R\'EK;&4L('!I;&YA
M96MR86YI<R!R961A:W1O<FEA=7,@<F7^:6UA<R`B"B)G86QI('-U:V5L=&D@
M<')O8FQE;?@L(&3K;"#P:6]S(&YA<O!Y:VSK<R!K;&%I9/@N($=A;&ET92!N
M96UA='ET:2!K86D@:W5R:?@@(@HB<F5D86MT;W)I875S(&5L96UE;G3X+B!*
M96EG=2!N875D;VIA=&4@5VEN9&]W<R`Y>"!/4R!G<F5IZ&EA=7-I86D@:OMS
M^"`B"B)K;VUP:75T97)I<R!P87!R8?#H:6%U<VEA:2!N=6QU\"!P87-K96QB
M9&%M87,@87!I92!P86=R:6YD:6[F(&ML86EDX"Y<7&XB"B)<7&Y*^W,@8G5V
M;W1E('!E<G-PZW1A<RX@2F5I9W4@=FES=&EE:R!N;W)I=&4@:?!B86YD>71I
M('!I;&YA96MR86[A(')E_FEMX"`B"B)S<&%U<VMI=&4@3TLN(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I
M9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B07!R
M8?!A<R!<(B5S7"(@:?!T<FEN=&%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E1I:R!K86ERZVIE('!U<^MJ92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B
M(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(D-R>7!T
M7W!Q<#HZ(&ML87-E:2!R96EK:6$@;G5R;V1Y=&D@:W5R('ER82!';G501R!F
M86EL86DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S
M('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D
M+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(DQA:?!K
M87,@:?!S:?AS=&%S("5S(&%D<F5S871U:2`E<R!T96UA(%PB)7-<(B!B=79O
M('!A<F]D>71A<RY<;B(*(E1AZ&EA=2!T86D@;F5G87)A;G1U;VIA(&MA9"!L
M86GP:V%S(&)U=F\@<&5R<VMA:71Y=&%S(&%R8F$@<W5P<F%S=&%S+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G
M<W1R(")0879A9&EN:6UA<R!K=7+A(&YA=61O<VET92!N=6]R;V1O:F4@X2!L
M86GP:V\@<F'P>6UO('!U<VQA<.$B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BT&D@<F5I:_!MZR!T=7)I
M(&+[=&D@<VMA:>AI=7,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R(")(;W)D95]#<GEP=%]S;6EM93HZ(&ML87-E:2!R96EK86QI;F=A<R!/
M<&5N4U-,(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@
M7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@
M(B(*(DYE9V%L:74@:?!S875G;W1I(&YU<W1A='EM;R!<(B5S7"(L(&YE<R!D
M=6]M96[X(&1Y9&ES('9I<O!Y:F$@;&5I<W1I;N`@<FEBX"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B4')O9W)A;6$L('-K:7)T82!P97+^:?MRZW1I(/#A(&1U;VUE
M;O@@=&EPX"`H)7,I+"!N97)A<W1A('-I<W1E;6]J92XB"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R
M86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB
M"FUS9W-T<B`B5&EK(&MA:7+K:F4@:7(@9&7P:6[K:F4@<'5SZW-E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E1I
M:R!D9?!I;NMJ92!P=7/K:F4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=F5R:7,@
M7"(E<UPB(&GP=')I;G1A<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R:7,@7"(E<UPB(&GP
M<V%U9V]T87,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`B)7,@<F5G:7-T<F%C:6IO<R!P<F'P>6UA<R!I
M\'1R:6YT87,N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B3G5R;V1Y=&$@96EL=73K(&YE96=Z:7-T=6]J82XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B3G5R;V1Y=&$@96EL=73K(&YE96=Z:7-T
M=6]J82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED
M(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT
M(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(E1I:R!V:7+P=71I
M;NMJ92!I<B!A<&%T:6[K:F4@<'5SZW-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O
M<"!S:61E(&]N;'DB"FUS9W-T<B`B5&EK(&%P871I;NMJ92!P=7/K:F4B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*
M;7-G<W1R(").=7-I^'-T:2!D=6]M96YY<R!P<F%R87-T:2XB"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD
M(&YO="!B92!S879E9"XB"FUS9W-T<B`B3F5G86QI=2!I\'-A=6=O=&D@;G5S
M:?AS=&\@9F%I;&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")796%T:&5R+F-O;2!B;&]K;R!NZW)A
M+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(").97)A<W1A<R`G)7,G(/!A8FQO;F%S+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DYU<W1A='EM^"!N
MZW)A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T
M,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N(@IM<V=S='(@(D1A;&GX+"!K=7)I87,@9V%L:6UA(')O
M9'ET:2!L86GP:V\@=&5K<W1E+"!NZW)A+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N(@IM<V=S='(@(B(*(M!I86UE(&QA=6ME(.%V97-T82!P
M97(@9&%U9R!S:6UB;VQI^"X@2OMS(.%V963K=&4@)7,L(&\@;6%K<VEM86QU
M<R!S:V%IZ&EU<R`B"B(M("5S('-I;6)O;&EA:2XB"@HC.B!S:6=N=7`N<&AP
M.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B4W5K=7)T:2`G)7,G(&YE<&%V>6MO.B`E
M<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(").97!A
M=GEK;R!I\'1R:6YT:2!V87)T;W1O:F\@)R5S)R!D=6]M96[X(&GP('-I<W1E
M;6]S.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DGP=')I;G1I("<E<R<@
M;F5P879Y:V\Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R!<(B5S7"(Z("5S(@IM<V=S='(@(D%T;F%U:FEN=&D@)R5S)R!N97!A=GEK
M;SH@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R
M(")0<F]B;&5M;W,@<W4@9F%I;/@@<VEU;G1I;74Z("5S(&YE;G5S:?AS=&%S
M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B
M"B).=7-I^'-T:2!F86EL;R!N97!A=GEK;RX@1F%I;&%S("5S('ER82!D:61E
M<VYI<R!N96=U(&QE:63^:6%M87,@9'ED:7,@*"5D("(*(F)A:71A:2DN(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N(@IM<V=S='(@(DYU<VGX<W1I(&9A:6QO(&YE<&%V>6MO+B!&86EL87,@
M)7,@=&EK(&1A;&EN86D@;G5S:?AS=&%S+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(DYE9V%L:74@<&%R;V1Y=&D@\&EO<R!L86GP:V\@9&%L:65S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R(")+;&%I9&$@X6ME;&EA;G0@:V]N=&%K=&EN:75S(&1U;VUE;FES
M+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(DML86ED82#A:V5L:6%N="!I0V%L96YD87(@9'5O;65N
M:7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN
M(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM
M<V=S='(@(B(*(DML86ED82!K;VYF:6?[<F%C:6IO<R!F;W)M;VIE+B!'<F5I
MZ&EA=7-I86D@;F5U_G!I;&3K=&4@<F5I:VEA;?@@;&%U:_@N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C
M:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"B)+;&%I9&$@871L:65K86YT(&YU<F]D
M>73@(&%D<F5S^"!K;GEG96SK<R!F=6YK8VEJX"X@4&%B86YD>6MI=&4@=NML
M:6%U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B2VQA:61A(&%T;F%U:FEN86YT(&MO;G1A:W1I;FEU<R!D
M=6]M96YI<RX@4&%B86YD>6MI=&4@=NML:6%U+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")+;&%I9&$@871N
M875J:6YA;G0@9&ES=')I8G5C:6IO<R!SX')A\.`N(%!A8F%N9'EK:71E(';K
M;&EA=2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(M!I<R!)34%0('-E<G9E<FES
M(&YE<&%L86EK;R!K871A;&]G^"!D86QI:FEM;W-I+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S
M='(@(D%T<F]D;RP@:V%D('1A:2!N971V87)K:6YG87,@4D%2(&%R8VAY=F%S
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N(@IM<V=S='(@(D%T<F]D;RP@:V%D('1A:2!N971V87)K:6YG87,@
M6DE0(&%R8VAY=F%S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+B(*;7-G<W1R(")!=')O9&\L(&MA9"!T86D@;F5T96ES:6YG
M87,@:V]R=&5LZW,@;G5M97)I<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L
M:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(M!I('1V87)K>6MLZR!L
M96ED_FEA('-I^'-T:2#^:6YU=&5S('!E<B!#;&EC:V%T96QL("AH='1P.B\O
M8VQI8VMA=&5L;"YC;VTI("(*(G!A<VEN875D;VIA;G0@2%144"!P<F]T;VMO
M;'4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M-`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*(M!I('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S('!E<B!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2`B"B)P87-I;F%U9&]J
M86YT($A45%`@<')O=&]K;VQU(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"B+0:2!T=F%R:WEK;.L@;&5I9/YI
M82!S:?AS=&D@_FEN=71E<R!P97(@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M
M86EL+F-O;2D@(@HB<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B
M"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I
M<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B+0:2!T=F%R:WEK;.L@
M;&5I9/YI82!S:?AS=&D@_FEN=71E<R!33510('!R;W1O:V]L=2!P97(@5F]D
M869O;F4@271A;&EJ;W,@(@HB=F%R='5S+"!T:6L@5F]D869O;F4@;G5M97)I
M86US+B!*:2!R96EK86QA=6IA(&5L+B!P8?!T;R!A9')E<V\@5F]D869O;F4@
M(@HB271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U
M-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS
M9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("+0:7,@;&%U
M:V%S('!R:79A;&]M87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G
M97)S+B(*;7-G<W1R("+0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-V96EK
M:65J:2!S:V%IZ&EA:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("+0:6%M92!L875K92!G86QI(&+[
M=&D@=&EK('-K86GH:6%I(&ER(&1V:71A\&MI86DN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`BT&EA;64@;&%U:V4@
M9V%L:2!B^W1I('1I:R!A\'1U;G1A:6YI86D@<VMA:>AI86DN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,B"FUS9W-T<B`B(@HBT&EA;64@;&%U:V4@='5R:2!B^W1I(&MA8FQE
M;&EA:7,@87)B82!T87)P86ES(&%T<VMI<G1I('-V96EK:65J:2!S:V%IZ&EA
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI
M<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("+0:2!R
M96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N
M=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@
M97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(M!I86UE(&QA=6ME
M(&=A;&D@8OMT:2!T:6L@<W!A;'9O<R!K;V1A<R!21T(@2&5X(&9O<FUA=&4L
M('!A=GEZ9/YI=6D@(@HB)R,Q,C,T048G+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E
M96X@<')O8V5S<V5D+B(*;7-G<W1R("+0:2!F;W)M82!J874@87!D;W)O=&$N
M(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B5&%I("5S+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI
M96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M
M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S
M92!V:7-I="`E<R(*;7-G<W1R("(B"B)486D@2V]L86(@1W)O=7!W87)E(&]B
M:F5K=&%S+B!.;W+K9&%M:2!P97+^:?MRZW1I(&]B:F5K=.`@<')I=F%L;W1E
M('1U<NMT:2`B"B)E;"X@<&'P=&\@:VQI96YTX"P@:W5R:7,@<W5P<F%N=.`@
M\.$@9F]R;6%TX"X@5&]K:?@@96PN('!A\'1O(&ML:65N=/@@<^!R8?#@("(*
M(F=A;&ET92!R87-T:2!A<'-I;&%N:^8@)7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(M!I<R!L86GP:V%S
M(&)U=F\@<&%R8?!Y=&%S("5S(&MO9'5O=&4N($K[<R!N875D;VIA=&4@:VET
M;VMIX"!K;V1U;W3F+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92XB"FUS9W-T<B`BT&ES('-K86GH:75S('1U<FD@8OMT:2!D:61E<VYI<R!U
M_B!N=6SA+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(M!I<R!S97)V97)I<R!N96=A
M;&D@:?!A<F-H>79U;W1I('II<"!I<B!G>FEP(&9A:6SX+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(M!I
M('-I<W1E;6$@9&%B87(@:?!J=6YG=&$N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BXB"FUS9W-T<B`BT&D@<F5I:_!MZR!T=7)I(&+[=&D@<VMA:>AI
M=7,N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM
M<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=R(*;7-G<W1R("+0X2!L86YGX"!R96EK:6$@871I9&%R:6[K
M=&D@:?`@;G5S=&%T>6WX(&QA;F=O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B
M4&5R:_MN:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM
M<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")":6QI971A:2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(DQA:6MA<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B
M"FUS9W-T<B`B3&%I:V\@87!S:V%I=&$B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(DQA:6MO(&9O<FUA
M=&%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B
M5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B3&%I:V\@<&%S:7)I;FMI;6%S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM
M;W)L97-TZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE
M(@IM<V=S='(@(E!A<F5I9V]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*
M;7-G<W1R(")0879A9&EN:6UA<SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")+86TB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T
M"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H
M:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B).;W+K9&%M:2!P87-I<FEN:W1I
M(&ME;&5TX"!E;&5M96YT^"P@;&%I:WEK:71E($-O;G1R;VP@*%!#*2!A<F)A
M($-O;6UN860@(@HB*$UA8RD@:VQA=FGPX"P@:7(@<&%S:7)I;FMI=&4@<&5L
M92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED
M(")4;V1A>2(*;7-G<W1R("+0:6%N9&EE;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,
M(%-O=7)C92(*;7-G<W1R(")2;V1Y=&D@2%1-3"!K;V3@(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(E)Y=&]J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS
M9W-T<B`B5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")6:7+P=6IE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")6:7+P=71I;FEA
M;64@;&%N9V4@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B5F5R=&EM86DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@
M(E1R:6YI9&%D87,@:7(@5&]B86=A<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5&%I
M<"!A<F)A(&YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B06YT<BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;FES87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R:VEJ82(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M
M.#@U.2TY*2(*;7-G<W1R(")4=7)K:?!K82`H25-/+3@X-3DM.2DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VWK
M;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<R(*;7-G<W1R(")4=7)K<V\@:7(@2V%I:V]S;R!S86QO<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@
M8VAO:6-E.B`B"FUS9W-T<B`BP79E<VMI=&4@<V%V;R!P87-I<FEN:VEMX#H@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(E4N5BX@:6YD96MS87,Z("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T
M,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T(@IM<V=S='(@(E-K<FEP=&\@<')I<W1A='EM;R!S=&%T=7-O(')A
M<&]R=&\@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN82(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B56YA8FQE
M('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!A=GEK;R!P
M97)S:V%I='ET:2!61E,@:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R(").
M97!A=GEK;R!P<FEDZW1I('!A<&EL9&]M;W,@=F%R=&]T;VIO(')E9VES=')A
M8VEJ;W,@:6YF;W)M86-I:F]S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").
M97!A=GEK;R!P86ME:7-T:2!61E,@9F%I;&\@7"(E<UPB('1E:7-I^"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*
M;7-G<W1R(").97!A=GEK;R!P86ME:7-T:2!T96ES:?@@5D93(&9A:6QU:2`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R(").97!A=GEK;R!P97)E:71I(.$@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R
M(").97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(").97!A
M=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`E<R\E<RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(").97!A=GEK;R!P<FES:6IU
M;F=T:2!P<FEE(%-13"!S97)V97)I;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!3
M4TPN(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I(%-33"!R9?YI;74N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM
M<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V
M>6MO(&YU:V]P:6IU;W1I(%9&4R!F86EL;RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").97!A
M=GEK;R!S=6MU<G1I(%9&4R!K871A;&]G;R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(U-@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(").97!A=GEK;R!S=6MU<G1I(%9&4R!K871A;&]G;RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").97!A=GEK;R!S=6MU<G1I
M(%9&4R!F86EL;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D
M:6YT:2!61E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92XB"FUS9W-T<B`B3F5P879Y:V\@<W5K=7)T:2!T=?#H:6\@5D93
M(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N
M<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T
M<B`B3F5P879Y:V\@:?!A<F-H>79U;W1I(&1U;VUE;O@N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R
M(").97!A=GEK;R!I\'1R:6YT:2!<(B5S7"(L(&MA=&%L;V=A<R!N971U\.AI
M87,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN
M=&D@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R
M(").97!A=GEK;R!I\'1R:6YT:2`E<RP@:V%T86QO9V%S(&YE='7PZ&EA<R(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(").
M97!A=GEK;R!R96MU<G-I\&MA:2!I\'1R:6YT:2!61E,@:V%T86QO9V\N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P879Y
M:V\@:?!T<FEN=&D@5D93(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(%9&4R!K
M871A;&]G;SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(%9&4R!F
M86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@
M5D93(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT
M:2!61E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B3F5P879Y:V\@<F5K
M=7)S:?!K86D@:?!T<FEN=&D@5D93.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@P,PIM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C
M=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P879Y:V\@;G5S=&%T>71I
M(&1A8F%R=&EN:6\@:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B3F5P879Y:V\@9V%U=&D@<V5R
M=&EF:6MA=&\@87!R8?!Y;6\B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B3F5P879Y:V\@=?YK<F%U=&D@)7,@
M87!R8?!Y;6\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+B(*;7-G<W1R(").97!A=GEK;R!P97)K96QT:2!61E,@9F%I;&\N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T
M."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B3F5P879Y:V\@871I9&%R>71I(%9&4R!F86EL;R!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2!61E,@
M9F%I;&\@<F'P>6UU:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3F5P879Y:V\@871I9&%R>71I(%9&
M4R!F86EL;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2!S=7-P875S=&\@87)C
M:'EV;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F
M86EL960I+B(*;7-G<W1R(").97!A=GEK;R#A<F'P>71I(%9&4R!F86EL;R`H
M8V]P>2@I(&ML86ED82DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V
M-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E
M=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5P879Y:V\@X7)A\'ET
M:2!61E,@9F%I;&\@*&-O<'DH*2!K;&%I9&$I+B(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(DYE
M<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(").97!A=GEK;R!P97)S:V%I
M='ET:2!V9G-R;V]T(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D:6YT:2`E<R#A("5S.B!T
M;VMS(&MA=&%L;V=A<R!J874@96=Z:7-T=6]J82(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D:6YT
M:2!61E,@:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D:6YT
M:2!61E,@:V%T86QO9V\Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\@)7,O)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B3F5P879Y:V\@<&5R
M=F%D:6YT:2!61E,@9F%I;&\N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@
M<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B3F5P879Y:V\@<&%L96ES=&D@)VUK
M:7-O9G,G+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT(@IM<V=S='(@(DYE<&%V>6MO(&GP=F5R<W1I(/!I;R!7;W)D
M(&1O:W5M96YT;R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DYE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DYE
M<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA:61A*2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82XB"FUS9W-T<B`B3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@
M9'5O;65N^"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N(@IM<V=S='(@(DYE<&%V>6MO(.%R8?!Y=&D@5D93
M(&9A:6QO("AC;W!Y*"D@:VQA:61A*2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS
M9W-T<B`B4&%B<F%U:W1I(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D%T\&%U:W1I('!A:V5I
M=&EM=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M(")!=/!A=6MT:2!A;FMS=&5S;N$@=F5I:W-MX"(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@
M(DYE=&EKZW1A('-E<G9E<FEO(&ML86ED83H@(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B3F5T:6OK=&$@<V5R=F5R
M:6\@:VQA:61A.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").96YU
M<F]D>71A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N
M:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEK;V1A<R`H551&+3@I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@
M(DIU;F=T:6YI86D@07)A8O@@16UY<F%T86DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(DIU;F=T:6[K($MA<F%L>7-T
MZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T
M<B`B2G5N9W1I;NMS(%9A;'-T:6IO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R
M(")*=6YG=&EN:?@@5F%L<W1Y:O@@071O:V5S;NMS('-A;&]S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(E9I96YE=&%I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(").
M9?YI;F]M87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2XB"FUS9W-T<B`B3F7^:6YO;6%S(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(DYE_FEN;VUA<R!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(DYE;G5S=&%T>71A('9I971O=NLN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G
M<W1R(").9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T
M8?YO9&ES+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`B4&%N86EK:6YT:2!N=6]R;V3@(/!I86T@96QE;65N
M='5I(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*
M;7-G:60@(E5N;F%M960B"FUS9W-T<B`B3F7A=F%R9&EN=&%S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B
M(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)3875G
M=6UO('-U;65T:6UA:7,@;F5P<FEV:6QE9VEJ=6]T:2!S:W)I<'1A:2!N96=A
M;&D@871L:6MT:2!097)KZVQI;6\O(@HB2V]P:6IA=FEM;R_!:^ML:6UO('!R
M;V=R86UI\&MA:2X@3F]RZV1A;6D@<&5R_FG[<NMT:2!T96-H;FEN97,@9&5T
M86QE<R`B"B)M;WII;&QA+F]R9R!T:6YK;&%P>6IE+"!I<B!S=?YI;F]T:2!K
M86EP('-K<FEP=&%M<R!L96ES=&D@<')I96ET:2!P<FEE("(*(FQA:6MI;F]S
M:6]S('-A=6=Y:VQO<RP@<&%S<&%U<VMI=&4@3TLN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B
M56YS970@8V]L;W(B"FUS9W-T<B`B3F5N875D;W1I('-P86QV;W,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(E!LZW1I;GES(&YE<&%L86EK;VUA<R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B071N875J
M:6YT:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%T;F%U
M:FEN=&D@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")!=&YA=6II;G1I('9A
M<G1O=&]JX"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B)R5S)R!A=&YA=6II;G1A+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G
M<W1R(")!=&YA=6II;FEM;R!S:W)I<'1A<R!I\'1R:6YT87,N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B3G5S
M:?AS=&DB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BXB"FUS9W-T<B`B5FES:2!M;V1U;&GX(&%T;F%U:FEN:6UO(&9A:6QA
M:2#A:V5L=&D@X2!S97)V97+A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B1&ED_FEO<VEO<R!L;W1I;FGP:V]S(')A
M:63K<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B1&ED:65J:2!R;VWK;FGP:VD@<VMA:>AI86DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=V86IU<R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(").
M875D;W1I(&1A8F%R=&ENYCH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G
M<W1R(").875D;W1I(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N(@IM<V=S='(@(DYA=61O=&D@:F5I9W4@=F%R=&]T
M;VIO('9A<F1A<R]S;&%P=&'^;V1I<R!)35-0('-E<G9E<FEU:2!Y<F$@:VET
M;VMS+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B5F%R=&]T;VIA:2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R(")687)T;W1O:F%S("5S(&YE875T;W)I>G5O=&%S('!R
M:>MJ:6UU:2!P<FEE("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I
M9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")687)T;W1O:O@@861M
M:6YI<W1R879I;6%S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")687)T;W1O:F\@
M;G5S=&%T>6UA:2(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(E9A<G1O=&]J^"!R96=I<W1R86-I:F$B"@HC
M.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")687)T;W1O
M:O@@<F5G:7-T<F%C:6IA(&GP:G5N9W1A+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-CD*(RP@9G5Z>GD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`B)7,@;F5R87-T87,N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B5F%R=&]T;VIO('9A<F1A
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B5F%R=&]T;VIO('9A<F1A<R`G)7,G(&IA
M=2!E9WII<W1U;VIA+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E9A<G1O=&]J;R!V87)D
M87,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B
M57-E<FYA;64Z("(*;7-G<W1R(")687)T;W1O:F\@=F%R9&%S.B`B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I
M;B!T:&4@<WES=&5M.B(*;7-G<W1R(")687)T;W1O:F%I(/!I;VIE('-I<W1E
M;6]J93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S
M='(@(E5Z8F5K:7-T86YA<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@
M(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!K
M871A;&]G87,@;F5E9WII<W1U;VIA+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%T;W-T;V=O
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L
M:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")287-T;W,@
M=&5I<VEN9V]S('9I971O=NMS.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B1V%L
M:6]J:6UA<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RXB"FUS9W-T<B`B4F5I:_!MZR!M:6YU=.MM:7,@;G5O(&1A8F%R+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*
M;7-G<W1R(")296EK\&WK<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E)E:6OP;>MS(&GP(&MU<FGX
M(&=A;&EM82!P87-I<FEN:W1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N
M=6%T=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B2VEN=&%N
M=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@
M(E9E;F5S=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S
M86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B4&%T
M=FER=&EN:6UA<R!N96)A:6=T87,@+2#P:7,@;&%I\&MA<R!S=6=A9&EN=&%S
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS
M9VED(")697)S:6]N(@IM<V=S='(@(E9E<G-I:F$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`B5F5R<VEJ^"!K;VYT<F]LZR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L
M(&%L:6=N(@IM<V=S='(@(DQY9VEU;W1I('9E<G1I:V%L:6%I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B
M5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")697)T:6MA;'5S('1A<G!A<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6MA;'5S.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B3&%B86D@9&ED96QI<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86UA<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(E9I971N86UI971I\&MA("A625-#24DI(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B4&5R_FG[<NMT:2`E<R(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N
M86P@=V5B('!A9V4B"FUS9W-T<B`B4F]D>71I(&GP;W)I;N$@<'5S;&%PX2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E!E<OYI^W+K
M=&D@:V%I<"`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H(@IM<V=S='(@(D)R:73X(%9I<F3^:6YI:F]S('-A;&]S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B2D%6(%9I<F3^:6YI:F]S('-A;&]S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B36%T
M;VUU;6%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM
M<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(DUA=&]M=6UA<SH@(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O
M9&%F;VYE($ET86QI:F$@<&5R(%--5%`B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(E=!4DXB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B1,M-15-)
M3R$A(2!005194R!)T%1224Y+251%(%-+4DE05,`@2=`@)7,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*(RP@9G5Z>GD*
M;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@<&5R($A4
M5%`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*
M;7-G<W1R(")686QI<R!I<B!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B
M1.MM97-I;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(E1R9>@N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C
M87-T(@IM<V=S='(@(D]R^"!P<F]G;F]ZZR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E
M9"!B>2(*;7-G<W1R(")/<O@@<')O9VYO>NL@<&%G86PB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S
M='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*
M;7-G:60@(E=E8B(*;7-G<W1R(")75U<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R(")75U<@<'5S
M;&%P:7,B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B2V%S('-A=F%I=.8B"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M
M92(*;7-G<W1R(")3=F5I:VDB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")3=F5I:VD@871V
M>6OF(.$@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B3&%B87,L("5S(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I
M(@IM<V=S='(@(E9A:V%R^"`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM
M<V=S='(@(E9A:V%R^"`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E9A:V%R^"!386-H87)A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R
M(&QO9VEN/R(*;7-G<W1R(")+;VOA(&UO9'5LX2`E<R!T=7)I(')O9'ET:2!P
M;R!P<FES:6IU;F=I;6\_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M(@IM<V=S='(@(DMO:W,@<VMI<G1U:V\@<VEM8F]L:7,_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B2V]K<R!K86)UZ&GX('-I;6)O;&ES
M/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#8Q"B,L(&9U>GIY"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS
M9W-T<B`B075S=')A;&EJ82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM
M<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(DMU<FEO<R!F87KK<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I
M;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T
M<B`B2%1-3"!R961A:W1O<FEA=7,@;6]D=6QI^"#A:G5N9VEM87,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B4&QO=&ES(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S
M(@IM<V=S='(@(E!L;W1I<R!#4U,@;6%T86ES(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3HB"FUS9W-T<B`B)7,@:V%I<FEO:F\@;65N:74@<&QO=&ES("AP
M86ME:71I;6%I(&)U<R!M871Y=&D@<&\@:VET;R!P<FES:6IU;F=I;6\I.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B3&5N=&5LZW,@
M<&QO=&ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B4&QOZ&EO(&UA
M=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R(")0;&]T:7,Z(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R
M(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0HC+"!F=7IZ
M>0IM<V=I9"`B5VEN9"(*;7-G<W1R(")6ZVIA<SHB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R("),:65T=7,@<GET92(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS
M9W-T<B`B5NMJ;R!G<F5I=&ES(&UA>F=A:7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5NMJ87,Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@
M(@IM<V=S='(@(E;K:F%S.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("))\&UI;G1I<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*(RP@9G5Z>GD*;7-G:60@(E=I<VAL
M:7-T(@IM<V=S='(@(E!A9V5I9&%V:6UA:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")$87)B87,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@
M(E=O<FL@061D<F5S<R(*;7-G<W1R(")$87)B;R!A9')E<V%S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B
M5V]R:R!0:&]N92(*;7-G<W1R(")$87)B;R!T96QE9F]N87,B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(E-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I
M(%9&4R!F86ELX"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S
M"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S('!A9W)I;F1I;FEA:2!N=7-T
M871Y;6%I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B
M6#4P.78S(&GP<&SK<W1O(')A:W1O('!A;F%U9&]J:6UA<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R!A;'1E
M<FYA='EV=7,@=F%R9&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R(@IM<V=S='(@(E@U,#EV,R!R86MT;R!I9&5N=&EF:6MA=&]R:75S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@
M(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!M;V1U;&EA:2(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")9
M62(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M-0IM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M
M87`B"FUS9W-T<B`B66%H;V\A(/YE;>ML87!I<R(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*
M;7-G<W1R(")+87-M970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*
M;7-G<W1R(")*96UE;F%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(E1A:7`B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(E1A:7`L(&'P('-U=&EN:W4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R
M"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB
M2OMS(&5S871E(%1%2U-424Y)04U%(%)%WDE-12X@3F]RZV1A;6D@9W+A_G1I
M(.$@5UE325=91R!S<&%U<VMI=&4@6SP^72XB"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS
M9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")*^W,@
M;F5P<FES:6IU;F?F+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B4V%V;R!V87)D
M92!N96=A;&ET92!N875D;W1I('-I;6)O;&EO("=<7"<N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N(@IM<V=S='(@(L%V963K=&4@;F5T96ES:6YGX"!E;"X@<&'P
M=&\@861R97/@+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R(").97!R:6IU;F?K=&4@:F]K
M:?@@;&%U:_@@:?`@X6ME;&EA;6\@9F%I;&\@<')I92`E<R!A=&ET:6YK86WX
M(&QA=6OX+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I
M9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")*^W,@871S
M:6IU;F?K=&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM
M<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@
M(B(*(E1U<FET92#A=F5S=&D@=&5I<VEN9^`@=&5L969O;F\@;G5M97+A("AT
M:6L@<VMA:>AI=7,@:7(@)RLG+"!J96EG=2!N;W)I=&4@(@HB;G5R;V1Y=&D@
M=&%R<'1A=71I;N$@:V]DX"DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92XB"FUS9W-T<B`BP79E9.MT92!N971E:7-I;F?@(')E:6OP;>8N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+B(*;7-G<W1R("(B"B).;W+K9&%M:2!N875G;W1I<R!R96=I<W1R86-I
M:F]S('-I<W1E;6$L('1U<FET92!S=6MO;F9I9_MR=6]T:2!D=6]M96[X("(*
M(FUE9/YI;R!P;W-I<W1E;>8N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HT-38*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"B).;W+K9&%M:2!N875G;W1I<R!R
M96=I<W1R86-I:F]S('-I<W1E;6$L('1U<FET92!S=6MO;F9I9_MR=6]T:2!D
M=6]M96[X("(*(FUE9/YI;R!P;W-I<W1E;>8N(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+B(*;7-G<W1R(")0<FEE\"!S:?AS9&%M:2!P<F%N9?!I;>`L(&%P
M<F'P>6MI=&4@<')O8FQE;>`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(L%R8?!Y
M:VET92!N=6]R;V1O<R!54DPB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+B(*;7-G<W1R(")4=7)I=&4@<&%S:7)I;FMT:2!S97)V97+A
M+"!K=7+A(&YO<FET92!I\'1R:6YT:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N(@IM<V=S='(@(DYU<F]D>6MI=&4@=F%R=&]T;VIO('9A<F3@+"!K
M=7)I;R!D=6]M96YI<R!T<FEN871E+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`B3G5R;V1Y:VET92!V87)T;W1O:F\@=F%R9.`@=')Y;FEM
M=6DN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DYU<F]D>6MI=&4@:W5R:6%M;R!V
M87)T;W1O:F\@=F%R9.`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM
M<V=S='(@(DYU<F]D>6MI=&4@871N875J:6YA;6\@=F%R=&]T;VIO('9A<F3@
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F
M;W)M+B(*;7-G<W1R(").=7)O9'EK:71E('9E:6MS;>`N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@
M(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B
M2OMS('1U<FET92#A=F5S=&D@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI
M;>`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A
M;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(E<R!S97-I:F$@8F%I9^MS:2X@4')A\&]M92!P<FES:6IU;F=T:2!I
M\"!N875J;RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(DK[<_@@96PN
M('!A\'1O(&%D<F5S87,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M,@IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")%;"X@<&'P
M=&\@861R97-A<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I:F$@87!I92!*=7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B).=6\@)7,@<V5S:6IO<R!P<F%D_FEO<R!J^W/X($E0(&%D<F5S
M87,@<&%S:6ME:73K+B!4=7)I=&4@<')I<VEJ=6YG=&D@:?`@(@HB;F%U:F\N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R(")*^W/X('9A<F1A<R]P879A<F3K(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S
M='(@(B(*(DK[<_@@<VES=&5M;W,@875T96YT:69I:V%V:6UO('!O<VES=&5M
MZR!N97!A;&%I:V\@=F%R=&]T;VKX(&O[<FEM;RP@87)B82#P:2`B"B)G86QI
M;7EBZR!I\&IU;F=T82!DZVP@=&%M('1I:W+X('!R:67^87/H:?@N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(DK[<_@@
M875T96YT:69I:V%V:6UO('-I<W1E;6$@;F5P86QA:6MO('9A<G1O=&]J^"!S
MX')A\&\L(&%R8F$@\&D@9G5N:V-I:F$@(@HB=?YD<F%U<W1A(&3K;"!T86T@
M=&EK<O@@<')I9?YA<^AI^"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P
M<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B).=6\@)7,@<V5S
M:6IO<R!P<F%D_FEO<R!J^W/X(&YA<O!Y:VSK<R!T:7!A<R!P87-I:V5I=.LN
M(%1U<FET92!P<FES:6IU;F=T:2`B"B)I\"!N875J;RXB"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")*^W/X(&YA<O!Y:VSK
M(&YE<&%L86EK;R#P:6]S(&=A;&EM>6+K<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@
M(B(*(DK[<_@@;F%R\'EK;.L@;F5P86QA:6MO(/!I;R!S<&%U<V1I;FEM;R!N
M=7-T871Y;6\N($YO<NMD86UI(&%T<W!A=7-D:6YT:2`B"B)S<&%U<VMI=&4@
M0V]N=')O;"]/<'1I;VX@*R!0+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(DK[<_@@;&%I:V\@:G5O<W1A.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B
M965N(&-H86YG960N(@IM<V=S='(@(DK[<_@@<W1A;F1A<G1I;FES(&%P<F'P
M87,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")*^W/X('-T86YD87)T:6YI
M<R!A<')A\&%S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*;7-G
M:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")*^W/X('9A<F1A<R]P879A
M<F3K.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(DK[
M<_@@;G5S=&%T>6UA:2!A=&YA=6II;G1I+B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B2OMS^"!N875J87,@
M)7,@<VQA<'1A_F]D:7,@>7)A.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN(@IM<V=S='(@(DK[<_@@;G5S=&%T>6UA:2!A=&YA=6II;G1I+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(DK[<_@@
M;G5S=&%T>6UA:2!A=&YA=6II;G1I+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T(@IM<V=S='(@(DK[<_@@<VQA<'1A_F]D:7,@<&%K96ES=&%S(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B
M"B)*^W/X('-L87!T8?YO9&ES('!A:V5I<W1A<RX@4&%S:71I:W)I;FMI=&4@
M<V%V;R!P8?!TX"!I<B!P<FES:6IU;FMI=&4@<W4@(@HB;F%U:G4@<VQA<'1A
M_F]D_FEU+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T
M<B`B2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E
M<G,Z(@IM<V=S='(@(DK[<_@@;G5T;VSF('-E<G9E<FEA:3HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S
M;&%V:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<F%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)VZR(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B16YE
M<F=I;F=O<R(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG
M:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*
M;7-G<W1R(");4&%S;.MP=&D@8VET=6]J86W@('1E:W-TX%TB"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*
M;7-G<W1R(");4')O8FQE;6]S('!R86YE\&EM87-=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6U)O9'ET:2!C:71U;VIA;>`@=&5K<W3@
M("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H
M='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM2;V1Y=&D@8VET=6]J
M86W@('1E:W-TX"`M("5S(&5I;'5T97-=(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@
M;V8@)7-=(@IM<V=S='(@(EME:6QU=.L@)7,@:?`@)7-=(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?5F%L
M9'EM87,B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(E]$=6]M96[X(&UE9&ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L
M971E(%)O=R(*;7-G<W1R(")?2?!T<FEN=&D@96EL=73F(@H*(SH@;&EB+V%P
M:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(D=?<G5PZW,B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?
M2&5L<"(*;7-G<W1R(")085]G86QB82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7U!A=F5I:W-LZVQI;R!N=7-T871Y
M;6%I+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")0<FES:5]J=6YG=&DB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G
M(&]U="(*;7-G<W1R(")!='-I7VIU;F=T:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO
M9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]+96ES=&D@;G5O<F]DX"XN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P
M=&EO;G,B"FUS9W-T<B`B7TYU<W1A='EM86DB"@HC.B!L:6(O87!I+G!H<#HQ
M,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?5&5I<^MS(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7TGP=')I;G1I
M(&YU;W)O9.`N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U
M<"(*;7-G<W1R(")?2V]N9FEG^W)A8VEJ82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A
M8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7TQE;G1E;.MS(&YU<W1A='EM
M86DN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G
M<W1R(")67V%R=&]T;VIA:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(Q"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97/X(&MN
M>6=E;.LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M-`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B
M861R97/X(&MN>6=E;.LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDQ,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD;W)I=7,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(G)A;75S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G
M:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A
M;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G
M<W1R(")S<&%U<VMI=&4@Z&EA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*
M;7-G<W1R("(E<R!N=7-T871Y;6%I(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE
M(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R
M"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@
M;F5R87-T87,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B:W)E;G1A(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"FUS9VED(")F:6QE
M(@IM<V=S='(@(F9A:6QA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@
M)7,@)7,B"FUS9W-T<B`B;G5O("5S("@E<RD@)7,@)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(BP@9_MS:6%I("5S("5S(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T
M<B`B83HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T
M<B`B='5O:F%U('!A="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
M<&%P<F%S=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I
M;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=
M(@IM<V=S='(@(F5I;'5T97-=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*
M;7-G<W1R(")M:VES;V9S(&ML86ED;W,@:V]D87,@)60@8F5D87)A;G0@25-/
M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B
M;F%M92(*;7-G<W1R(")V87)D87,B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP
M:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;F5R96%L
M:7IU;W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(F1A<B!N
M97)E86QI>G5O=&$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")U_G)A\/@@:VYY9V5LZR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<')O8V5N=&%I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E1E:7/K<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*
M;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:6MS96QI86DB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T
M<B`B:WEL82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,30R"B,L(&9U>GIY"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S
M='(@(D]R;R!SX&QY9_@@8FQO:V\@;NMR82XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@
M(G)O9'ET:2!S:VER='5M=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(
M5%10(@IM<V=S='(@(G-M<S)E;6%I;"!P97(@2%144"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B<W1A8FEL:2(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F
M(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B
M=&%S:R!L:7-T(@IM<V=S='(@(F1A<F+X('/@<F'P87,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y
M(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R(")+
M:65K=FEE;F\@<')I<VEJ=6YG:6UO(&UE='4B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(G-L87!T8?YO9.$@='5R:71E(.%R8?!Y=&D@9'4@:V%R='5S(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEK=6]T:2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`B9&%L:7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S
M='(@(G9A<G1O=&]J;R!P87-I<FEN:VEM87,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S
M='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B<#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS
M9W-T<B`B=V5A=&AE<BYC;VTB"@``+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P;R]D95]$12YP;P``````````````````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P-S4P,#0P`#$P-3$U-#,Q,#8S`#`Q-C,S,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C($=E<FUA
M;B!T<F%N<VQA=&EO;G,@9F]R($AO<F1E('!A8VMA9V4*(R!'97)M86X@;65S
M<V%G97,@9F]R($AO<F1E+@HC($-O<'ER:6=H="`H0RD@,C`P,2TR,#`V($AO
M<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/BP@,C`P,2TR,#`V+@HC"B,@;6%R
M9VEN.B!!==]E;F%B<W1A;F0*(R!P861D:6YG.B!);FYE;F%B<W1A;F0*(R!(
M:7-T;W)Y.B!#:')O;FEK"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)
M9"U697)S:6]N.B!(;W)D92`S+C$M8W9S7&XB"B)297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#8M,#<M,S$@,3@Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-BTP."TP.2`Q-CHT-2LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^7&XB"B),86YG=6%G92U4
M96%M.B!'97)M86X@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E
M<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@W"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H
M=F]R("5S(%1A9V5N*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS
M9W-T<B`B("A:=6=R:69F<W1A<W1E("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D
M87ES*2(*;7-G<W1R("(@*&EN("5S(%1A9V5N*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S.3$*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H
M:&5U=&4I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y,PIM<V=I
M9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AM;W)G96XI(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,X.0IM<V=I9"`B("AY97-T97)D87DI(@IM
M<V=S='(@(B`H9V5S=&5R;BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*
M;7-G<W1R("(@;6ET("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C(R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E
M8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!I<W0@:V5I;B!697)Z96EC:&YI<RXB
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C@T"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@
M(EPB)7-<(B!I<W0@:V5I;F4@9_QL=&EG92!!=7-W86AL+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S`W"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@:7-T(&EN(&1E<B!(;W)D92!2
M96=I<W1R>2!N:6-H="!K;VYF:6=U<FEE<G0N(@H*(SH@9G)A;65W;W)K+U1R
M964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B1&5R($)A=6TM4F5N
M9&5R97(@9OQR(%PB)7-<(B!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(B!W=7)D92!Z=6T@1W)U<'!E;G-Y<W1E;2!H:6YZ=6=E9OQG="XB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@>G5M(%)E8VAT97-Y<W1E;2!H
M:6YZ=6=E9OQG="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB('=U<F1E
M(&YI8VAT(&5R<W1E;&QT.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR
M9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"("@E,R0N,F8E
M)2D@=F]N("4R)"XR9DU"(&5R;&%U8G1E;B!V97)B<F%U8VAT(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@=6YD("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N
M=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B26X@)60@5&%G
M96X@=VER9"!):'(@4&%S<W=O<G0@=6YG_&QT:6<N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M5&%G92U6;W)H97)S86=E(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@2&EN=V5I<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S($9I;F=E
M<F%B9')U8VLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-#(@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B)7,@5V%R='5N9W-A<F)E:71E;B`M($)E<W3D=&EG=6YG(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S
M='(@(B5S+4MO;F9I9W5R871I;VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@
M57`B"FUS9W-T<B`B)7,@4F5G:7-T<FEE<G5N9R(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M
M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@3G5T>G5N9W-B961I;F=U;F=E
M;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#4P(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3$V"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C@Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8R"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E
M<R!E>&ES=&EE<G0@8F5R96ET<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$V,2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-R!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T,0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E
M<R(*;7-G<W1R("(E<R!M:70@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R
M("(B"B(E<R!W:7)D(&1I92!787)T=6YG<V%R8F5I=&5N(&1U<F-H9OQH<F5N
M+"!D:64@=6YT96X@;6%R:VEE<G0@<VEN9"X@36%R:VEE<F5N("(*(E-I92!A
M;&QE($%U9F=A8F5N+"!D:64@:F5T>G0@9'5R8VAG96;\:')T('=E<F1E;B!S
M;VQL96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!I
M<W0@;F]T=V5N9&EG(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!-:6YU
M=&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C$S,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(B5S(&YI8VAT(&=E9G5N9&5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@
M;V8@)7,B"FUS9W-T<B`B)7,@8FES("5S('9O;B`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.34R"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S<R!!9')E<W-B=6-H(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<W,@2V%L96YD97(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7-S($YO=&EZ8FQO8VLB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDV,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S<R!!=69G86)E
M;FQI<W1E(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@
M8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK
M<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P
M97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z($1I97-E($YA
M8VAR:6-H="!S=&%M;70@=6YT97(@56US=.1N9&5N(&YI8VAT('9O;B!D96T@
M86YG96=E8F5N96X@(@HB06)S96YD97(N($9O;&=E;B!3:64@:V5I;F5N($QI
M;FMS(&EN(&1I97-E<B!.86-H<FEC:'0@=6YD(&C\=&5N(%-I92!S:6-H("(*
M(F1A=F]R+"!D96T@06)S96YD97(@<&5R<_9N;&EC:&4@1&%T96X@<')E:7-Z
M=6=E8F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T
M:6YG("(*;7-G<W1R("(L(&+V:6<@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3`@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@8FEG("5S("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@<V-H=V%N
M:V5N9"!V;VX@)7,@8FES("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,30V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HW-#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M
M+2!!=7-WY&AL96X@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G
M:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R+5-T=6YD96XM1F]R;6%T
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O
M<FUA="(*;7-G<W1R("(R-"U3='5N9&5N+49O<FUA="(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R
M-"!3='5N9&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ:=7+\8VLB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")&<B!D:65S96X@
M0FQO8VL@=VER9"!E:6YE($1A=&5N8F%N:R!B96YT:6=T+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")%:6X@<V-H=V5R97(@1F5H;&5R(&ES
M="!A=69G971R971E;CHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HY-#0*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E;G1L
M:6-H97(@4$=0+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L
M=6YG(&5I;F5R($YA8VAR:6-H="`B"B)B96[V=&EG="XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<W"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@
M=VER9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R("(*(G5N=&5R>F5I8VAN
M971E;B!.86-H<FEC:'0@8F5N]G1I9W0N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$P.`IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V
M9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!01U`M4V-H;/QS<V5L('-O
M=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B`B"B)D:64@16YT<V-H;/QS<V5L
M=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#(U"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB16EN
M(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'4"U38VAL_'-S96P@
M<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR("(*(F1I92!5;G1E<GIE:6-H
M;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@<')I=F%T97(@4R]-
M24U%+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@=VER9"`B"B)F_'(@
M9&EE($5N='-C:&S\<W-E;'5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M
M97-S86=E+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@
M<')I=F%T97(@4R]-24U%+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@
M=VER9"`B"B)F_'(@9&EE(%5N=&5R>F5I8VAN=6YG(&5I;F5R($YA8VAR:6-H
M="!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT
M;&EC:&5R(%,O34E-12U38VAL_'-S96P@=VER9"!F_'(@9&EE(%9E<G-C:&S\
M<W-E;'5N9R!E:6YE<B`B"B).86-H<FEC:'0@8F5N]G1I9W0N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(E9O<FUI='1A9W,@5V]L:V5N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI
M9VAT(%)A:6XB"FUS9W-T<B`B5F]R;6ET=&%G<R!L96EC:'1E<B!296=E;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS
M9VED(")!32!,:6=H="!3;F]W(@IM<V=S='(@(E9O<FUI='1A9W,@;&5I8VAT
M97(@4V-H;F5E9F%L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$R"FUS9VED(")!32!286EN(@IM<V=S='(@(E9O<FUI='1A
M9W,@4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,PIM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")6;W)M:71T86=S
M(%-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E9O<FUI
M='1A9W,@4V-H;F5E<V-H875E<B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I
M9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@
M961I=&]R(@IM<V=S='(@(MQB97(@9&EE<V5N($5D:71O<B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4T"FUS9VED(")!8F]U="XN+B(*;7-G<W1R
M("));F9O+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D%B<V]L=70@
M56YT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B06)S;VQU="!-:71T
M92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR.#$*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B6G5G<FEF9B!V97)W96EG97)T(&)E:6T@06YL96=E;B!D97,@5D93+59E
M<GIE:6-H;FES<V5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,S4*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M(@IM<V=S='(@(EIU9W)I9F8@=F5R=V5I9V5R="!B96EM($%N;&5G96X@9&5R
M(%9&4RU$871E:2XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")+;VYT;VEN9F]R;6%T
M:6]N96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C
M8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B2V]N=&]P87-S=V]R="(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM
M<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(DMO;G1O(&5I;F=E9G)O
M<F5N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@
M(D%C8V]U;G1I;F<B"FUS9W-T<B`B0G5C:&AA;'1U;F<B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")(:6YZ=6;\9V5N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,S$@861M:6XO9W)O=7!S+G!H<#HR,S(*;7-G:60@
M(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(").975E(%5N=&5R9W)U<'!E(&AI
M;GIU9OQG96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(DYE=64@56YT97)R96-H=&4@:&EN
M>G5F_&=E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED
M(")!9&0@2&5R93HB"FUS9W-T<B`B2&EE<B!H:6YZ=6;\9V5N.B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#8*;7-G:60@(D%D9"!-
M96UB97)S(@IM<V=S='(@(DUI=&=L:65D97(@:&EN>G5F_&=E;B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED
M(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(DYE=64@1W)U<'!E(&AI;GIU9OQG
M96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R(").975E(%)E8VAT92!H:6YZ=6;\9V5N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS
M9W-T<B`B56YT97)G<G5P<&4@>G4@7"(E<UPB(&AI;GIU9OQG96XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G
M<W1R(")5;G1E<G)E8VAT92!Z=2!<(B5S7"(@:&EN>G5F_&=E;B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T
M<B`B1OQG96X@4VEE(&5I;F5N(&YE=65N($)E;G5T>F5R(&AI;GIU.B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G
M:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B4W!A;'1E(&AI;GIU9OQG96XB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I
M<B(*;7-G<W1R(")086%R(&AI;GIU9OQG96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8T"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")$87,@)7,M365N
M_"!Z=7(@36]Z:6QL82!3:61E8F%R(&AI;GIU9OQG96XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T
M;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(EIU;2!!9')E<W-B=6-H(&AI;GIU
M9OQG96XZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@
M(EIU(&UE:6YE;2!!9')E<W-B=6-H(&AI;GIU9OQG96XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B0F5N=71Z97(@
M:&EN>G5F_&=E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M(@HB)7,N(@IM<V=S='(@(B(*(EPB)7-<(B!W=7)D92!Z=6T@4WES=&5M(&AI
M;GIU9V5F_&=T+"!A8F5R(&1I92!Z=7/D='IL:6-H96X@(@HB4F5G:7-T<FEE
M<G5N9W-I;F9O<FUA=&EO;F5N(&MO;FYT96X@;FEC:'0@9V5S<&5I8VAE<G0@
M=V5R9&5N.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO
M9R!I;B!N;W<N(@IM<V=S='(@(EPB)7-<(B!W=7)D92!Z=6T@4WES=&5M(&AI
M;GIU9V5F_&=T+B!3:64@:_9N;F5N('-I8V@@:F5T>G0@86YM96QD96XN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B1&%S($AI;GIU9OQG
M96X@=F]N($)E;G5T>F5R;B!I<W0@;FEC:'0@;?9G;&EC:"XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!
M9')E<W-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V)U8V@B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B5F5R=V%L=&5N("T@4F5C:'1E(&;\<B!A;F1E<F4@0F5N=71Z97(@9F5S
M=&QE9V5N(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3<*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(E=E<F)U;F<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=H86YI<W1A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9V5R:65N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B4W!I='IN86UE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B06QI9VXB"FUS9W-T<B`B075S<FEC:'1U;F<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE
M;G0Z(@IM<V=S='(@(D%U<W)I8VAT=6YG.B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8V"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*
M;7-G<W1R(")!;F=E;65L9&5T92!"96YU='IE<B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C@*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`B06QL92!'<G5P<&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R
M964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B06QL
M92!296-H=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R
M(")!;&QE('9I97(@4V5I=&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@X.0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S
M='(@(DUE:')E<F4@061R97-S96X@97)L875B96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,Q"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/R(*;7-G<W1R(")&;W)M870@=F]N(&YU;6UE<FEE<G1E
M;B!,:7-T96X@Y&YD97)N/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C4P-PIM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T
M<B`B17AI<W1I97)T(&)E<F5I=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!
M;'1E<FYA=&EV92!)35-0+4%N;65L9'5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,#0*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM
M<V=S='(@(D%L=&5R;F%T:79E<R!)35-0+5!A<W-W;W)T(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y-@IM<V=I9"`B06QT97)N871E($E-4U`@57-E
M<FYA;64B"FUS9W-T<B`B06QT97)N871I=F5R($E-4U`M0F5N=71Z97)N86UE
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D%L
M=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L=&5R;F%T:79E($4M
M36%I;"U!9')E<W-E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N871I=F4@
M5F]R;&%G96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*
M;7-G<W1R(")!;'1E<FYA=&EV97(@5&5X=#HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;65R:6-A;B!386UO82(*;7-G<W1R(")!;65R:6MA;FES8V@M4V%M;V$B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D5S('=U<F1E(&5I;B!U;F?\
M;'1I9V5R(%=E<G0@86YG96=E8F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N(@IM<V=S='(@(D5I;B!U;F)E:V%N;G1E<B!&96AL97(@:7-T(&%U
M9F=E=')E=&5N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T
M<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R
M(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R
M(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6UE<B!0
M<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED
M(")!;G-W97(B"FUS9W-T<B`B06YT=V]R="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&ES(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A('5N
M9"!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED
M(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!;G=E;F1U;F<B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS
M9W-T<B`B06YW96YD=6YG<VQI<W1E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$S.0IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(D%N=V5N9'5N9R!I<W0@8F5R96ET+B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$Y"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`B075F(%5N=&5R<F5C:'1E(&%N=V5N9&5N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS
M9W-T<B`B0F5S=.1T:6=E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@T,@IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R
M(")5;F=E9N1H<F4@1W+VWV4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B07!R:6PB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A8FEC("A7
M:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)I<V-H("A7:6YD;W=S+3$R-38I
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI
M=F4@1FEL92!3:7IE(@IM<V=S='(@(D%R8VAI=F=R]M]E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G
M<W1R(")!<F-H:79N86UE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/R(*;7-G<W1R("(B"B)3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE
M(&1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S(&SV<V-H96X@;?9C
M:'1E;C\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@
M(B(*(E-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@7"(E<UPB('5N9"!A;&QE
M(%5N=&5R9W)U<'!E;B!L]G-C:&5N(&WV8VAT96X_(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN:65N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FUE;FEE;B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*;7-G<W1R(")!<FUE;FES8V@@*$%235-#24DM."DB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")+=6YS
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS
M:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I;VXM26YS96QN(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T
M<B`B05-#24DM2W5N<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07-I
M96XO4&%Z:69I<V-H92!296=I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#(R"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B06YS=&5H96YD
M92!787)T=6YG<V%R8F5I=&5N(&)E<W3D=&EG96X@;&%S<V5N/R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@
M8V]L=6UN<R(*;7-G<W1R("):=6]R9&YU;F=S9F5L9&5R(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(D5S('=U<F1E('9E<G-U8VAT+"!E
M:6YE(&YI8VAT(&5X:7-T:65R96YD92!'<G5P<&4@>G4@;/9S8VAE;BXB"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")%
M<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R96YD97,@4F5C
M:'0@>G4@;/9S8VAE;BXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(D5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI
M<W1I97)E;F1E<R!296-H="!Z=2!B96%R8F5I=&5N+B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")%<R!W=7)D92!V97)S=6-H
M="P@96EN(&YI8VAT(&5X:7-T:65R96YD97,@4F5C:'0@>G4@8F5A<F)E:71E
M;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R(")!='1R:6)U=&4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S
M='(@(D%U9W5S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G
M<W1R(")!=7-T<F%L:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*
M;7-G<W1R("+6<W1E<G)E:6-H(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ
M($1I92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G
M969U;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@1&%S
M($)A8VME;F0@:&%T(&YI8VAT(&1I92!B96[V=&EG=&5N($;D:&EG:V5I=&5N
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I
M9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!$:64@8F5N]G1I9W1E($E-05`M
M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*
M(D%U=&A?9G1P.B!$:64@8F5N]G1I9W1E($944"U%<G=E:71E<G5N9R!W=7)D
M92!N:6-H="!G969U;F1E;BX@2V]M<&EL:65R96X@(@HB4VEE(%!(4"!M:70@
M9&5M("TM96YA8FQE+69T<"!087)A;65T97(N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I;6%P+G!H<#HV,`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA
M<#H@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT
M(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z($1I92!B96[V=&EG=&4@
M2V5R8F5R;W,M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U
M=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!$87,@2&EN
M>G5F_&=E;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O
M<GD@;FEC:'0@(@HB=6YT97)S=/QT>G0B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM
M<V=S='(@(B(*(D%U=&A?;&1A<#H@1&%S($SV<V-H96X@=F]N($)E;G5T>F5R
M;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT("(*(G5N=&5R<W3\
M='IT(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I
M9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@1&EE(&)E;O9T:6=T92!,1$%0+45R
M=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P.B!$
M97(@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&AI;GIU9V5F_&=T('=E<F1E
M;BX@365L9'5N9R!D97,@(@HB4V5R=F5R<SH@(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T
M:%]L9&%P.B!"96YU='IE<B`E<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!"96YU='IE<B`E<R!K;VYN
M=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@1&%S($%K='5A;&ES:65R96X@
M=F]N($)E;G5T>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT
M("(*(G5N=&5R<W3\='IT+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A
M;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($1I92!B96[V
M=&EG=&4@34-!3"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z($1I92!B96[V=&EG=&4@4V%M
M8F$M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`S"FUS9VED(")!=71H96YT
M:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%N;65L
M9'5N9R!B96EM($E-05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D%U=&AE;G1I
M9FEZ:65R=6YG(&9E:&QG97-C:&QA9V5N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")!
M;FUE;&1U;F<@9F5H;&=E<V-H;&%G96XN("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@
M<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B1&EE($%U=&AE
M;G1I9FEZ:65R=6YG('=U<F1E('9O;2!2041)55,M4V5R=F5R('IU<OQC:V=E
M=VEE<V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#DT"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B06YM96QD=6YG(&)E:6T@1E10+5-E<G9E<B!F96AL9V5S8VAL86=E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(D%N;65L9'5N9R!B96EM(%--0BU397)V97(@9F5H;&=E<V-H;&%G96XN
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A
M:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B5F5R9OQG8F%R92!&96QD97(Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!<V5R8F%I
M9'-C:&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"
M3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"U!=7-R961E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B2&EN=&5R9W)U;F0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"
M86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(DAI;G1E<F=R=6YD9F%R8F4B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(D9A;'-C:&5S($ME<F)E<F]S
M+5!A<W-W;W)T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B1F%L
M<V-H97(@2V5R8F5R;W,M0F5N=71Z97)N86UE+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F5I;B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G
M<W1R(")"86QT:7-C:"`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-C:"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D)A<VES+4)I;&1E<BU697)Z96EC:&YI<R!<(B5S7"(@;FEC:'0@9V5F
M=6YD96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")'<G5N9&QI
M;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")796G?
M<G5L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"
M96QG:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E
M;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q
M"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")'96)U<G1S=&%G(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0FQO8VL@7"(E<UPB(&1E<B!!;G=E
M;F1U;F<@7"(E<UPB(&YI8VAT(&=E9G5N9&5N+B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS
M9W-T<B`B0FQO8VME:6YS=&5L;'5N9V5N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(D)L
M;V-K='EP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(D9E='0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:65N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S
M='(@(DQE<V5Z96EC:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(E)A;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")286AM
M96YD:6-K93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(E+D;F1E
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B
M"FUS9W-T<B`B0F]S;FEE;BU(97)Z96=O=VEN82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")"96ED97,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(E5N=&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V971I;G-E;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%S:6QI96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(D)R:71I<V-H97,@5&5R<FET;W)I=6T@:6T@26YD
M:7-C:&5N($]Z96%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S
M<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QG87)I96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(E5N;G5M;65R:65R=&4@3&ES=&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN
M82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"
M=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),($1I<W1R:6)U
M=&EO;G-S=&5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B7UIE;&QE;F5I9V5N<V-H869T96XN+BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(")$97(@6G=I<V-H96YS<&5I
M8VAE<B!K;VYN=&4@;FEC:'0@:6YI=&EA;&ES:65R="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-#(@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`U,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED
M(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B5VEN
M9'-T:6QL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(DMA;6)O9'-C:&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G
M<W1R(")+86UE<G5N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED
M(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N
M(@IM<V=S='(@(D5X=&5R;F4@4V5S<VEO;BU(86YD;&5R(&OV;FYE;B!N:6-H
M="!A9&UI;FES=')I97)T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")697)B:6YD=6YG('IU;2!)34%0
M+5-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;CH@)7,B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B1&EE
M($1A=&5I(%PB)7-<(B!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B06)B<F5C:&5N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5M8F5R:6-H
M="!A8F)R96-H96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0T
M-"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S4*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(R,@IM<V=I9"`B0V%N;F]T(&-O<'D@9FEL92AS*2`M('-O=7)C
M92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE+B(*;7-G<W1R("(B"B)$
M871E:2AE;BD@:_9N;F5N(&YI8VAT(&MO<&EE<G0@=V5R9&5N("T@475E;&PM
M('5N9"!::65L9&%T96EE;B!S:6YD("(*(FED96YT:7-C:"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")$:64@1&%T
M96D@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G
M:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B2V5I;B!T96UP;W+D<F5S(%9E<GIE:6-H;FES(&=E9G5N9&5N+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3$P(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P-0HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<U,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3@W"FUS9VED
M(")#86YN;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN
M('-O=7)C92XB"FUS9W-T<B`B(@HB1&%T96DH96XI(&OV;FYE;B!N:6-H="!V
M97)S8VAO8F5N('=E<F1E;B`M(%II96QD871E:2!B969I;F1E="!S:6-H(&EM
M("(*(E%U96QL;W)D;F5R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B1F]R='-E='IU
M;F<@;VAN92!<(G1A<F=E=$9I;&5<(BU087)A;65T97(@;FEC:'0@;?9G;&EC
M:"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(D1A<R!697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI8VAT
M(&5N=&9E<FYT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DMO;FYT92!N:6-H="!E;G1F
M97)N="!W97)D96XL("5D($MI;F1E<B!E>&ES=&EE<F5N+B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8Q,0IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*(E5M<V]R=&EE<F5N(&YI8VAT(&WV9VQI8V@N($1I92!!;GIA
M:&P@9&5R($5I;G1RY&=E+"!D:64@=6US;W)T:65R="!W97)D96X@(@HB<V]L
M;&5N+"!S=&EM;70@;FEC:'0@;6ET(&1E<B!!;GIA:&P@9&5R(&=E<W!E:6-H
M97)T96X@16EN='+D9V4@_&)E<F5I;BXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR,0IM<V=I9"`B0V%N;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"B)087-S=V]R="!K86YN(&YI8VAT(&%U=&]M871I<V-H('IU<OQC
M:V=E<V5T>G0@=V5R9&5N+"!B:71T92!W96YD96X@4VEE('-I8V@@(@HB86X@
M26AR96X@061M:6YI<W1R871O<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*(D1I
M92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&%N(&1I92!A;F=E9V5B92!.=6UM
M97(@=V5I=&5R9V5L96ET970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B1&EE($1A=&5I(%PB)7-<
M(B!K86YN(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM
M<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+<8F5R<V-H<FEF="(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R(")0<F]V:61E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S
M='(@(DMA=&5G;W)I96X@=6YD($)E<V-H<FEF='5N9V5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA;BU);G-E
M;&XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("):96QL96YE
M:6=E;G-C:&%F=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B
M26YN96YA8G-T86YD.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R("):96QL96YE:6=E;G-C:&%F=&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A
M8VEN9SHB"FUS9W-T<B`B6F5L;&5N86)S=&%N9#HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B
M36]B:6QT96QE9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G
M:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1I<V-H("A)
M4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B6F5N
M=')I97)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC(@IM<V=S='(@(EIE;G1R86QA9G)I:V%N:7-C:&4@4F5P=6)L:6LB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B36ET=&5L975R;W#D:7-C
M:"`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("):97)T:69I:V%T9&5T86EL<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G
M<W1R("):97)T:69I:V%T8F5S:71Z97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I
M97,B"FUS9W-T<B`B6F5R=&EF:6MA=')I8VAT;&EN:65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(E1S8VAA9"(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("+$;F1E<FXB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(L1N9&5R;B!3:64@26AR(%!A<W-W;W)T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`B(@HBQ&YD97)N(%-I92!D96X@3F%M96X@;V1E<B!D:64@061R97-S92P@
M9&EE(&1I92!%;7!FY&YG97(@26AR97(@12U-86EL+2(*(DYA8VAR:6-H=&5N
M('-E:&5N+"!W96YN('-I92!D:65S92!L97-E;B!O9&5R(&1A<F%U9B!A;G=O
M<G1E;BXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G
M:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E
M9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB1&%S(,1N9&5R;B!)
M:')E<R!087-S=V]R=',@=VER9"!V;VX@9&EE<V5M(%-Y<W1E;2!Z=7(@6F5I
M="!N:6-H="`B"B)U;G1E<G-T_'1Z="X@0FET=&4@=V5N9&5N(%-I92!S:6-H
M(&%N($EH<F5N($%D;6EN:7-T<F%T;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*
M;7-G<W1R("):96EC:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN
M+B(*;7-G<W1R("),:6YK(/QB97)?<'+\9F5N+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EN82(*;7-G<W1R(")#:&EN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS
M9W-T<B`B0VAI;F5S:7-C:"!V97)E:6YF86-H="`H1T(R,S$R*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*2(*;7-G<W1R(")#:&EN97-I<V-H('1R861I=&EO;F5L;"`H
M0FEG-2DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#
M:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(D%N=V5N9'5N9R!A=7-WY&AL
M96XZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM
M<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B5^1H;&5N(%-I92!E
M:6X@4&%S<W=O<G0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")7Y&AL
M96X@4VEE(&5I;F5N($)E;G5T>F5R;F%M96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,CDU"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(DQE9V5N(%-I92!F97-T+"!W:64@9&%S($1A='5M(&%N
M9V5Z96EG="!W97)D96X@<V]L;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B
M3&ES=&5N9F]R;6%T(&%U<W?D:&QE;B`H9OQR(&YU;6UE<FEE<G1E($QI<W1E
M;BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S
M='(@(E=E:6AN86-H='-I;G-E;"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(DML87-S96YD969I;FET:6]N(&;\<B`E<R!N:6-H="!G969U
M;F1E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2&5I=&5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE
M87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(")-4RU/9F9I8V4M5&%G<R!E;G1F
M97)N96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED(")#;&5A
M<B!1=65R>2(*;7-G<W1R(")!8F9R86=E('IU<OQC:W-E='IE;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")"96YU='IE<F1A
M=&5N(&SV<V-H96XZ("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D)E;G5T>F5R
M9&%T96X@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B0F5N=71Z
M97)D871E;B!L]G-C:&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B
M4W#D=&5R($%U9FML87)E;F0B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B
M"FUS9W-T<B`B1F]R=&9A:')E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V
M:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('!E<B!(5%10(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B1F5N<W1E<B!S
M8VAL:67?96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@IM<V=I9"`B
M0VQO=61S(@IM<V=S='(@(E=O;&ME;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9',@16%R;'DB"FUS
M9W-T<B`B1G+\:"!7;VQK96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D)E=_9L
M:W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD
M<R(*;7-G<W1R(")+;VMO<VEN<V5L;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T
M<B`B365N_"!E:6YF86AR96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R
M9&5R<R(*;7-G<W1R("):=7-A;6UE;FCD;F=E;F1E(%)A:&UE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEE;B(*"B,Z
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")&87)B92(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S@*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*
M;7-G<W1R(")&87)B875S=V%H;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B1F%R
M8G=A:&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B4W!A;'1E;CHB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38T"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(E-P86QT96[\8F5R<V-H<FEF=&5N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(D-O;6EC<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R(")"969E:&PB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B0F5F96AL<WIE:6QE
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(DMO;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*
M;7-G<W1R(")%:6YD975T:6=E<B!.86UE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)E;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS
M9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G
M:60@(D-O;7!U=&5R<R(*;7-G<W1R(")#;VUP=71E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G
M<W1R(")"961I;F=U;F=E;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q
M"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D)E9&EN9W5N9V5N(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.3,*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`B2V]N9FEG=7)A=&EO;G-U;G1E<G-C:&EE
M9&4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,T"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")$:64@2V]N9FEG
M=7)A=&EO;B!M=7-S(&%K='5A;&ES:65R="!W97)D96XN(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`B)7,@:V]N9FEG=7)I97)E;B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@
M4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O<G0@8F5S=.1T:6=E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R(")$96UO:W)A=&ES8VAE(%)E<'5B;&EC($MO;F=O(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`T"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T-PIM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(E9E<F)I;F1U;F<@9F5H;&=E
M<V-H;&%G96XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C`T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,T-PIM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")6
M97)B:6YD=6YG(&9E:&QG97-C:&QA9V5N.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3D*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N
M9R!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E;'-E<G9E<B!W=7)D92!A8F=E
M=VEE<V5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C@P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R
M("(B"B)697)B:6YD=6YG('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R
M=F5R('=U<F1E(&%B9V5W:65S96XN($=R=6YD.B`E<R`H)7,I(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#@*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M
M($944"U397)V97(@9F5H;&=E<V-H;&%G96XB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDU,"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`W-PIM
M<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B2V]N=&%K=&4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(")$:64@2V]N=&%K=&4@=W5R9&5N(&5R9F]L9W)E:6-H
M($EH<F5M($%D<F5S<V)U8V@@:&EN>G5G96;\9W0N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T
M>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(DEN:&%L='-T>7`@
M9&5R(&MO;7!R:6UI97)T96X@1&%T96DZ("(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F
M(%PB)7-<(B(*;7-G<W1R("));FAA;'0@=F]N(%PB)7-<(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,P('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B5V5I=&5R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VLM
M26YS96QN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#
M;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM
M<V=S='(@(DMO<&EE<F5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM
M<V=S='(@(DMO<&EE<F5N(&9E:&QG97-C:&QA9V5N.B`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(D%U<W=A:&P@:V]P:65R96XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S
M="!)1"(*;7-G<W1R(")+;W-T96XM240B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D5L9F5N8F5I;FO\<W1E(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3@V"FUS9VED(")#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(D1I92!.
M86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!01U`@=F5R<V-H;/QS<V5L="!W
M97)D96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M-C0*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T
M<B`B1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!U;G1E<GIE
M:6-H;F5T('=E<F1E;CH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R(")$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M
M:70@4R]-24U%('9E<G-C:&S\<W-E;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B1&EE($YA8VAR:6-H="!K
M;VYN=&4@;FEC:'0@;6ET(%,O34E-12!U;G1E<GIE:6-H;F5T('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A
M8W0N("5S(@IM<V=S='(@(DMO;G1A:W0@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;BX@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C`*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I9"`B0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M($Q$
M05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T
M<B`B2V]N=&]S=&%N9"!K;VYN=&4@;FEC:'0@_&)E<G!R_&9T('=E<F1E;BX@
M)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8V"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN
M9'5N9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G96XN(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E
M<R(*;7-G<W1R(")&5%`M5F5R8FEN9'5N9R!Z=6T@4V5R=F5R(%PB)7-<(B!K
M;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N.B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(E9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H
M="!E<G-T96QL="!W97)D96XN("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$S-PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$Z("(*;7-G<W1R(")01U`M1&%T96X@:V]N;G1E;B!N:6-H="!E;G1S
M8VAL_'-S96QT('=E<F1E;CH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+B(*;7-G<W1R(")3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E
M;G1S8VAL_'-S96QT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMO;G1A
M:W0@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(")697)T96EL97)L:7-T92!K;VYN=&4@;FEC
M:'0@9V5L]G-C:'0@=V5R9&5N+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")$87,@
M06MT=6%L:7-I97)U;F=S<VMR:7!T(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5L
M]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDV,@IM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(D1I92!%+4UA:6PM061R97-S92!D97,@
M16UP9N1N9V5R<R!K;VYN=&4@;FEC:'0@97)M:71T96QT('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI8VAT(&MO;7!L
M971T(&=E;&5S96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(E9E<G1E
M:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3&ES=&4@9&5R(%9E
M<G1E:6QE<FQI<W1E;B!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N
M(@IM<V=S='(@(D1I92!3=')A=&5G:64@7"(E<UPB(&MO;FYT92!N:6-H="!G
M96QA9&5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(")$87,@5F5R>F5I8VAN:7,@
M7"(E<UPB(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R("+69F9E;G1L:6-H97(@4V-H;/QS<V5L(&MO;FYT92!N:6-H="!V;VT@
M4V-H;/QS<V5L<V5R=F5R(&=E:&]L="!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(EPB)7-<(B!K;VYN=&4@
M;FEC:'0@>G5M(%-C:')E:6)E;B!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M("(E<R!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,B"FUS9W-T<B`B1&%S($UA:6YT96YA;F-E7U1A<VL@36]D=6P@
M)7,@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")697)Z96EC:&YI<R!<(B5S
M7"(@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&MO
M;FYT92!N:6-H="!H97)G97-T96QL="!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O3V)J96-T+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B5S(&MO;FYT92!N:6-H="!G
M96QE<V5N('=E<F1E;BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HX-@IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*(D1A<R!087-S=V]R="!F_'(@9&5N(&%N9V5G96)E
M;F5N($)E;G5T>F5R(&MO;FYT92!N:6-H="!Z=7+\8VMG97-E='IT('=E<F1E
M;BP@(@HB=V5I;"!E:6YI9V4@06YG86)E;B!N:6-H="!R:6-H=&EG('=A<F5N
M+B!697)S=6-H96X@4VEE(&5S(&5R;F5U="!O9&5R('=E;F1E;B`B"B)3:64@
M<VEC:"!A;B!):')E;B!!9&UI;FES=')A=&]R+"!W96YN(%-I92!W96ET97)E
M($AI;&9E(&)E;O9T:6=E;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,#4*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S0V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HT,30*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z-#(P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C0R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(@IM<V=S='(@(D%#3"!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D
M96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")$87,@061R97-S8G5C:"!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(")697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@
M875S9V5L97-E;B!W97)D96XN("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B
M"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&5N(&MO;FYT92!N:6-H="!A=7-G96QE
M<V5N('=E<F1E;BX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,#0*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R.`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")$:64@4V5R=F5R9N1H:6=K96ET96X@
M:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E;B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC
M:'0@>G5R_&-K9V5S971Z="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S
M7"(N(@IM<V=S='(@(E9E<GIE:6-H;FES(%PB)7-<(B!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B5S+4MO;F9I9W5R871I;VX@:V]N;G1E
M(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T
M<B`B0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B0F%C:W5P(&1E<B!+;VYF:6=U
M<F%T:6]N(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="!K
M;VYN=&4@;FEC:'0@;F%C:"!<(B5S7"(@9V5S<&5I8VAE<G0@=V5R9&5N+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(D)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E
M<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB1&EE($MO;F9I9W5R871I;VX@
M)7,@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@4VEE(&OV;FYE
M;B!E;G1W961E<B`B"B)E:6YE(&1E<B!-]F=L:6-H:V5I=&5N('5N=&5R("5S
M('9E<G=E;F1E;BP@=6T@9&5N($-O9&4@>G4@<W!E:6-H97)N+"!O9&5R("(*
M(F1E;B!U;G1E;G-T96AE;F1E;B!#;V1E(&UA;G5E;&P@;F%C:"`E<R!K;W!I
M97)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM
M<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(D1E<B!,1$%0+5-E<G9E<B!K;VYN=&4@;FEC:'0@9'5R8VAS=6-H="!W
M97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(D1E<B!+;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W
M97)D96XN("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B5F5R=&5I
M;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&%K='5A;&ES:65R="!W97)D96XN("5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(D1I92!+;VYF:6=U<F%T:6]N(&;\<B!<(B5S7"(@
M:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8S"FUS9VED(")#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+B(*;7-G<W1R("(B"B)$:64@36]Z:6QL82!3:61E8F%R(&MO;FYT92!N
M:6-H="!G969U;F1E;B!W97)D96XN(%-T96QL96X@4VEE('-I8VAE<BP@9&%S
M<R`B"B)D:64@4VED96)A<B!G9?9F9FYE="!I<W0N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34U"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"B)$96T@0F5N=71Z97(@7"(E<UPB(&MO;FYT96X@9&EE(&9O;&=E;F1E
M(%)E8VAT92!F_'(@9&5N($]R9&YE<B!<(B5S7"(@;FEC:'0@(@HB>G5G97=I
M97-E;B!W97)D96XZ("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(D=E>N1H;'1E<B!4
M97AT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B3&%N9"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B2W5R
M<V4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")%<G-T96QL
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B3&EN
M:R!E<G-T96QL96XB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDV"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(DYE
M=64@261E;G1I=.1T(&%N;&5G96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(E5N=&5R;W)D;F5R(&5R<W1E;&QE;B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(D5R<W1E;&QE<G)E8VAT92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*
M;7-G<W1R(")+<F5D:71K87)T96YN=6UM97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B0W)O871I82(*;7-G<W1R(")+<F]A=&EE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")!:W1U96QL
M92`T(%!H87-E;B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B
M0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")!:W1U96QL92!397-S:6]N<R(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS
M,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D%K='5E;&QE(%IE:70B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D%K='5E
M;&QE(%523"!I<W0B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@
M(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B06MT=65L;&4@0F5N=71Z97(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H
M97(B"FUS9W-T<B`B06MT=65L;&5S(%=E='1E<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B1&5R>F5I=&EG92!"961I;F=U;F=E;CH@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B
M0W5R<F5N="!S='EL92(*;7-G<W1R(")!:W1U96QL97(@4W1I;"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G
M<W1R("(B"B),96=E;B!3:64@9F5S="P@=V5L8VAE($%U9F=A8F5N(&YA8V@@
M9&5R($%N;65L9'5N9R!B96D@)7,@97)L961I9W0@=V5R9&5N("(*(G-O;&QE
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")!=7-S8VAN96ED96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U
M"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(D%U<W=A:&P@875S<V-H
M;F5I9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(EIY
M<&5R;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#>7)I
M;&QI8R`H2T])."U2*2(*;7-G<W1R(")+>7)I;&QI<V-H("A+3TDX+5(I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMY<FEL;&ES8V@@*%=I;F1O=W,M,3(U
M,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(DMY<FEL;&ES8V@O56MR
M86EN:7-C:"`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E
M<'5B;&EC(@IM<V=S='(@(E1S8VAE8VAI<V-H92!297!U8FQI:R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(E14(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y,`IM<V=I9"`B(@HB1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"B)$4TX@*'-I96AE
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")4
MY&=L:6-H(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A
M5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&%4<F5E($)R;W=S97(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@X"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B1&%T96YB86YK86)F<F%G92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0Q-@IM<V=I9"`B1&%T92(*;7-G<W1R(")$871U;2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(D5M<&9A;F=S9&%T=6TB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C
M=&EO;B(*;7-G<W1R(")$871U;7-A=7-W86AL(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B5&%G(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED
M(")$95]L971E($-O;'5M;B(*;7-G<W1R(")3<&%L=&4@7VSV<V-H96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I
M9"`B1&5C96UB97(B"FUS9W-T<B`B1&5Z96UB97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED
M(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B6F%H;&5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(D5I;GIU9R!V97)R:6YG97)N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H
M<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4W1A;F1A<F0B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I
M9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")3=&%N9&%R9&9A<F)E(@H*(SH@
M9G)A;65W;W)K+U!R969S+TED96YT:71Y+G!H<#HY.`IM<V=I9"`B1&5F875L
M="!)9&5N=&ET>2(*;7-G<W1R(")3=&%N9&%R9&ED96YT:73D="(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW-0IM<V=I9"`B1&5F875L="!3:&5L;"(*
M;7-G<W1R(")3=&%N9&%R9'-H96QL(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")$969I;FET:6]N
M96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(W"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDT('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$W"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,30P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@S"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q
M"FUS9VED(")$96QE=&4B"FUS9W-T<B`B3/9S8VAE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I
M9"`B1&5L971E($-E;&PB"FUS9W-T<B`B6F5L;&4@;/9S8VAE;B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C`U(&%D;6EN+V=R;W5P<RYP:'`Z,C,S"FUS9VED
M(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B1W)U<'!E(&SV<V-H96XB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-3$*;7-G:60@(D1E;&5T92!,
M;V<B"FUS9W-T<B`B3&]G(&SV<V-H96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")296-H=&4@
M;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(DYA8VAR:6-H=&5N(&SV<V-H96X@=6YD(&5N=&9E<FYE;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*
M;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(EIE;&QE(&SV<V-H96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E-P86QT92!L]G-C
M:&5N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B0F5S=&5H
M96YD92!A;'1E<FYA=&EV92!6;W)L86=E(&SV<V-H96XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E
M(&UE<W-A9V5S(@IM<V=S='(@(DYA8VAR:6-H=&5N(&SV<V-H96XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M(")296-H=&4@9OQR(%PB)7-<(B!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_(@IM<V=S='(@(E)E8VAT92!F_'(@7"(E<UPB('5N9"!A;&QE(%5N
M=&5R<F5C:'1E(&SV<V-H96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*
M;7-G<W1R("):96EL92!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E
M;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y(@IM<V=S='(@(D%U<V=E=^1H;'1E($ED96YT:73D="!L]G-C:&5N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*
M;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")5;G1E<F]R9&YE
M<B!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN(@IM<V=S='(@(D1I92!A:W1U96QL92!3<&%L=&4@;/9S8VAE;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R
M(")$:64@86MT=65L;&4@6F5I;&4@;/9S8VAE;B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")$87,@06MT
M=6%L:7-I97)U;F=S<VMR:7!T(%PB)7-<(B!W=7)D92!G96SV<V-H="XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(D%U
M<VQI969E<G5N9W-Z96ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*
M;7-G<W1R(")$Y&YE;6%R:R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")"97-C:')E:6)E;B!3:64@9&%S(%!R;V)L96TB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B0F5S8VAR96EB=6YG(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HR,#8*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3HB"FUS9W-T<B`B1&5T86EL<R`H875C:"!I;B!(;W)D97,@3&]G9&%T96DI
M.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C$P"FUS9VED(")$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R(")$971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T
M;W(@;6ET9V5L;V=G="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")%;G1W:6-K;'5N9R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$Y"FUS9VED(")$97<@4&]I;G0B
M"FUS9W-T<B`B5&%U<'5N:W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M-@IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")4
M875P=6YK="!D97(@;&5T>G1E;B!3='5N9&4Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(E1A=7!U;FMT.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R(")6;VX@;&EN:W,@;F%C:"!R96-H=',B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")6;VX@<F5C:'1S(&YA8V@@
M;&EN:W,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER
M96-T;W)Y(@IM<V=S='(@(E9E<GIE:6-H;FES(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(V,@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R("):96ET(&EM(#(T+5-T=6YD96XM1F]R;6%T(&%N>F5I9V5N/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R(")!;GIE:6=E+45I;G-T96QL=6YG96XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@
M9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B1&5T86EL:65R=&4@5F]R:&5R
M<V%G92!A;GIE:6=E;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G
M:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B5F]R:&5R<V%G
M92`H5$%&*2!A;GIE:6=E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D%N>F5I9V5F
M;W)M870B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS
M9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B16UP9F%N
M9W-B97-TY'1I9W5N9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(D1S8VAI8G5T:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYI8VAT
M(&SV<V-H96XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G
M:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM
M<V=S='(@(D=R96EF96X@4VEE(&YI8VAT(&1I<F5K="!A=68@;6%I;G1E;F%N
M8V4N<&AP('IU(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@HB16YT:.1L="!D:64@97)S=&4@
M6F5I;&4@9&EE($9E;&1N86UE;C\@5V5N;B!J82P@9&EE<V5S($%U<W=A:&QK
MY'-T8VAE;B`B"B)M87)K:65R96XZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M
M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$
M;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:V%N:7-C:&4@4F5P
M=6)L:6LB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED
M(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(DYO
M8V@@:V5I;F5N(%IU9V%N9S\@2&EE<B!A;FUE;&1E;BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3,*;7-G:60@(D1O=VYL;V%D
M(@IM<V=S='(@(DAE<G5N=&5R;&%D96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W
M;FQO860@)7,B"FUS9W-T<B`B)7,@2&5R=6YT97)L861E;B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C$*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(D5R>F5U
M9W1E($MO;F9I9W5R871I;VX@86QS(%!(4"U3:W)I<'0@:&5R=6YT97)L861E
M;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(U"FUS9VED(")$
M<F]P(&1O=VX@;&ES="(*;7-G<W1R(")!=7-W86AL;&ES=&4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R
M;V=E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B12U-86EL(@IM<V=S='(@(D4M36%I;"(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@HB12U-86EL+6YA8V@M4TU3
M+6=A=&5W87D@9OQR(%!R;W9I9&5R+"!D:64@96EN96X@<V]L8VAE;B!$:65N
M<W0@=6YT97)S=/QT>F5N+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D52
M4B(*;7-G<W1R(")&14A,15(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R
M(@IM<V=S='(@(D5C=6%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M;7-G:60@(D5D:70B"FUS9W-T<B`B0F5A<F)E:71E;B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS
M9W-T<B`B0FQO8VL@8F5A<F)E:71E;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C`T"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(D=R=7!P92!B96%R8F5I
M=&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M
M:7-S:6]N(@IM<V=S='(@(E)E8VAT92!B96%R8F5I=&5N(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N
M<R(*;7-G<W1R(")296-H=&4@8F5A<F)E:71E;B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!0
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B4F5C:'1E(&;\<B`G)7,G(&)E
M87)B96ET96XB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED
M(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")%:6YS=&5L;'5N9V5N(&)E
M87)B96ET96X@9OQR.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R(")296-H=&4@9OQR(%PB)7-<(B!B96%R8F5I
M=&5N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M(")296-H=&4@9OQR("5S(&)E87)B96ET96XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")":6QD=6YG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`BQ&=Y<'1E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@
M4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B
M16QE;65N="XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@X-PIM<V=I9"`B16UA:6PB"FUS9W-T<B`B12U-
M86EL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(D4M36%I;"U!9')E<W-E(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DX,0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N(@IM<V=S='(@(D1I92!%+4UA:6PM061R97-S96X@;?QS<V5N(&=L
M96EC:"!S96EN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#<*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D4M36%I
M;"U!9')E<W-E(&UI="!"97-TY'1I9W5N9R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU3
M35,@1V%T97=A>2(*;7-G<W1R(")%+4UA:6PM;F%C:"U335,M1V%T97=A>2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3D*
M;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")3;6EL97ES(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("),965R92!.86-H<FEC:'0N(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U
M,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("),965R97,@17)G96)N
M:7,N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM
M<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E-U8VAB96=R:69F
M92!L]G-C:&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,`IM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B16EN9OQG96X@=F]N($)I;&1E<FX@
M875S($9O=&]G86QE<FEE;B!I;B!D96X@5&5X="!E<FQA=6)E;C\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$U"FUS9VED(")%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")+;VYT97AT;65N_"!B96D@
M4F5C:'1S:VQI8VL@86MT:79I97)E;C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C`V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(D5N9&IA:'(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E
M($5D:71O<B(*;7-G<W1R(")%9&ET;W(@=F5R9W+VWV5R;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,38*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T
M:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B)'96)E;B!3:64@
M96EN92!3:6-H97)H96ET<V9R86=E(&5I;BP@9&EE($EH;F5N(&=E<W1E;&QT
M('=I<F0L('=E;FX@4VEE($EH<B`B"B)087-S=V]R="!Z=7+\8VMS971Z96X@
M;?9C:'1E;BP@>BX@0BX@7")7:64@;&%U=&5T(&1E<B!.86UE($EH<F5S($AA
M=7-T:65R<S\B"B)<(CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I
M;6%G92!54DP@:&5R92(*;7-G<W1R(")(:65R(&1I92!":6QD+5523"!A;F=E
M8F5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(D=E8F5N('-I92!D:64@0G5C:'-T86)E;B!U;G1E;B!E:6XZ(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`BQ'%U871O
M<FEA;"U'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S
M='(@(D5R:71R96$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.3(@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*;7-G
M:60@(D5R<F]R(@IM<V=S='(@(D9E:&QE<B(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")&96AL97(@8F5I;2!%
M<G-T96QL96X@96EN97,@0FQO8VMS.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")&96AL97(@8F5I;2!,
M]G-C:&5N(&1E<R!3>6YC:')O;FES871I;VYS86YK97)S.B`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")&96AL
M97(@8F5I;2!,]G-C:&5N(&1E<R!3>6YC:')O;FES871I;VYS;&]G<SH@)7,B
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM
M<V=S='(@(D9E:&QE<B!B96EM($5R>F5U9V5N(&1E<R!);FAA;'1S.B`E<R(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T
M<B`B1F5H;&5R(&)E:6T@Q&YD97)N(&1E<R!087-S=V]R=',Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D9E
M:&QE<B!I;B!D97(@12U-86EL+4YA8VAR:6-H="XB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@
M7"(E<UPB+B(*;7-G<W1R(")&96AL97(@8F5I;2!38VAR96EB96X@=F]N(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S
M=&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("+$
M=&AI;W!I96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@
M(D5T:&YI8R(*;7-G<W1R(")%=&YI<V-H97,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O
M<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D%L;&4@,34@36EN=71E;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(D5V97)Y(#(@;6EN=71E
M<R(*;7-G<W1R(")!;&QE(#(@36EN=71E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-`IM<V=I9"`B
M179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")!;&QE(#,P(%-E:W5N9&5N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B06QL
M92`U($UI;G5T96XB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")"96D@
M:F5D97(@06YM96QD=6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-PIM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D%L;&4@:&%L8F4@
M4W1U;F1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@U"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T
M<B`B06QL92`V,"!396MU;F1E;B(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B0F5I
M<W!I96QW97)T93HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO
M8VUD<VAE;&PN<&AP.C4Q(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@
M(D5X96-U=&4B"FUS9W-T<B`B075S9OQH<F5N(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N
M9"(*;7-G<W1R(")697)G<O;?97)N(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@
M(B<I)R!E<G=A<G1E="(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FTB"FUS9W-T<B`B16EN>F5L;F5S(%=O<G0@;V1E<B!3=6-H
M8F5G<FEF9B!I;B!!;F;\:')U;F=S>F5I8VAE;B!E<G=A<G1E="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A
M=&EO;B!$871E(@IM<V=S='(@(E9E<F9A;&QS9&%T=6TB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B
M"FUS9W-T<B`B17AP;VYE;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R(")6;W)D97)G<G5N9&9A<F)E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-@IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")(
M;V-H;&%D96X@9&5R($MO;F9I9W5R871I;VX@<&5R($944"(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(D)E;G5T>F5R96EN<W1E
M;&QU;F=E;B!K;VYN=&5N(&YI8VAT(&=E;&%D96X@=V5R9&5N+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@3$1!4"!3
M97)V97(@9V5S8VAE:71E<G0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!334(M4V5R=F5R(&=E<V-H
M96ET97)T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB
M+B(*;7-G<W1R(")%<R!K;VYN=&4@:V5I;F4@2V]P:64@=F]N(%PB)7-<(B!E
M<G-T96QL="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@
M7"(E<UPB+B(*;7-G<W1R(")%<R!K;VYN=&4@;FEC:'0@;F%C:"!<(B5S7"(@
M:V]P:65R="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+B(*;7-G<W1R(")!=69B874@96EN96X@;F5U96X@4T%33"U697)B
M:6YD=6YG(&ES="!F96AL9V5S8VAL86=E;BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C4R,R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S
M7"(N(@IM<V=S='(@(D5S(&MO;FYT92!N:6-H="!N86-H(%PB)7-<(B!V97)S
M8VAO8F5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z
M("5S(@IM<V=S='(@(D9E:&QE<B!B96EM($QE<V5N.B`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&86ER
M(@IM<V=S='(@(DAE:71E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9&EN<V5L;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R
M]F5R(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(T,`IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(E-C:'=E<F5R($9E:&QE<CHB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&
M87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X92(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R(")&96)R=6%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C(*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B1V5F_&AL=&4@5&5M<&5R
M871U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G
M:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")'96;\:&QT92!496UP97)A='5R
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,`IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B5F5R96EN>F5L=&4@4V-H
M875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Q"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(E9E<F5I;GIE
M;'1E(%-C:&YE97-C:&%U97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.38R"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B1F5L9&UA=')I
M>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#,*;7-G:60@(D9I
M9VQE="!#05!40TA!(@IM<V=S='(@(D9I9VQE="!#05!40TA!(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,T-PIM<V=I9"`B1FEG;&5T(&9O;G0B
M"FUS9W-T<B`B1FEG;&5T+49O;G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II
M(@IM<V=S='(@(D9I9'-C:&DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-3<*;7-G:60@(D9I;&4B"FUS9W-T<B`B1&%T96DB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D%N>F%H;#H@)7,@1&%T96DB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")!;GIA:&PZ
M("5S($1A=&5I96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y
M"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1&%T96EM86YA9V5R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R(")$871E:6YA;64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")$871E
M:6%U<W=A:&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS
M9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")$871E:2U(;V-H;&%D96XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#`*;7-G:60@(D9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")$87,@2&]C:&QA
M9&5N('9O;B!$871E:65N('=I<F0@;FEC:'0@=6YT97)S=/QT>G0N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM
M<V=S='(@(D9I;'1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS
M9W-T<B`B1FEN;FQA;F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS
M9VED(")&:7)S="!(86QF(@IM<V=S='(@(D5R<W1E($CD;&9T92(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G
M:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B17)S=&5S(%9I97)T96PB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS
M9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B5F5R:.1L=&YI<R!Z=7+\8VMS971Z
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(E5M9')E:&5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I
M9"`B1FQO870B"FUS9W-T<B`B5&5X=&9L==\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B1F]G(@IM<V=S='(@
M(DYE8F5L(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#`@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B1&%S(%9E
M<GIE:6-H;FES("5S(&5X:7-T:65R="!N:6-H="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`B4V-H<FEF=&9A<F)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(D5S<V5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(*;7-G<W1R(")&_'(@0G)O=W-E<BP@9&EE(&ME:6YE($)I;&1E<B!U
M;G1E<G-T_'1Z96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-@IM<V=I
M9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B5F]R:&5R<V%G92`H5$%&*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R
M("(B"B)6;W)H97)G97-A9W1E(%1A9V4@*%9O<FAE<G-A9V5N(&5N=&AA;'1E
M;B!486=E('5N9"!.Y&-H=&4L(&5I;B!H;VAE<B!797)T("(*(FMA;FX@>G4@
M96EN96T@<V5H<B!G<F_?96X@0FQO8VL@9OQH<F5N*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`B4&%S<W=O<G0@=F5R9V5S<V5N/R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@
M(D9O<FUU;&%R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I
M9"`B1F]R='5N92(*;7-G<W1R(")';/QC:W-K96MS(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B
M1VS\8VMS:V5K<W1Y<"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B1VS\8VMS:V5K<V4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T
M<B`B1VS\8VMS:V5K<V4@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;W)E;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S
M='(@(E=E:71E<FQE:71U;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")&<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")286AM96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;FMR96EC:"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R
M;W!O;&ET86XB"FUS9W-T<B`B175R;W#D:7-C:&5S($9R86YK<F5I8V@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I
M9"`B1G)E97II;F<@1')I>GIL92(*;7-G<W1R(")'969R:65R96YD97(@4F5G
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@
M(D9R86YZ]G-I<V-H+4=U87EA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E
M;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N>O9S:7-C:"U0;VQY;F5S:65N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,B"FUS9W-T<B`B1G)A;GKV<VES8VAE($=E8FEE=&4@:6T@<_QD;&EC
M:&5N($EN9&ES8VAE;B!/>F5A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B5F]N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")!=7,@
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@
M(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B5F]L;'-TY&YD:6=E($)E<V-H
M<F5I8G5N9R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B5F]L;&UO
M;F0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S
M='(@(E9O;&QS=.1N9&EG97(@3F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A
M8F]N(@IM<V=S='(@(D=A8G5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")":6QD97(@875S(&1I97-E
M<B!'86QE<FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R
M(")'86QE<FEE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R
M(")'86UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H
M<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B)7,M2V]N9FEG=7)A=&EO;B!E<GIE=6=E;B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@
M0V]D92(*;7-G<W1R(")%<GIE=6=T97(@0V]D92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D=E;W)G:6$B"FUS9W-T<B`B1V5O<F=I96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(D1E=71S8VAL86YD(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA
M;64B"FUS9W-T<B`B5F]R;F%M92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-SD@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS
M(@IM<V=S='(@(D%L;&=E;65I;F4@16EN<W1E;&QU;F=E;B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R("),;W,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*
M;7-G<W1R(")';V5D96PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M1V]O9VQE($UA<',B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS
M9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92!3=6-H92(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G
M:60@(D=R87ES8V%L92(*;7-G<W1R(")'<F%U<W1U9F5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")'<FEE8VAE;FQA;F0B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(D=R:65C:&ES8V@@*$E33RTX.#4Y+3<I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R]FYL86YD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.#4*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D=R=7!P96YV97)W86QT=6YG(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>2(*;7-G<W1R(")'<G5P<&5N;F%M96X@9/QR9F5N(&YI8VAT(&QE97(@<V5I
M;B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*(D=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@:V]N;G1E(&YI8VAT
M(&AI;GIU9V5F_&=T('=E<F1E;BX@365L9'5N9R!D97,@(@HB4V5R=F5R<SH@
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R
M(")'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT92!N:6-H="!G96SV
M<V-H="!W97)D96XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S
M(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HR-#$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M,30*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-S@*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P<&5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D
M96QO=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A
M;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A
M=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I
M9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C@Y"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")'87-T
M<F5C:'1E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(D?D<W1E8G5C:"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN96$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5A+4)I<W-A=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U>6%N82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*
M;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S
M='(@(D1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%IE;&QE(&5I;F5R(%IE
M:6QE(&YI8VAT(&SV<V-H96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+B(*;7-G<W1R(")$97(@161I=&]R(&MA;FX@9&EE(&QE='IT92!3<&%L
M=&4@96EN97(@5&%B96QL92!N:6-H="!L]G-C:&5N+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92XB"FUS9W-T<B`B1&5R($5D:71O<B!K86YN(&1I92!L
M971Z=&4@6F5I;&4@96EN97(@5&%B96QL92!N:6-H="!L]G-C:&5N+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%144"U!=71H
M96YT:69I>FEE<G5N9R!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*
M;7-G<W1R(")(87-H+4%L9V]R:71H;75S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M1&EE<VEG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R
M("+<8F5R<V-H<FEF="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B2V]P9F5I
M;G1RY&=E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F0M('5N9"!-8T1O;F%L
M9&EN<V5L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(U"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E-C:'=E<F4@
M1V5W:71T97(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B
M2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G+D:7-C:"`H25-/
M+3@X-3DM."U)*2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G
M:60@(DAE:6=H="(*;7-G<W1R(")(]FAE(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L
M<"YP:'`Z,3@V"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-S4@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B2&EL9F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS
M9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")%9&ET;W)H:6QF92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E
M<B(*;7-G<W1R(")(:6QF92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM
M<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<W!H97)E(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FEL93HB"FUS9W-T<B`B1&EE<R!I<W0@9&5R($)E9VEN;B!D97(@1&%T
M96DZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*;7-G:60@(DAI9V@B"FUS9W-T<B`B2&]C:"(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E
M<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B7U-T87)T<V5I=&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R(")6871I:V%N<W1A9'0B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S
M<R(*;7-G<W1R(")!9')E<W-E('!R:79A="(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B2&5I
M;79E<GIE:6-H;FES(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE
M9F]N('!R:79A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N
M9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@56YG_&QT
M:6=E("5S+5A-3"U$871E;B!I;B!.86-H<FEC:'0@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C(Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5S('!A<W-T(&ME:6YE($YA8VAR
M:6-H="!Z=6T@3V)J96MT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($ME:6X@3V)J96MT('9O;2!4>7`@)7,@:6X@3F%C
M:')I8VAT("5S(&=E9G5N9&5N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C@U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z("5S(%PB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!E;G1F97)N="(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D
M92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@
M)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"B)(;W)D92]+;VQA
M8CH@1&EE($EN=&5G<F%T:6]N<V9U;FMT:6]N96X@8F5N]G1I9V5N(&1I92!<
M(F1O;7AM;%PB(%!(4"TB"B)%<G=E:71E<G5N9R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-3,X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!&_'(@9&%S($]B:F5K
M="`E<R!K;VYN=&4@:V5I;B!N975E<B!834PM0F%U;2!E<GIE=6=T('=E<F1E
M;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(X,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!<(B5S7"(@
M:V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;CH@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C4P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($1I
M92!-24U%+4E$(&1E<R!!8G-C:&YI='1S('9O;2!4>7`@)7,@:V]N;G1E(&YI
M8VAT("(*(FAE<F%U<V=E9G5N9&5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!<(B5S7"(@:V]N;G1E(&YI8VAT
M('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$S-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S
M='(@(B(*(DAO<F1E+TMO;&%B.B!$:64@9V5M96EN<V%M96X@3V)J96MT92!K
M;VYN=&5N(&YI8VAT('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,V-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(%5N8F5K86YN=&5S(&=E;65I;G-A;65S($]B:F5K
M="!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B2&]R
M:7IO;G1A;&4@3&EN:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B2&]R:7IO;G1A;&5R($EN;F5N86)S=&%N9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ
M;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT86PZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R
M(")7:64@<VEN9"!3:64@:&EE<FAE<F=E;&%N9W0_($)I='1E(&%N(&1I92!%
M;G1W:6-K;&5R('IU<OQC:VUE;&1E;B$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA
M;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B
M5VEE('9I96QE(%-P86QT96X@<V]L;&5N('IU<V%M;65N9V5F_&=T('=E<F1E
M;C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@
M(E=I979I96QE($9E;&1E<B`H4W!A;'1E;BD@9VEB="!E<S\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS
M9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R(")7:64@=FEE;&4@6F5I;&5N('-O;&QE;B!Z=7-A;6UE;F=E9OQG
M="!W97)D96X_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B2'5M:61I='DB"FUS
M9W-T<B`B3'5F=&9E=6-H=&EG:V5I="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B3'5F
M=&9E=6-H=&EG:V5I=#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q
M"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B2V]M:6ME<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")5;F=A<FXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")!;FQE9V5N
M(&1E<R!)34%0+5!O<W1F86-H<R!I<W0@9F5H;&=E<V-H;&%G96XZ("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M3/9S8VAE;B!D97,@24U!4"U0;W-T9F%C:',@:7-T(&9E:&QG97-C:&QA9V5N
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(D9E<W1L96=E;B!D97(@24U!4"U0;W-T9F%C:"U1=6]T
M82!I<W0@9F5H;&=E<V-H;&%G96XZ("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"U!
M9')E<W-E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW
M-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))
M4"U!9')E<W-E(&YI8VAT('9E<F;\9V)A<BXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"U!9')E<W-E
M(&YI8VAT(&EM(&5R;&%U8G1E;B!#2412+4)L;V-K+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B
M25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")697)L971Z=6YG(&1E
M<B!F97-T9V5L96=T96X@25`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O
M=R!"969O<F4B"FUS9W-T<B`B6F5I;&4@96EN9OQG96X@7W9O<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA;F0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<S"FUS9VED("))8V]N<R!/;FQY(@IM
M<V=S='(@(DYU<B!":6QD97(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@
M(DEC;VYS(&;\<B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S0*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")":6QD97(@=6YD(%1E
M>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@U"FUS9VED("))9&5N
M=&ET>2=S(&YA;64Z(@IM<V=S='(@(D)E>F5I8VAN=6YG(&1E<B!)9&5N=&ET
MY'0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G
M<W1R("(B"B)796YN('-I92!N:6-H="!K;W)R96MT(&%N9V5Z96EG="!W:7)D
M+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N($9E;G-T97(@(@HB86YG97IE
M:6=T('IU(&)E:V]M;65N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-3(*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T
M<B`B(@HB5V5N;B!3:64@;6ET(&1E;2!);G1E<FYE="!%>'!L;W)E<B!K96EN
M92!3>6UB;VQE('-E:&5N+"!M_'-S96X@4VEE(&1I97-E<R`B"B)+Y'-T8VAE
M;B!M87)K:65R96XL('5M(%!.1RU4<F%N<&%R96YZ(&%U<WIU<W1E;&QE;BXB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R
M"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB5V5N;B!3
M:64@9&EE<V4@3F%C:')I8VAT(&%N(%-T96QL92!E:6YE($)I;&1E<R!S96AE
M;BP@:V%N;B!):'(@0G)O=W-E<B!D87,@(@HB0FEL9"P@9&%S(%-I92!H;V-H
M;&%D96X@;?9C:'1E;B!N:6-H="!A;GIE:6=E;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(D)I;&1V;W)S8VAA=3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B0FEL9"U54DPB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B0FEL9"U54DPZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B
M0FEL9"!V;VX@1V%L97)I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y.B(*;7-G<W1R(")":6QD('9O;B!'86QE<FEE.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A
M9"(*;7-G<W1R(")":6QD+4AO8VAL861E;B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B0FEL9&5R(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T:65R96XL(%-C
M:')I='0@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T
M<B`B26UP;W)T:65R=&5S($9E;&0Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("));7!O<G1I97)T92!&96QD97(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T
M(%)O=R!!9G1E<B(*;7-G<W1R("):96EL92!E:6YF_&=E;B!?;F%C:"(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")5;F?\
M;'1I9V4@06MT:6]N(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B56YG_&QT:6=E
M<B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O<G0N(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-3,*;7-G:60@(B(*(DEN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@HB1F%L<V-H97(@0F5N=71Z97)N86UE(&]D
M97(@12U-86EL+4%D<F5S<V4N(%9E<G-U8VAE;B!3:64@97,@97)N975T(&]D
M97(@(@HB=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N(%-Y<W1E;6%D;6EN:7-T
M<F%T;W(L('=E;FX@4VEE('=E:71E<F4@2&EL9F4@(@HB8F5N]G1I9V5N+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*
M;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")%:6YZ=6<@=F5R9W+V
MWV5R;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD
M:65N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S4*;7-G:60@(DEN9&EV:61U86P@
M57-E<G,B"FUS9W-T<B`B16EN>F5L;F4@0F5N=71Z97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5S:65N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("));F9O<FUA=&EO;B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(DEN9F]R;6%T:6]N96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+B(*;7-G<W1R("));F9O<FUA=&EO;F5N(&YI8VAT(&UE:'(@=F5R9OQG8F%R
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S4*;7-G
M:60@(DEN:&5R:71E9"!-96UB97)S(@IM<V=S='(@(E9E<F5R8G1E($UI=&=L
M:65D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM
M<V=S='(@(E]3<&%L=&4@9&%V;W(@96EN9OQG96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G
M:60@(DEN<V5R="!);6%G92(*;7-G<W1R(")":6QD(&AI;GIU9OQG96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS
M9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B5&%B96QL92!E:6YF_&=E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*
M;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("),:6YK(&5I;F;\9V5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T
M<B`B4U]P86QT92!D86YA8V@@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(D5I;F4@;F5U92!3<&%L=&4@;F%C:"!D97(@86MT=65L;&5N(&5I;F;\
M9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B16EN92!N975E(%-P86QT92!V
M;W(@9&5R(&%K='5E;&QE;B!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M16EN92!N975E(%IE:6QE(&YA8V@@9&5R(&%K='5E;&QE;B!E:6YF_&=E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(D5I;F4@;F5U92!:96EL92!V;W(@9&5R(&%K
M='5E;&QE;B!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B16EN96X@
M;F5U96X@06)S871Z(&YA8V@@9&5M(&%K='5E;&QE;B!%;&5M96YT(&5I;F;\
M9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B16EN96X@;F5U96X@06)S871Z
M('9O<B!D96T@86MT=65L;&5N($5L96UE;G0@96EN9OQG96XB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R(")!;'1E<FYA=&EV92!6;W)L86=E(&5I;F;\9V5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S-`IM<V=I9"`B26YS97)T
M(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H
M92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*(D=E8F5N(%-I92!E:6YE($4M
M36%I;"U!9')E<W-E(&%N+"!A;B!D:64@9&%S(&YE=64@4&%S<W=O<G0@9V5S
M8VAI8VMT('=E<F1E;B`B"B)S;VQL.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C
M96QL(&%F=&5R(@IM<V=S='(@(EIE;&QE(&1A;F%C:"!E:6YF_&=E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("):96QL92!D
M879O<B!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T
M97(B"FUS9W-T<B`B4W!A;'1E(&1A;F%C:"!E:6YF_&=E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(E-P86QT92!D879O
M<B!E:6YF_&=E;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B3F%C:')I
M8VAT96X@:&EN>G5F_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!A9G1E<B(*;7-G<W1R(")!8G-A='H@9&%N86-H(&5I;F;\9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R
M(")!8G-A='H@9&%V;W(@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(EIE:6QE(&1A;F%C:"!E:6YF_&=E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(EIE:6QE(&1A
M=F]R(&5I;F;\9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-0IM
M<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.B(*;7-G<W1R(")'96)E;B!3:64@9&EE($%N='=O<G0@
M875F(&1I92!3:6-H97)H96ET<V9R86=E(&5I;CHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O
M36]D:69Y($EM86=E(@IM<V=S='(@(D)I;&0@96EN9OQG96XO8F5A<F)E:71E
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("),:6YK(&5I
M;F;\9V5N+V)E87)B96ET96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B6G4@=V5N:6<@1W5T:&%B96XL('5M(&%N(&1I92!697)T96EL97)L:7-T
M92!Z=2!V97)S8VAI8VME;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`B6G4@=V5N:6<@1W5T:&%B96XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R
M(")'86YZ>F%H;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*
M;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("),:7-T92!V;VX@1V%N>GIA
M:&QE;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"FUS9W-T<B`B56YG_&QT:6=E<B!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q
M,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")5;F?\;'1I9V4@
M6DE0+41A=&5N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G
M:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(E5N9_QL=&EG92!!
M;G=E;F1U;F<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G
M<W1R(")5;F?\;'1I9V4@0F%T8V@M240N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3<V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3`@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R(")5;F?\;'1I9V4@1&%T96X@96EN9V5B96XN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED
M("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(E5N9_QL
M=&EG92!::65L861R97-S92XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G
M<W1R(")5;F?\;'1I9V5S($1A=&5I9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME
M>2XB"FUS9W-T<B`B56YG_&QT:6=E<B!,:7IE;GIS8VAL_'-S96PN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI
M9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B56YG_&QT:6=E<B!/<G0@
M86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS
M9W-T<B`B56YG_&QT:6=E<B!M<V=?='EP92XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(E5N9_QL=&EG92!O9&5R
M(&9E:&QE;F1E(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES
M<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")5;F?\;'1I9V4@;V1E<B!F96AL
M96YD92!087)A;65T97(N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")5;F?\;'1I9V5S(-QB97)R96-H="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM
M<V=S='(@(E5N9_QL=&EG92!087)T;F5R+4E$+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R(")5;F?\;'1I9V5R(%!R;V1U:W1C;V1E+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM
M<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B56YG_&QT:6=E<R!0
M<F]T;VMO;&PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB
M)7-<(B(*;7-G<W1R(")5;F?\;'1I9V5R($5M<&;D;F=E<CH@7"(E<UPB(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3$W(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(Y-PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE
M8W0B"FUS9W-T<B`B56YG_&QT:6=E<R!G96UE:6YS86UE<R!/8FIE:W0B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(E5N
M9_QL=&EG92!5<G-P<G5N9W-A9')E<W-E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI
M9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(E5N9_QL=&EG92!5;FEC;V1E+41A
M=&5N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@
M(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1A<B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S
M96QE8W1I;VXB"FUS9W-T<B`B075S=V%H;"!U;6ME:')E;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R
M("))<VQA;6ES8VAE(%)E<'5B;&EK($ER86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DER87$B"FUS9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M27)E;&%N9"(*;7-G<W1R("))<FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B27-L
M92!O9B!-86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-@IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B5F5R
M96EN>F5L=&4@1V5W:71T97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E
M;"(*;7-G<W1R("))<W)A96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(D%U<W-T96QL
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CD*;7-G:60@(DET86QI8R(*;7-G<W1R(")+=7)S:78B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DET86QI96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EK82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU
M87)Y(@IM<V=S='(@(DIA;G5A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P
M86XB"FUS9W-T<B`B2F%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!A
M;FES8V@@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&%N:65N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G
M:60@(DIU;'DB"FUS9W-T<B`B2G5L:2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU
M;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(D)L;V-K<V%T>B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("):96YT<FEE
M<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")";&]C
M:W-A='HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(DQI
M;FMS(&%U<W)I8VAT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*
M;7-G<W1R(")296-H=',@875S<FEC:'1E;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87-A8VAS=&%N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B3W)I9VEN86P@8F5I8F5H86QT96X_(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+96YI82(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M2V5R8F5R;W,M4V5R=F5R(&AA="!!=71H96YT:69I>FEE<G5N9R!Z=7+\8VMG
M97=I97-E;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@
M(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"U.975L:6YG92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M($-R96%T:6]N(@IM<V=S='(@(E-C:&S\<W-E;&5R>F5U9W5N9R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(D9I;F=E<F%B9')U8VL@9&5S(%-C:&S\<W-E
M;',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`B4V-H;/QS<V5L;.1N9V4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4
M>7!E(@IM<V=S='(@(E-C:&S\<W-E;'1Y<"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T
M<B`B4V-H;/QS<V5L>G=E8VLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@HB1&5R(%-C:&S\<W-E;"!B
M969I;F1E="!S:6-H(&)E<F5I=',@875F(&1E;2#V9F9E;G1L:6-H96X@4V-H
M;/QS<V5L<V5R=F5R+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM
M<V=I9"`B2VED<R(*;7-G<W1R(")+:6YD97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9B(*;7-G<W1R(")$96UO:W)A=&ES8VAE(%9O;&MS<F5P=6)L:6,@2V]R96$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G
M<W1R(")297!U8FQI:R!+;W)E82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R96%N:7-C
M:"`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S
M='(@(DMU=V%I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*
M;7-G<W1R(")+:7)G:7-I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")!;E]P87-S96XB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G
M92(*;7-G<W1R(")3<')A8VAE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM
M<V=S='(@(DQE='IT92!(Y&QF=&4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z.#@*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(DQE
M='IT92!087-S=V]R=.1N9&5R=6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R
M(@IM<V=S='(@(DQE='IT97,@5FEE<G1E;"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34S"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(DQE='IT
M92!!:W1U86QI<VEE<G5N9SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS
M9W-T<B`B3&5T>G1E($%N;65L9'5N9SH@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<R(*;7-G<W1R("),971Z=&4@06YM96QD=6YG.B`E<R!V
M;VX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G:60@
M(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(DQE='IT92!!;FUE;&1U;F<Z
M($YO8V@@;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T
M<B`B3&5T=&QA;F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G
M:60@(DQA=R(*;7-G<W1R(")'97-E='HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*
M;7-G<W1R(")&;W)M870B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R
M9&5R(@IM<V=S='(@(DQE97(@;&%S<V5N(&;\<B!K96EN96X@4F%H;65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B3&EN:W,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G
M<W1R("),:6YK92#<8F5R<V-H<FEF="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,34*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(DQI;FME
M(%=E<G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@
M(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-3<*
M;7-G:60@(DQE=F5L(@IM<V=S='(@(D5B96YE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB>65N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@
M(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")3
M<'+\:')E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B3&5I8VAT97(@
M4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R(")&<OQH(&QE
M:6-H=&5R(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")3
M<.1T97(@3&5I8VAT97(@4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B
M"FUS9W-T<B`B3&5I8VAT92!296=E;G-C:&%U97(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4F%I
M;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B3&5I8VAT97(@4F5G96X@;6ET($=E
M=VET=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S,*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B3&5I8VAT97(@4V-H
M;F5E9F%L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,T"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("),96EC
M:'1E(%-C:&YE97-C:&%U97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R:6-K(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G<W1R
M("),:6YK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-PIM<V=I
M9"`B3&EN:R!54DPB"FUS9W-T<B`B3&EN:RU54DPB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#,R"FUS9VED("),:6YK(&%C8V5S<R!K97DB"FUS
M9W-T<B`B3&EN:RU:=6=R:69F<W1A<W1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK
M('!O:6YT<R!T;SHB"FUS9W-T<B`B3&EN:R!V97)W96ES="!A=68Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@R,PIM<V=I9"`B3&EN:R!T87)G
M970B"FUS9W-T<B`B3&EN:RU::65L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@R,`IM<V=I9"`B3&EN:R!T97AT(@IM<V=S='(@(DQI;FLM5&5X
M="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X.3,*;7-G:60@(DQI
M;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N
M(&1I<W!L87EI;F<B"FUS9W-T<B`B12U-86EL+4%D<F5S<V4@=F5R;&EN:V5N
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,CD*;7-G:60@(DQI
M;FL@=&ET;&4@871T<FEB=71E(@IM<V=S='(@(DQI;FLM5&ET;&4M071T<FEB
M=70B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X
M="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("),:6YK<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM
M<V=S='(@(DQI;G5X+4=L_&-K<VME:W-E(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S
M964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T("T@0F5N=71Z97(@:V%N;B!D
M96X@3W)D;F5R('-E:&5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S-`IM
M<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B1&%T96YB86YK96X@86YZ
M96EG96XB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B
M3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")(:6QF965I;G1RY&=E(&%N>F5I
M9V5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!4
M86)L97,B"FUS9W-T<B`B5&%B96QL96X@86YZ96EG96XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C8P,0IM<V=I9"`B3&ES="U!<F-H
M:79E(@IM<V=S='(@(DQI<W1E;BU!<F-H:78B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(DQI<W1E;BU(:6QF92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-C`S"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI<W1E;BU)
M9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DY"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI<W1E;BU"97-I='IE<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-C`P"FUS9VED("),
M:7-T+5!O<W0B"FUS9W-T<B`B3&ES=&5N+4%D<F5S<V4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y.`IM<V=I9"`B3&ES="U3=6)S
M8W)I8F4B"FUS9W-T<B`B3&ES=&5N+4%N;65L9'5N9R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DW"FUS9VED("),:7-T+55N<W5B
M<V-R:6)E(@IM<V=S='(@(DQI<W1E;BU!8FUE;&1U;F<B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S
M97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(D1A<R!!;GIE:6=E;B!D97(@
M4V5S<VEO;G,@:7-T(&9E:&QG97-C:&QA9V5N.B`E<R(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S
M97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B1&%S($%N>F5I9V5N(&1E<B!"96YU
M='IE<B!I<W0@9F5H;&=E<V-H;&%G96XZ("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R(")$87,@06YZ96EG96X@9&5R($)E;G5T>F5R
M(&ES="!N:6-H="!M]F=L:6-H+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71E<F%T=7(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71A=65N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW
M-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),861E+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM
M93H@(@IM<V=S='(@(DQO:V%L92!5:')Z96ET.B`B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R
M(")3<')A8VAE('5N9"!:96ET(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")/<G0B"@HC.B!L;V=I
M;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#0@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS
M9VED("),;V<@:6XB"FUS9W-T<B`B06YM96QD96XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#<*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S
M>6YC('-E<W-I;VXB"FUS9W-T<B`B3&]G(&1E<B!L971Z=&5N(%-Y;F-H<F]N
M:7-A=&EO;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DX
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D%B;65L9&5N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*;7-G<W1R(")!;FUE
M;&1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(D%N;65L9&5A=69G86)E;B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB1&EE($%N;65L9'5N9R!I<W0@9F5H
M;&=E<V-H;&%G96XL('=E:6P@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@;V1E
M<B!):'(@(@HB4&%S<W=O<G0@9F%L<V-H(&5I;F=E9V5B96X@:&%B96XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F
M86EL960N(@IM<V=S='(@(D%N;65L9'5N9R!F96AL9V5S8VAL86=E;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`B3&%N9V5R(%1E>'0B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B3&EE8F4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B3&]W
M(@IM<V=S='(@(DYI961R:6<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E
M:R!L971T97)S(@IM<V=S='(@(DML+B!G<FEE8VAI<V-H92!"=6-H<W1A8F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R
M(")+;"X@;&%T96EN:7-C:&4@0G5C:'-T86)E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@
M(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B2VPN('+V;6ES8VAE(%IA
M:&QE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R
M("),=7AE;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,SD@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-
M(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1BU!
M;FAA;F<@96YT:&EE;'0@:V5I;F4@1&%T96XN(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-PIM<V=I9"`B35-'(@IM<V=S='(@(DA)3E=%25,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS
M9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B1&EE(&5H96UA;&EG92!*=6=O<VQA=VES8VAE(%)E<'5B
M;&EK($UA>F5D;VYI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C
M87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:64B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`B
M5V5B;6%I;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G
M:60@(DUA:6P@061M:6XB"FUS9W-T<B`B12U-86EL($%D;6EN:7-T<F%T:6]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(DQI;FL@
M7V%N;&5G96XN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G
M<W1R(")-86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM
M<V=S='(@(DUA;&%Y<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E
M<R(*;7-G<W1R(")-86QI9&EV96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA
M;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B
M"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*
M;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I
M871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(E9E<G=A
M;'1E;B!3:64@9&EE($MA=&5G;W)I96XL(&UI="!D96YE;B!3:64@16QE;65N
M=&4@=6YD($5I;G1RY&=E("(*(FME;FYZ96EC:&YE;B!K]FYN96XL('-O=VEE
M(&1I92!Z=6=E:/9R:6=E;B!&87)B96XN(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R(")-87`R-"U+87)T92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS
M9W-T<B`B36%P475E<W0M2V%R=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B
M6G5O<F1N=6YG96X@9V5S<&5I8VAE<G0N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@
M(DWD<GHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B077?96YA8G-T
M86YD(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*
M;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-
M:70@1V5L97-E;BTO56YG96QE<V5N+5-T871U<R!V97)S96AE;B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*
M;7-G<W1R(")-:70@86YD97)E;2!3=&%T=7,@=F5R<V5H96X@*'HN0BX@5VEC
M:'1I9R]"96%N=V]R=&5T*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA
M;&P@27-L86YD<R(*;7-G<W1R(")-87)S:&%L;&EN<V5L;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI<75E(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H
M:6YG(&9I96QD<R(*;7-G<W1R("):=6=E;W)D;F5T92!&96QD97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<F5T86YI
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-
M875R:71I=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS
M9W-T<B`B36%X:6UA;"!E<FQA=6)T97(@2W)E9&ET+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(DUA>&EM86QE
M($YA8VAT:6-H=&5N=&5I;&4@_&)E<G-C:')I='1E;BXB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P.`IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@(@IM<V=S='(@(DCV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT96X@,C0@
M4W1U;F1E;CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#`*;7-G:60@
M(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DCV8VAS='1E;7!E
M<F%T=7(@9&5R(&QE='IT96X@-B!3='5N9&5N.B`B"@HC.B!L:6(O87!I+G!H
M<#HQ.#$*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B
M"FUS9W-T<B`B36%X:6UA;&4@06YZ86AL(&%N(%!O<G1A;&)L]F-K96XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")-87AI;6%L92!,Y&YG
M92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B36%I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E($ES;&%N9"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
M365D:7II;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B36ET9VQI961E<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(DUE;G4@;6]D93HB"FUS
M9W-T<B`B365N_&UO9'5S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM
M<V=S='(@(EIE;&QE;B!Z=7-A;6UE;F;\9V5N(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS
M,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-3<*;7-G:60@(DUE
M<W-A9V4B"FUS9W-T<B`B3F%C:')I8VAT(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)$:64@3F%C
M:')I8VAT(&MO;FYT92!E<F9O;&=R96EC:"#\8F5R<'+\9G0@=V5R9&5N(&%B
M97(@;FEC:'0@9&%S(%IE<G1I9FEK870@(@HB9&5S($%B<V5N9&5R<RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B3F%C:')I8VAT
M(&YI8VAT(&UE:'(@9_QL=&EG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE
M<W-A9V4@='EP92(*;7-G<W1R(").86-H<FEC:'1E;G1Y<"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R
M(")-971A<B!7971T97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS
M9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A
M<F)L;V-K(&YI8VAT('9E<F;\9V)A<BXB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB365T87)B;&]C:R!N:6-H="!V97)F_&=B87(N($1E
M=&%I;',@=W5R9&5N(&;\<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@
M(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B2V5I;F4@5F5R
M8FEN9'5N9R!Z=7(@365T87)$0BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-971H;V1E(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO
M4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T
M:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")$:64@365T:&]D
M92!<(B5S7"(@:7-T(&YI8VAT(&1E9FEN:65R="(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B365T
M:&]D92!N:6-H="!D969I;FEE<G0N($%U9F=E<G5F96YE($UE=&AO9&4Z("5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#(*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-971R:7-C
M:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE>&EK
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F(@IM<V=S='(@(D;V9&5R:65R=&4@4W1A871E;B!V;VX@36EK
M<F]N97-I96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")-:71T92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B36EM971Y<"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$R"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B5&EE9G-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`R-"!3
M='5N9&5N.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-`IM<V=I9"`B
M36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&EE9G-T=&5M<&5R
M871U<B!D97(@;&5T>G1E;B`V(%-T=6YD96XZ("(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D
M(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(D1A<R!M:6YI;6%L
M92!087-S=V]R=&%L=&5R(&ES="!N;V-H(&YI8VAT(&%B9V5L875F96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS
M9VED(")-:7)R;W(B"FUS9W-T<B`B4W!I96=E;&XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M5F5R<V-H:65D96YE<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+B(*;7-G<W1R(")014%2+5!A:V5T($A45%!?4F5Q
M=65S="!F96AL="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$T"FUS
M9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@HB1F5H;&5N9&4@2V]N9FEG=7)A=&EO;BX@
M4VEE(&W\<W-E;B!D:65S92!J971Z="!E<GIE=6=E;BP@=V5N;B!3:64@9&EE
M("(*(D%N=V5N9'5N9R!V97)W96YD96X@;?9C:'1E;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@
M(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B1F5H;&5N9&4@3F%C:')I
M8VAT96XM240N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(@IM<V=S='(@(E!%05(M4&%K970@36%I;"!F96AL
M="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B
M1F5H;&5N9&4@4VET>G5N9W,M240N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B36\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(D4M36%I;"!-;V)I;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")-Y-]I9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U
M"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(L1N9&5R=6YG<V1A='5M
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(E523"!B96%R
M8F5I=&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QU<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4F5P
M=6)L:6L@36]L9&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS
M9W-T<B`B36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*
M;7-G<W1R(")-;VYG;VQE:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V,#(*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUO;F%T('5N
M9"!*86AR(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-;VYA=&QI8V@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E
M<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B36]N9'!H87-E
M;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E
M9"`E9"XB"FUS9W-T<B`B365H<B!&96QD97(@:6X@6F5I;&4@)60@86QS(&1I
M92!E<G=A<G1E=&5N("5D(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:VMO(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&5A
M<B(*;7-G<W1R("+<8F5R=VEE9V5N9"!H96ET97(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY($-L
M;W5D>2(*;7-G<W1R("+<8F5R=VEE9V5N9"!"97?V;&MT(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(DUO<W1L
M>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@(MQB97)W:65G96YD($)E=_9L
M:W0@=6YD(%=I;F1I9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,X"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`BW&)E
M<G=I96=E;F0@4V]N;FEG(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R
M(").86-H('5N=&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(").
M86-H(&QI;FMS(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B3F%C
M:"!R96-H=',B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(").86-H(&]B
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B3F%C:"!U;G1E;B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I
M9"`B36]V92!U<"(*;7-G<W1R(").86-H(&]B96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]S86UB:6LB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C`R"FUS9VED(")-=6QT:2UL979E;"!D
M<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B075S=V%H;&QI<W1E(&EN(&UE:')E
M<F5N($5B96YE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B
M375L=&EM87`M54LM2V%R=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C8P"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B365H
M<F9A8VAA=7-W86AL(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-96EN($MO;G1O(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DUE:6X@2V]N=&\B"@HC.B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C0T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B
M365I;B!0;W)T86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#(*
M;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B365I;B!0;W)T86QL
M87EO=70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B
M0G5R;6$B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY%
M24XL(&EC:"!S=&EM;64@3DE#2%0@>G4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").86UE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B3FEE9&5R;&%N9&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS
M9W-T<B`B3FEE9&5R;.1N9&ES8VAE($%N=&EL;&5N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A
M<V4@55),(@IM<V=S='(@(DYE='-C87!E+4)A<VES+5523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P
M92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92U#02U3<&5R
M<G5N9W,M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4M0T$M4FEC:'1L:6YI96XM55),(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W
M86P@55),(@IM<V=S='(@(DYE='-C87!E+5IE=&EF:6MA='-E<FYE=65R=6YG
M<RU54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4M4W!E<G)U;F=S+5523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA
M;64B"FUS9W-T<B`B3F5T<V-A<&4M4U-,+5-E<G9E<FYA;64B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S8V%P92U+;VUM
M96YT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").
M971S8V%P92U:97)T:69I:V%T='EP(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").971Z=V5R:R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#,*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").975K86QE9&]N:65N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").975E($MA=&5G;W)I
M92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB
M"FUS9W-T<B`B3F5U;6]N9"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM
M<V=S='(@(DYE=65R($)E;G5T>F5R;F%M92`H;W!T:6]N86PI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").975S965L86YD
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").
M97<@<&%S<W=O<F0B"FUS9W-T<B`B3F5U97,@4&%S<W=O<G0B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G
M:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B
M1&%S(&YE=64@4&%S<W=O<F0@=VER9"!A;2`E>"!A8FQA=69E;BXB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S
M=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(D1I92!N975E;B!087-S=_9R
M=&5R('-T:6UM96X@;FEC:'0@_&)E<F5I;BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W
M("A?8FQA;FLI(@IM<V=S='(@(DYE=65S($9E;G-T97(@*%]B;&%N:RDB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B
M3F5W<R(*;7-G<W1R(").86-H<FEC:'1E;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B3F5W
M<V=R=7!P96XB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR
M-0IM<V=I9"`B3F5X="(*;7-G<W1R(")796ET97(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B3N1C
M:'-T92`T(%!H87-E;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED
M(").97AT(&]P=&EO;G,B"FUS9W-T<B`B3N1C:'-T92!%:6YS=&5L;'5N9V5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#8*;7-G:60@(DYE
M>'0^(@IM<V=S='(@(E=E:71E<CXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6=E<FEA(@IM<V=S='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(").86-H
M=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*
M;7-G:60@(DYO(@IM<V=S='(@(DYE:6XB"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(DME:6YE($MO;F9I9W5R871I;VYS9&%T96X@=F5R9OQG8F%R+"!U;2!5;G1E
M<G-C:&EE9&4@86YZ=7IE:6=E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B2V5I;F4@
M4W1R871E9VEE('IU;2!%<G-T96QL96X@=F]N($E33RU!8F)I;&1E<FX@=F5R
M9OQG8F%R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S
M='(@(DME:6YE($)A=&-H+59O<FQA9V4N(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S
M='(@(D5S(&5X:7-T:65R="!K96EN($)L;V-K(&%N(&1E<B!A;F=E9V5B96YE
M;B!0;W-I=&EO;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z
M-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME:6X@2V%L96YD97)N86UE(&;\
M<B!D:64@34-!3"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-3$*;7-G:60@(DYO(&-H86YG92XB"FUS
M9W-T<B`B2V5I;F4@Q&YD97)U;F=E;BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@HB56YT97)H86QB
M(&1I97-E<B!%8F5N92!K]FYN96X@:V5I;F4@=V5I=&5R96X@56YT97)R96-H
M=&4@:&EN>G5G96;\9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3<X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$Q"B,Z
M(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(D;\<B`E<R!W=7)D96X@:V5I;F4@2V]N9FEG=7)A
M=&EO;G-I;F9O<FUA=&EO;F5N(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@V-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(B(*
M(D;\<B!D96X@1E10+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U
M<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-S(W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B
M(@HB1OQR(&1E;B!344PM5D93+51R96EB97(@=W5R9&5N(&ME:6YE($MO;F9I
M9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<W,@IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RXB"FUS9W-T<B`B(@HB1OQR(&1E;B!344PM1&%T96DM5D93+51R96EB97(@
M=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B`B"B)A
M;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T
M<B`B2V5I;B!+<F5D:70@;65H<B#\8G)I9RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DME:6X@16UP9N1N9V5R(&%N
M9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,3@*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B2V5I;F4@1&%T
M96D@:&]C:&=E;&%D96XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*
M;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")+96EN92!)8V]N<R!G
M969U;F1E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$S,`IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(")%
M<R!W=7)D92!K96EN($]R="!F97-T9V5L96=T+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(")+96EN($]R="!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DME:6YE($YA8VAR:6-H
M="!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R(")+96EN($YA;64@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(")+96EN92!.=6UM97(@86YG96=E
M8F5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DME:6YE(&%N<W3VWVEG96X@
M1VS\8VMS:V5K<V4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP
M.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5I;B!087-S=V]R="!F_'(@9&EE($A4
M5%`M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`P"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5I
M;B!087-S=V]R="!F_'(@9&EE($E-05`M075T:&5N=&EF:7II97)U;F<@86YG
M96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5I;B!087-S=V]R="!F_'(@9&EE($ME
M<F)E<F]S+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H
M<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D:64@
M3&]G:6XM075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!005-35T0M075T:&5N=&EF:7II
M97)U;F<@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5I;B!087-S=V]R="!F_'(@9&EE
M(%--0BU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P
M871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y3
M4TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q
M,B!D871A+B(*;7-G<W1R("(B"B)+96EN(%!F860@>G5M($]P96Y34TPM4')O
M9W)A;6T@86YG96=E8F5N+B!$87,@3W!E;E-33"U0<F]G<F%M;2!W:7)D("(*
M(F)E;O9T:6=T+"!U;2!02T-3+3$R+41A=&5N('9E<F%R8F5I=&5N('IU(&OV
M;FYE;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV
M"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(DME:6YE(&%U
M<W-T96AE;F1E;B!296=I<W1R:65R=6YG96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C<U,PIM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")+
M96EN(%-P96EC:&5R<&QA='HM2V]N=&EN9V5N="!F97-T9V5L96=T+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DME:6YE(%)A:&UE;B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B2V5I;B!4<F5N;GIE:6-H96X@
M86YG96=E8F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DME
M:6YE(%-E:71E;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C`Y
M"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B1&%T96D@;FEC:'0@9V5F
M=6YD96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS
M9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N(@IM<V=S='(@(DME:6YE('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9OQR
M(&1E;B!#86-H92!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DME:6X@0F5N=71Z97)N86UE
M('5N9"]O9&5R(%!A<W-W;W)T(&%N9V5B96XN(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ-#8*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(D5S('=U<F1E;B!K96EN92!G_&QT:6=E;B!8
M34PM1&%T96X@>G5R_&-K9V5G96)E;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T
M<B`B2V5I;F4@5V5R=&4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
M2V5I;F4@5F5R<VEO;G-N=6UM97(@:6X@9&5R($]R:6=I;F%L:V]N9FEG=7)A
M=&EO;B!G969U;F1E;BX@17)N975E<FX@4VEE("(*(DEH<F4@2V]N9FEG=7)A
M=&EO;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)+96EN92!697)S:6]N
M<VYU;6UE<B!I;B!):')E<B!+;VYF:6=U<F%T:6]N(&=E9G5N9&5N+B!%<FYE
M=65R;B!3:64@26AR92`B"B)+;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.34*;7-G:60@(DYO;F4B"FUS9W-T
M<B`B2V5I;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@
M(DME:6YS("A3=&%N9&%R9"!B96YU='IE;BDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B3F]R9&ES8V@@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L:VEN<V5L(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM
M<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(").]G)D;&EC:&4@
M2&5M:7-P:&5R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S(@IM<V=S='(@(D[V<F1L:6-H92!-87)I86YE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G=E9V5N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@
M(DYO="!!9G1E<B(*;7-G<W1R(")'_&QT:6<@8FES(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B
M"FUS9W-T<B`B1_QL=&EG(&%B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-#(T"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B2V5I
M;B!697)Z96EC:&YI<R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C,T.`IM<V=I9"`B3F]T(&9O=6YD+B(*;7-G<W1R(").:6-H
M="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.CDU"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B
M3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(").:6-H="!I;7!L96UE;G1I97)T
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3FEC:'0@9F5S=&=E;&5G="(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,38S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3DR"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,W(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S.2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR.#,@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,S(*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,T-R!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S8T"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS.3<@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C0U-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3,V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HV,#4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C8R,@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3FEC
M:'0@=6YT97)S=/QT>G0N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M-`HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V."!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1I>F5N
M(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3FEC:'1S(&%N
M>G5Z96EG96XL(&)I='1E('IU<OQC:V=E:&5N+B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*
M;7-G<W1R(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R("):86AL(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A
M8W1E<G,B"FUS9W-T<B`B06YZ86AL(&1E<B!:96EC:&5N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU
M;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(D%N>F%H;"!D97(@4W!A;'1E;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R
M"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(")!;GIA:&P@9&5R(%IE
M:6QE;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")+96EN92!.
M=6UM97)N(&;\<B!D:64@5F5R=&5I;&5R;&ES=&4@86YG96=E8F5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I
M9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J
M96MT(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3(*;7-G:60@
M(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K=&5R<W1E;&QE<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM
M<V=S='(@(D]K=&%L>F%H;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]K=&]B
M97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N
M<V4@9FEL=&5R(@IM<V=S='(@(D9I;'1E<B!F_'(@86YS=/;?:6=E($EN:&%L
M=&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`B0OQR;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+B(*;7-G<W1R(")):'(@;F5U97,@4&%S<W=O<G0@;75S
M<R!S:6-H('9O;B!):')E;2!A;'1E;B!U;G1E<G-C:&5I9&5N+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W
M;W)D(@IM<V=S='(@(D%L=&5S(%!A<W-W;W)T(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T
M(&-O<G)E8W0N(@IM<V=S='(@(D9A;'-C:&5S(&%L=&5S(%!A<W-W;W)T+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@R-@IM<V=I9"`B3VYC;&EC:R!E
M=F5N="(*;7-G<W1R(")/;F-L:6-K+45V96YT(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S
M97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(DYU<B!)
M34%0+5-E<G9E<B!U;G1E<G-T_'1Z96X@9V5M96EN<V%M92!/<F1N97(N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R(").=7(@86YS=/;?:6=E($=L_&-K<VME
M:W-E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")/;FQY(&]N92!E;6%I;"!A
M9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DYU<B!E:6YE($4M36%I;"U!9')E
M<W-E(&5R;&%U8G0N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U
M"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S
M:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B).=7(@9&5R($)E<VET>F5R
M(&]D97(@9&5R(%-Y<W1E;6%D;6EN:7-T<F%T;W(@:V%N;B!D96X@0F5S:71Z
M97(@;V1E<B!D:64@(@HB0F5S:71Z97)R96-H=&4@Y&YD97)N(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-#$@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#(*
M;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(DEN(&YE=65M
M($9E;G-T97(@]F9F;F5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@
M(B(*(D]P96Y34TPM1F5H;&5R.B!3:6=N:65R=&4@4R]-24U%+41A=&5N(&MO
M;FYT96X@;FEC:'0@97AT<F%H:65R="!W97)D96XN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED
M(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D1I
M97-E;B!,:6YK(&EN(&5I;F5M(&YE=65M($9E;G-T97(@]F9F;F5N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(D)E=')I96)S>7-T96TB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,34U"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D5I
M;G-T96QL=6YG96XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B16EN<W1E;&QU;F=E;B!F_'(@)7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS
M9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B3G5M;65R:65R=&4@3&ES=&4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I
M9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-A=&EO;B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A
M;FES871I;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N:7-A=&EO;G-A8G1E:6QU
M;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/
M<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7-I97)E;B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R(")/<FEG:6YA;'9O<FQA9V4@9&5R($%N=V5N9'5N
M9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*
M;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B3W)I
M9VEN86QV;W)L86=E(&EN("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/
M=&AE<B(*;7-G<W1R(")3;VYS=&EG92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED(")/=&AE<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")!;F1E<F4@26YF;W)M871I;VYE;B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S(*;7-G:60@(D]W;F5R(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(D)E<VET>F5R<F5C:'1E(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-+4%U=&AE;G1I9FEZ
M:65R=6YG(&ES="!N:6-H="!V97)F_&=B87(N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-
M86EL(&)A8VME;F0B"FUS9W-T<B`B4$5!4CHZ36%I;"U"86-K96YD(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(X-0IM<V=I9"`B4$=0
M($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D1I9VET86QE(%!'4"U5;G1E
M<G-C:')I9G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S,Q"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0+79E
M<G-C:&S\<W-E;'1E($1A=&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,X,PIM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B
MUF9F96YT;&EC:&5R(%!'4"U38VAL_'-S96PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S8U"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(DUI="!01U`@=6YT97)Z96EC:&YE=&4O=F5R
M<V-H;/QS<V5L=&4@1&%T96XB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*
M;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!#;V1E(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0
M(%-H96QL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#`*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B5F]R;6ET=&%G
M<R!L96EC:'1E<B!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!286EN(@IM<V=S='(@(DYA8VAM
M:71T86=S(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B3F%C:&UI
M='1A9W,@4V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0S"FUS9VED(")032!3;F]W(@IM<V=S='(@(DYA8VAM:71T
M86=S(%-C:&YE92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B3F%C
M:&UI='1A9W,@4V-H;F5E<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M3F%C:&UI='1A9W,@4V]N;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B
M3F%C:&UI='1A9W,@1V5W:71T97(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R(")$:64@4$]325@M17)W96ET97)U;F<@9F5H;'0B"@HC.B!L:6(O87!I
M+G!H<#HR,34*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B7U!(4"!3:&5L
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B26YN96YA8G-T86YD
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI
M<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A
M;&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")"97-E='IT92!086SD<W1I;F5N<VES
M8VAE($=E8FEE=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G
M<W1R(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'
M=6EN96$B"FUS9W-T<B`B4&%P=6$M3F5U9W5I;F5A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R(")496EL=V5I<V4@0F5W]FQK="(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S8*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)T(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&%S<W=O<G0@97)F;VQG<F5I8V@@9V7D
M;F1E<G0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B1F%L<V-H
M97,@4&%S<W=O<G0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D:64@
M4D%$2553+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<Q"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")087-S=V]R="!M:70@0F5S=.1T:6=U
M;F<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@
M(E!A<W-W;W)D.B(*;7-G<W1R(")087-S=V]R=#HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")087-S=V]R=#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D1I92!087-S=_9R=&5R(&W\<W-E;B!G;&5I8V@@<V5I;BXB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS
M9W-T<B`B16EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*
M;7-G<W1R(")6;VX@9&5R(%IW:7-C:&5N86)L86=E(&5I;F;\9V5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R(")09F%D(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B
M075S<W1E:&5N9&4@4F5G:7-T<FEE<G5N9V5N.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E!E<G-O;F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4')O>F5N="(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B5V%R='5N
M9W-A<F)E:71E;B!D=7)C:&;\:')E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,#,*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\B"FUS9W-T<B`B5V%R='5N9W-A<F)E:71E;B!N86-H(&1E
M<B!!;FUE;&1U;F<@9'5R8VAF_&AR96X_(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M4F5C:'1E(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB
M"FUS9W-T<B`B4F5C:'0@7"(E<UPB('=U<F1E(&YI8VAT(&=E;/9S8VAT+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C$R"FUS9VED(")097)M
M:7-S:6]N($1E;FEE9"(*;7-G<W1R("):=6=R:69F('9E<G=E:6=E<G0B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4F5C:'1E(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E
M>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4F5C:'1E=F5R=V%L
M='5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R
M<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B4&5R<_9N;&EC:&4@06YG86)E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S
M='(@(DAA=7-T:65R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN
M97,B"FUS9W-T<B`B4&AI;&EP<&EN96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R
M(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(E!I>&5L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(E!L871T:&5I=&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(D)I='1E(&ML:6-K96X@4VEE(&EN(&5I;F4@6F5L;&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`B0FET=&4@8F5S=.1T:6=E;B!3:64L
M(&1A<W,@4VEE(&1I97-E<R!%;&5M96YT(&SV<V-H96X@;?9C:'1E;CHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@HB0FET=&4@8F5TY'1I
M9V5N(%-I92P@9&%S<R!3:64@9&5N($QI;FL@=F]N(&1I97-E;2!%;&5M96YT
M(&5N=&9E<FYE;B!M]F-H=&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U.#`*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE
M87(N(@IM<V=S='(@(D)I='1E(&5I;F5N($UO;F%T('5N9"!E:6X@2F%H<B!A
M;F=E8F5N+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")":71T92!G96)E;B!3:64@96EN96X@
M3F%M96X@9OQR(&1I92!N975E($MA=&5G;W)I92!A;CHB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")":71T92!E:6YE(&?\;'1I9V4@
M25`M061R97-S92!E:6YG96)E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C4X"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R
M("(B"B)":71T92!G96)E;B!3:64@96EN(&?\;'1I9V5S($1A='5M(&%N.R#\
M8F5R<'+\9F5N(%-I92!D:64@6F%H;"!D97(@5&%G92!I;B`B"B)D96T@36]N
M870N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0V-0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B0FET=&4@96EN
M96X@9_QL=&EG96X@6F5I='=E<G0@96EN9V5B96XN(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")":71T92!G96)E
M;B!3:64@96EN92!:=7-A;6UE;F9A<W-U;F<@26AR97,@4')O8FQE;7,@86XN
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")":71T92!G96)E;B!3
M:64@26AR96X@0F5N=71Z97)N86UE;B!U;F0@26AR(%!A<W-W;W)T(&%N(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B
M"B)":71T92!L97-E;B!3:64@<VEC:"!D96X@9F]L9V5N9&5N(%1E>'0@<V]R
M9V;D;'1I9R!D=7)C:"X@4VEE($W<4U-%3B!D:65S96X@(@HB0F5D:6YG=6YG
M96X@>G5S=&EM;65N+"!W96YN(%-I92!D:65S97,@4WES=&5M(&)E;G5T>F5N
M(&WV8VAT96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93HB"FUS9W-T<B`B0FET=&4@9&5N(&YE=65N($MA=&5G;W)I
M96YA;65N(&5I;F=E8F5N.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(E!O;&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W
M"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EK(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B
M56UF<F%G96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G
M<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I=&EO;FEE<G5N9R!D:65S92!"
M:6QD97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R(")0;W-I=&EO;FEE<G5N9R!D:65S97(@5&%B96QL92(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B
M4V5N9&5N(&%N(&1I97-E;B!/<F1N97(@*&YI8VAT(&1U<F-H($E-05`I(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B3FEE9&5R<V-H;&%G(&EN(&1E
M;B!L971Z=&5N("5S(%-T=6YD92AN*3H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC92(*;7-G<W1R(").:65D97)S8VAL86=S+3QB<B`O/G=A:')S8VAE:6YL
M:6-H:V5I="(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HQ
M,#0*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@1&EE(&)E;O9T:6=T
M92!,1$%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!$:64@8F5N]G1I9W1E
M(%-E<W-I;VXM17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(E!R97-S=7)E(@IM
M<V=S='(@(DQU9G1D<G5C:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8Q
M"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("),=69T
M9')U8VL@875F(%-E96CV:&4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B3'5F=&1R
M=6-K.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")6;W)S
M8VAA=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(D5I;F4@5F]R<V-H874@9&5S($)I;&1E
M<R!I;B!E:6YE;2!N975E;2!&96YS=&5R(&%N>F5I9V5N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T
M<B`B5F]H97)I9V4@16EN<W1E;&QU;F=E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(D1O:W5M96YT(&1R=6-K96XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM
M<V=S='(@(E!R:79A=&5R(%-C:&S\<W-E;"(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B
M4')O8FQE;64B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FQE;6)E<V-H<F5I
M8G5N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@
M(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:W1E(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C`V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.30*;7-G:60@(E!R;VUP
M="!T97AT(@IM<V=S='(@(DYA8VAF<F%G971E>'0B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS
M9W-T<B`BUF9F96YT;&EC:&5R(%-C:&S\<W-E;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L
M9V]R:71H;2(*;7-G<W1R(")!;&=O<FET:&UU<R!D97,@]F9F96YT;&EC:&5N
M(%-C:&S\<W-E;',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R
M;6%T:6]N96X@>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96PB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM
M<V=S='(@(D1A<R#V9F9E;G1L:6-H92]P<FEV871E(%-C:&S\<W-E;'!A87(@
M:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED
M(")0=7)G92!M97-S86=E<R(*;7-G<W1R(").86-H<FEC:'1E;B!E;F1G_&QT
M:6<@;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S
M='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")1
M=65R>2(*;7-G<W1R(")!8F9R86=E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@P"FUS9VED(")1=6]T82(*;7-G<W1R(")3<&5I8VAE<G!L871Z+4MO
M;G1I;F=E;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@
M8FET*2(*;7-G<W1R("+69F9E;G1L:6-H97(@4E-!(%-C:&S\<W-E;"`H)60@
M0FET*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.#(*;7-G:60@
M(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")!=7-W86AL:VYO<&8B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B
M4F%I;B(*;7-G<W1R(")296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@
M(D9R_&@@4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(E-PY'1E<B!2
M96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4P"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")296=E;G-C:&%U97(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM
M<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")38VAN965R96=E;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")286EN('1O(%-N;W<B"FUS9W-T<B`B4F5G96X@:6X@4V-H;F5E(/QB97)G
M96AE;F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N
M9&]M($9O<G1U;F4B"FUS9W-T<B`B1VS\8VMS:V5K<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B
M5F5R:.1L=&YI<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q"FUS9VED(")296%D(@IM<V=S='(@(DQE<V5N(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S
M<V%G97,B"FUS9W-T<B`B3F%C:')I8VAT96X@;&5S96XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`B(@HB)7,@=VER:VQI8V@@;/9S8VAE;C\@1&EE
M<V5R(%9O<F=A;F<@:V%N;B!N:6-H="!R_&-K9^1N9VEG(&=E;6%C:'0@=V5R
M9&5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O
M<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"B)$871E;B!D97,@0F5N=71Z97)S("5S('=I<FML:6-H(&SV
M<V-H96X_($1I97-E<B!6;W)G86YG(&MA;FX@;FEC:'0@(@HB<OQC:V?D;F=I
M9R!G96UA8VAT('=E<F1E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R(")&_&AR="!L971Z=&4@06MT:6]N(&5R;F5U="!A=7,B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#0@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C$P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T.`IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")!:W1U86QI<VEE
M<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B1'EN86UI<V-H
M92!-96[\96QE;65N=&4@86MT=6%L:7-I97)E;CHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,X"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*
M;7-G<W1R(")0;W)T86QA;G-I8VAT(&%K='5A;&ES:65R96XZ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I
M9"`B4F5G97@B"FUS9W-T<B`B4F5G=6SD<F5R($%U<V1R=6-K(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP
M($)R;W=S97(B"FUS9W-T<B`B5F5R8FEN9'5N9W,M0G)O=W-E<B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-"!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR,3`*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")!:W1U86QI
M<VEE<F5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C@*;7-G:60@(E)E
M;6%R:W,B"FUS9W-T<B`B0F5M97)K=6YG96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")%
M;G1F97)N=&4@4V5R=F5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B4V5R=F5R861R97-S92`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`B16YT9F5R;F5N(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`B0FQO8VL@;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C
M;VQU;6XB"FUS9W-T<B`B4W!A;'1E(&SV<V-H96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R(")&;W)M871I97)U;F<@96YT9F5R;F5N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V
M92!P86ER(@IM<V=S='(@(E!A87(@;/9S8VAE;B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,#$*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")'97-P
M96EC:&5R=&5S(%-K<FEP="!A=7,@9&5M('1E;7!O<N1R96X@5F5R>F5I8VAN
M:7,@96YT9F5R;F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G
M<W1R(")%;G1F97)N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")$:65S97,@16QE;65N="!A
M=7,@9&5M($1O:W5M96YT(&5N=&9E<FYE;B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S
M='(@(D)E;G5T>F5R(&SV<V-H96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S
M97(Z("5S(@IM<V=S='(@(D)E;G5T>F5R(&SV<V-H96XZ("5S(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#0*;7-G:60@(E)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM
M<V=S='(@(D%N9G)A9V4@:V]N;G1E(&YI8VAT(&)E86YT=V]R=&5T('=E<F1E
M;BX@6G5R_&-K9V5G96)E;F5R($9E:&QE<F-O9&4Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B1&5R(&=E=_QN<V-H
M=&4@1&EE;G-T(&MO;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B7"(E<UPB('=U<F1E(&EN(&1E<B!+;VYF:6=U<F%T:6]N(&;\<B`E
M<R!N:6-H="!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HW,S,@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<W.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB('=U<F1E(&EN(&1E<B!6
M1E,M2V]N9FEG=7)A=&EO;B!N:6-H="!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z.#`P"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(EPB)7-<(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A=&EO;B!N
M:6-H="!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S,V"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(").
M;W1W96YD:6=E<R!&96QD(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,R,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I
M9"`B4F5S970B"FUS9W-T<B`B6G5R_&-K<V5T>F5N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#@*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(E!A<W-W;W)T('IU<OQC:W-E='IE;B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(X"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(E-E='IE;B!3:64@26AR(%!A<W-W;W)T('IU<OQC:R(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G:60@(E)E<W1O<F4@3&%S="!1
M=65R>2(*;7-G<W1R("),971Z=&4@06)F<F%G92!E:6YF_&=E;B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M
M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM<V=S='(@(D5R
M9V5B;FES<V4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/
M<'1I;VYS(@IM<V=S='(@(EIU<OQC:R!Z=2!%:6YS=&5L;'5N9V5N(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(DYE=65S(%!A<W-W;W)T(&5R;F5U="!E
M:6YG96)E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T
M<B`B4NEU;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B2V]N9FEG=7)A=&EO;B!Z=7+\8VMS971Z96XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,B"FUS9W-T<B`B5UE325=91RU%9&ET;W(@16EN<W1E
M;&QU;F=E;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B
M4FED9&QE<R(*;7-G<W1R(")2Y'1S96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM
M<V=S='(@(E)E8VAT<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")296-H=&4@W&)E<G-C
M:')I9G0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED
M(")2:6=H="!V86QU97,B"FUS9W-T<B`B4F5C:'1E(%=E<G1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X
M"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7UIE:6QE;F5I
M9V5N<V-H869T96XN+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E)O;&QE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6WD;FEE
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B56T@,3@PL"!D<F5H96XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S
M"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(").86-H(&QI;FMS(&1R96AE
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(").86-H(')E8VAT<R!D
M<F5H96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("):
M96EL96YE:6=E;G-C:&%F=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I
M97,B"FUS9W-T<B`B6F5I;&5N96EG96YS8VAA9G1E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S
M.B(*;7-G<W1R("):96EL96XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T
M<B`B4F5G96QN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")286AM96X@>G=I
M<V-H96X@86QL96X@6F5I;&5N('5N9"!3<&%L=&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`B4F%H;65N(&YU<B!Z=VES8VAE;B!3<&%L=&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B
M4F%H;65N(&YU<B!Z=VES8VAE;B!:96EL96XB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(Q"FUS9VED(")2=6XB"FUS9W-T<B`B4W1A<G1E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2
M=7-S:7-C:&4@1O9R9&5R871I;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@:W)Y=&]G<F%P:&ES8VAE(%5N
M=&5R<V-H<FEF="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T
M<B`B36ET(%,O34E-12!V97)S8VAL_'-S96QT92!.86-H<FEC:'0B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TPM
M075T:&5N=&EF:7II97)U;F<@:7-T(&YI8VAT('9E<F;\9V)A<BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G
M:6YG(@IM<V=S='(@(E--4RU697)S86YD(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,(%-H96QL(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y,@IM<V=I9"`B4U%,('-T
M871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")344PM06YW96ES
M=6YG('IU<B!!8F9R86=E(&1E<B!797)T92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(D521D],1R(*
M"B,Z(&QI8B]A<&DN<&AP.C(Q.0IM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R
M(")37U%,(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B4V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%I;G0@2&5L
M96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`B4V%I;G0@2VET=',@=6YD($YE=FES(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VXB"FUS9W-T<B`B4V%I;G0@4&EE<G)E('5N9"!-:7%U96QO;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@=6YD(&1I92!'<F5N861I;F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(D=L96EC:&5R
M(%)A:&UE;B`H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B
M"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R
M:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@=6YD
M(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L;&ET
M96YP<F]V:61E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I
M82(*;7-G<W1R(")3875D:2U!<F%B:65N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(E-P96EC:&5R
M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB
M('-P96EC:&5R;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B)7,@<W!E
M:6-H97)N(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B
M4V%V92!/<'1I;VYS(@IM<V=S='(@(D5I;G-T96QL=6YG96X@<W!E:6-H97)N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-@IM<V=I9"`B(@HB4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"B)%<GIE=6=T92!+;VYF:6=U<F%T:6]N(&%L<R!02%`M4VMR:7!T(&EM
M('1E;7!O<N1R96X@5F5R>F5I8VAN:7,@26AR97,@(@HB4V5R=F5R<R!S<&5I
M8VAE<FXN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B)7,M2V]N9FEG=7)A=&EO;B!G97-P96EC:&5R="XB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")$
M87,@06MT=6%L:7-I97)U;F=S<VMR:7!T('=U<F1E(&EN(%PB)7-<(B!G97-P
M96EC:&5R="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(E9E
M<F5I;GIE;'1E($=E=VET=&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(E=I<W-E;G-C:&%F="(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B
M4W5C:&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED
M(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")3=6-H;6%S8VAI;F5N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I
M;&5S(@IM<V=S='(@(D1A=&5I96X@875S=^1H;&5N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T
M(&$@9&%T92(*;7-G<W1R(")$871U;2!A=7-WY&AL96XB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.0IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(DAI;GIU>G5F_&=E;F1E($=R=7!P96X@875S=^1H
M;&5N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT-`IM<V=I9"`B
M4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(DYE=65N($)E<VET>F5R(&%U
M<W?D:&QE;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM
M<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E-E<G9E<B!A=7-WY&AL
M96XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-PIM<V=I9"`B
M4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B2&EN>G5Z=6;\9V5N9&5N
M($)E;G5T>F5R(&%U<W?D:&QE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`B06QL92!A=7-WY&AL96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C8Q"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS
M9W-T<B`B3&5G96X@4VEE(&%L;&4@1&%T=6US:V]M<&]N96YT96X@9F5S="XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S
M"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(D]B:F5K="!A=7-W
MY&AL96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<W"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")+96EN96X@875S
M=^1H;&5N(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B
M"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB5^1H;&5N(%-I92!D
M:64@8F5N]G1I9W1E;B!:96EC:&5N(&%U<R!D96X@:F5W96EL:6=E;B!&96QD
M97)N(&%U<RX@1&%N;B`B"B)K]FYN96X@4VEE(&1I97-E(&%U<R!D96T@5&5X
M=&9E;&0@:V]P:65R96X@=6YD(&EN($EH<F4@3F%C:')I8VAT(&5I;F;\9V5N
M+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1A
M<R!$871U;7-T<F5N;GIE:6-H96XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S
M='(@(E?D:&QE;B!3:64@9&%S($1A='5M<V9O<FUA=#HB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDR"FUS9VED(")396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B5^1H
M;&5N(%-I92!D:64@261E;G1I=.1T+"!D:64@4VEE(.1N9&5R;B!M]F-H=&5N
M.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1A
M<R!:96ET=')E;FYZ96EC:&5N.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R
M(")7Y&AL96X@4VEE(&1A<R!:96ET9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+B(*;7-G<W1R(")7Y&AL96X@4VEE('IW96D@>G5S86UM96YG96CV
M<FEG92!&96QD97(@875S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,#,*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
M5^1H;&5N(%-I92!E:6X@1F%R8G-C:&5M82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C0T"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z(@IM<V=S='(@(E?D:&QE;B!3:64@26AR92!B979O<GIU9W1E(%-P
M<F%C:&4Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*
M;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4')O8FQE;6)E
M<FEC:'0@86)S8VAI8VME;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R(")3
M35,@=F5R<V-H:6-K96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L
M(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q
M.`IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B`B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E
M;F5G<F\B"FUS9W-T<B`B4V5R8FEE;B!U;F0@36]N=&5N96=R;R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(E-E<FEE;FYU;6UE<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-E<G9E<F1A=&5N('5N
M9_QL=&EG(&]D97(@;FEC:'0@=F5R9OQG8F%R+B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")397-S
M<VEO;G9E<G=A;'1U;F<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B4V5S<VEO;BU)1"!A8F=E;&%U9F5N+B(*"B,Z(&QI8B]A
M<&DN<&AP.C(Q,0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4VET>G5N9V5N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,S,@IM<V=I9"`B4V5T
M(@IM<V=S='(@(D%U<W=A:&PM4V%T>B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G
M<W1R("(B"B),96=E;B!3:64@9&EE($5I;G-T96QL=6YG96X@9F5S="P@9&EE
M(&5S($EH;F5N(&5R;&%U8F5N($EH<B!087-S=V]R="`B"B)Z=7+\8VMZ=7-E
M='IE;BP@9F%L;',@<VEE(&5S(&5I;FUA;"!V97)G97-S96X@<V]L;'1E;BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HB3&5G96X@4VEE(&5N=&9E<FYT92!3
M97)V97(@9F5S="P@875F(&1I92!3:64@=F]N($EH<F5M(%!O<G1A;"!A=7,@
M>G5G<F5I9F5N("(*(FWV8VAT96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(E?D:&QE;B!3:64@
M26AR92!B979O<GIU9W1E(%-P<F%C:&4L(%IE:71Z;VYE('5N9"!$871U;7-E
M:6YS=&5L;'5N9V5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*
M;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA
M>2!O<'1I;VYS+B(*;7-G<W1R("(B"B),96=E;B!3:64@9&%S(&1I92!3=&%R
M=&%N=V5N9'5N9RP@9&%S($9A<F)S8VAE;6$L(&1I92!396ET96YA:W1U86QI
M<VEE<G5N9R`B"B)U;F0@86YD97)E($%N>F5I9V5E:6YS=&5L;'5N9V5N(&9E
M<W0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T
M=7`B"FUS9W-T<B`B2V]N9FEG=7)A=&EO;B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE(@IM<V=S='(@(D%K='5A;&ES:65R=6YG<W-K<FEP
M=&4@<VEN9"!V97)F_&=B87(B"@HC($UE:')E<F4@<&%S<V5N9&4@3W)T92!M
M:70@9&EE<V5M(%!A<F%M971E<CH@"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(DUE:')E<F4@<&%S<V5N
M9&4@3W)T92!M:70@9&EE<V5M(%!A<F%M971E<CH@(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC:&5L;&5N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B
M"FUS9W-T<B`B16EN:V%U9B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMU<GIE
M(%IU<V%M;65N9F%S<W5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#,*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/R(*;7-G<W1R(")3;VQL96X@5&%S=&5N:V]M8FEN871I;VYE
M;B!F_'(@9&EE(&UE:7-T96X@3&EN:W,@86MT:79I97)T('=E<F1E;C\B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B
M4VAO=R(*;7-G<W1R("):96EG96XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,34T"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(E5N=&5R<V-H:65D92!Z=VES8VAE;B!D
M97(@86MT=65L;&5N('5N9"!D97(@9V5R861E(&5R>F5U9W1E;B!+;VYF:6=U
M<F%T:6]N("(*(F%N>F5I9V5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.#<*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\B"FUS9W-T<B`B06YZ96EG96XL('=A;FX@9&EE(&QE='IT92!!;FUE
M;&1U;F<@97)F;VQG="!I<W0_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*
M;7-G<W1R(")%<FAA;'1E;B!D97,@3W)I9VEN86QS(&5R;?9G;&EC:&5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P
M:6-K97(B"FUS9W-T<B`B075S=^1H;&5R(&%N>F5I9V5N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R,PIM<V=I9"`B4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")797)K>F5U9VQE:7-T92!F_'(@5&%B
M96QL96X@86YZ96EG96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H
M92!L969T/R(*;7-G<W1R(")$87,@)7,M365N_"!A=68@9&5R(&QI;FME;B!3
M96ET92!A;GIE:6=E;C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1&EA;&]G(&;\<B!4
M86)E;&QE;GIE;&QE;F5I9V5N<V-H869T96X@86YZ96EG96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(D1I86QO9R!F_'(@5&%B96QL96YE:6=E;G-C:&%F=&5N(&%N>F5I9V5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B1&EA;&]G(&;\<B!486)E;&QE;GIE:6QE;F5I
M9V5N<V-H869T96X@86YZ96EG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D1I86QO9R!F_'(@
M0FEL9&5I9V5N<V-H869T96X@86YZ96EG96XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")(
M;V-H;&%D96X@97)M]F=L:6-H96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")3
M8VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-34*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B1G+\:"!38VAA
M=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-38*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")3<.1T97(@4V-H875E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")38VAA
M=65R(&EN(&1E<B!5;6=E8G5N9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T
M<B`B5F5R:VQE:6YE<FXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X
M-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E9E<FML96EN97)N(&]D
M97(@=F5R<V-H:65B96X@4VEE(&5R<W0@9&EE(&)E;F%C:&)A<G1E;B!";/9C
M:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T
M<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")296=I<W1R:65R
M96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM
M<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA='5R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R
M92!!;&=O<FET:&TB"FUS9W-T<B`B4VEG;F%T=7)A;&=O<FET:&UU<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!U
M<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I
M>F4B"FUS9W-T<B`B1W+VWV4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*
M;7-G<W1R(")787)T=6YG<V%R8F5I=&5N(/QB97)S<')I;F=E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W=A:V5I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=V5N
M:65N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<B"FUS9W-T<B`B4V-H;F5E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO
M=V5R(@IM<V=S='(@(E-C:&YE97-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B4VYO=R!3:&]W97)S
M(@IM<V=S='(@(E-C:&YE97-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B4VYO=R!3:&]W97)S($5A
M<FQY(@IM<V=S='(@(D9R_&@@4V-H;F5E<V-H875E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")3;F]W(%-H
M;W=E<G,@3&%T92(*;7-G<W1R(")3<.1T97(@4V-H;F5E<V-H875E<B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@P"FUS9VED(")3;F]W(&1E<'1H.B`B
M"FUS9W-T<B`B4V-H;F5E:/9H93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.#0*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S
M='(@(E-C:&YE96UE;F=E(&%L<R!787-S97(Z("(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")3;VQO;6]N:6YS96QN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA
M;&EE;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N
M9W,@)B!0;V5M<R(*;7-G<W1R("),:65D97(@)B!'961I8VAT92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@
M<V5L96-T:6]N(@IM<V=S='(@(D%U<W=A:&P@9&5R(%-O<G1I97)R96EH96YF
M;VQG92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@
M(E5R<W!R=6YG<V%D<F5S<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T
M:"!!9G)I8V$B"FUS9W-T<B`B4_QD869R:6MA(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*2(*;7-G<W1R(")3_&1E=7)O<.1I<V-H("A)4T\M.#@U.2TS*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4_QD9V5O<F=I96X@=6YD(&1I92!3
M_&1L:6-H96X@4V%N9'=I8VAI;G-E;&XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(E/\9&QI8VAE($AE;6ES<&AE<F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")!8G-T
M86YD('IW:7-C:&5N(&%U9F5I;F%N9&5R(&9O;&=E;F1E;B!:96QL96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R(")!8G-T86YD('IW:7-C:&5N($EN:&%L="!U;F0@4F%H;65N
M('9O;B!:96QL96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*
M;7-G:60@(E-P86-E<B(*;7-G<W1R(")!8G-T86YD:&%L=&5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS
M9VED(")3<&%C:6YG(@IM<V=S='(@(D%B<W1A;F0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3
M<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(D%B<W3D;F1E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(E-P86YI96XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@
M(E-P86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P
M96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(E-O;F1E<GIE:6-H96XM
M16EN9V%B92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B6F5L
M;&4@=&5I;&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@
M(E-P86QT92!T96EL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T
M<B`B6F5I;&4@=&5I;&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q
M"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<F0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G
M<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C`T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T
M('EE87(B"FUS9W-T<B`B4W1A<G1J86AR(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(D)U;F1E<W-T86%T(&]D97(@4')O=FEN>B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B
M"FUS9W-T<B`B4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B4W!E:6-H97)F
M;W)M870B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B4W1R8=]E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")$=7)C:&=E<W1R:6-H96XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R("):96EC:&5N;&ES=&4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#DQ"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@
M861D<F5S<R(*;7-G<W1R(")$;VUA:6X@875S(&1E<B!!9')E<W-E(&5N=&9E
M<FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T:6P@
M6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")3;R(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B56YT97)V97)Z96EC:&YI
M<R!<(B5S7"(@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G
M<W1R(")"971R969F(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`IM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(D%B<V-H:6-K96XB"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@
M=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G
M<W1R("(B"B)$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E(&;\<B!<(B5S7"(@
M=W5R9&4@86)G97-C:&EC:W0N(%-I92!K]FYN96X@<VEC:"!N;V-H("(*(FYI
M8VAT(&%N;65L9&5N+"!S;VQA;F=E(&1I92!!;F9R86=E(&YO8V@@;FEC:'0@
M8F5S=.1T:6=T('=U<F1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")4
M:65F9V5S=&5L;'0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B17)F;VQG(@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@:&EN>G5G96;\9W0N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B1&%T96X@9&5S($)E;G5T>F5R<R!<(B5S7"(@
M=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T
M<B`B7"(E<UPB('=U<F1E(&5R9F]L9W)E:6-H(&=E;/9S8VAT+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB
M"FUS9W-T<B`B(@HB2V]N9FEG=7)A=&EO;B!E<F9O;&=R96EC:"!Z=7+\8VMG
M97-E='IT+B!396ET92!N974@;&%D96XL('5M(&1I92#$;F1E<G5N9V5N("(*
M(F%N>G5Z96EG96XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D)A8VMU<"!D
M97(@2V]N9FEG=7)A=&EO;B!E<F9O;&=R96EC:"!G97-P96EC:&5R="XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N
M("5S(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D
M871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB('=U<F1E(&5R9F]L9W)E:6-H
M(&%K='5A;&ES:65R="(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!W=7)D92!E<F9O
M;&=R96EC:"!G97-P96EC:&5R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G
M<W1R("):=7-A;6UE;F9A<W-U;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-O;FYE;F%U9F=A;F<B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B
M"FUS9W-T<B`B4V]N;F5N=6YT97)G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E-U;FYY(@IM<V=S='(@
M(E-O;FYI9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*
M;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B4V]N;F5N875F9V%N9R(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B4V]N;F5N875F+W5N
M=&5R9V%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*
M;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")3;VYN96YA=69G86YG.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B4V]N;F5N=6YT97)G86YG(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B
M4V]N;F5N=6YT97)G86YG.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R
M(")(;V-H9V5S=&5L;'0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E-U<'!O<G0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U
M<FYA;64B"FUS9W-T<B`B3F%C:&YA;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D('5N
M9"!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B
M"FUS9W-T<B`B4W=A<VEL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E
M9&5N(@IM<V=S='(@(E-C:'=E9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W
M:71Z97)L86YD(@IM<V=S='(@(E-C:'=E:7HB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G
M<W1R(")3>6YC:')O;FEZ871I;VYS;&]G(&=E;/9S8VAT(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D9O<FUA=&9E:&QE<B!I;B!3
M=6-H8F5G<FEF9F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R
M86(@4F5P=6)L:6,B"FUS9W-T<B`B07)A8FES8VAE(%)E<'5B;&EK(%-Y<FEE
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T
M"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D=E=VET=&5R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O
M<FT@86YD(%=I;F1Y(@IM<V=S='(@(D=E=VET=&5R('5N9"!7:6YD:6<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I
M9"`B5"U3=&]R;7,B"FUS9W-T<B`B1V5W:71T97(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5"U3=&]R;7,@
M16%R;'DB"FUS9W-T<B`B1G+\:"!'97=I='1E<B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O='-V+G!H<#HQ-S`*;7-G:60@(E135B!F:6QE(@IM<V=S='(@
M(E135BU$871E:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS
M9W-T<B`B5&%B96QL96YE:6=E;G-C:&%F=&5N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T
M(@IM<V=S='(@(E1A8F5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T
M:65S(@IM<V=S='(@(E1A8F5L;&5N96EG96YS8VAA9G1E;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486EW86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL(&-H
M:6YE<VES8VAE(%!R;W9I;GHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II
M:VES=&%N(@IM<V=S='(@(E1A9'-C:&EK:7-T86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(E9E<F5I;FEG=&4@4F5P=6)L:6L@5&%N<V%N:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z
M(@IM<V=S='(@(EII96PZ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY-3@@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3D*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B075F
M9V%B96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")496QE9F]N;G5M
M;65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3(*;7-G:60@(E1E;7`@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7!E<F%T=7(@9&5R(&QE='IT
M96X@4W1U;F1E.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I
M9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E
M.B`B"FUS9W-T<B`B5&5M<&5R871U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E
M;7!E<F%T=7(\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B5F]R;&%G92!<(B5S7"(@;FEC:'0@9V5F=6YD96XN(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(E9O<FQA9V5N=F5R=V%L='5N9R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,T-0IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W,@IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(DYU
M<B!497AT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")!=7-R
M:6-H='5N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5X="!/8F5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM
M<V=I9"`B5&@B"FUS9W-T<B`B1&\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA:6SD;F1I
M<V-H("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD
M(@IM<V=S='(@(E1H86EL86YD(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-C,*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(D1I92!&5%`M17AT96YS:6]N(&ES="!N:6-H="!V
M97)F_&=B87(N(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z
M-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B1&EE($-H<F]N:6L@<W1E:'0@;FEC:'0@>G5R(%9E<F;\9W5N9RXB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDV-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(D1I92!(;W)D92]+
M;VQA8B!);G1E9W)A=&EO;G-F=6YK=&EO;F5N('5N=&5R<W3\='IE;B!<(B5S
M7"(@;FEC:'0B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H
M<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+B(*;7-G<W1R(")$:64@24U34"U,;V=D871E:2!K;VYN=&4@;FEC
M:'0@97)S=&5L;'0@=V5R9&5N+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")$:64@36%I;G1E;F%N8V4Z
M.B!+;&%S<V4@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N(@H*(SH@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(D1A
M<R!%:6YS=&5L;'5N9V5N+49E;G-T97(@:7-T(&=E<V-H;&]S<V5N('=O<F1E
M;BX@06)B<G5C:"XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$Y
M,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(Q,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(U,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(V-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P-`IM<V=I
M9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@
M=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)$97(@061M:6YI<W1R
M871O<B!M=7-S(&5I;B!P97)M86YE;G1E<R!296-H=&4M0F%C:V5N9"!E:6YR
M:6-H=&5N+"!W96YN(%-I92`B"B)D:64@4F5C:'1E=F5R=V%L='5N9R!N=71Z
M96X@;?9C:'1E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL
M>2(*;7-G<W1R(").=7(@=6YT96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B
M"B)$:64@240M3G5M;65R(&1E<R!+;VYT86MT<R!W=7)D92!N:6-H="!A;F=E
M8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I;B!D97(@(@HB1&%T96YB86YK
M(&YI8VAT(&=E9G5N9&5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(D1E<B!+;VYT86MT('=U<F1E(&5R9F]L9W)E:6-H($EH<F5M($%D
M<F5S<V)U8V@@:&EN>G5G96;\9W0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$X,0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S
M:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B(@HB1&5R(%!'4"U3:6=N871U<F)L;V-K
M('=I<F0@8F5N]G1I9W0L('5M(&1I92!U;G1E<GIE:6-H;F5T92!.86-H<FEC
M:'0@>G4@(@HB_&)E<G!R_&9E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G
M<W1R("(B"B)$:64@240M3G5M;65R(&1E<B!697)T96EL97)L:7-T92!W=7)D
M92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92`B"B)I;B!D
M97(@1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E<F1E;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I
M9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*
M;7-G<W1R(")$:64@5F5R=&5I;&5R;&ES=&4@=W5R9&4@;FEC:'0@86YG96=E
M8F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)$:64@5F5R<V-H;/QS<V5L=6YG
M<V9U;FMT:6]N96X@8F5N]G1I9V5N(&5I;F4@<VEC:&5R92!397)V97)V97)B
M:6YD=6YG+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@V(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB
M"FUS9W-T<B`B1&EE($1A=&5I("5S('-O;&QT92!E:6YE;B`E<R!%:6YT<F%G
M(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W
M.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+B(*;7-G<W1R(")$:64@1&%T96D@)7,@<V]L;'1E(&5I;FEG92`E
M<R!%:6YT<N1G92!E;G1H86QT96XN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB
M"FUS9W-T<B`B1&EE($1A=&5I(&5N=&AI96QT(&ME:6YE($1A=&5N+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(DAI97(@<VEN9"!D:64@
M2V]P9F5I;G1RY&=E(&;\<B!D:65S92!M97-S86=E+W)F8S@R,B!.86-H<FEC
M:'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+B(*;7-G<W1R("(B"B)$97(@5F]L;&)I;&1M;V1U<R!V97)U<G-A
M8VAT(&%U9B!'<G5N9"!V;VX@1F5H;&5R;B!I;2!);G1E<FYE="!%>'!L;W)E
M<B`B"B)B96MA;FYT97)M8=]E;B!0<F]B;&5M92!M:70@9&EE<V5M($)R;W=S
M97(L(&1I92!W:7(@;FEC:'0@=6UG96AE;B!K]FYN96XN("(*(E5N=&5R(%5M
M<W3D;F1E;B!E<FAA;'1E;B!3:64@96EN92!F96AL97)H869T92!!;GIE:6=E
M+"!F96AL96X@(@HB161I=&]R9G5N:W1I;VYE;BP@;V1E<B!D97(@0G)O=W-E
M<B!S=/QR>G0@86(N($%U9B!E:6YE;2!7:6YD;W<@.7@@4WES=&5M("(*(G=E
M<F1E;B!3:64@=F5R;75T;&EC:"!E:6YE("=!;&QG96UE:6YE(%-C:'5T>G9E
M<FQE='IU;F<G(&5R:&%L=&5N('5N9"!M_'-S96X@(@HB9&5N(%)E8VAN97(@
M;F5U('-T87)T96XN7%QN7%QN4VEE('=U<F1E;B!G97=A<FYT+B!":71T92!D
M<OQC:V5N(%-I92!A=68@3TLL("(*(G=E;FX@4VEE(&YO8V@@:6UM97(@9&5N
M(%9O;&QB:6QD;6]D=7,@=F5R=V5N9&5N(&WV8VAT96XN(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E
M;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D1I92!)
M9&5N=&ETY'0@7"(E<UPB('=U<F1E(&=E;/9S8VAT+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@
M(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DYU<B!L:6YK<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B
M(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*(D1E
M<B!/<G0@9&5S($=N=5!'+5!R;V=R86UM<R!M=7-S(&1E<B!#<GEP=%]P9W`Z
M.B!+;&%S<V4@_&)E<F=E8F5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<
M(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"XB"FUS9W-T<B`B(@HB1&EE($YA8VAR:6-H="!M:70@9&5M($)E=')E9F8@
M7"(E,R1S7"(L(&1I92!A;2`E,21S(&%N("4R)',@9V5S8VAI8VMT('=U<F1E
M+"`B"B)I<W0@86YG97IE:6=T('=O<F1E;BY<;B(*(D1A<R!H96G?="!N:6-H
M="P@9&%S<R!D:64@3F%C:')I8VAT(&%U8V@@9V5L97-E;B!O9&5R('9E<G-T
M86YD96X@=W5R9&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Y
M-0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@
M8V]M<&]S92!P86=E(@IM<V=S='(@(DYA;64@9OQR(&1E;B!,:6YK('IU<B!.
M86-H<FEC:'1E;F5R<W1E;&QU;F<B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@
M8F4@;G5M97)I8RXB"FUS9W-T<B`B1&EE($%N>F%H;"!D97(@1F5L9&5R(&UU
M<W,@86QS(%IA:&P@86YG96=E8F5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N(@IM<V=S='(@(D1A<R!/<&5N4U-,+4UO9'5L('=I<F0@9OQR
M(&1I92!(;W)D95]#<GEP=%]S;6EM93HZ($ML87-S92!B96[V=&EG="XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(X.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB1&EE($)E;G5T>F5R96EN
M<W1E;&QU;F<@7"(E<UPB(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D
M96XL('=E:6P@:6AR92`B"B)$871E;B!D:64@;6%X:6UA;"!E<FQA=6)T92!'
M<O;?92#\8F5R<V-H<F5I=&5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)$87,@
M4')O9W)A;6T@9OQR(&1I92!!;GIE:6=E(&1I97-E<R!$871E:71Y<',@*"5S
M*2!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B1&%S($%N9OQH
M<G5N9W-Z96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE<R!:96EC:&5N(&%N9V5G
M96)E;B!W97)D96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'DB"FUS9W-T<B`B3G5R(&QI;FMS('5N9"!R96-H=',B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M3G5R(')E8VAT<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W
M.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+B(*;7-G<W1R(")$87,@5')E;FYZ96EC:&5N(&UU<W,@86QS(&5I
M;GIE;&YE<R!:96EC:&5N(&%N9V5G96)E;B!W97)D96XN(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M1&5R(%-E<G9E<B!<(B5S7"(@=W5R9&4@96YT9F5R;G0N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(D1E
M<B!397)V97(@7"(E<UPB('=U<F1E(&=E<W!E:6-H97)T+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(D1I
M92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S('=U<F1E(&5N=&9E<FYT
M+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W
M("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1I92!A;F=E9V5B96YE
M(%IE:6QE("@E9"D@97AI<W1I97)T(&YI8VAT+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(D1I92!T96UP;W+D<F4@1&%T96D@7"(E<UPB(&5X:7-T:65R="!N:6-H="XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(P"FUS9VED(")4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN(@IM<V=S='(@(B(*(D1E<B!497AT+"!D96X@4VEE(&%N9V5G
M96)E;B!H86)E;BP@96YT<W!R:6-H="!N:6-H="!D96T@5&5X="!A=68@9&5M
M("(*(D)I;&1S8VAI<FTN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B3G5R(&]B96X@=6YD('5N=&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B3G5R(&]B
M96XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H
M92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S
M=&5P+B(*;7-G<W1R("(B"B)$:64@:&]C:&=E;&%D96YE;B!$871E;B!S:6YD
M(&YA8V@@9&5M(&QE='IT96X@4V-H<FET="!V97)L;W)E;B!G96=A;F=E;BXB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-S8*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B1&EE(&AO8VAG96QA
M9&5N92!$871E:2!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@
M8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1&5R('=E871H97(N
M8V]M($)L;V-K(&ES="!N:6-H="!V97)F_&=B87(N(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B5&AE;65N+59E
M<GIE:6-H;FES(%PB)7-<(B!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(")%<R!S:6YD(&ME:6YE($5I
M;G-T96QL=6YG96X@=F5R9OQG8F%R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D5S(&=I
M8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C:')I8VAT96YT96EL92XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)$:65S97,@
M1F5L9"!E;G1HY&QT('IU('9I96QE(%IE:6-H96XN(%-I92!H86)E;B`E<R!:
M96EC:&5N(&%N9V5G96)E;CL@4VEE("(*(FW\<W-E;B!W96YI9V5R(&%L<R`E
M<R!A;F=E8F5N+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(D)E:6T@
M2&EN>G5F_&=E;B!V;VX@7"(E<UPB('IU;2!3>7-T96T@:7-T(&5I;B!0<F]B
M;&5M(&%U9F=E=')E=&5N.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(B(*(D)E:6T@3/9S8VAE;B!D97(@1&%T96X@=F]N($)E;G5T>F5R
M(%PB)7-<(B!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ("(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ
M("(*;7-G<W1R(")"96EM($SV<V-H96X@=F]N(%PB)7-<(B!A=7,@9&5M(%-Y
M<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ("(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B0F5I;2!!
M:W1U86QI<VEE<F5N('9O;B!<(B5S7"(@:7-T(&5I;B!0<F]B;&5M(&%U9F=E
M=')E=&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM
M<V=S='(@(B(*(D)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I<W0@96EN($9E
M:&QE<B!A=69G971R971E;BX@)7,@=W5R9&4@;FEC:'0@(@HB:&]C:&=E;&%D
M96XN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,P"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*(D)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I<W0@96EN($9E:&QE<B!A
M=69G971R971E;BX@)7,@=V%R(&=R]M]E<B!A;',@9&EE("(*(FUA>&EM86P@
M97)L875B=&4@1W+VWV4@*"5D($)Y=&5S*2XB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB
M0F5I;2!(;V-H;&%D96X@9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E
M=')E=&5N+B`E<R!W=7)D92!N=7(@=&5I;'=E:7-E("(*(FAO8VAG96QA9&5N
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(D)E:6T@06YZ96EG96X@9&EE<V5S($YA
M8VAR:6-H=&5N=&5I;',@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+B(*;7-G<W1R(")"96EM($EM<&]R=&EE<F5N(&1E<B!+;VYT86MT9&%T
M96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]I;6,N<&AP.C,P"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B0F5I
M;2!);7!O<G1I97)E;B!D97(@:4-A;&5N9&%R($1A=&5N(&ES="!E:6X@1F5H
M;&5R(&%U9F=E=')E=&5N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I
M<F5D(&9I96QD+B(*;7-G<W1R("(B"B)$87,@2V]N9FEG=7)A=&EO;G,M1F]R
M;75L87(@96YT:&EE;'0@96EN96X@1F5H;&5R+B!6:65L;&5I8VAT(&AA8F5N
M(%-I92!E:6X@(@HB4&9L:6-H=&9E;&0@;&5E<B!G96QA<W-E;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D)E:6T@075S9OQH<F5N(&1E<B!A
M;F=E9V5B96YE;B!!9')E<W-B=6-H9G5N:W1I;VX@:7-T(&5I;B!&96AL97(@
M(@HB875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R
M(&YO8V@@96EN;6%L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB0F5I(&1E<B!!:W1U86QI<VEE<G5N
M9R!D97(@2V]N=&%K=&1E=&%I;',@:7-T(&5I;B!&96AL97(@875F9V5T<F5T
M96XN($)I='1E("(*(G9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN
M;6%L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"B)"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!697)T
M96EL97)L:7-T92!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@
M(@HB=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Y.0IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B1&EE<V5R($E-05`M4V5R=F5R('5N=&5R<W3\='IT
M(&ME:6YE(&=E;65I;G-A;65N($]R9&YE<BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")$
M:65S('-C:&5I;G0@:V5I;B!G_&QT:6=E<R!205(M07)C:&EV('IU('-E:6XN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`B1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@6DE0
M+4%R8VAI=B!Z=2!S96EN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")$:65S('-C:&5I;G0@:V5I;F4@9_QL
M=&EG92!+87)T96YN=6UM97(@>G4@<V5I;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1I97-E<B!4
M<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E
M;B!D=7)C:"!D96X@0VQI8VMA=&5L;"TB"B)'871E=V%Y("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)$:65S97(@5')E:6)E<B!E
M<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@
M9&5N(%=)3BU'871E=V%Y("(*(BAH='1P.B\O=VEN<&QC+F-O;2D@;6ET($AI
M;&9E(&1E<B!(5%10+4%022XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M
M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1I97-E<B!4<F5I8F5R(&5R;&%U
M8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@
M<VUS,FUA:6PM(@HB1V%T97=A>2`H:'1T<#HO+W-M<S)M86EL+F-O;2D@;6ET
M($AI;&9E(&1E<B!(5%10+4%022XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR
M;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB
M"FUS9W-T<B`B(@HB1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H
M:6-K96X@=F]N($YA8VAR:6-H=&5N('!E<B!33510(&1U<F-H(&1E;B`B"B)6
M;V1A9F]N92U)=&%L:65N+4=A=&5W87D@875S<V-H;&EEWVQI8V@@86X@5F]D
M869O;F4M3G5M;65R;BX@1&%F_'(@=VER9"!E:6X@(@HB12U-86EL+4MO;G1O
M(&)E:2!6;V1A9F]N92!)=&%L:65N("AH='1P.B\O=W=W+C$Y,"YI="D@8F5N
M]G1I9W0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#0W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.38*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0V.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@S,0IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB"FUS9W-T<B`B1&EE<V5S($9E;&0@:7-T(&YO='=E;F1I9RXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(D1I97-E
M<R!&96QD(&1A<F8@;G5R(&=A;GIE(%IA:&QE;B!E;G1H86QT96XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0S-`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS
M9W-T<B`B1&EE<V5S($9E;&0@9&%R9B!N=7(@6F%H;&5N('5N9"!E:6YE;B!0
M=6YK="!E;G1H86QT96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RXB"FUS9W-T<B`B1&EE<V5S($9E;&0@9&%R9B!N=7(@3VMT86QZ
M86AL96X@96YT:&%L=&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P
M86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*(D1I
M97-E<R!&96QD(&UU<W,@96EN92!K;VUM82T@;V1E<B!L965R>F5I8VAE;F=E
M=')E;FYT92!,:7-T92!V;VX@9V%N>F5N("(*(EIA:&QE;B!E;G1H86QT96XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B1&EE<V5S
M($9E;&0@;75S<R!E:6YE(&?\;'1I9V4@6F%H;"!E;G1H86QT96XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B
M"B)$:65S97,@1F5L9"!M=7-S(&5I;F5N($9A<F)W97)T(&EM(&AE>&%D97II
M;6%L96X@4D="+49O<FUA="!E;G1H86QT96XL('HN($(N("(*(B<C,3(S-&%F
M)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
M1&EE<V5S($9O<FUU;&%R('=U<F1E(&)E<F5I=',@=F5R87)B96ET970N(@H*
M(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B1&EE<R!I<W0@)7,N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE
M87-E('9I<VET("5S(@IM<V=S='(@(B(*(D1I92!I<W0@96EN($MO;&%B+4=R
M;W5P=V%R92U/8FIE:W0N(%5M(&1I97-E<R!/8FIE:W0@86YZ=7IE:6=E;BP@
M8F5N]G1I9V5N("(*(E-I92!E:6X@12U-86EL+5!R;V=R86UM+"!D87,@9&%S
M($MO;&%B+4=R;W5P=V%R92U&;W)M870@=6YT97)S=/QT>G0N($5I;F4@(@HB
M3&ES=&4@<V]L8VAE<B!0<F]G<F%M;64@9FEN9&5N(%-I92!U;G1E<B`E<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B(@HB1&EE<V4@3F%C:')I8VAT('=U<F1E(&EN(&5I;F5M(%IE:6-H
M96YS871Z("@E<RD@97)S=&5L;'0L(&1E<B!N:6-H="!):')E;2`B"B)E:6=E
M;F5N(&5N='-P<FEC:'0N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+B(*;7-G<W1R(")$:65S92!:86AL(&UU<W,@,2!O9&5R(&=R]M]E<B!S
M96EN+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(D1I97-E<B!397)V97(@:V%N;B!:
M25`M('5N9"!'6DE0+41A=&5I;B!N:6-H="!E;G1P86-K96XN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#8*;7-G:60@(E1H
M:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B
M1&EE<V5S(%-Y<W1E;2!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B1&EE<V5R(%=E<G0@
M;75S<R!E:6YE(%IA:&P@<V5I;BXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(D1I97-E<R!&
M96YS=&5R(&UU<W,@=F]N(&5I;F5M($5I;G-T96QL=6YG96XM1F5N<W1E<B!G
M9?9F9FYE="!W97)D96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")$;VYN97(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K
M971S(@IM<V=S='(@(E1I8VME=',B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#0S('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-PIM<V=I
M9"`B5&EM92(*;7-G<W1R("):96ET(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("):96ET
M97)F87-S=6YG(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4
M:6UE(&9O<FUA="(*;7-G<W1R("):96ET9F]R;6%T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4T.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS
M9W-T<B`B6F5I=&%U<W=A:&PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO
M<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I=&5L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B
M5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")4:71E;"`H5&]O;'1I<"DZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B06XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B
M"B)(86QT96X@4VEE(&)E:6T@2VQI8VME;B!3=')G(&)Z=RX@*%!#*2!#;VUM
M86YD("A-86,I(&=E9'+\8VMT+"!U;2!M96AR97)E("(*(D5I;G1RY&=E(&%U
M<WIU=^1H;&5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DAE=71E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE
M($A434P@4V]U<F-E(@IM<V=S='(@(EIU($A434PM475E;&QC;V1E('5M<V-H
M86QT96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O
M9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O
M:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS
M9VED(")4;VUO<G)O=R(*;7-G<W1R(")-;W)G96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV86QI
M9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@(EIU
M('9I96QE('5N9_QL=&EG92!!;FUE;&1E=F5R<W5C:&4@:6X@9&5N(&QE='IT
M96X@36EN=71E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")/8F5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM
M<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("+$==]E<G-T97(@4F%H
M;65N("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(MQB97)S971Z=6YG96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@
M(E1R:6YI9&%D('5N9"!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E=A:'(@
M;V1E<B!F86QS8V@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")$:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N97-I96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5/QR:V5I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(E3\<FMI<V-H("A)4T\M.#@U.2TY*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N
M:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',B"FUS9W-T<B`B5'5R:W,M('5N9"!#86EC;W-I;G-E;&XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,PIM<V=I9"`B5'EP92!Y;W5R
M(&-H;VEC93H@(@IM<V=S='(@(DEH<F4@075S=V%H;#H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@
M(@IM<V=S='(@(E56+4EN9&5X.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W
M"FUS9VED(")54DPB"FUS9W-T<B`B2&]M97!A9V4B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),
M(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S
M='(@(E523"!):')E<R!3:W)I<'1S(&;\<B!D96X@5F5R<V%N9'-T871U<V)E
M<FEC:'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(D%D<F5S<V4Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN92(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0R.`IM<V=I9"`B56YA8FQE
M('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!=68@9&%S(%9&
M4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@>G5G96=R:69F96X@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@HB1&EE('IU<^1T>FQI8VAE;B!"96YU
M='IE<FEN9F]R;6%T:6]N96X@:V]N;G1E;B!B96D@9&5R(%)E9VES=')I97)U
M;F<@;FEC:'0@(@HB:&EN>G5F_&=T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@HB1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D:64@5D93+41A
M=&5I(%PB)7-<(B!K;VYN=&5N(&YI8VAT(&=EY&YD97)T('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#$@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*
M;7-G<W1R("(B"B)$:64@6G5G<FEF9G-R96-H=&4@9OQR(&1I92!61E,M1&%T
M96D@)7,O)7,@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B17,@:V%N
M;B!N:6-H="!I;B!697)Z96EC:&YI<R`E<R!G97=E8VAS96QT('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDW"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB
M+B(*;7-G<W1R(")$:64@1W+VWV4@=F]N(%PB)7-<(B!K;VYN=&4@;FEC:'0@
M8F5S=&EM;70@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8U(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z.30*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*
M;7-G<W1R(")$:64@1W+VWV4@=F]N(%PB)7,O)7-<(B!K;VYN=&4@;FEC:'0@
M8F5S=&EM;70@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M(%-13"!397)V97(@:V%N;B!N
M:6-H="!H97)G97-T96QL="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX.#(*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+B(*;7-G<W1R(")34TPM5F5R8FEN9'5N9R!K;VYN=&4@;FEC:'0@:&5R
M9V5S=&5L;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(T,2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-#8*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(S,R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR-#8*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE
M+B(*;7-G<W1R(")$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!K;W!I97)T
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(%PB
M)7-<(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,W,"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C8Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR.3,*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@86YG
M96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,C,*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S
M='(@(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C,P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(%PB)7-<(B!K;VYN
M=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(X,0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92XB"FUS9W-T<B`B3&5E<F4@5D93+41A=&5I(&MO;FYT92!N
M:6-H="!A;F=E;&5G="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+W1A<BYP:'`Z-S4*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V=Z:7`N<&AP.C4R"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]G>FEP+G!H<#HX,@IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@
M9&%T82XB"FUS9W-T<B`B1&EE($1A=&5N(&MO;FYT96X@;FEC:'0@9&5K;VUP
M<FEM:65R="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"(@:V]N;G1E(&YI
M8VAT(&=E;/9S8VAT('=E<F1E;BP@9&%S(%9E<GIE:6-H;FES(&ES="!N:6-H
M="!L965R+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(EPB)7-<(B!K86YN(&YI8VAT
M(&=E;/9S8VAT('=E<F1E;CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S0W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#4P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(*;7-G<W1R("(E<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+"!D
M87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#`S(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HT,#<*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC
M:&YI<R!K;VYN=&4@;FEC:'0@<F5K=7)S:78@9V5L]G-C:'0@=V5R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U,R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S,S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS-#8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,U-`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D1A<R!6
M1E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0W-2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")$87,@
M5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XZ
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,V"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(")$:64@5D93+41A=&5I(%PB)7-<(B!K;VYN=&4@;FEC
M:'0@9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,Q.2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S-`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38V(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-SD*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$X-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#,X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT-#8*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(D1I92!61E,M1&%T
M96D@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")$
M87,@5D93+59E<GIE:6-H;FES(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B1&%S(%9&4R!K;VYN=&4@;FEC:'0@
M<F5K=7)S:78@9V5L]G-C:'0@=V5R9&5N.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@T-@IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN
M92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S(&%K='5E;&QE(%9E
M<GIE:6-H;FES(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B
M1&EE(%IE<G1I9FEK871D971A:6QS(&MO;FYT96X@;FEC:'0@875S9V5L97-E
M;B!W97)D96XB"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W
M(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`B1&5R("5S+51R96EB97(@:V]N;G1E(&YI8VAT(&=E
M;&%D96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(Q,2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,38*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y."!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C`S"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@=F5R
M<V-H;V)E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C8W-"!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D1I92!61E,M1&%T96D@7"(E<UPB
M(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,CDS(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ-3<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$V,`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(@IM<V=S='(@(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('IU;2!"
M97-C:')E:6)E;B!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z.#8@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,30P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HY-0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(D1I92!61E,M
M1&%T96D@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(D1A<R!!
M<F-H:78@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#0S"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(")$:64@5D93
M+41A=&5I(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;B`H9FEL97-I>F4H
M*2!F96AL9V5S8VAL86=E;BDN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@W.`IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*'-I>F4H*2!F
M86EL960I+B(*;7-G<W1R(")$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G
M96QE<V5N('=E<F1E;B`H<VEZ92@I(&9E:&QG97-C:&QA9V5N*2XB"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP
M:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")$
M:64@1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N.B`B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.3$*;7-G:60@(E5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S('9F
M<W)O;W0M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T
M:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@HB)7,@
M:V]N;G1E(&YI8VAT(&YA8V@@)7,@=6UB96YA;FYT('=E<F1E;CH@1&%S(%II
M96QV97)Z96EC:&YI<R!E>&ES=&EE<G0@(@HB8F5R96ET<R(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S(%9&4RU697)Z
M96EC:&YI<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,X-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!U;6)E;F%N
M;G0@=V5R9&5N.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(X,"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B1&EE(%9&4RU$871E:2!<(B5S7"(@:V]N;G1E(&YI8VAT('5M
M8F5N86YN="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C,R(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B1&EE(%9&4RU$871E:2`E<R\E<R!K;VYN=&4@;FEC:'0@
M=6UB96YA;FYT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,X,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C,@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,S-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S4V"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(*;7-G<W1R(")$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!U;6)E;F%N
M;G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N(@IM<V=S='(@(EPB;6MI<V]F<UPB(&MO;FYT92!N:6-H="!A=7-G
M96;\:')T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")$:65S97,@5V]R9"U$;VMU;65N
M="!LY'-S="!S:6-H(&YI8VAT(&%N>F5I9V5N(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ.#,Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A=&4@9F]R("5S(@IM<V=S='(@
M(B(*(D1I92!&<F5I+T=E8G5C:'0M26YF;W)M871I;VYE;B!F_'(@)7,@:V]N
M;G1E;B!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HQ-S@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HQ.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!<(B5S7"(@
M:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#D*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(D1I92!61E,M
M1&%T96D@:V]N;G1E(&YI8VAT(&=E<V-H<FEE8F5N('=E<F1E;B`H8V]P>2@I
M(&9E:&QG97-C:&QA9V5N*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR.3<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<P"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B1&EE(%9&
M4RU$871E;B!K;VYN=&5N(&YI8VAT(&=E<V-H<FEE8F5N('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4S"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S
M='(@(B(*(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E<V-H<FEE8F5N
M('=E<F1E;BP@9&%S(%-P96EC:&5R<&QA='HM2V]N=&EN9V5N="`B"B)W_')D
M92#\8F5R<V-H<FET=&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")5
M;G1E<G-T<FEC:&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM
M<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(L1N9&5R=6YG96X@<OQC:V?D
M;F=I9R!M86-H96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R(")-86-H="!D:64@;&5T>G1E($%K=&EO;B!R_&-K9^1N9VEG(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0R-PIM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`B56YG_&QT:6=E(%+\8VMM96QD=6YG('9O;2!397)V
M97(@8F5I;2!(97)S=&5L;&5N(&1E<B!697)B:6YD=6YG.B`B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C0*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0Q-0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,C$*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")5;F5R=V%R
M=&5T92!!;G1W;W)T(&1E<R!397)V97)S(&%U9CH@(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N
M9FEL960B"FUS9W-T<B`B3FEC:'0@>G5G96]R9&YE="(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T
M<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E
M9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(E9E<F5I;FEG=&4@07)A8FES8VAE
M($5M:7)A=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M
M(@IM<V=S='(@(E9E<F5I;FEG=&5S($OV;FEG<F5I8V@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(E9E<F5I;FEG=&4@
M4W1A871E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")+;&5I;F5R92!!;65R
M:6MA;FES8VAE(-QB97)S965I;G-E;&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B16EN:&5I=&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0S,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(E5N8F5K86YN="(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM
M<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G
M<W1R(")5;F)E:V%N;G1E(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@IM<V=S='(@(E5N8F5K86YN=&4@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W
M"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")%
M<R!W=7)D92!E:6X@=6YB96MA;FYT97(@3W)T(&%N9V5G96)E;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*
M;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@
M(E5N8F5K86YN=&5R($)E;G5T>F5R;F%M92!O9&5R(%!A<W-W;W)T+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B3&EN:R!V;VT@86MT=65L;&5N($5L96UE;G0@96YT9F5R;F5N(@H*(SH@
M9G)A;65W;W)K+U!R969S+TED96YT:71Y+G!H<#HS,#0*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B56YB96YA;FYT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B
M"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)!=7,@4VEC:&5R:&5I='-G<OQN
M9&5N(&3\<F9E;B!U;F%U=&]R:7-I97)T92!3:W)I<'1E(&YI8VAT(&%U<V-H
M;F5I9&5N+"`B"B)K;W!I97)E;B!U;F0@96EN9OQG96XN($ML:6-K96X@4VEE
M(&%U9B!/2RP@=6T@96EN96X@2&EN=V5I<R!A=68@;6]Z:6QL82YO<F<@(@HB
M86YG97IE:6=T('IU(&)E:V]M;65N+"!D97(@8F5S8VAR96EB="P@=VEE(%-I
M92!E:6YE;2!3:W)I<'0@9&5N(%IU9W)I9F8@875F("(*(F1I92!:=VES8VAE
M;F%B;&%G92!E<FQA=6)E;B!K]FYN96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@
M8V]L;W(B"FUS9W-T<B`B1F%R8F4@>G5R_&-K<V5T>F5N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*
M;7-G<W1R(")%<G=E:71E<G5N9R!N:6-H="!U;G1E<G-T_'1Z="(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B06MT
M=6%L:7-I97)U;F<B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M("(E<R!A:W1U86QI<VEE<F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B0F5N
M=71Z97(@86MT=6%L:7-I97)E;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@86MT=6%L:7-I97)T+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP
M="!D96QE=&5D+B(*;7-G<W1R(")!:W1U86QI<VEE<G5N9W-S:W)I<'0@9V5L
M]G-C:'0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-R!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO
M860B"FUS9W-T<B`B2&]C:&QA9&5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$X-0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*(D1I92!+;VYF:6=U
M<F%T:6]N<V1A=&5I96X@86QL97(@06YW96YD=6YG96X@=W5R9&5N(&%U9B!D
M96X@4V5R=F5R("(*(FAO8VAG96QA9&5N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P
M<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B1W(N(&QA=&5I;FES8VAE($)U
M8VAS=&%B96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(D=R+B!R]FUI<V-H92!:86AL96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B06MT=65L
M;&4@8F5N=71Z96XZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
M4U-,(&)E;G5T>F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM
M<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BXB"FUS9W-T<B`B(@HB0FET=&4@875S9OQL;&5N+"!W96YN
M(%-I92!E:6YE;B!A;F1E<F5N($)E;G5T>F5R;F%M96XO4&%S<W=O<G0@9OQR
M(&1E;B!)35-0+2(*(E-E<G9E<B!H86)E;BXB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(D)E
M;G5T>F5R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(D)E;G5T>F5R("5S(&ES="!F_'(@
M)7,@;FEC:'0@875T;W)I<VEE<G0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D)E;G5T>F5R
M=F5R=V%L='5N9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B0F5N=71Z97)E:6YS
M=&5L;'5N9V5N(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VXB"FUS9W-T<B`B0F5N=71Z97)R96=I<W1R:65R=6YG(@H*(SH@
M<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B1&EE($)E;G5T
M>F5R<F5G:7-T<FEE<G5N9R!W=7)D92!A=68@9&EE<V5M(%-Y<W1E;2!D96%K
M=&EV:65R="XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#DT"FUS9VED
M(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(D)E;G5T>F5R:V]N
M=&\@;FEC:'0@9V5F=6YD96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<X"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS-`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R(")"96YU='IE<FYA;64B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M1&5R($)E;G5T>F5R;F%M92!<(B5S7"(@97AI<W1I97)T(&)E<F5I=',N(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`B0F5N=71Z97)N86UE.B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
M0F5N=71Z97)N86UE.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")"
M96YU='IE<B!D97,@4WES=&5M<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5
M>F)E:VES=&%N(@IM<V=S='(@(E5S8F5K:7-T86XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ-S,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C<Q"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(&5X:7-T:65R="!N:6-H="XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A
M=&EO;B(*;7-G<W1R(")!8G=E<V5N:&5I="(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z("(*;7-G<W1R(")087-S96YD92!G969U;F1E;F4@3W)T93H@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@
M(E9A;&ED:71Y(@IM<V=S='(@(D?\;'1I9VME:70B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E=E<G0@:6X@
M36EN=71E;B!V;VX@:F5T>G0@86XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N(@IM<V=S='(@(D1E<B!797)T(&ES="#\8F5R(&1E<B!M87AI
M;6%L96X@3.1N9V4@=F]N("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-C(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(X-`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S,T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E=E<G1E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C`T"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T
M<B`B5V5R=&4L(&%U<R!D96YE;B!A=7-G97?D:&QT('=E<F1E;B!K86YN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B
M5F%R:6%B;&4B"FUS9W-T<B`B1')E:&5N9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(B(*(MQB97)P<OQF=6YG(&9E:&QG97-C:&QA
M9V5N("T@9&EE<V4@3F%C:')I8VAT(&OV;FYT92!M86YI<'5L:65R="!W;W)D
M96X@<V5I;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:6]N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(E9E<G-I;VYS:V]N=')O;&QE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B
M5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B075S<FEC:'1U;F<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")6
M97)T:6-A;"!P861D:6YG(@IM<V=S='(@(E9E<G1I:V%L97(@26YN96YA8G-T
M86YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:V%L.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED
M(")697)Y($AI9V@B"FUS9W-T<B`B4V5H<B!(;V-H(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI
M(@IM<V=S='(@(E9I971N86UE<VES8V@@*%9)4T-)22DB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(E<R!A;GIE:6=E;B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B
M('!A9V4B"FUS9W-T<B`B16EN92!E>'1E<FYE(%=E8G-E:71E(&%N>F5I9V5N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B06YZ96EG
M96X@86QS("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L($)R:71I<V@B"FUS9W-T<B`B0G)I=&ES8VAE($IU;F=F97)N:6YS96QN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B06UE<FEK86YI<V-H92!*=6YG9F5R;FEN<V5L;B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$Q"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S
M='(@(E-I8VAT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E-I8VAT.B`B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D
M869O;F4@271A;&EE;B!P97(@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G
M:60@(E=!4DXB"FUS9W-T<B`B5T%23E5.1R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")705).
M54Y'(2$A($S64T-(14X@4TE%($1!4R!32U))4%0@34%.545,3"!!55,@)7,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*
M;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@_&)E<B!(5%10(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T
M<B`B5V%L;&ES('5N9"!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.34*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5V%R
M;G5N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(DUI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(E=E='1E<G9O<FAE<G-A9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B5V5T=&5R9&%T96X@=F]N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")7
M96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED
M(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5V5B<VET92(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(E=E96ML>2(*;7-G<W1R(")7]F-H96YT;&EC:"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@
M(E=I;&QK;VUM96XB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")7:6QL:V]M;65N(&)E:2`E
M<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE+"`E<R(*;7-G<W1R(")7:6QL:V]M;65N+"`E<R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*
M;7-G<W1R(")797-T975R;W#D:7-C:"`H25-/+3@X-3DM,2DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,34I(@IM<V=S='(@(E=E<W1E=7)O<.1I<V-H("A)4T\M.#@U.2TQ-2DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B5V5S
M='-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B5V5L8VAE($%N=V5N9'5N9R!S
M;VQL("5S(&YA8V@@9&5M($%N;65L9&5N(&%N9V5Z96EG96X_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E=E;&-H97,@5')E;FYZ
M96EC:&5N('=I<F0@=F5R=V5N9&5T/R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_(@IM<V=S='(@(E=E;&-H92!!;F;\:')U;F=S>F5I8VAE;B!W97)D96X@
M=F5R=V5N9&5T/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS
M9W-T<B`B5VAE<F5I<RU!=7-T<F%L:6$M2V%R=&4B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")796QC
M:&4@4&AA<V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R(")796QC:&4@4&QU9VEN<R!F_'(@9&5N(%=94TE7
M64<M161I=&]R('-O;&QE;B!A:W1I=FEE<G0@=V5R9&5N/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G
M:60@(E=I9'1H(@IM<V=S='(@(D)R96ET92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G
M<W1R(")"<F5I=&4@:6X@0U-3+45I;FAE:71E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ(@IM<V=S='(@(D)R96ET92!D97,@)7,M365N_',@;&EN:W,@
M*'=I<FMS86T@;F%C:"!D97(@;N1C:'-T96X@06YM96QD=6YG*3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I
M9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(E1A8F5L;&5N8G)E:71E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B16EN:&5I="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED
M(")7:61T:#HB"FUS9W-T<B`B0G)E:71E.B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(E=I;F0B"FUS9W-T
M<B`B5VEN9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<P"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(D9R_&@@5VEN9"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B5VEN9&=E<V-H=VEN9&EG=&ME:70@:6X@2VYO
M=&5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(E=I;F0Z
M(@IM<V=S='(@(E=I;F0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E=I;F0Z("(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@
M(E=E:7-H96ET(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B5W5N<V-H>F5T=&5L(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(D%R
M8F5I="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@9V5S
M8VCD9G1L:6-H(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N
M(&=E<V-HY&9T;&EC:"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C$Y,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D9A;'-C:&4@06YZ
M86AL(&%N($9E;&1E<FX@:6X@6F5I;&4@)60N("5D(&5R=V%R=&5T+"`E9"!G
M969U;F1E;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@
M17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")&86QS8VAE($%N>F%H
M;"!A;B!&96QD97)N+B`E9"!E<G=A<G1E="P@)60@9V5F=6YD96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I
M;&4N(@IM<V=S='(@(E5N9_QL=&EG97(@3V9F<V5T("5D(&)E:6T@3&5S96X@
M9&5R(%9&4RU$871E:2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")1=65R=F5R=V5I<V4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!'96YE<F5L
M;&4@16EN<V-H<N1N:W5N9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E
M(@IM<V=S='(@(E@U,#EV,R!%<G=E:71E<G1E<B!38VAL_'-S96QZ=V5C:R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED
M(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U
M,#EV,R!!;'1E<FYA=&EV97(@3F%M92!D97,@6F5R=&EF:6MA=&EN:&%B97)S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U
M,#EV,R!)9&5N=&ETY'0@9&5S(%IE<G1I9FEK871S8VAL_'-S96QS(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U
M,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!%<G=E:71E<G5N9V5N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@
M(DI*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4V"FUS9VED(")965E9(@IM<V=S='(@(DI*2DHB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A
M(&UA<"(*;7-G<W1R(")986AO;R$@2V%R=&4B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS
M9W-T<B`B2N1H<FQI8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*
M;7-G<W1R(")*96UE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")*82(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED
M(")997,L($D@06=R964B"FUS9W-T<B`B2F$L(&EC:"!S=&EM;64@>G4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS
M9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB4VEE
M(&)E9FEN9&5N('-I8V@@:6T@5&5X=&UO9'5S+B!"96YU='IE;B!3:64@9&5N
M(%L\/ET@2VYO<&8L('5M(&EN(&1E;B`B"B)765-)5TE'+4UO9'5S('IU('=E
M8VAS96QN+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S
M='(@(E-I92!D_')F96X@;FEC:'0@;65H<B!A;',@)60@0FSV8VME(&5R<W1E
M;&QE;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,34*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(E-I92!S
M:6YD(&YI8VAT(&%N9V5M96QD970N(@H*(SH@9G)A;65W;W)K+U!R969S+TED
M96YT:71Y+G!H<#HS,3`*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E-I92!D
M_')F96X@9&%S(%IE:6-H96X@)UQ<)R!N:6-H="!I;B!):')E;2!.86UE;B!V
M97)W96YD96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3DS"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E-I92!H
M86)E;B!K96EN92!G_&QT:6=E($4M36%I;"U!9')E<W-E(&%N9V5G96)E;BXB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B
M"B)I;B`E<RXB"FUS9W-T<B`B(@HB4VEE(&AA8F5N(&ME:6YE($9E;&1E<B!A
M=7,@9&5N(&EM<&]R=&EE<G1E;B!$871E;B!D96X@96YT<W!R96-H96YD96X@
M1F5L9&5R;B`B"B)I;B`E<R!Z=6=E;W)D;F5T+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+B(*;7-G<W1R(")3:64@=W5R9&5N(&%B9V5M96QD970N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E-I92!M_'-S96X@96EN
M92!G_&QT:6=E($UO8FEL=&5L969O;FYU;6UE<B!A;F=E8F5N+"!N=7(@875S
M(%IA:&QE;B!U;F0@9V=F+B`B"B)E:6YE;2!<(BM<(B!F_'(@:6YT97)N871I
M;VYA;&4@5F]R=V%H;&5N(&)E<W1E:&5N9"XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F5N(&?\;'1I9V5N
M(%=E<G0@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB4VEE(&W\
M<W-E;B!E:6X@1&%T851R964M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+"!U;2!2
M96=I<W1R:65R=6YG96X@=F5R=V5N9&5N("(*(GIU(&OV;FYE;BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0V-0IM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E-I92!M_'-S96X@
M96EN(%9&4RU"86-K96YD(&MO;F9I9W5R:65R96XN(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+B(*;7-G<W1R(")3:64@;?QS<V5N(&1A<R!0<F]B;&5M(&)E
M<V-H<F5I8F5N+"!U;2!D96X@0F5R:6-H="!A8GIU<V-H:6-K96XN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I
M9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O(@IM<V=S='(@(E-I92!M_'-S96X@9&EE(%523"!A;F=E8F5N+"!A
M=68@9&EE(&1I97-E<B!,:6YK('9E<G=E:7-E;B!S;VQL(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B4VEE(&W\<W-E
M;B!E<G-T(&1E;B!Z=2!E;G1F97)N96YD96X@4V5R=F5R(&%U<W?D:&QE;BXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*(E-I92!M
M_'-S96X@96EN96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+"!D97-S96X@1&%T
M96X@9V5L]G-C:'0@=V5R9&5N('-O;&QE;BXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N(@IM<V=S='(@(E-I92!M_'-S96X@96EN96X@>G4@;/9S8VAE;F1E
M;B!"96YU='IE<FYA;65N(&%N9V5B96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@
M(E-I92!M_'-S96X@96EN96X@:&EN>G5Z=6;\9V5N9&5N($)E;G5T>F5R;F%M
M96X@86YG96)E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`B4VEE(&W\<W-E;B!D96X@>G4@86MT=6%L:7-I97)E;F1E;B!"96YU='IE
M<FYA;65N(&%N9V5B96XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@
M86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(E-I92!M_'-S96X@96EN92!!
M:W1I;VX@86YG96)E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F5N(&YE
M=65N($MA=&5G;W)I96YA;65N(&%N9V5B96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS
M9W-T<B`B4VEE(&W\<W-E;B!E:6YE($ET86QI96YI<V-H92!496QE9F]N;G5M
M;65R(&%N9V5B96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(DEH<F4@)7,M4V5S
M<VEO;B!I<W0@86)G96QA=69E;BX@0FET=&4@;65L9&5N(%-I92!S:6-H(&5R
M;F5U="!A;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(DEH<F4@12U-
M86EL+4%D<F5S<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`W"FUS
M9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(DEH<F4@5F]N.B!!
M9')E<W-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")):')E($%N9V%B96XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)):')E
M($EN=&5R;F5T861R97-S92!H870@<VEC:"!G9>1N9&5R="P@<V5I="!3:64@
M9&EE("5S+5-I='IU;F<@8F5G;VYN96X@(@HB:&%B96XN(%IU;2!38VAU='H@
M26AR97(@4VEC:&5R:&5I="!M_'-S96X@4VEE('-I8V@@;F5U(&%N;65L9&5N
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED
M(")9;W5R($YA;64B"FUS9W-T<B`B26AR($YA;64B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U
M<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T
M:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB26AR($%U=&AE;G1I
M9FEZ:65R=6YG<W-Y<W1E;2!E<FQA=6)T(&ME:6X@2&EN>G5F_&=E;B!V;VX@
M;F5U96X@0F5N=71Z97)N+B`B"B)796YN(%-I92!(;W)D92!B96YU='IE;B!M
M]F-H=&5N+"!U;2!):')E($)E;G5T>F5R('IU('9E<G=A;'1E;BP@;?QS<V5N
M(%-I92`B"B)E:6YE;B!A;F1E<F5N($%U=&AE;G1I9FEZ:65R=6YG<W1R96EB
M97(@8F5N=71Z96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*(DEH<B!!=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L
M875B="!D87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&YI8VAT+"!O9&5R("(*
M(F1I97-E($WV9VQI8VAK96ET('=U<F1E(&%U<V=E<V-H86QT970N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB26AR($)R;W=S97(@:&%T('-I8V@@86YS8VAE:6YE;F0@
M9V7D;F1E<G0@<V5I="!3:64@9&EE("5S+5-I='IU;F<@8F5G;VYN96X@(@HB
M:&%B96XN(%IU;2!38VAU='H@26AR97(@4VEC:&5R:&5I="!M_'-S96X@4VEE
M('-I8V@@;F5U(&%N;65L9&5N+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N(@IM<V=S='(@(DEH<B!"<F]W<V5R('5N=&5R<W3\='IT(&1I
M97-E($9U;FMT:6]N(&YI8VAT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB26AR($)R;W=S97(@
M=6YT97)S=/QT>G0@9&EE<V4@1')U8VMF=6YK=&EO;B!N:6-H="X@0FET=&4@
M9'+\8VME;B!3:64@4W1R9R\B"B)+;VUM86YD;R`K(%`@=6T@>G4@9')U8VME
M;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4S"FUS9VED(")9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")):')E(&%K='5E;&QE(%IE
M:71Z;VYE.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M(")):')E(%-T86YD87)D:61E;G1I=.1T('=U<F1E(&=EY&YD97)T+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3,*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>3HB"FUS9W-T<B`B26AR92!3=&%N9&%R9&ED96YT:73D=#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DV"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`B26AR('9O;&QS=.1N9&EG97(@3F%M93HB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G
M:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(DEH<B!:=6=A;F<@:7-T(&%B9V5L
M875F96XN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<R(*;7-G<W1R(")):'(@;F5U97,@4&%S<W=O<G0@9OQR("5S(&QA=71E
M=#H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")):')E($5I;G-T
M96QL=6YG96X@=W5R9&5N(&;\<B!D:64@1&%U97(@9&EE<V5R(%-I='IU;F<@
M9V5S<&5I8VAE<G0N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB
M"FUS9W-T<B`B26AR92!%:6YS=&5L;'5N9V5N('=U<F1E;B!G97-P96EC:&5R
M="XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@IM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")):'(@4&%S
M<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z="(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C@P"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB26AR(%!A<W-W;W)T
M('=U<F1E('IU<OQC:V=E<V5T>G0N(%)U9F5N(%-I92!):')E($4M36%I;"U.
M86-H<FEC:'1E;B!A8B!U;F0@(@HB;65L9&5N(%-I92!S:6-H(&UI="!):')E
M;2!N975E;B!087-S=V]R="!A;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM
M<V=S='(@(DEH<B!087-S=V]R="!I<W0@86)G96QA=69E;BXB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(@IM<V=S='(@(DEH<F4@4V5R=F5R.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L87=I
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86ER92(*;7-G<W1R("):86ER92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA;6)I82(*;7-G<W1R(")386UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")::6UB86)W92(*;7-G<W1R(")3:6UB86)W92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6UII
M=&%T=&5X="!V97)S=&5C:V5N72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;&5M
M8F5R:6-H=%TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");
M6FET871T97AT(&%N>F5I9V5N("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,C`S"B,L('!H<"UF;W)M
M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S
M='(@(EM::71A='1E>'0@86YZ96EG96X@+2`E<R!:96EL96Y=(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EM:96EL92`E<R!V;VX@)7-=
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES=')A=&EO;B(*"B,Z(&QI
M8B]A<&DN<&AP.C(R,PIM<V=I9"`B7T-,22(*;7-G<W1R(")"95]F96AL<WIE
M:6QE(@H*(SH@;&EB+V%P:2YP:'`Z,C`W"FUS9VED(")?1&%T851R964B"FUS
M9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*
M;7-G<W1R("):96EL92!?;/9S8VAE;B(*"B,Z(&QI8B]A<&DN<&AP.C$Y.0IM
M<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<'!E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T)I;&1E:6=E;G-C
M:&%F=&5N+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")!;E]M96QD96XB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G
M(&]U="(*;7-G<W1R(")!8E]M96QD96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I
M9GD@3&EN:RXN+B(*;7-G<W1R("),:6YK(%]B96%R8F5I=&5N+BXN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P
M=&EO;G,B"FUS9W-T<B`B7T5I;G-T96QL=6YG96XB"@HC.B!L:6(O87!I+G!H
M<#HR,#,*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4F5C:'1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B3&EN:R!?
M96YT9F5R;F5N+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3DQ"FUS9VED(")?4V5T
M=7`B"FUS9W-T<B`B7TMO;F9I9W5R871I;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]4
M86)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]486)E;&QE;F5I9V5N<V-H
M869T96XN+BXB"@HC.B!L:6(O87!I+G!H<#HQ.34*;7-G:60@(E]5<V5R<R(*
M;7-G<W1R(")?0F5N=71Z97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDU,0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(D%D<F5S<V)U
M8V@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM
M<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B061R97-S870@=6YB
M96MA;FYT(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-#,*;7-G
M:60@(F-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")W:6YD<W1I;&PB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(")!=7-G86)E9&%T96D@
M:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I
M;G!U="(*;7-G<W1R(")%:6YG86)E(&MA;FX@;FEC:'0@9V7V9F9N970@=V5R
M9&5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P
M"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FML:6-K96X@4VEE(&AI97(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(E5N9_QL=&EG
M92!"96YU='IU;F<@9&5R($MO;6UA;F1O>F5I;&4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO
M;B!E<G)O<B(*;7-G<W1R(")+;VYF:6=U<F%T:6]N<V9E:&QE<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(DMR:71I<V-H92!3
M>7-T96UD871E:2!F96AL="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R
M(")$871E;F9O<FUA=&9E:&QE<B(*"B,Z('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B8F5A<F)E:71E;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E
M;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B16EN=')A9R!N:6-H="!G969U;F1E
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<U
M"FUS9VED(")F86QL:6YG(@IM<V=S='(@(F9A;&QE;F0B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.38*;7-G:60@(F9I;&4B"FUS9W-T
M<B`B1&%T96DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V,B!L:6(O0FQO8VLO;65T87(N<&AP.C,X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM
M<V=S='(@(F%U<R`E<R`H)7,I(&UI="`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B
M8O9I9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T
M<B`B:&@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B2&]S=&YA;64@
M=6YB96MA;FYT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B
M<V]F;W)T(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C0@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-S8*;7-G:60@(FEN;&EN92(*;7-G<W1R("));FQI;F4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I
M9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(D5I;BTO075S9V%B969E
M:&QE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V
M"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("));G1E
M<FYE<B!3;V9T=V%R969E:&QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B6F5I
M;&5N72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M
M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B;6MI<V]F
M<RU&96AL97)C;V1E("5D(&)E:2!D97(@17)S=&5L;'5N9R!D97,@25-/+4%B
M8FEL9&5S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S`*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W-`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0S
M"FUS9VED(")N86UE(@IM<V=S='(@(DYA;64B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B
M;FEC:'0@:6UP;&5M96YT:65R="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*
M;7-G<W1R(").;V-H(&YI8VAT(&EM<&QE;65N=&EE<G0B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDS-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R
M(").;W1I>F)L;V-K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")0
M<F]Z96YT(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(EIU9W)I9F8@
M=F5R=V5I9V5R="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")0:7AE
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS
M9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B4F5M;W1E
M9F5H;&5R(&EM(%!R;W1O:V]L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<W"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<W1E
M:6=E;F0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T
M,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")397)V:6-E
M(&YI8VAT('9E<F;\9V)A<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(E5N=&5R<V-H
M:65D92!A;GIE:6=E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B
M"FUS9W-T<B`B<VUS,F5M86EL(/QB97(@2%144"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S
M='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S8*;7-G:60@(G-T96%D>2(*;7-G<W1R(")G;&5I8VAB;&5I8F5N9"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B4WES=&5M9F5H;&5R(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-3D*;7-G:60@(G1A<VL@;&ES="(*
M;7-G<W1R(")!=69G86)E;FQI<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(E9O<OQB97)G96AE;F1E<B!&96AL97(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS
M9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S
M='(@(F=E8F5N(%-I92!D87,@4&%S<W=O<G0@96EN('IW96ET97,@36%L('IU
M<B!"97-TY'1I9W5N9R!E:6XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV
M-"!A9&UI;B]S971U<"]D:69F+G!H<#HW-@IM<V=I9"`B=6YI9FEE9"(*;7-G
M<W1R(")U;FEF:65D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H
M<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")U;F)E;F%N;G0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(F)E;G5T>F5R9&5F:6YI
M97)T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM
M<V=S='(@(F(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!O+VYL7TY,+G!O````````````````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`W,S0V,38`,3`U,34T,S$P-C,`,#$V-#$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````",@
M2&]R9&4@1'5T8V@@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`Q
M+3(P,#8@2F%N($MU:7!E<G,N"B,@2F%N($MU:7!E<G,@/&IR:W5I<&5R<T!L
M875W97)S8V]L;&5G92YN;#XL(#(P,#$M,C`P-BX*(R`*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2XQ+6-V<UQN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`S+3$R(#`P.C,Q*S`Q,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,3,@,C(Z-#`K,#$P,%QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA
M=7=E<G-C;VQL96=E+FYL/EQN(@HB3&%N9W5A9V4M5&5A;3H@1'5T8V@@/&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@9&%G96X@9V5L961E
M;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H4VYE
M;'1O971S("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@
M*&)I;FYE;B`E<R!D86=E;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*'9A;F1A86<I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO
M<G)O=RDB"FUS9W-T<B`B("AM;W)G96XI(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H
M9VES=&5R96XI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B
M(&]P("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM
M<V=S='(@(EPB)7-<(B!I<R!G965N(&1I<F5C=&]R>2XB"@HC.B!F<F%M97=O
M<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!I<R!G
M965N(&=E;&1I9V4@:V5U>F4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HW,3`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S
M='(@(EPB)7-<(B!I<R!N:65T(&=E8V]N9FEG=7)E97)D(&EN(&AE="!(;W)D
M92!R96=I<W1E<BXB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")<(B5S7"(@=')E92!W965R9V5V97(@;FEE="!G
M979O;F1E;BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN(@IM<V=S='(@(EPB)7-<(B!A86X@:&5T(&=R;V5P96YS>7-T965M('1O
M96=E=F]E9V0N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&%A;B!H970@<F5C
M:'1E;G-Y<W1E96T@=&]E9V5V;V5G9"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M7"(E<UPB(&ES(&YI970@86%N9V5M86%K=#H@)7,N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U
M<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-
M0B!G96)R=6EK="!V86X@)2XR9DU"('1O96=E<W1A86X@*"4N,F8E)2DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!E;B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HU.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y
M<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B5D(&1A
M9V5N('1O="!U=R!W86-H='=O;W)D('9E<G9A;'0N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M9&%G('9O;W)U:71Z:6-H="(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($]P;65R:VEN9R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S('9I
M;F=E<F%F9')U:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T,B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(E<R!/;F1E<FAO=61S=V5R:WIA86UH961E;B`M($)E=F5S
M=&EG:6YG(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E
M='5P(@IM<V=S='(@(B5S($EN<W1E;&QE;B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M4VEG;B!5<"(*;7-G<W1R("(E<R!I;G-C:')I:G9E;B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!4
M97)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@9V5B<G5I:V5R<V]V97)E
M96YK;VUS="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@R(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#,R(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R("(E<R!B97-T86%T(&%L+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S
M(@IM<V=S='(@(B5S(&]P("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y
M('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME
M9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B
M(@HB)7,@:7,@9V5R965D(&]M(&]N9&5R<W1A86YD92!G97-E;&5C=&5E<F1E
M(&]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I="!T92`B"B)V;V5R96XN(%9I
M;FL@9&4@8F5W97)K:6YG*&5N*2!A86X@9&EE('4@;W`@9&ET(&UO;65N="!W
M:6QT('5I='9O97)E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S
M='(@(B5S(&ES('9E<F5I<W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S
M(&UI;G5T96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,3,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B)7,@;FEE="!G979O;F1E;BXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O
M("5S(&]F("5S(@IM<V=S='(@(B5S('1O="`E<R!V86X@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(E<R=S(&%D<F5S8F]E:R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B)7,G<R!A9V5N9&$B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,G<R!N;W1I=&EE
M8F]E:R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,G<R!T
M86ME;FQI:G-T(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L
M:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N
M>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z($1I="!B
M97)I8VAT(&MO;70@;6ES<V-H:65N(&YI970@=F%N(&1E9V5N92!D:64@:&5T
M(&)E=V5E<G0@=&4@>FEJ;BX@5V5E<R`B"B)V;V]R>FEC:'1I9R!B:6H@:&5T
M(&ML:6MK96X@;W`@;&EN:W,@:6X@:&5T(&)E<FEC:'0@;V8@9&4@869Z96YD
M97(@(@HB<&5R<V]O;FQI:FME(&EN9F]R;6%T:64@=&4@<W1U<F5N+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R
M("(L('=I;F1V;&%G96X@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@=VEN9'9L86=E;B`E<R`E<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G
M:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA
M8F5L('9A;B`E<R!T;W0@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-S0X(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,CDT"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$R.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM
M('-E;&5C=&5R96X@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G
M:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R('5U<G-W965R9V%V92(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M
M870B"FUS9W-T<B`B,C0@=75R<W=E97)G879E(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('5U
M<G,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\
M4')E=FEO=7,B"FUS9W-T<B`B/%9O<FEG92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(D5E;B!D871A8F%S92!B86-K
M96YD(&ES('9E<F5I<W0@=F]O<B!D:70@8FQO:RXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960B"FUS9W-T<B`B17(@:&5E9G0@>FEC:"!E96X@9F%T86QE(&9O
M=70@=F]O<F=E9&%A;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B165N(&]P96YB87)E(%!'
M4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@8V]D97)E
M;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS
M9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)%96X@;W!E;F)A<F4@4$=0
M('-L975T96P@:7,@=F5R96ES="!O;2!E96X@;VYD97)T96ME;F0@8F5R:6-H
M="!T92!V97)I9FGK<F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)%96X@;W!E;F)A<F4@
M4$=0('-L975T96PL('!R:7;I(%!'4"!S;&5U=&5L(&5N('=A8VAT=V]O<F1R
M96=E;"!Z:6IN('9E<F5I<W0@(@HB;VT@965N(&)E<FEC:'0@=&4@9&5C;V1E
M<F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,38*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"B)%96X@;W!E;F)A<F4@4$=0('-L975T96PL('!R
M:7;I(%!'4"!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN('9E<F5I
M<W0@(@HB;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@HB165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P
M<FEVZ2!3+TU)344@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B`B
M"B)V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&1E8V]D97)E;BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(D5E;B!O<&5N8F%R92!3+TU)344@<VQE=71E;"P@<')I
M=ND@4R]-24U%('-L975T96P@96X@=V%C:'1W;V]R9')E9V5L('II:FX@(@HB
M=F5R96ES="!O;2!E96X@8F5R:6-H="!T92!O;F1E<G1E:V5N96XN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@
M<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B165N(&]P96YB87)E(%--24U%('-L975T96P@:7,@
M=F5R96ES="!O;2!E96X@8F5R:6-H="!T92!C;V1E<F5N+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R(")"97=O;&MI;F<@=F]O<B`Q,BXP,"!U=7(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R("),:6-H=&4@<F5G96X@=F]O<B`Q,BXP
M,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")296=E;B!V;V]R(#$R+C`P
M('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D)U:65N('9O;W(@,3(N
M,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;F5E=7=B
M=6EE;B!V;V]R(#$R+C`P('5U<B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I
M9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@
M961I=&]R(@IM<V=S='(@(D]V97(@9&5Z92!E9&ET;W(B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
M3W9E<BXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-B;W1T;VTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R
M"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B06)S;6ED9&QE(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")4;V5G86YG
M(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A;B!61E,@9&ER96-T;W)Y+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E1O96=A
M;F<@9V5W96EG97)D(&)I:B!H970@;6%K96X@=F%N(%9&4R!B97-T86YD+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(D%C8V]U;G1I;F9O<FUA=&EE(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D
M(@IM<V=S='(@(D%C8V]U;G1W86-H='=O;W)D(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O
M=6YT(&9R;WIE;BXB"FUS9W-T<B`B06-C;W5N="!B979R;W)E;BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG
M(@IM<V=S='(@(E9E<F%N='=O;W)D:6YG(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS
M9VED(")!9&0B"FUS9W-T<B`B5&]E=F]E9V5N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL
M9"!'<F]U<"(*;7-G<W1R(")#:&EL9"!G<F]E<"!T;V5V;V5G96XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(D-H:6QD(')E8VAT('1O979O96=E;B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B
M2&EE<B!T;V5V;V5G96XZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M
M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T
M<B`B3FEE=7=E(&=R;V5P('1O979O96=E;B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(DYI975W
M(')E8VAT('1O979O96=E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D5E;B!<(F-H:6QD9W)O97!<
M(B!A86X@7"(E<UPB('1O979O96=E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(D5E;B!<(F-H:6QD
M<F5C:'1<(B!A86X@7"(E<UPB('1O979O96=E;B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3FEE=7=E
M(&=E8G)U:6ME<B!T;V5V;V5G96XZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G
M<W1R(")+;VQO;2!T;V5V;V5G96XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T
M<B`B3FEE=7=E(&QE9&5N('1O979O96=E;B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E!A87(@
M=&]E=F]E9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(B"FUS9W-T<B`B2&5T("5S(&UE;G4@=&]E=F]E9V5N(&%L<R!E
M96X@36]Z:6QL82!3:61E8F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K
M.B(*;7-G<W1R(")6;V5G('1O92!A86X@861R97-B;V5K.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D
M('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")6;V5G('1O92!A86X@;6EJ
M;B!A9')E<V)O96LB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D
M('5S97(B"FUS9W-T<B`B1V5B<G5I:V5R('1O979O96=E;B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(EPB
M)7-<(B!A86X@:&5T('-Y<W1E96T@=&]E9V5V;V5G9"P@;6%A<B!K;VX@9V5E
M;B!E>'1R82`B"B)I;G-C:')I:G9I;F=S:6YF;W)M871I92!T;V5V;V5G96XZ
M("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RXB"FUS9W-T<B`B7"(E<UPB(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D
M+B!5(&MU;G0@;G4@86%N;65L9&5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(E1O979O96=E;B!V86X@9V5B<G5I:V5R<R!I<R!U:71G
M97-C:&%K96QD+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED
M(")!9&1R97-S(@IM<V=S='(@(D%D<F5S(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D
M<F5S8F]E:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDT"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4V"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<R(*;7-G<W1R(")"96AE97(@+2!R96-H=&5N('9O;W(@86YD
M97)E(&=E8G)U:6ME<G,@:6YS=&5L;&5N(@H*(SH@861M:6XO:6YD97@N<&AP
M.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(D)E:&5E<B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R(")!9'9E<G1E
M;G1I97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R
M(")!9F=A;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,0IM<V=I9"`B06QB86YI82(*;7-G
M<W1R(")!;&)A;FGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-`IM<V=I9"`B06QG97)I82(*;7-G
M<W1R(")!;&=E<FEJ92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B56ET;&EJ;F5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B
M06QI9VYM96YT.B(*;7-G<W1R(")5:71L:6IN:6YG.B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R(")!;&QE(&=E875T:&5N=&EC965R9&4@9V5B<G5I:V5R
M<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR
M,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B06QL92!G<F]E<&5N(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ"FUS9VED(")!;&P@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B06QL92!R96-H=&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL
M(&9O=7(@<VED97,B"FUS9W-T<B`B06QL92!V:65R('II:F1E;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<R(*;7-G<W1R(")-965R9&5R92!A9')E<W-E;B!T;V5S
M=&%A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(DEN
M<W1E;&QE;B!V86X@9V5O<F1E;F1E(&QI:G-T('1Y<&4@=&]E<W1A86X_(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS
M9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")"97-T86%T(&%L(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-
M4U`@3&]G:6XB"FUS9W-T<B`B06QT97)N871I979E($E-4U`@86%N;65L9&EN
M9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R
M;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(D%L=&5R;F%T:65F($E-4U`@
M=V%C:'1W;V]R9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T
M:65V92!)35-0(&=E8G)U:6ME<G-N86%M(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M(@IM<V=S='(@(D%L=&5R;F%T:65F(&4M;6%I;&%D<F5S(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B
M"FUS9W-T<B`B06QT97)N871I979E('-J86)L;VYE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@IM
M<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T:65V92!T
M96MS=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G
M<W1R(")!;65R:6MA86YS(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q
M-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G
M<W1R(")%96X@;VYG96QD:6=E('=A87)D92!O<&=E9V5V96XN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B17(@:&5E9G0@>FEC:"!E
M96X@;VYB96ME;F1E9F]U="!V;V]R9V5D86%N+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38*;7-G
M:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0*;7-G
M:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P"FUS9VED
M(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*
M;7-G<W1R(")!;F]N:65M92!P<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B06YT=V]O<F0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R
M8W1I8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(D%N=&EG=6$@96X@0F%R8G5D82(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HS-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B5&]E
M<&%S<VEN9R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B
M07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")4;V5P87-S:6YG96YL:6IS="(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T
M:6]N(&ES(')E861Y+B(*;7-G<W1R(")4;V5P87-S:6YG(&ES(&=E<F5E9"XB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P
M;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D]P(&-H:6QD<VAA<F5S('1O
M97!A<W-E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D=O961K975R96XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G:60@(D%P
M<')O>&EM871E(%-I>F4B"FUS9W-T<B`B1V5S8VAA='1E(&=R;V]T=&4B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B07!R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@
M(D%R86)I<V-H("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C8*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@
M(D%R8VAI969B97-T86YD<V=R;V]T=&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-0IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D%R8VAI
M969N86%M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*
M;7-G<W1R(")7965T('4@>F5K97(@9&%T('4@:&5T(&%A;FUE;&1I;F=S=F5R
M>F]E:R!V86X@)7,@=VEL="!V97)W:6ID97)E;C\B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@
M86YY('-U8BUG<F]U<',_(@IM<V=S='(@(E=E970@=2!Z96ME<B!D870@=2!<
M(B5S7"(@96X@86QL92!S=6)G<F]E<&5N('=I;'0@=F5R=VEJ9&5R96X_(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-@IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN
M:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;65N
M:>LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI
M86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M965N<R`H05)-4T-)22TX*2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S
M='(@(DMU;G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,`IM<V=I9"`B07)U8F$B"FUS9W-T<B`B
M07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED
M(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(D%S8V5N<VEO;B!E:6QA;F0B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R
M="(*;7-G<W1R(")!<V-I:2!K=6YS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G
M<W1R(")!>FGK+U!A8VEF:7-C:&4@4F5G:6\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B3VT@
M8F5V97-T:6=I;F<@=G)A9V5N('9O;W(@:&5T('5I='9O97)E;B!V86X@;VYD
M97)H;W5D<W=E<FMZ86%M:&5D96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S`Y-0IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@
M(D]P9')A8VAT(&MO;&]M;65N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M(@IM<V=S='(@(E!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9&4@9W)O97`@
M=&4@=F5R=VEJ9&5R96XN(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR
M.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD
M(')E8VAT('1E('9E<G=I:F1E<F5N+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A
M86YD(')E8VAT('1E(&)E=V5R:V5N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+B(*;7-G<W1R(")0;V=I;F<@;VT@965N(&YI970@8F5S=&%A
M;F1E('-H87)E('1E(&)E=V5R:V5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<Q"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%U9W5S='5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86QIZR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C@*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B3V]S=&5N<FEJ:R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?8WER<W%L.B!V97)E:7-T92!I;6%P(&5X=&5N=&EE
M(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER
M=7,Z(&)A8VME;F0@:&5E9G0@;FEE="!D92!V97)E:7-T92!B96MW86%M:&5D
M96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS
M9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z('9E<F5I<W1E(&EM87`@97AT
M96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z('9E
M<F5I<W1E($944"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B!#;VUP:6QE97(@
M4$A0(&UE="!D92`M+65N86)L92TB"B)F='`@;W!T:64N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?:6UA<#H@=F5R96ES=&4@24U!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@
M(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VMR8C4Z('9E<F5I<W1E(&MR8C4@97AT96YT:64@
M;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!
M=71H7VQD87`Z('1O979O96=E;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T
M(&]N9&5R<W1E=6YD('9O;W(@06-T:79E("(*(D1I<F5C=&]R>2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!697)W:6ID97)E
M;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R<W1E=6YD('9O;W(@
M06-T:79E("(*(D1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z('9E<F5I
M<W1E($Q$05`@97AT96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE
M="!I;B!S=&%A="!G96)R=6EK97(@)7,@=&]E('1E('9O96=E;BX@1&4@<V5R
M=F5R(&UE;&1T.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YI970@:6X@
M<W1A870@9V5B<G5I:V5R("5S('1E('9E<G=I:F1E<F5N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T
M<B`B075T:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!B:6H@
M=&4@=V5R:V5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T
M:%]L9&%P.B!":6IW97)K96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O
M;F1E<G-T975N9"!V;V]R($%C=&EV92`B"B)$:7)E8W1O<GDN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?;6-A;#H@=F5R96ES=&4@34-!3"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@=F5R96ES=&4@<VUB
M875T:"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@
M870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71H96YT:6-A=&EE
M(&]P($E-05`@<V5R=F5R(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT
M:6-A=&EO;B!F86EL960B"FUS9W-T<B`B075T:&5N=&EC871I92!M:7-L=6MT
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<R(*;7-G<W1R(")!=71H96YT:6-A=&EE(&UI<VQU:W0N("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B075T:&5N=&EC871I92!G97=E:6=E<F0@9&]O<B!D92!2041)
M55,@<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@R
M"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B075T:&5N=&EC871I92!O<"!&5%`@<V5R=F5R(&UI<VQU:W0N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T
M:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")!=71H96YT:6-A=&EE(&]P(&1E(%--0B!S97)V97(@;6ES;'5K="XB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B
M;&4@9FEE;&1S.B(*;7-G<W1R(")"97-C:&EK8F%R92!V96QD96XZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I9'IJ
M86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@
M17AC=7-E<R(*;7-G<W1R(")"3T9(($5X8W5S97,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"
M86-K9W)O=6YD(@IM<V=S='(@(D%C:'1E<F=R;VYD(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R(")!8VAT97)G<F]N9&ML975R(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+B(*;7-G<W1R(")&;W5T(&ME<F)E<F]S=V%C:'1W;V]R
M9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED
M(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(D9O=71E(&ME<F)E
M<F]S9V5B<G5I:V5R<VYA86TN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-0IM<V=I9"`B0F%H86UA
M<R(*;7-G<W1R(")"86AA;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.`IM<V=I9"`B0F%H<F%I
M;B(*;7-G<W1R(")"86AR96EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#`*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I
M<V-H("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T"FUS9VED(")"86YG;&%D
M97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S"FUS9VED(")"
M87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")"87-I<R!A
M9F)E96QD:6YG96YD:7)E8W1O<GD@7"(E<UPB(&YI970@9V5V;VYD96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$Y"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")"87-I<VQI:FXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Y"FUS9VED(")"96QA<G5S(@IM<V=S='(@(E=I="!R=7-L86YD(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:>LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4P"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,`IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0Q"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0V"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER
M=&AD87DB"FUS9W-T<B`B5F5R:F%A<F1A9R(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D)L;VL@7"(E<UPB('9A;B!T;V5P87-S:6YG(%PB)7-<
M(B!N:65T(&=E=F]N9&5N+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO:VEN
M<W1E;&QI;F=E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW
M-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")";&]K='EP92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B
M0F]L9"(*;7-G<W1R(")6970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S"FUS9VED(")";VQI=FEA
M(@IM<V=S='(@(D)O;&EV:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B0F]O:VUA<FMS(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(E)A;F0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D
M97(@=&AI8VMN97-S.B(*;7-G<W1R(")286YD9&EK=&4Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I
M9"`B0F]R9&5R<R(*;7-G<W1R(")286YD96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R"FUS9VED
M(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYIZR!E;B!(
M97)Z96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I
M9"`B0F]T:"(*;7-G<W1R(")"96ED96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X"FUS9VED(")"
M;W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@IM<V=I9"`B0F]T=&]M
M(@IM<V=S='(@(D]N9&5R:V%N="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<*;7-G:60@(D)O=79E
M="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T(&5I;&%N9"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0*
M;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z:6QIZR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W
M"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T
M<B`B0G)I=',@26YD:7-C:&4@3V-E86%N(%1E<G)I=&]R:75M(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I
M($1A<G5S<V%L86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W"FUS9VED(")"=6QG87)I82(*;7-G
M<W1R(")"=6QG87)I:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@
M(D]N9V5O<F1E;F1E(&QI:G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-@IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD*;7-G
M:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED
M(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@IM<V=S='(@(D-23"!$:7-T<FEB=71I97!U;G1E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I
M9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")#7V5L96EG96YS8VAA
M<'!E;BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(D-A8VAE(&EN:71I86QI<V%T:64@:7,@;FEE="!A9F=E<F]N9"XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$V"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HQ,#0P(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(D%G96YD82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B2V%L;2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(X"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")#86UB;V1J
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C`*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R
M;V5N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@
M(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DMA;B!W86-H='=O
M;W)D(&YI970@875T;VUA=&ES8V@@<F5S971T96XL(&YE96T@8V]N=&%C="!O
M<"!M970@9&4@(@HB<WES=&5E;6)E:&5E<F1E<BXB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(")+86X@;FEE="!N
M86%R(&)E<W1A;F0@7"(E<UPB('-C:')I:G9E;B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S
M97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R(")+86X@9V5E;B!E>'1E<FYE('-E
M<W-I96AA;F1L97(@8F5H97)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,S$Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R(")+86X@;FEE="!V97)B:6YD96X@;65T
M($E-05`@<V5R=F5R.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")+86X@8F5S=&%N9"!<(B5S7"(@;FEE="!O<&5N
M96XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,0IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A;F%D
M82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$R('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%F8G)E
M:V5N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G
M:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5E;7)A
M<'!O<G0@869B<F5K96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")+86X@8F5S=&%N9"!<(B5S7"(@;FEE="!V97)W
M:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+B(*;7-G<W1R(")+86X@9V5E;B!T:6ID96QI:FME(&1I<F5C=&]R
M>2!V:6YD96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R(")+86X@;FEE="!D;V]R9V%A
M;B!Z;VYD97(@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!D
M:7)E8W1O<GD@7"(E<UPB(&YI970@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")+
M86X@;FEE="!V97)W:6ID97)E;CL@)60@8VAI;&1R96X@8F5S=&%A;BXB"@HC
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G
M:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O
M<F5D+B(*;7-G<W1R("(B"B)+86X@;FEE="!O<&YI975W(')A;F=S8VAI:VME
M;BP@:&5T(&%A;G1A;"!I;G9O97)E;B!O;2!O<&YI975W('1E("(*(G)A;F=S
M8VAI:VME;B!K;VUT(&YI970@;W9E<F5E;B!M970@:&5T(&]P9V5S;&%G96X@
M86%N=&%L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B2V%N(&)E<FEC:'0@;FEE="!N
M86%R(&AE="!O<&=E9V5V96X@;G5M;65R('9E<G-T=7)E;BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8U"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(DMA87`@5F5R9&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D]P<V-H<FEF="(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I
M9"`B0V%R<FEE<B(*;7-G<W1R(")$<F%G97(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R(")#871E9V]R:67K;B!E;B!L86)E;',B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-0IM<V=I
M9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N(&5I;&%N9&5N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM
M<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")496PN;G(N;6]B:65L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(D-E;&5I9V5N<V-H
M87!P96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")#96P@=G)I
M:F4@<G5I;71E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G
M<W1R(")#96QE:6=E;G-C:&%P<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB
M"FUS9W-T<B`B0V5L<W!A=&GK<FEN9SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5&5L+FYR
M+FUO8FEE;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#
M96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT:7-C:"`H25-/+3@X
M-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(DUI9&1E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-30*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*
M;7-G<W1R(")#96YT<F%A;"!!9G)I:V%A;G-E(%)E<'5B;&EE:R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N
M("A)4T\M.#@U.2TR*2(*;7-G<W1R(")#96YT<F%A;"!%=7)O<&5E<R`H25-/
M+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")#97)T
M:69I8V%A=&1E=&%I;',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
M0V5R=&EF:6-A871E:6=E;F%A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*
M;7-G<W1R(")#97)T:69I8V%A=&)E;&5I9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,0IM<V=I
M9"`B0VAA9"(*;7-G<W1R(")4<VIA860B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B5VEJ>FEG96XB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(E=I:GII9R!U=R!W86-H='=O;W)D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB5VEJ
M>FEG(&1E(&YA86TL(&%D<F5S(&5N(&]N9&5R=&5K96YI;F<@9&EE(&UE;B!Z
M:65T(&)I:B!H970@;&5Z96X@96X@(@HB8F5A;G1W;V]R9&5N('9A;B!U=R!E
M+6UA:6QS+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM
M<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R
M=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)7:6IZ:6=E;B!V
M86X@=7<@=V%C:'1W;V]R9"!W;W)D="!N:65T(&]N9&5R<W1E=6YD(&1O;W(@
M9&4@:'5I9&EG92`B"B)C;VYF:6=U<F%T:64N($YE96T@8V]N=&%C="!O<"!M
M970@=7<@<WES=&5E;6)E:&5E<F1E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM
M<V=S='(@(DMA<F%K=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN
M+B(*;7-G<W1R(")#;VYT7W)O;&5E<B!L:6YK+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.0IM
M<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q"FUS9VED
M(")#:&EN82(*;7-G<W1R(")#:&EN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS
M9W-T<B`B0VAI;F5E<R!V97)E96YV;W5D:6=D("A'0C(S,3(I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I(@IM<V=S='(@(D-H:6YE97,@=')A9&ET:6]N965L("A":6<U
M*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S
M92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B2VEE<R!T;V5P87-S:6YG.B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H
M;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(DMI97,@965N('=A8VAT=V]O<F0B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")+:65S(&5E;B!G96)R=6EK
M97)S;F%A;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@
M(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B2VEE<R!D
M871U;7=E97)G879E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")+:65S(&QI
M:G-T<W1I:FQT>7!E("AV;V]R(&=E;W)D96YD92!L:6IS=&5N*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C8*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B0VAR:7-T
M;6%S(&5I;&%N9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,30@9G)A
M;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(D-L87-S9&5F:6YI=&EE('9A;B`E<R!N:65T(&=E=F]N9&5N+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#
M;&5A<B(*;7-G<W1R(")(96QD97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(DU33V9F:6-E('1A9W,@=VES<V5N(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B
M5VES('%U97)Y(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(E=I<R!G96)R=6EK97(Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@
M(E=I<R!G96)R=6EK97(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(E=I<R!G
M96)R=6EK97)S9&%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(DQA
M=&4@;W!K;&%R:6YG96XB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS
M9W-T<B`B2VQI:R!O;2!V97)D97(@=&4@9V%A;B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI
M8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M4VQU:70@<V-H97)M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G
M:60@(D-L;W5D<R(*;7-G<W1R(")7;VQK96XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY
M(@IM<V=S='(@(E9R;V5G92!B97=O;&MI;F<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S
M='(@(D)E=V]L:W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R"FUS9VED(")#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<R(*;7-G<W1R(")#;V-O<R`H2V5E;&EN9RD@96EL86YD96XB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#
M;VQL87!S92!3:61E8F%R(@IM<V=S='(@(EII:F)A;&L@:6YK;&%P<&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B26YG96ML
M87!T92!R86YD96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R"FUS9VED(")#;VQO;6)I82(*;7-G
M<W1R(")#;VQO;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R
M(")+;&5U<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,S.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S,Y('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G
M:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")+;&5U<F5N:VEE>F5R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`IM<V=I9"`B0V]L;W5R('-E
M;&5C=&EO;B(*;7-G<W1R(")+;&5U<G-E;&5C=&EE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z
M(@IM<V=S='(@(DMO;&]M;65N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B2V]L;VUT
M:71E;',B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED
M(")#;VUI8W,B"FUS9W-T<B`B4W1R:7!S(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D]P9')A8VAT(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM
M<V=S='(@(D]P9')A8VAT<VAE;&PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B3W!M97)K
M:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*
M;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(D%L9V5M96YE(&YA86TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F5N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM
M<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")"961R:6IF(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B0V]M
M<'5T97)S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM
M<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(D-O;F1I=&EE(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B
M0V]N9&ET:65S(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@
M(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B5F5R<V-H:6QL
M96X@:6X@8V]N9FEG=7)A=&EE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$
M07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B)#;VYF
M:6=U<F%T:64@=F]O<B!H970@<WEN8VAR;VYI<V5R96X@;65T(%!$02=S+"!3
M;6%R='!H;VYE<R!E;B!/=71L;V]K+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M(@IM<V=S='(@(D-O;F9I9W5R871I92!I<R!V97)O=61E<F0N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYF:6=U<F4@)7,B"FUS9W-T<B`B)7,@8V]N9FEG=7)E<F5N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER
M;2!087-S=V]R9"(*;7-G<W1R(")"979E<W1I9R!W86-H='=O;W)D(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4S"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE(@IM<V=S='(@(DMO;F=O+"!$92!$96UO8W)A=&ES8VAE(%)E<'5B;&EE
M:R!V86X@9&4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B5F5R
M8FEN9&EN9R!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS
M9W-T<B`B5F5R8FEN9&EN9R!M:7-L=6MT.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9&EN
M9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V97(L(&ES(&=E=V5I9V5R
M9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@HB
M5F5R8FEN9&EN9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V97(L(&ES
M(&=E=V5I9V5R9"X@4F5D96XZ("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B5F5R8FEN9&EN9R!M970@1E10('-E<G9E
M<B!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*
M;7-G<W1R(")!9')E<W-E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D%D
M<F5S<V5N('II:FX@;65T('-U8V-E<R!A86X@=7<@861R97-B;V5K('1O96=E
M=F]E9V0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@
M(@IM<V=S='(@(D-O;G1E;G0@='EP92!V86X@9V5C;VUP<FEM965R9"!B97-T
M86YD.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B26YH
M;W5D('9A;B!<(B5S7"(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O
M;G1I;G5E(@IM<V=S='(@(D1O;W)G86%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.`IM<V=I9"`B
M0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VL@96EL86YD96XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#
M;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:>MR96XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P:>MR96X@
M;6ES;'5K=#H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+
M;W!I965R('-E;&5C=&EE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B2V]S=&5N($E$
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T
M82!2:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-PIM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G
M<W1R("))=F]O<FMU<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E
M.B`B"FUS9W-T<B`B2V]N(%!'4"!B97)I8VAT(&YI970@8V]D97)E;CH@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")+;VX@4$=0
M(&)E<FEC:'0@;FEE="!O;F1E<G1E:V5N96XZ("(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B2V]N(&)E<FEC:'0@;FEE
M="!3+TU)344@8V]D97)E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(DMO;B!B97)I8VAT(&YI970@4R]-24U%(&]N9&5R
M=&5K96YE;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DMO;B!A9')E<R`E<R!N:65T('1O
M979O96=E;BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DMO;B!G965N('9E<F)I;F1I;F<@;65T
M(&1E($Q$05`M<V5R=F5R(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B
M2V]N('1E9V]E9"`E<R!N:65T(&-O;G1R;VQE<F5N+B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+;VX@;FEE="!V97)B:6YD96X@;65T
M($Q$05`@<V5R=F5R+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B2V]N(&YI970@=F5R
M8FEN9&5N(&UE="!S97)V97(@7"(E<UPB(&UE="!&5%`Z("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B2V]N(&=E96X@9&ES=')I8G5T:65L:6IS
M="`E<R!M86ME;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM
M<V=S='(@(DMO;B!01U`@9&%T82!N:65T(&1E8V]D97)E;CH@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(")+;VX@4R]-24U%
M(&1A=&$@;FEE="!D96-O9&5R96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+;VX@
M861R97,@)7,@;FEE="!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")+;VX@9&ES=')I8G5T:65L:6IS="`E<R!N:65T('9E<G=I
M:F1E<F5N+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")+;VX@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB(&YI970@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B2V]N(&AE
M="!E+6UA:6QA9')E<R!V86X@9&4@;VYT=F%N9V5R(&YI970@8F5P86QE;BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`B2V]N(&-O;7!L971E(&%D<F5S8F]E:R!N:65T(&]P
M:&%L96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B2V]N(&-O;7!L971E(&1I<W1R
M:6)U=&EE;&EJ<W0@;FEE="!O<&AA;&5N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+B(*;7-G<W1R(")+;VX@8V]M<&QE=&4@;&EJ<W0@=F%N(&1I<W1R:6)U
M=&EE;&EJ<W1E;B!N:65T(&]P:&%L96XN(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DMO;B!S=')A=&5G
M:64@7"(E<UPB(&YI970@;&%D96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B2V]N(&1I<F5C
M=&]R>2!<(B5S7"(@;FEE="!M86ME;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DMO;B!D92!O
M<&5N8F%R92!S;&5U=&5L(&YI970@=F5R:W)I:F=E;B!V86X@9&4@<VQE=71E
M;'-E<G9E<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB
M"FUS9W-T<B`B2V]N(%PB)7-<(B!N:65T(&]P96YE;B!V;V]R('-C:')I:G9E
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(DMO;B`E<R!N:65T(&]P96YE;BXB"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<R(*;7-G<W1R(")+;VX@;VYD97)H;W5D<W1A:V5N;6]D=6QE("5S
M(&YI970@;W!E;F5N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(DMO;B!D:7)E8W1O<GD@7"(E<UPB(&YI970@;W!E;F5N+B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2V]N(&1E($Q$05`M<V5R=F5R
M(&YI970@8F5R96EK96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T
M+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@
M)7,N(@IM<V=S='(@(DMO;B`E<R!N:65T(&QE>F5N+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB2V]N(&AE="!W86-H
M='=O;W)D('9A;B!D92!G97=E;G-T92!G96)R=6EK97(@;FEE="!R97-E='1E
M;BX@4V]M;6EG92!O9B!A;&QE("(*(F1E=&%I;',@>FEJ;B!N:65T(&IU:7-T
M+B!0<F]B965R(&]P;FEE=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE="!D92`B
M"B)S>7-T965M8F5H965R9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP(&YO
M9&EG(&AE969T+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B2V]N
M($%#3"!N:65T(&]P:&%L96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")+
M;VX@861R97-B;V5K("5S(&YI970@;W!H86QE;BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(DMO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@
M;W!H86QE;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")+;VX@
M9&ES=')I8G5T:65L:6IS=&5N("5S(&YI970@;W!H86QE;BXB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")+
M;VX@<V5R=F5R8F5K=V%A;6AE9&5N(&YI970@;W!H86QE;B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N(&-O;F9I9W5R871I92!N:65T
M('1E<G5G>F5T=&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R
M(")+;VX@9&ER96-T;W)Y(%PB)7-<(B!N:65T('9E<G=I:F1E<F5N+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(DMO;B!C;VYF:6=U<F%T:64@)7,@;FEE="!O<'-L86%N+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+B(*;7-G<W1R(")+;VX@9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A
M;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<R(*;7-G<W1R(")+;VX@9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S
M;&%A;CH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")+;VX@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@;FEE="!O<'-L86%N(&%L<SH@7"(E<UPB+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(DMO;B!H970@8F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"!N
M:65T(&]P<VQA86X@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"B)+;VX@:&5T(&-O;F9I9W5R871I96)E<W1A;F0@)7,@;FEE="!O
M<'-L86%N+B!5(&MU;G0@;V8@Z^MN('9A;B!D92!O<'1I97,@(@HB9V5B<G5I
M:V5N(&]M(&1E(&-O9&4@=&5R=6<@;W`@=&4@<VQA86X@;W`@)7,@;V8@;VYD
M97)S=&%A;F1E(&-O9&4@:&%N9&UA=&EG("(*(FYA87(@)7,@:V]P:>MR96XN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@
M(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+
M;VX@9&4@3$1!4"US97)V97(@;FEE="!D;V]R>F]E:V5N+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B2V]N(%PB)7-<(B!N:65T(&QO<VMO
M<'!E;&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V]N(&%D<F5S("5S(&YI970@
M8FEJ=V5R:V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMO;B!D
M:7-T<FEB=71I96QI:G-T("5S(&YI970@8FEJ=V5R:V5N+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G
M<W1R(")+;VX@8V]N9FEG=7)A=&EE('9O;W(@7"(E<UPB(&YI970@=V5G<V-H
M<FEJ=F5N.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(DMO;B!D92!-
M;WII;&QA(%-I9&5B87(@;FEE="!V:6YD96XN(%IO<F<@97)V;V]R(&1A="!D
M92!S:61E8F%R(&]P96X@:7,N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@
M9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)+;VX@9V5B
M<G5I:V5R(%PB)7-<(B!D92!V;VQG96YD92!R96-H=&5N(&]P(&1E(&UA<"!<
M(B5S7"(@;FEE="!G979E;CH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B1V5T96QD
M92!T96MS="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(DQA;F0B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@
M(D-U<G-U<W-E;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@
M(DUA:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@
M(DUA86L@965N(&QI;FLB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@
M(DUA86L@965N(&YI975W92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C4R"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T
M<B`B36%A:R!S=6)M87!P96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R
M(")%:6=E;F%A<G)E8VAT96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C$R"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B0W)E
M9&ET8V%R9&YU;6UE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y"FUS9VED(")#<F]A=&EA(@IM
M<V=S='(@(DMR;V%T:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T"FUS9VED(")#=6)A(@IM<V=S
M='(@(D-U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U
M<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B2'5I9&EG92`T(&9A<V5N(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS
M(@IM<V=S='(@(DAU:61I9V4@<V5S<VEE<R(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4
M:6UE(@IM<V=S='(@(DAU:61I9V4@=&EJ9"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R
M<F5N="!54DP@:7,B"FUS9W-T<B`B2'5I9&EG92!54DP@:7,B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T
M<B`B2'5I9&EG92!G96)R=6EK97)S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(DAU:61I9R!W
M965R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I
M9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")(=6ED:6=E(&-O;F1I
M=&EE.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(DAU:61I9V4@
M<W1I:FPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RXB"FUS9W-T<B`B06%N<&%S<V5N('9A;B!T86ME;B!T:6ID96YS
M(&%A;FUE;&1I;F<@8FEJ("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(DMN:7!P96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(E-E
M;&5C=&EE(&MN:7!P96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R=7,B"FUS
M9W-T<B`B0WEP<G5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-Y<FEL;&ES8V@@*$M/
M23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B0WER:6QL:7-C:"`H5VEN
M9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0WER:6QL
M:7-C:"]5:W)A:6YS("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.`IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`B5'-J96-H:7-C:&4@4F5P=6)L:65K(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<R"FUS9VED("(B"B)$
M4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E
M+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H
M>FEE(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R
M(")$86=E;&EJ:W,B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@
M(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@8G)O=W-E<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S`*;7-G:60@(D1A=&%B
M87-E($QO;VMU<"(*;7-G<W1R(")$871A8F%S92!D;V]R>F]E:V5N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDX"FUS9VED(")$871E(@IM<V=S='(@
M(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T=6T@3VYT=F%N
M9V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<X.0IM<V=I9"`B
M1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B1&%T=6T@<V5L96-T:64B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")$86<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E9E<E]W:6ID
M97(@:V]L;VTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5C96UB97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5C:6UA
M;&4@9V5T86QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B
M26YS<')I;F=E;B!V97)K;&5I;F5N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`B4W1A;F1A87)D(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B
M"FUS9W-T<B`B4W1A;F1A87)D(&ML975R(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R(")3=&%N9&%A<F0@:61E;G1I=&5I="(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW-0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3
M=&%N9&%A<F0@<VAE;&PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*
M;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:71I97,B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"FUS9VED(")$
M96QE=&4B"FUS9W-T<B`B5F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E
M;&5T92!#96QL(@IM<V=S='(@(E9E<G=I:F1E<B!C96PB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L
M971E($=R;W5P(@IM<V=S='(@(D=R;V5P('9E<G=I:F1E<F5N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G
M(@IM<V=S='(@(E9E<G=I:F1E<B!L;V<B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")296-H="!V
M97)W:6ID97)E;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(E9E<G=I:F1E<B!E;B!W:7,@8F5R:6-H=&5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B5F5R=VEJ9&5R(&-E;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B5F5R=VEJ9&5R(&MO;&]M
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E
M>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B0F5S=&%A;F0@
M86QT97)N871I968@<VIA8FQO;VX@=F5R=VEJ9&5R96XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E
M(&UE<W-A9V5S(@IM<V=S='(@(E9E<G=I:F1E<B!B97)I8VAT96XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M(")296-H=&5N('9A;B!<(B5S7"(@=F5R=VEJ9&5R96XB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`B4F5C:'1E;B!E;B!E=F5N='5E;&4@<W5B
M<F5C:'1E;B!V;V]R(%PB)7-<(B!V97)W:6ID97)E;C\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@<F]W(@IM<V=S='(@(E9E<G=I:F1E<B!R:6HB"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE
M=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B1V5S96QE8W1E97)D92!I
M9&5N=&ET96ET('9E<G=I:F1E<F5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R
M<R(*;7-G<W1R(")697)W:6ID97(@<W5B;6%P<&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E9E<G=I:F1E
M<B!D92!H=6ED:6=E(&MO;&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@<F]W(@IM<V=S='(@(E9E<G=I:F1E<B!D92!H=6ED:6=E(')I
M:B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R(")3971U<"!U<&=R861E('-C<FEP="!<(B5S7"(@=F5R=VEJ
M9&5R9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(D%F;&5V97)T:6ID(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N;6%R
M:R(*;7-G<W1R(")$96YE;6%R:V5N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM
M<V=S='(@(D)E<V-H<FEJ9B!H970@<')O8FQE96TB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B0F5S8VAR:6IV:6YG(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HR,#8*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3HB"FUS9W-T<B`B1&5T86EL<R`H;V]K(&EN($AO<F1E)W,@;&]G8F5S=&%N
M9"DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,3`*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(D1E=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T
M965M8F5H965R9&5R+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D]N='=I:VME;&EN9R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B
M"FUS9W-T<B`B1&%U=W!U;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")$
M875W<'5N="!V;V]R(&AE="!A9F=E;&]P96X@=75R.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*
M;7-G<W1R(")$875W<'5N=#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0B"FUS9W-T<B`B4FEC:'1I;F<@;&EN:W,@;F%A<B!R96-H="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G
M:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(E)I8VAT:6YG
M(')E8VAT<R!N86%R(&QI;FMS(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W1O<GDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_(@IM<V=S='(@(C(T+75U<G,@=&EJ9'=E97)G879E/R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T
M:6]N<R(*;7-G<W1R(")7965R9V%V96]P=&EE<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F
M;W)E8V%S="(*;7-G<W1R(")'961E=&%I;&QE97)D92!W965R<W9O;W)S<&5L
M;&EN9R!T;VYE;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@
M(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B5V5E<G-V;V]R<W!E
M;&QI;F<@=&]N96X@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-SDY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")7965R9V%V
M969O<FUA870B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ
M"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B5F]O
M<F)E<F5I9&EN9W-N;W1I9FEC871I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`*;7-G:60@(D1J
M:6)O=71I(@IM<V=S='(@(D1J:6)O=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T
M<B`B3FEE="!V97)W:6ID97)E;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'`B"FUS9W-T<B`B;6%I;G1E;F%N8V4N<&AP(&YI970@9&ER96-T
M(&%A;G-P<F5K96XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")"979A="!D92!E97)S=&4@<FEJ
M(&1E('9E;&1N86UE;C\@6F\@:F$L(&1I="!H;VMJ92!A86YV:6YK96XZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,@IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<S"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B1&]M:6YI8V%A;G-E(%)E<'5B;&EE:R(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB"FUS9W-T<B`B1V5E;B!A8V-O=6YT/R!38VAR:6IF('4@:6XN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4S"FUS
M9VED(")$;W=N;&]A9"(*;7-G<W1R(")$;W=N;&]A9&5N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*
M;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B5S(&1O=VYL;V%D96XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R
M(")$;W=N;&]A9"!G96=E;F5R965R9&4@8V]N9FEG=7)A=&EE(&%L<R!02%`@
M<V-R:7!T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(D1R;W`@9&]W;B!L:6IS="(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS
M9W-T<B`B1')U9W,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+4UA:6PB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(D4M;6%I;"!N
M86%R(%--4R!G871E=V%Y('-T=75R<')O9W)A;6UA+"!V;V]R(&1R86=E<G,@
M9&EE(&1E>F4@<V5R=FEC92`B"B)O;F1E<G-T975N96XN(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4*
M;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16-U861O<B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")"97=E<FME;B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D
M:70@0FQO8VLB"FUS9W-T<B`B0FQO:R!B97=E<FME;B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET
M($=R;W5P(@IM<V=S='(@(D=R;V5P(&)E=V5R:V5N(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E)E
M8VAT(&)E=V5R:V5N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")296-H=&5N(&)E
M=V5R:V5N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R(")296-H=&5N('9A;B`G)7,G(&)E=V5R:V5N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS
M9W-T<B`B3W!T:65S(&)E=V5R:V5N('9O;W(Z(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E)E8VAT96X@=F%N
M(%PB)7-<(B!B97=E<FME;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B4F5C:'1E;B!V86X@)7,@8F5W97)K96XB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G
M<W1R(")/;F1E<G=I:G,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W"FUS9VED(")%9WEP="(*;7-G
M<W1R(")%9WEP=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<*;7-G:60@(D5L(%-A;'9A9&]R
M(@IM<V=S='(@(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT
M+BXN(@IM<V=S='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B
M16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL
M(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM<V=I
M9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%+6UA:6QA9')E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E
M<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%+6UA:6QA9')E<W-E;B!M;V5T
M96X@;W9E<F5E;FMO;65N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(D4M;6%I;"!M970@8F5V97-T:6=I;F<B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3
M($=A=&5W87DB"FUS9W-T<B`B12UM86EL(&YA87(@4TU3(&=A=&5W87DB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS
M9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B16UO=&EC;VYS(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("),965G(&)E<FEC:'0N(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM
M<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")'965N(')E<W5L=&%A="XB
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED
M(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B3&5G92!Z;V5K=&5R;65N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE
M(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@
M=&5X=#\B"FUS9W-T<B`B26YV;V5G96X@=F%N(&%F8F5E;&1I;F=E;B!U:70@
M9F]T;V%L8G5M<R!I;B!T96MS="!I;G-C:&%K96QE;C\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/R(*;7-G<W1R(")296-H=&ML:6MK96X@8V]N=&5X="!M
M96YU(&EN<V-H86ME;&5N/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U.#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B16YD
M('EE87(B"FUS9W-T<B`B16EN9&IA87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R(")697)G<F]O="!E9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB1V5E9B!E96X@8F5V96EL:6=I
M;F=S=G)A86<@9&EE('4@9V5V<F%A9V0@=V]R9'0L('=A;FYE97(@:&5T(&YO
M9&EG(&ES(&]M('5W("(*(G=A8VAT=V]O<F0@=&4@<F5S971T96XL(&(N=BX@
M)W=A="!I<R!D92!N86%M('9A;B!U=R!H=6ES9&EE<C\G.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.0IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(E9O
M97(@9&4@869B965L9&EN9R!54DP@:&EE<B!I;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H
M92!L971T97)S(&)E;&]W.B(*;7-G<W1R(")6;V5R(&]N9&5R<W1A86YD92!L
M971T97)S(&EN.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D*;7-G:60@(D5Q=6%T;W)I86P@1W5I
M;F5A(@IM<V=S='(@(D5Q=6%T;W)I86%L($=U:6YE92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD*
M;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E82(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H
M<#HY-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT.`IM<V=I9"`B17)R;W(B"FUS9W-T<B`B1F]U="(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G
M<W1R(")&;W5T(&)I:B!M86ME;B!V86X@8FQO:SH@)7,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B1F]U="!B
M:6H@=F5R=VEJ9&5R96X@=F%N('-Y;F,@86YK97(Z("5S(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(D9O=70@8FEJ
M('9E<G=I:F1E<F5N('9A;B!S>6YC(&QO9SH@)7,B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(D9O=70@8FEJ
M(&]P:&%L96X@=F%N(&EN:&]U9#H@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D9O=70@8FEJ(&)I:G=E<FME
M;B!V86X@=V%C:'1W;V]R9#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@
M96UA:6P@;65S<V%G92XB"FUS9W-T<B`B1F]U="!M970@92UM86EL8F5R:6-H
M="XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")&;W5T(&)I:B!S
M8VAR:6IV96X@=F%N(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V"FUS9VED(")%<W1O
M;FEA(@IM<V=S='(@(D5S=&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q"FUS9VED(")%=&AI
M;W!I82(*;7-G<W1R(")%=&AI;W!IZR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FES8V@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S
M"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D5L:V4@,34@;6EN
M=71E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V
M97)Y(#(@;6EN=71E<R(*;7-G<W1R(")%;&ME(#(@;6EN=71E;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")%;&ME(#,P
M('-E8V]N9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B
M"FUS9W-T<B`B16QK92`U(&UI;G5T96XB"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*
M;7-G<W1R(")%;&ME(&%A;FUE;&1I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B16QK
M(&AA;&8@=75R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`B16QK92!M:6YU=70B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(E9O;W)B
M965L9'=A87)D96XZ(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D;6EN
M+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED
M(")%>&5C=71E(@IM<V=S='(@(E5I='9O97)E;B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B56ET:VQA<'!E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@
M(EII:F)A;&L@=6ET:VQA<'!E;B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")6
M97)W86-H='1E("<I)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FTB"FUS9W-T<B`B5F5R=V%C:'1T92!E;FME;"!W;V]R9"!O
M9B!A86YG96AA86QD92!Z;V5K=&5R;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S
M='(@(E9E<G9A;&1A='5M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5X<&]N96YT
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B5F]O<F=R;VYD:VQE
M=7(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@
M=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D944"!U<&QO860@=F%N('-E='5P
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C(P"FUS9VED
M(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B3W!H
M86QE;B!V;V]R:V5U<G-I;G-T96QL:6YG96X@;6ES;'5K="XB"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(E9E<F)I;F1I;F<@;65T(&1E($Q$05`M
M<V5R=F5R(&ES(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+B(*;7-G<W1R(")697)B:6YD:6YG(&UE="!D92!334(M<V5R=F5R(&ES
M(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(DMO<&GK<F5N('5I="!<(B5S7"(@:7,@;6ES;'5K="XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@
M(DMO<&GK<F5N(&YA87(@7"(E<UPB(&ES(&UI<VQU:W0N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R
M96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")-86ME;B!V86X@
M;FEE=7=E(%-!4TP@=F5R8FEN9&EN9R!I<R!M:7-L=6MT+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB"FUS9W-T<B`B5F5R<&QA871S96X@;F%A<B!<(B5S7"(@
M:7,@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S
M(@IM<V=S='(@(D]P:&%L96X@=F%N("5S(&ES(&UI<VQU:W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I
M<B(*;7-G<W1R(")-;V]I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-`IM<V=I9"`B1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD(&5I;&%N9&5N
M("A-86QV:6YA<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(D9A<F_K<B!E:6QA;F1E;B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")&871A
M;&4@9F]U=#HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B
M1F%X96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<FDB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R(")6;V5L="!A;',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B5F]E;'0@86QS
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B16YK96QE(&)U:65N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G
M:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B16YI9V4@<VYE975W8G5I
M96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&
M:65L9"!M871R:7@B"FUS9W-T<B`B5F5L9&UA=')I>"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,C4*;7-G:60@(D9I9VQE="!#05!40TA!(@IM
M<V=S='(@(D9I9VQE="!#05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,R.0IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B1FEG;&5T
M(&9O;G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@S"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I
M;&4B"FUS9W-T<B`B0F5S=&%N9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8W"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`B06%N=&%L(&)E<W1A;F1E;CH@)7,@8F5S=&%N9"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D%A;G1A;"!B97-T
M86YD96XZ("5S(&)E<W1A;F1E;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")"97-T86YD
M8F5H965R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*;7-G:60@
M(D9I;&4@3F%M92(*;7-G<W1R(")"97-T86YD<VYA86TB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3<W"FUS9VED(")&:6QE('-E;&5C=&EO;B(*
M;7-G<W1R(")"97-T86YD(&MI97IE;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(D)E<W1A
M;F1U<&QO860B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,#(*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M(")"97-T86YD=7!L;V%D<R!W;W)D96X@;FEE="!O;F1E<G-T975N9"XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B1FEL=&5R<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(*;7-G:60@(D9I;FQA;F0B
M"FUS9W-T<B`B1FEN;&%N9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*
M;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B165R<W1E(&AE;&9T(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM
M<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")%97)S=&4@:W=A<G1A86PB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W
M"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B5F5R:&]U9&EN9R!H97)S=&5L
M;&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")/;6ME<F5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I
M9"`B1FQO870B"FUS9W-T<B`B1')I:G9E;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B
M36ES="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(DUA<"`E<R!B
M97-T86%T(&YI970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D9O;G1K
M;&5U<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O
M9"(*;7-G<W1R(")6;V5D<V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"FUS9VED(")&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")6;V]R
M(&)R;W=S97)S(&1I92!G965N(&%F8F5E;&1I;F=E;B!O;F1E<G-T975N96XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I9"`B1F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`B5V5E<G-V;V]R<W!E;&QI;F<@*%1!1BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB
M5F]O<G5I='II8VAT9&%G96X@*&UE<FL@;W`@9&%T(&AE="!G96=E=F5N('9O
M;W)U:71Z:6-H="!D86=E;B!E;B!N86-H=&5N("(*(F=E969T.R!E96X@9W)O
M;W0@86%N=&%L(&MA;B!R97-U;'1E<F5N(&EN(&5E;B!B<F5E9"!B;&]K*2(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G
M;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B57<@=V%C:'1W;V]R9"!V97)G
M971E;C\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED
M(")&;W)M<R(*;7-G<W1R(")&;W)M=6QI97)E;B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")&;W)T=6YE
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE
M('1Y<&4B"FUS9W-T<B`B1F]R='5N971Y<&4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D9O<G1U;F5S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE
M<R`R(@IM<V=S='(@(D9O<G1U;F5S(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R=6US(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`B1&]O<G-T=7)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E9R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(D9R86UE<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#<*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N:W)I:FLB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@
M365T<F]P;VQI=&%N(@IM<V=S='(@(D9R86YK<FEJ:RP@2&]O9F1S=&5D96QI
M:FLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDQ"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@
M(D9R86YS($=U>6%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T"FUS9VED(")&<F5N8V@@4&]L
M>6YE<VEA(@IM<V=S='(@(D9R86YS(%!O;'EN97-IZR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,@IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@
M(D9R86YS92!:=6ED96QI:FME(%1E<G)I=&]R:6$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM
M<V=S='(@(E9A;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS
M9W-T<B`B5F%N(&1E("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E9O;&QE
M9&EG92!B97-C:')I:G9I;F<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S
M='(@(E9O;&QE(&UA86XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C4@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L
M;"!.86UE(@IM<V=S='(@(E9O;&QE9&EG92!N86%M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.`IM
M<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@
M(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D%L8G5M('=A
M87)U:70@9&4@869B965L9&EN9R!G96AA86QD(&1I96YT('1E('=O<F1E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B06QB=6TZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-@IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F5E
M<B`E<R!C;VYF:6=U<F%T:64B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B
M1V5G96YE<F5E<F1E(&-O9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP"FUS9VED(")'96]R9VEA
M(@IM<V=S='(@(D=E;W)G:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y"FUS9VED(")'97)M86YY
M(@IM<V=S='(@(D1U:71S;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,*;7-G:60@(D=H86YA
M(@IM<V=S='(@(D=H86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R
M(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E9O
M;W)N86%M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B1VQO
M8F%L92!O<'1I97,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM
M<V=I9"`B1V\B"FUS9W-T<B`B1V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B
M1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE(&MA87)T96XB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM
M<V=S='(@(D=O;V=L92!Z;V5K96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T
M<B`B1W)I:G-S8VAA86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,`IM<V=I9"`B1W)E96-E(@IM
M<V=S='(@(D=R:65K96YL86YD(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<FEE:W,@
M*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-0IM<V=I9"`B1W)E96YL86YD(@IM
M<V=S='(@(D=R;V5N;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D*;7-G:60@(D=R96YA9&$B
M"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS
M9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<F]E<'-B96AE
M97(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R;V5P;F%M96X@;6]G96X@
M;FEE="!L965G('II:FXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("(*;7-G<W1R(")'<F]U<%]L9&%P.B!.:65T(&EN('-T86%T(&=R
M;V5P("5S('1O92!T92!V;V5G96XN($1E('-E<G9E<B!M96QD=#H@(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U
M<%]L9&%P.B!.:65T(&EN('-T86%T(&=R;V5P("5S('1E('9E<G=I:F1E<F5N
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B
M"FUS9W-T<B`B1W)O=7!?;&1A<#H@3FEE="!I;B!S=&%A="!G<F]E<"`E<R!B
M:6H@=&4@=V5R:V5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<F]E
M<&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY.`IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'
M=6%D96QO=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,*;7-G:60@(D=U86TB"FUS9W-T<B`B
M1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`R"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B
M1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM
M<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")'
M87-T(')E8VAT96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R
M"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B1V%S=&5N8F]E:R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3<*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN964B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#0*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5E+4)I
M<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U
M>6%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B
M2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M(@IM<V=S='(@(DA434Q!<F5A('=E:6=E<G0@;&%F(&]M(&1E(&QA871S=&4@
M8V5L(&EN(&1E(')I:B!T92!V97)W:6ID97)E;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A('=E:6=E<G0@;&%F
M(&]M(&1E(&QA871S=&4@:V]L;VT@:6X@9&4@=&%B96P@=&4@=F5R=VEJ9&5R
M96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,
M07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T<W1E(')I:B!I;B!D92!T86)E
M;"!T92!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT
M='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(DA45%`@875T:&5N=&EC871I92!N:65T(&=E=F]N9&5N
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M86QG;W)I=&AM92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")(87IE(@IM<V=S='(@(DYE=F5L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,30*;7-G:60@
M(DAE861E<B(*;7-G<W1R(")+;W`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@
M(DMO<'!E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-PIM<V=I9"`B2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D(&5I;&%N9"!E;B!-
M8T1O;F%L9"!E:6QA;F1E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(EIW87)E(&]N=V5E<G-B=6DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E
M975W<R`H25-/+3@X-3DM."U)*2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")(;V]G=&4B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B
M"FUS9W-T<B`B2&5L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(DAE;'`@8FEJ(&=E8G)U:6L@=F%N(&5D:71O<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(
M96QP97(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES
M<&AE<F4B"FUS9W-T<B`B2&%L9G)O;F0B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM
M<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G
M<W1R(")(:65R(&ES(&AE="!B96=I;B!V86X@:&5T(&)E<W1A;F0Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@
M(DAI9V@B"FUS9W-T<B`B2&]O9R(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM
M<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]?;64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S"FUS
M9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")(
M;VQY(%-E92`H5F%T:6-A86YS=&%D*2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R(")(;VUE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED
M(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R97,@*'!R:7;I*2(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB
M"FUS9W-T<B`B2&]M961I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS
M9W-T<B`B5&5L+FYR+B`H<')I=NDI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X"FUS9VED(")(
M;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-@IM<V=I
M9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!/;F=E;&1I9V4@)7,@6$U,(&1A=&$@=&5G96YG96MO;65N(&EN(&)E
M<FEC:'0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($=E96X@8F5R:6-H="!C;W)R97-P;VYD965R="!M970@;V)J96-T("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($=E96X@
M;V)J96-T('9A;B!T>7!E("5S(&=E=F]N9&5N(&EN(&)E<FEC:'0@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@;65T('-U8V-E<R!V
M97)W:6ID97)D(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@1&4@:6YT97)G<F%T:64@=F5R96ES="!D92`G
M9&]M>&UL)R!E>'1E;G-I92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!+86X@9V5E;B!N:65U=V4@6$U,(&)O;VT@;6%K
M96X@=F]O<B!O8FIE8W0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@2V%N("5S(%PB)7-<(B!N:65T('9E<G=I:F1E<F5N.B`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"B)(;W)D92]+
M;VQA8CH@3FEE="!I;B!S=&%A="!H970@34E-12!)1"P@=F]O<B!H970@9V5D
M965L=&4@;65T('1Y<&4@)7,L(&]P('1E("(*(FAA;&5N(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N("5S(%PB)7-<(B!N:65T
M('-Y;F-H<F]N:7-E<F5N.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($MA;B!G961E96QD92!B<F]N;F5N(&YI970@<WEN8VAR;VYI
M<V5R96XZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA
M<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!/;F)E:V5N9&4@9V5D
M965L9&4@8G)O;B!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS
M9W-T<B`B2&]R:7IO;G1A;&4@;&EJ;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D
M9&EN9R(*;7-G<W1R(")(;W)I>F]N=&%L92!V<FEJ92!R=6EM=&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED
M(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N=&%A;#HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*
M;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I
M(@IM<V=S='(@(DAO92!K=V%M('4@:&EE<C\@*$=R86%G(')A<'!O<G1A9V4A
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_(@IM<V=S='(@(DAO979E96P@:V]L;VUM96X@=VEL="!U
M('-A;65N=F]E9V5N/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\B"FUS9W-T<B`B2&]E=F5E;"!V96QD96X@*&MO;&]M;65N*2!Z:6IN(&5R
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(DAO979E96P@<FEJ96X@=VEL="!U('-A;65N
M=F]E9V5N/R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*;7-G:60@(DAU;6ED:71Y(@IM<V=S
M='(@(E9O8VAT:6=H96ED(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")6;V-H=&EG:&5I
M9#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO
M<FES=',B"FUS9W-T<B`B2'5M;W)I<W1E;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,0IM<V=I
M9"`B2'5N9V%R>2(*;7-G<W1R(")(;VYG87)I:F4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")-86ME;B!V86X@24U!
M4"!M86EL8F]X(&UI<VQU:W0Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(Y-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B5F5R=VEJ9&5R96X@=F%N($E-05`@
M;6%I;&)O>"!M:7-L=6MT.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR-#(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DUA:V5N('9A;B!)34%0(&UA
M:6QB;W@@<75O=&$@;6ES;'5K=#H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0($%D
M<F5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A
M9')E<R!N:65T(&)E<V-H:6MB86%R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0(&%D<F5S('9A;'0@
M;FEE="!B:6YN96X@:&5T('1O96=E<W1A;F4@0TE$4B!B;&]K+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM
M<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("))4"!L;V-K
M9&]W;B!O=F5R=')E9&EN9RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W
M($)E9F]R92(*;7-G<W1R(")2:6H@:5]N=F]E9V5N('9O;W(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C`*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B24IS;&%N9"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS
M9W-T<B`B06QL965N('!I8W1O9W)A;6UE;B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B
M"FUS9W-T<B`B4&EC=&]G<F%M;65N('9O;W(@)7,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T
M<B`B4&EC=&]G<F%M;65N(&UE="!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B
M261E;G1I=&5I='-N86%M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N(@IM<V=S='(@(B(*(E=A;FYE97(@:&5T(&YI970@9V]E9"!W
M;W)D="!W965R9V5G979E;BP@)7,@;VT@:&5T(&EN(&5E;B!N:65U=R!S8VAE
M<FT@=&4@(@HB;W!E;F5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T
M<B`B(@HB06QS('4@9V5E;B!P:6-T;V=R86UM96X@>FEE="P@8FEJ(&=E8G)U
M:6L@=F%N($EN=&5R;F5T($5X<&QO<F5R+"!K86X@:&5T("(*(FYO9&EG('II
M:FX@9&ET('9A:VIE(&%A;B!T92!V:6YK96X@;VT@4$Y'('1R86YS<&%R871I
M92!U:70@=&4@<V-H86ME;&5N+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+B(*;7-G<W1R("(B"B)786YN965R('4@9&ET(&)E<FEC:'0@>FEE="P@;6%A
M<B!G965N(&%F8F5E;&1I;F<L(&1A;B!K86X@9&4@869B965L9&EN9R!D:64@
M(@HB=2!W:6QT('5P;&]A9&5N(&YI970@9&]O<B!U=R!B<F]W<V5R('=O<F1E
M;B!W965R9V5G979E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*;7-G:60@(DEM86=E(%!R979I
M97<Z(@IM<V=S='(@(D%F8F5E;&1I;F=S8F5O;W)D96QI;F<Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM
M<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D%F8F5E;&1I;F<@55),(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$X"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(D%F8F5E;&1I;F<@
M55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM
M<V=S='(@(D%F8F5E;&1I;F<@=6ET(&%L8G5M(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(D%F8F5E;&1I;F<@=6ET
M(&%L8G5M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G
M:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")!9F)E96QD:6YG<W5P;&]A9"(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B069B965L9&EN9V5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z-R!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C<@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B
M"FUS9W-T<B`B26UP;W)T97)E;BP@<W1A<"`E9"(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M=&5D(&9I96QD.B`E<R(*;7-G<W1R(")'96EM<&]R=&5E<F0@=F5L9#H@)7,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O
M<G1E9"!F:65L9',Z(@IM<V=S='(@(D=E:6UP;W)T965R9&4@=F5L9&5N.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B4FEJ
M(&EN=F]E9V5N(&YA(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN(@IM<V=S='(@(D]N:G5I<W1E(&)E=V5R:VEN9W-C;V1E(&]P9V5G979E
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@96XO;V8@
M=V%C:'1W;V]R9"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)/
M;FIU:7-T92!G96)R=6EK97)S;F%A;2!O9B!A;'1E<FYA=&EE9B!A9')E<RX@
M4')O8F5E<B!O<&YI975W(&]F(&YE96T@(@HB8V]N=&%C="!O<"!M970@9&4@
M<WES=&5E;6)E:&5E<F1E<BP@=V%N;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I
M9R!H965F="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B5F5R
M9W)O;W0@:6YS<')I;F=I;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38*;7-G:60@(DEN9&EA
M(@IM<V=S='(@(DEN9&EA(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@
M(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B26YD:79I9'5E;&4@9V5B<G5I
M:V5R<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(DEN9&]N97-IZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N
M(@IM<V=S='(@(DEN9F]R;6%T:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+B(*;7-G<W1R("));F9O<FUA=&EE(&YI970@;&%N9V5R(&)E<V-H
M:6MB86%R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B
M"FUS9W-T<B`B2V]L;VT@:6YV;V5G96X@;F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*;7-G:60@
M(DEN<V5R="!);6%G92(*;7-G<W1R(")!9F)E96QD:6YG(&EN=F]E9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM
M<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(E1A8F5L(&EN=F]E9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM
M<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(E=E8FQI;FL@:6YV;V5G
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G
M<W1R(")?2V]L;VT@:6YV;V5G96X@=F]O<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B165N(&YI975W92!K;VQO;2!I;G9O96=E;B!N82!D92!H=6ED:6=E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B165N(&YI975W92!K;VQO;2!I;G9O96=E
M;B!V;V]R(&1E(&AU:61I9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5E;B!N:65U
M=V4@<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R(")%96X@;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H=6ED:6=E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R(")%96X@;FEE=7=E('!A<F%G<F%A9B!I;G9O
M96=E;B!N82!D92!H=6ED:6=E(&YO9&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M(")%96X@;FEE=7=E('!A<F%G<F%A9B!I;G9O96=E;B!N82!D92!H=6ED:6=E
M(&YO9&4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")!;'1E<FYA=&EE9B!S
M:F%B;&]O;B!I;G9O96=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R(")%96X@
M92UM86EL861R97,@:6YV;V5G96XL('=A87(@=2!H970@;FEE=7=E('=A8VAT
M=V]O<F0@:V%N(&]N='9A;F=E;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L
M;"!A9G1E<B(*;7-G<W1R(")#96P@:6YV;V5G96X@;F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED
M("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B0V5L(&EN=F]E9V5N('9O
M;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@
M(DMO;&]M(&EN=F]E9V5N(&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M
M;B!B969O<F4B"FUS9W-T<B`B2V]L;VT@:6YV;V5G96X@=F]O<B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"FUS9VED("));G-E
M<G0@;65S<V%G97,B"FUS9W-T<B`B0F5R:6-H=&5N(&EN=F]E9V5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(E!A
M<F%G<F%A9B!I;G9O96=E;B!N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B4&%R86=R86%F(&EN=F]E9V5N('9O
M;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(E)I
M:B!I;G9O96=E;B!N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E
M(@IM<V=S='(@(E)I:B!I;G9O96=E;B!V;V]R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")(970@9V5W
M96YS=&4@86YT=V]O<F0@=F]O<B!D92!B979E:6QI9VEN9W-V<F%A9R!I;G9O
M96=E;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(D%F
M8F5E;&1I;F<@:6YV;V5G96XO86%N<&%S<V5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(DQI;FL@:6YV;V5G96XO86%N<&%S<V5N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D]N=F]L9&]E;F1E(&MR961I
M970@;VT@;F%A<B!D92!D:7-T<FEB=71I96QI:G-T('1E('IE;F1E;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B3VYV;VQD
M;V5N9&4@:W)E9&EE="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B26YT96=E<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*
M;7-G<W1R("));G1E9V5R(&QI:G-T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")/;F=E;&1I9V4@541(
M+B`H57-E<B!$871A($AE861E<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS
M9W-T<B`B3VYG96QD:6=E(%I)4"!D871A(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`B3VYG96QD:6=E('1O97!A<W-I;F<N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED
M(&)A=&-H($E$+B(*;7-G<W1R(")/;F=E;&1I9R!B871C:"!)1"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T
M82!S=6)M:71T960N(@IM<V=S='(@(D]N9V5L9&EG92!D871A(&]P9V5G979E
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B3VYG96QD:6<@8F5S=&5M;6EN9V%D<F5S+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED
M(&9I;&4@9F]R;6%T(@IM<V=S='(@(D]N9V5L9&EG('1I:F1F;W)M86%T(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV
M86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3VYG96QD:6=E(&QI8V5N=&EE
M<VQE=71E;"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")/
M;F=E;&1I9V4@;&]C871I92!O<&=E9V5V96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A
M;&ED(&US9U]T>7!E+B(*;7-G<W1R(")/;F=E;&1I9R!M<V=?='EP92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@
M(D]N9V5L9&EG(&]F(&]N=&)R96ME;F0@87!I7VED+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(D]N9V5L
M9&EG92!O9B!O;G1B<F5K96YD92!P87)A;65T97)S+B(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B3VYG96QD:6<@<&%R96YT(')E8VAT+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L
M:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B3VYG96QD:6<@<&%R=&YE<B!I9"XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("))
M;G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B3VYG96QD:6=E('!R;V1U
M8W1I96-O9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G
M<W1R(")/;F=E;&1I9R!P<F]T;V-O;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED
M(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D]N9V5L9&EG92!O;G1V86YG
M97(Z(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`X
M,"!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L
M:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(D]N9V5L9&EG92!G961E96QD92!B
M<F]N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G
M<W1R(")/;F=E;&1I9R!B<F]N861R97,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED
M('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B3VYG96QD:6=E('5N:6-O9&4@9&%T
M82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B26YV96YT87)I<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S
M96QE8W1I;VXB"FUS9W-T<B`B4V5L96-T:64@;VUK97)E;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q.0IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R
M("))<F%N+"!)<VQA;6ET:7-C:&4@4F5P=6)L:65K('9A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q.`IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S
M"FUS9VED("))<F5L86YD(@IM<V=S='(@(DEE<FQA;F0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS
M9W-T<B`B16EL86YD($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R(")'96ES;VQE97)D92!O;G=E97)S8G5I96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30*
M;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)AZVPB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S
M='(@(E5I=&=E=F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B0W5R<VEE9B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,0IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&GK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(S"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM
M<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YU87)I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U
M"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!A;B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM
M<V=S='(@(DIA<&%N<R`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S
M97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C0*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D
M86YIZR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(DIU;&DB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G
M<W1R(")*=6YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")U:71L
M:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B
M1V5C96YT<F5E<F0@=6ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@
M1G5L;"(*;7-G<W1R(")6;VQL961I9R!U:71L:6IN96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I
M9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(DQI;FMS('5I=&QI:FYE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(E)E8VAT<R!U:71L
M:6IN96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T
M<B`B2V%Z86-H<W1A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@
M(D]R:6=I;F5E;"!B96AO=61E;C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8*;7-G:60@(DME
M;GEA(@IM<V=S='(@(DME;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!S97)V97(@=V5I9V5R
M9&4@875T:&5N=&EC871I92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"!.97=B
M:65S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B4VQE=71E;"!M86ME;B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y
M($9I;F=E<G!R:6YT(@IM<V=S='(@(E-L975T96QV:6YG97)A9F1R=6LB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME
M>2!,96YG=&@B"FUS9W-T<B`B4VQE=71E;&QE;F=T92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS
M9W-T<B`B4VQE=71E;'1Y<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E-L975T
M96QG96)R=6EK(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(D1E('-L975T96P@8F5S=&%A="!A;"!O<"!D
M92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")+:6YD97)E;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R.0IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S(*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A+"!$96UO8W)A=&ES8VAE
M(%9O;&MS<F5P=6)L:65K('9A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,PIM<V=I9"`B2V]R
M96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A+"!297!U8FQI96L@=F%N
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H
M155#+4M2*2(*;7-G<W1R(")+;W)E86%N<R`H155#+4M2*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-`IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMO97=E:70B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C<*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2WER9VEE<VGK(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T
M(@IM<V=S='(@(D]?<&UA86LB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")486%L(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8R(*;7-G<W1R(")$96UO8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K($QA;R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*
M;7-G<W1R("),86%T<W1E(&AE;&9T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@X"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("),
M86%T<W1E('=A8VAT=V]O<F1W:6IZ:6=I;F<B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U
M87)T97(B"FUS9W-T<B`B3&%A='-T92!K=V%R=&EE<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@
M(DQA871S="!B:6IG97=E<FMT.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*
M;7-G<W1R("),86%T<W1E(&%A;FUE;&1I;F<Z("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B3&%A='-T92!A86YM96QD:6YG
M.B`E<R!V86X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*
M;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(DQA871S=&4@86%N
M;65L9&EN9SH@3F]O:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8*;7-G:60@(DQA='9I82(*
M;7-G<W1R("),971L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T
M"FUS9VED("),87<B"FUS9W-T<B`B4F5C:'1E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(D]P;6%A:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B3&%A="!L965G('9O;W(@9V5E;B!R86YD(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*;7-G:60@(DQE9G0B"FUS9W-T<B`B3&EN:W,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3`Q"FUS9VED("),969T(&AE861E<B(*;7-G
M<W1R("),:6YK<V4@:V]P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S`Y-PIM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B3&EN:W-E('=A87)D
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#,*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S
M;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I
M9"`B3&5V96PB"FUS9W-T<B`B3FEV96%U(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R"FUS9VED
M("),:6)E<FEA(@IM<V=S='(@(DQI8F5R:6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<*;7-G
M:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB:7-C:&4@
M07)A8FES8VAE($IA;6%H:7)I>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`*;7-G:60@(DQI
M96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H
M="!$<FEZ>FQE(@IM<V=S='(@(EIA8VAT(&)U:71J92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!2
M86EN(@IM<V=S='(@(DQI8VAT92!R96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A
M<FQY(@IM<V=S='(@(E9R;V5G(&QI8VAT92!R96=E;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`B3&EC:'1E(')E9V5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A
M:6X@4VAO=V5R(@IM<V=S='(@(DQI8VAT92!R96=E;F)U:2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H
M="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("),:6-H=&4@<F5G96X@;65T
M(&]N=V5E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DQI8VAT92!S;F5E
M=7<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3&EC:'1E('-N
M965U=V)U:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B
M3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I8VLB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(DQI;FLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("),:6YK('=I
M:G-T(&YA87(Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM
M<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("),:6YK(&AE="!E+6UA:6QA
M9')E<R!A86X@9&4@;FEE=7<@8F5R:6-H="!P86=I;F$@=&EJ9&5N<R!W965R
M9V%V92(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T
M97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI;FMS(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B
M"FUS9W-T<B`B3&EN=7@@0V]O:VEE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<B(*;7-G<W1R("),:6IS="`M(&=E8G)U:6ME<B!K86X@9&4@
M;6%P('II96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),
M:7-T($1A=&%B87-E<R(*;7-G<W1R(")$871A8F%S96QI:G-T(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I
M8W,B"FUS9W-T<B`B3&EJ<W0@=F%N(&AE;'`@;VYD97)D96QE;B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S
M='(@(E1A8F5L;&EJ<W0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI:G-T
M+4%R8VAI968B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI:G-T+4AE;'`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B
M3&ES="U)9"(*;7-G<W1R("),:6IS="U)9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(DQI:G-T+45I9V5N86%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:6IS
M="U0;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI:G-T+4EN<V-H
M<FEJ=F5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&EJ<W0M56ET
M<V-H<FEJ=F5N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF
M;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G
M<W1R(")7965R9V5V96X@=F%N('-E<W-I96QI:G-T(&ES(&UI<VQU:W0Z("5S
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G
M:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")7965R9V5V
M96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!M:7-L=6MT.B`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B5V5E<F=E=F5N('9A;B!G
M96)R=6EK97)S;&EJ<W0@:7,@=6ET9V5S8VAA:V5L9"XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B
M3&ET97)A='5U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-`IM<V=I9"`B3&ET:'5A;FEA(@IM
M<V=S='(@(DQI=&]U=V5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),
M861E;BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*
M;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("),;VMA;&4@=&EJ9#HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R("),86YD:6YS=&5L;&EN9R!E;B!T:6ID(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"FUS9VED("),;V-A=&EO;B(*;7-G
M<W1R("),;V-A=&EE(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.3`*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D%A
M;FUE;&1E;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM
M<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("),
M;V<@=F%N('9O;W)G86%N9&4@<WEN8R!S97-S:64B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@
M(D%F;65L9&5N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED
M("),;V=I;B(*;7-G<W1R(")!86YM96QD96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")!86YM
M96QD=&%K96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(D%A
M;FUE;&1I;F<@;6ES;'5K="!O;61A="!U=R!G96)R=6EK97)S;F%A;2!O9B!W
M86-H='=O;W)D(&]N:G5I<W0@:7,@(@HB:6YG979O97)D+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*
M;7-G<W1R(")!86YM96QD:6YG(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQA
M;F=E('1E:W-T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED
M("),;W9E(@IM<V=S='(@(DQI969D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B3&%A
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T
M<B`B1W)I96MS92!K;&5I;F4@;&5T=&5R<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO
M=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&%T:6IN<V4@:VQE:6YE(&QE
M='1E<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(DML96EN92!2;VUE:6YS92!G971A;&QE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U<F<B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G
M<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!B:6IL86=E(&)E=F%T=&4@9V5E
M;B!D871A+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M(")-4T<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3<*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA
M8V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34S"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%C961O;FGK+"!$
M92!V<F]E9V5R92!*;V5G;W-L879I<V-H92!297!U8FQI96L@=F%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34Q"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-C
M87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(DUA9VEE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C@S"FUS9VED(")-86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T
M<B`B36%I;&)E:&5E<F1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN
M+B(*;7-G<W1R(")-86%K(&QI;E]K+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W"FUS9VED
M(")-86QA>7-I82(*;7-G<W1R(")-86QE:7-IZR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-`IM
M<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L861I=F5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34T"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(*
M;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G
M<W1R("(B"B)"96AE97(@=7<@;&EJ<W0@;65T(&-A=&5G;W)I9>MN(&5N(&1E
M(&-O<G)E<W!O;F1E<F5N9&4@:VQE=7)E;BP@=V%A<FUE92`B"B)O;F1E<F1E
M;&5N('=O<F1E;B!G96QA8F5L9"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B36%P,C0@:V%A<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@
M(DUA<%%U97-T:V%A<G0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B2V]P<&5L
M:6YG96X@;W!G97-L86=E;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%A<G0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B36%R9V4B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`IM<V=I9"`B36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUA<FME97(@;65T($=E
M>FEE;B].:65T($=E>FEE;B!V;&%G9V5N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUA<FME
M97(@;65T(&%N9&5R92!V;&%G9V5N("AB+G8N($)E;&%N9W)I:FLO0F5A;G1W
M;V]R9"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3(*;7-G:60@(DUA<G-H86QL($ES;&%N9',B
M"FUS9W-T<B`B36%R8VAA;&P@96EL86YD96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D*;7-G
M:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L
M9',B"FUS9W-T<B`B3W9E<F5E;FMO;65N9&4@=F5L9&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38P"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)E=&%N:>LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C,*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:71I
M=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B
M36%X:6UA86P@=&]E9V5S=&%A;B!K<F5D:65T+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(DUA>&EM=6T@8F5R
M:6-H=&]N9&5R9&5L96X@;W9E<G-C:')E9&5N+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M"FUS9W-T<B`B36%X:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N
M(#(T('5U<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@
M(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DUA>&EM=6T@=&5M
M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`V('5U<CH@(@H*(SH@;&EB+V%P
M:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,B"FUS9W-T<B`B36%X:6UU;2!A86YT86P@<&]R=&%A;&)L;VMK96XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")-87AI;75M(&QE;F=T
M92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B365I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,PIM<V=I
M9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")'96YE97-K
M=6YD92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B3&5D96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE
M;G4@;6]D93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")#
M96QL96X@<V%M96YV;V5G96XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G
M<W1R(")"97)I8VAT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U
M;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E
M("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)"97)I8VAT(&UE="!S=6-C97,@
M9V5V97)I9FEE97)D+"!M86%R(&AE="!C97)T:69I8V%A="!V86X@9&4@;VYD
M97)G971E:V5N9&4@(@HB:V]N(&YI970@=V]R9&5N(&=E=F5R:69I965R9"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B0F5R:6-H
M="!V97)L;W!E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"FUS9VED(")-97-S86=E('1Y
M<&4B"FUS9W-T<B`B0F5R:6-H='1Y<&4B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B365T87(@5V5E
M<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DU%5$%2(&)L;VL@:7,@;FEE
M="!B97-C:&EK8F%A<BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM
M<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B(@HB345405(@8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R+B!$971A:6QS
M('II:FX@9V5L;V=D('9O;W(@9&4@<WES=&5E;6)E:&5E<F1E<BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"
M(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(DUE=&%R1$(@:7,@;FEE="!V
M97)B;VYD96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"FUS9VED(")-971H;V0B"FUS9W-T<B`B365T:&]D92(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+W-O87`N<&AP.C$Q-R!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C@Q"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@
M:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365T:&]D92!<(B5S7"(@:7,@;FEE
M="!G961E9FEN:65E<F0B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N
M($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DUE=&AO9&4@:7,@;FEE="!G
M961E9FEN:65E<F0N($%A;F=E<F]E<&5N(&UE=&AO9&4Z("5S(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C<*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-971R:7-C:"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-@IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE>&EC;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@U"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F
M(@IM<V=S='(@(DUI8W)O;F5S:>LL($9E9&5R86QE(%-T871E;B!V86XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#(*;7-G:60@(DUI9&1L92(*;7-G<W1R(")-:61D96XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4
M>7!E(@IM<V=S='(@(DUI;64@='EP92(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$W"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B36EN:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#(T('5U
M<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DUI;FEM=6T@=&5M<&5R871U
M=7(@=F%N(&1E(&%F9V5L;W!E;B`V('5U<CH@(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B36EN:6UU;2!W86-H
M='=O;W)D;&5E9G1I:F0@:7,@;F]G(&YI970@=F5R;&]P96XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED(")-
M:7)R;W(B"FUS9W-T<B`B36ER<F]R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(D%L;&5R:&%N
M9&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B3VYT8G)E:V5N9&4@4$5!4B!M;V1U;&4@2%144%]2
M97%U97-T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@
M(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"B)/;G1B<F5K96YD92!C;VYF:6=U<F%T:64N(%4@
M9&EE;G0@9&5Z92!N=2!T92!G96YE<F5R96XL('=A;FYE97(@=2!D97IE("(*
M(G1O97!A<W-I;F<@=VEL="!G96)R=6EK96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(D]N=&)R96ME;F0@8F5R:6-H="!)
M1"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B3VYT8G)E:V5N9&4L('9E<F5I<W1E+"!014%2
M(&UO9'5L92!-86EL+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$
M+B(*;7-G<W1R(")/;G1B<F5K96YD('-E<W-I92!)1"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*
M;7-G<W1R(")-82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM
M<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B36]B:65L92!E+6UA:6PB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I
M9"`B36]D97)A=&4B"FUS9W-T<B`B1V5M:61D96QD(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S,*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T
M<B`B5VEJ>FEG:6YG<V1A='5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),
M(@IM<V=S='(@(E=I:GII9R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U
M;'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34P"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O
M9B(*;7-G<W1R(")-;VQD879IZRP@4F5P=6)L:65K('9A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T.0IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L:>LB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@T"FUS9VED(")-;VYT:"!A;F0@
M>65A<B(*;7-G<W1R(")-86%N9"!E;B!J86%R(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R(")-86%N9&5L:6IK<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,0IM<V=I9"`B36]N
M='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H
M87-E<R(*;7-G<W1R(")-86%N9F%S96XB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI
M;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(DUE97(@=F5L
M9&5N(&EN(')E9V5L("5D(&=E=F]N9&5N+"!D86X@9&4@=F5R=V%C:'1T92`E
M9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#@*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R
M;VMK;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B5F]O<FYA;65L:6IK
M(&]N8F5W;VQK="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(E9O;W)N
M86UE;&EJ:R!B97=O;&MT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y
M(@IM<V=S='(@(E9O;W)N86UE;&EJ:R!B97=O;&MT(&5N('=I;F1E<FEG(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G
M:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")6;V]R;F%M96QI:FL@>F]N;FEG
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(").86%R(&)E;F5D96XB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8U,@IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(DYA87(@;&EN:W,B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U
M-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(").86%R(')E8VAT<R(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T
M"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(DYA87(@8F]V96XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-
M;W9E(&1O=VXB"FUS9W-T<B`B3F%A<B!B96YE9&5N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(DYA87(@8F]V96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@*;7-G:60@(DUO
M>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:7%U92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<R(*;7-G<W1R(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&EJ<W1E
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM87`@
M5DL@:V%A<G0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS
M9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B365E<G9O=61I9V4@
M<V5L96-T:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS
M9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUI:FX@86-C;W5N="(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O
M<FUA=&EO;B(*;7-G<W1R(")5=R!A8V-O=6YT:6YF;W)M871I92(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#0*;7-G:60@(DUY(%!O<G1A;"(*
M;7-G<W1R(")-:6IN('!O<G1A86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z-#(*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B36EJ
M;B!P;W)T86%L;&%Y;W5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U"FUS9VED(")->6%N;6%R
M(@IM<V=S='(@(D)I<FUA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*
M;7-G<W1R(").964L(&EK(&%C8V5P=&5E<B!D92!V;V]R=V%A<F1E;B!.2454
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B
M"FUS9W-T<B`B3F%A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*
M;7-G<W1R(").86UI8FGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X"FUS9VED(").875R=2(*
M;7-G<W1R(").875R=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P86PB"FUS
M9W-T<B`B3F5P86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S
M(@IM<V=S='(@(DYE9&5R;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").961E<FQA;F1S($%N=&EL;&5N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G
M:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(DYE='-C87!E($)A<VES
M(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T
M"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").
M971S8V%P92!#02!I;G1R96MK:6YG(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI
M8WD@55),(@IM<V=S='(@(DYE='-C87!E($-!(&)E;&5I9"!54DPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T<V-A<&4@=F5R;FEE=7=I
M;F<@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE
M='-C87!E(&EN=')E:VMI;F<@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@
M;F%M92(*;7-G<W1R(").971S8V%P92!34TP@<V5R=F5R;F%A;2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E(&-E
M<G1I9FEC86%T8V]M;65N=&%A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T
M>7!E(@IM<V=S='(@(DYE='-C87!E(&-E<G1I9FEC86%T='EP92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS
M9W-T<B`B3F5T=V5R:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYO;VET
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<P"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@
M(DYI975W($-A;&5D;VYIZR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS
M9W-T<B`B3FEE=7=E(&-A=&5G;W)I92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3FEE=7=E(&UA86XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").
M97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(").:65U=V4@9V5B<G5I
M:V5R<VYA86T@*&]P=&EO;F5E;"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`*;7-G:60@(DYE
M=R!:96%L86YD(@IM<V=S='(@(DYI975W(%IE96QA;F0B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*
M;7-G<W1R(").:65U=R!W86-H='=O;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(DYI975W('=A8VAT
M=V]O<F0@>F%L('9E<FQO<&5N(&]P("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`B3FEE=7=E(%=A8VAT=V]O<F1E;B!K;VUE;B!N:65T
M(&]V97)E96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R
M(").:65U=R!S8VAE<FT@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3(@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").:65U
M=W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(DYI975W<V=R;V5P96XB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR-2!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.0HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,2!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-0IM<V=I9"`B3F5X="(*;7-G<W1R
M(")6;VQG96YD92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B
M3F5X="`T(%!H87-E<R(*;7-G<W1R(")6;VQG96YD92`T(&9A<V5N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G
M<W1R(")6;VQG96YD92!O<'1I97,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B5F]L9V5N9&4^(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<T"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A
M9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<Q"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,PIM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E
M<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I
M9"`B3FEG:'0B"FUS9W-T<B`B3F%C:'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD*;7-G:60@
M(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(DYE92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B
M3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E
M<F5N8V5S(&9O<BXB"FUS9W-T<B`B1V5E;B!B97-C:&EK8F%R92!C;VYF:6=U
M<F%T:65D871A(&]M('9E<G-C:&EL;&5N('1E(&QA=&5N('II96XN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G
M:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G
M97,N(@IM<V=S='(@(D=E96X@8F5S8VAI:V)A<F4@<W1R871E9VEE('9O;W(@
M:&5T(&UA:V5N('9A;B!)4T\@:6UA9V5S+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T
M8V@@=&5M<&QA=&4N(@IM<V=S='(@(D=E96X@8F%T8VAS:F%B;&]O;BXB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`B17(@8F5S=&%A="!G965N(&)L;VL@;W`@
M9&4@9V5V<F%A9V1E('!O<VET:64B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D
M(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")'965N(&%G96YD
M86YA86T@;W!G96=E=F5N('9O;W(@34-!3"!A=71H96YT:6-A=&EE+B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(D=E96X@=VEJ>FEG:6YG96XN(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(D%A;B!D:70@<F5C
M:'0@:W5N;F5N(&=E96X@8VAI;&0@<F5C:'1E;B!W;W)D96X@=&]E9V5V;V5G
M9"XB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-C@@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")'965N
M(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O;W(@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R(")'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E
M=F5N('9O;W(@1E10(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(D=E96X@8V]N9FEG=7)A
M=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!344P@5D93+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL
M92!61E,N(@IM<V=S='(@(D=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O
M<&=E9V5V96X@=F]O<B!344PM8F5S=&%N9"!61E,N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").
M;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B1V5E;B!K<F5D:65T(&UE97(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(")'
M965N(&)E<W1E;6UI;F<@;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.CDR,`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*
M;7-G<W1R(")'965N(&)E<W1A;F0@=7!L;V%D960B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R
M(")'965N('!I8W1O9W)A;6UE;B!G979O;F1E;BXB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$S,"!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I
M;VX@:7,@<V5T+B(*;7-G<W1R(")%<B!I<R!G965N(&QO8V%T:64@:6YG97-T
M96QD+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")'965N(&QO8V%T
M:64@;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R(")'965N(&)E<FEC:'0@9V5L979E<F0N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@
M(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(")'965N(&YA86T@;W!G96=E
M=F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M(")'965N(&=E=&%L(&]P9V5G979E;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M(")'965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D=E96X@=V%C
M:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!(5%10(&%U=&AE;G1I8V%T:64N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@24U!4"!A
M=71H96YT:6-A=&EE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!W86-H='=O;W)D(&]P
M9V5G979E;B!V86X@2V5R8F5R;W,@875T:&5N=&EC871I92XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-"!F<F%M97=O<FLO075T:"]!
M=71H+W!A;2YP:'`Z-S4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HW-PIM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")'965N('=A8VAT=V]O<F0@;W!G96=E
M=F5N('9O;W(@3&]G:6X@875T:&5N=&EC871I92XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")'
M965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:64N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@
M4TU"(&%U=&AE;G1I8V%T:64N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R
M("(B"B)'965N('!A9"!N86%R(&1E($]P96Y34TP@8FEN87)Y(&]P9V5G979E
M;BX@1&4@3W!E;E-33"!B:6YA<GD@:7,@;F]D:6<@;VT@=&4@(@HB:W5N;F5N
M('=E<FME;B!M970@4$M#4R`Q,B!D871A+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P
M<RXB"FUS9W-T<B`B1V5E;B!H86YG96YD92!I;G-C:')I:G9I;F=E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S
M970N(@IM<V=S='(@(D=E96X@<75O=&$@:6YG97-T96QD+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G
M:60@(DYO(')U;&5S(@IM<V=S='(@(D=E96X@;&EN:>MR:6YG(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T
M;W(@<W!E8VEF:65D+B(*;7-G<W1R(")'965N('-C:&5I9&EN9W-T96ME;B!O
M<&=E9V5V96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B1V5E
M;B!Z:6ID96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-PIM
M<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(D=E96X@9&5R9V5L:6IK(&)E
M<W1A;F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS
M9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N(@IM<V=S='(@(D=E96X@=&EJ9&5L:6IK(&1I<F5C=&]R>2!B97-C:&EK
M8F%A<B!V;V]R(&-A8VAE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B1V5E;B!G96)R=6EK97)S;F%A;2!E
M;B]O9B!W86-H='=O;W)D('9E<GIO;F1E;BXB"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960B"FUS9W-T<B`B1V5E;B!G96QD:6=E(%A-3"!D871A('1E<G5G
M9V5S='5U<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(D=E96X@=V%A<F1E
M;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)'965N('9E<G-I92!G
M979O;F1E;B!I;B!O<FEG:6YE;&4@8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E
M<B!C;VYF:6=U<F%T:64N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1V5E;B!V
M97)S:64@9V5V;VYD96X@:6X@=7<@8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E
M<B!C;VYF:6=U<F%T:64N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(W('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-0IM<V=I9"`B3F]N92(*;7-G<W1R(")'965N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N
M92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")'965N("AV97)P;&EC:'0I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/
M+3@X-3DM,3`I(@IM<V=S='(@(DYO;W)D($5U<F]P965S("A)4T\M.#@U.2TQ
M,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S(*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S
M='(@(DYO<F9O;&L@96EL86YD(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R(").;V]R9&5L:6IK(&AA;&9R;VYD(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34X"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B
M36%R:6%N96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8*;7-G:60@(DYO<G=A>2(*;7-G<W1R
M(").;V]R=V5G96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYI970@;F$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B
M3F]T($)E9F]R92(*;7-G<W1R(").:65T('9O;W(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,34*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*
M;7-G<W1R(")'965N(&1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.CDU"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DYI970@9V5I
M;7!L96UE;G1E97)D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3FEE="!I
M;F=E<W1E;&0B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-CD@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X-0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`Q(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,38*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,S,R!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S8V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C8@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P-0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3<T(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.3$*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C8V.2!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S
M-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3FEE="!O;F1E<G-T
M975N9"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C0T(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`X"B,Z(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#4X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&ET:65S(@H*(SH@<V5R
M=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O
M(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3FEE=',@=&4@8FQA9&5R96XL
M(&=A('1E<G5G+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E
M<B(*;7-G<W1R(")'971A;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(D%A
M;G1A;"!K87)A:W1E<G,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS
M9W-T<B`B06%N=&%L(&MO;&]M;65N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S
M(@IM<V=S='(@(D%A;G1A;"!R:6IE;B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R(")'971A;&QE;B!N:65T(&]P9V5G979E;B!V;V]R(&)I:G=E
M<FME;B!I;B!E96X@9&ES=')I8G5T:65L:6IS="XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S
M='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5C="(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R(")/8FIE8W1E:6=E;F%A<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]C=&%A
M;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]K=&]B97(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S
M='(@(D)E;&5D:6=I;F=F:6QT97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2V%N=&]O<B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")/
M=61E(&5N(&YI975W92!W86-H='=O;W)D96X@9&EE;F5N('9E<G-C:&EL;&5N
M9"!T92!Z:6IN+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(D]U9&4@=V%C:'1W;V]R
M9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B
M3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")/=61E('=A
M8VAT=V]O<F0@:7,@;FEE="!J=6ES="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,0IM<V=I9"`B
M3VUA;B(*;7-G<W1R(")/;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(D%L;&5E;B!)34%0('-E
M<G9E<G,@;VYD97)S=&5U;F5N(&=E9&5E;&1E(&UA<'!E;BXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(D%L;&5E;B!B96QE9&EG96YD92!F;W)T=6YE<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R(")3;&5C:'0@Z>EN(&4M;6%I;&%D<F5S('1O
M96=E<W1A86XN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS
M9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N
M<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)!;&QE96X@9&4@96EG96YA87(@
M;V8@965N('-Y<W1E96UB96AE97)D97(@;6%G(&1E(&5I9V5N86%R<F5C:'1E
M;B!V86X@965N("(*(G-H87)E('=I:GII9V5N(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-#$@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P
M96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]P96X@:6X@965N(&YI975W
M('-C:&5R;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D
M871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N
M4U-,(&9O=70Z(&MO;B!G965N(&1A=&$@=6ET(&AE="!O;F1E<G1E:V5N9&4@
M4R]-24U%(&]N9&5R9&5E;"!H86QE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W!E;G0@9&5Z
M92!L:6YK(&EN(&5E;B!N:65U=R!S8VAE<FTB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B
M0F5S='5R:6YG<W-Y=&5E;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!T:65S(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S
M='(@(D]P=&EE<R!V;V]R("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S
M='(@(D=E;W)D96YD92!L:6IS="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B
M3W)G86YI<W1A=&EE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
M3W)G86YI<V%T:64@965N:&5I9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI<V5R
M96XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B3W)I9VEN965L('1O
M97!A<W-I;F=S<VIA8FQO;VXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(@IM<V=S='(@(D]R:6=I;F5L92!S:F%B;&]N96X@:6X@)7,Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%N9&5R92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(D%N9&5R92!I;F9O<FUA=&EE(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B16EG96YA87)R96-H=&5N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-(&%U=&AE;G1I8V%T:64@
M:7,@;FEE="!B97-C:&EK8F%A<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C
M:V5N9"(*;7-G<W1R(")014%2.CI-86EL(&)A8VME;F0B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A
M;"!3:6=N871U<F4B"FUS9W-T<B`B1&EG:71A;&4@4$=0(&AA;F1T96ME;FEN
M9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")'96-O9&5E<F1E(%!'
M4"!D871A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B3W!E;F)A<F4@4$=0
M('-L975T96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(D]N9&5R=&5K96YD92]G96-O9&5E<F1E(%!'4"!D871A(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C8Y"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")02%`@
M8V]D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H
M96QL(@IM<V=S='(@(E!(4"!S:&5L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!,:6=H="!286EN(@IM
M<V=S='(@(DQI8VAT92!R96=E;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I
M;B(*;7-G<W1R(")296=E;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VAO=V5R
M<R(*;7-G<W1R(")"=6EE;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*
M;7-G<W1R(")3;F5E=7<@;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")3;F5E=7=B=6EE;B!N82`Q,BXP,"!U=7(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B
M4$T@4W5N(@IM<V=S='(@(EIO;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B3VYW965R<V)U:65N(&YA(#$R+C`P('5U<B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8(&5X=&5N
M<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8(&5X=&5N<VEE(&]N=&)R
M965K="(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*
M;7-G<W1R(")02%`@7U-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G
M<W1R(")6<FEJ92!R=6EM=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-`IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR"FUS9VED(")0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S
M=&EJ;G,@5&5R<FET;W)I=6TL($)E>F5T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED
M(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U"FUS9VED
M(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YI975W($=U:6YE
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.34*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A
M<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B1V5D965L=&5L
M:6IK(&)E=V]L:W0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")786-H='=O
M;W)D(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED
M(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5V%C
M:'1W;V]R9"!M970@<W5C8V5S(&=E=VEJ>FEG9"XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN
M8V]R<F5C="(*;7-G<W1R(")786-H='=O;W)D(&]N:G5I<W0B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R
M9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")786-H='=O;W)D(&ES('9E<F5I<W0@=F]O<B!2041)55,@875T:&5N=&EC
M871I92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED
M(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")786-H='=O
M;W)D(&UE="!B979E<W1I9VEN9R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E=A8VAT=V]O
M<F0Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@
M(E!A<W-W;W)D.B`B"FUS9W-T<B`B5V%C:'1W;V]R9#H@(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(E=A8VAT=V]O<F1E;B!M;V5T
M96X@;W9E<F5E;FMO;65N+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(R"FUS9VED(")087-T92(*;7-G<W1R(")0;&%K:V5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S
M=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B4&QA:VME;B!V86YA9B!P<FEK
M8F]R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B4&%D(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B2&%N9V5N9&4@:6YS8VAR:6IV:6YG96XZ(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B365N
M<V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4')O8V5N="(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED
M(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B3VYD
M97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET=F]E<F5N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")/;F1E<FAO=61S=V5R:WIA
M86UH961E;B!U:71V;V5R96X@8FEJ(&%A;FUE;&1I;F<_(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB
M"FUS9W-T<B`B4F5C:'0B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D
M96QE=&5D+B(*;7-G<W1R(")296-H="!<(B5S7"(@;FEE="!V97)W:6ID97)D
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")0
M97)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")296-H="!G97=E:6=E<F0B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4F5C:'1E;B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV
M,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P.2!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(*;7-G:60@(E!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E)E8VAT96YB96AE
M97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(E!E<G-O;VYL:6IK92!I;F9O<FUA
M=&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@S"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS
M9W-T<B`B2'5I<V1I97)E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-@IM<V=I9"`B4&AI;&EP
M<&EN97,B"FUS9W-T<B`B4&AI;&EP<&EJ;F5N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS
M9W-T<B`B5&5L969O;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;R=S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I
M9"`B4&EX96QS(@IM<V=S='(@(E!I>&5L<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")0;&%T:71U
M9&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M(@IM<V=S='(@(DML:6L@:6X@965N(&-E;"P@82YU+F(N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z(@IM<V=S='(@(D)E=F5S=&EG+"!D870@=2!D:70@96QE
M;65N="!W:6QT('9E<G=I:F1E<F5N+"!A+G4N8CHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@
M(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="XB"FUS9W-T<B`B0F5V97-T:6<L(&1A="!U(&1I="!E;&5M96YT
M('=I;'0@;&]S:V]P<&5L96XL(&$N=2YB+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U-C(*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N(@IM<V=S='(@(D=E968@965N(&UA86YD(&5N(&5E;B!J86%R
M+"!A+G4N8BXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B165N(&YA86T@=F]O<B!D92!N:65U
M=V4@8V%T96=O<FEE(&EN=F]E<F5N+"!A+G4N8BXZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RXB"FUS9W-T<B`B1V5E9B!E96X@9V5L9&EG($E0(&%D
M<F5S+"!A+G4N8BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0P
M"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@
M;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"B)'965F
M(&5E;B!G96QD:6=E(&1A='5M(&$N=2YB+BP@8V]N=')O;&5E<B!H970@86%N
M=&%L(&1A9V5N(&EN(&1E(&UA86YD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N
M(@IM<V=S='(@(D=E968@965N(&=E;&1I9V4@=&EJ9"P@82YU+F(N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")'
M965F(&5E;B!S86UE;G9A='1I;F<@=F%N(&AE="!P<F]B;&5E;2P@82YU+F(N
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")'965F('5W(&=E8G)U
M:6ME<G-N86%M(&5N('=A8VAT=V]O<F0L(&$N=2YB+B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE
M(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3&5E<R!D92!V
M;VQG96YD92!T96MS="P@82YU+F(N(%4@34]%5"!D92!V;V]R=V%A<F1E;B!T
M92!A8V-E<'1E<F5N(&]M(&AE="`B"B)S>7-T965M('1E(&MU;FYE;B!G96)R
M=6EK96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93HB"FUS9W-T<B`B1V5E9B!D92!N:65U=V4@8V%T96=O<FEE;F%A
M;2P@82YU+F(N.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S
M='(@(E!O;&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED
M(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EE:R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(E!E:6QI
M;F=E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3,*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@
M(E!O<G1U9V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E(@IM<V=S='(@(E!O<VET:6]N97)I;F<@=F%N(&1E>F4@869B
M965L9&EN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM
M<V=S='(@(E!O<VET:6]N97)I;F<@=F%N(&1E>F4@=&%B96PB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0IM<V=I9"`B4&]S="!T
M;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@
M(E-T=75R(&YA87(@9&5Z92!M87`@*&YI970@869G961W;VYG96X@9&]O<B!)
M34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I
M;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(DYE97)S;&%G('9A
M;B!D92!A9F=E;&]P96X@)7,@=7)E;CH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC92(*;7-G<W1R(").965R<VQA9SQB<B`O/FMA;G,B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M4')E9G-?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS
M,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!V97)E
M:7-T92!S97-S:64@97AT96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B
M3'5C:'1D<G5K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@
M(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(DQU8VAT9')U:R!O
M<"!Z965N:79E874Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B3'5C:'1D<G5K.B`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,`IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")"96]O<F1E;&5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(Q"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B0F5O;W)D965L(&1E(&%F8F5E;&1I;F<@:6X@
M965N(&YI975W('-C:&5R;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S4V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS
M9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(E9O<FEG92!O<'1I97,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q
M"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")$;V-U;65N="!A9F1R
M=6MK96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*
M;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E!R:79E('-L975T96PB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0
M<F]B;&5M(@IM<V=S='(@(E!R;V)L965M(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@
M(E!R;V)L965M8F5S8VAR:6IV:6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5C=&5N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-S8*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E!R;VUP="!T96MS
M="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4'5B;&EC($ME>2(*;7-G<W1R(")/<&5N8F%R92!S;&5U=&5L(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U
M8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D]P96YB87)E('-L975T96P@
M86QG;W)I=&AM92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B3W!E;F)A
M<F4@<VQE=71E;&EN9F]R;6%T:64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D]P96YB86%R
M+U!R:79E('-L975T96QP86%R(&YI970@9V5G96YE<F5E<F0N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,0IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I
M8V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5VES(&)E<FEC:'1E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.38*;7-G:60@(E%A=&%R(@IM<V=S='(@(E%U871A
M<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM<V=I9"`B475E<GDB"FUS
M9W-T<B`B475E<GDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*;7-G
M:60@(E%U;W1A(@IM<V=S='(@(E%U;W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!
M(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!(&]P96YB87)E('-L
M975T96P@*"5D(&)I="DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B2V5U>F5R;VYD
M:F4@<V5L96-T:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B(*;7-G<W1R(")296=E;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")2
M86EN($5A<FQY(@IM<V=S='(@(E9R;V5G(')E9V5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T
M92(*;7-G<W1R("),86%T(')E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S
M='(@(E)E9V5N8G5I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4F5G
M96X@96X@<VYE975W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")296=E
M;B!N86%R('-N965U=R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS
M9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")286YD;VT@1F]R='5N92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T
M:6\B"FUS9W-T<B`B5F5R:&]U9&EN9R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQE>F5N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*;7-G
M:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3&5E<R!B97)I8VAT96XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B)7,@96-H="!V97)W:6ID97)E
M;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@;VYG961A86X@9V5M86%K="!W
M;W)D96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*(D=E8G)U:6ME<G-D871A('9A;B!G96)R=6EK97(@)7,@
M96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@(@HB
M;VYG961A86X@9V5M86%K="!W;W)D96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VXB"FUS9W-T<B`B2&5R:&%A;'0@=7<@=F]R:6=E(&)E=V5R
M:VEN9R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(E9E<G9E
M<G-E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")697)V97)S
M(&1Y;F%M:7-C:&4@;65N=2!O;F1E<F1E;&5N.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(E!O<G1A;'=E97)G879E('9E<G9E<G-E;CHB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")2
M96=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R,S$*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@
M(D)E=')E:VMI;F=E;B!B<F]W<V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM
M<V=I9"`B4F5L;V%D(@IM<V=S='(@(DAE<FQA9&5N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B3W!M97)K
M:6YG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")2
M96UO=&4@4V5R=F5R<R(*;7-G<W1R(")397)V97)S(&]P(&%F<W1A;F0B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M(")54DP@;W`@869S=&%N9"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,R!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R"FUS9VED(")296UO
M=F4B"FUS9W-T<B`B5F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")"
M;&]K('9E<G=I:F1E<F5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M(")+;VQO;2!V97)W:6ID97)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG
M(@IM<V=S='(@(D]P;6%A:R!V97)W:6ID97)E;B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R
M(")086%R('9E<G=I:F1E<F5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*(E9E<G=I:F1E<B!H
M970@;W!G97-L86=E;B!S8W)I<'0@=6ET(&1E('1I:F1E;&EJ:V4@9&ER96-T
M;W)Y(&]P(&1E('-E<G9E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B
M"FUS9W-T<B`B5F5R=VEJ9&5R(&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E9E<G=I:F1E
M<B!D97IE(&YO9&4@=6ET(&AE="!D;V-U;65N="(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(D=E8G)U:6ME<B!V97)W:6ID97)E;B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B5F5R=VEJ9&5R(&=E8G)U:6ME<CH@
M)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I
M9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R
M;W)C;V1E.B`B"FUS9W-T<B`B5F5R>F]E:R!K;VX@;FEE="!W;W)D96X@8F5A
M;G1W;V]R9"X@1V5R971O=7)N965R9&4@9F]U=&-O9&4Z("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S
M97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B1&4@9V5V<F%A
M9V1E('-E<G9I8V4@:V]N(&YI970@=V]R9&5N(&=E=F]N9&5N+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(E9E<F5I<W1E(%PB)7-<(B!N:65T(&]P9V5G979E;B!I;B`E<R!C;VYF
M:6=U<F%T:64N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5F5R96ES=&4@7"(E<UPB(&YI970@;W!G96=E=F5N
M(&EN(%9&4R!C;VYF:6=U<F%T:64N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9E
M<F5I<W1E(%PB)7-<(B!N:65T(&]P9V5G979E;B!I;B!C;VYF:6=U<F%T:64N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,V"FUS
M9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")697)E:7-T('9E;&0B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C$*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")(97)S
M=&5L;&5N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G
M:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E)E<V5T('=A8VAT=V]O<F0B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S
M970@66]U<B!087-S=V]R9"(*;7-G<W1R(")297-E="!U=R!W86-H='=O;W)D
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,
M87-T(%%U97)Y(@IM<V=S='(@(E9O;W)G86%N9&4@<75E<GD@:&5R<W1E;&QE
M;B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S(@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM
M<V=S='(@(E)E<W5L=&%T96XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E
M='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1E<G5G(&YA87(@;W!T:65S(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y
M<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E1Y<"!N:65U=R!W86-H='=O;W)D
M(&]P;FEE=7<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(D-O;F9I9W5R871I92!T97)U9WIE='1E;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")2:6-H(%1E>'0@161I=&]R(&]P=&EE
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE
M<R(*;7-G<W1R(")286%D<V5L<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`IM<V=I9"`B4FEG:'0B"FUS9W-T
M<B`B4F5C:'1S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,PIM
M<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(E)E8VAT<V4@:V]P(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B4FEG:'0@=F%L
M=65S(@IM<V=S='(@(E)E8VAT<V4@=V%A<F1E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B
M4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E)I7VIE:6=E;G-C:&%P<&5N
M+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VPB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX
M"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)O96UE;FGK(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R("(Q.#`@9')A86EE;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,
M969T(@IM<V=S='(@(DYA87(@;&EN:W,@9')A86EE;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R(").86%R(')E8VAT<R!D<F%A:65N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM
M<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B4FEJ(&5I9V5N<V-H87!P
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")2:6H@
M96EG96YS8VAA<'!E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")2:6IE;CHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("),:6YIZW)I;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS(@IM<V=S='(@(DQI;FGK<FEN9R!Z86P@=F5R<V-H:6IN96X@
M='5S<V5N(&%L;&4@<FEJ96X@96X@:V]L;VUM96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R
M("),:6YIZW)I;F<@>F%L(&%L;&5E;B!T=7-S96X@:V]L;VUM96X@=F5R<V-H
M:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R("),:6YIZW)I;F<@>F%L(&%L;&5E;B!T=7-S
M96X@<FEJ96X@=F5R<V-H:6IN96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Q"FUS9VED(")2=6XB"FUS9W-T<B`B4W1A<G1E;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3D*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-S:7-C
M:&4@1F5D97)A=&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,`IM<V=I9"`B4G=A;F1A(@IM
M<V=S='(@(E)W86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4B"FUS9W-T<B`B0W)Y<'1O9W)A9FES8VAE(%,O34E-12!H86YD=&5K96YI
M;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM
M<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-
M12!G96-O9&5E<F0@8F5R:6-H="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"!A=71H96YT:6-A=&EE(&ES(&YI
M970@8F5S8VAI:V)A87(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")335,@=F5R<W1U
M<F5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE
M;&PB"FUS9W-T<B`B4U%,('-H96QL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(W-`IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<R(*;7-G<W1R(")344P@<W1A=&5M96YT('9O;W(@=V%A<F1E>F]E:V]P
M9')A8VAT96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS
M9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I
M9"`B4U5#0T534R(*;7-G<W1R(")354-#15,B"@HC.B!L:6(O87!I+G!H<#HQ
M-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]13"!S:&5L;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G
M:60@(E-A(@IM<V=S='(@(EIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-PIM<V=I9"`B4V%I
M;G0@2&5L96YA(@IM<V=S='(@(E-T($AE;&5N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,0IM
M<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-T($MI='1S
M(&5N($YE=FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y"FUS9VED(")386EN="!,=6-I82(*
M;7-G<W1R(")3="!,=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4W0@4&EE<G)E(&5N($UI
M<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-`IM<V=I9"`B4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4W0@5FEN8V5N="!E;B!D92!'
M<F5N861I;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@
M(EIE;&9D92!F<F%M92`H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,0IM<V=I9"`B
M4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R"FUS9VED(")3
M86X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V
M"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O
M;64@96X@4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T
M96QL:65T<')O=FED97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D:2!!
M<F%B:6$B"FUS9W-T<B`B4V%U9&D@07)A8FGK(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(D]P<VQA
M86XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(EPB)7-<
M(B!O<'-L86%N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(E<R!O<'-L
M86%N(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V
M92!/<'1I;VYS(@IM<V=S='(@(D]P=&EE<R!O<'-L86%N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)'96=E;F5R
M965R9&4@8V]N9FEG=7)A=&EE(&%L<R!02%`@<V-R:7!T(&]P9V5S;&%G96X@
M:6X@9&4@=&EJ9&5L:6IK92`B"B)D:7)E8W1O<GD@=F%N('5W('-E<G9E<BXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!C
M;VYF:6=U<F%T:64@;W!G97-L86=E;B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(E-E='5P('5P9W)A
M9&4@<V-R:7!T(&]P9V5S;&%G96X@;F%A<CH@7"(E<UPB+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")38V%T
M=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B1V5S<')E:61E(&]N=V5E<G-B=6EE
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC
M92(*;7-G<W1R(")7971E;G-C:&%P(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("):;V5K96XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*
M;7-G<W1R("):;V5K;6%C:&EN97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.34U"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B2VEE<R!B
M97-T86YD96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C
M=&5E<B!E96X@9&%T=6TB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E-E
M;&5C=&5E<B!E96X@9W)O97`@;VT@=&]E('1E('9O96=E;B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O
M=VYE<B(*;7-G<W1R(")396QE8W1E97(@965N(&YI975W92!E:6=E;F%A<B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L
M96-T(&$@<V5R=F5R(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@<V5R=F5R(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C
M="!A('5S97(@=&\@861D(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@9V5B<G5I
M:V5R(&]M('1O92!T92!V;V5G96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S
M='(@(D%L;&5S('-E;&5C=&5R96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C0S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB
M"FUS9W-T<B`B4V5L96-T965R(&%L;&4@9&%T=6UC;VUP;VYE;G1E;BXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS
M9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E-E;&5C=&5E<B!E96X@
M;V)J96-T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B3FEE=',@<V5L
M96-T97)E;B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B
M(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O
M>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE
M;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E-E;&5C=&5E<B!D
M92!B96YO9&EG9&4@:V%R86MT97)S('5I="!D92!O;F1E<G-T86%N9&4@=F%K
M:F5S+B!5(&MU;G0@9&5Z92!D86X@(@HB:V]P:>MR96X@96X@<&QA:VME;B!I
M;B!H970@=&5K<W1G96)I960N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S
M='(@(E-E;&5C=&5E<B!H970@9&%T=6US8VAE:61I;F=S=&5K96XZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!F;W)M870Z(@IM<V=S='(@(E-E;&5C=&5E<B!H970@9&%T=6UF;W)M
M86%T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.B(*;7-G<W1R(")396QE8W1E97(@9&4@:61E;G1I=&5I="!D:64@=2!W
M:6QT('=I:GII9V5N.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V
M"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")3
M96QE8W1E97(@:&5T('1I:F1S8VAE:61I;F=S=&5K96XZ(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F
M;W)M870Z(@IM<V=S='(@(E-E;&5C=&5E<B!H970@=&EJ9'-F;W)M86%T.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")396QE8W1E97(@='=E
M92!O=F5R965N:V]M96YD92!V96QD96XN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*
M;7-G<W1R(")396QE8W1E97(@=7<@:VQE=7)S8VAE;6$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R(")396QE8W1E97(@=7<@9V5W96YS=&4@
M=&%A;#HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM
M<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5E;7)A
M<'!O<G0@=F5R>F5N9&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E9E
M<GIE;F0@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G
M<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E
M<B(*;7-G<W1R(")397!T96UB97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(E-E<G9IZR!E;B!-;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB
M97(B"FUS9W-T<B`B4V5R:65N=6UM97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")397)V97)D871A(&9O=70@;V8@;FEE
M="!B97-C:&EK8F%A<BXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G
M:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B4V5S<VEE8F5H965R9&5R(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(E-E<W-I
M92!)1"!V97)L;W!E;BXB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E
M<W-I;VYS(@IM<V=S='(@(E-E<W-I97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B26YS=&5L;&5N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(DEN<W1E;&QE;B!V86X@;W!T
M:65S(&]M('4@=&]E('1E('-T86%N('5W('=A8VAT=V]O<F0@=&4@<F5S971T
M96XL('=A;FYE97(@=2`B"B)D:70@8F5N="!V97)G971E;BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"XB"FUS9W-T<B`B(@HB26YS=&5L;&5N('9A;B!S97)V97)S(&]P(&%F<W1A
M;F0@9&EE('4@=VEL="!B96YA9&5R96X@=F%N=6ET('5W('!O<G1A;"XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB
M"FUS9W-T<B`B26YS=&5L;&5N('9A;B!U=R!G97=E;G-T92!T86%L+"!T:6ID
M>F]N92!E;B!D871U;6]P=&EE<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N
M+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*
M(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB26YS=&5L;&5N('9A;B!U
M=R!O<'-T87)T=&]E<&%S<VEN9RP@:VQE=7)S8VAE;6$L('!A9VEN879E<G9E
M<G-I;F<@96X@86YD97)E("(*(G=E97)G879E;W!T:65S+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(DEN
M<W1E;&QE;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM
M<V=S='(@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!B97-C:&EK8F%A<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R
M86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM
M<V=S='(@(E9E<G-C:&EL;&5N9&4@;&]C871I97,@;6]G96QI:FL@;65T(&1E
M('!A<F%M871E<CH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,PIM<V=I9"`B4V5Y8VAE;&QE
M<R(*;7-G<W1R(")397EC:&5L;&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B5VEN:V5L96XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B
M4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")+;W)T92!S86UE;G9A='1I;F<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C
M97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B
M1&EE;F5N('-N96QT;V5T<V5N('9O;W(@9&4@;65E<W1E(&QI;FMS(&=E9&5F
M:6YI965R9"!T92!W;W)D96X_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B5V5E<F=E=F5N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO
M=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE
M(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B)697)S8VAI;&QE;B!L871E;B!Z:65N('1U<W-E;B!D92!H=6ED:6=E(&]P
M9V5S;&%G96X@8V]N9FEG=7)A=&EE(&5N(&1E("(*(FYI975W92!G96=E;F5R
M965R9&4@8V]N9FEG=7)A=&EE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\B"FUS9W-T<B`B3&%A='-T92!A86YM96QD:6YG<W1I:F0@=V5E<F=E
M=F5N(&)I:B!A86YM96QD96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*
M;7-G<W1R(")/<'1I92!W965R9V5V96X@;VT@;W)I9VEN965L('1E(&)E=V%R
M96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDU"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R(")+:65Z97(@=V5E<F=E=F5N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R
M871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")486)E;&)E=V5R:VEN9W-T86%K
M8F%L:R!W965R9V5V96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H
M92!L969T/R(*;7-G<W1R("(E<R!M96YU(&%A;B!D92!L:6YK97)K86YT('=E
M97)G979E;C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%B96QC96QE:6=E;G-C:&%P
M<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%B
M96QE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(E1A8F5L<FEJ96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N
M<W1E<B!W965R9V5V96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D%F8F5E;&1I;F=S96EG96YS
M8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G
M<W1R(")5<&QO860@=V5E<F=E=F5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B
M0G5I96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")"=6EE;B!V<F]E
M9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T
M"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B0G5I96X@;&%A="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED
M(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")"=6EE;B!I;B!D
M92!N86)I:FAE:60B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(E9E<FML
M96EN96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E9E<FML96EN(&]F('9E<G!L86%T<R!N
M86)U<FEG92!B;&]K:V5N(&5E<G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B
M4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B
M"FUS9W-T<B`B26YT96ME;F5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")(86YD
M=&5K96YI;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")(86YD
M=&5K96YI;F<@86QG;W)I=&AM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8*;7-G:60@(E-I
M;F=A<&]R92(*;7-G<W1R(")3:6YG87!O<F4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3`U"FUS9VED(")3:7IE(@IM<V=S='(@(D=R;V]T=&4B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")/;F1E<FAO=60@
M;W9E<G-L86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,`IM<V=I9"`B4VQO=F%K:6$B"FUS
M9W-T<B`B4VQO=V%K:6IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.`IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B4VQO=F5N:>LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R(")3;F5E
M=7<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PIM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B4VYE975W=FQA86<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I
M9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N965U=V)U:65N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N
M;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")S;F5E=7=B=6EE;B!V<F]E9R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS
M9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")3;F5E=7=B=6EE;B!L
M86%T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@
M9&5P=&@Z("(*;7-G<W1R(")3;F5E=7=D:65P=&4Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z("(*;7-G<W1R(")3;F5E=7=E<75I=F%L96YT(&EN('=A=&5R.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`R"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B
M4V]L;VUO;B!E:6QA;F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30*;7-G:60@(E-O;6%L
M:6$B"FUS9W-T<B`B4V]M86QIZR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("),:65D97)E;B!E
M;B!G961I8VAT96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`X
M"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3;W)T965R
M=F]L9V]R9&4@<V5L96-T:64B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D
M<F5S<R(*;7-G<W1R(")"<F]N861R97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U"FUS9VED
M(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B6G5I9"!!9G)I:V$B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I(@IM<V=S='(@(EIU:60@175R;W!E97,@*$E33RTX.#4Y+3,I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`Q"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("):=6ED($=E;W)G:>L@
M96X@9&4@6G5I9"!386YD=VEC:"!E:6QA;F1E;B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B6G5I9&5L:6IK(&AA;&9R;VYD(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*
M;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B
M4W!A=&GK<FEN9R!T=7-S96X@86%N9W)E;GIE;F1E(&-E;&QE;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED
M(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM
M<V=S='(@(E-P871IZW)I;F<@='5S<V5N(&EN:&]U9"!E;B!R86YD(&EN(&-E
M;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A
M8V5R(@IM<V=S='(@(E-C:&5I9&EN9W-T96ME;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0IM<V=I9"`B4W!A
M8VEN9R(*;7-G<W1R(")3<&%T:>MR:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN
M9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")3<&%T:>MR:6YG(&5N('9R:6IE(')U
M:6UT92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@P"FUS9VED(")3<&%I;B(*;7-G<W1R(")3<&%N
M:F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3
M<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(E-P
M96-I86%L(&MA<F%K=&5R(&EN=F]E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B0V5L(&]P<W!L:71S96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI
M="!C;VQU;6XB"FUS9W-T<B`B2V]L;VT@;W!S<&QI='-E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G
M:60@(E-P;&ET(')O=R(*;7-G<W1R(")2:6H@;W!S<&QI='-E;B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@
M(E-P;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30Q"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T
M<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8*;7-G:60@(E-T86YD87)D(@IM
M<V=S='(@(E-T86YD86%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<Y,0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")3=&%R=&IA
M87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B4W1A870@;V8@<')O
M=FEN8VEE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&]R86=E(&9O<FUA="(*
M;7-G<W1R(")/<'-L86=F;W)M86%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(D%D<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")$;V]R
M:&%L96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED
M(")3=')I;F<@;&ES="(*;7-G<W1R(")3=')I;F=L:6IS="(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E-T<FEP(&1O;65I;B!V86X@:&5T
M(&%D<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I
M:FP@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("):;R(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4W5B9&ER96-T;W)Y
M(%PB)7-<(B!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`B3VYD97)W97)P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`IM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(D)E=F5S=&EG96XB"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@
M=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G
M<W1R("(B"B)697)Z;V5K('9E<G-T=75R9"!O;2!<(B5S7"(@86%N(&AE="!S
M>7-T965M('1O92!T92!V;V5G96XN(%4@:W5N="!N:65T("(*(F%A;FUE;&1E
M;B!T;W0@=7<@=F5R>F]E:R!I<R!G;V5D9V5K975R9"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S
M8W)I<'0B"FUS9W-T<B`B4W5B<V-R:7!T(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$P-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S
M='(@(E-U8V-E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&UE="!S=6-C97,@86%N(&AE="!S>7-T
M965M('1O96=E=F]E9V0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1&%T82!V
M86X@9V5B<G5I:V5R(%PB)7-<(B!M970@<W5C8V5S('5I="!H970@<WES=&5E
M;2!V97)W:6ID97)D+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!M970@
M<W5C8V5S('9E<G=I:F1E<F0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!M970@<W5C8V5S
M('5I="!H970@<WES=&5E;2!V97)W:6ID97)D+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@
M(D-O;F9I9W5R871I92!M970@<W5C8V5S('1E<G5G9V5Z970N(%9E<FYI975W
M(&]M('=I:GII9VEN9V5N('1E('II96XN(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(D)A8VMU<&-O;F9I9W5R871I92!M970@<W5C8V5S<R!O<&=E<VQA9V5N
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")"86-K=7!C;VYF:6=U<F%T:65B
M97-T86YD("5S(&UE="!S=6-C97-S(&]P9V5S;&%G96XN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@;65T('-U8V-E<R!B
M:6IG97=E<FMT(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S(&UE="!S=6-C97,@9V5S
M8VAR979E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@
M(E-O961A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4V%M96YV
M871T:6YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3
M=6X@4FES92(*;7-G<W1R("):;VYS;W!G86YG(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(EIO;G-O;F1E
M<F=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B6F]N;FEG(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R("):;VYS;W!G86YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E
M="(*;7-G<W1R("):;VYS;W!G86YG+UIO;G-O;F1E<F=A;F<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B
M"FUS9W-T<B`B6F]N<V]P9V%N9SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(EIO;G-O;F1E
M<F=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS
M9VED(")3=6YS970Z("(*;7-G<W1R("):;VYS;VYD97)G86YG.B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED
M(")3=7!E<G-C<FEP="(*;7-G<W1R(")3=7!E<G-C<FEP="(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`B3VYD97)S=&5U;FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN
M86UE(@IM<V=S='(@(E-U<FEN86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B06-H
M=&5R;F%A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`B4W!I='-B97)G96X@96X@2F%N($UA>65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W87II
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#4*;7-G:60@(E-W961E;B(*;7-G<W1R("):
M=V5D96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T
M<B`B6G=I='-E<FQA;F0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3>6YC(&QO
M9R!V97)W:6ID97)D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM
M<V=I9"`B4WEN8TU,(@IM<V=S='(@(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(*;7-G<W1R(")3>6YT87AF;W5T(&EN('IO96MT97)M
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$X"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI
M8R(*;7-G<W1R(")3>7)I<V-H92!!<F%B:7-C:&4@4F5P=6)L:65K(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@
M(E0M4W1O<FTB"FUS9W-T<B`B3VYW965R<V)U:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N
M9"!7:6YD>2(*;7-G<W1R(")/;G=E97)S8G5I96X@96X@=VEN9&5R:6<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I
M9"`B5"U3=&]R;7,B"FUS9W-T<B`B3VYW965R<V)U:65N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O
M<FUS($5A<FQY(@IM<V=S='(@(D]N=V5E<G-B=6EE;B!V<F]E9R(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE
M(@IM<V=S='(@(E135B!B97-T86YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O
M<&5R=&EE<R(*;7-G<W1R(")486)E;&5I9V5N<V-H87!P96XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")4
M86)L92!3970B"FUS9W-T<B`B5&%B96QS970B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L
M92!P<F]P97)T:65S(@IM<V=S='(@(E1A8F5L96EG96YS8VAA<'!E;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S0*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486EW
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW
M86XL(%!R;W9I;F-I92!V86X@0VAI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U"FUS9VED
M(")486II:VES=&%N(@IM<V=S='(@(E1A9'IJ:6MI<W1A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S4*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B5&%N>F%N:6$L(%9E<F5N:6=D92!297!U8FQI96L@=F%N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I
M9"`B5&%R9V5T.B(*;7-G<W1R(")$;V5L.B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3,R(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(E1A:V5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L
M969O;VYN=6UM97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I
M9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U=7(@
M=F%N(&AE="!A9F=E;&]P96X@=75R.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U
M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED
M(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T=75R.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,B"FUS9W-T<B`B5&5M<&5R871U=7(\8G(@+SXH)7-(;V]G)7,O)7-,86%G
M)7,I("9G<F0[)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(")3:F%B;&]O;B!<(B5S7"(@;FEE="!G979O
M;F1E;BXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M
M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4VIA8FQO;VYB96AE97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,C<*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N
M;'DB"FUS9W-T<B`B06QL965N('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R(")496MS="!U:71L:6IN96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P
M(@IM<V=S='(@(E1E:W-T8F]V96YK86YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B
M1&\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H
M5$E3+38R,"DB"FUS9W-T<B`B5&AA:7,@*%1)4RTV,C`I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-`IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6QA;F0B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E
M>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1&4@1E10(&5X
M=&5N=&EE(&ES(&YI970@8F5S8VAI:V)A87(N(@H*(SH@9G)A;65W;W)K+TAI
M<W1O<GDO2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E
M;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B2&5T(&=E<V-H:65D96YI<W-Y<W1E
M96T@:7,@=6ET9V5S8VAA:V5L9"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB
M(@IM<V=S='(@(D1E($AO<F1E+TMO;&%B(&EN=&5G<F%T:64@;VYD97)S=&5U
M;G0@7"(E<UPB(&YI970B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]"
M;V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B(*;7-G<W1R(")(970@24U34"!L;V<@:V]N(&YI970@
M=V]R9&5N(&=E:6YI=&EA;&ES965R9"XB"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I
M9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B1&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!W97)D(&YI970@9V5L861E;B(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I
M;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")(970@3W!T:65S
M<V-H97)M(&ES(&=E<VQO=&5N+B!!9G-L=6ET96XN(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE
M961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K
M96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T
M<B`B(@HB1&4@8F5H965R9&5R(&1I96YT(&5E;B!P97)M86YE;G0@<F5C:'1E
M;F)A8VME;F0@=&4@8V]N9FEG=7)E<F5N(&%L<R!U("(*(G)E8VAT96X@=VEL
M="!G96)R=6EK96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N
M;'DB"FUS9W-T<B`B06QL965N(&1E(&]N9&5R:V%N="(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B
M"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N
M(@IM<V=S='(@(B(*(DAE="!C;VYT86-T($E$(&YU;6UE<B!I<R!N:65T(&]P
M9V5G979E;BP@;&5E9R!G96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@:6X@
M(@HB9&4@9&%T86)A<V4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")(
M970@861R97,@:7,@;65T('-U8V-E<R!A86X@=7<@861R97-B;V5K('1O96=E
M=F]E9V0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$W
M,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@HB2&5T(&QO<V=E:V]P<&5L9&4@4$=0(&]N9&5R=&5K96YI;F=S
M8FQO:R!I<R!V97)E:7-T(&]M(&AE="!O;F1E<G1E:V5N9&4@(@HB8F5R:6-H
M="!T92!V97)I9FGK<F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@
M(B(*(DAE="!D:7-T<G5B=71I96QI:G-T($E$(&ES(&YI970@;W!G96=E=F5N
M+"!L965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B`B"B)I;B!D92!D
M871A8F%S92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(")$92!D:7-T<FEB=71I96QI:G-T
M(&ES(&YI970@;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")$92!C;V1E
M97)M;V=E;&EJ:VAE9&5N('9E<F5I<V5N(&5E;B!B979E:6QI9V1E('=E8G9E
M<F)I;F1I;F<N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#8@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+B(*;7-G<W1R(")(970@8F5S=&%N9"`E<R!D:65N="!E96X@)7,@:6YS=&5L
M;&EN9R!T92!B979A='1E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+B(*;7-G<W1R(")(970@8F5S=&%N9"`E<R!D:65N="!E
M;FEG92`E<R!I;G-T96QL:6YG96X@=&4@8F5V871T96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")(970@8F5S=&%N
M9"!K86X@;FEE="!N86%R('II8VAZ96QF(&=E:V]P:65E<F0@=V]R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DAE="!B97-T86YD(&)E
M=F%T=&4@9V5E;B!D871A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM
M<V=S='(@(DAE="!V;VQG96YD92!Z:6IN(&1E(&MO<'!E;B!V86X@9&ET(&UE
M<W-A9V4O<F9C.#(R(&)E<FEC:'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)686X@9&4@
M=F]L;&5D:6<@<V-H97)M(&UO9&4@:7,@8F5K96YD+"!D870@9&ET('!R;V)L
M96UE;B!K86X@=F5R;V]R>F%K96X@;65T("(*(DEN=&5R;F5T($5X<&QO<F5R
M+"!V86YW96=E(&)R;W=S97)B=6=S('=A87(@=VEJ(&YI970@;VUH965N(&MU
M;FYE;BX@2&5T(&ES("(*(FUO9V5L:6IK(&1A="!U(')O;6UE;"!I;B!H970@
M8F5E;&1S8VAE<FTL(&=E8G)E:R!A86X@961I=&]R9G5N8W1I97,@96XO;V8@
M(@HB<F%N9&]M(&)R;W=S97(M(&-R87-H97,@97)V86%R="X@5V%N;F5E<B!U
M=R!S>7-T965M(%=I;F1O=W,@.7@@:7,L(&ES(&AE="`B"B)W86%R<V-H:6IN
M;&EJ:R!D870@=2!E96X@)T%L9V5M96YE($)E=F5I;&EG:6YG<R!&;W5T)R!K
M<FEJ9W0L(&5N(&]P;FEE=7<@(@HB9&EE;G0@=&4@:&5R<W1A<G1E;BY<7&Y<
M7&Y5(&)E;G0@9V5W86%R<V-H=7=D+B!$<G5K(&]P($]+('=A;FYE97(@=2!T
M;V-H(&1E("(*(G9O;&QE9&EG('-C:&5R;2!E9&ET;W(@=VEL="!P<F]B97)E
M;BXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B1&4@:61E;G1I=&5I="!<(B5S7"(@:7,@=F5R=VEJ9&5R9"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M(")!;&QE96X@9&4@;&EN:V5R:V%N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H
M92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P
M.CH@8VQA<W,N(@IM<V=S='(@(B(*(D1E('!L86%T<R!V86X@:&5T($=N=5!'
M('!R;V=R86UM82!D:65N="!O<&=E9V5V96X@=&4@=V]R9&5N(&EN(&1E("(*
M(D-R>7!T7W!G<#HZ(&-L87-S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B
M965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G
M<W1R("(B"B)(970@8F5R:6-H="!V97)S='5U<F0@;W`@)7,@86%N("5S(&UE
M="!O;F1E<G=E<G`@7"(E<UPB(&ES('=E97)G96=E=F5N+EQN(@HB1&ET(&ES
M(&=E96X@9V%R86YT:64@9&%T(&AE="!B97)I8VAT(&ES(&=E;&5Z96X@;V8@
M8F5G<F5P96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM
M<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E(@IM<V=S='(@(D1E(&YA86T@9&EE(&=E8G)U:6MT('=O<F1T
M(&)I:B!L:6YK96X@;F%A<B!D92!N:65U=R!B97)I8VAT('!A9VEN82(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")(970@
M86%N=&%L('9E;&1E;B!D:65N="!N=6UE<FEE:R!T92!Z:6IN+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B1&4@;W!E;G-S;"!M;V1U;&4@
M:7,@=F5R96ES="!V;V]R(&1E($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(D1E('9O;W)K975R
M<VEN<W1E;&QI;F<@7"(E<UPB(&MO;B!N:65T('=O<F1E;B!O<&=E<VQA9V5N
M+"!O;61A="!D92!D871A(&1E("(*(FUA>&EM=6T@=&]E;&%A=&)A<F4@9W)O
M;W1T92!O=F5R<V-H<FEJ9'0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)(970@
M<')O9W)A;6UA(&]M(&1I="!D871A='EP92`H)7,I('1E(&)E:VEJ:V5N+"!W
M97)D(&YI970@;W`@:&5T('-Y<W1E96T@(@HB9V5V;VYD96XN(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@
M8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(DAE="!A86YH86QI;F=S=&5K96X@9&EE;G0@Z^MN(&5N:V5L('1E:V5N
M('1E('II:FXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'DB"FUS9W-T<B`B06QL965N(&1E(')E8VAT97(M(&5N(&QI;FME
M<FMA;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B06QL965N(&1E(')E8VAT97)K86YT(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(DAE="!S8VAE
M:61I;F=S=&5K96X@9&EE;G0@Z^MN(&5N:V5L('1E:V5N('1E('II:FXN(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B1&4@<V5R=F5R(%PB)7-<(B!I<R!V97)W:6ID97)D+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R(")$92!S97)V97(@7"(E<UPB(&ES(&]P9V5S;&%G96XN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B
M2&5T(&%A;FUE;&1I;F=S=F5R>F]E:R!V;V]R("5S(&ES('9E<G=I:F1E<F0N
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&4@;W!G96=E=F5N(')I
M:B`H)60I(&)E<W1A870@;FEE="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y
M(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")(970@=&EJ
M9&5L:6IK(&)E<W1A;F0@7"(E<UPB(&)E<W1A870@;FEE="XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`R"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(D1E(&EN9V5V;V5R9&4@=&5K<W0@:V]M="!N:65T(&]V97)E
M96X@;65T(&1E('1E:W-T(&]P(&AE="!S8VAE<FTN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B06QL965N
M(&1E(&)O=F5N+2!E;B!O;F1E<FMA;G0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P
M('-I9&4@;VYL>2(*;7-G<W1R(")!;&QE96X@9&4@8F]V96YK86YT(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS
M9W-T<B`B1&4@=7!L;V%D960@9&%T82!I<R!N82!D92!V;V]R9V%A;F1E('-T
M87`@=F5R;&]R96X@9V5G86%N+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM
M<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*
M;7-G<W1R(")(970@=7!L;V%D960@8F5S=&%N9"!I<R!N:65T(&]P9V5S;&%G
M96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R
M+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")(970@=V5A
M=&AE<BYC;VT@8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R+B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M
M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E1H96UA
M9&ER96-T;W)Y(%PB)7-<(B!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@
M;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(D=E96X@;W!T:65S(&)E<V-H
M:6MB86%R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C,U,`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D5R('II:FX@9V5E;B!O;F1E<F1E
M;&5N+"!W96QK92!I;FQI;F4@=V5E<F=E9V5V96X@:W5N;F5N('=O<F1E;BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN
M('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@
M(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)%
M<B!Z:6IN('1E('9E96P@:V%R86MT97)S(&EN(&1I="!V96QD+B!5(&AE969T
M("5S(&MA<F%K=&5R<R!O<&=E9V5V96X[('4@(@HB9&EE;G0@;6EN9&5R(&1A
M;B`E<R!O<"!T92!G979E;BXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S
M97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R
M(")%96X@<')O8FQE96T@;65T(&AE="!T;V5V;V5G96X@=F%N(%PB)7-<(B!A
M86X@:&5T('-Y<W1E96TZ("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B(@HB165N('!R;V)L965M(&UE="!H970@=F5R=VEJ9&5R96X@=F%N
M(&1A=&$@=F%N(&=E8G)U:6ME<B!<(B5S7"(@=6ET(&AE="`B"B)S>7-T965M
M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B165N('!R;V)L965M(&UE="!H970@=F5R
M=VEJ9&5R96X@=F%N(%PB)7-<(B!U:70@:&5T('-Y<W1E96TZ("(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B165N
M('!R;V)L965M(&UE="!H970@8FEJ=V5R:V5N('9A;B!<(B5S7"(Z("5S(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B165N('!R
M;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@1V5E;B`E<R!W97)D(&=E
M=7!L;V%D+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N
M('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G
M<W1R("(B"B)%96X@<')O8FQE96T@;65T(&1E(&)E<W1A;F1S=7!L;V%D.B!(
M970@)7,@:7,@9W)O=&5R(&1A;B!D92!M87AI;75M("(*(G1O96QA871B87)E
M(&=R;V]T=&4@*"5D(&)Y=&5S*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB165N('!R
M;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES('-L96-H
M=',@9V5D965L=&5L:6IK(&=E=7!L;V%D+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(D5E;B!F;W5T(&)I:B!H970@8F5K:6IK96X@=F%N(&1I="!B97)I8VAT;VYD
M97)D965L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M8V]N=&%C="!D871A+B(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&EM<&]R
M=&5R96X@=F%N(&1E(&%D<F5S9&%T82XB"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")%96X@9F]U="!B
M:6H@:&5T(&EM<&]R=&5R96X@=F%N(&1E(&E#86QE;F1A<F1A=&$N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*
M(D5E;B!F;W5T(&EN(&AE="!C;VYF:6=U<F%T:65F;W)M=6QI97(N($UI<W-C
M:&EE;B!B96YT('4@965N('9E<G!L:6-H="!V96QD("(*(G9E<F=E=&5N+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*
M(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB165N(&9O=70@8FEJ(&AE
M="!U:71V;V5R96X@=F%N(&1E(&]P9V5G979E;B!A9')E<V)O96MF=6YC=&EE
M+B!0<F]B965R(&QA=&5R("(*(F]P;FEE=7<L(&$N=2YB+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M165N(&9O=70@;65T(&AE="!B:6IW97)K96X@=F%N(&1E(&%D<F5S9&5T86EL
M<RX@4')O8F5E<B!L871E<B!O<&YI975W+"!A+G4N8BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@
M;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB165N
M(&9O=70@;65T(&AE="!B:6IW97)K96X@=F%N(&1E(&1I<W1R:6)U=&EE;&EJ
M<W0N(%!R;V)E97(@;&%T97(@;W!N:65U=RP@82XB"B)U+F(N(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R(")$97IE($E-05`@<V5R=F5R(&]N9&5R<W1E=6YT(&=E
M96X@9&5L:6YG('9A;B!M87!P96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B1&ET(&QI
M:FMT(&YI970@965N(&=E;&1I9R!R87(@8F5S=&%N9"!T92!Z:6IN+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N
M(@IM<V=S='(@(D1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@>FEP(&)E<W1A
M;F0@=&4@>FEJ;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(W
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`B1&ET(&QI:FMT(&YI970@965N(&=E;&1I9R!K
M86%R=&YU;6UE<B!T92!Z:6IN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&ET('-T=75R<')O9W)A
M;6UA(&=E969T(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E
M($-L:6-K871E;&P@(@HB*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A
M>2!T92!V97)Z96YD96XL(&0N;2YV+B!D92!(5%10($%022(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&ET('-T=75R<')O9W)A;6UA
M(&=E969T(&1E(&UO9V5L:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E(%=)
M3B`H:'1T<#HO+R(*(G=I;G!L8RYC;VTI(&=A=&5W87D@=&4@=F5R>F5N9&5N
M+"!D+FTN=BX@9&4@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1I="!S='5U<G!R;V=R86UM
M82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!S
M;7,R96UA:6P@(@HB*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y('1E
M('9E<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I
M82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="DN(@IM<V=S='(@(B(*(D1I="!S='5U<G!R;V=R86UM82!G965F
M="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!33510(&0N;2YV
M+B!D92`B"B)6;V1A9F]N92!)=&%L>2!G871E=V%Y('1E('9E<GIE;F1E;B!N
M86%R(%9O9&%F;VYE(&YU;6UE<G,N($AI97)V;V]R(&ES(&5E;B`B"B)6;V1A
M9F]N92!)=&%L>2!E+6UA:6QA9')E<R`H:'1T<#HO+W=W=RXQ.3`N:70I(&YO
M;V1Z86ME;&EJ:RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#4P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@P-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$S"FUS9VED(")4:&ES(&9I96QD(&ES
M(')E<75I<F5D+B(*;7-G<W1R(")$:70@=F5L9"!I<R!V97)E:7-T(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")$:70@=F5L
M9"!M86<@86QL965N(&EN=&5G97)S(&)E=F%T=&5N+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,38*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D1I
M="!V96QD(&UA9R!A;&QE96X@9V5T86QL96X@96X@9&4@9'5B8F5L92!P=6YT
M(&)E=F%T=&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N(@IM<V=S='(@(D1I="!V96QD(&UA9R!A;&QE96X@;V-T86%L('=A87)D
M96X@8F5V871T96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R
M,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB1&ET('9E
M;&0@9&EE;G0@965N(&MO;6UA(&]F('-P871I92!G97-C:&5I9&5N(&QI:G-T
M(&UE="!I;G1E9V5R<R!T92!Z:6IN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N(@IM<V=S='(@(D1E>F4@=V%A<F1E(&1I96YT(&5E;B!G96QD:6<@
M9V5T86P@=&4@>FEJ;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$X"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G
M(S$R,S1A9B<N(@IM<V=S='(@(B(*(D1I="!V96QD(&1I96YT(&5E;B!K;&5U
M<F-O9&4@:6X@4D="($A%6"UF;W)M86%T('1E(&)E=F%T=&5N+"!B+G8N("<C
M,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B1&ET(&9O<FUU;&EE<B!I<R!R965D<R!V97)W97)K="XB"@HC.B!T
M96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&ES("5S+B(*;7-G<W1R(")$:70@:7,@)7,N(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I
M<VET("5S(@IM<V=S='(@(B(*(D1I="!I<R!E96X@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@3VT@9&ET(&]B:F5C="!W965R('1E(&=E=F5N(&AE969T('4@
M965N(&4M(@HB;6%I;"!C;&EE;G0@;F]D:6<@9&EE(&AE="!+;VQA8B!'<F]U
M<'=A<F4@9F]R;6%A="!B96=R:6IP="X@5F]O<B!E96X@;&EJ<W0@(@HB;65T
M(&1E>F4@92UM86EL8VQI96YT<RP@8F5Z;V5K("5S+"!A+G4N8BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@
M(B(*(D1I="!B97)I8VAT(&ES(&EN(&5E;B!A;F1E<F4@:V%R86MT97)S970@
M*"5S*2!G97-C:')E=F5N+"!D86X@=7<@96EG96XN(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")$:70@9V5T86P@9&EE;G0@
M=&5N;6EN<W1E(.GI;B!T92!Z:6IN+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N
M)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(D1E
M>F4@<V5R=F5R(&MA;B!G965N('II<"!E;B!G>FEP(&)E<W1A;F1E;B!U:71P
M86MK96XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"XB"FUS9W-T<B`B2&5T('-Y<W1E96T@:7,@;6]M96YT965L('5I=&=E
M<V-H86ME;&0N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T
M<B`B1&5Z92!W86%R9&4@9&EE;G0@965N(&=E=&%L('1E('II:FXN(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=R(*;7-G<W1R(")$:70@<V-H97)M(&1I96YT(&%A;F=E<F]E<&5N('1E('=O
M<F1E;B!V86YU:70@965N($]P=&EE<W-C:&5R;2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM
M<V=S='(@(D]N=V5E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B5&EC:V5T<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C4@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(E1I:F0B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG
M(@IM<V=S='(@(E1I:F1P;&%N;FEN9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B5&EJ9&9O<FUA870B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Q"FUS9VED(")4:6UE
M('-E;&5C=&EO;B(*;7-G<W1R(")4:6ID<V5L96-T:64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(E1I=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")4:71E
M;"`H=&]O;'1I<"DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B06%N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC
M:VEN9RXB"FUS9W-T<B`B(@HB3VT@;65E<F1E<F4@;VYD97)D96QE;B!T92!S
M96QE8W1E<F5N+"!H;W5D(&1E($-O;G1R;VP@*%!#*2!O9B!#;VUM86YD("A-
M86,I("(*(G1O971S('9A<W0@=&EJ9&5N<R!K;&EK:V5N+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S
M='(@(E9A;F1A86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T
M<B`B2%1-3"!B<F]N(&]M<V-H86ME;&5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,PIM<V=I
M9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-@IM<V=I9"`B
M5&]K96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B36]R
M9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R.0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N
M9V$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G
M:60@(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M
M:6YU=&5S+B(*;7-G<W1R(")492!V965L(&]N9V5L9&EG92!A86YM96QD:6YG
M96X@9V5D=7)E;F1E(&1E(&%F9V5L;W!E;B!M:6YU=&5N+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I
M9"`B5&]P(@IM<V=S='(@(D)O=F5N:V%N="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H
M7W1O<"DB"FUS9W-T<B`B0F]V96YS=&4@9G)A;64@*%]T;W`I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS
M9W-T<B`B5F5R=&%L:6YG96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R"FUS9VED(")4<FEN
M:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D(&5N(%1O8F%G;R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@
M;W(@9F%L<V4B"FUS9W-T<B`B5')U92!O9B!F86QS92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM
M<V=S='(@(D1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.`IM<V=I9"`B5'5N:7-I82(*;7-G
M<W1R(")4=6YE<VGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,0IM<V=I9"`B5'5R:V5Y(@IM
M<V=S='(@(E1U<FMI:F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM
M<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R:W,@*$E3
M3RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-PIM<V=I9"`B5'5R:VUE;FES=&%N
M(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`*;7-G:60@
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<R!E;B!#
M86EC;W,@96EL86YD96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S"FUS9VED(")4=79A;'4B
M"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V
M-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(E1Y<"!U=R!K
M975Z93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM
M<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E4N5BX@:6YD97@Z("(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(E523"!V;V]R('5W(&%F;&5V97)I;F=S<W1A
M='5S<F%P<&]R="!S8W)I<'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,W"FUS9VED(")59V%N9&$B"FUS9W-T<B`B3V5G86YD
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B3V5K
M<F'O;F4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3D*;7-G
M:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y(&%A;B!T92!S<')E:V5N+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B(@HB3FEE="!I;B!S=&%A="!E>'1R82!G96)R
M=6EK97)S:6YF;W)M871I92!T;V4@=&4@=F]E9V5N(&)I:B!I;G-C:')I:G9E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!D92!R
M96-H=&5N('9A;B!61E,@8F5S=&%N9"!<(B5S7"(@=&4@=VEJ>FEG96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,SDR(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B3FEE="!I;B!S=&%A="!D92!R96-H=&5N('9A;B!61E,@8F5S
M=&%N9"`E<R\E<R!T92!W:6IZ:6=E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(*;7-G<W1R(").:65T(&EN('-T86%T('1E('=I:GII
M9V5N(&YA87(@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@8F5S=&%N
M9'-G<F]O='1E('9A;B!<(B5S7"(@=&4@8V]N=')O;&5R96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T
M(&)E<W1A;F1S9W)O;W1T92!V86X@7"(E<R\E<UPB('1E(&-O;G1R;VQE<F5N
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYI
M970@:6X@<W1A870@;65T(&1E(%-13"!S97)V97(@=&4@=F5R8FEN9&5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3FEE="!I;B!S=&%A
M="!M970@4U-,('1E('9E<F)I;F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,S(@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,W
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T
M92!K;W!IZW)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB('1E(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,V,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E(&UA:V5N+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93
M(&)E<W1A;F0@=&4@;6%K96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!6
M1E,@;6%P(%PB)7-<(B!T92!M86ME;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@965N(&QE96<@5D93
M(&)E<W1A;F0@=&4@;6%K96XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V=Z:7`N<&AP.C<Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(*;7-G<W1R(").:65T(&EN('-T86%T(&1A=&$@=6ET('1E('!A:VME
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,R!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN(@IM<V=S='(@(DYI970@:6X@<W1A870@7"(E<UPB('1E('9E<G=I
M:F1E<F5N+"!D92!D:7)E8W1O<GD@:7,@;FEE="!L965G(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB
M"FUS9W-T<B`B3FEE="!I;B!S=&%A="!<(B5S7"(Z("5S('1E('9E<G=I:F1E
M<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S."!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,SDU(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3FEE="!I
M;B!S=&%A="`E<R!T92!V97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y(&ES(&YI
M970@;&5E9R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*
M;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@<F5C=7)S:65F
M('1E('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,T-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!V
M97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R
M,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@)7,@=&4@=F5R
M=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M7"(E<UPB('1E('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$X-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(Y,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@=&4@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!61E,@;6%P(%PB)7-<(B!T92!V97)W:6ID97)E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@
M)7,N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93("5S(')E8W5R<VEE9B!T
M92!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!H=6ED:6=E(&1I<F5C=&]R
M>2!T92!B97!A;&5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS(@IM<V=S='(@(DYI970@:6X@<W1A870@8V5R=&EF:6-A871D
M971A:6QS('5I="!T92!F:6QT97)E;B(*"B,Z(&9R86UE=V]R:R].971?24U3
M4"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP
M:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(").:65T(&EN('-T86%T(&]M
M(&1E(&1E9FEN:71I92!V86X@)7,@=&4@;&%D96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(").:65T(&EN('-T86%T
M(%9&4R!B97-T86YD('1E('9E<G!L86%T<V5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.3@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C8U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@7"(E<UPB('1E(&]P96YE;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#0@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T
M92!O<&5N96X@=F]O<B!S8VAR:6IV96XN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z.#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,W
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@=&4@;W!E;F5N+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!H
M970@:6YG97!A:W1E(&)E<W1A;F0@=&4@;W!E;F5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@=&4@;&5Z96X@*&9I;&5S:7IE*"D@;6ES;'5K="DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS
M9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!L97IE;B`H9V5T
M1FEL95-I>F4H*2!M:7-L=6MT*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L
M92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(").:65T(&EN('-T86%T(&)E<W1A
M;F0@=&4@;&5Z96XZ("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(*;7-G<W1R(").:65T(&EN('-T86%T('9F<W)O;W0@9&ER96-T;W)Y
M('1E(&]P96YE;BXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q
M,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S
M='(@(DYI970@:6X@<W1A870@;VT@)7,@=&4@:&5R;F]E;65N(&YA87(@)7,Z
M(&)E<W1E;6UI;F=S;6%P(&)E<W1A870@86PB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&1I
M<F5C=&]R>2!T92!H97)N;V5M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3FEE="!I;B!S=&%A
M="!61E,@9&ER96-T;W)Y("5S('1E(&AE<FYO96UE;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@
M8F5S=&%N9"!<(B5S7"(@=&4@:&5R;F]E;65N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E
M<W1A;F0@)7,O)7,@=&4@:&5R;F]E;65N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR,3,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0U,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@
M=&4@:&5R;F]E;65N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N(@IM<V=S='(@(DMA;B`G;6MI<V]F<R<@;FEE="!U:71V;V5R
M96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H
M<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0B"FUS9W-T<B`B3FEE="!I;B!S=&%A="!D:70@5V]R9"!D;V-U;65N
M="!T92!V97)T86QE;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@7"(E<UPB('1E('-C
M:')I:G9E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H
M<FEJ=F5N("AC;W!Y*"D@9F%I;&5D*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9'-D871A('1E('-C:')I:G9E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM
M<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H<FEJ=F5N
M+"!Q=6]T82!W;W)D="!O=F5R<V-H<F5D96XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE
M(@IM<V=S='(@(D]N9&5R<W1R97!E;B(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")(97)S=&5L
M('=I:GII9VEN9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB
M"FUS9W-T<B`B1&]E="!U=R!L86%T<W1E(&)E=V5R:VEN9R!T96YI970B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I
M;VXZ("(*;7-G<W1R(")/;G9E<G=A8VAT(&%N='=O;W)D('9A;B!D92!S97)V
M97(@;W`@=F5R8FEN9&EN9SH@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B`B"FUS9W-T<B`B3VYV97)W86-H="!A;G1W;V]R9"!V86X@
M<V5R=F5R(&%A;CH@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3VYB
M96YO96UD(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N
M:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-PIM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
M5F5R96YI9V1E($%R86)I<V-H92!%;6ER871E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.`IM
M<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B5F5R96YI9V0@2V]N:6YG
M:W)I:FLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0P"FUS9VED(")5;FET960@4W1A=&5S(@IM
M<V=S='(@(E9E<F5N:6=D92!3=&%T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y"FUS9VED
M(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T
M<B`B5F5R96YI9V1E(%-T871E;BP@:VQE:6YE(&)U:71E;B!L:6=G96YD92!E
M:6QA;F1E;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R(")%
M96YH961E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-3@@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W
M;B(*;7-G<W1R(")/;F)E:V5N9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")/;F)E:V5N9"!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")/;F)E:V5N
M9"!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(D]N8F5K96YD92!L;V-A=&EE(&]P9V5G
M979E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(D]N8F5K96YD92!G96)R=6EK97)S;F%A;2!O9B!W86-H
M='=O;W)D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`B2&5T(&AU:61I9V4@96QE;65N="!L;W-K;W!P96QE
M;B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(D]N8F5N;V5M9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB3FEE="!G97)E
M8VAT:6=D92!S8W)I<'1S(&MU;FYE;B!P<F]G<F%M;6%M871I9R!N:65T($MN
M:7!P96XO2V]P:>MR96XO(@HB4&QA:VME;BP@=F%N=V5G92!B979E:6QI9VEN
M9W-R961E;F5N+B!+;&EK(&]P($]+(&]M(&5E;B!T96-H;FES8VAE(&]P;65R
M:VEN9R`B"B)O<"!M;WII;&QA+F]R9R!T92!B96MI:FME;B!H;V4@=2!E96X@
M<V-R:7!T('1O97-T86%T(&AE="!P<FEK8F]R9"!T92`B"B)B96YA9&5R96XN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B2VQE=7(@=&5R
M=6=S=&5L;&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N
M<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(").:65T(&]N9&5R<W1E=6YD
M92!E>'1E;G1I92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`B0FEJ=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&4@)7,B"FUS9W-T<B`B)7,@8FEJ=V5R:V5N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS
M9W-T<B`B1V5B<G5I:V5R(&)I:G=E<FME;BXB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&)I:F=E=V5R:W0N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N(@IM<V=S='(@(E5P9W)A9&4@<V-R:7!T('9E<G=I:F1E<F0N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS
M9W-T<B`B57!L;V%D(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM
M<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N(@IM<V=S='(@(D%L;&4@=&]E<&%S<VEN9R!S971U<&)E
M<W1A;F1E;B!N86%R(&1E('-E<G9E<B!G975P;&]A9"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS
M9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(DQA=&EJ;G-E(&AO
M;V9D;&5T=&5R<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B1W)O=&4@4F]M96EN<V4@9V5T86QL96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Q"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B
M1V5B<G5I:R!H=6ED:6=E.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(D=E8G)U:6L@4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B1V5B<G5I:V5N('=A;FYE97(@;F%A
M;2]W86-H='=O;W)D('9E<G-C:&EL="!M970@24U34"!S97)V97(N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E
M<B(*;7-G<W1R(")'96)R=6EK97(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B1V5B<G5I
M:V5R("5S(&ES(&YI970@9V5A=71O<FES965R9"!V;V]R("5S+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")'96)R=6EK97)S8F5H965R(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M(")'96)R=6EK97)S;W!T:65S(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B1V5B<G5I:V5R<W)E9VES=')A
M=&EE(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B
M1V5B<G5I:V5R<W)E9VES=')A=&EE(&ES('5I=&=E<V-H86ME;&0@;W`@9&5Z
M92!S:71E+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT.30*;7-G:60@
M(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B1V5B<G5I:V5R<V%C
M8V]U;G0@;FEE="!G979O;F1E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS
M9VED(")5<V5R;F%M92(*;7-G<W1R(")'96)R=6EK97)S;F%A;2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R(")'96)R=6EK97)S;F%A;2!<(B5S7"(@8F5S=&%A="!A;"XB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE
M.B(*;7-G<W1R(")'96)R=6EK97)S;F%A;3HB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(D=E
M8G)U:6ME<G-N86%M.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")'
M96)R=6EK97)S(&EN(&AE="!S>7-T965M.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(*;7-G
M:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B3V5Z8F5K:7-T86XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C8R"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")61E,@9&ER96-T;W)Y(&)E<W1A870@;FEE="XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO
M;B(*;7-G<W1R(")!9G=E>FEG:&5I9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z("(*;7-G<W1R(")'979O;F1E;B!G96QD:6=E(&QO8V%T:65S(&)E=F%T
M=&5N.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S
M.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B1V5L9&EG:&5I9"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-PIM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B
M5V%A<F1E(&EN(&UI;G5T96X@=F%N868@;G4N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(E=A87)D92!L:6=T(&)O=F5N(&1E
M(&UA>&EM=6T@;&5N9W1E('9A;B`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3$P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")786%R9&5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB
M"FUS9W-T<B`B5V%A<F1E;B!W86%R=6ET(&=E<V5L96-T965R9"!K86X@=V]R
M9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T.0IM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")6
M86YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM
M<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B96QE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B5F5R:69I8V%T:64@;6ES;'5K
M="`M(&5R(&MA;B!M970@9&ET(&)E<FEC:'0@9V5K;F]E:60@>FEJ;BXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B
M5F5R<VEO;B(*;7-G<W1R(")697)S:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B
M5F5R<VEE8V]N=')O;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*
M;7-G<W1R(")697)T:6MA86P@=6ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@
M<&%D9&EN9R(*;7-G<W1R(")697)T:6MA;&4@=G)I:F4@<G5I;71E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:V%A;#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(D5R9R!H;V]G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.`IM<V=I9"`B
M5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@
M(E9I971N86UE97,@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HY-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R(*;7-G<W1R("(E<R!B96MI:FME;B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T
M<B`B0F5K:6IK(&5E;B!E>'1E<FYE('=E8G!A9VEN82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(&%S("5S(@IM<V=S='(@(D)E:VEJ:V5N(&%L<R`E<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#8*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(DUA86=D96X@96EL86YD96XL($)R:71S92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DUA86=D
M96X@96EL86YD96XL(%8N4RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q
M-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")::6-H="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ
M("(*;7-G<W1R(")::6-H=#H@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET
M86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE($ET86QY('9I82!33510
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")705).
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N(@IM<V=S='(@(E=!05)30TA55TE.1R$A(2`@5D525TE*1$52(%-#
M4DE05"!(04Y$34%424<@54E4("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS
M9W-T<B`B5TE.('9I82!(5%10(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L
M;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES(&5N($9U='5N82(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HY-0IM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R(")786%R<V-H=7=I;F<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G
M<W1R(")7;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM
M<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")7965R<W9O;W)U:71Z
M:6-H="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G
M:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")7965R8F5R
M:6-H="!G96=E=F5N<R!G96QE=F5R9"!D;V]R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")7
M96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED
M(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5V5B<VET92(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(E=E96ML>2(*;7-G<W1R(")796ME;&EJ:W,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")7
M96QK;VTB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92!T;R`E<R(*;7-G<W1R(")796QK;VT@8FEJ("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM
M<V=S='(@(E=E;&MO;2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B5V5S=&5R
M<R`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(E=E<W1E<G,@
M*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X"FUS9VED(")797-T97)N(%-A
M:&%R82(*;7-G<W1R(")797-T96QI:FME(%-A:&%R82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS
M9W-T<B`B5V5L:V4@=&]E<&%S<VEN9R!D:65N="`E<R!W965R('1E(&=E=F5N
M(&YA(&%A;FUE;&1I;F<_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M(@IM<V=S='(@(E=A="!I<R!H970@<V-H96ED:6YG<VMA<F%K=&5R/R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E=A="!I<R!H970@8VET
M86%T:V%R86MT97(_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*
M;7-G<W1R(")7:&5R96ES($%U<W1R86QIZR!K86%R="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E=E
M;&ME(&9A<V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R(")796QK92!P;'5G:6YS('9O;W(@9&4@4FEC:"!4
M97AT(&5D:71O<B!I;G-C:&%K96QE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*
M;7-G<W1R(")"<F5E9'1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$P-PIM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(D)R965D
M=&4@:6X@0U-3(&5E;FAE9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B(@HB0G)E961T92!V86X@:&5T("5S(&UE;G4@86%N(&1E(&QI
M;FME<FMA;G0@*&%K=&EE9B!B:6H@=F]L9V5N9&4@86%N;65L9&EN9RDZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*
M;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R(")"<F5E9'1E('9A
M;B!D92!T86)E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(D)R965D
M=&4@965N:&5I9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B0G)E961T93HB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI
M(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED(")7:6YD(@IM<V=S='(@(E=I;F0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*
M;7-G<W1R(")7:6YD('9R;V5G(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")7:6YD<VYE
M;&AE:60@:6X@:VYO<&5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*
M;7-G:60@(E=I;F0Z(@IM<V=S='(@(E=I;F0Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E=I
M;F0Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES
M9&]M(@IM<V=S='(@(E=I:G-H96ED(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B5V5N<VQI:G-T
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM
M<V=S='(@(E=E<FLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")797)K
M861R97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;"YN<BX@*'=E
M<FLI(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B5F5R:V5E<F0@86%N=&%L('9E;&1E
M;B!I;B!R96=E;"`E9"X@5F5R=V%C:'0@)60L(&=E=F]N9&5N("5D+B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(E9E<FME97)D(&%A;G1A;"!V96QD96XN(%9E
M<G=A8VAT("5D+"!G979O;F1E;B`E9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5F5R
M:V5E<F1E(&]F9G-E="`E9"!B:6H@;&5Z96X@=F%N(%9&4R!B97-T86YD+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F
M(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*
M;7-G<W1R(")8-3`Y=C,@8F%S:7-B97!E<FMI;F=E;B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT
M96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!U:71G96)R96ED('-L
M975T96QG96)R=6EK(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64B"FUS9W-T<B`B6#4P.78S(&%L=&5R;F%T:65V92!O;F1E<G=E<G!N86%M
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U
M,#EV,R!O;F1E<G=E<G`@<VQE=71E;&ED96YT:69I8V%T;W(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S
M(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S(&5X=&5N=&EE<R(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")*2B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I
M9"`B65E962(*;7-G<W1R(")*2DI*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS
M9W-T<B`B66%H;V\A(&UA<"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")*86%R
M;&EJ:W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4R"FUS9VED(")996UE;B(*;7-G<W1R(")*
M96UE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")*82(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@
M06=R964B"FUS9W-T<B`B2F$L(&EK(&%C8V5P=&5E<B!D92!V;V]R=V%A<F1E
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B
M"B)5(&)E;G0@:6X@5$5+4U0@34]$12X@1V5B<G5I:R!D92!;/#Y=(&MN;W`@
M;VT@;F%A<B!765-)5UE'('1E<G5G('1E("(*(G-C:&%K96QE;BXB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")(970@:7,@=2!N
M:65T('1O96=E<W1A86X@;VT@;65E<B!D86X@)60@8FQO:VME;B!T92!M86ME
M;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C0*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(E4@8F5N="!N
M:65T(&=E875T:&5N=&EF:6-E97)D+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(")5
M(&MU;G0@9V5E;B`G7%PG(&MA<F%K=&5R(&EN('5W('9O;&QE9V4@;F%A;2!H
M96)B96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E4@:&5E9G0@
M9V5E;B!G96QD:6<@92UM86EL861R97,@;W!G96=E=F5N+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*
M;7-G<W1R("(B"B)5(&AE969T(&=E96X@=F5L9&5N('5I="!H970@9V5I;7!O
M<G1E97)D92!B97-T86YD(&=E:V]P<&5L9"!M970@9&4@(@HB;W9E<F5E;FMO
M;7-T:6=E('9E;&1E;B!I;B`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS
M9W-T<B`B52!B96YT(&%F9V5M96QD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+B(*;7-G<W1R("(B"B)5(&1I96YT(&5E;B!G96QD:6<@;6]B:65L(&YU
M;6UE<B!I;B!T92!V;V5R96XL(&%L;&5E;B!C:6IF97)S(&UE="!E96X@(@HB
M;W!T:6]N96QE("<K)R!V;V]R(&AE="!I;G1E<FYA=&EO;F%L92!K:65S=F]O
M<G9O96=S96PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM
M<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T
M<B`B52!D:65N="!E96X@9V5L9&EG92!W86%R9&4@;W`@=&4@9V5V96XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+B(*;7-G<W1R("(B"B)5(&1I96YT(&5E;B!$871A5')E92!B86-K
M96YD('1E(&-O;F9I9W5R97)E;B!O;2!I;G-C:')I:G9I;F=E;B!T92!K=6YN
M96X@(@HB9V5B<G5I:V5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`B52!D:65N="!E96X@5D93(&)A8VME;F0@=&4@8V]N9FEG
M=7)E<F5N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q
M"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB
M52!D:65N="!H970@<')O8FQE96T@=&4@8F5S8VAR:6IV96XL('9O;W)D870@
M=2!H970@<')O8FQE96UR87!P;W)T(&MU;G0@(@HB=F5R>F5N9&5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G
M:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;R(*;7-G<W1R(")5(&1I96YT(&5E;B!54DP@:6X@=&4@=F]E<F5N
M('=A87)N86%R(&1E>F4@;&EN:R!V97)W:6IS="(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E4@9&EE;G0@965N('-E
M<G9E<B!T92!S96QE8W1E<F5N(&]M('1E('9E<G=I:F1E<F5N+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B52!D:65N="!E96X@9V5B
M<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&4@=VES<V5N+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B52!D:65N="!E96X@9V5B<G5I
M:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&4@=F5R=VEJ9&5R96XN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N(@IM<V=S='(@(E4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P
M('1E(&=E=F5N(&]M('1O92!T92!V;V5G96XN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(E4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M
M(&]P('1E(&=E=F5N(&]M(&)I:B!T92!K=6YN96X@=V5R:V5N+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G
M<W1R(")5(&1I96YT(&5E;B!B97=E<FMI;F<@;W`@=&4@9V5V96X@=V5L:V4@
M=6ET9V5V;V5R9"!M;V5T('=O<F1E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")5(&1I96YT(&5E
M;B!N:65U=V4@8V%T96=O<FEE;F%A;2!O<"!T92!G979E;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM
M<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU
M;6)E<B(*;7-G<W1R(")5(&1I96YT(&5E;B!)=&%L:6%A;G,@=&5L969O;VYN
M=6UM97(@;W`@=&4@9V5V96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(E5W("5S
M('-E<W-I92!I<R!V97)L;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N=2YB
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED
M(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B57<@92UM86EL861R97,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R
M;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E5W(%9A;CH@861R97,Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E5W
M(&EN9F]R;6%T:64B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)5=R!I;G1E<FYE=&%D<F5S(&ES
M(&=E=VEJ>FEG9"!S:6YD<R!H970@8F5G:6X@=F%N('5W("5S('-E<W-I92X@
M3VT@=7<@(@HB=F5I;&EG:&5I9"!T92!B97-C:&5R;65N+"!D:65N="!U('II
M8V@@;W!N:65U=R!A86X@=&4@;65L9&5N+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B
M57<@;F%A;3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB
M"FUS9W-T<B`B(@HB2&5T('1O979O96=E;B!V86X@9V5B<G5I:V5R<R!W;W)D
M="!N:65T(&]N9&5R<W1E=6YD(&1O;W(@=7<@875T:&5N=&EC871I92`B"B)B
M86-K96YD+B!786YN965R('4@2&]R9&4@9V5B<G5I:V5R<R!W:6QT(&)E:&5R
M96XL(&1I96YT('4@965N(&%N9&5R("(*(F%U=&AE;G1I8V%T:64@8F%C:V5N
M9"!T92!G96)R=6EK96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(@IM<V=S='(@(B(*(DAE="!W965R9V5V96X@=F%N(&5E;B!G96)R=6EK
M97)S;&EJ<W0@=V]R9'0@;FEE="!O;F1E<G-T975N9"!D;V]R('5W("(*(F%U
M=&AE;G1I8V%T:64@8F%C:V5N9"P@;V8@9&5Z92!O<'1I92!I<R!O;2!A;F1E
M<F4@<F5D96YE;B!U:71G97-C:&%K96QD+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E5W
M(&)R;W=S97(@;&EJ:W0@=&4@>FEJ;B!G97=I:GII9V0@<VEN9',@:&5T(&)E
M9VEN('9A;B!U=R`E<R!S97-S:64N($]M('5W("(*(G9E:6QI9VAE:60@=&4@
M8F5S8VAE<FUE;BP@9&EE;G0@=2!Z:6-H(&]P;FEE=7<@86%N('1E(&UE;&1E
M;BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-PIM<V=I9"`B66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R
M(")5=R!B<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@;6]G96QI:FMH96ED(&YI
M970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R
M:6YT+B(*;7-G<W1R("(B"B)5=R!B<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@
M<')I;G1O<'1I92!N:65T+B!$<G5K(&]P($-O;G1R;VPO0V]M;6%N9"`K(%`@
M;VT@(@HB868@=&4@9')U:VME;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M(")5=R!H=6ED:6=E('1I:F1Z;VYE.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R(")5=R!S=&%N9&%A<F0@:61E;G1I=&5I="!I<R!G
M97=I:GII9V0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")5=R!S=&%N9&%A
M<F0@:61E;G1I=&5I=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T
M"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B57<@=F]L;&5D:6=E
M(&YA86TZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED
M(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")5=R!A86YM96QD
M:6YG(&ES('9E<FQO<&5N+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B57<@;FEE=7=E('=A8VAT=V]O<F0@
M=F]O<B`E<R!I<SH@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")5
M=R!O<'1I97,@>FEJ;B!B:6IG97=E<FMT('9O;W(@9&4@9'5U<B!V86X@9&5Z
M92!S97-S:64N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS
M9W-T<B`B57<@;W!T:65S('II:FX@8FEJ9V5W97)K="XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R(")5=R!W86-H='=O;W)D(&ES(&=E<F5S
M970B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B
M(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E
M;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM
M<V=S='(@(B(*(E5W('=A8VAT=V]O<F0@:7,@=F5R;FEE=7=D+"!C;VYT<F]L
M965R('5W(&4M;6%I;"!E;B!M96QD(&%A;B!M970@=7<@;FEE=7=E("(*(G=A
M8VAT=V]O<F0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")5=R!W
M86-H='=O;W)D(&ES('9E<FQO<&5N+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS
M9W-T<B`B57<@<V5R=F5R<R!O<"!A9G-T86YD.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-30*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2F]E9V]S;&%V:>LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):
M86ER92(*;7-G<W1R("):8>]R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38*;7-G:60@(EIA
M;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W"FUS9VED("):
M:6UB86)W92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6U9E<F)E
M<F<@86%N9V5H86%L9&4@=&5K<W1=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP
M:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U!R;V)L
M965M<F%P<&]R=%TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R
M(");06%N9V5H86%L9&4@=&5K<W0@=V5E<F=E=F5N("TB"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T
M"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=(@IM<V=S='(@(EM!86YG96AA86QD92!T96MS="`M("5S(')E9V5L
M<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)E9V5L
M("5S('9A;B`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U
M-30@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D)?96AE97(B"@HC.B!L:6(O87!I+G!H<#HQ
M-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP
M.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B5F5R7W=I:F1E<B!R
M:6HB"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T
M<B`B7T=R;V5P96XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?2&5L<"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM
M<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T%F8F5E;&1I
M;F=S96EG96YS8VAA<'!E;BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7T%A;FUE
M;&1E;B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*
M;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]!9FUE;&1E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM
M<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]7:6IZ:6<@;&EN:RXN
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G
M:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<'1I97,B"@HC.B!L:6(O87!I+G!H
M<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4F5C:'1E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]697)W
M:6ID97(@;&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E
M='5P(@IM<V=S='(@(E]);G-T96QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]486)E;&5I9V5N<V-H87!P96XN
M+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M(")'95]B<G5I:V5R<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B061R97-B;V5K(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(D=E861R97-S965R9&4@;VYB
M96ME;F0B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-PIM<V=I
M9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0IM<V=I9"`B
M8V%L;2(*;7-G<W1R(")+86QM(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`B2V%N(&]U='!U=&)E<W1A;F0@;FEE="!M86ME;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C
M86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")+86X@:6YP=70@;FEE="!O<&5N
M96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*
M;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B2VQI:R!H:65R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")#;VUM86YD;W)E9V5L(&=E
M8G)U:6MS9F]U="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(D-O
M;F9I9W5R871I969O=70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R(")+<FET:7-C:"!S>7-T965M8F5S=&%N9"!O;G1B<F5E:W0B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I
M9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B1&%T869O<FUA871F;W5T
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I
M="(*;7-G<W1R(")B97=E<FME;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T
M<B`B:6YV;V5R(&YI970@9V5V;VYD96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R
M(")D86QE;F0B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.3@*;7-G:60@(F9I;&4B"FUS9W-T<B`B8F5S=&%N9"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B=F%N(&1E("5S("@E<RD@
M;W`@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y
M"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(G9L86=E<FEG(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB
M"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA
M;64@=6YK;F]W;B(*;7-G<W1R(")H;W-T;F%A;2!O;F)E:V5N9"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0IM<V=I9"`B:6UM961I871E(@IM<V=S='(@(F]N;6ED9&5L:6IK(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")I;FQI;F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T
M<'5T(&5R<F]R(@IM<V=S='(@(FEN<'5T+V]U='!U="!F;W5T(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R
M;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(FEN=&5R;F4@<V]F='=A<F5F
M;W5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")R96=E;'-=(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L
M('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL
M92!M86MI;F<@25-/+B(*;7-G<W1R(")M:VES;V9S(&9O=71C;V1E("5D(&)I
M:B!H970@86%N;6%K96X@=F%N($E33RXB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M
M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N86%M(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(FYI970@=F%N('1O97!A<W-I;F<B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B3F]G(&YI970@=F%N('1O97!A<W-I
M;F<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP.0IM<V=I9"`B
M;F]T97!A9"(*;7-G<W1R(")N;W1I=&EE8F]E:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E
M<F-E;G0B"FUS9W-T<B`B<')O8V5N="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*
M;7-G<W1R(")296-H="!G97=E:6=E<F0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B
M"FUS9W-T<B`B<&EX96QS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R(")296UO=&4@9F]U="!I;B!P<F]T;V-O;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B
M"FUS9W-T<B`B<W1I:F=E;F0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G
M<W1R(")397)V:6-E(&YI970@8F5S8VAI:V)A87(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G
M<W1R(")T;V]N('9E<G-C:&EL;&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V
M:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@=FEA($A45%`B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S
M<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B<W1A8FEE;"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B<WES=&5E;69O=70B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM
M<V=S='(@(G1A:V5N;&EJ<W0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T
M<B`B=&EJ9&5L:6IK92!M:7-L=6MK:6YG(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")6
M;V5R+"!T97(@8F5V97-T:6=I;F<L(&AE="!W86-H='=O;W)D('1W964@;6%A
M;"!I;B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I960B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(F]N8F5N;V5M9"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B=7-E
M<B!S96QE8W0B"FUS9W-T<B`B1V5B<G5I:V5R<V5L96-T:64B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#
M87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:F%?2E`N<&\`
M````````````````````````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#8W-S<S,@`Q,#4Q-30S,3`V,P`P,38S-S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!*87!A;F5S92!T<F%N<VQA=&EO
M;B!F;W(@2&]R9&4N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE
M8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!(:7)O;6D@2VEM=7)A
M(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N:G`^"B,*;7-G:60@(B(*;7-G<W1R
M("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2XP7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP,3`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`V+3`S+3(R(#$R.C`P*S`Y,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@2&ER;VUI($MI;75R82`\:&ER;VUI0'1A8RYT<W5K=6)A
M+F%C+FIP/EQN(@HB3&%N9W5A9V4M5&5A;3H@2F%P86YE<V4@/'5N:VYO=VY`
M=6YK;F]W;BYD;VUA:6X^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/5-(24947TI)4UQN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,V-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S()/ZD4\I(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("*#08-.@UJ#6(-,@T,@)7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B@6DE<R"3^H+,D^""R8%J
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,`IM<V=I9"`B("AT
M;V1A>2DB"FUS9W-T<B`B("B-H9/Z*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S(*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(H%IEKZ3
M^H%J(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.`IM<V=I9"`B
M("AY97-T97)D87DI(@IM<V=S='(@(B`HC?"3^BDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM
M<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(G)7,G((+-@V:#0H.,@TZ#9X.*@5N"
MQ8+-@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@@LV0LX*U@J*129'P@L6"S8*@@NB"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z-S$P"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@
M@LT@2&]R9&4@@XR#5X-8@V>#BH+)D-V2Z(*S@NJ"Q(*B@MR"N8+Q+B(*"B,Z
M(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(EPB)7-<(B"#8X.*@5N57(ZFBT"47(*JC*F5=(*I@NB"W(*Y@O&!0B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB((*J@T^#BX%;@W:#5H-8@V6#@(+)DL>)P8*S@NJ"W(*U@KV!0B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S
M>7-T96TN(@IM<V=S='(@(EPB)7-<(B""JH-!@TZ#6H-8C*"#5H-8@V6#@(+)
MDL>)P8*S@NJ"W(*U@KTN(@H*(R!M<V=S='(@(B<E<R>"JHN6B<*0W9+H@U:#
M6(-E@X""R9+'B<&"LX+J@MR"M8*]+B(*(SH@861M:6XO9W)O=7!S+G!H<#HU
M-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB
M)7-<(B""S8WLD*R"LX+J@MR"N8+Q@L6"M8*].B`E<RXB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`BEV67
MRB`E,B0N,F9-0B"2AH+,("4Q)"XR9DU"((YGEW`H)3,D+C)F)24I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@@L8@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("*#<(-8@X^!
M6X-H@LV"H(+&("5D()/ZETR,^(+%@K>!0B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y
M(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G
M<W1R("*2RI)M("T@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN
M="(*;7-G<W1R("(E<R"39(YQCG>6Y"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T,"!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T
M<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R"5VX[GD8"-[(+,BFV41B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R
M("(E<R""S)#=DN@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T
M<B`B)7,@@U2#0X.3@T&#8H-V(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E
M;65N="(*;7-G<W1R("(E<R"3KXC3C_"-@"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#,R(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@R(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R""S8KY@LF1MHW=@K6"W(*W@4(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+B(*;7-G<W1R("(B"B(E<R""S8Z?@LF.=Y+H@K."ZH+$@J*"Z97;CN>1
M@(WL@O".P(US@K>"Z8^`E/6"JI"N@J*"W(*U@KV!0H[`C7."M8*]@J*1@(WL
M@LPB"B*#>X-B@TZ#6(+P@V"#1H-B@TZ"M8+$@JV"OH*S@J*!0B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@@JJ52Y=V@L6"MR(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@E:HB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@@JJ"H(+H@MR"N8+Q@4(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S((*I@N<@
M)7.!08V'C'8@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G
M<W1R("(E<R""S(-!@VB#C(-8DJ`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(B5S((+,EUR2Z)5<(@H*(R!M<V=S='(@(B5S@LR#2H.,@Y.#
M7R(*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S((+,@X&#@I*@
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E<R""S(->@UB#
M3H.*@UB#9R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET
M(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN
M:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@
M<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B""L8+,@X&#
M8H-:@5N#5X+-CJ:"LX+J@L2"HH+ID9>038[2@JF"YX+,@N""S(+%@LV"R(*B
M@L:.=H+M@NJ"W(*W@4*"NX+,DH8B"B*"S(.*@Y.#3H+P@TZ#BH-B@TZ"M8*]
M@NB!08S"D&R/[I7Q@O"1EY!-@K>"Z8+,@LV/7)6J@LF2C8C3@K6"Q(FZ@K."
MHH%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S
M=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HW-#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2"1
M29'P("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(
M;W5R($9O<FUA="(*;7-G<W1R("(Q,HZ>BM2,8(ZN(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R
M-(Z>BM2,8(ZN(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G
M:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T((Z>BM0B"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B
M/)%/@LR#>8%;@U<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I
M9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L
M;V-K+B(*;7-G<W1R("*"L8+,@W6#C8-B@TZ"R8+-@V:!6X->@WB!6X-8@JJ5
M2Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S$*
M;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(I)V
MEKV328+(@T>#B8%;@JJ4K9"V@K6"W(*U@KTB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E!'
M4(SVBDJ,KH*J@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`B4$=0C/:*2HRN@JJ/D):\@K."ZH*]@X&#8H-:
M@5N#5X+,C)^/V(+)E4N7=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)01U",]HI*
MC*Z!05!'4)3IEJ>,KH*H@N:"T8-P@UB#=(.,@5N#68*JB,.-AHF[@X&#8H-:
M@5N#5X+,E9R-AH+)E4N7=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R(")01U",]HI*C*Z!05!'
M4)3IEJ>,KH*H@N:"T8-P@UB#=(.,@5N#68*J@X&#8H-:@5N#5X+,CY"6O(+)
ME4N7=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B
M"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB4R]-24U%C/:*2HRN
M@4%3+TU)3464Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JHC#C8:)NX.!@V*#
M6H%;@U>"S)6<C8:"R95+EW:"Q2(*(H*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(E,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9
M@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B4R]-24U%C/:*2HRN@JJ#@8-B@UJ!6X-7@LR(PXV&B;N"R95+EW:"
MQ8*W@4(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@
M(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("*"
ML8+,@T>#9H-"@UZ!6X+)@L*"HH+$(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B
M<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")61E.#9H-"@XR#3H-G@XJ"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(E9&4X-T@T"#0X.+@LR-[)"L@LV#08-.@UJ#6(N1E-N"LX+J@MR"M8*]@4(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!)
M;F9O<FUA=&EO;B(*;7-G<W1R("*#08-*@T6#DX-GC^Z5\2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*
M;7-G<W1R("*#08-*@T6#DX-G@LR#<(-8@X^!6X-H(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B@T&#2H-%@Y.#9X+-DX",BX*S@NJ"
MQ(*B@MR"MX%"(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM
M<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("*#08-*@T6#DX-G(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`BDL>)P2(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B@U2#=8-/@XN!6X-V@O"2QXG!(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES
M<VEO;B(*;7-G<W1R("*#5(-U@T&#3H-:@UB,H(+PDL>)P2(*"B,@;7-G<W1R
M("*#5(-UBY:)PH-T@XF#3X+PDL>)P2(*(SH@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("*"L8*Q@LF2QXG!
M.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(I!6@K6"HH-/@XN!
M6X-V@O"2QXG!(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX
M-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@
M3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`BD%:"M8*B@O"#08-.@UJ#6(R@@O"2
MQXG!(@H*(R!M<V=S='(@(I!6@K6"HHN6B<*#=(.)@T^"\)+'B<$B"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S
M='(@(H-4@W6#3X.+@5N#=H+P(%PB)7-<(B""R9+'B<$B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("*#
M5(-U@T&#3H-:@UB,H(+P(%PB)7-<(B""R9+'B<$B"@HC(&US9W-T<B`B@U2#
M=8N6B<*0W9+H@O`G)7,G@LF2QXG!(@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM
M<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(I!6BTN#AH%;@U6"\)+'
MB<&!1B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`BE_&"\)+'B<$B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!
M9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BD%:+2X.!@Y.#;X+PDL>)P8%&(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A
M:7(B"FUS9W-T<B`B@WF#08+PDL>)P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B5S((.!@VJ#A8%;@O`@
M36]Z:6QL82""S(-4@T.#:(-O@5N"R9+'B<&"MX+I(@H*(R!M<V=S='(@(H-*
M@XR#DX-?@5N"R9+'B<$B"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS
M9W-T<B`B@T&#:(.,@UB2H(+)DL>)P3HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`BCH2"S(+,@T&#:(.,@UB2H(+)DL>)P2(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("*#
MAH%;@U6"\)+'B<$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("(*(B5S+B(*;7-G<W1R("(B"B*#5H-8@V6#@(+)(%PB)7-<(B""\)+'B<&"
MM8+<@K6"O8*J@4&#5(-#@Y.#08-B@W:"S(_NE?&"JI+'B<&"Q8*K@MR"N8+Q
M@L6"M2(*(H*]@48E<R(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B@U:#6(-E@X""R2!<(B5S7"(@@O"2QXG!
M@K6"W(*U@KV"S(+%@4&#C8-/@T.#DX+%@JN"W(*W@4(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*#AH%;@U6"S)+'B<&/B)>=@LV6LXSX
M@LF"R(+!@L2"HH+<@K>!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,X
M"FUS9VED(")!9&1R97-S(@IM<V=S='(@(H]:CXHB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`B@T&#:(.,@UB2H"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C4V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("**QY>=("T@D;R"S(.&@5N#58+,
M@T&#3H-:@UB,H"(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("**QY>=(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,PIM<V=I9"`B061S(@IM<V=S='(@(D%D<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%F9VAA;FES=&%N(@IM<V=S='(@(H-!@W2#2X-J@UB#7H.3(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R("*#08.+@V^#:H-!(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("*#08.+@U>#1H.*@T$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W
M"FUS9VED(")!;&EA<R(*;7-G<W1R("*5RI:\(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI
M9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("*(RI)U
MD;6"IH%&(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!
M;&PB"FUS9W-T<B`BD5.5E"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@
M(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(I%3E$:/V(.&@5N#
M52(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR
M,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`BD5."Q(+,@T^#BX%;@W8B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R
M:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M
M:7-S:6]N<R(*;7-G<W1R("*14X+$@LR#08-.@UJ#6(R@(@H*(R!M<V=S='(@
M(I%3@L2"S(N6B<*0W9+H(@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8X"FUS
M9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`BE:&0E(+,
M@T&#:(.,@UB"\(N6B<(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X
M"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*
M;7-G<W1R("*4U(V&E72"JX.*@UB#9X+PD-V2Z(+%@JN"Z8+F@J2"R8*U@MR"
MMX*I@4@B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(HKY@LF1MHW=
M@K6"W(*W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`BD>.1UH+,($E-4U`@@XV#
M3X-#@Y,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!
M;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("*1XY'6@LP@24U34""#
M<(-8@X^!6X-H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I
M9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`BD>.1UH+,($E-
M4U`@@X:!6X-5EKPB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BD>.1
MUH+,@X&!6X.+@T&#:(.,@U@B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("*1XY'6@LR#
M98.3@W:#C(%;@V<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT
M.B(*;7-G<W1R("*1XY'6@V6#3(-8@V>!1B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(H-!@X&#BH-*E\R#5(."@T$B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N(@IM<V=S='(@(I5SD+."R))L@JJ.=Y+H@K."ZH+$
M@J*"W(*W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM
M<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B
MEUR*^H*U@LB"HH-'@XF!6X*JE*V0MH*U@MR"M8*](@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B06YD;W)R82(*;7-G<W1R("*#08.3@VB#B2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N9V]L82(*;7-G<W1R("*#08.3@U.#B8NDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(H-!@Y.#3X-"@XDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N
M>6UO=7,@4')O>'DB"FUS9W-T<B`BD[V6O(-V@XV#3(-6@5LB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S
M='(@(I.:@J8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S
M='(@(I/LB\F!:9'EEZ2!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@
M86YD($)A<F)U9&$B"FUS9W-T<B`B@T&#DX-E@T*#3X-!@46#;X%;@W6!6X-?
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A
M=&EO;B(*;7-G<W1R("*#08-V@XJ#4(%;@U:#AX.3(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S
M='(@(H-!@W:#BH-0@5N#5H.'@Y.(ZI>7(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S
M='(@(H-!@W:#BH-0@5N#5H.'@Y..9Y=PB<(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S
M(@IM<V=S='(@(HFZB,J"S(NDETR"R9-+EW`B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R
M("*/LY1&(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#0P"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(H*H@JB"YH*[
M@LR#5(-#@UDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B@E.,CB(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U
M-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*
M;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(H-!@5N#2H-#@W6#
M=(-`@T.#BX-4@T.#62(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W
M"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B@T&!6X-*@T.#=9:\(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(E
M<R""S(-4@T.#DX-!@V*#=I=VBX&"\)9[DY:"R8WMCYR"M8+$@J*"HH+%@K>"
MJ8%((@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("*6
M>Y.6@LD@7"(E<UPB((+&@U2#=8-/@XN!6X-VD5."Q(+PC>V/G(*U@L2"HH*B
M@L6"MX*I/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M("*#08.+@UN#DX-@@Y.+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE
M;FEA(@IM<V=S='(@(H-!@XN#@8-J@T&+I)AAC9$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!
M<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T
M<B`B@T&#BX-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM
M<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("*#08-:@Y.#5H.'@Y.3
MAR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("*#08-7
M@T&!7I&^E;V7;9)NB.8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y
M"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BE=N.YXWLB\:"S([`C7.1
M3X+)BFV41H+PBX&"WX+I@N:"I(+)@K6"W(*W@JF!2"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,P.3(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T
M<B`BD;:-W8*U@LB"HH-/@XN!6X-V@O"-[8^<@K6"YH*D@L:"M8+<@K6"O8%"
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`BD;:-W8*U@LB"HH-!@TZ#6H-8C*""\(WMCYR"M8+F@J2"QH*U@MR"M8*]
M@4(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(I&VC=V"M8+(@J*#08-.@UJ#6(R@@O"5TH]7@K6"YH*D@L:"M8+<@K6"O8%"
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(I&V
MC=V"M8+(@J*+I)=,@O"5TH]7@K6"YH*D@L:"M8+<@K6"O8%"(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`BD:Z0JR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B@E>,CB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("*#28%;@UB#9X.)@XJ#
M02(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B@TF!6X-8
M@V>#BH-!BZ2888V1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ()5+EW:"
MR$E-05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*
M;7-G<W1R(")!=71H7V-Y<G5S.B"#;X-B@TZ#1X.3@VB"S95+EW:"R)1<E\V"
M\)=,@K6"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@EW:+
M@8*W@NEI;6%PBF>2HX*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E
M<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W
M:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!
M=71H7V9T<#H@1E10BF>2HXM`E%R"JH+=@L*"J8+H@MR"N8+Q+B!02%""\"`M
M+65N86)L92UF='`@@TF#=H-6@X>#DX+P@L*"KX+$(@HB@U*#DX-P@T.#BX*U
M@LB"J(*U@L2"K8*^@K."HH%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@24U!4(IG
MDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@
M:W)B-8IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y((+%@LR#
MAH%;@U62QXG!@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GD@
M@L6"S(.&@5N#58WMCYR"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O$B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]L9&%P.B!,1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U
M=&A?;&1A<#H@@X:!6X-5("5S((+PDL>)P8+%@JN"W(*Y@O&!0H-4@5N#;X+,
MB9Z3FCH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B"#AH%;@U4@)7,@@O"-
M[8^<@L6"JX+<@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@@X:!6X-5
M("5S((+PC5B05H+%@JN"W(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G
M<W1R(")!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GD@@L6"S(.&@5N#58U8
MD%:"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L
M.B!-0T%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7W-M8F%U=&@Z('-M8F%U=&B*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("))34%0@U2!6X-O@L6"S)1&C]B"R8ZXE'."M8+<@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BE$:/
MV(+)CKB4<X*U@MR"M8*](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("*41H_8@LF.N)1S
M@K6"W(*U@KV!0B5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N
M<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BXB"FUS9W-T<B`B4D%$2553@U2!6X-O@LF"YH+HE$:/V(*J
MBY&4VX*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#@R"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B1E10@U2!6X-O@LR41H_8@LF.N)1S@K6"W(*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B4TU"@U2!6X-O@LR41H_8@LF.N)1S@K6"W(*U@KV!0B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L
M9',Z(@IM<V=S='(@(HYGEW")PI1<@LB#=(-"@5N#BX-H@48B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(H-!@UN#BX-O@T.#5X.#
M@Y.+I)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(I1WC&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(I1WC&F01B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B
M2V5R;V)E<F]S((-P@UB#CX%;@VB"JI:SC/B"Q8*W@4(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@
M=7-E<FYA;64N(@IM<V=S='(@(DME<F]B97)O<R"#AH%;@U66O(*JEK.,^(+%
M@K>!0B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B@V^#
M;H-](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("*#;X%;
M@XR!6X.3(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A
M;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)A;F=L861E<V@B"FUS9W-T<B`B@V^#DX-/@XF#9H-6@X60;):OBZ28
M88V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B@V^#
MBX-O@VB#6"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("**[I9[@T^#B8-T@T*#3H-8@LR#9H-"@XR#
M3H-G@XJ!6R!<(B5S7"(@@JJ"H(+H@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A
M<V5L:6YE(@IM<V=S='(@(HKNCX"0_"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&%R=7,B"FUS9W-T<B`B@WB#B8.+@5N#5HNDF&&-D2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B@WB#BX--@5LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")"96QI>F4B"FUS9W-T<B`B@WB#BH%;@UDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"96YI;B(*;7-G<W1R("*#>(-I@Y.+I)AAC9$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(H-O@WZ#A8%;@U^!:8^4DX>!
M:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("*#=8%;@UZ#
MDXFDC9$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("*289"VD_HB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*#=8.-@V*#3B!<(B5S7"(@@LR#
M08-V@XJ#4(%;@U:#AX.3(%PB)7-<(B""JH*@@NB"W(*Y@O&!0B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T
M=&EN9W,B"FUS9W-T<B`B@W6#C8-B@TZ0W9+H(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(H-U@XV#8H-.@UZ#0X-V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(I&^CIHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(H-[@XJ#<H-!BZ28
M88V1(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B
M0F]O:VUA<FMS(@IM<V=S='(@(H-U@V*#3H-]@5N#3B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@
M(D)O<F1E<B(*;7-G<W1R("*)CR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z
M(@IM<V=S='(@(HF/@LR1OH*S@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM
M<V=S='(@(HF/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z
M96=O=FEN82(*;7-G<W1R("*#>X-8@VJ#08%%@W>#BX-C@T:#4X-R@VDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B@WN#
M8X./@VF+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(H-U@5N#
M>).'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(H-U@XF#
M5X.+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>2(*;7-G<W1R("*)<)?,@T.#DX-HCY23AR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(H-U@XN#;(-#
M@46#7X.+@U2#B8%;@X`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*
M;7-G<W1R("*#=8.+@TN#BH-!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R("*)TX_PCY&"JR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S
M;R(*;7-G<W1R("*#=8.+@TR#:8-T@T"#7"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U<G5N9&DB"FUS9W-T<B`B@W6#BX.3@U>+I)AAC9$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM
M<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<R(*;7-G<W1R(")#4DP@E'J5>H-\@T.#DX-G(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED
M(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]%@UJ#BY&ND*LN+BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("*#3(.#@V*#
M5H.%@LR/B8KZB;N"JHJNE[F"M8+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,38@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`T,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R("*77)+HE5PB"@HC(&US9W-T<B`B@TJ#C(.3@U^!6R(*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS
M9W-T<B`B@TJ#DX-[@U>#02(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N
M(@IM<V=S='(@(H-*@X&#BX%;@Y.+I)AAC9$B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B@W"#6(./@5N#:(+-CJF3KH+%@LV#BH-:@V*#9X+%@JN"W(*Y
M@O&!0HK'EYV.TH+)F$&7C8*U@L2)NH*S@J*!0B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@
M;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(H-T@T"#0X.+(%PB
M)7-<(B""R8^1@J^"W(*Y@O&!0B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R("**3Y64@LR#6H-B@U:#AX.3@VZ#DX-H@XF!6X+-
MBL>7G8+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S(@IM<V=S='(@(DE-05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"
M\8+%@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B@W2#0(-#@XL@7"(E<UPB((*JBDJ"KX+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(H-*@VF#7R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(H-,@X.#DX-:
M@XLB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I
M9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(H_ABE&5\8V0@O"#
M3(.#@Y.#6H.+@K>"Z2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(H-T@T"#0X.+(%PB)7-<(B""\(WMCYR"Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R("*-[(O&@V:#0H.,@TZ#9X.*@JJ,J95T@JF"Z(+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+B(*;7-G<W1R("(G=&%R9V5T1FEL92<@@W"#B8.!@5N#
M7H+(@K6"Q8+-D;&-<X+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B@V:#0H.,@TZ#9X.*
M@5L@7"(E<UPB((+PC>V/G(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`BC>V/G(+%
M@JN"W(*Y@O&!0HYQD;>"JB`E9""1MHW=@K6"W(*W@4(B"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G
M<W1R("(B"B*5P(+7D=:"IH+,D<Z/VX+,D)2"JI7;D;:"LX+J@L2"HH+ID)2"
MQHV'@NV"R(*B@LR"Q97`@M>1UH*F@JJ"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G
M:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M(@IM<V=S='(@(HYWDNB"LX+J@KV4U(V&@LF#@8-B@UJ!6X-7@O"4>I&7@L6"
MJX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D
M92(*;7-G<W1R("*#2H%;@WR#>(.+@V:+I)AAC9$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#
M87!T:6]N(@IM<V=S='(@(I5<D>@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`B@TR#@X.*@T$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G
M:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("*5JI?>@L:#B8-X
M@XLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T
M<B`B@U"#0X-]@Y./E).'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("*,
M9Y'1DV288B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R
M("*#6H.+D:Z0JR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(H-:
M@XN6A)&0@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T
M<B`B@UJ#BY&ND*LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("*#
M6H.+EUV4DH%&(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W,0IM
M<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(HQGD=&39)AB(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("*2AHF;
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(I*&B9N#08-T@XJ#2HNDF&&-D2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("*/V):^CY&"S(_:C=<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
MC]B6OH^1@LR/BI=,CM(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T
M<B`BC]B6OH^1@WR#BH-6@5LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B
M"FUS9W-T<B`B@V"#@X-HBZ2888V1(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM
M<V=I9"`B0VAA;F=E(@IM<V=S='(@(I7/C5@B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(H-P@UB#CX%;@VB"\)7/C5@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("*39(YQ@X&#0X.+@LF.9Y=P
M@K>"Z9:\D4^"QH-!@VB#C(-8@O"5SXU8@K6"W(*W@4(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO
M=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT
M(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HBC+N-W8+,D-V2Z(+%@LV#<(-8@X^!6X-H@LR5SXU8
M@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"BL>7G8[2@LF809>-@K6"Q(FZ@K,B
M"B*"HH%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E]+@XJ#DX-.@O"#8(-&
M@V*#3BXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(H-@
M@XJ+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("*2
MAHG8D&R6KXNDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS
M9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T
M<B`B@T&#=H.*@U"!6X-6@X>#DY%)D?"!1B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D
M(@IM<V=S='(@(H-P@UB#CX%;@VB"\)%)D?`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M
M92(*;7-G<W1R("*#AH%;@U66O(+PD4F1\"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SHB"FUS9W-T<B`BD_J5=)5<CJ:,8(ZN@48B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*
M;7-G<W1R("*#3H.*@UB#?8-8DX<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("*#3H.)@UB2Z(M@("5S((*JC*F5=(*I@NB"W(*Y@O&!0B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS
M9VED(")#;&5A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(DU3+4]F9FEC98+,@UZ#3X+PCN:"Z(^<@JTB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G
M<W1R("*,GXWUC\&+CB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E
M<R(*;7-G<W1R("*#AH%;@U6"S)'>BXZ!1B5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S
M='(@(H.&@5N#58_!BXXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(H.&@5N#
M58-F@5N#7H_!BXXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B@TZ#BH-B@TZ"MX+I
M@L:.GX+6(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S
M='(@(H-%@T*#DX-H@T6"\)7"@K:"Z2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(H-2@U*#6(^4DX<B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC
M.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(H-4@T.#:(-O
M@5N"\(_T@MXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("*#
M4H.-@Y.#<H-!BZ2888V1(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(I!&(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,S-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S,V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,#,@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I
M9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(I!&D4F1\"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,C4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB
M"FUS9W-T<B`BD$:129'P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(I?Q@48B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30S"FUS9VED(")#;VQU
M;6X@=&ET;&5S(@IM<V=S='(@(I?Q@UZ#0X-G@XLB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B@U*#
M?H-B@TZ#6"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R("*#4H-]@Y.#:"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("*#4H-]@Y.#:(-6
M@T:#BR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B0V]M;65N="(*;7-G<W1R("*#4H.!@Y.#9R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M
M92(*;7-G<W1R("*+I)+*EKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O
M<R(*;7-G<W1R("*#4H."@XV808V'(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R
M("*)[X[0(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#
M;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(I#=DNB"S(VWE:HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN(@IM<V=S='(@(E!$08%!@UB#?8%;@V>#=(-(@Y.!04]U=&QO;VN"
MQH+,DZ^*^H+PD-V2Z(*U@MR"MX%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB
M"FUS9W-T<B`BD-V2Z(+-C]R6H8KZC,"0V(+J@L6"MX%"(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`B)7,@@O"0W9+H@K>"Z2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S
M<W=O<F0B"FUS9W-T<B`B@W"#6(./@5N#:(+PBFV41B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O;F=O(@IM<V=S='(@(H-2@Y.#4XNDF&&-D2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T
M:&4B"FUS9W-T<B`B@U*#DX-3EJ^.Y8NDF&&-D2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D+B(*;7-G<W1R("*0VI&QCKB4<X%"(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960Z("(*;7-G<W1R("*0VI&QCKB4<X%&(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(HSVCT^,KH-4
M@5N#;X+6@LR0VI&Q@JJ+D93;@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(HSVBDJ,KH-4@5N#;X+6@LR0VI&Q
M@JJ+D93;@K."ZH+<@K6"O8%"EYV74H%&)7,@*"5S*2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%"#5(%;@V^"UH+,D-J1L8+)
MCKB4<X*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`BF$&7C9#F(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
MF$&7C9#F@LV#08-H@XR#6)*@@LF2QXG!@K."ZH+<@K6"O8%"(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N
M=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(HBSCVN#
M=(-`@T.#BX+,@U*#DX-E@Y.#8X->@T.#=H%&(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@
M;V8@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B""S)/@EV4B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(I&Q@JTB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B@TZ#8H-.CY23
MAR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R("*#4H-S
M@5LB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B@U*#<X%;
MCKB4<X%&)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("*129'P
ME,V(S8+P@U*#<X%;(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("*#4H-8@UZ#BH-*BZ2888V1
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("*#
M4H%;@V>#5X-[@X^!6X.+BZ2888V1(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G93H@(@IM<V=S='(@(H.!@V*#6H%;@U>"S"!01U`@B,.-AHF[@JJ"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@(@IM<V=S='(@(H.!@V*#6H%;@U>"S"!01U`@CY"6O(*J@L6"JX+<@KF"
M\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E
M+B(*;7-G<W1R("*#@8-B@UJ!6X-7@LP@4R]-24U%((C#C8:)NX*J@L6"JX+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+B(*;7-G<W1R("*#@8-B@UJ!6X-7@LP@4R]-24U%((^0EKR"JH+%@JN"W(*Y
M@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`BF$&7C9#F@O"2QXG!@L6"JX+<
M@KF"\8+%@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@@U2!6X-O@LF#;X-#
M@Y.#:(+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B
MCF.-@H*JBFV41H+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@@U2!6X-O@LF0VI&Q@L6"JX+<
M@KF"\8+%@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")&5%`@@L6#5(%;@V\@
M7"(E<UPB((+)D-J1L8+%@JN"W(*Y@O&"Q8*U@KTZ("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`BD9>039#F@XJ#6(-G@JJ-[)"L@L6"JX+<@KF"
M\8+%@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM
M<V=S='(@(E!'4""#9H%;@UZ"S)6<C8:)NX*J@L6"JX+<@KF"\8+%@K6"O3HB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I
M9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(E,O
M34E-12"#9H%;@UZ"S)6<C8:)NX*J@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<R(*;7-G<W1R("*809>-D.:"JHWMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(I&7D$V0YH.*@UB#9X*J
MC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(I#=
MDNB-6)!6EW"#6(-.@XJ#=H-G(%PB)7-<(B""\(WMCYR"Q8*K@MR"N8+Q@L6"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X
M,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("*.\Y!-CM*"S)-DCG&#@8%;@XN#08-H@XR#6(*JBFV2
MZ(+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("*#08-H@XR#6)*@
M@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("*1EY!-D.:#BH-8@V>"JHJND5."R8+-CN:3OH+%@JN"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("*1EY!-
MD.:#BH-8@V>"JHJND5."R8+-CN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G
M<W1R("*#6(-G@XF#98-7@5L@7"(E<UPB((+P@XV!6X-H@L6"JX+<@KF"\8+%
M@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I
M<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B36MD:7(@7"(E<UPB((+)CKB4<X*U@MR"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*
M;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N(@IM<V=S='(@(HSVBDJ,KH+PC*Z#5(%;@V^"J8+GCN:3OH+%
M@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W
M<FET:6YG+B(*;7-G<W1R(")<(B5S7"(@@O"/D8*KC9Z"W9=P@LF#28%;@W:#
MDX+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B)7,@@O"#28%;@W:#DX+%
M@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@
M(I7;CN>-[(O&@X*#5X.%@5N#BR`E<R""\(I*@J^"W(*Y@O&"Q8*U@KV!0B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*#9H-"
M@XR#3H-G@XJ!6R!<(B5S7"(@@JJ*2H*O@MR"N8+Q@L6"M8*]@4(B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@@U2!6X-O@LF0VI&Q@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(B5S((*JD\>"W8]O@KF"W(*Y@O&!0B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE
M('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL
M(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*
M(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HBEW:+@8*S@NJ"O8.&@5N#58+,
M@W"#6(./@5N#:(+P@XJ#6H-B@V>"Q8*K@MR"N8+Q@L6"M8*]@4*"HH*M@L*"
MJ8*@@NF"HH+-D5."Q"(*(H+,C^Z5\8+-BM2(X8+!@L2"HH+<@K>!0HW$DWB.
MCH*U@L2"W8+I@JF*QY>=CM*"R9A!EXV"M8+$B;J"LX*B@4(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,(@IM<V=S='(@(D%#3"""\([FD[Z"Q8*K@MR"N8+Q@L6"
MM8*](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B@T&#:(.,@UB2H(+PCN:3
MOH+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("*1EY!-D.:#BH-8@V>"\([FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(I&7D$V0YH.*@UB#
M9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B@U2!6X-O@LR+
M0)1<B.J7EX+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KTB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(I#=DNB"\(RS@LF6WX*Y@MR"N8+Q@L6"M8*]
M@4(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB((-F
M@T*#C(-.@V>#BH%;@JJ-[8^<@L6"JX+<@KF"\8%"(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@D-V2Z(+P
ME=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("*0
MW9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R("*0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"Q8*K@MR"N8+Q@L6"
MM8*]@48E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(I#=DNB-6)!6EW"#6(-.@XJ#
M=H-G@O`@7"(E<UPB((+)E=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(I#=DNB"S(-O@V*#3H-!@V*#=H-T@T"#0X.+("5S((+P
ME=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A
M=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@
M=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A
M8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E
M<RXB"FUS9W-T<B`B(@HBD-V2Z(-T@T"#0X.+("5S((+)E=N1MH+%@JN"W(*Y
M@O&"Q8*U@KV!0B5S((+)EM^"P8+$E=N1MH-)@W:#5H.'@Y."\([`C7."MX+I
M(@HB@JF!08[H@L6"L8+,B>:6RH+,@U*!6X-H@O`@)7,@@LF#4H-S@5N"M8+$
MB;J"LX*B@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T
M,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DQ$05`@@U2!6X-O@JJ,GXWU@L6"JX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@@O"-[8^<*'5N;&EN
M:RF"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(IA!EXV0
MYH+PC5B05H+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`BD9>039#F@XJ#6(-G@O"-6)!6@L6"JX+<@KF"\8+%@K6"
MO8%")7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B7"(E<UPB((+,D-V2Z(*JCY&"JXV>@M^"
MW(*Y@O&!1B5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I
M9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U
M<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B36]Z:6QL82""S(-4
M@T.#:(-O@5N"JHRIE72"J8+H@MR"N8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)
MNH*S@J*!0B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E
M('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30Q-@IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED
M(")#;W5N=')Y(@IM<V=S='(@(HV1(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("*-[)"L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED
M(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O
M;F4B"FUS9W-T<B`BD%:+2XWLD*PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(H-4@W6#=(-(@XN#7X+PC>R0K"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(HWLD*R.TH+,@T&#3H-:@UB,H"(*"B,@;7-G<W1R("*-[)"L
MCM*"S)7;C.R0W9+H(@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C`Y
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B@TZ#C(-7@V*#
M9X-*@5N#:)34C88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G
M<W1R("*#3H.-@T&#8(-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B
M82(*;7-G<W1R("*#3(.%@5N#;XNDF&&-D2(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO
M;G,B"FUS9W-T<B`BC+N-W8+,@UJ#8H-6@X>#DR(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N
M="!4:6UE(@IM<V=S='(@(HR[C=V"S(Z>BM0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U
M<G)E;G0@55),(&ES(@IM<V=S='(@(HR[C=V"S"!54DP@@LTB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T
M<B`BC+N-W8+,@X:!6X-5@5LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD
M:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+B(*;7-G<W1R("(E<R""UH+,@XV#3X-)@Y..GH+)CL"-<X*W@NF#
M7H-8@TZ"\)#=DNB"M8+<@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(I#8@NB.YH+H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("*1
M29'PE,V(S8+PD-B"Z([F@N@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B
M"FUS9W-T<B`B@TR#=H.-@UB+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS
M9W-T<B`B@V"#1H-2BZ2888V1(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B1$0B"FUS9W-T<B`BD_HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C8Y"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP
M:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(I:(D_HB"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`B1&%T851R964@B7N7ER(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R-C<*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R
M("*#9H%;@UZ#>(%;@UB.48_&(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,SDU"FUS9VED(")$871E(@IM<V=S='(@(I/ZE70B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E
M9"(*;7-G<W1R("*#9H%;@UZ.\Y!-(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<X-@IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BD_J5
M=)%)D?`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@
M(E],E_&"S(WMCYPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B,3*,CB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("*/7)!ID)0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P
M"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`BDFF)NH*P@O"0\X*M
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R
M969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B@V:#=(-(@XN#
M9R(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(H-F@W2#2(.+@V>0
M1B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B@V:#=(-(@XN#9R!)1"(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3
M:&5L;"(*;7-G<W1R("*#9H-T@TB#BX-G('-H96QL(@H*(R!M<V=S='(@(H-F
M@W2#2(.+@V>+EHG"D-V2Z"(*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S
M"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`BC>V/G"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T
M<B`B@UJ#BXWMCYPB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(H-/
M@XN!6X-V@O"-[8^<(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(H.-@T^"S(WMCYPB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO
M;B(*;7-G<W1R("*#08-.@UJ#6(R@@O"-[8^<(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E
M(&-E;&PB"FUS9W-T<B`B@UJ#BXWMCYPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@
M8V]L=6UN(@IM<V=S='(@(I?Q@LR-[8^<(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`BD>.1UH-E@Y.#=H.,@5N#9X+,C>V/G"(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4T"FUS9VED(")$
M96QE=&4@;65S<V%G97,B"FUS9W-T<B`B@X&#8H-:@5N#5X+PC>V/G"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(EPB)7-<(B""S(-!@TZ#6H-8C*""\(WMCYPB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\B"FUS9W-T<B`B7"(E<UPB((+,@T&#3H-:@UB,H(+&@KN"S(-4
M@W6#08-.@UJ#6(R@@O"14X+$C>V/G(*U@MR"MX*I@4@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@<F]W(@IM<V=S='(@(HUS@LR-[8^<(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E
M;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(I%)D?""M8*]242"\(WMCYPB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I
M9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(H-4@W6#=(-(@XN#7X+P
MC>V/G"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;B(*;7-G<W1R("*,NXW=B,J2=8+,E_&"\(WMCYPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BC+N-W8C*DG6"S(US
M@O"-[8^<(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(I#=DNB-6)!6EW"#6(-.@XJ#=H-G(%PB)7-<(B""
M\(WMCYR"M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R("*4>I&7CIZ*U"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1E;FUA<FLB"FUS9W-T<B`B@V:#DX-]@5N#3B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R("*/X8I1D^"798+,D."6OB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDS-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M("*0X):^(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#8*;7-G
M:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T
M<B`BC]J-UX%I2&]R9&6"S(.-@T^#=(-`@T.#BX+@CE&/QH%J@48B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q,`IM<V=I9"`B1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`BC]J-UX+-BL>7G8[2@LR"O8+?@LF+3)A>@K."ZH+<@K6"O8%"(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE
M;G0B"FUS9W-T<B`BBDJ4K2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T
M"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`BC;:"J8+GB46"UB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@
M(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(HE%@JF"YXVV@M8B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G
M:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B,C2.GHK4E5R.
MIB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R("*57(ZF@TF#=H-6@X>#DR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.38*;7-G:60@(D1I
M<W!L87D@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G
M<W1R("*#5X-U@V"+I)AAC9$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("*-[8^<
M@K6"R(*B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED
M(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G
M<W1R(")M86EN=&5N86YC92YP:'`@@LF2O)#:@T&#3H-:@UB"M8+(@J*"Q8*M
M@KZ"LX*B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I
M<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C
M:R!T:&ES(&)O>#HB"FUS9W-T<B`BC<6/B8+,E_&"JH-T@T*!6X.+@VB6O(+P
MBMR"\8+%@J*"W(*W@JD_((*[@J2"R(+G@V"#1H-B@TZ"M8+$@JV"OH*S@J*!
M1B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(H-H@WZ#
M:H-*(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(H-H@WZ#:H-*BZ2888V1(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(*;7-G<W1R("*#08-*@T6#DX-G@JJ52Y=V@LB"YX-4@T.#DX-!@V*#
M=H%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q
M"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("*#7X-%@Y.#C8%;@V@B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B)7,@@LR#7X-%@Y.#
MC8%;@V@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+B(*;7-G<W1R("*0MI"L@K."ZH*]D-V2Z(+P(%!(4""#6(-.@XJ#=H-G@O""
MQH*U@L2#7X-%@Y.#C8%;@VB"MX+I@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3`T"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(I-DCG&#@8%;@XLB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%8W5A9&]R(@IM<V=S='(@(H-'@TZ#08-H@XN+I)AAC9$B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`BE=*/
M5R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@
M(D5D:70@0FQO8VLB"FUS9W-T<B`B@W6#C8-B@TZ"S)72CU<B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B
M161I="!'<F]U<"(*;7-G<W1R("*#3X.+@5N#=H+,E=*/5R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R
M("*#08-.@UJ#6(R@@LR5TH]7(@H*(R!M<V=S='(@(HN6B<*0W9+H@LR5TH]7
M(@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(H-!@TZ#6H-8C*""S)72CU<B"@HC(&US
M9W-T<B`BBY:)PI#=DNB"S)72CU<B"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B)7,@@LR#08-.@UJ#6(R@@LR5TH]7(@H*(R!M
M<V=S='(@(B5S((+,BY:)PI#=DNB"S)72CU<B"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(H-)@W:#5H.'@Y."S)72CU>!1B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@@LR#08-.@UJ#6(R@
M@LR5TH]7(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("(E<R""S(-!@TZ#6H-8C*""S)72CU<B"@HC(&US9W-T<B`B)7,@@LR+
MEHG"D-V2Z(+,E=*/5R(*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS
M9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16=Y<'0B"FUS9W-T<B`B@T>#5X-V@V>!18-!@XF#=8NDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B@T>#BX-4@XN#
M;X-H@XN+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@V-@IM<V=I9"`B16UA:6PB"FUS9W-T<B`BDV2.<8.!@5N#BR(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")%@X&!6X.+@T&#:(.,@U@B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38P"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`B18.!@5N#BX-!@VB#C(-8@JJ(ZI)V@K6"R(*O@NJ"SH*B
M@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#8*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D6#@8%;
M@XN#08-H@XR#6(IME$8B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM
M<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`BB_.#@8-B@UJ!6X-7@L6"
MMX%"(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("*)O8+@C*F"
MPH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("*+
M\X+,C)^-]8SJ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B@TV#@X.)@XJ!6X*I@N>)YI&<@O"1
M?9/\@L6"JX+I@N:"I(+)@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_(@IM<V=S='(@(HE%@TZ#BH-B@TZ"Q8.!@VJ#A8%;@O"57(ZF@K6"
MW(*W@JF!2"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#4@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,`IM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B@T>#9H-"
M@UZ!6XGFELJ"\)'E@JN"K2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B
M"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.B(*;7-G<W1R("(B"B*"H(+(@KV"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G
M@K>"Z8Z>@LR7<)!3@LR"O8+?@LR.OY;B@O"3_)?-@4*7X8*F@LZ!08%U@WF#
M8H-G(@HB@LR6O)%/@LV!2(%V@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R
M('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("*)YI&<@LQ54DR"\)/\E\TB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR
M"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B
MD-23N8--@VJ#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B
M"FUS9W-T<B`B@T>#BH-G@XJ#02(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B@T>#B8%;(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(H-U@XV#
M8H-.C>R0K(-'@XF!6SH@)7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("*3KXKZ@XV#3X+,C>V/G(-'
M@XF!6SH@)7,N(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT
M96YT.B`E<R(*;7-G<W1R("*3X)=ECN:3OH-'@XF!6SH@)7,N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("*#<(-8
M@X^!6X-HC5B05H-'@XF!6SH@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H
M(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(H.!@5N#BX-!@VB#C(-8@LR#1X.)
M@5N"Q8*W@4(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@@LR/D8*KC9Z"W8-'@XF!6X+%@K>!0B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5S=&]N:6$B"FUS9W-T<B`B@T>#6(-G@VJ#08NDF&&-D2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(H-'@V"#28-S@T$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D5U<F]P92(*;7-G<W1R("*#B(%;@XV#8H-P(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R
M("(Q-96JEH@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED
M(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B,I6JEH@B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B,S"5JI:((@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-96JEH@B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P
M"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("*#C8-/@T.#DY:((@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H
M;W5R(@IM<V=S='(@(C,PE:J6B"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(C&5JI:((@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("*.
M=Y+HDFR"S)?A(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@R(&%D;6EN+V-M
M9'-H96QL+G!H<#HU,2!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")%
M>&5C=71E(@IM<V=S='(@(H[`C7,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S
M='(@(I-7BDHB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("*#5(-#@VB#;X%;@O"3
M5XI*(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM
M<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B<I)R""\)-7BDHB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(I=,C/B*^HS`(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N
M96YT(@IM<V=S='(@(HYWD)0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R("*13XQID$8B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS
M9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(I#=DNB"\"!&5%`@
M@L6#08-B@W:#C8%;@VB"MX+I(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-Q;"YP:'`Z,C(P"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RXB"FUS9W-T<B`B@W:#C(-T@T"#C(.3@UB0W9+H@O".YI.^@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("),1$%0((-4
M@5N#;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B4TU"((-4@5N#;X+)D-J1L8+%@JN"
MW(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S$W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@
M7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@@JF"YX+,@U*#<X%;@LF.N)1S@K6"
MW(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(R"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB
M"FUS9W-T<B`B7"(E<UPB((+6@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("*0
M5HM+@LP@4T%33""0VI&Q@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O
M(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB((+6@LR(VI.N@LF.N)1S@K6"W(*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8U"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T
M<B`BCN:3OH+)CKB4<X*U@MR"M8*]@48E<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I
M;F%S*2(*;7-G<W1R("*#=(-(@5N#3H.)@Y.#:(^4DX>!:8-]@XN#<H-I@UB/
ME).'@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S
M='(@(H-T@T:#C8%;CY23AR(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("*2=I:]DTF#1X.)@5N!
M1B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&05@B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&05@B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I
M9"`B1F5B<G5A<GDB"FUS9W-T<B`B@E&,CB(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI
M:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G
M:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DT,0IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C(*;7-G:60@
M(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,C8*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B@W2#0H-7@5N/E).'
MBZ2888V1(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS
M9VED(")&:6QE(@IM<V=S='(@(H-T@T"#0X.+(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL92(*;7-G<W1R("*#=(-`@T.#BY"4.B`E<R"#=(-`@T.#BR(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(H-T@T"#0X.+
MD)0Z("5S((-T@T"#0X.+(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(H-T@T"#0X.+@WV#
M;(%;@U>#@R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED
M(")&:6QE($YA;64B"FUS9W-T<B`B@W2#0(-#@XN6O"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y-S0*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM
M<V=S='(@(H-T@T"#0X.+D4F1\"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T.#,*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(H-T@T"#0X.+
M@T&#8H-V@XV!6X-H(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B@W2#0(-#@XN#08-B@W:#C8%;@VB"S8-4@WR!6X-G@K."ZH+$@J*"
MW(*Y@O&!0B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I
M9"`B1FEL=&5R<R(*;7-G<W1R("*#=(-"@XN#7B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(D9I;FQA;F0B"FUS9W-T<B`B@W2#0H.3@XF#DX-HBZ2888V1(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(H_CC+>"
MS(R.(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@
M(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R
M("*#=(-(@XN#7X%;("5S((*J@J""Z(+<@KF"\2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`BE;:.FI!&(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T
M<B`BB>:1G(+P@U2#?(%;@V>"M8+(@J*#=8.)@T6#59=P(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I
M9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F
M;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM
M<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(H-P@UB#CX%;
M@VB"\)99@NJ"Q(*U@MR"HH+<@K6"O8*I@4@B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("*#=(-(@5N#
M@"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G
M:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED
M(")&;W)U;7,B"FUS9W-T<B`B@W2#2(%;@XF#@"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*
M;7-G:60@(D9R(@IM<V=S='(@(HO@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM
M<V=S='(@(IAG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@
M(H-T@XF#DX-8BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("*#
M=(.)@Y.#6(%IEGN-D8%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U
M:6%N82(*;7-G<W1R("*#=(.)@Y.#6)?,@TV#08-I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B@W2#B8.3@UB7S(-\
M@XJ#;(-6@T$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R
M;B!497)R:71O<FEE<R(*;7-G<W1R("*#=(.)@Y.#6)?,B\F3[(^4DX<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS
M9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BC]J"
MM8*BD."6OB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`BEIZ,CB(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B
MCH&6O"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(H-+@WN#
MDXNDF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VTB"FUS9W-T<B`BB>:1G(+PCN:"Z(]O@K>#38.#@XF#BH%;(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("*#38.#@XF#BH%;
M@48B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B@TN#DX-R
M@T&+I)AAC9$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H
M<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B)7,@C5R0K(_NE?&"\)"VD*R"MX+I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E
M(@IM<V=S='(@(I"VD*R"LX+J@KV#4H%;@V@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")'96]R9VEA(@IM<V=S='(@(H-/@XN#5X-!BZ2888V1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("*#:(-#@V.8099-BZ2888V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B@TN!6X-IBZ2888V1
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(H-7@W6#
MB8.+@UZ#BR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(I"I(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B
M1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`BBZ22RH-)@W:#5H.'@Y,B"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L
M92"#?8-B@W8B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED
M(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92",GXWU(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B
M1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E
M8V4B"FUS9W-T<B`B@TV#BH-6@X.+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("*#3X.*
M@5N#DX.)@Y.#:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T
M<B`B@T^#C(-I@U\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B@T^#BX%;@W:*QY>=(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>2(*;7-G<W1R("*#3X.+@5N#=I:\@LV+\Y22@L6"S8+(
M@J*"L8+&(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"2QXG!@L6"JX+<
M@KF"\8%"@U2!6X-O@LR)GI.:.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z((-/@XN!6X-V("5S
M((+PC>V/G(+%@JN"W(*Y@O$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B"#3X.+@5N#
M=B`E<R""\(U8D%:"Q8*K@MR"N8+Q(@H*(R!M<V=S='(@(H-/@XN!6X-VBY:)
MPI#=DN@B"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B@T^#BX%;@W8B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(H-/@T&#:(.+
M@5N#=I.'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B@T^#
M08.`DX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@
M(H-/@T&#98-]@XF+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("*#2X%;@Y.#5X%;DX<B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N
M<R(*;7-G<W1R("*#48-8@V>#08-.@UJ#6(R@(@H*(R!M<V=S='(@(H-1@UB#
M9XN6B<*0W9+H(@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS
M9VED(")'=65S=&)O;VLB"FUS9W-T<B`B@U&#6(-G@W6#8H-.(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(H--@VJ#08NDF&&-D2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("*#38-J
M@T&#<H-4@T6+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*
M;7-G<W1R("*#2X-#@T&#:8NDDZ^+I)AAC9$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY-3<*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT
M='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(DA45%`@E$:/V(*J@MV"PH*I@NB"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B@VZ#0X-@BZ2888V1
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("*#;H-B@U:#A8-!@XN#4X.*@UF#
M@"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R
M"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDQ-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$Q"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B@W>#8H-?(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G
M<W1R("*#=X-B@U\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("*#;H%;@VB!18-]@TZ#
M:(-I@XN#:(^4DX<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W("A)4T\M
M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("*-@H*S(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM
M<V=S='(@(H-W@XN#=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C@*;7-G:60@
M(DAE;'!E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*
M;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`BE+R+A2(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N
M+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B@WJ!6X.`(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB"FUS9W-T<B`B@XV!6X-]ED")I)*A@6F#;X-@@TJ#DXYSC9&!:B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T.`IM<V=I9"`B2&]M
M92(*;7-G<W1R("*#>H%;@X`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R
M("*.J9'N@LR/6H^*(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS
M9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("*#>H%;@X"#9H-"@XR#3H-G
M@XJ!6R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BCJF1[H+,DV288I34
MC88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(H-Z
M@Y.#5X.%@XF#6(NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+
M;VYG(@IM<V=S='(@(HV!C6`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@E7.0LX+((%A-
M3""#9H%;@UX@)7,@@JJ#@8-B@UJ!6X-7("5S((+%C)^/;X*S@NJ"W(*U@KTB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z((-)@W6#5X-&
M@TZ#9R`E<R""R9'.B9Z"MX+I@X&#8H-:@5N#5X+-@J""Z(+<@KF"\2(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"#28-U@U>#
M1H-.@V>,7B`E<R""S8.!@V*#6H%;@U<@)7,@@LF"S8*@@NB"W(*Y@O$B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@@LV-[8^<@K."ZH+<
M@K6"O2!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R
M,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(%!(4""*9Y*C("=D;VUX;6PG((*JE4N7=H+%@K<B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@@TF#
M=8-7@T:#3H-G("5S((+,(%A-3""#8X.*@5N"JHWLD*R"Q8*K@MR"N8+Q(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S((*JC>V/G(+%@JN"
MW(*Y@O$@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@@LP@34E-12!)1"""JH[FD[Z"
MQ8*K@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@)7,@@L:3KXKZ@L6"JX+<@KF"\2!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@DZ^*^H+%@JN"W(*Y@O&!1B5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!<(B5S7"(@@LV5<Y:^@LB+I)=,@L6"MR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*
M;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("*0A96]D/PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED
M(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO
M;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS
M9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/R(*;7-G<W1R("*"HH*M@L*"S)?Q@O",BXV'@K6"W(*W@JF!2"(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B@W2#0H%;@XN#
M:"B-<RF"S)"4@LV"HH*M@L*"Q8*W@JF!2"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(H*B
M@JV"PH+,C7."\(R+C8>"M8+<@K>"J8%((@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S-PIM<V=I
M9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T
M<B`B@VZ#DX-+@XJ!6XNDF&&-D2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@@X&!6X.+@WN#8H-.@UB"S(WL
MD*R"R8ZXE'."M8+<@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0((.!@5N#BX-[@V*#3H-8@LR-
M[8^<@LF.N)1S@K6"W(*U@KTZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!4""#@8%;@XN#>X-B
M@TZ#6(-.@TB!6X->@LR-[)"L@LF.N)1S@K6"W(*U@KTZ("5S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q,PIM<V=I9"`B25`@061D<F5S<R(*
M;7-G<W1R("))4""#08-H@XR#6"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B25`@@T&#:(.,@UB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D
M9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@
M(DE0@T&#:(.,@UB"JHN6B<*"LX+J@KU#2412@W6#C8-B@TZ3X(+)@J""Z(+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM
M<V=S='(@(DE0E96-O8CAE+V"Q8*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E
M<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DEC96QA;F0B"FUS9W-T<B`B@T&#0X-8@XF#DX-HBZ2888V1(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G
M<W1R("*#08-#@U*#DX+,@MTB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@
M(B5S((+,@T&#0X-2@Y,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q
M"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B@T&#0X-2@Y."QH-E
M@TR#6(-G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R("))1(+,EKR13R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(H+@@K6"X)"S
M@K6"K95<CJ:"LX+J@LB"HH+(@N>!025S((*U@L205H*U@J*#18-#@Y.#:(%;
M@O"*2H*B@L2)NH*S@J*!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T
M<B`B(@HB@N""M8+@($EN=&5R;F5T($5X<&QO<F5R((+PCF>"P8+$@J*"Q(%!
M@T&#0X-2@Y."JI5<CJ:"LX+J@LB"HH+(@N>!08*Q@K&"\)%)D?`B"B*"M8+$
MB;J"LX*B@4(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("*)
MYI&<@W:#C(-R@X6!6R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R
M("*)YI&<(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G
M<W1R("*)YI&<(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@
M9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<U.`IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T
M<B`BB>:1G"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(H-#
M@Y.#?(%;@V>!08-8@V6#8H-V("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE
M;&0Z("5S(@IM<V=S='(@(H-#@Y.#?(%;@V>"LX+J@KV#=(-"@5N#BX-H@48@
M)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("))
M;7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(H-#@Y.#?(%;@V>"LX+J@KV#=(-"
M@5N#BX-H@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R("**U(CA@L&"O8-!@TZ#5H.'@Y.#4H%;@VB"JI=>@J:"YX+J@L2"
MHH+<@K>!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R("*#AH%;@U66O(*I@W"#6(./@5N#:(*JD+."
MM8*M@J""Z(+<@KF"\8%"(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B
M(@HB@X:!6X-5EKR"J9'CD=:#08-H@XR#6(*JD+."M8*M@J""Z(+<@KF"\8%"
MC<23>(Z.@K6"Q(+=@NF"J8%!BL>7G8[2@LF809>-@K6"Q"(*(HFZ@K."HH%"
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(I)IB;J"L(+PD%N"
MK2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B@T.#DX-H
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E
M<G,B"FUS9W-T<B`BC,*5RH.&@5N#52(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M26YD;VYE<VEA(@IM<V=S='(@(H-#@Y.#:(-L@U:#08NDF&&-D2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(DEN9F\B"FUS9W-T<B`BC^Z5\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(H-#@Y.#=(-(
M@X&!6X-6@X>#DR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B
M"FUS9W-T<B`B7T^,XX+K@LF7\8+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B
M26YS97)T($EM86=E(@IM<V=S='(@(HGFD9R"\)%]D_PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E
M<G0@5&%B;&4B"FUS9W-T<B`BE5R"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B
M($QI;FLB"FUS9W-T<B`B@XJ#DX-.@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("))
M;G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B7T.13X+)E_&"\)%]D_PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(HR[C=V(RI)U@LR,XX+K@LF7\8+PD7V3
M_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(HR[C=V(RI)U@LR13X+)E_&"\)%]
MD_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(HR[C=V(RI)U@LR,XX+K@LF-<X+PD7V3
M_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(HR[C=V(RI)U@LR13X+)C7."\)%]D_PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(HR[C=V(RI)U@LR,XX+K@LF2:9>.@O"1
M?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BC+N-W8C*DG6"S)%/@LF2:9>.
M@O"1?9/\(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN
M<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BD>.1UH-E@Y.#=H.,
M@5N#9X+,D7V3_"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G
M:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("*05H*U@J*#<(-8
M@X^!6X-H@O".\X*OCN:"Z8.!@5N#BX-!@VB#C(-8@O"3_)?-@48B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("*,XX+K@LF#6H.+
M@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S
M='(@(I%/@LF#6H.+@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M
M;B!A9G1E<B(*;7-G<W1R("*,XX+K@LF7\8+PD7V3_"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(I%/@LF#6H.+@O"1?9/\
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G
M:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("*#@8-B@UJ!6X-7@O"1?9/\
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S
M='(@(HSC@NN"R9)IEXZ"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(I%/@LF2:9>.@O"1?9/\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("*,XX+K@LF-<X+P
MD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@
M(I%/@LF-<X+PD7V3_"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*
M;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`BEW"04X+,@KV"WX+,CK^6XH+,DYJ"
MIH+PD_R7S8%&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R
M("*)YI&<@LR1?9/\@5Z5SXU8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK
M(@IM<V=S='(@(H.*@Y.#3H+,D7V3_(%>E<^-6"(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("*1EY!-D.:"R9&7@NF"O8+?@LR.8XV"@JJ5<Y&K@K6"
MQ(*B@MR"MX%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM
M<V=S='(@(HYCC8*"JI5SD:N"Q8*W@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#<R"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S`*;7-G:60@(DEN=&5G97(@;&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM
M<V=S='(@(I5SD+."R"!::7`@@V:!6X->@L6"MX%"(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`BE7.0LX+(@T&#=H.*@U"!6X-6@X>#DX+%@K>!0B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM
M<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,34U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,CD@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+B(*;7-G<W1R("*6LXSX@LB#9H%;@UZ"JI+QCV^"LX+J@MR"M8*]
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*
M;7-G<W1R("*1EX+HD.:"S(-!@VB#C(-8@JJ5<Y"S@L6"MX%"(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L
M:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB
M"FUS9W-T<B`BE7.0LX+(@XF#0X-:@Y.#6(-,@T."Q8*W@4(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("*5<Y"S@LB/ZH^*@JJ.=Y+H@K."
MZH+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`BC^.(RH+,@T&#3H-:@UB,H(*JE7.0LX+%@K>!0B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R
M=&YE<B!I9"XB"FUS9W-T<B`BE7.0LX+(@W"!6X-G@VF!6TE$@L6"MX%"(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV
M86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(I5SD+."R)"[E6F#4H%;@VB"
MQ8*W@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@
M(I5SD+."R(-V@XV#9X-2@XN"Q8*W@4(B"@HC("!P:'`M9F]R;6%T"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"FUS9VED("));G9A;&ED
M(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(I5SD+."R([SD$V.TH+%@K>!
M1EPB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@
M<VAA<F4@;V)J96-T(@IM<V=S='(@(I5SD+."R(NDETR#28-U@U>#1H-.@V<B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@
M(I5SD+."R)2MD$V,LX-!@VB#C(-8@L6"MX%"(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A
M;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`BE7.0LX+(=6YI8V]D98-F@5N#
M7H+%@K>!0B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T
M:6]N(@IM<V=S='(@(I%)D?""\)2]DUTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B@T.#B8.3@46#
M0X-8@XF#@(NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G
M<W1R("*#0X.)@TZ+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`B@T&#0X.+@XF#DX-H(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(H-]
M@Y.3AR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("*#0X-8@XF#1X.+(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@
M(DES<W5E<B(*;7-G<W1R("*4K8USCM(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R
M("*.SI',(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("*#
M0X->@XJ#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*
M;7-G<W1R("*#5X.#@WV#0X-*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B@E",
MCB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`BD_J6>R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B@U>#@X%;@U>!
M6Y.'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B@XB#
MBX-?@Y,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("*"5HR.(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS
M9W-T<B`B@E6,CB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`BD;6"
MIH+I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(I*&
MB9N1M8*F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("*7
MO));D;6"IB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B
MC;:1M8*F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B
MB461M8*F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S
M='(@(H-*@U6#=(-8@UZ#DXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_
M(@IM<V=S='(@(H-)@XJ#5X-I@XN"\)7;D;:!2"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2V5N>6$B"FUS9W-T<B`B@U"#:H-!BZ2888V1(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O
M<R"#5(%;@V^"JI1&C]B+D93;@K6"W(*U@KV!0B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@0W)E871I;VXB"FUS9W-T<B`BC*Z-[)"LD_HB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P
M<FEN="(*;7-G<W1R("*,KHYWEN0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`BC*Z2
MMR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I
M9"`B2V5Y(%1Y<&4B"FUS9W-T<B`BC*Z.[9?>(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*
M;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`BDV2.<8RN@JJ"MX+%@LF,]H]/C*Z#5(%;@V^"R9&V
MC=V"M8+<@K>!0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I
M9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB
M871I(@IM<V=S='(@(H-,@XJ#;X-8BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*
M;7-G<W1R("*2J9%.EJ^.Y8[EBV"0;):OBZ2888V1(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`BD>6*V):OC9$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%
M54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(H-.@T6#1H%;@V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY
M<F=Y>G-T86XB"FUS9W-T<B`B@TR#BX--@UB+I)AAC9$B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B
M7UF#C(-#@T&#18-G(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX
M,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BC+Z,ZB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS
M9W-T<B`B@XF#28-8D&R6KY:OCN6+I)AAC9$B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H
M86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T
M<B`BB;J,MX+,C(XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM<V=I
M9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,B"FUS9W-T<B`BD4^)\8+,@XV#3X-#@Y,Z("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA
M<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BD4^)\8+,@XV#3X-#@Y,Z
M("4R)',@@JF"YR`E,21S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("*13XGQ@LR#
MC8-/@T.#DSH@@LB"M2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM
M<V=S='(@(H.)@V>#<H-!BZ2888V1(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO
M=70B"FUS9W-T<B`BE'J2=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N
M(@IM<V=S='(@(H.,@V^#;8.3BZ2888V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM
M<V=S='(@(HVV(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.`IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S`Y-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(H.,@UR#
M9XFDC9$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(DQE=F5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("*#BH-X@XJ#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("*1Y8.*@W*#
M08%%@T&#B8-UCM")[X[EBV"0;):O@U>#@X-]@5N#<8.*@5N#A"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("*#BH-Q@V6#
MDX-6@X6#7H-#@Y.,]HV1(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*
M;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R
M:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M,3$*;7-G:60@(DQI;FLB"FUS9W-T<B`B@XJ#DX-.(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED
M("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W,@IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S
M<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R
M("*#@8%;@XN-[)"LEW""R8.!@5N#BX-!@VB#C(-8@LF#BH.3@TZ"MX+I(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@
M(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E
M<R(*;7-G<W1R("*#9H%;@UZ#>(%;@UB(ZI>7(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T
M<B`B@W>#BX-VC8"6VH+PE5R.IH*W@NDB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,S"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("*57(+,B.J7ER(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED
M("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM
M<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(H-:@V*#5H.'@Y."
MS(CJEY>-[)"L@LF.N)1S@48E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B@X:!6X-5@LR(ZI>7C>R0K(+)CKB4<X%&)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(H.&@5N#58+,@XJ#6(-G
M@LV6LXSX@LF"R(+!@L2"HH+<@K>!0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("*#BH-G@T&#:H-!BZ28
M88V1(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("*#C8%;@VB2ABXN+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO
M8V%L('1I;64Z("(*;7-G<W1R("*,NY)NCIZ*U(%&(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T
M<B`BDFZ(YH+&CIZ*U"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BC^J/BB(*"B,Z(&QO9VEN+G!H
M<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R("*#C8-/@T.#DR(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@
M<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(H.-@T^#08-%@V<B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM
M<V=S='(@(H.-@T^#0X.3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B@XV#3X-#@Y,@@UZ#6(-.
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS9VED("),;V=I
M;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A
M<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("*#AH%;@U66O(*I@W"#
M6(./@5N#:(*JD+."M8*M@LB"HH*]@M^"R8.-@T^#0X.3@LF.N)1S@K6"W(*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B
M3&]G:6X@9F%I;&5D+B(*;7-G<W1R("*#C8-/@T.#DX+)CKB4<X*U@MR"M8*]
M@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8R"FUS9VED("),
M;VYG('1E>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R
M("*#38.*@U:#@Y6VCIJ!:8^LE;:.FH%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W
M97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("*#B8-E@Y.5MHZ:@6F/K)6VCIJ!
M:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B@XV!6X-]D)2.FH%ICZR5MHZ:@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQU>&5M8F]U<F<B"FUS9W-T<B`B@XN#3H-:@Y.#=8.+@TZ1Y8SVC9$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(HR.(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R("*3695T@K."ZH*]($U3+51.148@@LV#9H%;@UZ"
M\(K<@O&"Q8*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-
M4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G
M<W1R("*#?8-*@TDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("*#?8-0
M@VB#:H-!BXR#AH%;@U.#6(.)@W*#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("*#?8-?@TN#6(-*@XN+I)AAC9$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I
M9"`B36%I;"(*;7-G<W1R("*39(YQ@X&!6X.+(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B@WV#B8-%@T.+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(H-]
M@XR!6X-6@T$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S
M='(@(H."@XN#9H-"@W6+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA
M;&DB"FUS9W-T<B`BDV2.<8.!@5N#BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%L=&$B"FUS9W-T<B`B@WV#BX->BZ2888V1(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G
M<W1R("*01I5T@J^"LX+J@KV#B8-X@XN"\)'.B9Z"LX*Y@L25JI?>@O"*QY>=
M@K6"W(*W@4(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("*"4HR.(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%R9VEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM
M<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("*#?8%;@U:#@X.+CY23
MAXNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G
M<W1R("*#?8.+@V6#0H-J@TZ3AR(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B@W2#
M0H%;@XN#:(+PB.J2=H*S@KF"Q(*B@MR"MR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B36%U<FET86YI82(*;7-G<W1R("*#@H%;@XJ#7H-J@T&!18-#@UB#B8.`
MBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B@X*!6X.*@U:#@X-8BZ2888V1(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E
M9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$T"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,S8*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B@E2,CB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(DUA>6]T=&4B"FUS9W-T<B`B@WV#0X.(@V*#9Y.'(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(H.!@Y.#;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B@X&#:H.%
M@5N#@H%;@V@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("*#
M6H.+C(N-AR(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(I9[E;8B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I
M9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(H.!@V*#6H%;@U>"S8R?C]B"Q8*K@MR"M8*]@JJ!08^0EKR.
MTH+,D&>,LX+-C)^/V(+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(H.!@UR#8H-H(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@
M9&5F:6YE9"(*;7-G<W1R("*#@8-<@V*#:"!<(B5S7"(@@LV2Z(M@@K."ZH+$
M@MR"N8+Q(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I9"`B365T
M<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM
M<V=S='(@(H.!@TR#5H-2C8>/3XV1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B@WZ#3H.-
M@VR#5H-!F$&632(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED
M(")-:6UE(%1Y<&4B"FUS9W-T<B`B36EM92!4>7!E(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I
M9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*
M;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS
M9W-T<B`B4$5!4B"#<(-B@U"!6X-7@LP@2%144%]297%U97-T((*JC*F3EH*]
M@NB"W(*Y@O&!0B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G
M:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI
M8V%T:6]N+B(*;7-G<W1R("(B"B*6HI#=DNB"Q8*W@4*"L8+,@T&#=H.*@U"!
M6X-6@X>#DX+PCF>7<(*W@NF"O8+?@LF"S9#=DNB#=(-`@T.#BX+PC>R0K(*W
M@NF52Y=V(@HB@JJ"H(+H@MR"MX%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE
M<W-A9V4@240N(@IM<V=S='(@(H.!@V*#6H%;@U<@240@@JJ,J9.6@KV"Z(+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN(@IM<V=S='(@(E!%05(@@W"#8H-0@5N#5X+,($UA:6P@
M@JJ,J9.6@KV"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I
M;VX@240N(@IM<V=S='(@(H-:@V*#5H.'@Y,@240@@JJ,J9.6@KV"Z(+<@KF"
M\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`BC(XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(HQG
MD=&#@8%;@XLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS
M9W-T<B`BCT.0LY/Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B@X*#BX-H@V^+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("*#@H-I
M@U*,]HV1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M("*#@H.3@U.#BR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#$*
M;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H
M;'DB"FUS9W-T<B`BEHB,CB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E
M<G)A="(*;7-G<W1R("*#@H.3@V>#6H.)@V>3AR(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0
M:&%S97,B"FUS9W-T<B`BC(Z7[B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E
M9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(H."@XV#8H-2B:2-D2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED
M(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,V"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@
M(DUO=F4@1&]W;B(*;7-G<W1R("*)NH+6(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F
M="(*;7-G<W1R("*-MH+6(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T
M<B`BB46"UB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(H_C@M8B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS
M9VED(")-;W9E(&1O=VXB"FUS9W-T<B`BB;J"UB(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!U<"(*
M;7-G<W1R("*/XX+6(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E
M(@IM<V=S='(@(H."@U6#DX-R@5N#3HNDF&&-D2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#$*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,SD*;7-G
M:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S
M='(@(H-!@TJ#18.3@V<B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*
M;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B@T&#2H-%
M@Y.#9X_NE?$B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS
M9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("*#?H.#
M@Y.#?8%;F$&632(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T
M<B`BDZ^(TX*U@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BEKR13R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B3F%M:6)I82(*;7-G<W1R("*#:8-^@W*#08NDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B@VF#18.+BZ2888V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("*#;(-P@5N#BXFD
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(H-)@XF#DX-?B:2-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD
M<R!!;G1I;&QE<R(*;7-G<W1R("*#28.)@Y.#7Y?,@T&#DX-E@T*#BX^4DX<B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I
M9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!
M(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI
M8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(H-L@V*#
M9X./@5N#3B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(H+(@K4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B@W2#B8.3
M@UB7S(-J@X6!6X-*@XR#:(-J@T$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y
M(@IM<V=S='(@(I!6BTN5JI?>(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V
M(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T
M"FUS9VED(").97<@36]O;B(*;7-G<W1R("*05HR.(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE
M("AO<'1I;VYA;"DB"FUS9W-T<B`BD%:"M8*B@X:!6X-5EKPHE$.(TRDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(H-J@X6!
M6X-7@5N#B8.3@V@B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("*05H*U@J*#<(-8@X^!
M6X-H(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N(@IM<V=S='(@(I!6@K6"HH-P@UB#CX%;@VB"S2`E>"""R8KZC,"0V(+J
M@LF"R(+H@MR"MX%"(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R
M("*05H*U@J*#<(-8@X^!6X-H@JJ(ZI)V@K6"W(*Y@O&!0B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE
M=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B
M@VJ#A8%;@U@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS
M9VED(").97=S9W)O=7!S(@IM<V=S='(@(H-J@X6!6X-8@T^#BX%;@W8B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X
M="(*;7-G<W1R("*.GR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(HZ?@LR#28-V
M@U:#AX.3(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G
M:60@(DYE>'0^(@IM<V=S='(@(HZ?@LR#>8%;@U<^(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B@VJ#2H.)@T^#08NDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B@VJ#5X-&@5N#
MBXNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M("*#:8-#@U>#1H.*@T&8099-BZ2888V1(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(H-J@T6#1Y.'(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I
M9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I
M9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("*-MY6J@O"5
M7(ZF@K>"Z8*]@M^"S)#=DNB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A
M=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB
M"FUS9W-T<B`BE<^-6(+(@K6!0B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("*"L8+,@T&#3H-:@UB,H(+)
M@LV#5(-U@T&#3H-:@UB,H(+-DL>)P8+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<X(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3$W"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(B5S((+,D-V2Z(_NE?&"JHYW
MDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-34*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(")&5%`@5D93((+,C5R0
MK(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")344P@
M5D93((+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RXB"FUS9W-T<B`B4U%,((-*@V6#4X.*@LR-7)"LC^Z5\8*JCG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R("*.8XV"@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(I&7D$V0YH*JCG>2Z(*S@NJ"
MQ(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HY,C`*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B@W2#0(-#
M@XN"JH-!@V*#=H.-@5N#:(*S@NJ"Q(*B@MR"N8+Q(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T
M<B`B@T&#0X-2@Y."JH*@@NB"W(*Y@O&!0B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I
M<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M("*/ZH^*@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("*#@8-B@UJ!6X-7@JJ.=Y+H@K."
MZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB
M"FUS9W-T<B`BEKR13X*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I
M9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BE-2-AH*JCG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*
M;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B2%144""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DE-05`@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")+97)B97)O<R"41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*#C8-/@T.#DR"4
M1H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0
M05-35T0@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")3
M34(@E$:/V(+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B
M"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE
M($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@
M4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B)/<&5N4U-,((-V@XV#3X.)@X""
MS(-P@UB"JHYWDNB"LX+J@L2"HH+<@KF"\8%"3W!E;E-33"""S2!02T-3(#$R
M((+,@V:!6X->@O"(M2(*(H*D@LR"R95+EW:"Q8*W@4(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG
M('-I9VYU<',N(@IM<V=S='(@(I7;EZ^"S(-4@T.#DX-!@V*#=H+(@K6!0B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A
M('-E="XB"FUS9W-T<B`B@TZ#2(%;@UZ"JI#=DNB"LX+J@L2"HH+<@KF"\8%"
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@
M<W!E8VEF:65D+B(*;7-G<W1R("*#6H-P@XR!6X->@JJ.=Y+H@K."ZH+$@J*"
MW(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H
M(&9I;&4B"FUS9W-T<B`BBEF3EH-T@T"#0X.+@LB"M2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G
M:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R
M("*#AH%;@U66O(*I@W"#6(./@5N#:(*JD9>"YX+J@MR"N8+Q@L6"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`BEK.,^(+,6$U,
M@V:!6X->@JJ5U(+H@MR"M8*](@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("*2
M;(+(@K4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B@TF#BH-7@VF#BX+,
MD-V2Z(-T@T"#0X.+@LF#;X%;@U>#AX.3@JJ"H(+H@MR"N8+Q@4*0W9+H@O"-
MQ)"VD*R"M8+<@K>!0B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*
M;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(I#=DNB#=(-`
M@T.#BX+)@V^!6X-7@X>#DX*J@J""Z(+<@KF"\8%"D-V2Z(-T@T"#0X.+@O"-
M[(+HDKR"M8+$B;J"LX*B@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(H+(@K4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED
M(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD
M(@IM<V=S='(@(H-M@5N#=(-(@5N#3I.'(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@
M2&5M:7-P:&5R92(*;7-G<W1R("*6:Y2\BX4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("*6:X-]@XJ#
M08-ICY23AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@
M(H-M@XN#18-&@5N)I(V1(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("*"L8+J@N:"
MZ)%/(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*
M;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B@K&"ZH+F@NB,XR(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T(&$@9&ER
M96-T;W)Y(@IM<V=S='(@(H-F@T*#C(-.@V>#BH+%@LV"H(+H@MR"N8+Q(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E
M9"XB"FUS9W-T<B`BCL"1E8*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@
M<V5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(P."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V
M.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@U(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,#$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S,S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS-C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4Y,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-C8Y"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("*#5(-\@5N#
M9X*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDP."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0T"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(H.!@X(B
M"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`B,3&,CB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-#,*;7-G:60@(DYU;6)E<B(*;7-G<W1R("*0E"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C(*;7-G:60@(DYU;6)E<B!O9B!C:&%R
M86-T97)S(@IM<V=S='(@(I6VCIJ0E"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0R('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L
M=6UN<R(*;7-G<W1R("*7\9"4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM
M<V=S='(@(HUSD)0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B
MD9>039#F@XJ#6(-G@O"-6)!6@KV"WX+,E-2-AH*JCG>2Z(*S@NJ"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B
M"FUS9W-T<B`B@TF#=8-7@T:#3H-G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(H-)
M@W6#5X-&@TZ#9XWLD*R.TB(*"B,@;7-G<W1R("*#28-U@U>#1H-.@V>-[)"L
MCM*"S(N6B<*0W9+H(@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`Q
M"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R
M("(Q,(R.(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/
M9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B@TF#=(-"@U@B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L
M9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED
M(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`BC,."HH-P@UB#CX%;@V@B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`BC,."HH-P@UB#CX%;@VB"
MJI"S@K6"K8*@@NB"W(*Y@O$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB
M"FUS9W-T<B`B@TF#?8%;@Y,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P
M<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`BBZ273(-T@TB#BX-?@LT@
M24U!4""#5(%;@V^"OH*O@JJ#5(-\@5N#9X+%@JN"W(*W@4(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV.`IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("*39(YQ@X&!
M6X.+@T&#:(.,@UB"S3&"PH*^@J^.=Y+H@L6"JX+<@K>!0B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T
M<B`BCXJ73([2@JF#5H-8@V6#@(K'EYV.TH*^@J^"JHNDETR"S(^*ETR,H(+&
M@T&#3H-:@UB,H(+PE<^-6(+%@JN"W(*W(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z-#$@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(I!6BTN#18-#@Y.#:(%;@LF57(ZF
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G
M:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*(D]P96Y34TP@@T>#
MB8%;@493+TU)344@CY"6O(*S@NJ"O8-P@5N#9X*I@N>#9H%;@UZ"\([F@NB/
M;X*Y@MR"N8+Q@L6"M8*]@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G
M:60@(D]P=&EO;G,B"FUS9W-T<B`B@TF#=H-6@X>#DR(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R"#
M28-V@U:#AX.3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(I34C8:5
M=(G3C_"/D8*K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("*19Y!$(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`BE92/D"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T
M<B`BD*Z7G2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("*,LX+,@T&#
M=H.*@U"!6X-6@X>#DX-E@Y.#=H.,@5N#9R(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(I&\@LR#0X.3
M@W2#2(.!@5N#5H.'@Y,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("*/BI=,CM*"
MS(-!@TZ#6H-8C*`B"@HC(&US9W-T<B`BCXJ.G8[2@LR+EHG"D-V2Z"(*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-()1&
MC]B"S8YGEW""Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C
M:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T
M<B`B4$=0()-DCG&/D):\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(E!'4""(PXV&E;8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@C/:*
M2HRN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@
MCY"6O(W/+XC#C8:)NX-F@5N#7B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV
M.0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0@U*!6X-H(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B
M4$A0@U:#1H.+(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@
M(E!-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*
M;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")032!4
M+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R
M(")03U-)6""*9Y*C@JJ,J9.6@KV"Z(+<@KF"\2(*"B,Z(&QI8B]A<&DN<&AP
M.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED
M(")0861D:6YG(@IM<V=S='(@(I:$D9`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(H-P@TR#6(->@Y.!18-#@UB#B8.`BZ2888V1
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B@W"#B8-)
MBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("*#<(.,@UB#8(-ICJF.H8OF(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B@W"#:8-]BZ28
M88V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM
M<V=S='(@(H-P@W:#08-J@X6!6X--@VJ#09/&EZ>-D2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(H-P@XF#3X-!@T.+I)AAC9$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM
M<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#$U"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R
M9"(*;7-G<W1R("*#<(-8@X^!6X-H(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B@W"#6(./@5N#:(+-D+./[8+)E<^-6(*S@NJ"W(*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R
M,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(H-P@UB#CX%;
M@VB"JI"S@K6"K8*@@NB"W(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@
M4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")2041)55,@E$:/V(+,
M@W"#6(./@5N#:(*JE4N7=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-3`*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(H-P@UB#CX%;@VB"S(IME$8B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("*#
M<(-8@X^!6X-H.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q
M"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(H-P@UB#CX%;@V@Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#,Q"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G
M:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("*#<(-8@X^!6X-H
M@JJ(ZI)V@K6"W(*Y@O&!0B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(R"FUS9VED(")087-T92(*;7-G<W1R("*37(+HE72"KR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A
M<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(H-.@XJ#8H-V@WN!6X-H@JF"
MYY-<@NB5=(*O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("*#<(-8(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG
M;G5P<SHB"FUS9W-T<B`BE=N7KY*&@LR#5(-#@Y.#08-B@W:!1B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(H-P@5N#6H.3@V<B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I
M9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(I7;
MCN>1@(WL@O".P(US@K>"Z2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\B"FUS9W-T<B`B@XV#3X-#@Y..GH+)E=N.YY&`C>R"\([`C7."M8+<
M@K>"J8%((@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B@T&#3H-:@UB,H"(*"B,@;7-G
M<W1R("*+EHG"D-V2Z"(*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L
M971E9"XB"FUS9W-T<B`B@T&#3H-:@UB,H"!<(B5S7"(@@LV-[8^<@K."ZH+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(H-!@TZ#6H-8
M@LV+D93;@K."ZH+<@K6"O2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS
M9VED(")097)M:7-S:6]N<R(*;7-G<W1R("*#08-.@UJ#6(R@(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B@T&#3H-:@UB,H(+,BL>7G2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS
M9W-T<B`BC,*0;(_NE?$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS
M9W-T<B`B@WF#BX%;BZ2888V1(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B@W2#0H.*@W.#DXNDF&&-D2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G
M:60@(E!H;VYE(@IM<V=S='(@(I-DF&(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B@W.#9X-0@T&#DY.'
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("*#<X-.@UJ#BR(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-34Y"FUS9VED(")0;&5A<V4@96YT97(@82!M
M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("*,CH+&E$Z"\)/\E\V"M8+$@JV"
MOH*S@J*!0B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("*05H*U@J*5JI?>@LR6O)%/@O"3_)?-
M@K6"Q(FZ@K."HCHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,CDX
M"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C,W"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R
M(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("*0LX*U@J*3^I5T@O"3
M_)?-@K6"Q(*M@KZ"LX*B+B",CH+,D_J0E(+P@V"#1H-B@TZ"M8+$@JV"OH*S
M@J*!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#0*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`BC^&*
M49/@EV6"\)=VEO&"M8+$@K*+3)/\@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0B"FUS9W-T<B`B@X:!6X-5EKR"QH-P@UB#CX%;@VB"\)/\E\V"
MM8+$@JV"OH*S@J*!0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9
M;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y
M<W1E;2XB"FUS9W-T<B`B(@HBCI^"S)6VCY&"\)/'@O&"Q8*M@KZ"LX*B+B""
ML8+,@U:#6(-E@X""\(YGEW""MX+I@KV"WX+,BTN2Z(Z6C8""R9.OB-."MX+I
ME4N7=B(*(H*J@J""Z(+<@K>!0B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(H-\@5N#B8.3@VB+I)AAC9$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(I.*E5N0E"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!O<G1U9V%L(@IM<V=S='(@(H-\@XN#9X-+@XN+I)AAC9$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*
M;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]L9&%P.B"52Y=V@LA,1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z
M,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@E4N7=H+(
M<V5S<VEO;HIGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(H-V@XR#<H.%@5LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R("*05H*U@J*#18-#@Y.#:(%;@LF)YI&<@O"57(ZF
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P
M=&EO;G,B"FUS9W-T<B`BD4^"S(-)@W:#5H.'@Y,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D
M;V-U;65N="(*;7-G<W1R("*(\XW\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("*4
MZ9:GC*XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y
M"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(H_ABE$B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`BC^&*49/@EV6"S)#@EKXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,PIM<V=I
M9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@
M(HSVBDJ,KB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("*,]H]/
MC*Z#08.+@U.#BH-9@X`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(HSV
MBDJ,KH_NE?$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR
M-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(HSVCT^,KB^4Z9:GC*Z"JI"VD*R"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R
M=&\@4FEC;R(*;7-G<W1R("*#=H-'@XN#9X.*@U(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S
M<V%G97,B"FUS9W-T<B`B@X&#8H-:@5N#5X+P@W"!6X-7(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B@TJ#7H%;@XLB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@(H-.@T>#
MBH%;(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T
M82(*;7-G<W1R("*#2H->@5N#BR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)308SVCT^,KB@E9(-R@V*#9RDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8Q"FUS9VED(")2861I
M;R!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G
M:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.`IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@
M86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M
M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R("*4Y"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(I/'@MXB"@HC()/'C9X@D\>/;PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BEGN3EH+)("5S
M((+PC>V/G(*U@MR"MX*I/R""L8+,D8"-[(+-C+."R9;?@KF"W(*Y@O&!0B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R
M("*6>Y.6@LF#AH%;@U4@)7,@@LR#9H%;@UZ"\(WMCYR"M8+<@K>"J8%(((*Q
M@LR1@(WL@LV.YH+HC\&"N8+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VXB"FUS9W-T<B`BC<6,XX+,D8"-[(+P@N*"Z)*\@K<B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SHB"FUS9W-T<B`BDZZ328.!@VJ#A8%;@LR-Q)5<CJ:*U(IU
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E
M<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(H-\@5N#7H.+@LR-Q)5<CJ8B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,R
M"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C(X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS
M9W-T<B`B@XJ#C8%;@V@B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("*#BH."
M@5N#9X-4@5N#<H-8(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3HB"FUS9W-T<B`B@XJ#@H%;@V=54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B`B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("*-[8^<(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS
M9W-T<B`B@W6#C8-B@TZ"\(WMCYPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(H^1
MCJZ"\(WMCYPB"@HC(&US9W-T<B`BCJF5JH+,@TJ#C(.3@U^"J8+GC>V/G"(*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V
M92!P86ER(@IM<V=S='(@(H-Y@T&"\(WMCYPB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`BE=N1MH*U
M@KV#6(-.@XJ#=H-G@O"-[(O&@V:#0H.,@TZ#9X.*@JF"YXWMCYR"MX+I@4(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BC>V/G(%&(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT(@IM<V=S='(@(H*Q@LR#;8%;@VB"\(-H@TR#A8.!@Y.#9X*I@N>-[8^<
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I
M9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B@X:!6X-5@O"-[8^<(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("*#AH%;@U6"\(WMCYPZ
M("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G
M:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@(@IM<V=S='(@(I=VBX&"R974DYJ"Q8*K@MR"N8+Q.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(I=VBX&"LX+J@KT@7"(E<UPB((+-("5S((+,D-V2Z(+)CG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*7=HN!@K."ZH*](%PB)7-<(B""S2!6
M1E,@D-V2Z(+)CG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M571I;"]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`BEW:+@8*S@NJ"O2!<(B5S7"(@@LV0W9+H@LF.=Y+H@K."ZH+$@J*"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B@XJ#6H-B
M@V<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B
M4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B@W"#6(./@5N#:(+P@XJ#6H-B@V<B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S
M970@66]U<B!087-S=V]R9"(*;7-G<W1R("*"H(+(@KV"S(-P@UB#CX%;@VB"
M\(.*@UJ#8H-G(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B
M4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HW,B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<W%L<VAE
M;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM<V=S='(@(HR+B<HB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@
M(H-)@W:#5H.'@Y."R9;?@NDB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B
M@W"#6(./@5N#:(+PC<23_)?-(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U
M;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(HRS@LR-7)"L@LF6WX*W(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS(@IM<V=S='(@(H-E@TR#6(-G@T>#9H-"@UZ!6X+,@TF#=H-6@X>#
MDR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(HE%(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,`IM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,P.38*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*
M;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2
M;VQE(@IM<V=S='(@(I;PBH0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA
M;FEA(@IM<V=S='(@(H.+@5N#?8-J@T$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM
M<V=S='(@(C$X,)-XB?&372(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@
M(HVV@LF)\9-=(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(HE%@LF)
M\9-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`BC7.1
MKI"K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`BC7.1
MKI"K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(HUS@48B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED
M(")2=6QE<R(*;7-G<W1R("*,<I#\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R
M("*14X+$@LR-<X+&E_&"S(K4@LF,<I#\@O"(^(*M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`BC7."S(K4@LF,<I#\@O"(^(*M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`BE_&"S(K4@LF,
M<I#\@O"(^(*M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B
M4G5N(@IM<V=S='(@(H[`C7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B@XV#5H-!F$&632(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R("*#BX./@Y.#7R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%((C#
MC8:/D):\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3
M+TU)344@B,.-AI6V(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")305-,()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S
M<V%G:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM
M<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13""#5H-&@XLB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Q"FUS9VED(")344P@<W1A=&5M96YT
M(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(I"LC/<B
M"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`BDWDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B@UJ#DX-G@W>#C(-IDX<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G
M<W1R("*#6H.3@V>#3(-B@V.!E8-L@5N#E(-"@U@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*
M;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(H-:@Y.#9X.+@U:#02(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB
M"FUS9W-T<B`B@U2#DX-S@T>!6X.+@46#?H-.@XV#DY.'(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B
M"FUS9W-T<B`B@UJ#DX-G@W.#DX-:@Y.#9X*H@N:"T8-/@XR#:8-F@T*!6X.3
MCY23AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("*#5(."@T&3QI>G
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@
M(H-4@Y.#?8.*@VV+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B@U2#DX-G@X&!18-V@XJ#DX-6
M@WF6KX[EBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("*#5(-%
M@U>#08.)@W*#08FDC9$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`BE=N1MB(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB((+PE=N1MB(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@)7,B"FUS9W-T<B`B)7,@@O"5VY&V(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@
M(H-)@W:#5H.'@Y."\)7;D;8B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(I"VD*R"LX+J@KV0W9+H@O`@4$A0((-8
M@TZ#BH-V@V>"QH*U@L2#5(%;@V^"S(WLB\:#9H-"@XR#3H-G@XJ"R97;D;:"
MMX+I@4(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(E<R"0W9+H@O"5VY&V@K6"W(*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(I#=DNB-6)!6
MEW"#6(-.@XJ#=H-G(%PB)7-<(B""\)7;D;:"M8+<@K6"O8%"(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-C
M871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("*,GXWU
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A
M<F-H($5N9VEN97,B"FUS9W-T<B`BC)^-]8-'@Y.#5X.3(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDU,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM
M<V=S='(@(H-T@T"#0X.+@O"129'P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*
M;7-G<W1R("*3^I5T@O".=Y+H@K6"Q(*M@KZ"LX*B@48B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(I+'B<&"MX+I@T^#BX%;@W:"\)%)D?""M8+$@JV"
MOH*S@J(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED
M(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`BD%:"M8*BCXJ.G8[2@O"1
M29'P@K6"Q(*M@KZ"LX*B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B@U2!6X-O
M@O"129'P@K6"Q(*M@KZ"LX*B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@
M(I+'B<&"MX+I@X:!6X-5@O"129'P@K6"Q(*M@KZ"LX*B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L
M96-T(&%L;"(*;7-G<W1R("*14X+$D4F1\"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-#`*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R
M96$N(@IM<V=S='(@(B(*(I5+EW:"R)6VCIJ"\(FZ@LR#>X-B@TZ#6(*I@N>1
M28+Q@L6#4H-S@5N"MX+I@L:!08-E@TR#6(-G@T>#BH-!@M:#>8%;@UB#9X+%
M@JLB"B*"W(*W@4(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`BD_J5
M=(+,B^:0V(+HE;:.FH+PCG>2Z(*U@L2"K8*^@K."HH%&(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F
M;W)M870Z(@IM<V=S='(@(I/ZE72"S(Q@CJZ"\(YWDNB"M8+$@JV"OH*S@J*!
M1B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*
M;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.B(*;7-G<W1R("*5SXU8@K6"O8*B242"\)%)D?`Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z(@IM<V=S='(@(HZ>C8^"S(OFD-B"Z)6VCIJ"\(YWDNB"M8+$@JV"
MOH*S@J*!1B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED
M(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("*.GHV/@LR,8(ZN
M@O".=Y+H@K6"Q(*M@KZ"LX*B@48B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB
M"FUS9W-T<B`BB.J2=H*W@NF"48+"@LR#=(-"@5N#BX-H@O"128+Q@L6"K8*^
M@K."HH%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("*01I*R@O"129'P
M@K6"Q(*M@KZ"LX*B+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*
M;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T
M<B`BC+Z,ZH+PD4F1\(*U@L2"K8*^@K."HCHB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R
M="(*;7-G<W1R("*/X8I1@XR#?(%;@V>"\)&7D$V"MX+I(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E
M;F0@4TU3(@IM<V=S='(@(E--4R"1EY!-(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V5N96=A;"(*;7-G<W1R("*#6H-L@TN#BXNDF&&-D2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM
M<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(H)8C(XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(H-:@XN#<H-!@46#@H.3@V6#;(-/@XTB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B
M4V5R:6%L($YU;6)E<B(*;7-G<W1R("*2RI34(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@
M;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(H-:@V*#
M5H.'@Y.*QY>=(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B
M"FUS9W-T<B`B@UJ#8H-6@X>#DR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,3$*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="XB"FUS9W-T<B`BEEF"ZH+$@K6"W(+!@KV#<(-8@X^!6X-H@O"#BH-:@V*#
M9X+%@JN"Z8+F@J2"R8*U@MR"MX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(H-\
M@5N#7H.+@L6#08-.@UJ#6(*W@NF#BH."@5N#9X-4@5N#;X+PD-V2Z(*U@MR"
MMX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N(@IM<V=S='(@(HR^C.J!08Z>BM21T8%!D_J5=(+PD-V2Z(*U@MR"
MMX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(B(*(HI*CFZ.GH+,@T&#=H.*@U"!6X-6@X>#DX%!D$:2LH%!
M@WF!6X-7C<257(ZF@4&"NX+,D;R"S)5<CJ:#28-V@U:#AX.3@O"129'P@K4B
M"B*"Q(*M@KZ"LX*B+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*
M;7-G:60@(E-E='5P(@IM<V=S='(@(I#=DN@B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("*0W9+HC5B05H-8@TZ#BH-V@V<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S
M(@IM<V=S='(@(H-:@5N#5H-&@XN+I)AAC9$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO
M<G0@4W5M;6%R>2(*;7-G<W1R("**R))0@LB7=I;Q@48B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@
M8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B@6F#@8-J@X6!
M6X+(@L>"Q8%J@U:#AX%;@V>#2H-B@V>#3(%;@JJ.9X*F@NF"YH*D@LF"M8+<
M@K>"J8%((@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`BE5R.IB(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BC+N-W8+,D-V2Z(+&D%:"M8*M
MD+:0K(*S@NJ"O9#=DNB"QH+,C;>5JH+PE5R.IH*W@NF!0B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B@XV#3X-#@Y..GH+)D4^)
M\8+,@XV#3X-#@Y..GHK4@O"57(ZF@K6"W(*W@JF!2"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C(*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<Y,@IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("*57)&`C>R#@8-J@X6!6X+P
ME5R.IH*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_(@IM<V=S='(@(HGFELJ-MH+)("5S((.!@VJ#A8%;@O"57(ZF@K6"
MW(*W@JF!2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("*57(+,@UJ#BY&ND*N#7X-#@T&#
MC8-/@O"57(ZF(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("*57)&ND*N#7X-#@T&#C8-/@O"57(ZF
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`BE5R"S)?QD:Z0JX-?@T.#08.-@T^"\)5<CJ8B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(I5<@LR-<Y&ND*N#7X-#@T&#C8-/@O"57(ZF(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,`IM<V=I9"`B4VAO=R!U<&QO
M860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-0IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R("*/:X^L(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G
M<W1R("*"W(*XE]>"Z(+,@W6#C8-B@TZ"\(]KCZR"W(*]@LV(VI.N@K."N8+$
M@JV"OH*S@J*!0B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N
M92(*;7-G<W1R("*#5H-'@XF#C(-)@VR+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(H-4@T.#DX-!@V*#=B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`BDV2.<8^0
MEKPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM
M<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("*39(YQCY"6O(-!
M@XN#4X.*@UF#@"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R("*#5H.3@TN#?(%;@XN+I)AAC9$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#,@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3`R"FUS9VED(")3:7IE(@IM<V=S='(@(H-4@T.#62(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R
M"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(I7;CN>"\(-8@TR#
M8H-V@K>"Z2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S
M='(@(H-8@XV#;X-,@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M;&]V96YI82(*;7-G<W1R("*#6(.-@WB#:H-!BZ2888V1(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P
M=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM
M<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@
M(H-<@XV#@H.3CY23AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B
M"FUS9W-T<B`B@UR#?8.*@T&6KX[EBZ2888V1(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,#4*;7-G:60@(E-O<G0@
M;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(I7`@M&/AX+,D4F1\"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(I&7D$V,LX-!@VB#
MC(-8(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S
M='(@(I/L@T&#=(.*@TJ+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`BD^R#5X.'@5N#
M5X-!DX>!19/L@U2#DX-H@T.#8H-@CY23AR(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`BD^R4O(N%(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`BE]>"S(-:@XN"QH+,EUV4
MDB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL(@IM<V=S='(@(H-:@XN"QHNKBD6"QH+,EUV4DB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Q,@IM<V=I9"`B4W!A8V5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("*77922(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM
M<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("*77922@L:6A)&0
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(H-8@WF#0X.3
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A
M;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G
M:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(I/!CNJ5MHZ:
M@LR3_)?-(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("*#6H.+
ME:J*A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("*7\96J
MBH0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`BC7.5JHJ$(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T
M<B`B@UB#BH.)@Y.#2I:OCN6.T(GOCN6+8(NDF&&-D2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q
M"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(W.#@*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T
M871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(H]"@MR"O8+-C*<B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(H_SD=0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-SDT"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T
M($%D9')E<W,B"FUS9W-T<B`BCUJ/BI34DFXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O
M=6=H(@IM<V=S='(@(H[FC\&"M9#\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S,`IM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,`IM<V=I9"`B4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B@UB#7H-#@XL@6T-34UTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3
M=2(*;7-G<W1R("*3^B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B@U2#=8-F@T*#C(-.@V>#BB!<(B5S7"(@@JJ"H(+H
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.2!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("*.P(US(@H*
M(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO
M=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E
M;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S
M='(@(HFZE72"JR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("*0K(SW(@H*(SH@
M861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")<
M(B5S7"(@@LV#5H-8@V6#@(+)DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(EPB)7-<(B""JH-6@UB#98.`@JF"YXWMCYR"LX+J@MR"
MM8*]@4(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@@JJ-[8^<@K."ZH+<
M@K6"O8%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(EPB)7-<(B""JH-6@UB#98.`@JF"YXWMCYR"LX+J
M@MR"M8*]@4(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D
M('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("*0W9+H@LV0LX_M@LF6WX*S@NJ"
MW(*U@KV!0H.*@XV!6X-H@K6"Q(IME$:"Q8*K@MR"MX%"(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(I#=DNB"S(-O@V*#3H-!@V*#=H+-D+./[8+)E=N1MH*S
M@NJ"W(*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("*0W9+H@W2#0(-#
M@XN"S(-O@V*#3H-!@V*#=B`E<R""S9"SC^V"R97;D;:"LX+J@MR"M8*]@4(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B""
MS9"SC^V"R8U8D%:"LX+J@MR"M8*](@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S((+-
MD+./[8+)CY&"JXV>@MR"ZH+<@K6"O2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-U9&%N(@IM<V=S='(@(H-8@5N#7X.3BZ2888V1(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B
M4W5M;6%R>2(*;7-G<W1R("**5)=V(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("*3^H+,CV\B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T
M<B`BD_J"S)/\@N@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@
M(I/Z@LR/;R^3^H+,D_R"Z"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("*3^H+,CV^!1B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U
M;G-E="(*;7-G<W1R("*3^I9V(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`BD_J6=H%&(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM
M<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BC^.5=(*K(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R
M("*#5(-\@5N#9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM
M<V=S='(@(H-8@XJ#:8.`BZ2888V1(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BD*DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@IM<V=S='(@(H-8@Y2#0(%;@XN#;X.+@4&#A(.3@WV#0X-'@Y./E).'(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(H-8@X^#
M5X.)@Y.#:(FDC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B@UB#18-&@5N#9H.3B:2-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3
M=VET>F5R;&%N9"(*;7-G<W1R("*#6(-#@UB8099-(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I
M9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T
M97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@
M07)A8B!297!U8FQI8R(*;7-G<W1R("*#5H.*@T&!18-!@XF#=8NDF&&-D2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS
M9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M
M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135H-T
M@T"#0X.+(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R
M("*57)&ND*LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM
M<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("*57)&ND*LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`BD>28<"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED
M(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(I'DF'"!:9*&
MC9&"S(CJE92!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B@UZ#5X-,@UB#7H.3BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM
M<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("*#
M7H.3@U6#:H-!F$&638NDF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S(@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-#D*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B@UZ#6(-.(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N
M92!.=6UB97(B"FUS9W-T<B`BDV288I34C88B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E
M<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(H-E@Y.#=H.,@5N#9R!<(B5S7"(@@JJ"
MH(+H@MR"N8+Q@4(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I
M9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B@V6#DX-V@XR!
M6X-G@LR*QY>=(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(T"FUS9VED(")497AT(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E
M>'0@3VYL>2(*;7-G<W1R("*#98-,@UB#9X+,@MTB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")4
M97AT(&%L:6=N(@IM<V=S='(@(I6VCIJ4>I)U(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*
M;7-G<W1R("*5MHZ:@LR/XR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(I;8(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)4RTV,C`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM
M<V=S='(@(H->@T.)I(V1(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(D944""*9Y*C@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O
M<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*7FI?P@U:#6(-E@X""
MS9:SC/B"R8+(@L&"Q(*B@MR"MX%"(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO
M;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K
M+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN
M:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N8V4@@TZ#
MB8-8@LR3QXV>@MV"JI"SC^V"R8US@J:"W(*Y@O&"Q8*U@KTB"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B@TF#
M=H-6@X>#DX-%@T*#DX-H@T6"\)7"@K:"W(*U@KV!0H])E[F"M8+<@K>!0B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N(@IM<V=S='(@(B(*(H-!@TZ#6H-8C*""\)=,C/B"R8*W@NF"R8+-
MBL>7G8[2@JJ"NX+,@V^#8H-.@T>#DX-H@O"0W9+H@K>"Z8*Q@L:"JI5+EW:"
MQ8*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B*809>-D.9)1)34C8:"
MJHYWDNB"LX+J@LB"J8+!@KV"J8%!B_."OH+!@KV"J8%!@J""Z8*B@LV#9H%;
M@UZ#>(%;@UB2AH+)C*F5=(*I(@HB@NB"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B
M5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`BF$&7C9#F@LV"H(+(@KV"S(-!@VB#C(-8
MDJ""R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("*39(YQCY"6O(*S@NJ"O8.!@V*#6H%;@U>"
M\(R?C]B"MX+I@LF"S8%!4$=0((^0EKR"JI5+EW:"Q8*W@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I
M9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE
M(&1A=&%B87-E+B(*;7-G<W1R("(B"B*1EY!-D.9)1)34C8:"JHYWDNB"LX+J
M@LB"J8+!@KV"J8%!B_."OH+!@KV"J8%!@J""Z8*B@LV#9H%;@UZ#>(%;@UB2
MAH+)C*F5=(*I(@HB@NB"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@
M(I&7D$V0YDE$E-2-AH*JCG>2Z(*S@NJ"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R("*(PXV&B;N"R8+-B,"14X+(@T6#1H-UD-J1L8*JE4N7=H+%
M@K>!0B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@V(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3(X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B@W2#0(-#@XL@)7,@@LF"S2`E<R""S)#=DNB"JI5+D'N"Q8*W@4(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G
M<W1R("*#=(-`@T.#BR`E<R""R8+-("5S((+,D-V2Z(*JE4N0>X+%@K>!0B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B
M@W2#0(-#@XN"S8ZIE:J.J9!G@LF#4H-S@5N"Q8*K@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("*#=(-`@T.#BX*J@V:!6X->@O"*
MW(+Q@L6"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE
M(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS
M9W-T<B`BB,B)NH+-@K&"S(.!@V*#6H%;@U>!:5)&0S@R,H%J@LR#=X-B@U^"
MQ8*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N(@IM<V=S='(@(B(*(I*-B-.!22"#=(.+@UB#3H.*@5N#DX."
M@5N#:(+-($EN=&5R;F5T($5X<&QO<F5R((+%@LV6XI'H@JJ4K9"V@K>"Z8*Q
M@L:"JH*@@N@B"B*"W(*W@6F#=8.)@T6#58+,@V^#3X+%@K>!:H%"B>:6RH+)
M@U.#?H*JE5R.IH*S@NJ"O8+H@4%7:6YD;W=S((*J@TZ#B8-B@U:#A8*U(@HB
M@KV"Z(*W@NF"J8+@@K6"ZH+<@KF"\8%"7&XB"B*#=(.+@UB#3H.*@5N#DX."
M@5N#:(+)@K>"Z8+(@N<@3TL@@O")GX*U@L2)NH*S@J*!0B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))1"!<
M(B5S7"(@@LV-[8^<@K."ZH+<@K6"O8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB1VYU4$<@@V^#0X-I@XJ"S(-P
M@UB"JB!#<GEP=%]P9W`@@TZ#B8-8@LF0W9+H@K."ZH+$@J*"Z95+EW:"JH*@
M@NB"W(*W@4(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@
M)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y
M960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-`IM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I
M9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G
M<W1R("*"L8+,@W2#0H%;@XN#:(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*
M;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R
M>7!T7W-M:6UE@TZ#B8-8@LF"S6]P96YS<VR#@H-7@X6!6X.+@JJ52Y=V@L6"
MMX%"(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B
M"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(H-V@XR#=(-`
M@XR#DX-87"(E<UPB@LV#9H%;@UZ"JH-4@T.#69"GC,""\(EZ@J:"O8*]@M^5
MVY&V@L6"JX+<@KF"\8+%@K6"O2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(H*Q
M@LR#9H%;@UZ,7B@E<RF"\)5<CJ:"MX+I@KV"WX+,@W:#C8-/@XF#@(*J@K&"
MS(-6@UB#98.`@LF"W8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(HCXEW"5
MA(+-@E"5MHZ:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@
M(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-SD*;7-G:60@(E1H
M92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`BB^:0V(+HE82"S8)0E;:.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("*#5(%;@V\@7"(E<UPB((+-C>V/G(*S@NJ"W(*U@KV!0B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*
M;7-G<W1R("*#5(%;@V\@7"(E<UPB((+-E=N1MH*S@NJ"W(*U@KV!0B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(HYWDNB"M8*]E_&!
M:25D@6J"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@
M9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(HCJCIZ#=(-`
M@T.#BR!<(B5S7"(@@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,CDY"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I
M9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N(@IM<V=S='(@(H-!@V*#=H.-@5N#:(-F@5N#7H*JDKR13X+,
M@UB#98-B@W:"Q8_!CKB"M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N(@IM<V=S='(@(H-!@V*#=H.-@5N#:(-F@5N#7H+PE=N1MH+%@JN"W(*Y
M@O&"Q8*U@KV!0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B@V6!6X-]@V:#0H.,@TZ#9X.*@5L@7"(E<UPB((*J@J""Z(+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G
M:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B
MCG>2Z(+%@JN"Z8-)@W:#5H.'@Y."S8*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T.`IM<V=I9"`B5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM
M<V=S='(@(H-#@Y.#B8-#@Y.57(ZF@L6"JX+IE925JH+-@J""Z(+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB
ME;:.FI"4@JJ"L8+,@W2#0H%;@XN#:(+)D;V)WX*L@MR"MRX@)7,@@LR5MHZ:
M@JJ3_)?-@K."ZH+$@J*"W(*W+B`E<R"(R(FZ@L6"R"(*(H*M@L2"S8*B@J^"
MW(*Y@O&!0B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(EPB)7-<(B""
M\(-6@UB#98.`@M:2QXG!DH:"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("*#AH%;@U4@7"(E<UPB((+,
M@V:!6X->@O"#5H-8@V6#@(*I@N>/P8N.DH:"R9;BD>B"JI2MD+:"M8+<@K6"
MO3HB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B7"(E<UPB((+P@U:#6(-E@X""J8+GC>V/
MG)*&@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")<(B5S7"(@@O"-6)!6DH:"
MR9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+B(*;7-G<W1R("(B"B*#=(-`@T.#BX-!@V*#=H.-@5N#:(+)
MEN*1Z(*JE*V0MH*U@MR"M8*].B`E<R""S8-!@V*#=H.-@5N#:(*S@NJ"Q(*B
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS
M9W-T<B`B(@HB@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<
M@K6"O3H@)7,@@LV#=(-`@T.#BX+,@U2#0X-9D*>,P))L*"5D@V^#0R(*(H-G
M*8+PB7J"IH+$@J*"W(*W@4(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB@W2#0(-#@XN#
M08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,@@LV(ZI64@LR"
MW8-!@V*#=H.-@5N#:(*S@NJ"W(*U(@HB@KV!0B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S
M='(@(H*Q@LR#<(%;@V>"\)5<CJ:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KTB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N(@IM<V=S='(@(IA!EXV0YH-F@5N#7H+,@T.#DX-\@5N#9Y*&@LF#
M1X.)@5N"JI2MD+:"M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B:4-A;&5N9&%R((+,
M@T.#DX-\@5N#9Y*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O2XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HBD-V2
MZ(-T@TB!6X.`DH:"R8-'@XF!6X*J@J""Z(+<@K6"O8%"@KV"U(+Q@4&52Y![
MC8"6VH*JB_.4DH*^@L&"O8+,@L6"M8+E@J2!0B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HBCG>2Z(*S@NJ"O8-!@VB#C(-8DJ""S)&`C>R2AH+)
M@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K,B
M"B*"HH%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("*809>-D.:"S(_:C=>"\(U8D%:2AH+)@T>#B8%;@JJ4
MK9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(I&7D$V0YH.*@UB#9X+,C5B05I*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"
MC.."Q8W$DWB.P(US@K6"Q(*M@KZ"LX*B@4(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S
M='(@(H*Q@LP@24U!4""#5(%;@V^"S8NDETR#=(-(@XN#7X+P@U2#?(%;@V>"
MM8+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(H*Q@NJ"S9=,C/B"R"!R
M87(@@T&!6X-*@T.#=8+%@LV"R(*B@N:"I(+%@K>!0B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@
M(H*Q@NJ"S9=,C/B"R"!Z:7`@@W2#0(-#@XN"Q8+-@LB"HH+F@J2"Q8*W@4(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(T"FUS9VED(")4:&ES
M(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS
M9W-T<B`B@K&"ZH+-ETR,^(+(@TJ!6X-HE-2-AH+%@LV"R(*B@N:"I(+%@K>!
M0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*
M(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC
M;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,3(*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$W.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4S"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,Y-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,S8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DU-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`R
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`W-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,30V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,3@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#0W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.30*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S@P,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS.#$P"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R
M("*"L8+,@W2#0H%;@XN#:(+-E4N0>X+%@K>!0B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-C(*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B@K&"S(-T@T*!6X.+@VB"S9"N
MD)2"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0Q,PIM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B@K&"S(-T@T*!
M6X.+@VB"S9"4CIJ"QH-2@XV#DX+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DQ"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("*"
ML8+,@W2#0H%;@XN#:(+-.)!ID)2"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,`IM<V=I9"`B5&AI<R!F
M:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@
M;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB@K&"S(-T@T*!6X.+@VB"S8-2@Y.#
M?8+<@KV"S8OSE)*"Q8OFD-B"YX+J@KV0KI"4@LR#BH-8@V>"Q8+(@JV"Q(+-
M@J*"KX+<@KDB"B*"\8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3@V"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(H*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G
M:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F
M)RXB"FUS9W-T<B`B@K&"S(-T@T*!6X.+@VB"S3$VD&E21T*57(M,@LR01H-2
M@5N#:(+(@JV"Q(+-@J*"KX+<@KF"\8%"E^$Z)R,Q,C,T868G+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4U.`IM<V=I9"`B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("*"L8+,@W2#2(%;
M@X""S8KY@LF/B)>=@K."ZH+$@J*"W(*W@4(B"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0V
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DW"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M("(B"B*"L8+,@X&#8H-:@5N#5X+-@J""R(*]@JJ.9Y=P@K>"Z8+,@L:(V8+(
M@NF5MHZ:@UJ#8H-G@6DE<X%J@L6/D8*I@NJ"Q(*B@MR"MX%"(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("*"L8+,E-2-AH+-
MC<6/K(+%@N`Q@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM
M<V=S='(@(H*Q@LR#5(%;@V^"Q8+->FEP@L9G>FEP@W2#0(-#@XN"\)-7BDJ"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R("*"L8+,@U:#6(-E@X""S8CJCIZ328+)EK.,
M^(+)@LB"P8+$@J*"W(*W@4(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+B(*;7-G<W1R("*"L8+,DFR"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I
M9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS
M('=I;F1O=R(*;7-G<W1R("*"L8+,@T6#0H.3@VB#18+-@TF#=H-6@X>#DX-%
M@T*#DX-H@T6"J8+GC,2/;X*S@NJ"Z95+EW:"JH*@@NB"W(*W@4(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C(@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(HZ>BM0B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM
M<V=S='(@(H->@T.#@(-6@5N#9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`BCIZ*U(^1CJXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3(X"FUS9VED(")4:6UE('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,
M97-T92(*;7-G<W1R("*3C(-E@T*#@H%;@XN6KX[EBZ2888V1(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B@UZ#0X-G
M@XLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(I6AD)2"
MS(V`EMJ"\)%)D?""MX+I@LF"S8%!4$."Q8+-0V]N=')O;(-,@T.!04UA8X+(
M@N=#;VUM86YD@TR#0X+PB9^"M8+(@JJ"YX-.(@HB@XJ#8H-.@K6"W(*W@4(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4
M;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS
M9W-T<B`B2%1-3(-<@5N#6)5<CJ:0V)'6(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&]G;R(*;7-G<W1R("*#9X%;@U.+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VME;&%U(@IM<V=S='(@(H-G@U"#B8-%CY23AR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S
M='(@(H-G@Y.#2XFDC9$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B
M+G!H<#HQ,#0*;7-G:60@(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN
M9R!T:&4@;&%S="!M:6YU=&5S+B(*;7-G<W1R("*"L8+,D)25JHK4@LF)O9-X
M@N"#C8-/@T.#DX*JCHZ-<X*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED
M860@86YD(%1O8F%G;R(*;7-G<W1R("*#9X.*@VJ#7X%;@VB!18-G@V^#4XND
MF&&-D2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.#<*;7-G:60@
M(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B
MB<XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(H-@
M@X6#:H-7@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB
M"FUS9W-T<B`B@V>#BX-2BZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("*#
M9X.+@TZ#@8-J@UB#7H.3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(H->@5N#3H-8@46#2H-#@U*#
M6(^4DX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B
M@V.#;X.+(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B
M5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(I%)D?"!1B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")5
M4DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")5
M4DPZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*
M;7-G<W1R("*#18-+@Y.#7XNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E5K<F%I;F4B"FUS9W-T<B`B@T6#3H.)@T.#:2(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*@LF#08-.
M@UJ#6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(E9&4R"#=(-`@T.#BR!<(B5S7"(@@LR#08-.@UJ#
M6(R@@LV5SXU8@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,SDR(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B5D93((-T@T"#0X.+
M("5S+R5S((+,@T&#3H-:@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(B5S((+)E<^-
M6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("*#=(-`@T.#BR!<(B5S7"(@@LR#
M5(-#@UF"JH-@@T:#8H-.@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P
M,C@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M(%PB)7,O)7-<(BXB"FUS9W-T<B`B@W2#0(-#@XL@7"(E<R\E<UPB((+,@U2#
M0X-9@JJ#8(-&@V*#3H+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N(@IM<V=S='(@(E-13""#5(%;@V^"R9#:D;&"Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,`IM<V=I
M9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(E-33"""
MQ9#:D;&"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,S(@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,W"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92XB"FUS9W-T<B`B5D93((-T@T"#0X.+@O"#4H-S@5N"Q8*K@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*(%PB)7-<(B""\(WLD*R"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M-C$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G
M@XJ"\(WLD*R"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"\(WLD*R"Q8*K@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*(%PB)7-<(B""\(WLD*R"Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S(*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@
M(HOS@LP@5D93((-T@T"#0X.+@O"-[)"L@L6"JX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("*#9H%;@UZ"\(BSCVN"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R
M."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(EPB)7-<(H+PC>V/G(+%@JN"W(*Y
M@O$N((-F@T*#C(-.@V>#BH*JB_."Q8+-@J""Z(+<@KF"\8%"(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B7"(E<UPB@O"-[8^<@L6"JX+<@KF"\3H@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,SDU"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(E<X+PC>V/G(+%@JN"W(*Y
M@O$N((-F@T*#C(-.@V>#BH*JB_."Q8+-@J""Z(+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(E9&4R"#9H-"
M@XR#3H-G@XJ"\(W$BT&328+)C>V/G(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G
M@XJ"\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*@O"-[8^<@L6"JX+<
M@KF"\8%&)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B5D93((-T@T"#0X.+(%PB)7-<(B""\(WMCYR"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,3`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.3$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"\(WMCYR"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*(%PB)7-<
M(B""\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(E9&4R""\(W$BT&3
M28+)C>V/G(+%@JN"W(*Y@O&!1B5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN(@IM<V=S='(@(HR[C=V"S(-F@T*#C(-.@V>#BH%;@JJ3
MP9+H@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',B"FUS9W-T<B`BC]B6OH^1@LR/VHW7@JJ.YH+HCV^"N8+<
M@KF"\2(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S
M+B(*;7-G<W1R("(E<R""S)+HBV""JH.-@5N#:(+%@JN"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y
M"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B5D93
M((-T@T"#0X.+@JJ(VI.N@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P
M-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8U,B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93((-T@T"#
M0X.+(%PB)7-<(B""JHI*@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(X-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*
M;7-G<W1R(")61E,@@W2#0(-#@XN"\(^1@JN-GH+=EW""R8I*@J^"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@S(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"JHI*@J^"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`BB+./
M:X^1C,F#=(-`@T.#BX+PBDJ"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93((-T@T"#0X.+@JJ3
MQX+?@MR"N8+Q@6EF:6QE<VEZ92@I((-'@XF!6X%J@4(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@
M9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R(")61E,@@W2#
M0(-#@XN"JI/'@M^"W(*Y@O&!:6=E=$9I;&53:7IE*"D@@T>#B8%;@6J!0B(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N
M;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S
M='(@(E9&4R"#=(-`@T.#BX*JD\>"WX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@@V:#0H.,
M@TZ#9X.*@O"3QX+?@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$Q,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(I:\D4\@)7,@@O`@)7,@@LF5SXU8@L6"JX+<@KF"\8%&
M@W2#2(.+@U^!6X+-BOF"R9&VC=V"M8+<@K<B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ!6X+,
MEKR13X+PE<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(E9&4R"#9H-"@XR#
M3H-G@XJ!6X+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!1B5S(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R"#=(-`@T.#BR!<(B5S
M7"(@@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C$W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B5D93((-T@T"#0X.+("5S+R5S((+,
MEKR13X+PE<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S(V(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4N(@IM<V=S='(@(E9&4R"#=(-`@T.#BX+,EKR13X+PE<^-6(+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(H*Q@LP@5V]R9""5MH^1@O"6?);S
M@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-30@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B5D93((-T@T"#0X.+(%PB)7-<(B""R8^1@J^"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M5D93((-T@T"#0X.+@LF/D8*O@MR"N8+Q@6EC;W!Y*"F.N)1S@6J!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X."!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"R8^1@J^"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS
M9W-T<B`B5D93((-T@T"#0X.+@LF/D8*O@MR"N8+Q@4)Q=6]T82""\)*TB=^"
MM8*]@N:"I(+%@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("*)NI#\
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#
M:&%N9V5S(@IM<V=S='(@(I7/C5B"\([F@NB/P8*W(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S
M('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BC<6,XX+,D8"-[(+PC+."R9;?
M@K<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ("(*;7-G<W1R("*0VI&QCIZ"S(-4@5N#;X%;@JF"YX+,EUR*
M^H*U@LB"HHF>DYJ!1B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,SD*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!T;SH@(@IM<V=S='(@(H-4@5N#;X%;@JF"YX+,EUR*^H*U@LB"HHF>DYJ!
M1B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(I:BD*Z7G2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M
M:7)A=&5S(@IM<V=S='(@(H-!@XF#=8[QDK>-D9A!EDTB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(HEPC9$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(I7$C9$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`BE<27S)&^E;V7;8^4DX<B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0S,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(I5SEKXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*
M;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI5S
MEKZ"Q8*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E
M;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(I:SEKPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS
M9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U
M="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*
M(H-:@TR#A8.*@V6#0H%;C^."S)>=EU*"J8+GD\&,H(+,EK."HH-8@TZ#BH-V
M@V>"S2!#=70O0V]P>2]087-T92""Q8*K@MR"N8+Q@4(B"B)/2R""\(-.@XJ#
M8H-.@K>"Z8+&@4&"QX*D@N*"P8+$@TZ#BH-B@W:#>X%;@VB"R8-!@TZ#6H-8
M@K>"Z8*I@L:"HH*D(&UO>FEL;&$N(@HB;W)G((+,BUJ/<)6VCY&"\(RI@NF"
ML8+&@JJ"Q8*K@MR"MX%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P
M<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("*#5(-\@5N#9X*U@L2"HH+(@J**
M9Y*CCG&"Q8*W(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P
M9&%T92(*;7-G<W1R("*-6)!6(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B
M"FUS9W-T<B`B)7,@@O"-6)!6@K>"Z8%"(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T
M<B`B@X:!6X-5@O"-6)!6@K>"Z2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"(@@O"-6)!6@K6"W(*U@KV!0B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D
M96QE=&5D+B(*;7-G<W1R("*-6)!6@UB#3H.*@W:#9X+PC>V/G(*U@MR"M8*]
M@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*
M;7-G<W1R("*#08-B@W:#C8%;@V@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@
M9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`BD5."Q(+,@T&#=H.*@U"!
M6X-6@X>#DX+,D-V2Z(-T@T"#0X.+@O"#5(%;@V^"R8-!@V*#=H.-@5N#:(*U
M@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(H.)@V6#DY6VCIJ!:9'EE;:.FH%J(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I
M9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("*#C8%;@WV0E(Z:@6F1
MY96VCIJ!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T
M<B`B@T6#BX-/@T&#0Y.,E?N+I)AAC9$B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`BC+N-W8+,DFR"\(YGEW"!
M1B5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B4U-,((+PCF>7<"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM
M<V=S='(@(DE-4U`@@U2!6X-O@LR#AH%;@U66O(%>@W"#6(./@5N#:(*JB-F"
MR(+IC^J-AX+)CF>7<(*U@MR"MX%"(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R("*#AH%;@U4B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RXB"FUS9W-T<B`B@X:!6X-5("5S((+-("5S((+%E$:/V(*S@NJ"
MQ(*B@MR"N8+Q@4(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B@X:!6X-5BL>7G2(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P
M=&EO;G,B"FUS9W-T<B`B@X:!6X-5@TF#=H-6@X>#DR(*"B,Z('-I9VYU<"YP
M:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(H.&@5N#
M59-OF%XB"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R
M("*#AH%;@U6"S)-OF%Z"S8*Q@LR#5(-#@V>"Q8+-B]:.?H*S@NJ"Q(*B@MR"
MMX%"(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E
M<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("*#AH%;@U6!6X-!@TJ#18.3
M@V>"JH*@@NB"W(*Y@O&!0H%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I
M9"`B57-E<FYA;64B"FUS9W-T<B`B@X:!6X-5EKPB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B@X:!
M6X-5EKP@7"(E<UPB((+-BOF"R8*@@NB"W(*W@4(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M("*#AH%;@U66O#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(H.&@5N#59:\.B`B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I
M;B!T:&4@<WES=&5M.B(*;7-G<W1R("*#5H-8@V6#@)*&@LR#AH%;@U6!1B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B@T6#
M68-X@TR#6(->@Y.+I)AAC9$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R"FUS9VED
M(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO
M;B(*;7-G<W1R("*+>(G)(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#8S"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R("*73(SXD*LB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U,R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3<T"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#,*;7-G:60@(E9A;'5E<R!T;R!S
M96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")6
M86YU871U(@IM<V=S='(@(H-O@VN#08-CBZ2888V1(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@
M(H-X@VR#68-'@XF!18-[@XJ#;X.+BZ2888V1(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+B(*;7-G<W1R("*,GX_8CKB4<R`M((*Q@LR#@8-B@UJ!6X-7@LV)_.*"
M@K."ZH+$@J*"Z8+F@J2"Q8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("*4Q2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I
M;VX@0V]N=')O;"(*;7-G<W1R("*#;X%;@U>#AX.3BL>7G2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(H]CB,J2=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E
M<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<R"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B@WB#9X-I@X".T(GOCN6+
M8(NDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6
M:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(@IM<V=S='(@(B5S((+PC*F"Z2(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`BBD^5E(+,('=E8B"#>8%;@U>"\)5<CJ8B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("*)<)?,@V^!
M6X-7@Y./E).'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L(%4N4RXB"FUS9W-T<B`BE<27S(-O@5N#5X.3CY23AR(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O
M;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@
M(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("*#18-(@XJ#6(%%@W2#9X-$
M@5N#:8^4DX<B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BC'B-D"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E
M(@IM<V=S='(@(I"%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.#D*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B
M5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(I:(
MCU0B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B
M5V5L8V]M92(*;7-G<W1R("*"YH*D@K&"NR(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(B5S
M((+)@N:"I(*Q@KLB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B)7,@@K."\8%!@N:"I(*Q@KLB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B
MD+R#5(-N@XDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B5S@XV#3X-#@Y.,XX+'@LR#
M08-V@XJ#4(%;@U:#AX.3@O"57(ZF@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("*+YI#8@NB5MHZ:@LV)O8+%@K>"
MJ8%((@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@
M(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`BB/B7<)6V
MCIJ"S8F]@L6"MX*I@4@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`V-0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B
M5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B@V6#3(-8@V>#1X-F@T*#
M7H%;@LR#=H.)@T^#0X.3@O"129'P@K6"W(*W@4(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7
M:61T:"(*;7-G<W1R("*5G2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,#0*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("*-MH+)DG6"K25S@X&#
M:H.%@5N"S)6=@6F.GXGQ@LR#C8-/@T.#DX*I@N>73(SX@6HZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@
M(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("*57(+,E9TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B
M5VED=&@@=6YI="(*;7-G<W1R("*5G8+,DE"(RB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB
M"FUS9W-T<B`BE9V!1B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS
M9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS
M9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`BEWZ"M8*B@N""
MS(CJEY<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O
M<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BB\Z6
ML9#F@LR/6H^*(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("*+SI:QD.:"
MS)-DF&*4U(V&(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B)60@C7.6VH+%BM2(X8+!
M@KV-@);:D)2!0I"S@K6"K8+-("5D@4&.=Y+H@K."ZH*]@LR"S2`E9(%"(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`BBM2(X8+!@KV-@);:D)2!0I"S@K6"K8+-
M("5D@4&.=Y+H@K."ZH*]@LR"S2`E9(%"(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F
M9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(E9&
M4X-T@T"#0X.+@LR3QX+=CV^"M9*&@LF5<Y"S@LB#28-T@UJ#8H-G("5D((*J
MCG>2Z(*S@NJ"W(*U@KV!0B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S((KNEGN0IXS`(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S((RNCF>7<)9`
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B
M6#4P.78S(([ED<R.TH+,E<J6O"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@CN61S([2@LR,KHZOE<J.<2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8
M-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@BF>2HXM`E%PB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`BE$XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*
M;7-G:60@(EE965DB"FUS9W-T<B`BE$XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`BEHB43B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(H-#@T>#@8.3BZ2888V1
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M-@IM<V=I9"`B665S(@IM<V=S='(@(H+-@J(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(I.OB-."M8+<@K<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RXB"FUS9W-T<B`BC:&"S8-E@TR#6(-G@X*!6X-H@L6"MX%"
M6SP^78-[@UZ#DX+%5UE325=91X."@5N#:(+)EM^"Z(+<@K>!0B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B5D((C(C^."S(-U
M@XV#8H-.@O"-[)"L@K>"Z8*Q@L:"S8N6B<*"LX+J@L2"HH+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(T"FUS9VED(")9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("*"H(+(@KV"S91&C]B"
MLX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C
M:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(I:\D4^"S)*&
M@LD@)UQ<)R""QH*B@J25MHZ:@LV.9X*F@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S(*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RXB"FUS9W-T<B`BETR,^(+(DV2.<8.!@5N#BX-!@VB#C(-8@L6"
MS8*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@
M9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O
M;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B*#0X.3@WR!6X-G
M@K."ZH*]@W2#0(-#@XN"S(-T@T*!6X.+@VB"\"5SD^""S)'.B9Z"MX+I@W2#
M0H%;@XN#:(+)@WV#8H-V@K6"Q(+<(@HB@KF"\2XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D
M(&]U="XB"FUS9W-T<B`B@XV#3X-!@T6#9X*U@MR"M8*]+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-3@*;7-G:60@(B(*(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@
M=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B*0LX*U@J*39)ABE-2-AH+P
MD_R7S8*W@NF"YH*D@LF2C8C3@K6"Q(FZ@K."HH%"D)2.FH*^@J^"JHYGEW""
MQ8*K@MR"MX*J@4&-D8W;(@HBDV288H+(@N>0YI.J@LF!>X+PE72"KX+<@K>!
M0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#4*;7-G:60@(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(I"S@K6"
MHI)L@O"3_)?-@K6"Q(FZ@K."HH%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B*#
M5(-#@Y.#08-B@W:"\)>8EW""MX+I@KV"WX+)@LT@1&%T851R964@@V^#8H-.
M@T>#DX-H@O"0W9+H@K>"Z95+EW:"JH*@@NB"W"(*(H*W@4(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W,0IM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E9&4R"#;X-B@TZ#1X.3
M@VB"\)#=DNB"MX+IE4N7=H*J@J""Z(+<@K>!0B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="XB"FUS9W-T<B`BC^&*48+,D^"798+PBTR/<8*U@L2"J8+G@4&/
MX8I1@XR#?(%;@V>"\)&7D$V"M8+$@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*
M;7-G<W1R("*"L8*Q@LF#BH.3@TZ"MX+I55),@O"3_)?-@K6"Q(FZ@K."HB(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(HWMCYR"MX+I@U2!6X-O@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(H_!BXZ"MX+I@X:!6X-5EKR"
M\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB
M"FUS9W-T<B`BC>V/G(*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N(@IM<V=S='(@(I+'B<&"MX+I@X:!6X-5EKR"\(YWDNB"
MM8+$@JV"OH*S@J*!0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G
M<W1R("*-6)!6@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB
M"FUS9W-T<B`BCL"-<X*W@NF#08-.@U:#AX.3@O".=Y+H@K6"Q(*M@KZ"LX*B
M@4(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R("*05H*U@J*5JI?>EKR"\)/\E\V"M8+$B;J"LX*B@4(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N
M('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B5S((-:@V*#5H.'@Y."S)=,C/B*^HS`@JJ0V(+J@L2"HH+<@K>!0H.-@T^#
M0X.3@K62O(*U@L2"K8*^@K."HH%"(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G
M<W1R("*39(YQ@X&!6X.+@T&#:(.,@U@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(H*@@LB"O8+,($9R;VTZ((-!@VB#C(-8(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS
M9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(H*@@LB"O8+,@T.#DX-T
M@TB#@8%;@U:#AX.3(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB@UJ#8H-6@X>#DR`E<R""S(K4
M@LF"H(+(@KV"S(-!@VB#C(-8@JJ5SXU8@K."ZH+<@K6"O8%"@UJ#3(.%@XJ#
M98-"@5N5VXSL@LR"O2(*(H+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(H*@@LB"O8+,EKR13R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A
M=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B*"L8+,E$:/V(-O
M@V*#3H-'@Y.#:(+%@LV!08.&@5N#58+,DL>)P8*J@U2#?(%;@V>"LX+J@L2"
MHH+<@KF"\8%"@N""M2!(;W)D92""Q2(*(H.&@5N#58-!@TJ#18.3@V>"\(K'
MEYV"M8*]@J*"S(+(@N>!09&\@LR41H_8@V^#8H-.@T>#DX-H@O".9X*D@M>"
MJX+%@K>!0B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G
M<W1R("(B"B*"L8+,E$:/V(-O@V*#3H-'@Y.#:(+%@LV!08.&@5N#58+,@XJ#
M6(-G@JJ#5(-\@5N#9X*S@NJ"Q(*B@LB"HH*I@4&"H(+I@J*"S8F](@HB@N>"
MJ8+,EYV74H+%@K&"S(M`E%R"JI:SC/B"R8+(@L&"Q(*B@MR"MX%"(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB@UJ#8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-U@XF#
M18-5@JJ5SXU8@K."ZH*]@N:"I(+(@LR"Q8%!@UJ#3(.%@XJ#98-"@5N5VR(*
M(HSL@LR"O8+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HU-PIM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("*"J(YG@J*"S(-U
M@XF#18-5@LV"L8+,BT"47(+P@U2#?(%;@V>"M8+$@J*"W(*Y@O&!0B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO
M;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS
M9W-T<B`B(@HB@JB.9X*B@LR#=8.)@T6#58+-@K&"S(CSC?R#28-V@U:#AX.3
M@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"0V]N=')O;"]#;VUM86YD("(*(BL@
M4"""Q8CSC?R"M8+$B;J"LX*B@4(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M("*#7H-#@X"#78%;@Y.!1B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*
M;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D
M+B(*;7-G<W1R("*"H(+(@KV"S(-F@W2#2(.+@V=)1(+-E<^-6(*S@NJ"W(*U
M@KV!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B@J""R(*]@LR#9H-T@TB#
MBX-G240Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B
M66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(H*@@LB"O8+,CH&6O"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H
M87,@97AP:7)E9"XB"FUS9W-T<B`B@XV#3X-#@Y."S8KZC,"0V(+J@L6"MX%"
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*
M;7-G<W1R("*05H*U@J(@)7,@EW""S(-P@UB#CX%;@VB!1B5S(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B@J""R(*]@LR#28-V@U:#AX.3@LV,NXW=
M@LR#6H-B@U:#AX.3DH:"R97/C5B"LX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("*#28-V@U:#AX.3@O"-6)!6
M@K6"W(*U@KTB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM
M<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("*#
M<(-8@X^!6X-H@LV#BH-:@V*#9X*S@NJ"W(*U@KV!0B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB@W"#6(./
M@5N#:(+-@XJ#6H-B@V>"LX+J@MR"M8*]@LR"Q8%!D%:"M8*B@W"#6(./@5N#
M:(+%@XV#3X-#@Y."M8+$@MV"Q(FZ@K,B"B*"HH%"(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("*#<(-8@X^!6X-H@JJ*^HS`D-B"ZH+%@K>!0B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U
M<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B@XJ#@H%;@V>#5(%;@V\Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R
M("*#AH%;@U.#6(.)@W*#02(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(H-5@T.!6X.+BZ2888V1
M@6F#4H.3@U.6KX[EBZ2888V1@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):
M86UB:6$B"FUS9W-T<B`B@U6#DX-R@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R("*#5X.3@V^#=8-'BZ2888V1(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0
M<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B@6V/X8I1E?&-D(%N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T
M<B`B6XUS.B5S+R5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34U-"!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B7T&*QY>=(@H*(SH@;&EB+V%P:2YP:'`Z
M,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B
M7T1E;&5T92!2;W<B"FUS9W-T<B`B7T2-<X+PC>V/G"(*"B,Z(&QI8B]A<&DN
M<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1X-/@XN!6X-V(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B
M7TAE;'`B"FUS9W-T<B`B7TB#=X.+@W8B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E])B>:1G(-V@XV#<(-E@T(N+BXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(E],@XV#3X-#@Y,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G
M<W1R(")?3(.-@T^#08-%@V<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN
M:RXN+B(*;7-G<W1R(")?38.*@Y.#3I7/C5@B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R
M(")?3X-)@W:#5H.'@Y,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]0
M97)M:7-S:6]N<R(*;7-G<W1R(")?4(-!@TZ#6H-8C*`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G
M:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?4H.*@Y.#3HWMCYPB"@HC
M.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?4X-:
M@V*#9X-!@V*#=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B7U257)&ND*LB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G
M:60@(E]5<V5R<R(*;7-G<W1R(")?58.&@5N#52(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B@T&#:(.,@UB2H"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("*5
M<Y:^@LB#08-H@XR#6"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$W"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("*77)+HE5PB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@
M8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(H]OE\V#=(-`@T.#BX*JC>R0
MK(+%@JN"W(*Y@O$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`BD_R7
MS8-T@T"#0X.+@JJ*2H*O@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DX"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(H*Q@K&"\(-.@XJ#8H-.(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*
M;7-G<W1R("*#4H-]@Y.#:(USCF>7<(+,@T>#B8%;(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`BD-V2Z(-'@XF!6R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(H]DEW:"R(-6@UB#98.`@W2#0(-#
M@XN"S(R'EXXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B@V:!6X->
MC&".KH-'@XF!6R(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*
M;7-G:60@(F5D:70B"FUS9W-T<B`BE=*/5R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B
M"FUS9W-T<B`BC8"6VH*J@J""Z(+<@KF"\2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")F86QL:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y.`IM
M<V=I9"`B9FEL92(*;7-G<W1R("*#=(-`@T.#BR(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C
M:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P
M"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B
M:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B@WJ#6(-GEKR"JI5SEKXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`BD_R/;Y?-@T>#B8%;(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R
M(@IM<V=S='(@(H-<@W2#9X-%@T:#09/@E92"S(-'@XF!6R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE
M<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<P"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@
M(FYA;64B"FUS9W-T<B`BEKR13R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H
M<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("*.P)&5@K."
MZH+$@J*"W(*Y@O$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B
M@MR"OH[`D96"LX+J@L2"HH+<@KF"\2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(H.!@X*2H"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B@W"!6X-:@Y.#9R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("*#08-.@UJ#6(+-BY&4VX*S@NJ"
MW(*U@KTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B@W.#3H-:@XLB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(H.*@X*!6X-G
M@L6"S(-V@XV#9X-2@XN#1X.)@5LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED
M(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(H-4@5N#<H-8E7.47"(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I
M9F9E<F5N8V5S(@IM<V=S='(@(HVWE:J"\)5<CJ8B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS
M,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G
M<W1R("*#5H-8@V6#@(-'@XF!6R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B@UZ#6(-.@XJ#
M6(-G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*
M;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(HCJCIZ328+(@T>#
MB8%;(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(*;7-G<W1R("**;91&@LR"O8+?@W"#6(./@5N#:#*3
M>)/\E\V"M8+$B;J"LX*B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I
M9"`B=6YN86UE9"(*;7-G<W1R("*6LY:\(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R
M('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T
M,@IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!O+W1R86YS;&%T:6]N+G!H<```````````````
M````````````````````````````````````````````````````````````
M,#$P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-38R-S``,3`U,34T,S$P
M-C,`,#(P,3$R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<"`M<0H\/W!H
M<`HO*BH*("H@5')A;G-L871I;VX@:&5L<&5R(&%P<&QI8V%T:6]N(&9O<B!T
M:&4@2&]R9&4@9G)A;65W;W)K+@H@*@H@*B!&;W(@=7-A9V4@:6YF;W)M871I
M;VX@8V%L;#H*("H@+B]T<F%N<VQA=&EO;BYP:'`@:&5L<`H@*@H@*B`D2&]R
M9&4Z(&AO<F1E+W!O+W1R86YS;&%T:6]N+G!H<"QV(#$N.3$N,BXQ-B`R,#`V
M+S`U+S(S(#`R.C$S.C0S('-E;'-K>2!%>'`@)`H@*B\*"F9U;F-T:6]N(&9O
M;W1E<B@I"GL*("`@(&=L;V)A;"`D8RP@)&-U<F1I<CL*"B`@("`D8RT^=W)I
M=&5L;B@I.PH@("`@)&,M/G=R:71E;&XH)U!L96%S92!R97!O<G0@86YY(&)U
M9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N)RD["@H@("`@8VAD:7(H)&-U
M<F1I<BD["B`@("!E>&ET.PI]"@IF=6YC=&EO;B!U<V%G92@I"GL*("`@(&=L
M;V)A;"`D;W!T:6]N<RP@)&,["@H@("`@:68@*&-O=6YT*"1O<'1I;VYS6S%=
M*2`F)@H@("`@("`@("@D;W!T:6]N<ULQ75LP72`]/2`G:&5L<"<@)B8@(65M
M<'1Y*"1O<'1I;VYS6S%=6S%=*2!\?`H@("`@("`@("%E;7!T>2@D;W!T:6]N
M<ULQ75LP72D@)B8@:6Y?87)R87DH)&]P=&EO;G-;,5U;,%TL(&%R<F%Y*"=C
M;VUM:70G+"`G8V]M<&5N9&EU;2<L("=E>'1R86-T)RP@)VEN:70G+"`G;6%K
M92<L("=M97)G92<I*2DI('L*("`@("`@("!I9B`H)&]P=&EO;G-;,5U;,%T@
M/3T@)VAE;'`G*2!["B`@("`@("`@("`@("1C;60@/2`D;W!T:6]N<ULQ75LQ
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8VUD(#T@)&]P=&EO
M;G-;,5U;,%T["B`@("`@("`@?0H@("`@("`@("1C+3YW<FET96QN*"=5<V%G
M93HG("X@)R!T<F%N<VQA=&EO;BYP:'`@6V]P=&EO;G-=("<@+B`D8VUD("X@
M)R!;8V]M;6%N9"UO<'1I;VYS72<I.PH@("`@("`@(&EF("@A96UP='DH)&-M
M9"DI('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)T-O;6UA;F0@;W!T:6]N<SHG*3L*("`@("`@("!]"B`@
M("`@("`@<W=I=&-H("@D8VUD*2!["B`@("`@("`@("`@(&-A<V4@)V-L96%N
M=7`G.@H@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C
M86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XG*3L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D
M=6QE+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)V-O;6UI="<Z"B`@("`@("`@("`@(&-A<V4@)V-O;6UI="UH96QP)SH*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO8V%L93UL
M;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@
M=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M32P@+2UM97-S86=E
M/4U%4U-!1T4@(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@
M=&AE(&1E9F%U;'0@;VYE<RXG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"<@("UN+"`M+6YE=R`@("`@("`@("`@("`@5&AI<R!I<R!A(&YE=R!T
M<F%N<VQA=&EO;BP@8V]M;6ET(&%L<V\@0U)%1$E44RPG*3L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@("`@("`@
M0TA!3D=%4R!A;F0@;FQS+G!H<"YD:7-T+B<I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@)V-O;7!E;F1I=6TG.@H@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6$L("TM861D/49)3$4@("`@("`@
M($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T
M;R<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F
M97)E;G0@8G)A;F-H('1O)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@G("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP
M96YD:75M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+60L
M("TM9&ER96-T;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@
M9&ER96-T;W)Y+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92XG*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=E>'1R86-T
M)SH*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L
M93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@8V%S92`G:6YI="<Z"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92XG
M*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)R`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M
M(&9I;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L="<I.PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@
M*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN)RD[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@($1O;EPG="!U<V4@82!C;VUP96YD:75M+B<I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VUA:V4G.@H@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C86QE/6QL7T-#
M("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@
M34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XG*3L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UC+"`M+6-O;7!E;F1I=6T]
M1DE,12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I
M=6T@9FEL92<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@
M("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F('1H92!D969A=6QT(&]N
M92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4G*3L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@
M9&ER96-T;W)Y+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VY<)W0@;65R9V4@;F5W('1R86YS
M;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2XG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("US+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T
M<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL92XG*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M86ME+6AE
M;'`G.@H@("`@("`@("`@("!C87-E("=U<&1A=&4M:&5L<"<Z"B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@
M(%5S92!O;FQY('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L
M<"!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VUE<F=E)SH*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO8V%L93UL
M;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!0
M3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6,L("TM8V]M<&5N9&EU;3U&
M24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@
M9&5F875L="<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@
M("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE
M(&AO<F1E+W!O(&1I<F5C=&]R>2DN)RD["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@G("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;EPG="!U<V4@
M82!C;VUP96YD:75M+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)W5P9&%T92<Z"B`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L
M92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L
M92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UC+"`M+6-O
M;7!E;F1I=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E
M860@;V8@=&AE(&1E9F%U;'0G*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"<@("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP96YD:75M
M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+B<I.PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)R`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$
M;VY<)W0@=7-E(&$@8V]M<&5N9&EU;2XG*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@)&,M/G=R:71E
M;&XH)U5S86=E.B<@+B`G('1R86YS;&%T:6]N+G!H<"!;;W!T:6]N<UT@8V]M
M;6%N9"!;8V]M;6%N9"UO<'1I;VYS72<I.PH@("`@("`@("1C+3YW<FET96QN
M*'-T<E]R97!E870H)R`G+"!3=')I;F<Z.FQE;F=T:"@G57-A9V4Z)RDI("X@
M)R!T<F%N<VQA=&EO;BYP:'`@6VAE;'!\+6A\+2UH96QP72!;8V]M;6%N9%TG
M*3L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("1C+3YW<FET96QN
M*"=(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T
M<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D92<I.PH@("`@("`@("1C+3YW<FET
M96QN*"=F<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N)RD["B`@("`@
M("`@)&,M/G=R:71E;&XH)T9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@
M9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN)RD["B`@("`@("`@)&,M
M/G=R:71E;&XH*3L*("`@("`@("`D8RT^=W)I=&5L;B@G0V]M;6%N9',Z)RD[
M"B`@("`@("`@)&,M/G=R:71E;&XH)R`@:&5L<"`@("`@("`@4VAO=R!T:&ES
M(&AE;'`@;65S<V%G92XG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!C;VUP
M96YD:75M("!296)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z
M(%1H:7,@;W9E<G=R:71E<R!T:&4G*3L*("`@("`@("`D8RT^=W)I=&5L;B@G
M("`@("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I=6TN)RD["B`@("`@("`@
M)&,M/G=R:71E;&XH)R`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA
M=&4@*"YP;W0I(&9I;&5S+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@(&EN
M:70@("`@("`@($-R96%T92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N
M97<@;&]C86QE+B!787)N:6YG.B!4:&ES)RD["B`@("`@("`@)&,M/G=R:71E
M;&XH)R`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@
M9FEL97,@;V8@=&AI<R!L;V-A;&4N)RD["B`@("`@("`@)&,M/G=R:71E;&XH
M)R`@;65R9V4@("`@("`@365R9V4@=&AE(&-U<G)E;G0@4$\@9FEL92!W:71H
M('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I;&4N)RD["B`@("`@("`@)&,M
M/G=R:71E;&XH)R`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E
M('-E<75E;G0N)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@=7!D871E+6AE
M;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D(&5N=')I97,@9G)O;2!T
M:&4@16YG;&ES:"!834P@:&5L<"<I.PH@("`@("`@("1C+3YW<FET96QN*"<@
M("`@("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI
M<W1I;F<@;VYE<RXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!C;&5A;G5P
M("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D
M(&%N9"!O8G-O;&5T92!E;G1R:65S+B<I.PH@("`@("`@("1C+3YW<FET96QN
M*"<@(&UA:V4@("`@("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H
M92!S<&5C:69I960@4$\@9FEL97,N)RD["B`@("`@("`@)&,M/G=R:71E;&XH
M)R`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE
M;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9"<I.PH@("`@("`@("1C+3YW
M<FET96QN*"<@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@9F]R('1H
M92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U)RD["B`@("`@
M("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N
M(&UA:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE
M)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@:&5L<"!F
M:6QE+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@(&-O;6UI="`@("`@($-O
M;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N)RD["B`@("`@
M("`@)&,M/G=R:71E;&XH)R`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL
M97,@=&\@=&AE($-64R!S97)V97(N)RD["B`@("!]"B`@("`D8RT^=W)I=&5L
M;B@I.PH@("`@)&,M/G=R:71E;&XH)T]P=&EO;G,Z)RD["B`@("`D8RT^=W)I
M=&5L;B@G("`M8BP@+2UB87-E/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(
M;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U;&0@8F4G*3L*("`@("1C
M+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@('5S960N)RD["B`@("`D
M8RT^=W)I=&5L;B@G("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE
M<W-A9V5S(&9R;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+B<I.PH@("`@)&,M
M/G=R:71E;&XH)R`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@
M;65S<V%G92XG*3L*("`@("1C+3YW<FET96QN*"<@("UT+"`M+71E<W0@("`@
M("`@(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VY<)W0@<G5N
M(&%N>71H:6YG+B<I.PI]"@IF=6YC=&EO;B!C:&5C:U]B:6YA<FEE<R@I"GL*
M("`@(&=L;V)A;"`D9V5T=&5X=%]V97)S:6]N+"`D8SL*"B`@("`D8RT^=W)I
M=&5L;B@G4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BXG*3L*("`@(')E
M<75I<F5?;VYC92`G4WES=&5M+G!H<"<["B`@("!F;W)E86-H("AA<G)A>2@G
M9V5T=&5X="<L("=M<V=A='1R:6(G+"`G;7-G8V%T)RP@)VUS9V-O;6TG+"`G
M;7-G9FUT)RP@)VUS9VEN:70G+"`G;7-G;65R9V4G+"`G>&=E='1E>'0G*2!A
M<R`D8FEN87)Y*2!["B`@("`@("`@96-H;R`D8FEN87)Y("X@)RXN+B`G.PH@
M("`@("`@("1'3$]"04Q36R1B:6YA<GE=(#T@4WES=&5M.CIW:&EC:"@D8FEN
M87)Y*3L*("`@("`@("!I9B`H)$=,3T)!3%-;)&)I;F%R>5TI('L*("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)&,M/F=R965N*"=F;W5N9#H@)RD@+B`D1TQ/
M0D%,4ULD8FEN87)Y72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)&,M/G)E9"@G;F]T(&9O=6YD)RDI.PH@("`@("`@("`@
M("!F;V]T97(H*3L*("`@("`@("!]"B`@("!]"B`@("`D8RT^=W)I=&5L;B@I
M.PH*("`@("1O=70@/2`G)SL*("`@(&5X96,H)$=,3T)!3%-;)V=E='1E>'0G
M72`N("<@+2UV97)S:6]N)RP@)&]U="P@)')E="D["B`@("`D<W!L:70@/2!E
M>'!L;V1E*"<@)RP@)&]U=%LP72D["B`@("!E8VAO("=G971T97AT('9E<G-I
M;VXZ("<@+B`D<W!L:71;8V]U;G0H)'-P;&ET*2`M(#%=.PH@("`@)&=E='1E
M>'1?=F5R<VEO;B`](&5X<&QO9&4H)RXG+"`D<W!L:71;8V]U;G0H)'-P;&ET
M*2`M(#%=*3L*("`@(&EF("@D9V5T=&5X=%]V97)S:6]N6S!=(#T](#`@)B8@
M)&=E='1E>'1?=F5R<VEO;ELQ72`\(#$R*2!["B`@("`@("`@)$=,3T)!3%-;
M)W!H<%]S=7!P;W)T)UT@/2!F86QS93L*("`@("`@("`D8RT^=W)I=&5L;B@I
M.PH@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)U=A<FYI;F<Z("<I("X@
M)UEO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@;F]T
M('-U<'!O<G0@4$A0(&YA=&EV96QY+B<I.PH@("`@("`@("1C+3YW<FET96QN
M*"=.;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N)RD["B`@("!]
M(&5L<V4@>PH@("`@("`@("1'3$]"04Q36R=P:'!?<W5P<&]R="==(#T@=')U
M93L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)R`G("X@)T]+)RDI
M.PH@("`@?0H@("`@)&,M/G=R:71E;&XH*3L*?0H*9G5N8W1I;VX@<V5A<F-H
M7V9I;&4H)&9I;&4L("1D:7(@/2`G+B<L("1L;V-A;"`](&9A;'-E*0I["B`@
M("!S=&%T:6,@)&9F.PH@("`@:68@*"%I<W-E="@D9F8I*2!["B`@("`@("`@
M)&9F(#T@)FYE=R!&:6QE7T9I;F0H*3L*("`@('T*"B`@("!I9B`H<W5B<W1R
M*"1F:6QE+"`P+"`Q*2`A/2!$4RD@>PH@("`@("`@("1F:6QE(#T@(B\D9FEL
M92\B.PH@("`@?0H*("`@(&EF("@D;&]C86PI('L*("`@("`@("`D9FEL97,@
M/2`D9F8M/F=L;V(H)&9I;&4L("1D:7(L("=P97)L)RD["B`@("`@("`@)&9I
M;&5S(#T@87)R87E?;6%P*&-R96%T95]F=6YC=&EO;B@G)&9I;&4G+"`G<F5T
M=7)N("(G("X@)&1I<B`N($13("X@)R(@+B`D9FEL93LG*2P@)&9I;&5S*3L*
M("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@?2!E;'-E('L*("`@("`@("!R
M971U<FX@)&9F+3YS96%R8V@H)&9I;&4L("1D:7(L("=P97)L)RD["B`@("!]
M"GT*"F9U;F-T:6]N('-E87)C:%]E>'0H)&5X="P@)&1I<B`]("<N)RP@)&QO
M8V%L(#T@9F%L<V4I"GL*("`@(')E='5R;B!S96%R8VA?9FEL92@B+BM<7"XD
M97AT7"0B+"`D9&ER+"`D;&]C86PI.PI]"@IF=6YC=&EO;B!G971?<&]?9FEL
M97,H)&1I<BD*>PH@("`@)&QA;F=S(#T@<V5A<F-H7V5X="@G<&\G+"`D9&ER
M*3L*("`@(&EF("@H)&ME>2`](&%R<F%Y7W-E87)C:"@D9&ER("X@1%,@+B`G
M;65S<V%G97,N<&\G+"`D;&%N9W,I*2`A/3T@9F%L<V4I('L*("`@("`@("!U
M;G-E="@D;&%N9W-;)&ME>5TI.PH@("`@?0H@("`@:68@*"@D:V5Y(#T@87)R
M87E?<V5A<F-H*"1D:7(@+B!$4R`N("=C;VUP96YD:75M+G!O)RP@)&QA;F=S
M*2D@(3T](&9A;'-E*2!["B`@("`@("`@=6YS970H)&QA;F=S6R1K97E=*3L*
M("`@('T*("`@(')E='5R;B`D;&%N9W,["GT*"F9U;F-T:6]N(&=E=%]L86YG
M=6%G97,H)&1I<BD*>PH@("`@9VQO8F%L("1C=7)D:7(["@H@("`@8VAD:7(H
M)&1I<BD["B`@("`D;&%N9W,@/2!G971?<&]?9FEL97,H)W!O)RD["B`@("`D
M;&%N9W,@/2!A<G)A>5]M87`H8W)E871E7V9U;F-T:6]N*"<D;&%N9R<L("=R
M971U<FX@<W1R7W)E<&QA8V4H(G!O(B`N($13+"`B(BP@<W1R7W)E<&QA8V4H
M(BYP;R(L("(B+"`D;&%N9RDI.R<I+"`D;&%N9W,I.PH@("`@8VAD:7(H)&-U
M<F1I<BD["B`@("!R971U<FX@)&QA;F=S.PI]"@IF=6YC=&EO;B!S96%R8VA?
M87!P;&EC871I;VYS*"D*>PH@("`@)&1I<G,@/2!A<G)A>2@I.PH@("`@)&AO
M<F1E(#T@9F%L<V4["B`@("!I9B`H0&ES7V1I<BA"05-%("X@1%,@+B`G<&\G
M*2D@>PH@("`@("`@("1D:7)S6UT@/2!"05-%.PH@("`@("`@("1H;W)D92`]
M('1R=64["B`@("!]"B`@("`D9&@@/2!`;W!E;F1I<BA"05-%*3L*("`@(&EF
M("@D9&@I('L*("`@("`@("!W:&EL92`H)&5N=')Y(#T@0')E861D:7(H)&1H
M*2D@>PH@("`@("`@("`@("`D9&ER(#T@0D%312`N($13("X@)&5N=')Y.PH@
M("`@("`@("`@("!I9B`H:7-?9&ER*"1D:7(I("8F"B`@("`@("`@("`@("`@
M("!S=6)S='(H)&5N=')Y+"`P+"`Q*2`A/2`G+B<@)B8*("`@("`@("`@("`@
M("`@(&9I;&5I;F]D92A(3U)$15]"05-%*2`A/2!F:6QE:6YO9&4H)&1I<BDI
M('L*("`@("`@("`@("`@("`@("1S=6(@/2!O<&5N9&ER*"1D:7(I.PH@("`@
M("`@("`@("`@("`@:68@*"1S=6(I('L*("`@("`@("`@("`@("`@("`@("!W
M:&EL92`H)'-U8F5N=')Y(#T@<F5A9&1I<B@D<W5B*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)'-U8F5N=')Y(#T]("=P;R<@)B8@:7-?9&ER
M*"1D:7(@+B!$4R`N("1S=6)E;G1R>2DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D:7)S6UT@/2`D9&ER.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1E;G1R>2`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&AO<F1E(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(&EF("@A)&AO<F1E*2!["B`@("`@("`@("`@
M(&%R<F%Y7W5N<VAI9G0H)&1I<G,L($A/4D1%7T)!4T4I.PH@("`@("`@('T*
M("`@('T*"B`@("!R971U<FX@)&1I<G,["GT*"F9U;F-T:6]N('-T<FEP7VAO
M<F1E*"1F:6QE*0I["B`@("!I9B`H:7-?87)R87DH)&9I;&4I*2!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y7VUA<"AC<F5A=&5?9G5N8W1I;VXH)R1F:6QE)RP@
M)W)E='5R;B!S=')I<%]H;W)D92@D9FEL92D[)RDL("1F:6QE*3L*("`@('T@
M96QS92!["B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*$)!4T4@+B!$4RP@
M)R<L("1F:6QE*3L*("`@('T*?0H*9G5N8W1I;VX@>'1R86-T*"D*>PH@("`@
M9VQO8F%L("1C;61?;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D9&5B=6<L("1T
M97-T+"`D8RP@)&=E='1E>'1?=F5R<VEO;BP@)'-I;&5N8V4L("1C=7)D:7([
M"@H@("`@9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*
M("`@("`@("!S=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S
M92`G:"<Z"B`@("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("`@
M("`@9F]O=&5R*"D["B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@
M("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@
M)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M("`@('T*("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@
M(&EF("@D1TQ/0D%,4ULG<&AP7W-U<'!O<G0G72D@>PH@("`@("`@("1L86YG
M=6%G92`]("=02%`G.PH@("`@?2!E;'-E('L*("`@("`@("`D;&%N9W5A9V4@
M/2`G0RLK)SL*("`@('T*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D
M:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO9'5L92D@)B8@
M)&UO9'5L92`A/2`D87!P<ULD:5TI('L*("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@?0H@("`@("`@('!R:6YT9B@G17AT<F%C=&EN9R!F<F]M("5S
M+BXN("<L("1A<'!S6R1I72D["B`@("`@("`@8VAD:7(H)&1I<G-;)&E=*3L*
M("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*("`@("`@("`@
M("`@)&9I;&5S(#T@<V5A<F-H7V5X="@G<&AP)RP@)RXG+"!T<G5E*3L*("`@
M("`@("`@("`@9F]R96%C:"`H87)R87DH)V%D;6EN)RP@)V9R86UE=V]R:R<L
M("=L:6(G+"`G<V5R=FEC97,G+"`G=&5M<&QA=&5S)RP@)W5T:6PG+"`G8V]N
M9FEG)R`N($13("X@)W1H96UE<R<I(&%S("1S96%R8VA?9&ER*2!["B`@("`@
M("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G92@D9FEL97,L('-E87)C
M:%]E>'0H)RAP:'!\:6YC?&IS*2<L("1S96%R8VA?9&ER*2D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S
M+"!S96%R8VA?97AT*"=D:7-T)RP@)V-O;F9I9R<I*3L*("`@("`@("`@("`@
M)'-H(#T@)$=,3T)!3%-;)WAG971T97AT)UT@+B`G("TM;&%N9W5A9V4])R`N
M("1L86YG=6%G92`N"B`@("`@("`@("`@("`@("`@("<@+2UF<F]M+6-O9&4]
M:7-O+3@X-3DM,2`M+6ME>7=O<F0]7R`M+7-O<G0M;W5T<'5T("TM8V]P>7)I
M9VAT+6AO;&1E<CTB2&]R9&4@4')O:F5C="(G.PH@("`@("`@("`@("!I9B`H
M)&=E='1E>'1?=F5R<VEO;ELP72`^(#`@?'P@)&=E='1E>'1?=F5R<VEO;ELQ
M72`^(#$Q*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@)R`M+6US9VED+6)U
M9W,M861D<F5S<STB9&5V0&QI<W1S+FAO<F1E+F]R9R(G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1F:6QE(#T@)&1I<G-;)&E=("X@1%,@+B`G<&\G
M("X@1%,@+B`D87!P<ULD:5T@+B`G+G!O="<["B`@("`@("`@("`@(&EF("AF
M:6QE7V5X:7-T<R@D9FEL92D@)B8@(6ES7W=R:71A8FQE*"1F:6QE*2D@>PH@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"AS<')I;G1F*"<E
M<R!I<R!N;W0@=W)I=&%B;&4N)RP@)&9I;&4I*2D["B`@("`@("`@("`@("`@
M("!F;V]T97(H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&UP7V9I
M;&4@/2`D9FEL92`N("<N=&UP+G!O="<["B`@("`@("`@("`@("1S:"`N/2`G
M("UO("<@+B`D=&UP7V9I;&4@+B`G("<@+B!I;7!L;V1E*"<@)RP@)&9I;&5S
M*3L*("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B`G
M+W!O+W1R86YS;&%T:6]N+G!H<"<I*2!["B`@("`@("`@("`@("`@("`D<V@@
M+CT@)R!P;R]T<F%N<VQA=&EO;BYP:'`G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A)&1E8G5G*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@
M)'-I;&5N8V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D96)U
M9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X
M96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&5S="D@97AE8R@D
M<V@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QE<R`]('-E
M87)C:%]E>'0H)RAP:'!\:6YC?&IS*2<I.PH@("`@("`@("`@("`D9FEL97,@
M/2!A<G)A>5]F:6QT97(H)&9I;&5S+"!C<F5A=&5?9G5N8W1I;VXH)R1F:6QE
M)RP@)W)E='5R;B!S=6)S='(H)&9I;&4L(#`L(#DI("$]("(N(B`N($13("X@
M(F-O;F9I9R(@+B!$4SLG*2D["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y
M7VUE<F=E*"1F:6QE<RP@<V5A<F-H7V5X="@G9&ES="<L("=C;VYF:6<G*2D[
M"B`@("`@("`@("`@("1S:"`]("1'3$]"04Q36R=X9V5T=&5X="==("X@)R`M
M+6QA;F=U86=E/2<@+B`D;&%N9W5A9V4@+@H@("`@("`@("`@("`@("`@("`G
M("TM:V5Y=V]R9#U?("TM<V]R="UO=71P=70@+2UF;W)C92UP;R`M+6-O<'ER
M:6=H="UH;VQD97(](DAO<F1E(%!R;VIE8W0B)SL*("`@("`@("`@("`@:68@
M*"1G971T97AT7W9E<G-I;VY;,%T@/B`P('Q\("1G971T97AT7W9E<G-I;VY;
M,5T@/B`Q,2D@>PH@("`@("`@("`@("`@("`@)'-H("X]("<@+2UM<V=I9"UB
M=6=S+6%D9')E<W,](F1E=D!L:7-T<RYH;W)D92YO<F<B)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D9FEL92`]("=P;R<@+B!$4R`N("1A<'!S6R1I
M72`N("<N<&]T)SL*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE
M*2`F)B`A:7-?=W)I=&%B;&4H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@D8RT^<F5D*'-P<FEN=&8H)R5S(&ES(&YO="!W<FET86)L
M92XG+"`D9FEL92DI*3L*("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T;7!?9FEL92`]("1F:6QE("X@)RYT
M;7`N<&]T)SL*("`@("`@("`@("`@)'-H("X]("<@+6\@)R`N("1T;7!?9FEL
M92`N("<@)R`N(&EM<&QO9&4H)R`G+"`D9FEL97,I("X@*"1D96)U9R`_("<G
M(#H@)'-I;&5N8V4I.PH@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T
M*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I
M.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(21T97-T*2!E>&5C*"1S:"D["B`@("`@
M("`@?0H@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&UP7V9I;&4I*2!["B`@
M("`@("`@("`@("1F:6QE<R`]('-E87)C:%]E>'0H)VAT;6PG+"`G=&5M<&QA
M=&5S)RD["B`@("`@("`@("`@(&EF("@A)'1E<W0I("1T;7`@/2!F;W!E;B@D
M9FEL92`N("<N=&5M<&QA=&5S)RP@)W<G*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)&9I;&5S(&%S("1T96UP;&%T92D@>PH@("`@("`@("`@("`@("`@)&9P
M(#T@9F]P96XH)'1E;7!L871E+"`G<B<I.PH@("`@("`@("`@("`@("`@)&QI
M;F5N;R`](#`["B`@("`@("`@("`@("`@("!W:&EL92`H*"1L:6YE(#T@9F=E
M=',H)&9P+"`T,#DV*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@)&QI;F5N;RLK.PH@("`@("`@("`@("`@("`@("`@("1O9F9S970@/2`P
M.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@H)&QE9G0@/2!S=')P;W,H
M)&QI;F4L("<\9V5T=&5X=#XG+"`D;V9F<V5T*2D@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1L969T("L](#D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1B=69F97(@/2`G)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@)&QI;F5S<&%N(#T@,#L*("`@("`@("`@("`@("`@("`@("`@("`@
M=VAI;&4@*"@D96YD(#T@<W1R<&]S*"1L:6YE+"`G/"]G971T97AT/B<L("1L
M969T*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8G5F9F5R("X]('-U8G-T<B@D;&EN92P@)&QE9G0I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&QE9G0@/2`P.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`L(#0P.38I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&QI;F5S<&%N*RL["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&QI;F4@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E
M9"AS<')I;G1F*"(\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E
M<RY<;D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N(BP@)'1E;7!L871E
M+"`D;&EN96YO*2DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K(#(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&)U9F9E<B`N/2!S=6)S='(H)&QI;F4L("1L969T+"`D96YD("T@)&QE9G0I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21T97-T*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F=W)I=&4H)'1M<"P@(B,Z("1T96UP
M;&%T93HD;&EN96YO7&XB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9W<FET92@D=&UP+"`G;7-G:60@(B<@+B!S=')?<F5P;&%C92AA<G)A>2@G
M(B<L(")<;B(I+"!A<G)A>2@G7"(G+"`B7%QN7")<;EPB(BDL("1B=69F97(I
M("X@(EPB7&XB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9W<FET
M92@D=&UP+"`G;7-G<W1R("(B)R`N(")<;EQN(BD["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&]F9G-E="`]
M("1E;F0@*R`Q,#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!F8VQO<V4H)'1M<"D["B`@("`@("`@("`@("1S
M:"`]("1'3$]"04Q36R=M<V=C;VUM)UT@+B`B("TM;6]R92UT:&%N/3`@+2US
M;W)T+6]U='!U="!<(B1T;7!?9FEL95PB(%PB)&9I;&4N=&5M<&QA=&5S7"(@
M+2UO=71P=70M9FEL92!<(B1T;7!?9FEL95PB(B`N("1S:6QE;F-E.PH@("`@
M("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(21T97-T*2!["B`@("`@("`@("`@("`@("!E>&5C*"1S:"D["B`@("`@
M("`@("`@("`@("!U;FQI;FLH)&9I;&4@+B`G+G1E;7!L871E<R<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92DI
M('L*("`@("`@("`@("`@("`@("1D:69F(#T@87)R87E?9&EF9BAF:6QE*"1T
M;7!?9FEL92DL(&9I;&4H)&9I;&4I*3L*("`@("`@("`@("`@("`@("1D:69F
M(#T@<')E9U]G<F5P*"<O7B)03U0M0W)E871I;VXM1&%T93HO)RP@)&1I9F8L
M(%!214=?1U)%4%])3E9%4E0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&4I('Q\(&-O=6YT*"1D:69F
M*2D@>PH@("`@("`@("`@("!`=6YL:6YK*"1F:6QE*3L*("`@("`@("`@("`@
M<F5N86UE*"1T;7!?9FEL92P@)&9I;&4I.PH@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@D8RT^9W)E96XH)W5P9&%T960G*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@0'5N;&EN:R@D=&UP7V9I;&4I.PH@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@D8RT^8F]L9"@G;F]T(&-H86YG960G*2D["B`@("`@("`@
M?0H@("`@("`@(&-H9&ER*"1C=7)D:7(I.PH@("`@?0I]"@IF=6YC=&EO;B!M
M97)G92@I"GL*("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1A<'!S+"`D9&ER
M<RP@)&1E8G5G+"`D=&5S="P@)&,["@H@("`@)&-O;7!E;F1I=6T@/2`G("TM
M8V]M<&5N9&EU;3TB)R`N($)!4T4@+B!$4R`N("=P;R<@+B!$4R`N("=C;VUP
M96YD:75M+G!O(B<["B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@
M)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@
M("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@
M("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z
M"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@
M("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM;V1U
M;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G8R<Z"B`@
M("`@("`@("`@(&-A<V4@)RTM8V]M<&5N9&EU;2<Z"B`@("`@("`@("`@("`@
M("`D8V]M<&5N9&EU;2`]("<@+2UC;VUP96YD:75M/2<@+B`D;W!T:6]N6S%=
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VXG
M.@H@("`@("`@("`@("!C87-E("<M+6YO+6-O;7!E;F1I=6TG.@H@("`@("`@
M("`@("`@("`@)&-O;7!E;F1I=6T@/2`G)SL*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*("`@('T*("`@(&EF("@A:7-S970H)&QA;F<I("8F
M("%E;7!T>2@D8V]M<&5N9&EU;2DI('L*("`@("`@("`D8RT^=W)I=&5L;B@D
M8RT^<F5D*"=%<G)O<CH@)R`N("=.;R!L;V-A;&4@<W!E8VEF:65D+B<I*3L*
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E*"D["B`@("`@
M("`@9F]O=&5R*"D["B`@("!]"@H@("`@8VQE86YU<"@I.PH*("`@(&9O<B`H
M)&D@/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF
M("@A96UP='DH)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L*
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@("1C+3YW
M<FET96QN*'-P<FEN=&8H)TUE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L
M92`E<RXN+B<L("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@("`@("`D9&ER
M(#T@)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,["B`@("`@("`@:68@*&5M
M<'1Y*"1L86YG*2D@>PH@("`@("`@("`@("`D;&%N9W,@/2!G971?;&%N9W5A
M9V5S*"1D:7)S6R1I72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*"%`9FEL95]E>&ES=',H)&1I<B`N("1L86YG("X@)RYP;R<I*2!["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN+B<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L86YG<R`](&%R
M<F%Y*"1L86YG*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&QA;F=S
M(&%S("1L;V-A;&4I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT
M9B@G365R9VEN9R!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H)&QO8V%L92DI
M*3L*("`@("`@("`@("`@)'-H(#T@)$=,3T)!3%-;)VUS9VUE<F=E)UT@+B`G
M("TM=7!D871E("UV)R`N("1C;VUP96YD:75M("X@)R`B)R`N("1D:7(@+B`D
M;&]C86QE("X@)RYP;R(@(B<@+B`D9&ER("X@)&%P<'-;)&E=("X@)RYP;W0B
M)SL*("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"$D=&5S="D@97AE8R@D<V@I.PH@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D8RT^9W)E96XH)V1O;F4G*2D["B`@("`@("`@?0H@("`@?0I]
M"@IF=6YC=&EO;B!S=&%T=7,H*0I["B`@("!R971U<FX["B`@("!G;&]B86P@
M)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L("1C
M.PH*("`@("1O=71P=70@/2`B<W1A='5S+FAT;6PB.PH@("`@9F]R96%C:"`H
M)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S=VET8V@@
M*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@
M("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@
M("`@("`@("`@(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E("<M+6QO8V%L
M92<Z"B`@("`@("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;,5T["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@
M("`@("`@(&-A<V4@)RTM;6]D=6QE)SH*("`@("`@("`@("`@("`@("1M;V1U
M;&4@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)V\G.@H@("`@("`@("`@("!C87-E("<M+6]U='!U="<Z
M"B`@("`@("`@("`@("`@("`D;W5T<'5T(#T@)&]P=&EO;ELQ73L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@?0H@("`@?0H@("`@9F]R("@D:2`]
M(#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@("`@("`@:68@*"%E
M;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S6R1I72D@>PH@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@)&,M/G=R:71E
M;&XH<W!R:6YT9B@G1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN
M+B<L("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@("`@("!I9B`H96UP='DH
M)&QA;F<I*2!["B`@("`@("`@("`@("1L86YG<R`](&=E=%]L86YG=6%G97,H
M)&1I<G-;)&E=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H
M(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L
M86YG("X@)RYP;R<I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G
M4VMI<'!E9"XN+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1L86YG<R`](&%R<F%Y*"1L86YG*3L*("`@("`@("!]"B`@("`@
M("`@9F]R96%C:"`H)&QA;F=S(&%S("1L;V-A;&4I('L*("`@("`@("`@("`@
M)&,M/G=R:71E;&XH<W!R:6YT9B@G4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@
M)RP@)&,M/F)O;&0H)&QO8V%L92DI*3L*("`@("`@("!]"B`@("!]"GT*"F9U
M;F-T:6]N(&-O;7!E;F1I=6TH*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS
M+"`D9&ER<RP@)&1E8G5G+"`D=&5S="P@)&,L("1S:6QE;F-E.PH*("`@("1D
M:7(@/2!"05-%("X@1%,@+B`G<&\G("X@1%,["B`@("`D861D(#T@)R<["B`@
M("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@
M("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H
M)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F
M;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A
M<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO
M;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=D)SH*("`@("`@("`@("`@8V%S92`G+2UD:7)E8W1O<GDG.@H@("`@("`@
M("`@("`@("`@)&1I<B`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@8V%S92`G82<Z"B`@("`@("`@("`@(&-A<V4@
M)RTM861D)SH*("`@("`@("`@("`@("`@("1A9&0@/2`G("<@+B`D;W!T:6]N
M6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H@
M("`@:68@*"%I<W-E="@D;&%N9RDI('L*("`@("`@("`D8RT^=W)I=&5L;B@D
M8RT^<F5D*"=%<G)O<CH@)R`N("=.;R!L;V-A;&4@<W!E8VEF:65D+B<I*3L*
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E*"D["B`@("`@
M("`@9F]O=&5R*"D["B`@("!]"B`@("!P<FEN=&8H)TUE<F=I;F<@86QL("5S
M+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN("<L("1L86YG*3L*("`@
M("1P;V9I;&5S(#T@87)R87DH*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O
M=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@("1P;V9I;&4@/2`D9&ER<ULD
M:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L86YG("X@)RYP;R<["B`@("`@("`@
M:68@*&9I;&5?97AI<W1S*"1P;V9I;&4I*2!["B`@("`@("`@("`@("1P;V9I
M;&5S6UT@/2`D<&]F:6QE.PH@("`@("`@('T*("`@('T*("`@(&EF("@A96UP
M='DH)&1I<BD@)B8@<W5B<W1R*"1D:7(L("TQ*2`A/2!$4RD@>PH@("`@("`@
M("1D:7(@+CT@1%,["B`@("!]"B`@("`D<V@@/2`D1TQ/0D%,4ULG;7-G8V%T
M)UT@+B`G("TM<V]R="UO=71P=70@)R`N(&EM<&QO9&4H)R`G+"`D<&]F:6QE
M<RD@+B`D861D("X@)R`^("<@+B`D9&ER("X@)V-O;7!E;F1I=6TN<&\@)R`N
M("@D9&5B=6<@/R`G)R`Z("1S:6QE;F-E*3L*("`@(&EF("@D9&5B=6<@?'P@
M)'1E<W0I('L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("1C+3YW
M<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@)&,M/G=R:71E;&XH)'-H
M*3L*("`@('T*("`@(&EF("@D=&5S="D@>PH@("`@("`@("1R970@/2`P.PH@
M("`@?2!E;'-E('L*("`@("`@("!E>&5C*"1S:"P@)&]U="P@)')E="D["B`@
M("!]"B`@("!I9B`H)')E="`]/2`P*2!["B`@("`@("`@)&,M/G=R:71E;&XH
M)&,M/F=R965N*"=D;VYE)RDI.PH@("`@?2!E;'-E('L*("`@("`@("`D8RT^
M=W)I=&5L;B@D8RT^<F5D*"=F86EL960G*2D["B`@("!]"GT*"F9U;F-T:6]N
M(&EN:70H*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I
M<G,L("1D96)U9RP@)'1E<W0L("1C+"`D<VEL96YC93L*"B`@("!F;W)E86-H
M("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C
M:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@
M("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*
M("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C
M86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@
M("`@("`@("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO
M9'5L92`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"B`@("!]"B`@("!I9B`H96UP='DH)&QA;F<I*2![("1L86YG(#T@
M9V5T96YV*"=,04Y')RD[('T*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO9'5L92D@
M)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L@8V]N=&EN=64[('T*("`@("`@
M("`D<&%C:V%G92`]('5C9FER<W0H)&%P<'-;)&E=*3L*("`@("`@("`D<&%C
M:V%G95]U(#T@4W1R:6YG.CIU<'!E<B@D87!P<ULD:5TI.PH@("`@("`@($!I
M;F-L=61E("1D:7)S6R1I72`N("<O;&EB+W9E<G-I;VXN<&AP)SL*("`@("`@
M("`D=F5R<VEO;B`](&1E9FEN960H)'!A8VMA9V5?=2`N("=?5D524TE/3B<I
M(#\@8V]N<W1A;G0H)'!A8VMA9V5?=2`N("=?5D524TE/3B<I(#H@)S\_/R<[
M"B`@("`@("`@<')I;G1F*"=);FET:6%L:7II;F<@;6]D=6QE("5S+BXN("<L
M("1A<'!S6R1I72D["B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&1I<G-;
M)&E=("X@)R]P;R\G("X@)&%P<'-;)&E=("X@)RYP;W0G*2D@>PH@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=F86EL960G*2D["B`@("`@("`@
M("`@("1C+3YW<FET96QN*'-P<FEN=&8H)R5S(&YO="!F;W5N9"X@4G5N(%PG
M=')A;G-L871I;VX@97AT<F%C=%PG(&9I<G-T+B<L("1D:7)S6R1I72`N($13
M("X@)W!O)R`N($13("X@)&%P<'-;)&E=("X@)RYP;W0G*2D["B`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D9&ER(#T@)&1I<G-;
M)&E=("X@1%,@+B`G<&\G("X@1%,["B`@("`@("`@)'-H(#T@)$=,3T)!3%-;
M)VUS9VEN:70G72`N("<@+2UN;RUT<F%N<VQA=&]R("UI("<@+B`D9&ER("X@
M)&%P<'-;)&E=("X@)RYP;W0@)R`N"B`@("`@("`@("`@("`@*"%E;7!T>2@D
M;&%N9RD@/R`G("UO("<@+B`D9&ER("X@)&QA;F<@+B`G+G!O("TM;&]C86QE
M/2<@+B`D;&%N9R`Z("<G*2`N"B`@("`@("`@("`@("`@*"1D96)U9R`_("<G
M(#H@)'-I;&5N8V4I.PH@("`@("`@(&EF("@A96UP='DH)&QA;F<I("8F("%/
M4U]724Y$3U=3*2!["B`@("`@("`@("`@("1P;V9I;&4@/2`D9&ER<ULD:5T@
M+B`G+W!O+R<@+B`D;&%N9R`N("<N<&\G.PH@("`@("`@("`@("`D<V@@+CT@
M(CL@<V5D("=S+U!!0TM!1T4@<&%C:V%G92\D<&%C:V%G92!P86-K86=E+R<@
M)'!O9FEL92`B("X*("`@("`@("`@("`@("`@("`@(")\('-E9"`G<R]004-+
M04=%(%9%4E-)3TXO)'!A8VMA9V4@)'9E<G-I;VXO)R`B("X*("`@("`@("`@
M("`@("`@("`@(")\('-E9"`G<R]M97-S86=E<R!F;W(@4$%#2T%'12]M97-S
M86=E<R!F;W(@)'!A8VMA9V4O)R`B("X*("`@("`@("`@("`@("`@("`@(")\
M('-E9"`G<R],86YG=6%G92U496%M.B!N;VYE+TQA;F=U86=E+51E86TZ(&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G+R<@(B`N"B`@("`@("`@("`@("`@("`@("`B
M/B`D<&]F:6QE+G1M<"(["B`@("`@("`@?0H@("`@("`@(&EF("@D9&5B=6<@
M?'P@)'1E<W0I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN
M9SHG*3L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"1T97-T*2!["B`@("`@("`@("`@("1R970@/2`P.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D
M<F5T*3L*("`@("`@("!]"B`@("`@("`@<F5N86UE*"1P;V9I;&4@+B`G+G1M
M<"<L("1P;V9I;&4I.PH@("`@("`@(&EF("@D<F5T(#T](#`I('L*("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)V9A
M:6QE9"<I*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N(&UA:V4H*0I[
M"B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D96)U
M9RP@)'1E<W0L("1C+"`D<VEL96YC92P@)')E9&ER7V5R<CL*"B`@("`D8V]M
M<&5N9&EU;2`]($)!4T4@+B!$4R`N("=P;R<@+B!$4R`N("=C;VUP96YD:75M
M+G!O)SL*("`@("1S879E7W-T871S(#T@9F%L<V4["B`@("!F;W)E86-H("@D
M8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H
M)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@
M("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@
M("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE
M)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@
M("`@("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L
M92`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@8V%S92`G8R<Z"B`@("`@("`@("`@(&-A<V4@)RTM8V]M<&5N9&EU
M;2<Z"B`@("`@("`@("`@("`@("`D8V]M<&5N9&EU;2`]("1O<'1I;VY;,5T[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;B<Z
M"B`@("`@("`@("`@(&-A<V4@)RTM;F\M8V]M<&5N9&EU;2<Z"B`@("`@("`@
M("`@("`@("`D8V]M<&5N9&EU;2`]("<G.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)W,G.@H@("`@("`@("`@("!C87-E("<M
M+7-T871I<W1I8W,G.@H@("`@("`@("`@("`@("`@)'-A=F5?<W1A=',@/2!T
M<G5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H@
M("`@)&AO<F1E(#T@87)R87E?<V5A<F-H*"=H;W)D92<L("1D:7)S*3L*("`@
M("1H;W)D95]M<V<@/2!A<G)A>2@I.PH@("`@)'-T871S7V%R<F%Y(#T@87)R
M87DH*3L*"B`@("!R97%U:7)E7V]N8V4@)T-O;G-O;&4O5&%B;&4N<&AP)SL*
M("`@("1S=&%T<R`](&YE=R!#;VYS;VQE7U1A8FQE*"D["B`@("`D<W1A=',M
M/G-E=$AE861E<G,H87)R87DH)TUO9'5L92<L("=,86YG=6%G92<L("=4<F%N
M<VQA=&5D)RP@)T9U>GIY)RP@)U5N=')A;G-L871E9"<I*3L*"B`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*("`@("`@("!I
M9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P<'-;)&E=*2!C
M;VYT:6YU93L*("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"="=6EL9&EN
M9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN)RP@)&,M/F)O;&0H)&%P<'-;
M)&E=*2DI.PH@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@("`@
M("`@)&QA;F=S(#T@9V5T7VQA;F=U86=E<R@D9&ER<ULD:5TI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1D:7)S
M6R1I72`N($13("X@)W!O)R`N($13("X@)&QA;F<@+B`G+G!O)RDI('L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"=3:VEP<&5D+BXN)RD["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QA;F=S(#T@87)R
M87DH)&QA;F<I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;&%N9W,@
M87,@)&QO8V%L92D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F
M*"="=6EL9&EN9R!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H)&QO8V%L92DI
M*3L*("`@("`@("`@("`@)&1I<B`]("1D:7)S6R1I72`N($13("X@)VQO8V%L
M92<@+B!$4R`N("1L;V-A;&4@+B!$4R`N("=,0U]-15-304=%4R<["B`@("`@
M("`@("`@(&EF("@A:7-?9&ER*"1D:7(I*2!["B`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PH@("`@("`@("`@("`@("`@:68@
M*"1D96)U9RD@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'-P
M<FEN=&8H)TUA:VEN9R!D:7)E8W1O<GD@)7,G+"`D9&ER*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(21T97-T("8F("%`4WES
M=&5M.CIM:V1I<B@B+7`@)&1I<B(I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=#
M;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E
M<SHG+"`D;&]C86QE*2D["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&1I<BD["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V]N=F5R="!T;R!U
M;FEX(&QI;F5B<F5A:W,N("HO"B`@("`@("`@("`@("1P;V9I;&4@/2`D9&ER
M<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L;V-A;&4@+B`G+G!O)SL*("`@
M("`@("`@("`@)&-O;G1E;G0@/2!F:6QE7V=E=%]C;VYT96YT<R@D<&]F:6QE
M*3L*"B`@("`@("`@("`@("1C;VYT96YT(#T@<W1R7W)E<&QA8V4H(EQR(BP@
M)R<L("1C;VYT96YT*3L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)'!O9FEL
M92P@)W=B)RD["B`@("`@("`@("`@(&9W<FET92@D9G`L("1C;VYT96YT*3L*
M("`@("`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("`@("`O*B!#:&5C
M:R!03R!F:6QE('-A;FET>2X@*B\*("`@("`@("`@("`@)'-H(#T@)$=,3T)!
M3%-;)VUS9V9M="==("X@(B`M+6-H96-K(%PB)'!O9FEL95PB)')E9&ER7V5R
M<B(["B`@("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D=&5S="D@>PH@("`@("`@("`@("`@("`@)')E="`](#`[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!E>&5C*"1S
M:"P@)&]U="P@)')E="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1R970@(3T@,"D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M
M/G)E9"@G5V%R;FEN9SH@)RD@+B`G86X@97)R;W(@:&%S(&]C8W5R960Z)RD[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAI;7!L;V1E*")<;B(L("1O
M=70I*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@
M("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($-O;7!I;&4@34\@9FEL92X@*B\*("`@("`@("`@("`@)'-H(#T@
M)$=,3T)!3%-;)VUS9V9M="==("X@)R`M+7-T871I<W1I8W,@+6\@(B<@+B`D
M9&ER("X@1%,@+B`D87!P<ULD:5T@+B`G+FUO(B`G.PH@("`@("`@("`@("!I
M9B`H)&%P<'-;)&E=("$]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("1H
M;W)D95]P;R`]("1D:7)S6R1H;W)D95T@+B!$4R`N("=P;R<@+B!$4R`N("1L
M;V-A;&4@+B`G+G!O)SL*("`@("`@("`@("`@("`@(&EF("@A0&ES7W)E861A
M8FQE*"1H;W)D95]P;RDI('L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@D8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)W1H92!(;W)D
M92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T.B<L
M("1L;V-A;&4I*3L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D
M:&]R9&5?<&\I.PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D[
M"B`@("`@("`@("`@("`@("`@("`@)'-H("X]("1D:7)S6R1I72`N($13("X@
M)W!O)R`N($13("X@)&QO8V%L92`N("<N<&\G.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<V@@/2`D1TQ/0D%,4ULG
M;7-G8V]M;2==("X@(B`M+6UO<F4M=&AA;CTP("TM<V]R="UO=71P=70@7"(D
M<&]F:6QE7"(@7"(D:&]R9&5?<&]<(B!\("1S:"`M(CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S
M:"`N/2`D<&]F:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S:"`N
M/2`D<F5D:7)?97)R.PH@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T
M*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I
M.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D;W5T(#T@)R<["B`@("`@("`@("`@(&EF("@D
M=&5S="D@>PH@("`@("`@("`@("`@("`@)')E="`](#`["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!P=71E;G8H)TQ!3D<]96XG*3L*
M("`@("`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*("`@("`@
M("`@("`@("`@('!U=&5N=B@G3$%.1STG("X@)$=,3T)!3%-;)VQA;F=U86=E
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<F5T(#T](#`I
M('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YG<F5E;B@G9&]N
M92<I*3L*("`@("`@("`@("`@("`@("1M97-S86=E<R`](&%R<F%Y*#`L(#`L
M(#`I.PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H7&0K*2!T
M<F%N<VQA=&5D+R<L("1O=71;,%TL("1M871C:"DI('L*("`@("`@("`@("`@
M("`@("`@("`D;65S<V%G97-;,%T@/2`D;6%T8VA;,5T["B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1H;W)D95]M<V=;)&QO8V%L95TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E<ULP72`M/2`D:&]R9&5?
M;7-G6R1L;V-A;&5=6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&UE<W-A9V5S6S!=(#P@,"D@)&UE<W-A9V5S6S!=(#T@,#L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+RA<9"LI(&9U>GIY+R<L("1O=71;,%TL("1M
M871C:"DI('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G97-;,5T@/2`D
M;6%T8VA;,5T["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1H;W)D
M95]M<V=;)&QO8V%L95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M
M97-S86=E<ULQ72`M/2`D:&]R9&5?;7-G6R1L;V-A;&5=6S%=.PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&UE<W-A9V5S6S%=(#P@,"D@)&UE<W-A
M9V5S6S%=(#T@,#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA<9"LI
M('5N=')A;G-L871E9"\G+"`D;W5T6S!=+"`D;6%T8V@I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&UE<W-A9V5S6S)=(#T@)&UA=&-H6S%=.PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D:&]R9&5?;7-G6R1L;V-A;&5=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;65S<V%G97-;,ET@+3T@)&AO
M<F1E7VUS9ULD;&]C86QE75LR73L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1M97-S86=E<ULR72`\(#`I("1M97-S86=E<ULR72`](#`["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@
M("`@("`@("`@)&AO<F1E7VUS9ULD;&]C86QE72`]("1M97-S86=E<SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S=&%T<U]A<G)A>5LD
M87!P<ULD:5U=6R1L;V-A;&5=(#T@)&UE<W-A9V5S.PH@("`@("`@("`@("`@
M("`@)'-T871S+3YA9&12;W<H87)R87DH)&%P<'-;)&E=+"`D;&]C86QE+"`D
M;65S<V%G97-;,%TL("1M97-S86=E<ULQ72P@)&UE<W-A9V5S6S)=*2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@D8RT^<F5D*"=F86EL960G*2D["B`@("`@("`@("`@("`@("!E>&5C*"1S
M:"P@)&]U="P@)')E="D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAI
M;7!L;V1E*")<;B(L("1O=70I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H8V]U;G0H)&QA;F=S*2`^(#$I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!-97)G92!T
M<F%N<VQA=&EO;B!I;G1O(&-O;7!E;F1I=6TN("HO"B`@("`@("`@("`@(&EF
M("@A96UP='DH)&-O;7!E;F1I=6TI*2!["B`@("`@("`@("`@("`@("!P<FEN
M=&8H)TUE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD
M:75M+BXN("<L("1C+3YB;VQD*"1A<'!S6R1I72DI.PH@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D9&ER*2`F)B!S=6)S='(H)&1I<BP@+3$I("$]($13
M*2!["B`@("`@("`@("`@("`@("`@("`@)&1I<B`N/2!$4SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1S:"`]("1'3$]"04Q36R=M<V=C
M870G72`N("(@+2US;W)T+6]U='!U="!<(B1C;VUP96YD:75M7"(@7"(D<&]F
M:6QE7"(@/B!<(B1C;VUP96YD:75M+G1M<%PB(CL*("`@("`@("`@("`@("`@
M(&EF("@A)&1E8G5G*2!["B`@("`@("`@("`@("`@("`@("`@)'-H("X]("1S
M:6QE;F-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"D["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X
M96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D
M<V@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&]U="`]
M("<G.PH@("`@("`@("`@("`@("`@:68@*"1T97-T*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E="`](#`["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@($!U;FQI;FLH)&-O;7!E
M;F1I=6TI.PH@("`@("`@("`@("`@("`@<F5N86UE*"1C;VUP96YD:75M("X@
M)RYT;7`G+"`D8V]M<&5N9&EU;2D["B`@("`@("`@("`@("`@("!I9B`H)')E
M="`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M
M/F=R965N*"=D;VYE)RDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=F86EL960G
M*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&,M/G=R:71E;&XH*3L*("`@("`@("!]"B`@("!]"B`@("!I9B`H96UP
M='DH)&UO9'5L92DI('L*("`@("`@("`D8RT^=W)I=&5L;B@G4F5S=6QT<SHG
M*3L*("`@('T@96QS92!["B`@("`@("`@)&,M/G=R:71E;&XH)U)E<W5L=',@
M*&EN8VQU9&EN9R!(;W)D92DZ)RD["B`@("!]"B`@("`D8RT^=W)I=&5L;B@D
M<W1A=',M/F=E=%1A8FQE*"DI.PH@("`@:68@*"1S879E7W-T871S*2!["B`@
M("`@("`@)&9P(#T@0&9O<&5N*"=T<F%N<VQA=&EO;E]S=&%T<RYT>'0G+"`G
M=R<I.PH@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@9G=R:71E*"1F
M<"P@<V5R:6%L:7IE*"1S=&%T<U]A<G)A>2DI.PH@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N(&-L96%N=7`H
M)&ME97!?=6YT<F%N<VQA=&5D(#T@9F%L<V4I"GL*("`@(&=L;V)A;"`D8VUD
M7V]P=&EO;G,L("1A<'!S+"`D9&ER<RP@)&1E8G5G+"`D=&5S="P@)&,["@H@
M("`@9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@
M("`@("!S=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G
M:"<Z"B`@("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("`@("`@
M9F]O=&5R*"D["B`@("`@("`@("`@(&-A<V4@)VPG.@H@("`@("`@("`@("!C
M87-E("<M+6QO8V%L92<Z"B`@("`@("`@("`@("`@("`D;&%N9R`]("1O<'1I
M;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`G;2<Z"B`@("`@("`@("`@(&-A<V4@)RTM;6]D=6QE)SH*("`@("`@("`@
M("`@("`@("1M;V1U;&4@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO
M9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L@8V]N=&EN=64[('T*
M("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"=#;&5A;FEN9R!U<"!03R!F
M:6QE<R!F;W(@;6]D=6QE("5S+BXN)RP@)&,M/F)O;&0H)&%P<'-;)&E=*2DI
M.PH@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@("`@("`@)&QA
M;F=S(#T@9V5T7VQA;F=U86=E<R@D9&ER<ULD:5TI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1D:7)S6R1I72`N
M($13("X@)W!O)R`N($13("X@)&QA;F<@+B`G+G!O)RDI('L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"=3:VEP<&5D+BXN)RD["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QA;F=S(#T@87)R87DH)&QA
M;F<I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;&%N9W,@87,@)&QO
M8V%L92D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"=#;&5A
M;FEN9R!U<"!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H)&QO8V%L92DI*3L*
M("`@("`@("`@("`@)'!O9FEL92`]("1D:7)S6R1I72`N($13("X@)W!O)R`N
M($13("X@)&QO8V%L92`N("<N<&\G.PH@("`@("`@("`@("`D<V@@/2`D1TQ/
M0D%,4ULG;7-G871T<FEB)UT@+B`H)&ME97!?=6YT<F%N<VQA=&5D(#\@)R<@
M.B`G("TM=')A;G-L871E9"<I("X@(B`M+6YO+6]B<V]L971E("TM9F]R8V4M
M<&\@)'!O9FEL92`^("1P;V9I;&4N=&UP(CL*("`@("`@("`@("`@:68@*"$D
M9&5B=6<I('L*("`@("`@("`@("`@("`@("1S:"`N/2`D<VEL96YC93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2![
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&]U="`]("<G.PH@("`@("`@("`@("!I9B`H)'1E<W0I('L*("`@("`@("`@
M("`@("`@("1R970@/2`P.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@97AE8R@D<V@L("1O=70L("1R970I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@D<F5T(#T](#`I('L*("`@("`@("`@("`@("`@
M($!U;FQI;FLH)'!O9FEL92D["B`@("`@("`@("`@("`@("!R96YA;64H)'!O
M9FEL92`N("<N=&UP)RP@)'!O9FEL92D["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D8RT^9W)E96XH)V1O;F4G*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!`=6YL:6YK*"1P;V9I;&4@+B`G+G1M<"<L
M("1P;V9I;&4I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E
M9"@G9F%I;&5D)RDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C+3YW
M<FET96QN*"D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!C;VUM:70H
M)&AE;'!?;VYL>2`](&9A;'-E*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS
M+"`D87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L("1C.PH*("`@("1D;V-S
M(#T@9F%L<V4["B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P
M=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@
M("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@
M("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@
M("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L
M86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM;V1U;&4G
M.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;B<Z"B`@("`@
M("`@("`@(&-A<V4@)RTM;F5W)SH*("`@("`@("`@("`@("`@("1D;V-S(#T@
M=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=-)SH*("`@("`@("`@("`@8V%S92`G+2UM97-S86=E)SH*("`@("`@("`@
M("`@("`@("1M<V<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H@("`@?0H@("`@)&9I;&5S(#T@87)R87DH*3L*("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@
M("`@(&EF("@A96UP='DH)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD
M:5TI(&-O;G1I;G5E.PH@("`@("`@(&EF("@D87!P<ULD:5T@/3T@)VAO<F1E
M)RD@>PH@("`@("`@("`@("`D9&ER<UM=(#T@)&1I<G-;)&E=("X@1%,@+B`G
M861M:6XG.PH@("`@("`@("`@("`D87!P<UM=(#T@)VAO<F1E+V%D;6EN)SL*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2D@>PH@("`@("`@("`@
M("`@("`@)&UO9'5L92`]("=H;W)D92]A9&UI;B<["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1L86YG*2D@>PH@("`@("`@
M("`@("!I9B`H)&AE;'!?;VYL>2D@>PH@("`@("`@("`@("`@("`@)&9I;&5S
M(#T@87)R87E?;65R9V4H)&9I;&5S+"!S=')I<%]H;W)D92AS96%R8VA?97AT
M*"=X;6PG+"`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G*2DI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?
M;65R9V4H)&9I;&5S+"!S=')I<%]H;W)D92AG971?<&]?9FEL97,H)&1I<G-;
M)&E=("X@1%,@+B`G<&\G*2DI.PH@("`@("`@("`@("`@("`@)&9I;&5S(#T@
M87)R87E?;65R9V4H)&9I;&5S+"!S=')I<%]H;W)D92AS96%R8VA?9FEL92@G
M7EMA+7I=>S)]7UM!+5I=>S)])RP@)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE
M)RP@=')U92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D:&5L<%]O;FQY*2!["B`@("`@("`@("`@("`@("!I
M9B`H(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G("X@
M1%,@+B`D;&%N9R`N($13("X@)VAE;'`N>&UL)RDI(&-O;G1I;G5E.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"%`9FEL95]E
M>&ES=',H)&1I<G-;)&E=("X@)R]P;R\G("X@)&QA;F<@+B`G+G!O)RDI(&-O
M;G1I;G5E.PH@("`@("`@("`@("`@("`@)&9I;&5S6UT@/2!S=')I<%]H;W)D
M92@D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L86YG("X@)RYP;R<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F:6QE<UM=(#T@<W1R:7!?
M:&]R9&4H)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)R`N($13("X@)&QA;F<I
M.PH@("`@("`@('T*("`@("`@("!I9B`H)&1O8W,@)B8@(21H96QP7V]N;'D@
M)B8@)&%P<'-;)&E=*2!["B`@("`@("`@("`@("1F:6QE<UM=(#T@<W1R:7!?
M:&]R9&4H)&1I<G-;)&E=("X@1%,@+B`G9&]C<R<I.PH@("`@("`@("`@("!I
M9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("1H
M;W)D95]C;VYF(#T@)&1I<G-;87)R87E?<V5A<F-H*"=H;W)D92<L("1D:7)S
M*5T@+B!$4R`N("=C;VYF:6<G("X@1%,["B`@("`@("`@("`@("`@("`D9FEL
M97-;72`]('-T<FEP7VAO<F1E*"1H;W)D95]C;VYF("X@)VYL<RYP:'`N9&ES
M="<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@8VAD:7(H
M0D%312D["B`@("!I9B`H8V]U;G0H)&9I;&5S*2D@>PH@("`@("`@(&EF("@D
M9&]C<RD@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@G061D:6YG(&YE=R!F
M:6QE<R!T;R!R97!O<VET;W)Y.B<I.PH@("`@("`@("`@("`D<V@@/2`G8W9S
M(&%D9"<["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D9FEL92P@)VQO8V%L92<I
M('Q\('-T<G-T<B@D9FEL92P@)RYP;R<I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'-H("X]("(@)&9I;&4B.PH@("`@("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"1F:6QE*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<V@@+CT@)SL@8W9S(&%D9"<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@
M:68@*'-T<G-T<B@D9FEL92P@)VQO8V%L92<I*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1H96QP7V]N;'DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-H("X]("<@)R`N("1F:6QE("X@1%,@+B`G*BYX;6PG.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D9FEL92`N($13("X@)RHN
M>&UL)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'-H("X]("<@)R`N("1F:6QE("X@1%,@+B`G*BYX
M;6P@)R`N("1F:6QE("X@1%,@+B`G3$-?34534T%'15,G.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D9FEL92`N($13("X@(BHN>&UL
M7&XD9FEL92(@+B!$4R`N("=,0U]-15-304=%4R<I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H(21H96QP7V]N;'DI('L*("`@("`@("`@("`@("`@("1S
M:"`N/2`G.R!C=G,@861D)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F
M:6QE<R!A<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')S
M='(H)&9I;&4L("=L;V-A;&4G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D861D(#T@)&9I;&4@+B!$4R`N("=,0U]-15-304=%4R<@+B!$4R`N("<J
M+FUO)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'-H("X]("<@)R`N("1A
M9&0["B`@("`@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1A9&0I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@
M("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(21T97-T*2!S>7-T96TH)'-H*3L*("`@("`@("`@("`@)&,M/G=R:71E;&XH
M*3L*("`@("`@("!]"B`@("`@("`@)&,M/G=R:71E;&XH)T-O;6UI='1I;F<Z
M)RD["B`@("`@("`@)&,M/G=R:71E;&XH:6UP;&]D92@G("<L("1F:6QE<RDI
M.PH@("`@("`@(&EF("@A96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1L
M86YG(#T@)R`G("X@)&QA;F<["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D;7-G*2D@>PH@("`@("`@("`@("!I9B`H)&1O8W,I('L*("`@("`@("`@
M("`@("`@("1M<V<@/2`B061D)&QA;F<@=')A;G-L871I;VXN(CL*("`@("`@
M("`@("`@?2!E;'-E:68@*"1H96QP7V]N;'DI('L*("`@("`@("`@("`@("`@
M("1M<V<@/2`B57!D871E)&QA;F<@:&5L<"!F:6QE+B(["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D;7-G(#T@(E5P9&%T921L86YG
M('1R86YS;&%T:6]N+B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@)'-H(#T@)V-V<R!C;VUM:70@+6T@(B<@+B`D;7-G("X@)R(@)R`N(&EM
M<&QO9&4H)R`G+"`D9FEL97,I.PH@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E
M<W0I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"$D=&5S="D@<WES=&5M*"1S:"D["B`@("!]"GT*"F9U;F-T:6]N
M('5P9&%T95]H96QP*"D*>PH@("`@9VQO8F%L("1C;61?;W!T:6]N<RP@)&1I
M<G,L("1A<'!S+"`D9&5B=6<L("1T97-T+"`D;&%S=%]E<G)O<E]M<V<L("1C
M.PH*("`@(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D;W!T:6]N*2![
M"B`@("`@("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@("`@(&-A
M<V4@)V@G.@H@("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@
M("`@(&9O;W1E<B@I.PH@("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@
M("`@8V%S92`G+2UL;V-A;&4G.@H@("`@("`@("`@("`@("`@)&QA;F<@/2`D
M;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@)VTG.@H@("`@("`@("`@("!C87-E("<M+6UO9'5L92<Z"B`@("`@
M("`@("`@("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@("1F:6QE<R`](&%R<F%Y
M*"D["B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI
M('L*("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@
M)&%P<'-;)&E=*2![(&-O;G1I;G5E.R!]"B`@("`@("`@:68@*"%I<U]D:7(H
M(B1D:7)S6R1I72]L;V-A;&4B*2D@8V]N=&EN=64["B`@("`@("`@:68@*"1A
M<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("1D:7)S6UT@/2`D
M9&ER<ULD:5T@+B!$4R`N("=A9&UI;B<["B`@("`@("`@("`@("1A<'!S6UT@
M/2`G:&]R9&4O861M:6XG.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1M;V1U
M;&4I*2!["B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)VAO<F1E+V%D;6EN
M)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)&QA;F<I*2!["B`@("`@("`@("`@("1F:6QE<R`]('-E87)C:%]F:6QE*"=H
M96QP+GAM;"<L("1D:7)S6R1I72`N($13("X@)VQO8V%L92<I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y*"1D:7)S6R1I
M72`N($13("X@)VQO8V%L92<@+B!$4R`N("1L86YG("X@1%,@+B`G:&5L<"YX
M;6PG*3L*("`@("`@("!]"B`@("`@("`@)&9I;&5?96X@(#T@)&1I<G-;)&E=
M("X@1%,@+B`G;&]C86QE)R`N($13("X@)V5N7U53)R`N($13("X@)VAE;'`N
M>&UL)SL*("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9FEL95]E;BDI('L*
M("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M/G)E9"@G5V%R
M;FEN9SH@)RD@+B!S<')I;G1F*"=4:&5R92!D;V5S;EPG="!Y970@97AI<W0@
M82!H96QP(&9I;&4@9F]R("5S+B<L("1C+3YB;VQD*"1A<'!S6R1I72DI*2D[
M"B`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I
M;&5?;&]C*2!["B`@("`@("`@("`@("1L;V-A;&4@/2!S=6)S='(H)&9I;&5?
M;&]C+"`P+"!S=')R<&]S*"1F:6QE7VQO8RP@1%,I*3L*("`@("`@("`@("`@
M)&QO8V%L92`]('-U8G-T<B@D;&]C86QE+"!S=')R<&]S*"1L;V-A;&4L($13
M*2`K(#$I.PH@("`@("`@("`@("!I9B`H)&QO8V%L92`]/2`G96Y?55,G*2!C
M;VYT:6YU93L*("`@("`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&9I;&5?
M;&]C*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H
M)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&4@)7,@:&5L<"!F
M:6QE(&9O<B`E<R!D;V5S;EPG="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W
M(&]N92XG+"`D8RT^8F]L9"@D;&]C86QE*2P@)&,M/F)O;&0H)&%P<'-;)&E=
M*2DI*3L*("`@("`@("`@("`@("`@("1D:7)?;&]C(#T@<W5B<W1R*"1F:6QE
M7VQO8RP@,"P@+3DI.PH@("`@("`@("`@("`@("`@:68@*"%I<U]D:7(H)&1I
M<E]L;V,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3
M>7-T96TN<&AP)SL*("`@("`@("`@("`@("`@("`@("!I9B`H)&1E8G5G('Q\
M("1T97-T*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN
M*'-P<FEN=&8H)TUA:VEN9R!D:7)E8W1O<GD@)7,G+"`D9&ER7VQO8RDI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M(21T97-T("8F("%`4WES=&5M.CIM:V1I<B@B+7`@)&1I<E]L;V,B*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=7
M87)N:6YG.B`G*2`N('-P<FEN=&8H)T-O=6QD(&YO="!C<F5A=&4@;&]C86QE
M(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.B<L("1L;V-A;&4I*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&1I<E]L;V,I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&1E8G5G
M('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M=V]R9'=R87`H<W!R:6YT9B@G0V]P>6EN9R`E<R!T;R`E<R<L("1F:6QE7V5N
M+"`D9FEL95]L;V,I*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H(21T97-T("8F("%`8V]P>2@D9FEL95]E;BP@)&9I;&5?;&]C
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H
M)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G0V]U;&0@;F]T(&-O<'D@)7,@=&\@
M)7,G+"`D9FEL95]E;BP@)&9I;&5?;&]C*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&,M/G=R
M:71E;&XH<W!R:6YT9B@G57!D871I;F<@)7,@:&5L<"!F:6QE(&9O<B`E<RXG
M+"`D8RT^8F]L9"@D;&]C86QE*2P@)&,M/F)O;&0H)&%P<'-;)&E=*2DI.PH@
M("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL95]L;V,L("=R)RD["B`@("`@
M("`@("`@("1L:6YE(#T@9F=E=',H)&9P*3L*("`@("`@("`@("`@9F-L;W-E
M*"1F<"D["B`@("`@("`@("`@(&EF("@A<W1R<W1R*"1L:6YE+"`G/#]X;6PG
M*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M
M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&4@:&5L<"!F:6QE("5S
M(&1I9&Y<)W0@<W1A<G0@=VET:"`\/WAM;"<L("1F:6QE7VQO8RDI*3L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D96YC;V1I;F<@
M/2`G)SL*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]E;F-O9&EN9STH
M6R)<)UTI*%M>7%PQ72LI7%PQ+R<L("1L:6YE+"`D;6%T8V@I*2!["B`@("`@
M("`@("`@("`@("`D96YC;V1I;F<@/2`D;6%T8VA;,ET["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&1O8U]E;B`](&1O;7AM;%]O<&5N7V9I;&4H)&9I
M;&5?96XI.PH@("`@("`@("`@("!I9B`H(6ES7V]B:F5C="@D9&]C7V5N*2D@
M>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M/G)E
M9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&5R92!W87,@86X@97)R;W(@
M;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN
M<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E
M<R!F<F]M('1H92!X;6P@<&%R<V5R+B<L("1F:6QE7V5N*2DI.PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E(#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1O8U]L;V,@/2!D
M;VUX;6Q?;W!E;E]F:6QE*"1F:6QE7VQO8RD["B`@("`@("`@("`@(&EF("@A
M:7-?;V)J96-T*"1D;V-?;&]C*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F
M*"=4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y
M(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@
M<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+B<L
M("1F:6QE7VQO8RDI*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D[
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D9&]C7VYE=R`@/2!D;VUX;6Q?;F5W7V1O8R@G,2XP)RD["B`@
M("`@("`@("`@("1H96QP7V5N("`]("1D;V-?96XM/F1O8W5M96YT7V5L96UE
M;G0H*3L*("`@("`@("`@("`@)&AE;'!?;&]C(#T@)&1O8U]L;V,M/F1O8W5M
M96YT7V5L96UE;G0H*3L*("`@("`@("`@("`@)&AE;'!?;F5W(#T@)&AE;'!?
M;&]C+3YC;&]N95]N;V1E*"D["B`@("`@("`@("`@("1E;G1R:65S7VQO8R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1E;G1R:65S7VYE=R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1C;W5N=%]U<'1O9&%T92`](#`["B`@("`@("`@("`@
M("1C;W5N=%]N97<@("`@("`](#`["B`@("`@("`@("`@("1C;W5N=%]C:&%N
M9V5D("`](#`["B`@("`@("`@("`@("1C;W5N=%]U;FMN;W=N("`](#`["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1D;V-?;&]C+3YG971?96QE;65N='-?8GE?
M=&%G;F%M92@G96YT<GDG*2!A<R`D96YT<GDI('L*("`@("`@("`@("`@("`@
M("1E;G1R:65S7VQO8ULD96YT<GDM/F=E=%]A='1R:6)U=&4H)VED)RE=(#T@
M)&5N=')Y.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M;V-?96XM/F=E=%]E;&5M96YT<U]B>5]T86=N86UE*"=E;G1R>2<I(&%S("1E
M;G1R>2D@>PH@("`@("`@("`@("`@("`@)&ED(#T@)&5N=')Y+3YG971?871T
M<FEB=71E*"=I9"<I.PH@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E
M>&ES=',H)&ED+"`D96YT<FEE<U]L;V,I*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1E;G1R:65S7VQO8ULD:61=+3YH87-?871T<FEB=71E*"=M9#4G
M*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!M9#4H)&5N=')Y+3YG971?
M8V]N=&5N="@I*2`A/2`D96YT<FEE<U]L;V-;)&ED72T^9V5T7V%T=')I8G5T
M92@G;60U)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;6UE;G0@
M/2`D9&]C7VQO8RT^8W)E871E7V-O;6UE;G0H(B!%;F=L:7-H(&5N=')Y.EQN
M(B`N('-T<E]R97!L86-E*"<M+2<L("<F(S0U.R8C-#4[)RP@)&1O8U]L;V,M
M/F1U;7!?;F]D92@D96YT<GDI*2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1E;G1R:65S7VQO8ULD:61=+3YA<'!E;F1?8VAI;&0H)&-O;6UE;G0I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE?;F5W(#T@)&5N=')I97-?
M;&]C6R1I9%TM/F-L;VYE7VYO9&4H=')U92D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1E;G1R>5]N97<M/G-E=%]A='1R:6)U=&4H)W-T871E)RP@)V-H
M86YG960G*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-O=6YT7V-H86YG
M960K*SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(21E;G1R:65S7VQO8ULD:61=+3YH87-?871T
M<FEB=71E*"=S=&%T92<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]M;65N="`]("1D;V-?;&]C+3YC<F5A=&5?8V]M;65N="@B($5N9VQI
M<V@@96YT<GDZ7&XB("X@<W1R7W)E<&QA8V4H)RTM)RP@)R8C-#4[)B,T-3LG
M+"`D9&]C7VQO8RT^9'5M<%]N;V1E*"1E;G1R>2DI*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E;G1R:65S7VQO8ULD:61=+3YA<'!E;F1?8VAI
M;&0H)&-O;6UE;G0I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N
M=')Y7VYE=R`]("1E;G1R:65S7VQO8ULD:61=+3YC;&]N95]N;V1E*'1R=64I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y7VYE=RT^<V5T
M7V%T=')I8G5T92@G<W1A=&4G+"`G=6YK;F]W;B<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O=6YT7W5N:VYO=VXK*SL*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E;G1R>5]N97<@/2`D96YT<FEE<U]L;V-;)&ED72T^8VQO;F5?;F]D
M92AT<G5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N=%]U
M<'1O9&%T92LK.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D96YT<GE?;F5W(#T@)&5N=')Y+3YC;&]N95]N;V1E
M*'1R=64I.PH@("`@("`@("`@("`@("`@("`@("1E;G1R>5]N97<M/G-E=%]A
M='1R:6)U=&4H)W-T871E)RP@)VYE=R<I.PH@("`@("`@("`@("`@("`@("`@
M("1C;W5N=%]N97<K*SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1E;G1R:65S7VYE=UM=(#T@)&5N=')Y7VYE=SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9&]C7VYE=RT^87!P96YD7V-H:6QD*"1D;V-?;F5W
M+3YC<F5A=&5?8V]M;65N="@G("0G("X@)TAO<F1E)"`G*2D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1E;G1R:65S7VYE=R!A<R`D96YT<GDI('L*("`@("`@
M("`@("`@("`@("1H96QP7VYE=RT^87!P96YD7V-H:6QD*"1E;G1R>2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H
M<W!R:6YT9B@G16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D
M(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]U;G1?=7!T;V1A=&4@*R`D8V]U
M;G1?;F5W("L@)&-O=6YT7V-H86YG960@*R`D8V]U;G1?=6YK;F]W;BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N=%]U<'1O
M9&%T92P@)&-O=6YT7VYE=RP@)&-O=6YT7V-H86YG960L("1C;W5N=%]U;FMN
M;W=N*2DI.PH@("`@("`@("`@("`D9&]C7VYE=RT^87!P96YD7V-H:6QD*"1H
M96QP7VYE=RD["B`@("`@("`@("`@("1O=71P=70@/2`D9&]C7VYE=RT^9'5M
M<%]M96TH=')U92P@)&5N8V]D:6YG*3L*("`@("`@("`@("`@:68@*"1D96)U
M9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R
M9'=R87`H<W!R:6YT9B@G5W)I=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E
M<RXG+"`D9FEL95]L;V,I*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"$D=&5S="D@>PH@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH)&9I
M;&5?;&]C+"`G=R<I.PH@("`@("`@("`@("`@("`@)&QI;F4@/2!F=W)I=&4H
M)&9P+"`D;W5T<'5T*3L*("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1C+3YW<FET96QN*'-P<FEN=&8H
M)R5D(&)Y=&5S('=R:71T96XN)RP@<W1R;&5N*"1O=71P=70I*2D["B`@("`@
M("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC
M=&EO;B!M86ME7VAE;'`H*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D
M9&ER<RP@)&%P<',L("1D96)U9RP@)'1E<W0L("1C.PH*("`@(&9O<F5A8V@@
M*"1C;61?;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@("`@<W=I=&-H
M("@D;W!T:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@("`@
M("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@
M("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@("`@8V%S92`G+2UL;V-A
M;&4G.@H@("`@("`@("`@("`@("`@)&QA;F<@/2`D;W!T:6]N6S%=.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@
M("`@("`@("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@("`@("`D;6]D
M=6QE(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*("`@('T*("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*("`@("`@("!I9B`H
M(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P<'-;)&E=*2!C;VYT
M:6YU93L*("`@("`@("!I9B`H(6ES7V1I<B@B)&1I<G-;)&E=+VQO8V%L92(I
M*2!C;VYT:6YU93L*("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I
M('L*("`@("`@("`@("`@)&1I<G-;72`]("1D:7)S6R1I72`N($13("X@)V%D
M;6EN)SL*("`@("`@("`@("`@)&%P<'-;72`]("=H;W)D92]A9&UI;B<["B`@
M("`@("`@("`@(&EF("@A96UP='DH)&UO9'5L92DI('L*("`@("`@("`@("`@
M("`@("1M;V1U;&4@/2`G:&]R9&4O861M:6XG.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@("`@
M("`@)&9I;&5S(#T@<V5A<F-H7V9I;&4H)VAE;'`N>&UL)RP@)&1I<G-;)&E=
M("X@1%,@+B`G;&]C86QE)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9I;&5S(#T@87)R87DH)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)R`N
M($13("X@)&QA;F<@+B!$4R`N("=H96QP+GAM;"<I.PH@("`@("`@('T*("`@
M("`@("`D9FEL95]E;B`@/2`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G("X@
M1%,@+B`G96Y?55,G("X@1%,@+B`G:&5L<"YX;6PG.PH@("`@("`@(&EF("@A
M0&9I;&5?97AI<W1S*"1F:6QE7V5N*2D@>PH@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE
M7VQO8RD@>PH@("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9FEL95]L
M;V,I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN
M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L
M;V-A;&4@/2!S=6)S='(H)&9I;&5?;&]C+"`P+"!S=')R<&]S*"1F:6QE7VQO
M8RP@1%,I*3L*("`@("`@("`@("`@)&QO8V%L92`]('-U8G-T<B@D;&]C86QE
M+"!S=')R<&]S*"1L;V-A;&4L($13*2`K(#$I.PH@("`@("`@("`@("!I9B`H
M)&QO8V%L92`]/2`G96Y?55,G*2!C;VYT:6YU93L*("`@("`@("`@("`@)&,M
M/G=R:71E;&XH<W!R:6YT9B@G57!D871I;F<@)7,@:&5L<"!F:6QE(&9O<B`E
M<RXG+"`D8RT^8F]L9"@D;&]C86QE*2P@)&,M/F)O;&0H)&%P<'-;)&E=*2DI
M.PH@("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL95]L;V,L("=R)RD["B`@
M("`@("`@("`@("1L:6YE(#T@9F=E=',H)&9P*3L*("`@("`@("`@("`@9F-L
M;W-E*"1F<"D["B`@("`@("`@("`@(&EF("@A<W1R<W1R*"1L:6YE+"`G/#]X
M;6PG*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H
M)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&4@:&5L<"!F:6QE
M("5S(&1I9&Y<)W0@<W1A<G0@=VET:"`\/WAM;"<L("1F:6QE7VQO8RDI*3L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D96YC;V1I
M;F<@/2`G)SL*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]E;F-O9&EN
M9STH6R)<)UTI*%M>7%PQ72LI7%PQ+R<L("1L:6YE+"`D;6%T8V@I*2!["B`@
M("`@("`@("`@("`@("`D96YC;V1I;F<@/2`D;6%T8VA;,ET["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&1O8U]E;B`@(#T@9&]M>&UL7V]P96Y?9FEL
M92@D9FEL95]E;BD["B`@("`@("`@("`@(&EF("@A:7-?;V)J96-T*"1D;V-?
M96XI*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D
M8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)U1H97)E('=A<R!A;B!E
M<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA
M=&EO;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE
M<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S97(N)RP@)&9I;&5?96XI*2D["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64@,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&]C7VQO
M8R`@/2!D;VUX;6Q?;W!E;E]F:6QE*"1F:6QE7VQO8RD["B`@("`@("`@("`@
M(&EF("@A:7-?;V)J96-T*"1D;V-?;&]C*2D@>PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S
M<')I;G1F*"=4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E
M<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@
M+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R
M<V5R+B<L("1F:6QE7VQO8RDI*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:&5L<%]L;V,@/2`D9&]C7VQO8RT^9&]C=6UE;G1?
M96QE;65N="@I.PH@("`@("`@("`@("`D;60U7V5N("`@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`D8V]U;G1?86QL(#T@,#L*("`@("`@("`@("`@)&-O=6YT
M("`@("`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1D;V-?96XM/F=E=%]E
M;&5M96YT<U]B>5]T86=N86UE*"=E;G1R>2<I(&%S("1E;G1R>2D@>PH@("`@
M("`@("`@("`@("`@)&UD-5]E;ELD96YT<GDM/F=E=%]A='1R:6)U=&4H)VED
M)RE=(#T@;60U*"1E;G1R>2T^9V5T7V-O;G1E;G0H*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@9F]R96%C:"`H)&1O8U]L;V,M/F=E=%]E;&5M96YT
M<U]B>5]T86=N86UE*"=E;G1R>2<I(&%S("1E;G1R>2D@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&5N=')Y+3YC:&EL9%]N;V1E<R@I(&%S("1C:&EL
M9"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8VAI;&0M/FYO9&5?='EP
M92@I(#T](%A-3%]#3TU-14Y47TY/1$4@)B8@<W1R<W1R*"1C:&EL9"T^;F]D
M95]V86QU92@I+"`G16YG;&ES:"!E;G1R>2<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1E;G1R>2T^<F5M;W9E7V-H:6QD*"1C:&EL9"D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&-O=6YT7V%L;"LK.PH@("`@("`@("`@("`@("`@)&ED(#T@)&5N
M=')Y+3YG971?871T<FEB=71E*"=I9"<I.PH@("`@("`@("`@("`@("`@:68@
M*"%A<G)A>5]K97E?97AI<W1S*"1I9"P@)&UD-5]E;BDI('L*("`@("`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D8RT^<F5D*"=787)N
M:6YG.B`G*2`N('-P<FEN=&8H)TYO(&5N=')Y('=I=&@@=&AE(&ED("(E<R(@
M97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N)RP@)&ED*2DI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M96YT<GDM/G-E=%]A='1R:6)U=&4H)VUD-2<L("1M9#5?96Y;)&ED72D["B`@
M("`@("`@("`@("`@("`@("`@)&5N=')Y+3YS971?871T<FEB=71E*"=S=&%T
M92<L("=U<'1O9&%T92<I.PH@("`@("`@("`@("`@("`@("`@("1C;W5N="LK
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1O=71P=70@/2`D9&]C7VQO8RT^9'5M<%]M96TH=')U92P@)&5N8V]D:6YG
M*3L*("`@("`@("`@("`@:68@*"$D=&5S="D@>PH@("`@("`@("`@("`@("`@
M)&9P(#T@9F]P96XH)&9I;&5?;&]C+"`G=R<I.PH@("`@("`@("`@("`@("`@
M)&QI;F4@/2!F=W)I=&4H)&9P+"`D;W5T<'5T*3L*("`@("`@("`@("`@("`@
M(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C+3YW
M<FET96QN*'-P<FEN=&8H)R5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P
M+71O+61A=&4G+"`D8V]U;G0L("1C;W5N=%]A;&PI*3L*("`@("`@("`@("`@
M)&,M/G=R:71E;&XH*3L*("`@("`@("!]"B`@("!]"GT*"B1C=7)D:7(@/2!G
M971C=V0H*3L*9&5F:6YE*"=$4R<L($1)4D5#5$]265]315!!4D%43U(I.PH*
M)&QA;F=U86=E(#T@9V5T96YV*"=,04Y')RD["FEF("AE;7!T>2@D;&%N9W5A
M9V4I*2!["B`@("`D;&%N9W5A9V4@/2!G971E;G8H)TQ!3D=504=%)RD["GT*
M"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HD8R`]("9N97<@
M2&]R9&5?0TQ)*"D["FEF("@A)&,M/G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@
M("1C+3YF871A;"@G5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O;2!T:&4@
M8V]M;6%N9"!L:6YE+B<I.PI]"B1C+3YI;FET*"D["@HD8RT^=W)I=&5L;B@D
M8RT^8F]L9"@G+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM)RDI.PHD8RT^
M=W)I=&5L;B@D8RT^8F]L9"@G2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R
M)RDI.PHD8RT^=W)I=&5L;B@D8RT^8F]L9"@G+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM)RDI.PH*+RH@4V%N:71Y(&-H96-K<R`J+PII9B`H(65X=&5N
M<VEO;E]L;V%D960H)V=E='1E>'0G*2D@>PH@("`@)&,M/G=R:71E;&XH)&,M
M/G)E9"@G1V5T=&5X="!E>'1E;G-I;VX@;F]T(&9O=6YD(2<I*3L*("`@(&9O
M;W1E<B@I.PI]"@HD8RT^=W)I=&5L;B@G3&]A9&EN9R!L:6)R87)I97,N+BXG
M*3L*)&QI8G-?9F]U;F0@/2!T<G5E.PH*9F]R96%C:"`H87)R87DH)T-O;G-O
M;&5?1V5T;W!T)R`]/B`G0V]N<V]L92]'971O<'0N<&AP)RP*("`@("`@("`@
M("`@("`@)T-O;G-O;&5?5&%B;&4G("`]/B`G0V]N<V]L92]486)L92YP:'`G
M+`H@("`@("`@("`@("`@("`G1FEL95]&:6YD)R`@("`@(#T^("=&:6QE+T9I
M;F0N<&AP)RD*("`@("`@("`@87,@)&-L87-S(#T^("1F:6QE*2!["B`@("!E
M8VAO("1C;&%S<R`N("<N+BX@)SL*("`@($!I;F-L=61E("1F:6QE.PH@("`@
M:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/F=R965N*"=/2R<I*3L*("`@('T@96QS92!["B`@("`@("`@)&,M
M/G=R:71E;&XH)&,M/G)E9"AS<')I;G1F*"<E<R!N;W0@9F]U;F0N)RP@)&-L
M87-S*2DI.PH@("`@("`@("1L:6)S7V9O=6YD(#T@9F%L<V4["B`@("!]"GT*
M"FEF("@A)&QI8G-?9F]U;F0I('L*("`@("1C+3YW<FET96QN*"D["B`@("`D
M8RT^=W)I=&5L;B@G36%K92!S=7)E('1H870@>6]U(&AA=F4@4$5!4B!I;G-T
M86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H+B<I.PH@("`@)&,M/G=R
M:71E;&XH)VEN8VQU9&5?<&%T:#H@)R`N(&EN:5]G970H)VEN8VQU9&5?<&%T
M:"<I*3L*("`@(&9O;W1E<B@I.PI]"B1C+3YW<FET96QN*"D["@HO*B!#;VUM
M86YD;&EN92!P87)A;65T97)S("HO"B1A<F=S("`@(#T@0V]N<V]L95]'971O
M<'0Z.G)E86102%!!<F=V*"D["B1O<'1I;VYS(#T@0V]N<V]L95]'971O<'0Z
M.F=E=&]P="@D87)G<RP@)V(Z9&AT)RP@87)R87DH)V)A<V4])RP@)V1E8G5G
M)RP@)VAE;'`G+"`G=&5S="<I*3L*:68@*%!%05(Z.FES17)R;W(H)&]P=&EO
M;G,I("8F("1A<F=S6S!=(#T]("1?4T525D526R=02%!?4T5,1B==*2!["B`@
M("!A<G)A>5]S:&EF="@D87)G<RD["B`@("`D;W!T:6]N<R`]($-O;G-O;&5?
M1V5T;W!T.CIG971O<'0H)&%R9W,L("=B.F1H="<L(&%R<F%Y*"=B87-E/2<L
M("=D96)U9R<L("=H96QP)RP@)W1E<W0G*2D["GT*:68@*%!%05(Z.FES17)R
M;W(H)&]P=&EO;G,I*2!["B`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"='971O
M<'0@17)R;W(Z("<@+B!S=')?<F5P;&%C92@G0V]N<V]L95]'971O<'0Z)RP@
M)R<L("1O<'1I;VYS+3YG971-97-S86=E*"DI*2D["B`@("`D8RT^=W)I=&5L
M;B@I.PH@("`@=7-A9V4H*3L*("`@(&9O;W1E<B@I.PI]"FEF("AE;7!T>2@D
M;W!T:6]N<ULP75LP72D@)B8@96UP='DH)&]P=&EO;G-;,5U;,%TI*2!["B`@
M("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=%<G)O<CH@)R`N("=.;R!C;VUM86YD
M('-P96-I9FEE9"XG*2D["B`@("`D8RT^=W)I=&5L;B@I.PH@("`@=7-A9V4H
M*3L*("`@(&9O;W1E<B@I.PI]"B1D96)U9R`](&9A;'-E.PHD=&5S="`@/2!F
M86QS93L*9F]R96%C:"`H)&]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@
M<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@8V%S92`G8B<Z"B`@("`@
M("`@8V%S92`G+2UB87-E)SH*("`@("`@("`@("`@:68@*'-U8G-T<B@D;W!T
M:6]N6S%=+"`M,2D@/3T@1%,I('L*("`@("`@("`@("`@("`@("1O<'1I;VY;
M,5T@/2!S=6)S='(H)&]P=&EO;ELQ72P@,"P@+3$I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&1E9FEN92@G0D%312<L("1O<'1I;VY;,5TI.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=D)SH*("`@("`@("!C87-E
M("<M+61E8G5G)SH*("`@("`@("`@("`@)&1E8G5G(#T@=')U93L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@8V%S92`G="<Z"B`@("`@("`@8V%S92`G
M+2UT97-T)SH*("`@("`@("`@("`@)'1E<W0@/2!T<G5E.PH@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!C87-E("=H)SH*("`@("`@("!C87-E("<M+6AE
M;'`G.@H@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("!F;V]T97(H
M*3L*("`@('T*?0II9B`H(21D96)U9RD@>PH@("`@:6YI7W-E="@G97)R;W)?
M<F5P;W)T:6YG)RP@9F%L<V4I.PI]"FEF("@A9&5F:6YE9"@G0D%312<I*2![
M"B`@("!D969I;F4H)T)!4T4G+"!(3U)$15]"05-%*3L*?0II9B`H)&]P=&EO
M;G-;,5U;,%T@/3T@)VAE;'`G*2!["B`@("!U<V%G92@I.PH@("`@9F]O=&5R
M*"D["GT*)'-I;&5N8V4@/2`D9&5B=6<@?'P@3U-?5TE.1$]74R`_("<G(#H@
M)R`R/B`O9&5V+VYU;&PG.PHD<F5D:7)?97)R(#T@3U-?5TE.1$]74R`_("<G
M(#H@)R`R/B8Q)SL*)&]P=&EO;G-?;&ES="`](&%R<F%Y*`H@("`@)V-L96%N
M=7`G("`@(#T^(&%R<F%Y*"=H;#IM.B<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO
M8V%L93TG*2DL"B`@("`G8V]M;6ET)R`@("`@/3X@87)R87DH)VAL.FTZ;DTZ
M)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=N97<G+"`G;65S<V%G
M93TG*2DL"B`@("`G8V]M;6ET+6AE;'`G/3X@87)R87DH)VAL.FTZ;DTZ)RP@
M87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=N97<G+"`G;65S<V%G93TG
M*2DL"B`@("`G8V]M<&5N9&EU;2<@/3X@87)R87DH)VAL.F0Z83HG+"!A<G)A
M>2@G;&]C86QE/2<L("=D:7)E8W1O<GD])RP@)V%D9#TG*2DL"B`@("`G97AT
M<F%C="<@("`@/3X@87)R87DH)VAM.B<L(&%R<F%Y*"=M;V1U;&4])RDI+`H@
M("`@)VEN:70G("`@("`@(#T^(&%R<F%Y*"=H;#IM.FYC.B<L(&%R<F%Y*"=M
M;V1U;&4])RP@)VQO8V%L93TG+"`G;F\M8V]M<&5N9&EU;2<L("=C;VUP96YD
M:75M/2<I*2P*("`@("=M97)G92<@("`@("`]/B!A<G)A>2@G:&PZ;3IC.FXG
M+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4])RP@)V-O;7!E;F1I=6T])RP@
M)VYO+6-O;7!E;F1I=6TG*2DL"B`@("`G;6%K92<@("`@("`@/3X@87)R87DH
M)VAL.FTZ8SIN<R<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG+"`G8V]M
M<&5N9&EU;3TG+"`G;F\M8V]M<&5N9&EU;2<L("=S=&%T:7-T:6-S)RDI+`H@
M("`@)VUA:V4M:&5L<"<@(#T^(&%R<F%Y*"=H;#IM.B<L(&%R<F%Y*"=M;V1U
M;&4])RP@)VQO8V%L93TG*2DL"B`@("`G=7!D871E)R`@("`@/3X@87)R87DH
M)VAL.FTZ8SIN)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=C;VUP
M96YD:75M/2<L("=N;RUC;VUP96YD:75M)RDI+`H@("`@)W5P9&%T92UH96QP
M)ST^(&%R<F%Y*"=H;#IM.B<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG
M*2DL"B`@("`G<W1A='5S)R`@("`@/3X@87)R87DH)VAL.FTZ;SHG+"!A<G)A
M>2@G;6]D=6QE/2<L("=L;V-A;&4])RP@)V]U='!U=#TG*2D**3L*)&]P=&EO
M;G-?87)R(#T@)&]P=&EO;G-;,5T["B1C;60@("`@("`@("`](&%R<F%Y7W-H
M:69T*"1O<'1I;VYS7V%R<BD["FEF("AA<G)A>5]K97E?97AI<W1S*"1C;60L
M("1O<'1I;VYS7VQI<W0I*2!["B`@("`D8VUD7V]P=&EO;G,@/2!#;VYS;VQE
M7T=E=&]P=#HZ9V5T;W!T*"1O<'1I;VYS7V%R<BP@)&]P=&EO;G-?;&ES=%LD
M8VUD75LP72P@)&]P=&EO;G-?;&ES=%LD8VUD75LQ72D["B`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D8VUD7V]P=&EO;G,I*2!["B`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/G)E9"@G17)R;W(Z("<@+B!S=')?<F5P;&%C92@G0V]N<V]L95]'
M971O<'0Z)RP@)R<L("1C;61?;W!T:6]N<RT^9V5T365S<V%G92@I*2DI.PH@
M("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@=7-A9V4H*3L*("`@("`@
M("!F;V]T97(H*3L*("`@('T*?0H*+RH@4V5A<F-H:6YG(&%P<&QI8V%T:6]N
M<R`J+PIC:&5C:U]B:6YA<FEE<R@I.PH*)&,M/G=R:71E;&XH<W!R:6YT9B@G
M4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<R<L($)!4T4I*3L*
M)&1I<G,@/2!S96%R8VA?87!P;&EC871I;VYS*"D["@II9B`H)&1E8G5G*2![
M"B`@("`D8RT^=W)I=&5L;B@G1F]U;F0@9&ER96-T;W)I97,Z)RD["B`@("`D
M8RT^=W)I=&5L;BAI;7!L;V1E*")<;B(L("1D:7)S*2D["GT*"B1A<'!S(#T@
M<W1R:7!?:&]R9&4H)&1I<G,I.PHD87!P<ULP72`]("=H;W)D92<["B1C+3YW
M<FET96QN*'=O<F1W<F%P*'-P<FEN=&8H)T9O=6YD(&%P<&QI8V%T:6]N<SH@
M)7,G+"!I;7!L;V1E*"<L("<L("1A<'!S*2DI*3L*)&,M/G=R:71E;&XH*3L*
M"G-W:71C:"`H)&-M9"D@>PH@("`@8V%S92`G8VQE86YU<"<Z"B`@("!C87-E
M("=C;VUM:70G.@H@("`@8V%S92`G8V]M<&5N9&EU;2<Z"B`@("!C87-E("=M
M97)G92<Z"B`@("`@("`@)&-M9"@I.PH@("`@("`@(&)R96%K.PH@("`@8V%S
M92`G8V]M;6ET+6AE;'`G.@H@("`@("`@(&-O;6UI="AT<G5E*3L*("`@("`@
M("!B<F5A:SL*("`@(&-A<V4@)V5X=')A8W0G.@H@("`@("`@('AT<F%C="@I
M.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G:6YI="<Z"B`@("`@("`@:6YI
M="@I.PH@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@;65R9V4H*3L*
M("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VUA:V4G.@H@("`@("`@(&-L96%N
M=7`H=')U92D["B`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("!M86ME
M*"D["B`@("`@("`@8G)E86L["B`@("!C87-E("=M86ME+6AE;'`G.@H@("`@
M("`@(&UA:V5?:&5L<"@I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G=7!D
M871E)SH*("`@("`@("!X=')A8W0H*3L*("`@("`@("`D8RT^=W)I=&5L;B@I
M.PH@("`@("`@(&UE<F=E*"D["B`@("`@("`@8G)E86L["B`@("!C87-E("=U
M<&1A=&4M:&5L<"<Z"B`@("`@("`@=7!D871E7VAE;'`H*3L*("`@("`@("!B
M<F5A:SL*("`@(&-A<V4@)W-T871U<R<Z"B\O("`@("`@("!X=')A8W0H*3L*
M("`@("`@("!M97)G92@I.PHO+R`@("`@("`@<W1A='5S*"D["B`@("`@("`@
M8G)E86L["B`@("!D969A=6QT.@H@("`@("`@("1C+3YW<FET96QN*"1C+3YR
M960H)T5R<F]R.B`G*2`N('-P<FEN=&8H)U5N:VYO=VX@8V]M;6%N9#H@)7,G
M+"`D8VUD*2D["B`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("!U<V%G
M92@I.PH@("`@("`@(&9O;W1E<B@I.PI]"@IF;V]T97(H*3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:7-?25,N<&\`````
M````````````````````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8S
M,C,T-``Q,#4Q-30S,3`V,P`P,38T,#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R!)8V5L86YD:6,@=')A;G-L871I;VYS
M(&9O<B!D:7-K('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@9&ES:R!P86-K86=E+@HC"FUS9VED("(B
M"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`N-5QN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`R+3`Q+3$P(#$Y.C`P*S`Q,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,3$M,3D@,C`Z,S,K,#`P,%QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!":F]R;B!$879I9'-S;VX@/&)J;W-S:4!S
M;F5R<&$N:7,^7&XB"B),86YG=6%G92U496%M.B!)8V5L86YD:6,@/'-U<'!O
M<G1`<VYE<G!A+FES/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#D*;7-G:60@(B(*(B`@+4TL("TM;65S<V%G93U-15-3
M04=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D
M969A=6QT(&]N97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HU,PIM<V=I9"`B(@HB("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H
M:7,@4$\@9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O7&XB"B(@
M("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F
M<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T;UQN(@HB("`@("`@("`@("`@("`@
M("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP96YD:75M+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$S"FUS9VED("(B"B(@("UB+"`M
M+6)A<V4]+U!!5$@@($9U;&P@<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I
M<F5C=&]R>2!T:&%T('-H;W5L9"!B95QN(@HB("`@("`@("`@("`@("`@("`@
M("!U<V5D+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-CD*
M;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!-97)G92!N97<@
M=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N9&EU;2!F:6QE7&XB"B(@("`@
M("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O
M;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE7&XB"B(@("`@("`@("`@("`@("`@
M("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-C,@<&\O=')A;G-L871I;VXN<&AP.C@Q('!O
M+W1R86YS;&%T:6]N+G!H<#HX-PIM<V=I9"`B(@HB("`M8RP@+2UC;VUP96YD
M:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F
M('1H92!D969A=6QT7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@;VYE
M("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$T"FUS9VED("(@
M("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T
M:&4@97AE8W5T960@8FEN87)I97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HU-`IM<V=I9"`B("`M9"P@+2UD:7)E8W1O<GD]1$E2("`@
M0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,34*;7-G:60@(B`@+6@L("TM
M:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0R('!O+W1R86YS;&%T:6]N+G!H
M<#HV-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-S4*;7-G:60@(B`@+6PL("TM;&]C
M86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W('!O+W1R86YS;&%T:6]N+G!H
M<#HV,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-SD*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C@U"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H
M:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-34*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO
M8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8X"FUS
M9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@
M;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C0S"FUS9VED("(@("UM+"`M+6UO9'5L93U-
M3T153$4@("`@0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#@*;7-G:60@(B(*(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@
M=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV,@IM<V=I9"`B("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F
M;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C@P"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@365R9V4@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<V"FUS9VED
M("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE;'`@9FEL
M97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C@V"FUS9VED("(@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92XB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4X"FUS9VED("(@
M("UM+"`M+6UO9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@
M9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HW,`IM<V=I9"`B(@HB("`M;BP@+2UN;RUC;VUP96YD
M:75M("`@($1O;B=T(&UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AE(&-O
M;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV
M-"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(@<&\O=')A;G-L871I;VXN<&AP.C@X
M"FUS9VED("(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@
M8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C<Q"FUS9VED("(@("US+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T<F%N
M<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-@IM<V=I9"`B("`M="P@+2UT
M97-T("`@("`@("!3:&]W('1H92!E>&5C=71E9"!C;VUM86YD<R!B=70@9&]N
M)W0@<G5N(&%N>71H:6YG+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`U"FUS9VED("(B"B(@(&-L96%N=7`@("`@($-L96%N<R!T:&4@
M4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E(&5N
M=')I97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@*
M;7-G:60@(B`@8V]M;6ET("`@("`@0V]M;6ET('1R86YS;&%T:6]N<R!T;R!T
M:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P.0IM<V=I9"`B("!C;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F:6QE
M<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.CDY"FUS9VED("(B"B(@(&-O;7!E;F1I=6T@(%)E8G5I;&0@
M=&AE(&-O;7!E;F1I=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S
M('1H95QN(@HB("`@("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I=6TN(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#`*;7-G:60@(B`@
M97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M<&QA=&4@*"YP;W0I(&9I;&5S
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3@*;7-G:60@
M(B`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,0IM<V=I9"`B(@HB("!I
M;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@
M;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<UQN(@HB("`@("`@("`@("`@("!O
M=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO8V%L
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-@IM<V=I
M9"`B("!M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O;2!T
M:&4@<W!E8VEF:65D(%!/(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3`W"FUS9VED("(B"B(@(&UA:V4M:&5L<"`@($UA<FL@
M86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@=7`M=&\M
M9&%T92!A;F1<;B(*(B`@("`@("`@("`@("`@<')E<&%R92!T:&4@9FEL92!F
M;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T92UH96QP+B!9;W5<;B(*
M(B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!1E1%
M4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE7&XB"B(@("`@("`@("`@
M("`@(&AE;'`@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P,@IM<V=I9"`B(@HB("!M97)G92`@("`@("!-97)G92!T:&4@8W5R
M<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,PIM<V=I
M9"`B("!U<&1A=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N
M="XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-`IM<V=I
M9"`B(@HB("!U<&1A=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG
M960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H(%A-3"!H96QP7&XB"B(@("`@
M("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I
M;F<@;VYE<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(@
M)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS
M9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"FUS9VED("(@*'EE<W1E
M<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q.`IM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!B>71E<R!W<FET=&5N+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT
M;RUD871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?
M=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8SHS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,C0@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")6:?!H86QD<V'P9V5R\&ER(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HU-C@@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")-87!P86X@7"(E<UPB
M(&5R(&[Z(/YE9V%R('1I;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34W
M(&QI8B]";&]C:R]M971A<BYP:'`Z,38S(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,W"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0S(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC
M96QL960@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-3(T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D
M('1O('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,C@W('!O+W1R86YS;&%T:6]N+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:7,@;F]T('=R:71A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S,X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S
M(@IM<V=S='(@(L$@9FEM;2!M[6[Z=&YA(&9R97-T:2(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O=')A;G-L871I
M;VXN<&AP.C$S-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO
M;B!E>'1R86-T)R!F:7)S="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-3`X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E
M<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5D('1I;"`E
M9"!A9B`E9"!S:V5Y='5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=VES:&5S('1O(&%D9"!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H
M97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@Y
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B3F5T9F%N9V%B\VLB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C@X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.#<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-34T"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z.3(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@:7,@;F]T(&-O;F9I9W5R960@
M:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5')E92]4<F5E+G!H<#HQ-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S
M)R!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-PHC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DY"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8Y,0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,S(X('!O+W1R86YS;&%T:6]N+G!H<#HQ,S,P
M"FUS9VED("(M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q
M,B!(;W5R($9O<FUA="(*;7-G<W1R(")5<'!L_7-I;F=A<B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M
M870B"FUS9W-T<B`B57!P;/US:6YG87(B"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(D9Y<G)I(&)L8?!S[?!A(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(\9V5T=&5X
M=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RY<;B(*(D]P96YI;F<@=&%G
M(&9O=6YD(&EN(&QI;F4@)60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$W"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q
M=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY,3<*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-#(*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P-S0*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY.3(*;7-G:60@(B(*(D$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-PIM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C@*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED
M(")!32]032(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*;7-G:60@(D%022!)1"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8T,`IM<V=I9"`B06-C97!T(')E<75E<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV.#$*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O
M=6YT(%!A<W-W;W)D(@IM<V=S='(@(DQY:VEL;W+P(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,Q-`HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G
M<W1R(")(YFMK86YD:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#4Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C(U"B,L(&9U>GIY"FUS9VED(")!8W1I;VYS
M(@IM<V=S='(@(D'P9V5R\"(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$S,@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z,38*;7-G:60@(D%D9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q-"!A9&UI;B]G<F]U<',N<&AP.C(Q-0IM<V=I
M9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX-0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(
M97)E.B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P."!A9&UI
M;B]G<F]U<',N<&AP.C(P.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<S(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S0*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD(&=R;W5P('1O("<E<R<B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4S(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3,Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@)R5S)R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM
M<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*;7-G:60@(D%D9"!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHS-0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")!9&0@
M<&%I<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8S,0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8S-PIM<V=I9"`B061D('1H
M:7,@=&\@;7D@8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!
M9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")"YG1A(.T@;F5T9F%N9V%B
M\VL@*"5S*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O
M:R(*;7-G<W1R(")"YG1A(.T@;F5T9F%N9V%B\VL@*"5S*2(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET
M:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E(@HB<RXB"FUS9W-T<B`B(@H*
M(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"`G
M)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDV,@IM<V=I9"`B061D:6YG
M(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T-@HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")3
M96YD86YD86YE=&9A;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,V"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B3F5T9F%N9V%B\VLB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM
M<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M.#(*;7-G:60@(D%D<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A
M;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B
M06QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G
M<W1R("+6;&P@<VME>71I(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$X
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H
M96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<*;7-G:60@(D%L;"!097)M
M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q
M"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,PIM<V=I9"`B06QL;W<@<V5T
M=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-#`X"FUS9VED(")!
M;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(R"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DV"FUS9VED(")!;'1E
M<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#@X"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M
M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS
M9W-T<B`B3F5T9F%N9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS
M9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`BTW3F:W0@9VEL9&D@=&EL9W)E:6YT+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0HC+"!F=7IZ>0IM
M<V=I9"`B06YS=V5R(@IM<V=S='(@(E-V87)A\"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B
M06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C8*(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(@IM
M<V=S='(@(D'P9V5R\"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM
M<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D
M>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B
M07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,C0*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(F%P<NUL(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I
M9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(D5R="#^^B!V:7-S('5M(&'P(/[Z('9I;&II<B!G97)A(/YE
M='1A/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E("<E<R<@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G
M<W1R(")%<G0@_OH@=FES<R!U;2!A\"#^^B!V:6QJ:7(@=.9M82#^97-S82!M
M]G!P=3\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#
M24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X
M"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U
M8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Q-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(D%S
M<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$V-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(T.0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,Q.`IM<V=I9"`B
M071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U
M97-T('EO=2!S96YT(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S4*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C,X
M"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HY
M.`IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4W-PHC+"!F=7IZ>0IM<V=I9"`B071T96YD965S
M(@IM<V=S='(@(E9I\&AE;F=I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S
M="(*;7-G<W1R("+A9_IS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")!=7-T
M<FEA(@IM<V=S='(@(N%G^G-T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R("(B"B)6:7-T=6X@=7!P:V%S='-I;G,@;6ES=/-K<W0N
M($YE=/YJ\VYN:6YN(&MO;2!M9?`@969T:7)F87)A;F1I('9I;&QU.B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3@R"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER
M960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB
M875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.#D*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"(*;7-G<W1R(")%;F1U<G;M<W5N(&UI<VAE<'!A\&ES="XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")%;F1U<G;M<W5N(&UI<VAE<'!A\&ES
M="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS
M9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V
M.`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.#,*
M(RP@9G5Z>GD*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E1I
M;'3F:V%R(&YE=&9A;F=A8N9K=7(Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,30*;7-G:60@(D%W86ET:6YG(%)E
M<W!O;G-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS
M9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C
M:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*
M;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME
M<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C8P.`IM<V=I9"`B0F%R92(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R(")3=.9R\"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4
M>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.`HC+"!F=7IZ>0IM<V=I9"`B0F]L9"(*;7-G<W1R(")-
M96=I;FWA;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.`IM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R(")-]G!P=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(DWV<'!U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D+F\&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@
M(D)O='1O;2(*;7-G<W1R(")"YO!I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z
M:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD:6YG
M($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")"=6EL
M9&EN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(D)Y9V=I(&[Z(&QO8V%L92`E
M<R`N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y
M"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-S,*;7-G:60@(D--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"FUS9VED(")#4D,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#4*;7-G:60@(D-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3,*(RP@9G5Z>GD*;7-G:60@(D-A;&TB"FUS9W-T<B`B2.9T=&$@=FGP(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A
M<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N
M<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$T
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ-PHC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$W"FUS9VED(")#86YC96PB"FUS
M9W-T<B`B2.9T=&$@=FGP(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,3(@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HU,3,*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(D-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")686QS=&EL
M;&EN9V%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#
M871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@
M4&AO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I
M9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/
M+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-E
M;G1E<B(*;7-G<W1R(")"^F$@=&EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(D5F;FES
M_G+A\'5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G
M<W1R(")097)S\VYU;&5G="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@
M(D-H86YG92(*;7-G<W1R(")"<F5Y=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C8*(RP@9G5Z>GD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)(Z7(@9V5T
M=7(@_OH@8G)E>71T(/YV[2!H=F'P82!N869N+"!N971F86YG(&]G('-K97ET
M:7-B;W1N(&ME;75R(&9R86T@[2`B"B)S:V5Y='5M(/[M;G5M+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*
M(RP@9G5Z>GD*;7-G:60@(D-H87(B"FUS9W-T<B`B0G)E>71A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U
M"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#:&5C
M:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I
M9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8X"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R
M(")396UJ82!N_71T('-K97ET:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C(V"B,L(&9U>GIY"FUS9VED(")#
M:&]O<V4@86X@86-T:6]N.B(*;7-G<W1R(")696QD=2!A\&=E<O`Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`IM<V=I9"`B0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-C$S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4U"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@(@IM<V=S='(@
M(DAR96EN<V$@=&EL(.T@;&]C86QE("5S("XN+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")#;&5A<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,38*;7-G:60@(D-L
M96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM
M<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM<V=I9"`B0VQI8VL@
M=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@S"FUS9VED(")#;&EC:V%T96QL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO
M<V4@5VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0R"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L;W5D<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D%F
M<FET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHT"B,L(&9U>GIY"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@
M(DQO:V$@;?9P<'4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(X"B,L(&9U>GIY"FUS9VED(")#;VQL87!S960@
M8F]R9&5R<R(*;7-G<W1R("),;VMA(&WV<'!U(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HR.3<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C(Y.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#<R('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3$*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3(*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C@*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-CD*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#4*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#8*
M;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#4P"B,L(&9U>GIY"FUS9VED(")#;VQO=7(@<V5L
M96-T:6]N(@IM<V=S='(@(E9E;&1U(&'P9V5R\#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM
M<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C@S"B,L(&9U>GIY"FUS9VED(")#;VUI8W,B"FUS
M9W-T<B`B4V5M:F$B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@
M(D-O;6UA;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P
M"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HS.`IM<V=I9"`B0V]M;6%N9"!O<'1I;VYS.B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3<*;7-G:60@(D-O;6UA;F1S
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HS.3D*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P,#`*;7-G:60@(D-O;6UI='1I;F<Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")396UJ82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*(RP@9G5Z>GD*;7-G
M:60@(D-O;7!A;GDB"FUS9W-T<B`B069R:70B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y-PHC+"!F=7IZ>0IM<V=I
M9"`B0V]M<&QE=&5D(@IM<V=S='(@(E-E;6IA(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VUP;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R(")396UJ
M82!S:V5Y=&D@*"5S*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0HC
M+"!F=7IZ>0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(E-E;6IA(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#<*;7-G:60@(D-O;F1I=&EO;G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.#D*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,W
M"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(DQY
M:VEL;W+P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9"XB"FUS9W-T<B`B16YD=7)V[7-U;B!M:7-H97!P8?!I<W0N(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F
M=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")%;F1U
M<G;M<W5N(&UI<VAE<'!A\&ES="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW-S8*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S<X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S8R"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(").971F86YG:?`@7"(E<UPB('9A<B!BYG1T(.T@;F5T9F%N
M9V%B\VMI;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C`*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B`G)7,G(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT
M:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"B,L
M(&9U>GIY"FUS9VED(")#;V]K:64B"FUS9W-T<B`B4V5M:F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B069R:70B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")#
M;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")696QD=2!A\&=E<O`Z(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O<'EI;F<@)7,@=&\@)7,B"FUS9W-T<B`B5&5N9VIA<W0@)7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`S,`HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(M[Z(.%T="`Q
M(&[]='0@<VME>71I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-S`*;7-G:60@(D-O=6QD(&YO="!B:6YD
M('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@)R5S)R!U
M<VEN9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#@W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;W!Y("5S
M('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S(Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN
M<&AP.C$P-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,#(*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O
M;G1A8W0N("5S(@IM<V=S='(@(D=A="!E:VMI(&5Y='0@<VME>71U;2!F<N$@
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D=A
M="!E:VMI(&5Y='0@<VME>71U;2!F<N$@)7,Z("5S(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB
M"FUS9W-T<B`B1V%T(&5K:VD@97ET="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D-O=6QD(&YO="!D
M971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(X,@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3(*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M-#4*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O
M9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER("<E<R<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<P
M-0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S8*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N("<E<R<@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M)R5S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T
M+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@
M)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D
M971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B1V%T(&5K:VD@97ET
M="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#,V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O
M=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R;61I<B`G)7,G+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*
M;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@
M)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HX,`IM
M<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=6YL:6YK("<E<R<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M)R5S)SH@)7,B"FUS9W-T<B`B1V%T(&5K:VD@97ET="!S:V5Y='5M(&9RX2`E
M<SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4V"FUS9VED(")#
M;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T
M:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R
M:6=H=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-`HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;G1E9"!T97AT(@IM<V=S='(@(DQE:?!RZ71T=7(@=&5X=&DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U
M;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C8W"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.3<*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,0IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(D+Z82!T:6PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0OIA('1I;"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*
M;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B0OIA('1I;"!N_6IA
M(&WV<'!U("AR=7-L86OV<F9U*2!U;F1I<B!E>61D('-K97ET:2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"B,L(&9U>GIY
M"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B0OIA('1I;"!M
M]G!P=2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(Q-`IM<V=I9"`B0W)E871O<B!097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C,T"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0OIA
M('1I;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(%!H87-E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S
M='(@(DQE:?!RZ71T=7(@=&5X=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(D-U<G)E;G0@
M55),(&ES(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*
M;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"FUS9VED(")#=7)R96YT(&-O;F1I
M=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N(@IM<V=S='(@(E-T:6QL82!A\&=E<O!I<B!S96T@97)U(&9R86UK
M=N9M9&%R(/YE9V%R(/[Z('1E;F=I<W0@)7,N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#
M=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED
M(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,C,@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(D1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D1A:6QY(@IM
M<V=S='(@(MIT;&ET(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED
M(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Y-PIM<V=I9"`B1&%T92(*;7-G<W1R(")$86=S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*(RP@9G5Z>GD*
M;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B3?-T=&5K:?`@_F%N;CHB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")$871E
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Q"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B;6'M
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G
M<W1R(")%>?!A(&WV<'!U*&TI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,X-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E
M<V5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B1&5C:6UA;"!N=6UB
M97)S(@IM<V=S='(@(F1E<V5M8F5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#4*(RP@9G5Z>GD*;7-G:60@(D1E
M8VQI;F5D(@IM<V=S='(@(D5Y='0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M.#<@;&EB+W!R969S+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B
M"FUS9W-T<B`B17GP82(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@Q"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(DYO=&$@<VKA;&9G969I\"!G:6QD:2(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E
M;G1I='DB"FUS9W-T<B`B4VKA;&9G969I\"!K96YN:6UA<FLB"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,3D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ.38*;7-G:60@(D1E9F%U;'0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<*;7-G:60@
M(D1E9F%U;'0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")$969I;FET:6]N<R(*
M;7-G<W1R(")3:VEL9W)E:6YI;F<@X2!S[75R96=L=2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0S"B,L(&9U>GIY
M"FUS9VED(")$96QE9V%T92!P;W-I=&EO;B(*;7-G<W1R(")396UJ82!N_71T
M('-K97ET:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-CDS"B,L(&9U>GIY"FUS9VED(")$96QE9V%T960B"FUS9W-T
M<B`B17ET="(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S(@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,CDU(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S$U"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S,R('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B17GP82(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@Y(&%D;6EN+V=R;W5P<RYP:'`Z,C$W
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B17GP82(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-C,@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B17GP82!S:V5Y='5M(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B17ED9"!S
M:V5Y=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G
M<W1R(")%>?!A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M
M;B(*;7-G<W1R(")%>?!A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*
M;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@<F]W(@IM<V=S='(@(D5Y\&$B"@HC.B!T96UP;&%T97,O
M<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B5F5L9'4@:V5N;FDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C8*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6XB"FUS9W-T<B`B4W1I;&QA(&[Z=F5R86YD:2!T[6UA8F5L=&DN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M(@IM<V=S='(@(E-T:6QL82!N^G9E<F%N9&D@=.UM86)E;'1I+B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES('!E
M<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,U"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.30*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(U,@HC+"!F=7IZ>0IM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R(")%>?!A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N
M;6%R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8T,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#<Q"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HQ,3`@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3$T('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C$R-`IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU-C4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@
M9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(E9A;&MO<W1I<B!N
M;W1A;F1A(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G
M:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*(RP@9G5Z
M>GD*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(MYE='1A('-K97ET:2!H969U<B!V
M97)I\"!S96YT('1I;"!K97)F:7-U;7-J\VYA<B!S96T@=&EL:WEN;FEN9R!U
M;2!R=7-L</-S="`B"B(H4U!!32DN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y-0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,34*;7-G:60@(D1E=R!0;VEN="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,@IM<V=I9"`B1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DT"FUS9VED(")$97<@<&]I;G0Z("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I
M9"`B1&ER96-T;W)Y(@IM<V=S='(@(E+V\'5N87+A='0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(MIT;&ET<W-T:6QL:6YG
M87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS9VED(")$:7-P;&%Y
M(&9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,C$*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T
M(@IM<V=S='(@(MIT;&ET(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN
M<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS,34*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE
M=&4B"FUS9W-T<B`B16YD=7)V96MJ82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-`IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3D*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0IM<V=I9"`B1&]W;FQO
M860B"FUS9W-T<B`B4^9K:F$@>69I<B#A('9I;FYU<W3V\"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")3YFMJ82`E<R!Y9FER(.$@
M=FEN;G5S=/;P(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-0IM<V=I
M9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3D*(RP@9G5Z
M>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")0\W-T;6%P<&$B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(Y-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B
M161I="(*;7-G<W1R(")"<F5Y=&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G
M:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.#@@861M:6XO9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D:70@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HV
M,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@V"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T
M:6]N<R!F;W(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,C`T(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U>GIY"FUS
M9VED(")%9'5C871I;VXB"FUS9W-T<B`B0?!G97+P(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(D5L96UE;G0N
M+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0P"FUS9VED(")%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(DYE=&9A;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.38S"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`B3F5T9F%N9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR.#`*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")686QS
M=&EL;&EN9V%R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R("+!<NWP86YD:2!S:V5Y=&DB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C@X"B,L(&9U>GIY"FUS9VED(")%;7!T>2!R97-U
M;'0N(@IM<V=S='(@(E3F;6$@<G5S;&%K]G)F=2(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y
M('-E87)C:"!T97)M<R(*;7-G<W1R(")4YFUA(')U<VQA:_9R9G5M]G!P=2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S(*;7-G:60@(D5N86)L92!I
M;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E
M>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*
M;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#0X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-34S"FUS9VED(")%;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8P-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$U"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA
M<F=E($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C$Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$Q-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<FEE<SH@)60@
M=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@
M=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R
M:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET
M<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O
M<G1A;"]I;F1E>"YP:'`Z-SD*;7-G:60@(D5R<F]R(@IM<V=S='(@(E9I;&QA
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HQ.34*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HR-S@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HS-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN
M9R!R97!L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@)R5S
M)RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-3(R('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<W"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ-#,X('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-3`Q"B,L(&9U>GIY"FUS9VED(")%<G)O<CH@(@IM<V=S='(@(E9I;&QA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(Y"FUS9VED
M(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(L$@:V]R=&5R<R!F<F5S=&DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"B,L(&9U>GIY"FUS9VED
M(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BP2!F:6UM(&WM;OIT;F$@9G)E
M<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(L$@,S`@<V5K+B!F<F5S=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S(X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(D5V97)Y
M(#4@;6EN=71E<R(*;7-G<W1R("+!(&9I;6T@;>UN^G1N82!F<F5S=&DB"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"B,L
M(&9U>GIY"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+!(&WM;OIT=2!F
M<F5S=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,P"FUS9VED(")%
M=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BP2!HX6QF=.UM82!F<F5S=&DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+!(&WM;OIT
M=2!F<F5S=&DB"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR.`IM
M<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L
M<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,CDY('!O+W1R86YS;&%T:6]N+G!H<#HS,C`@
M<&\O=')A;G-L871I;VXN<&AP.C,V,@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#0Q('!O+W1R86YS;&%T:6]N+G!H<#HU-#$@<&\O=')A;G-L871I;VXN<&AP
M.C8P,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S`R('!O+W1R86YS;&%T:6]N
M+G!H<#HW,S<@<&\O=')A;G-L871I;VXN<&AP.C<Y.`HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#<U('!O+W1R86YS;&%T:6]N+G!H<#HY.30@<&\O=')A;G-L
M871I;VXN<&AP.C$P,38*;7-G:60@(D5X96-U=&EN9SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,SDT"B,L(&9U
M>GIY"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B3W!N82!A;&QA<B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(D]P;F$@;?9P<'4B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E
M9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HS.3@*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%>'1R86-T:6YG(&9R
M;VT@)7,N+BX@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HV,`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@
M4TU"('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HV,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-C`X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C8T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")&86ER(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O
M92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&
M87@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(F9E8G+Z87(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q.`IM<V=I9"`B1F5E;',@3&EK
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3DX"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D9E=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@
M(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PHC+"!F=7IZ>0IM
M<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(E-K<N%R;F%F;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE
M($YA;64B"FUS9W-T<B`B4VMRX7)N869N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDY.0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B96YG:6X@<F5G;&$@=F%L:6XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#DQ"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A9"(*
M;7-G<W1R(")296ET=7(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX-3,*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#8*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B4^UU<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z
M>GD*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;F$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM
M<V=S='(@(D9Y<G-T82!S[?!A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T
M(&QI8B]";&]C:R]M;V]N+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@
M475A<G1E<B(*;7-G<W1R(")&>7)S=&$@<^WP82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C$T"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G
M:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-3@@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G
M:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,@IM<V=I9"`B1F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<X"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.34*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDY"B,L(&9U>GIY"FUS
M9VED(")&;W)M<R(*;7-G<W1R(")&<N$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T
M=6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*
M;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B1F]R=6US(@IM<V=S
M='(@(DWV<'!U<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#8*
M(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(L%F<F%M<V5N9&$B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&;W5N9"!A<'!L:6-A=&EO;G,Z("5S(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ-#4R"FUS9VED(")&;W5N9"!D:7)E8W1O<FEE
M<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G(B"FUS9W-T<B`B1G+A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(DYA9FXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B
M2.9T=&$@=FGP(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-PHC
M+"!F=7IZ>0IM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@
M(E5P<&S]<VEN9V%R(&YE=/YJ\VYS(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C<*;7-G:60@(D9R964O0G5S>2!2
M97!L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0R,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HR-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HS-#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E
M<W!O;G-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'
M=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O
M;2(*;7-G<W1R(")&<N$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1G+A
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z
M>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4VMI;&=R96EN
M:6YG(.$@<^UU<F5G;'4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#(@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,SD*(RP@
M9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").869N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B1G5Z>GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P
M"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E
M("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V-O;F9I9RYH=&UL.C$P"FUS9VED(")'96YE<F%T960@0V]D
M92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D=E;F5R871I;F<@<W1A='5S(&9O<B!M;V1U;&4@
M)7,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<Q"FUS9VED(")'971O<'0@
M17)R;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*
M(RP@9G5Z>GD*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B4VMRX7)N869N
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B
M1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B3&5I
M=&$@[2!S:V5Y='5M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G
M<W1R(")%9FYI<_YRX?!U<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<P"FUS
M9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4X"FUS9VED(")'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HR,#$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-S<*
M;7-G:60@(D=R;W5P('!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$W-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(U,`HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C<@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,#4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX
M.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3(X(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C`V"FUS9VED(")'=65S="!P97)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B
M1W5I;F5A(@IM<V=S='(@(FKZ;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,S,0IM<V=I9"`B2$@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C,Y.0IM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G
M:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S8*;7-G:60@(DAE
M861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX
M+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<X(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#4*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G
M:60@(DAE;'`B"FUS9W-T<B`B2&KA;'`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D
M:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S<V"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&KA;'`B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.34*;7-G:60@(B(*(DAE;'!E<B!A<'!L
M:6-A=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F
M;W(@=&AE($AO<F1E7&XB"B)F<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO
M;G,N7&XB"B)&;W(@86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@4D5!
M1$U%(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3<@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(DAI9V@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z,S(Q"FUS9VED
M(")(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-`IM<V=I9"`B2&]?;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-#(V"FUS9VED(")(;VUE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0HC+"!F=7IZ
M>0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A;F5T9F%N
M9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3`*(RP@9G5Z>GD*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5.UM86)E
M;'1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C(*;7-G:60@(DAO<F1E(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(Y"FUS9VED(")(
M;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C`X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@7"(E<UPB(@IM<V=S='(@(DUA<'!A;B!<(B5S7"(@=F%R(&5N9'5R;F5F
M;F0@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$U
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@7"(E<UPB(@IM<V=S='(@(EPB
M)7-<(B!V87(@9V5R\"!V:7)K(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#@Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q
M-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(X,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@
M4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR.`IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@
M(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(X"FUS9VED(")(=6UI
M9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(Q"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S(P
M"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A
M;F5T9F%N9R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z
M-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I
M9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDT"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED("))
M8V]N<R!/;FQY(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM<V=I9"`B26-O
M;G,@=VET:"!T97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.#`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B2V5N
M;FEN869N.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C4X-@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#4*;7-G
M:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$U.`IM
M<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I
M9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S,*;7-G:60@(DEM<&]R=&5D
M(&9I96QD<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HW,#$*;7-G:60@(DEN(%!R;V-E<W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S$*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E-LX?!U(&EN;B!N;W1A;F1A
M;F%F;B!O9R!L>6ML:6]R\"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$T,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*(RP@9G5Z>GD*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R(")E;F=I;FXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"B,L(&9U>GIY"FUS9VED("));F9O(@IM<V=S='(@(DAU;F1S82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G:60@(DEN
M9F]R;6%T:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C4X,@HC+"!P:'`M9F]R;6%T"FUS9VED("));FET:6%L:7II
M;F<@;6]D=6QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN
M<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(E-K97ET:2!S96T@
M8OII\"!E<B!A\"!S=F%R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S
M"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3D*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G
M<W1R(")-\W1T96MI\"!F>7)I<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L
M=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU
M;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S
M<V%G97,B"FUS9W-T<B`B4VME>71I('-E;2!B^FGP(&5R(&'P('-V87)A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,PIM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(P"FUS9VED("));G-E<G0@
M=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R
M"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HR.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HS-3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E
M;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A
M;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L
M:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R.3<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-@IM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.34*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-#,*
M;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-0IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@)R5S)R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-#,@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C(P"FUS9VED("));G9A;&ED
M('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@
M<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B26YV86QI
M9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C(*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R(")%9FYI<_YRX?!U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B27-O
M;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("))<W)A96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@
M(DET86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")J86[Z87(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS
M9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B:OIL[2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-SD*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED
M(")*=6YE(@IM<V=S='(@(FKZ;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G
M:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME97`@;W)I9VEN
M86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM
M<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G
M:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y($-R96%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P
M,`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.`IM<V=I9"`B2V5Y($QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HS.3<*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+
M97D@57-A9V4B"FUS9W-T<B`B4VME>71I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S(V"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHX"B,L(&9U>GIY"FUS9VED("),85]Y;W5T
M(@IM<V=S='(@(D%F=&5N9VIA<W0B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<V('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(DQA;F=U
M86=E(@IM<V=S='(@(E1U;F=U;>%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("),87-T
M($AA;&8B"FUS9W-T<B`B<^WP87-T82!B;',N(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@X(&QI8B]";&]C:R]M;V]N+G!H<#HY,`HC+"!F=7IZ>0IM<V=I
M9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(G/M\&%S=&$@8FQS+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,30Y"FUS9VED("),87-T(%5P9&%T960Z(@IM
M<V=S='(@(G/M\&%S="!U<'!FYG)T.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C8V-@HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R(*;7-G<W1R(")3[?!A<W0@=&5N9W-T.B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C8V.`HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E/M\&%S="!T96YG<W0Z("5S(&9R
MX2`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C8V,PIM<V=I9"`B
M3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B4^WP87-T('1E;F=S=#H@06QD
M<F5I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T
M=&QA;F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA
M=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")&<F%M
M<V5T;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@
M(DSM8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B5FEN<W1R:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(DQE9G0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3D*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3.UB97+M82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G
M:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DQI9VAT(%)A:6XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C0*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G
M:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I
M;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED
M("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI;FLB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4V"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@
M(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S`*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@
M5&]P:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*
M;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R(")(:N%L
M<"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS
M9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS
M9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI=&CA
M96XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,S.`IM<V=I9"`B3&]A9&EN
M9R!L:6)R87)I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<X
M"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M-S`@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8S"B,L(&9U
M>GIY"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")!\&=E<O`B"@HC.B!L;V=I
M;BYP:'`Z,34U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-C0@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS
M9VED("),;V<@:6XB"FUS9W-T<B`B5&5N9VIA<W0B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,34X"FUS9VED("),;V<@;W5T(@IM<V=S='(@
M(MIT<VMRX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(E9E<FME9FYI('9I\"!T96YG:6YG=2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDQ,0HC+"!F=7IZ>0IM<V=I
M9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB5&5N
M9VEN9R!M:7-T\VMS="X@3.UK;&5G82!E<B!N;W1A;F1A;F%F;B#^:71T(&7P
M82!L>6MI;&]R\"!R86YG="!I;FYS;&5G:?`N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3`W"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N
M(@IM<V=S='(@(D5N9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S`*;7-G:60@(DQO;F<@=&5X="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO
M=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C,*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS
M9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*
M;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,T,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3`*;7-G:60@(DU/5$0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*
M;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C<X"FUS9VED(")-86EL(@IM<V=S='(@(E9E
M9G#S<W1U<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C<*;7-G
M:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"FUS9VED(")-86ME
M(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,S4W"FUS9VED(")-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A
M;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HV-S@@<&\O=')A;G-L871I;VXN<&AP.C$P
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B36%K:6YG(&1I<F5C=&]R>2`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R
M(")-86QA=NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S
M='(@(DUA;&'M<^UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*
M;7-G<W1R(")'<N9N:/9F\&%E>6IA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36%L:2(*;7-G<W1R(")-86SM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G
M:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#0P"FUS9VED(")-
M87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDW.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-S8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")M87)S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%R9VEN(@IM<V=S='(@(E-PX7-S[6$B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B
M36%R<VAA;&QE>6IA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$Q
M,0HC+"!F=7IZ>0IM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-V
MYO!I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@
M(DWA<NUT86[M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-`IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#<*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-`IM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDV"FUS9VED(")-87@@=&5M<"!L87-T(#8@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(FUA[2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*(RP@9G5Z>GD*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B;6'M(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C4S,0IM<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,#,*;7-G:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,#D*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C4*
M;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,30*;7-G:60@(DUE
M971I;F<@57!D871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$Y"FUS9VED(")-965T:6YG(%5P
M9&%T92!297%U97-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,3D*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B365N=2!M;V1E
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE<F=I;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD
M:75M+BXN("(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,X
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@;&]C86QE("5S+BXN("(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S@X"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H
M92!C;VUP96YD:75M+BXN("(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-#(U"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@=')A;G-L
M871I;VX@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R(")386UE:6YA(/[]\&EN
M9V%R(&9Y<FER("5S(&5I;FEN9W5N82XN+B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B4VME>71I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@
M5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF
M:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#D*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C@*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#$*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U.0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q,`IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<Q"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)0
M0R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D("<E
M<R<@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S,*;7-G
M:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE
M>&EC;R(*;7-G<W1R(")-97CM:_,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-[6MR\VYE
M<^UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@
M5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.`IM
M<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`P"FUS9VED(")-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C$W"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B
M4W!E9VQA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-
M:7-C96QL86YE;W5S(@IM<V=S='(@(MUM:7-L96=T(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S,Y"FUS9VED
M(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3<*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B36ES<VEN9R!S
M97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")-X2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW,0IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C0*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B36]D:69Y(%523"(*;7-G
M<W1R(")"<F5Y=&$@<VSS\"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*
M;7-G:60@(DUO9'5L92(*;7-G<W1R(")%:6YI;F<B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM
M<V=S='(@(DWS;F%K\R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P,@IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DUO
M<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,@IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0R.`IM<V=I9"`B36]V92!$
M;W=N(@IM<V=S='(@(D9L>71J82!N:?!U<B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C0S,@HC+"!F=7IZ>0IM<V=I9"`B36]V92!,
M969T(@IM<V=S='(@(D9L>71J82!U<'`B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HT,S8*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#(T
M"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(D9L>71J82!U<'`B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"B,L(&9U>GIY
M"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B9N9R82!N:?!U<B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.38*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-PHC+"!F=7IZ
M>0IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")FYG)A('5P<"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4Q"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N
M<&AP.C$R-`IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*;7-G
M:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3<@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I9"`B3F%M92(*;7-G<W1R(").
M869N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#8*(RP@
M9G5Z>GD*;7-G:60@(DYE961S($%C=&EO;B(*;7-G<W1R(")!\&=E<O`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYE<&%L(@IM<V=S='(@(D[]
M<B!P\W-T=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I
M;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G
M:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").
M971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!2
M96YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM
M<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"B,L(&9U>GIY"FUS9VED
M(").971W;W)K(@IM<V=S='(@(D[]='0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED(").979E<B(*;7-G
M<W1R(")!;&1R96DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,C<*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(D[]<B!P\W-T=7(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@
M*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(D[]<B!P\W-T=7(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED
M(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4X"B,L(&9U>GIY"FUS9VED(").
M97=S(@IM<V=S='(@(D[]='0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,CDR"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C0V"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S
M='(@(D[F<W1A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY
M"FUS9VED(").97AT(%!H87-E(@IM<V=S='(@(D[F<W1A('/M\&$B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V."!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,W,@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I
M;VYS(@IM<V=S='(@(E9A;&MO<W1I<B!N;W1A;F1A(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(D[F<W1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E
M<B(*;7-G<W1R(")!;&1R96DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y,PIM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX.#@*;7-G:60@(DYO(@IM<V=S='(@(DYE:2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ,38*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR,S`*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,C4R"FUS9VED(").;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")"<F5Y=&$B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T,`IM<V=I9"`B3F\@8VAI;&0@<&5R
M;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,0IM<V=I
M9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-S<*(RP@
M9G5Z>GD*;7-G:60@(DYO(&-O;6UA;F0@<W!E8VEF:65D+B(*;7-G<W1R(")%
M;F=I;B!M87!P82!V87(@=&EL9W)E:6YD(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S<*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<U"B,L('!H<"UF;W)M870*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW-#$*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C4W-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,#0*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8W)E
M9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$R-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@96YT<GD@=VET:"!T:&4@
M:60@)R5S)R!E>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<Q
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L
M871I;VXN<&AP.C4R,@HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C86QE('-P96-I
M9FEE9"XB"FUS9W-T<B`B16YG:6X@;6%P<&$@=F%R('1I;&=R96EN9"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C`@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(Q"FUS9VED
M(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY
M"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")._2!S:V5Y
M=&DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM
M<V=S='(@(F5N9VEN;B!T97AT:2!T:6QG<F5I;F1U<B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U>GIY
M"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(")E;F=I;FX@
M=&5X=&D@=&EL9W)E:6YD=7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L
M;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S`*;7-G:60@(DYO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S`*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"!S96YT+B(*;7-G<W1R(")3;.'P=2!I;FX@;F]T86YD86YA9FX@;V<@;'EK
M;&EO<O`B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM
M<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y-@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3`V"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY,3<*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDS-`IM<V=I
M9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8P-`IM<V=I9"`B3F]N
M(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@(DYO;F4B"FUS9W-T<B`B16YG
M:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX
M.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O
M;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R
M;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L
M(&9U>GIY"FUS9VED(").;W)W87DB"FUS9W-T<B`BP69R86US96YD82(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"B,L(&9U>GIY
M"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B16MK:2!U<'!K87-T(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO
M="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,Q"B,L(&9U>GIY"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS
M9W-T<B`B4O;P=6YA<N%T="(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,L
M(&9U>GIY"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(D5K:VD@
M97ET="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`B16MK:2!E
M>71T(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C$W-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,3`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(R-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-3<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(W
M-`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`W(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0T-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3$S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU,S`*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$V,0HC+"!F=7IZ>0IM<V=I9"`B3F]T97,B
M"FUS9W-T<B`B16YG:6XB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP
M:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N
M:6YC.C$P"B,L(&9U>GIY"FUS9VED(").;W1I8V4B"FUS9W-T<B`B16YG:6XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@T
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM
M<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B;O-V96UB97(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B
M"FUS9W-T<B`B;O-V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#,P"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30U,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#@@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@
M(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED(").=6UB97)S
M(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0X,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8V,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C0@<&\O=')A;G-L871I;VXN<&AP.C$T.`HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,T.`IM<V=I9"`B3TLB"FUS9W-T<B`B
MS2!L86=I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@Q-`HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(D5F;FDB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J
M96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3,W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C$U"FUS9VED
M(")/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")O:W3S8F5R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDX"FUS
M9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/
M;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@
M;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4T"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8P,`IM
M<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*
M;7-G<W1R(")686QS=&EL;&EN9V%R(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")686QS=&EL
M;&EN9V%R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,@HC+"!F=7IZ>0IM
M<V=I9"`B3W!T:6]N<SHB"FUS9W-T<B`B5F%L<W1I;&QI;F=A<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@
M(D]R9&5R960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X
M"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,CD*;7-G:60@(D]R9V%N:7II;F<B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@
M(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.30*(RP@9G5Z>GD*;7-G:60@(D]T:&5R(@IM<V=S='(@(F]K=/-B
M97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R.0HC+"!F=7IZ>0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS
M9W-T<B`B57!P;/US:6YG87(@;F5T_FKS;G,B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G
M:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C4P
M"B,L(&9U>GIY"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T
M<B`B2&%F82!U;F1I<G-K<FEF=&ER(&UE\"!D875F=6T@;&ET/R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R.38*;7-G:60@(E!'4"!%
M;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S0X"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S,P
M"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S0*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!-(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S<*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B
M4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ,C8*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3(*;7-G:60@(E!A<W-W;W)D
M(@IM<V=S='(@(DQY:VEL;W+P(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O
M<G)E8W0B"FUS9W-T<B`B3'EK:6QO<O`B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G
M<W1R("),>6MI;&]R\"(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DQY:VEL
M;W+P(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED
M(")087-T92(*;7-G<W1R(")$86=S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP
M8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-`IM<V=I9"`B4&5N9&EN9R!3
M:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PHC+"!F=7IZ>0IM<V=I9"`B
M4&5R8V5N="(*;7-G<W1R(")0<F5N=&$B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.C8*(RP@9G5Z>GD*;7-G:60@(E!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")6:?!H86QD
M<V'P9V5R\&ER(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@HC+"!F
M=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/R(*;7-G<W1R(")&<F%M:W;F;6$@=FGP:&%L9'-A\&=E<O!I<B!V
M:?`@=&5N9VEN9W4B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G
M<W1R(")097)S\VYU;&5G="(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B`G)7,G(&YO="!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR
M,C0@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.CDS"B,Z(&%D;6EN+W!E<FUS
M+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C<T"B,L(&9U
M>GIY"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")5<'!L_7-I;F=A<B!U;2!N;W1A;F1A(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-#4@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-#@*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-3(*;7-G
M:60@(E!E<FUI<W-I;VYS(&9O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM
M<V=S='(@(E5P<&S]<VEN9V%R('5M(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`B96YG:6YN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Q-0IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE
M;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS
M9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#@*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE
M87(N(@IM<V=S='(@(E-LX?!U(&EN;B!N_6IA(&YA9FYI\#HB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@HC+"!F=7IZ
M>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3HB"FUS9W-T<B`B4VSA\'4@:6YN(&[]='0@;?9P<'5N869N.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#<*(RP@9G5Z>GD*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E-L
MX?!U(&EN;B!G:6QD87(@;&5I=&%R9F]R<V5N9'5R+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-C<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M-#D*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N
M(@IM<V=S='(@(E-LX?!U(&EN;B!G:6QD87(@;&5I=&%R9F]R<V5N9'5R+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ."!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(R"FUS9VED(")0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")3;.'P=2!I;FX@
M;F]T86YD86YA9FX@;V<@;'EK;&EO<O`B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O86=R965M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-PIM<V=I9"`B
M4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R
M9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU-#`*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE
M(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0S-0HC
M+"!F=7IZ>0IM<V=I9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T
M:&4@;65N=2!B96QO=RXB"FUS9W-T<B`B5F5L9'4@82YM+FL@96EN82!M]G!P
M=2!T:6P@8?`@;&5I=&$@[2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")3;.'P=2!I
M;FX@;OUJ82!N869N:?`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED
M(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#(T"FUS9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@
M(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP
M.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(S"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U-PIM<V=I9"`B4')E<W-U<F4@870@<V5A
M(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P,@IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,PHC+"!F=7IZ>0IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")&>7)R:2!B
M;&'P<^WP82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S4X(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8R"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S
M='(@(D9Y<G)A('-K97ET:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P.0IM
M<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE
M;2(*;7-G<W1R(")686YD86WA;#\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q,`IM<V=I9"`B4')O:F5C
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"FUS9VED(")0<F]M<'0@
M=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,#D*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI
M8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C(R-PIM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C8R"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2
M861I;R!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E)A:6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*
M;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E)A:6X@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,PIM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A
M:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N
M9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Y,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`HC+"!F=7IZ>0IM<V=I
M9"`B4F5A9"(*;7-G<W1R("+3;&5S:?`B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R(")._2!S:V5Y=&DB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*(RP@9G5Z>GD*
M;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D5N9'5R:&QA
M\&$@;?9P<'5H86TZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T
M<B`B16YD=7)S971J82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-3,*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S(T"FUS9VED(")296UA<FMS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#4W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#<V"FUS9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$T"B,L(&9U>GIY"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R
M(")&:F%R;.9G:F$@=F%L:6XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(Q('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R(")(86QD
M82#A9G)A;2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D9J87)LYF=J
M82!V86QI;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,S(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T
M<B`B9N9R82!N:?!U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T
M:6YG(@IM<V=S='(@(E5P<&S]<VEN9V%R(&YE=/YJ\VYS(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3@*;7-G:60@
M(E)E;6]V92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3,V"B,L(&9U>GIY"FUS9VED(")296UO
M=F4@<&%I<B(*;7-G<W1R(")FYG)A('5P<"(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HR,#4*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B1FIA<FSF
M9VIA('9A;&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R
M;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U
M<V5R(@IM<V=S='(@(F9J87)LYF=J82!H86YD<FET(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(X,`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T.0HC+"!F=7IZ
M>0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B4W9A<F$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V.`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0W
M.`IM<V=I9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N
M97AT(#(@;6]N=&AS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-0IM<V=I9"`B4F5P;'D@=VET
M:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C$X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5P;'DZ("5S(@IM
M<V=S='(@(E-V87(Z(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#@W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P
M96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C4X,2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<T-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S$P"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@S"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,C@*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3DR"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$U
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`IM<V=I9"`B4F5S970B"FUS9W-T
M<B`B16YD=7)S971J82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("),
M>6MI;&]R\"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS
M9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO
M<W%L<VAE;&PN<&AP.C8U"B,L(&9U>GIY"FUS9VED(")297-U;'1S(@IM<V=S
M='(@(DYI\'5R<W1A\&$@;&5I=&%R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C@R,0IM<V=I9"`B4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E*3HB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@Q.0HC+"!F=7IZ>0IM<V=I
M9"`B4F5S=6QT<SHB"FUS9W-T<B`B3FGP=7)S=&'P82!L96ET87(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C<*(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS
M(@IM<V=S='(@(E9A;&MO<W1I<B!N;W1A;F1A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E5P<&S]<VEN
M9V%R(&YE=/YJ\VYS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,`IM
M<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E)I9VAT(&AE861E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS
M9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2
M;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I9"`B4F]L92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,#@*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC+"!F=7IZ>0IM
M<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B5&5N9VEL:?!A;&ES=&DB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$Q"FUS
M9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W
M(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(D5N9'5R<V5T:F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R
M;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G
M:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R(")396YD82!S:V5Y=&DB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-#D*(RP@9G5Z>GD*;7-G:60@(E--4R!-
M97-S86=I;F<B"FUS9W-T<B`B4VMO\&$@<VME>71I(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I
M9"`B4U,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,V,`IM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*
M;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,P
M"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.
M979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM
M<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A
M=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S
M='(@(E9I<W1A('-E;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S
M='(@(E9I<W1A('-E;2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)R5S
M)R(*;7-G<W1R(")6:7-T82!S96TB"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHU"B,L(&9U>GIY"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B
M5F%L:V]S=&ER(&YO=&%N9&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<P"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`G)7,G+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4V-A='1E<F5D(%0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DQE:71A(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B4V5A
M<F-H($5N9VEN97,B"FUS9W-T<B`B3FGP=7)S=&'P82!L96ET87(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,30T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M96%R8VAI;F<@2&]R9&4@87!P;&EC871I;VYS(&EN("5S(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,*;7-G:60@(E-E87)C:&EN9R!G
M971T97AT(&)I;F%R:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE
M<R(*;7-G<W1R(")696QJ82!A;&QT(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&$@9&%T92(*;7-G<W1R(")696QD=2!K96YN:2(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A
M9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(E9E;&IA(&5K:V5R="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHV,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@
M(E9E;&1U('-T869A<V5T=#HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B
M"FUS9W-T<B`B5F5L9'4@<W1A9F%S971T.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+B(*;7-G<W1R(")%>?!A('9I\&AE;F=I+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX,30*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5F5L:F$@96MK
M97)T(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET
M97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G
M<W1R(")696QD=2!S=&%F87-E='0Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHX.0IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-`IM<V=I9"`B4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR.38*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(S.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*
M;7-G<W1R(")696QD=2!S:N%L9F=E9FGP('1U;F=U;>%L.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C4S"B,L(&9U
M>GIY"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")5
M<'!L_7-I;F=A<B!N973^:O-N<R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C0*(RP@9G5Z>GD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E-E;F1A
M('-K97ET:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,30*;7-G:60@(E-E;G-O
M<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B<V5P=&5M
M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*
M;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R
M:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E-E<W-I;VX@240@
M97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Q,@HC+"!F=7IZ>0IM<V=I9"`B4V5T(@IM<V=S='(@(E9E;&IA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G
M:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B5F5L9'4@<VKA;&9G969I\"!T=6YG
M=6WA;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*
M(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"FUS
M9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HS.0IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34S"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L
M92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-#$*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED
M(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,S8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(Y,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34X"FUS9VED("(B"B)3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#`*(RP@9G5Z>GD*;7-G
M:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS
M9W-T<B`B4_UN82!H=F5NYG(@_OH@=&5N9V1I<W0@<^WP87-T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$W"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$U"FUS9VED(")3:&]W('1A
M8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO
M=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X
M"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Q"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8W
M"B,L(&9U>GIY"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")3YFMJ82!Y
M9FER(.$@=FEN;G5S=/;P(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@
M(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,SDY
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-CDR(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C<U-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HX,3(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#<T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDP.2!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY-#8*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3<T(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C$P,#0*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@Y"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E
M<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$R"B,L(&9U>GIY"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B
M56YD:7)S:W)I9G0@_NUN.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-CD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDS-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(W"FUS9VED(")3
M:7IE(@IM<V=S='(@(E-TYG+P(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V-O;F9I<FU?8F]T=&]M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S$@<&\O=')A
M;G-L871I;VXN<&AP.C0X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8V"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HX-C`@<&\O=')A;G-L871I;VXN<&AP.C$R,C,*
M;7-G:60@(E-K:7!P960N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G
M:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM
M<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S8*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(RP@9G5Z>GD*
M;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E+V\'5N87+A
M='0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4U.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4X.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D
M<F5S<R(*;7-G<W1R(")&=6QL="!N971F86YG(/YI='0@*$9RX3HI(#HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY-0IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(E/I<G3A:VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"B,L(&9U>GIY"FUS9VED
M(")3<&QI="!C96QL(@IM<V=S='(@(E9E;&IA(&%L;'0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED
M(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED(")3=&%N
M9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*
M;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0T,PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T.`IM<V=I9"`B4W1A
M<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3=&%R="!Y
M96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C4X,PHC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HT.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W1A='5S(&9O<B!L;V-A;&4@
M)7,N+BX@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3D*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@
M(E5P<&S]<VEN9V%R(&YE=/YJ\VYS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R
M97-S(@IM<V=S='(@(E-E;F1A;F1A;F5T9F%N9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H
M<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@
M6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8F1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R(")%9FYI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#0*;7-G:60@(E-U8FIE8W0@4'5B;&EC($ME>2!);F9O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3(*(RP@9G5Z>GD*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")%9FYI(@H*(SH@<VEG;G5P+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A
M9&0@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT
M:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B169N:2(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM
M<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")&<F%M:W;F;70B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B3F5T
M9F%N9VGP(%PB)7-<(B!V87(@8N9T="#M(&YE=&9A;F=A8O-K:6YA(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(')E;6]V960@)R5S)R!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU
M.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-0IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D("<E
M<R<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34X"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@
M(E-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8V"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-S$*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@
M(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.#,*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS
M9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3@R"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@HC+"!F
M=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(D5F;FDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@U"B,L(&9U>GIY"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R("(@169N:7-L[6YA.B`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S
M"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@
M9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-K<N%R;F%F;B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY
M"FUS9VED(")3=7)N86UE(@IM<V=S='(@(DYO=&%N9&%N869N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W=E9&5N(@IM<V=S
M='(@(DQE<VGP(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY
M-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-PIM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B5"U3
M=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E0M4W1O<FUS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G
M:60@(E135B!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]4
M86)L92YP:'`Z,3,V"FUS9VED(")486)L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@
M(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I
M;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED
M(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-S`*(RP@9G5Z>GD*;7-G:60@(E1A<VMS(@IM<V=S='(@(E9E<FME
M9FYI('9I\"!T96YG:6YG=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@X"FUS9VED(")496UP(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y,`IM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C(Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92`G)7,G
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C0Q"FUS9VED(")496YT871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8X.0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,0IM<V=I9"`B
M5&5X="(*;7-G<W1R(")497AT:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C4*(RP@9G5Z>GD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")497AT
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B
M3N9S=&$@<^WP82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B
M5&5X=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3`S"B,L(&9U>GIY"FUS9VED(")4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(B(*(M[Z
M(&AE9G5R(&[Z(&%F=&5N9W-T("5S+B!486MK(&9Y<FER(&YO=&MU;FEN82X@
MWF5G87(@_OH@=FEL="!T96YG:F%S="!A9G1U<BP@(@HB;F]T8?!U(/[A(')E
M:71I;F$@:.ER(&'P(&YE\&%N+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#8Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92`E<R!H96QP(&9I;&4@9F]R
M("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S,W"FUS
M9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y
M"B,L(&9U>GIY"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RXB"FUS9W-T<B`B4VME>71I;G4@<V5M('9E<FGP('9A<B!A
M\"!S96UJ82!H969U<B!V97)I\"!L;VMA\"XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C$U."!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$V
M.0HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X,"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(P,R!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,0HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S,R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(W,@IM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0Y"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,X"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I
M;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B3F5T9F%N9VGP(%PB)7-<(B!V87(@8N9T
M="#M(&YE=&9A;F=A8O-K:6YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$T-@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N
M871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#$*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T
M('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S@*
M;7-G:60@(E1H92!E=F5N="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N
M9&%R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#<X"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@
M)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$U,@IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C(V,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P
M.3<@<&\O=')A;G-L871I;VXN<&AP.C$R,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM;"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R(")+96YN:6YU(%PB)7-<(B!H969U<B!V97)I\"!E>71T
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$T,PIM
M<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S
M="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E
M<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*
M(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@
M=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED
M(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,N<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A
M8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W
M"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DME;FYI;G4@7"(E<UPB(&AE9G5R
M('9E<FGP(&5Y='0N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")+96YN:?`@(%PB)7-<(B!H
M969U<B!V97)I\"!V:7-T8?`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(DME;FYI\"`@7"(E
M<UPB(&AE9G5R('9E<FGP('9I<W1A\"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HR.3`*;7-G:60@(E1H92!S<&5C:69I960@<F]W
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A
M<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE
M('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S`W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(T,"!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,3<R"B,L(&9U>GIY"FUS9VED(")4:&4@=7!L;V%D960@
M9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D5K:VD@=F%R(&CF
M9W0@8?`@<VMI<'1A('5M('5N9&ER<VMR:69T+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.3,*(RP@9G5Z>GD*;7-G
M:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E
M<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(E5N9&ER<VMR:69T(&AE9G5R('9E
M<FGP(&)R97ET="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,#<@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q,0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y
M("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("+>8?`@97)U(&5N9VEN
M('-K97ET:2#M(/YE<W-U('#S<W1H\VQF:2XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HS,S@*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`V"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN
M('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@
M(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!D;V5S;B=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@)7,N
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@
M=&\@=&AE('-Y<W1E;2X@)7,N(@IM<V=S='(@(B(*(E9A;F1A;>%L(&MO;2!U
M<'`@=FGP('3F;6EN9W4@X2`E<RX@5FEL;'5T:6QK>6YN:6YG(&YE=/YJ\VYS
M:6YS(&9Y;&=I<B!HZ7(@X2`B"B)E9G1I<B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(B(*(E9A;F1A;>%L(&MO;2!U<'`@=FGP('3F;6EN9W4@X2`E<RX@5FEL;'5T
M:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2`B"B)E9G1I<B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB5F%N9&%M
MX6P@:V]M('5P<"!V:?`@=.9M:6YG=2!P\W-T:/-L9G,N(%9I;&QU=&EL:WEN
M;FEN9R!N973^:O-N<VEN<R!F>6QG:7(@(@HB:.ER(.$@969T:7(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R("(B"B)686YD86WA;"!K;VT@=7!P('9I\"!TYFUI
M;F=U(.$@)7,N(%9I;&QU=&EL:WEN;FEN9R!N973^:O-N<VEN<R!F>6QG:7(@
M:.ER(.$@(@HB969T:7(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D
M871I;F<@)R5S)SH@)7,B"FUS9W-T<B`B16MK:2!T\VMS="!A\"!S96YD82!S
M:V5Y=&GP.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@W.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A
M9&5D+B(*;7-G<W1R("(B"B)686YD86WA;"!K;VT@=7!P('9I\"!U<'!H;&7P
M<VQU('-K<N%R+B!3:W+A:6X@97(@92YT+G8N('-TYG)R:2!E;B!L97EF:6QE
M9W0@(@HB97(N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA
M<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET
M97,I+B(*;7-G<W1R("(B"B)686YD86WA;"!K;VT@=7!P('9I\"!U<'!H;&7P
M<VQU('-K<N%R+B!3:W+A:6X@97(@92YT+G8N('-TYG)R:2!E;B!L97EF:6QE
M9W0@(@HB97(@*"5D($U"*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(E9A
M;F1A;>%L(&MO;2!U<'`@=FGP('5P<&AL9?!S;'4@<VMRX7(N(%-K<N%I;B!E
M<B!E+G0N=BX@<W3F<G)I(&5N(&QE>69I;&5G="`B"B)E<BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M="(*;7-G<W1R(")6:6QL82!K;VT@=7!P('9I\"!B:7)T:6YG=2#^97-S82!H
M;'5T82!S:V5Y=&ES:6YS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")6:6QL
M82!K;VT@=7!P(/YE9V%R(.%T=&D@8?`@=FES=&$@=7!P:V%S=&GP+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B5FEL;&$@:V]M
M('5P<"#^96=A<B#A='1I(&'P('/];F$@=6UB9?!I\"!S:V5Y=&DN(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,R"B,L(&9U>GIY"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P('9I
M<W1A('5P<&MA<W1I\"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N
M(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@_F5G87(@X71T:2!A\"!S_6YA('5M
M8F7P:?`@<VME>71I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(D5K:VD@=/-K<W0@8?`@<V5N
M9&$@<VME>71I\#H@)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Y
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R
M871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E
M9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q
M,#<@<&\O=')A;G-L871I;VXN<&AP.C$Q,3,@<&\O=')A;G-L871I;VXN<&AP
M.C$R-#4*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I
M;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H92`B
M"B)F;&%G("UD('1O('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@
M>&UL('!A<G-E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B
M;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@=FGP(&)I<G1I
M;F=U(/YE<W-A(&AL=71A('-K97ET:7-I;G,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P('/];F$@=6UB9?!I\"!S:V5Y
M=&DN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C@R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR,#`*;7-G:60@
M(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$X
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M,S4Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30Y"B,L(&9U>GIY"FUS
M9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BXB"FUS9W-T<B`BWF5T=&$@9VEL9&D@=F5R\'5R(&'P('9E<F$@=&%L
M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B
M"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#`*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Y,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$U-C(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,R"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S<R
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-S,V"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,38*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("+>971T82!G:6QD:2!V97+P=7(@
M8?`@=F5R82!T86QA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M-#`*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C
M,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN
M8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J
M96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA
M:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE
M;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B5&%L86X@=F5R
M\'5R(&'P('9E<F$@8?`@;.%G;6%R:VD@,2XB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3,P-`IM<V=I9"`B5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O
M;2!T:&4@8V]M;6%N9"!L:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$T-PIM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*
M;7-G<W1R("+>971T82!G:6QD:2!V97+P=7(@8?`@=F5R82!T86QA+B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*(RP@9G5Z>GD*
M;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T
M:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@HBWF5S<VD@9VQU9V=I(/YA<F8@8?`@
M=F5R82!V[7-U;B!F<N$@9VQU9V=A;G5M(/YA<B!S96T@;OT@<VME>71I(&5R
M=2!S86UI;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")4:6-K971S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C8*(RP@9G5Z>GD*
M;7-G:60@(E1I;64B"FUS9W-T<B`B5.UM86)E;'1I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*(RP@9G5Z>GD*;7-G
M:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(E3M;6%B96QT:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U,S<*(RP@9G5Z>GD*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(E3M;6%B96QT:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B5&EL
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R
M.0IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W
M:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&]D87DB"FUS9W-T
M<B`B365G:6YMX6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G
M<W1R(")4:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3<*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PHC+"!F=7IZ>0IM<V=I9"`B5&]P(@IM
M<V=S='(@(E1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B5')A;G-L871E
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G
M:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@
M(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-30P"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S4*;7-G:60@(E5N86)L
M92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`X(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C,W,0IM<V=I
M9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-38*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-3@@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,38S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"FUS9VED(")5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(T.`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M.3@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N
M<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-30@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,#4*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S(V"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-SD@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0P(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S8*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S`@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C(P-@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S<P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-S@*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW,C`*;7-G:60@(E5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O075T:"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,CD@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3,T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-3@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$V,PIM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#4@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3(U"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A
M<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T
M;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HU.3(*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C@U"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HU,S,@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S."!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT
M-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(W-PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@
M(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5
M;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$R,B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,3(*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P.2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S4*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P"B,L(&9U>GIY"FUS9VED(")5;F1E
M<FQI;F4B"FUS9W-T<B`B16YD=7)V96MJ82(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C8*(RP@9G5Z>GD*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G
M<W1R(")"<F5Y=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-`HC+"!F=7IZ>0IM
M<V=I9"`B56YF:6QE9"(*;7-G<W1R("+3;&5S:?`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5
M;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-CD*;7-G:60@(E5N:71S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M-2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,38*;7-G:60@(E5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED(")5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,34P,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YK;F]W;B!C;VUM86YD.B`E<R(*;7-G<W1R(")3YFMJ
M82`E<R!Y9FER(.$@=FEN;G5S=/;P(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")5;FMN;W=N('5S
M97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*(RP@9G5Z
M>GD*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@
M(E-T:6QL82!N^G9E<F%N9&D@=.UM86)E;'1I+B(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM<V=S
M='(@(M-N969N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A
M;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O
M<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R
M=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C4W"B,L(&9U>GIY"FUS9VED(")5;G1R86YS;&%T960B"FUS9W-T<B`B
MTW-V87)A\"(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P-B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$X,PHC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B57!D871E(@IM<V=S
M='(@(D1A9W,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C8T.`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*;7-G
M:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3,W(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M)R5S)RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.3(@
M<&\O=')A;G-L871I;VXN<&AP.C$R,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57!D871I;F<@)7,@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#$*;7-G:60@(E5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#$@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$X,@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#D*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO
M;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,S4@<&\O=')A;G-L871I;VXN<&AP.CDR('!O
M+W1R86YS;&%T:6]N+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B57-A9V4Z(@IM
M<V=S='(@(E-K97ET:2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#
M=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PIM<V=I9"`B57-E(%-33"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C8Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4P"FUS
M9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B5F%L:V]S=&ER(&YO=&%N9&$B
M"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R(")686QK;W-T:7(@;F]T86YD82(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$W,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(T-@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!P97)M:7-S:6]N<R(*;7-G<W1R
M(")686QK;W-T:7(@;F]T86YD82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DW('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DYO=&%N9&%N869N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B36%P<&%N(%PB)7-<(B!E<B!N^B#^96=A<B!T:6PB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@
M(E5S97)N86UE.B(*;7-G<W1R(").;W1A;F1A;F%F;B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`B3F]T86YD86YA9FXB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B57-E<G,B"FUS9W-T
M<B`B3F]T86YD86YA9FXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$P,2!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ.#@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,34*(RP@9G5Z>GD*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@
M(D'P9V5R\"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I
M9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I
M9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4T"FUS9VED(")686QU92!I
M;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI
M;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I
M9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B
M5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@
M=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B4&5R<_-N=6QE
M9W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`R"FUS9VED(")6
M97)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC
M86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E9E
M<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T
M($YA;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM
M<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")3_6YA("5S(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@
M<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@
M87,@)7,B"FUS9W-T<B`B4_UN82`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-SD*;7-G:60@(E9I97<@979E;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E9I97<@=&%S:R(*;7-G
M<W1R(")3_6YA("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES
M;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#<*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-0IM<V=I9"`B
M5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<Y"FUS9VED(")6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(Y"FUS9VED(")787)N:6YG(@IM<V=S='(@(D'P
M=O9R=6XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U('!O+W1R86YS;&%T
M:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C<Q,0HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-S(U('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8P('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#8Y"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<W
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@W('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#DW"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`W('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,3$S('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,U"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,C0U('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4Q('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,C<Q"B,L(&9U>GIY"FUS9VED(")787)N:6YG.B`B
M"FUS9W-T<B`B0?!V]G)U;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&
M;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`Y"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED
M(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-C8*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(E=E96ML>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R
M(")696QK;VUI;BAN*2#M("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5F5L:V]M:6XH
M;BD@[2`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5F5L:V]M:6XH;BD@[2`E
M<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")-87!P82!E\&$@:&%M=7(@
M<V5M(.$@8?`@<_UN82#M('5P<&AA9FDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C$*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C
M:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(T"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B
M5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S$*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B
M5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R.0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F
M9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T
M:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4X"FUS9VED(")7:6MI(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q
M"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(D9I;FYA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E=I
M;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M.`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B5VEN9#HB
M"FUS9W-T<B`B1FEN;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B1FEN;F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<Y"FUS
M9VED(")7:7-H;&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7;W)K(@IM<V=S='(@(F7P82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`HC
M+"!F=7IZ>0IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A
M;F5T9F%N9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$Q-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)I
M=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B6"U2968B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I
M9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P
M.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV
M,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")962(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@V"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,C<*;7-G:60@(EE965DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#(*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(EEE
M;65N(@IM<V=S='(@(DQE<VGP(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@X.`IM<V=I9"`B665S(@IM<V=S='(@(DKA(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC
M.C8*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@
M87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I
M=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,C@X"FUS9VED(")9;W4@87)E(&YO="!A=71H
M96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3`S"B,L(&9U>GIY
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(E-T
M:6QL:6YG87(@_NUN87(@:&%F82!V97)I\"!U<'!FYG+P87(N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT,S$*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T
M(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R(")696QD=2!H=F'P82!K96YN:2#^^B!V:6QT(&5Y
M\&$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G
M<W1R(")4:6QG<F5I;F1U('9I\'1A:V%N9&$N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")4:6QG<F5I;F1U('9I\'1A:V%N
M9&$N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHX"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(M[Z(/YA<F9T(&9Y
M<G-T(&'P('9E;&IA(/YA=2!V:?!H96YG:2!S96T@_OH@=FEL="!S96YD82!M
M9?`@<VME>71I;G4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N(@IM<V=S='(@(M[Z(/YA<F9T(&9Y<G-T(&'P('9E;&IA(/YA=2!V:?!H
M96YG:2!S96T@_OH@=FEL="!S96YD82!M9?`@<VME>71I;G4N(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,W"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(E1I;&=R96EN9'4@=FGP=&%K86YD82XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,@HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+B(*;7-G<W1R(")4:6QG<F5I;F1U('9I\'1A:V%N9&$N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("),;W1A;B`E<R!E<B!R=6YN:6X@^G0@X2!T[6UA+B!496YG
M9'4@_FEG(&%F='5R+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS
M9W-T<B`B3F5T9F%N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#(*
M;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B1G5L;'0@;F5T
M9F%N9R#^:71T("A&<N$Z*2`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9
M;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.#DU"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")&=6QL="!N869N(/YI
M='0Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.CD*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.CD*;7-G:60@
M(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.#DY"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92XB"FUS9W-T<B`B(@HB5F5F<VMO\&%R:2#^:6YN('-T>?!U
M<B!E:VMI(/YE<W-A('!R96YT8?!G97+P+B!.;W1A\'4@0U123"]/<'1I;VX@
M;V<@4"!T:6P@(@HB8?`@<')E;G1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C(W"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/
M<'1I;VX@*R!0('1O("(*(G!R:6YT+B(*;7-G<W1R("(B"B)6969S:V_P87)I
M(/YI;FX@<W1Y\'5R(&5K:VD@_F5S<V$@<')E;G1A\&=E<O`N($YO=&'P=2!#
M5%),+T]P=&EO;B!O9R!0('1I;"`B"B)A\"!P<F5N=&$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@
M>F]N93HB"FUS9W-T<B`B3OIV97)A;F1I('3M;6%B96QT:3HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ(@IM<V=S='(@(E-JX6QF9V5F:?`@:V5N;FD@_FET=#HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DQ"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`B1G5L;'0@;F%F;B#^:71T.B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ-#4*;7-G:60@(B(*(EEO=7(@9V5T=&5X="!V97)S:6]N(&ES
M('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+EQN
M(@HB3F]T(&%L;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S
M='(@(E-T:6QL:6YG87(@_NUN87(@:&%F82!V97)I\"!U<'!FYG+P87(N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B4W1I;&QI
M;F=A<B#^[6YA<B!H869A('9E<FGP('5P<&;F<O!A<BXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!R96UO
M=&4@<V5R=F5R<SHB"FUS9W-T<B`B1G5L;'0@;F5T9F%N9R#^:71T("A&<N$Z
M*2`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM
M8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V
M"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z-38*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S
M(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#,R
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S0*;7-G:60@
M(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(R"B,L(&9U>GIY
M"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B1&%G<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F
M=7IZ>0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B17GP82(*"B,Z(&QI
M8B]A<&DN<&AP.C$Q-`IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L
M<"(*;7-G<W1R(")(:N%L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R
M(")496YG:F%S="(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(MIT<VMRX2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS
M(@IM<V=S='(@(E9A;&MO<W1I<B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.`IM<V=I
M9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$P-@IM
M<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B7U1A8FQE
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$P
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HX.3`*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*
M;7-G<W1R(").971F86YG86+S:R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M,3$*;7-G:60@(F%N(&5R<F]R(&AA<R!O8V-U<F5D.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@X,@IM<V=I9"`B8V%L96YD
M87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S`@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HU.#8*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C0T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z-34P('!O
M+W1R86YS;&%T:6]N+G!H<#HV,3$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<T
M.2!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$P('!O+W1R86YS;&%T:6]N+G!H<#HX
M.#<*;7-G:60@(F1O;F4B"FUS9W-T<B`B;&]K:?`B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-34R('!O+W1R86YS;&%T:6]N+G!H<#HU.#0@<&\O=')A;G-L
M871I;VXN<&AP.C8Q,PHC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S<X('!O+W1R
M86YS;&%T:6]N+G!H<#HX,3(@<&\O=')A;G-L871I;VXN<&AP.C@Y,`IM<V=I
M9"`B9F%I;&5D(@IM<V=S='(@(FML:6MK8?!I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(F9A;&QI;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#0Y
M"FUS9VED(")F:6QE(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,CD*;7-G:60@(F9O=6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C(*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F+G!H
M<#HW-@HC+"!F=7IZ>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(F5N9VEN;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C(X-R!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`U"B,L(&9U>GIY
M"FUS9VED(")N86UE(@IM<V=S='(@(DYA9FXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,S<X"FUS9VED(")N;W0@8VAA;F=E9"(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3,Q"FUS9VED(")N;W0@9F]U;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0HC+"!F=7IZ>0IM
M<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(D5K:VD@97ET="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0HC+"!F=7IZ
M>0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")%:VMI(&5Y
M='0B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@W-`HC+"!F=7IZ
M>0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("+3;&5S:?`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED
M(")P97)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.0HC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D'P=O9R=6XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDX"FUS9VED(")S:&]W(&1I
M9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$S"FUS9VED(")S;7,R96UA:6P@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@Y.`HC+"!F=7IZ>0IM<V=I9"`B
M=&%S:R!L:7-T(@IM<V=S='(@(E-V87)T;&ES=&DB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-S(U"B,L('!H<"UF;W)M870*;7-G:60@(G1H92!(;W)D92!0
M3R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T.B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T
M=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<V"FUS9VED(")U;FEF
M:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP
M:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(G5N;F%M960B"FUS9W-T<B`BTVYE9FYT
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,W-0IM<V=I9"`B=7!D871E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V-`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(F5N9VEN(')E9VQA('9A;&EN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(T"B,L(&9U>GIY"FUS9VED(")W.B(*;7-G<W1R("+!9G)A;7,N.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T
M:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P;R]S;%]322YP;P``````````````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C4T-#4V`#$P-3$U-#,Q,#8S
M`#`Q-C0R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C(%-L;W9E;FEA;B!T<F%N<VQA=&EO;G,@9F]R($AO<F1E('!A8VMA
M9V$*(R!3;&]V96YS:VD@<')E=F]D($AO<F1E('!A:V5T80HC($-O<'ER:6=H
M="`H0RD@,C`P-B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(&AO<F1E('!A
M8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P,#8N"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ("Y<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P-BTP-RTR-2`Q,3HS,"LP,C`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`V+3`T+3,P(#$P.C,R*S`Q,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@9'5C:T!O8F%L82YN971<;B(*(DQA;F=U86=E+51E
M86TZ('-L7U-)(#QD=6-K0&]B86QA+FYE=#Y<;B(*(DU)344M5F5R<VEO;CH@
M,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]=71F
M+3A<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AP<F5D("5S(&1N979I
M*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A$;W-T
M;W!N82!T:7!K82`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C8U"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T
M<B`B("AV("5S(&1N96@I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8V,0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B*&1A;F5S*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*;7-G:60@(B`H=&]M;W)R;W<I
M(@IM<V=S='(@(DIU=')I("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V-3D*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(H=L2-97)A:BDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-3,*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Y.0IM<V=I9"`B(&%T("(*;7-G<W1R("(@;V(@(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E
M<UPB(&YI(&EM96YI:R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H
M;VEC92XB"FUS9W-T<B`B7"(E<UPB(&IE(&YE=F5L:F%V;F$@:7IB:7)A(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&5M86EL(&%D
M9')E<W,N(@IM<V=S='(@(DYI<W1E('9S=&%V:6QI('9E;&IA=FYE9V$@96QE
M:W1R;VYS:V5G82!N87-L;W9A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-S`P"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z,3`V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G
M<W1R(")<(B5S7"(@;F4@>F%Z;F%M('8@2&]R9&]V96T@<F5G:7-T<G4@(@H*
M(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`B)R5S)R!N92!N86ID96T@9')E=F5S82!Z82!I>G)I<RXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@
M:F4@8FEL(&1O9&%N('-K=7!I;G-K96UU('-I<W1E;74B"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G
M<W1R("(G)7,G(&IE(&)I;"!D;V1A;B!K(&1O<'5S=&YE;74@<VES=&5M=2XB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4S(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C
M<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)R!N:2!U<W1V87)J96XZ("5S("(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*
M;7-G<W1R(")5<&]R86)L:F5N:6@@)2XR9DU"(&]D("4N,F9-0B!D;W9O;&IE
M;FEH("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T
M<B`B)60@)7,@:6X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C(V-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3DT"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S
M+B(*;7-G<W1R("+%H&4@)60@9&YI(&1O('!O=&5K82!G97-L82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D+61N979N82!N87!O
M=F5D(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S(.*`DR!";V1I
M=&4@<&]Z;W)N:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM
M<V=S='(@(B5S($]D=&ES(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,W(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+
M0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-2!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S($U"(@IM<V=S='(@(B5S($M"(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B)7,@5GID<L6^979A;&YA(&1E;&$@+2!0;W1R9&ET978B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T
M<B`B)7,@("`@("`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T
M<B`B)7,@<')I:F%V82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B)7,@4&]G;VII(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-#,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3D*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3@@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW-C`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z-S`P
M(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C<V-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@Q;YE(&]B
M<W1A:F$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S$@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S<@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-3<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@
M;V(@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C
M:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!J92!P<FEP
M<F%V;&IE;B!N82!I>G9A:F%N:F4@=GID<L6^979A;&YI:"!O<&5R86-I:BP@
M<')E=F5R:2!S<&]D86HN4')E=F5R:2`B"B)N86)I<F%L;FEK('IA('9S92!O
M<&5R86-I:F4L(&MI(&)I(&II:"!R860@;W!R879I;"!S961A:BXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C(X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(E!O=')E8G5J96T@)7,@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU="(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N92!N86ID96TB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S(&]B("5S
M(&]D("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M26UE;FEK("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+
M;VQE9&%R("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(D)E
M;&7%OFMA("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E
M<R!/<')A=FEL82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M
M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@
M;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A
M;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!T;R!S
M<&]R;\2-:6QO(&UO9V_$C64@;FD@;V0@<&_%H6EL:F%T96QJ82P@:V%T97)I
M('!R879I(&1A(&IE+B!087II=&4@<V4@(@HB:V%T97)I:&MO;&D@<&]V97IA
M=B!V('-P;W)OQ(UI;'4@86QI('!O9&%J86YJ=2!K871E<FEH(&MO;&D@;W-E
M8FYI:"`B"B)I;F9O<FUA8VEJ(&YA('1A(&YA<VQO=BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4W(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#(*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!G;W-T
M:6T@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S
M("5S(@IM<V=S='(@(BP@9V]S=&EM("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(BP@<W!R96UE;FQJ:79K82!O9"`E<R!D
M;R`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S4P
M"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@:7IB97)I("TM(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(U"FUS9VED("(Q,B!(;W5R($9O<FUA
M="(*;7-G<W1R("(Q,B!U<B!F;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,C0*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T('5R(&9O
M<FUA="(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R
M-"!H;W5R<R(*;7-G<W1R("(R-"!U<B(*"B,Z(&9R86UE=V]R:R]522]522]0
M86=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R(")0<F5JQ:%N
M:F$@;6_%OFYO<W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,0IM<V=I
M9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L
M;V-K+B(*;7-G<W1R("):82!T82!B;&]K(&IE('!O=')E8FYA('!O=F5Z879A
M(&YA('!O9&%T:V]V;FD@<W1R9<6^;FEK(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S$*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D(@IM<V=S='(@(E!O:F%V:6QA('-E(&IE(&AU9&$@;F%P86MA+B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D$@;65S<V%G92!H87,@8F5E;B!S96YT('1O(%PB
M)7-<(B!T;R!V97)I9GD@=&AA="!T:&ES(&ES(')E86QL>2!Y;W5R("(*(F%D
M9')E<W,N(%1H92!N97<@96UA:6P@861D<F5S<R!I<R!A8W1I=F%T960@87,@
M<V]O;B!A<R!Y;W4@8V]N9FER;2!T:&ES("(*(FUE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I
M9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B6F$@:V]D:7)A=&D@<W!O<F_$C6EL;R!P;W1R
M96)U:F5M(&IA=FYI(%!'4"!K;&IUQ(TN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`B2F%V;FD@4$=0(&ML:G7$C2!J92!P;W1R96)E;B!Z82!O9&ML97!A;FIE
M('-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DIA=FYI(%!'4"!K;&IUQ(TL
M('IA<V5B;FD@4$=0(&ML:G7$C2!I;B!G97-L;R!S;R!P;W1R96)N:2!Z82!O
M9&ML97!A;FIE("(*(G-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DIA=FYI(%!'
M4"!K;&IUQ(TL('IA<V5B;FD@4$=0(&ML:G7$C2!I;B!G97-L;R!S;R!P;W1R
M96)N:2!Z82!P;V1P:7,@<W!O<F_$C6EL82XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(DIA=FYI(%,O34E-12!K;&IUQ(TL('IA<V5B;FD@4R]-24U%(&ML:G7$
MC2!I;B!G97-L;R!S;R!P;W1R96)N:2!Z82!P;V1P:7,@(@HB<W!O<F_$C6EL
M82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*(DIA=FYI(%,O34E-12!K;&IUQ(TL('IA
M<V5B;FD@4R]-24U%(&ML:G7$C2!I;B!G97-L;R!S;R!P;W1R96)N:2!Z82!P
M;V1P:7,@(@HB<W!O<F_$C6EL82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(@2F%V
M;FD@4TU)344@:VQJ=64@:F4@<&]T<F5B96X@>F$@;V1K;&5P86YJ92!S<&]R
M;\2-:6QA("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")/8FQAQ(UN;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED
M(")!32!,:6=H="!286EN(@IM<V=S='(@(DIU=')A;FII(%)A:&5L(&1EQ;XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R(")*=71R86YJ:2!D9<6^(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-
M(%-H;W=E<G,B"FUS9W-T<B`B2G5T<F%N:FD@;F%L:78B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(DIU=')A;FII('-N9<6^;FD@;65T9<6^(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM
M<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)
M($E$(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B
M;W5T+BXN(@IM<V=S='(@(D]P:7,N+BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C@R"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E!R97!O=F5D86X@9&]S=&]P('IA
M('5S='9A<FIA;FIE(&UA<&4@5D93+B`B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+B(*;7-G<W1R(")0<F5P;W9E9&%N(&1O<W1O<"!Z82!U<W1V
M87)J86YJ92!D871O=&5K92!61E,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B5F'%
MH6D@<&]D871K:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I
M9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")0;W1R9&D@9V5S;&\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("))>G9A:F%M(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0IM<V=I9"`B06-C;W5N
M=&EN9R(*;7-G<W1R("))>G9A:F%M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED
M(")!9&0B"FUS9W-T<B`B1&]D86HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R
M,B!A9&UI;B]G<F]U<',N<&AP.C(R,PIM<V=I9"`B061D($-H:6QD($=R;W5P
M(@IM<V=S='(@(D1O9&%J('-K=7!I;F\@;W1R;VLB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@
M(D1O9&%J(&1O=F]L:F5N:F$@;W1R;VMA(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HW,`IM<V=I9"`B061D($-O;G1E;G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E
M.B(*;7-G<W1R(")$961A:B!S96TZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,38@861M:6XO9W)O=7!S+G!H<#HR,3<*;7-G:60@(D%D9"!.97<@1W)O=7`B
M"FUS9W-T<B`B1&]D86H@;F]V;R!S:W5P:6YO(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B1&]D
M86H@;F]V82!D;W9O;&IE;FIA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B1&]D86H@<VMU<&EN;R!O
M=')O:R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O(%PB)7-<(B(*;7-G<W1R(")$;V1A:B!D;W9O;&IE;FIE(&]T<F]K
M82!<(B5S7"(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR.0IM<V=I9"`B061D(&$@
M;F5W('5S97(Z(@IM<V=S='(@(D1O9&%J(&YO=F5G82!U<&]R86)N:6MA.B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3@*
M;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B1&]D86H@<W1O;'!E8R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D
M9"!N97<@;65M8F5R<R(*;7-G<W1R(")$;V1A:B!N;W9E(,2-;&%N92(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER
M(@IM<V=S='(@(D1O9&%J('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S
M(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(D1O9&%J("5S($UE;G4@=B!-
M;WII;&QA(%-I9&5B87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM
M<V=S='(@(D1O9&%J('8@:6UE;FEK.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E
M<W,@8F]O:R(*;7-G<W1R(")$;V1A:B!V(&UO:B!I;65N:6LZ(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D1O9&%J
M('5P;W)A8FYI:V$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("(*(B5S+B(*;7-G<W1R("(B"B(@1&]D86P@)R5S)R!S:7-T96UU+"!V96YD
M87(@8F\@;F5M;V=OQ(UE(&1O9&%J86YJ92!D;V1A=&YI:"!V<&ES;FEH("(*
M(FEN9F]R;6%C:6HZ("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B1&]D86X@)R5S)R!S:7-T96UU+B!3
M961A:B!S92!L86AK;R!P<FEJ879I=&4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B1&]D86IA;FIE('5P;W)A8FYI:V]V(&IE(&]N96UO
M9V_$C65N;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30U-`IM<V=I9"`B
M061D<F5S<R(*;7-G<W1R(").87-L;W8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,30X"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B26UE
M;FEK(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-38*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*
M;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S(@IM<V=S='(@(E5R961I(&1O=F]L:F5N:F$@>F$@;W-T86QE('5P
M;W)A8FYI:V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$W
M"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")5<')A=FQJ86YJ92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(D%D<R(*
M;7-G<W1R(")296ML86UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T
M86XB"FUS9W-T<B`B069H86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L
M8F%N:6$B"FUS9W-T<B`B06QB86YI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!
M;&=E<FEA(@IM<V=S='(@(D%LQ;YI<FEJ82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S
M='(@(D]Z:7)O;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G
M:60@(D%L;"(*;7-G<W1R(")6<V4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS
M9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")6<VD@;W9E
M<FIE;FD@=7!O<F%B;FEK:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S(@861M
M:6XO9W)O=7!S+G!H<#HR,C`*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B
M5G-E('-K=7!I;F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G
M:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")6<V$@1&]V;VQJ96YJ82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#D*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")$;W9O;&D@;6YO9V]K<F%T
M;F4@;F%S;&]V92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C@*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(D1O=F]L:2!N87-T879I='9E("`B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HU,3@*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(L."Q;UE(&]B<W1A:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R
M(").861O;65S=&YO($E-4U`@=7!O<F%B;FG%H6MO(&EM92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,#(*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A
M<W-W;W)D(@IM<V=S='(@(DYA9&]M97-T;F\@24U34"!G97-L;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%5S97)N86UE(@IM<V=S='(@(DYA9&]M97-T;F\@24U34"!U<&]R86)N:<6A
M:V\@:6UE(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G
M:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(DYA9&]M97-T
M;FD@96QE:W1R;VYS:VD@;F%S;&]V(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#$*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B3F%D
M;VUE<W1N:2!V>F]R8VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!3
M86UO82(*;7-G<W1R("(@06UE<FG%H6MA(%-A;6]A("(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"XB"FUS9W-T<B`B3F%V961E;F$@:F4@8FEL82!N97IA:V]N:71A('9R
M961N;W-T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@
M(G!O:F%V:6QA('-E(&IE(&YA<&%K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N
M9&]R<F$B"FUS9W-T<B`B06YD;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG
M;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I
M;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@
M(D%N;VYI;65N(%!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")/9&=O=F]R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT:6-A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R
M(")!;G1I9W5A(&EN($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C<S(&%D;6EN+W!H<'-H96QL+G!H<#HS-`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C0*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P;&EK86-I:F$B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`B4V5Z;F%M(&%P;&EK86-I:B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E
M861Y+B(*;7-G<W1R(")!<&QI:V%C:6IA(&IE('!R:7!R879L:F5N82(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T
M;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B4')I:F%V:2!O=')O:V]V92!D96QN
M:6-E("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q
M"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(E!O=')D:2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")!<')I;"(*
M;7-G<W1R(")!<')I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS
M9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A8G-K:2`H
M5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X
M"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")696QI:V]S="!D
M871O=&5K92!!<FAI=B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DEM92!!<FAI=F$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(E-T
M92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!P<F5K;&EC871I('IA:'1E=F\@
M>F$@<')I:F%V;R!Z82`E<R`_("(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R
M;W5P<S\B"FUS9W-T<B`B4W1E('!R97!R:<2-86YI+"!D82#%OF5L:71E(&EZ
M8G)I<V%T:2`G)7,G(&EN(&]S=&%L92!P;V1S:W5P:6YE/R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;65N:6IA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU3
M0TE)+3@I(@IM<V=S='(@(D%R;65N<VMI("A!4DU30TE)+3@I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")!<G0B"FUS9W-T<B`B56UE
M=&YO<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S
M8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B56UE=&YO<W1I
M(,2-<FLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07II82]086-I9FG%
MH6ME(')E9VEJ92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G
M:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")6<')AQ:%A:B!Z82!P;W1R9&ET
M978@<')E9"!I>G9A:F%N:F5M('9Z9'+%OF5V86YJ82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S.#(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R(")$;V1E;&IE;F4@:V]L;VYE(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,PIM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N(@IM<V=S='(@(E!O<VMU<R!I>F)R:7-A(&YE;V)S=&]J9<2-
M92!S:W5P:6YE+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,C@*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(E!O<VMU<R!I>F)R:7-A(&YE;V)S=&]J9<2-96=A(&1O
M=F]L:F5N:F$N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#8*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")0;W-K=7,@=7)E9&ET=F4@;F5O8G-T;VIEQ(UE9V$@9&]V;VQJ
M96YJ82XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3@*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`B4&]S:W5S('5R961I='9E(&YE;V)S=&]J9<2-92!D96QN:6-E+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(DQA<W1N;W-T:2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B079G
M=7-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%V
M<W1R86QI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@
M(D%V<W1R:6IA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C,Q-@IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B($%U=&A?8WER=7,Z(%IA:'1E=F%N
M;R!I;6%P(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ,S$*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B075T:%]C>7)U<SH@0F%C:V5N9"!N:6UA('IA:'1E=F%N:6@@>FUO
MQ;YN;W-T:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR
M,S0*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@6F%H=&5V86YO(&EM
M87`@Q:%I<FET978@;FES96T@;F'%H65L+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O9G1P+G!H<#HU-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T
M<#H@6F%H=&5V86YO($944"#%H6ER:71E=B!N:7-E;2!N8<6A96PN($EZ<&]L
M;FD@4$A0('H@+6]N96UO9V_$C65N;RT@9G1P("(*(GIA;65N:F%V;RX@(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#0*;7-G:60@(D%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VEM87!H=&5V86YO($E-05!I=&5V(&YI<V5M(&YAQ:%E
M;"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<S"FUS9VED
M(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]K<F(U.B!:86AT979A;F\@:W)B-2#%H6ER:71E
M=B!N:7-E;2!N8<6A96PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,#$*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T
M:%]L9&%P.B!.:2!M;\6^;F\@9&]D86IA;FIE('5P;W)A8FYI:V]V('8@06-T
M:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S4V"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T
M:%]L9&%P.B!.:2!M;\6^;F\@;V1S=')A;FIE=F%N:F4@=7!O<F%B;FEK;W8@
M=B!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HY,@IM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@6F%H=&5V
M86YO($Q$05`@Q:%I<FET978@;FES96T@;F'%H65L+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!.92!M
M;W)E;2!D;V1A=&D@=7!O<F%B;FEK82`E<RX@4W!O<F_$C6EL;R!S=')EQ;YN
M:6MA.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YE(&UO<F5M(&]D<W1R
M86YI=&D@=7!O<F%B;FEK82`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-#DX"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@
M3F4@;6]R96T@;F%D9W)A9&ET:2!U<&]R86)N:6MA("5S("(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`T"FUS9VED(")!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN(@IM<V=S='(@(D%U=&A?;&1A<#H@;F4@;6]R96T@;F%D9W)A
M:F5V871I('5P;W)A8FYI:V]V('8@06-T:79E($1I<F5S=&]R>2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C8R"FUS9VED(")!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]M8V%L.B!:86AT979A;F\@34-!3"#%H6ER:71E=B!N:7-E;2!N
M8<6A96PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@V"FUS
M9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!:86AT979A;F5G
M82!S;6)A=71H('IA(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3W9E<FIA
M;FIE('IA($944"!S=')EQ;YN:6L@;FD@=7-P96QO+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D]V97)J86YJ92!N:2!U
M<W!E;&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")/=F5R:F%N:F4@;FD@=7-P96QO
M+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ.#(*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N(@IM<V=S='(@(D]V97)J86YJ92!J92!Z879R;FEL(%)!1$E54R!S=')E
MQ;YN:6LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S,*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")/=F5R:F%N:F4@>F$@1E10('-T<F7%OFYI:R!N:2!U<W!E;&\N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z.#@Y"B,L(&9U>GIY"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!34T@R('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(D]V97)J86YJ92!Z82!&5%`@<W1R9<6^;FEK(&YI('5S<&5L;RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H
M96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D]V97)J86YJ92!Z82!334(@<W1R9<6^;FEK(&YI('5S<&5L;RXB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@
M9FEE;&1S.B(*;7-G<W1R(")0;VQJ82!N82!R87IP;VQA9V\Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%J9,6^86X@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B3F5U;6YI(&EZ9V]V;W)I(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,@IM<V=I9"`B0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+B(*;7-G<W1R(").87!AQ(UN;R!K97)B97)O<R!G97-L;RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@T"FUS9VED(")"860@
M:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(DYA<&'$C6YO(&ME<F)E<F]S
M('5P;W)A8FYIQ:%K;R!I;64N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA
M<R(*;7-G<W1R(")"86AA;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN
M(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&EK
M("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H
M(@IM<V=S='(@(D)A;F=L861EQ:$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B
M861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").:7-E;2!N8<6A
M96P@;W-N;W9N96=A(&=R869IQ(UN96=A(&EM96YI:V$@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B0F5L;W)U<VEJ82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEJ82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D<VMI(&]T;VMI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)U=&%N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM
M<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B4F]J<W1N:2!D86XB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").:7-E;2!N8<6A96P@8FQO:V$@7"(E
M<UPB+"!A<&QI:V%C:6IE(%PB)7-<(B`N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R
M("):875S=&%V:2!.87-T879I='9E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C<R"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(EIA=7-T
M879I(%1I<"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
M0F]L:79I:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS
M9VED(")";V]K;6%R:W,B"FUS9W-T<B`B4')I;&IU8FQJ96YE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")"
M;W-N82!I;B!(97)C96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HQ,#$*;7-G:60@(D)O=&@B"FUS9W-T<B`B3V)O:FDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";V-V86YA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V971O=F\@;W1O
MQ(UJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z
M:6QI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(B!"<FET86YS:V\@;WIE;6QJ92!);F1I
M:G-K96=A(&]C96%N82`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R
M=7-S86QA;2(*;7-G<W1R(")"<G5N96DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M=6QG87)I82(*;7-G<W1R(")";VQG87)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-PIM<V=I9"`B0TU3(@IM<V=S='(@
M(DU31R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO
M;B!0;VEN=',B"FUS9W-T<B`B($-23"!R87ID96QI='9E;F4@=&_$C6ME("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-38*;7-G:60@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DYA<W1A=FQJ
M86YJ92!P<F5D<&]M;FEL;FEK82!N:2!D;VMO;L2-86YO+B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$V(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#D*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P.3(@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$V-`IM<V=I9"`B0V%L
M96YD87(B"FUS9W-T<B`B2V]L961A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#`*;7-G:60@(D-A;&TB"FUS9W-T<B`B6F)R:<6A:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;V3%
MOF$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE
M<G5N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(Q"FUS9VED(")#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@
M(DYE(&UO<F5J;R!U<')A=FQJ871I('IU;F%N:FD@=7!R879L:F%L8VDB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR-#$@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C,S,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(").
M92!M;W)E;2!V>G!O<W1A=FET:2!P;W9E>F%V92!Z($E-05`@<W1R9<6^;FEK
M;VTZ("5S("(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(").:2!M;V=OQ(UE(&]D<')E=&D@7"(E<UPB(&1A=&]T96ME+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86YA9&$B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#`@861M:6XO=7-E<BYP:'`Z,3$Y('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,0HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(EIB<FG%H6DB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU,@IM<V=I9"`B
M0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(G!O<F_$C6EL;R!O('1E
MQ;YA=F%H('H@8G)I<V%N:F5M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,P-"!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R-PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV-S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z-C<Y(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,34*;7-G:60@(D-A;FYO
M="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T
M:&4@<V%M92XB"FUS9W-T<B`B3F4@;6]R96T@:V]P:7)A=&D@9&%T;W1E:R`H
M92D@+2!V:7(@:6X@8VEL:F$@<W1A(&ES=&$N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z
M,S$U"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!D871O=&5K92!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3F4@;F%J9&5M('IAQ(UA<VYE(&1A=&]T96LN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.#,@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C`W"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S,Y(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C<T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38Y"FUS9VED(")#86YN;W0@
M;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92XB
M"FUS9W-T<B`B3F4@;6]R96T@<')E;6%K;FET:2!D871O=&5K("AE*2`M(&-I
M;&H@:F4@>FYO=')A:B!V:7)A+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B3F4@;6]R
M96T@;F%D86QJ979A=&D@8G)E>B!P87)A;65T<F]V("=C:6QJ;F4@9&%T;W1E
M:V4G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$Y(&9R86UE
M=V]R:R]61E,O5D93+W-S:#(N<&AP.C,Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(EPB
M)7-<(B!);65N:6MA(&YE(&UO<F5M('IB<FES871I+B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C8Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B3F4@
M;6]R96T@;V1S=')A;FET:3L@;V)S=&%J82`E9"!P;V1V96QJ(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C(R"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@HB3F4@;6]R96T@<&]N;W9N;R!U<F5D:71I+"#%H71E=FEL
M;R!D86YI:"!V;F]S;W8@<V4@;F4@<VML861A(',@Q:%T979I;&]M("`B"B)S
M:')A;FIE;FEH+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86YN;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DYE(&UO<F5M
M(&%V=&]M871S:V\@<&]N87-T879I=&D@9V5S;&$L(&]B<FYI=&4@<V4@;F$@
M<VMR8FYI:V$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O
M('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DYE(&UO<F5M('!R975S;65R
M:71I('-P;W)OQ(UI;&$@;F%V961E;F5M=2#%H71E=FEL=2XB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(D-A;FYO
M="!W<FET92!T;R!F:6QE(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A
M<&4@5F5R9&4B"FUS9W-T<B`B2V%P=F5R9'-K:2!O=&]K:2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R(")0<FEN8<6A86QE8R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM
M<V=S='(@(DMA=&5G;W)I:F4@:6X@>FYA;6ME(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DMA>6UA;G-K:2!O=&]K:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*
M;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QN:2!T96QE9F]N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(X,PIM<V=I9"`B0V5L;'!H
M;VYE(@IM<V=S='(@(DUO8FEL;FD@=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G
M<W1R(")+96QT<VMI("A)4T\M.#@U.2TQ-"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED
M(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B0V5N=')A;&YO
M($%F<FG%H6MA(%)E<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G
M<W1R(")3<F5D;FIE979R;W!S:VD@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC
M871E($1E=&%I;',B"FUS9W-T<B`B4&]D<F]B;F]S=&D@<&]T<F1I;&$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B
M0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B3&%S=&YI:R!P;W1R9&EL82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")0<F%V:6QA('!O=')D
M:6QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(D5A9"(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")3
M<')E;65N:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B<W!R96UE;FET
M92!V8<6A92!G97-L;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(B(*(E-P<F5M96YI=&4@:6UE(&EN(&YA<VQO=B!V
M8<6A96=A(&5L96MT<F]N<VME9V$@;F%S;&]V82P@:VD@9V$@(@HB=FED:6IO
M<')E:F5M;FEK:2!O8B!B<F%N:G4@:6X@;V1G;W9A<FIA;FIU(&YA('9AQ:%O
M('!OQ:%T;RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*
M;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB5B!T<F5N=71N
M:2!K;VYF:6=U<F%C:6IE(&YE(&UO<F5T92!S<')E;65N:71I(&=E<VQA+B!+
M;VYT86MT:7)A:G1E('9AQ:%E9V$@(@HB<VMR8FYI:V$N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<F%C
M=&5R('1O('-P;&ET(&UU;'1I<&QE(&%D9')E<W-E<R!W:71H(@IM<V=S='(@
M(D1O=F]L:2!M;F]G;VMR871N92!N87-L;W9E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0VAI;&4B"FUS9W-T<B`BQ(UI;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M:&EN82(*;7-G<W1R(")+:71A:G-K82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS
M9W-T<B`B4&]E;F]S=&%V;&IE;F$@:VET86K%H<2-:6YA*$=",C,Q,BDB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B5')A9&EC:6]N86QN82!K:71A:L6A
MQ(UI;F$@*$)I9S4I(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM
M<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R("))>F)E<FD@87!L
M:6MA8VEJ;SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C<Q"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("))>F)E<FD@
M9V5S;&\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P
M"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("))>F)E<FD@=7!O
M<F%B;FG%H6MO(&EM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*
M;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B
M2V%K;R!P<FEK87IA=&D@9&%T=6UE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H
M<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B0F_%OFG$C6YI(&]T;VMI(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3FES96T@;F'%H65L(&1E
M9FEN:6-I:F4@=G)S=&4@>F$@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(DIA
M<VYO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B0VQE87(@
M475E<GDB"FUS9W-T<B`B4')EQ(UI<W1I('!O:7IV961B92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")/9'-T<F%N:2!Z=6YA
M;FIE9V$@=7!O<F%B;FEK83H@)7,@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D]D
M<W1R86YI('5P;W)A8FYI:V$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(DEZ
M8G)IQ:%I('!O9&%T96L@=7!O<F%B;FEK82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E
M(@IM<V=S='(@(FEZ8G)IQ:%I('!O=&5M(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O
M;G1I;G5E(@IM<V=S='(@(DML:6MN:2!Z82!N861A;&IE=F%N:F4@(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T
M"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E
M;&P@<')O=&]M($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R("):87!R:2!O:VYO(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-38*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")/8FQA:VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B
M0VQO=61S($5A<FQY(@IM<V=S='(@(EIJ=71R86H@3V)L8<2-;F\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B
M0VQO=61Y(@IM<V=S='(@(D]B;&'$C6YO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B2V]K;W-O=FD@;W1O
M:VDB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(T"FUS9VED
M(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(EID<G7%OFD@<W1R86YS:V\@
M;VMN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO
M;'5M8FEJ82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K
M+V-O;&]R+G!H<#HR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B0F%R=F$B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S0P"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-#$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P-R!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0
M:6-K97(B"FUS9W-T<B`B27IB:7)A;&5C(&)A<G8B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM
M<V=S='(@(B!)>F)I<F$@0F%R=F4@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(S-`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(").87-L
M;W8@<W1O;'!I8V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@P
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B4W1R:7!I(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(T"FUS9VED(")#;VUM86YD(@IM<V=S='(@(E5K87HB"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,3@*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B56MA>FYA(&QU<&EN82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUE
M;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W
M"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(")3:W5P;F\@:6UE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)I("(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G
M:60@(D-O;7!A;GDB"FUS9W-T<B`B1')UQ;YB82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(E)AQ(UU
M;F%L;FEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3`*
M;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(").87-T879I=&5V(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-C$*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T
M<B`B3F%S=&%V:71V92(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS
M9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(E)A>FQI
M:V4@;F%S=&%V:71V92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*
M;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3
M;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B3F%S=&%V:71V92!Z
M82!S:6YK<F]N:7IA8VEJ86\@9&QA;L2-;FEK;W8B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3,T"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+B(*;7-G<W1R(").87-T879I='9E('!O=')E8G5J96IO(&'%OG5R
M:7)A;FIE(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B3F%S=&%V:2`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3(*;7-G
M:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4&]T<F1I(&=E<VQO(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT,#<*(RP@9G5Z
M>GD*;7-G:60@(D-O;F9I<FT@;F5W(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B
M3F%D;VUE<W1N:2!E;&5K=')O;G-K:2!N87-L;W8B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T
M<B`B2V]N9V\L($1E;6]K<F%T:<2-;F$@<F5P=6)L:6MA(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960N(@IM<V=S='(@(E!O=F5Z879A(&YI('5S<&5L82XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(E!O=F5Z879A(&YI('5S
M<&5L83HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B6F%V<FYJ96YA('!O=F5Z879A('H@:F%V;FEM(&ML
M:G7$C6YI;2!S=')EQ;YN:6MO;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RDB"FUS9W-T<B`B6F%V<FYJ96YA('!O=F5Z879A('H@:F%V;FEM(&ML
M:G7$C6YI;2!S=')EQ;YN:6MO;2X@4F%Z;&]G.B`E<R`H)7,I(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C<*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E!O=F5Z879A(',@1E10
M('-T<F7%OFYI:V]M(&YI('5S<&5L82XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<V@R+G!H<#HX.#,*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@=&\@
M4U-(,B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")0;W9E>F%V82!S($944"!S
M=')EQ;YN:6MO;2!N:2!U<W!E;&$N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$Q,S<*;7-G:60@
M(D-O;G1A8W1S(@IM<V=S='(@(E-T:6MI(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B4W1I:R!J92!B:6P@=7-P9<6A;F\@9&]D86X@:R!V8<6A:6T@;F%S
M;&]V;VTN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@
M(@IM<V=S='(@(E1I<"!S=&EK82!S=&ES;FIE;F4@9&%T;W1E:V4Z(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(E9S96)I;F4@;V1<(B5S
M7"(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S
M='(@(DYA9&%L:G5J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S
M(@IM<V=S='(@(D-O;VMO=FD@;W1O:VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S<*;7-G:60@(D-O;VMI92(*;7-G<W1R(")0:<6A:V]T96LB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P:7)A;FIE(&YI
M('5S<&5L;SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("))1"!S=')OQ:%E:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B2V]S=&%R
M:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R
M("(@4VQO;F]K;\6AQ(UE;F$@;V)A;&$@(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G93H@(@IM<V=S='(@(E!'4"!N92!M;W)E(,6A:69R:7)A=&D@
M<W!O<F_$C6EL83HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM
M<V=S='(@(DYI(&UO9V]E(%!'4"!P;V1P:7,@<W!O<F]E:6QA+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3FD@;6]G
M;\2-92!3+TU)344@Q:%I9G)I<F%T:2!S<&]R;\2-:6QA+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B3FD@;6]G;\2-92!3
M+TU)344@<&]D<&ES('-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(").:2!M
M;V=OQ(UE(&1O9&%T:2!S=&EK;W8N("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#@R"FUS9VED(")#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B4&]V97IA
M=F$@>B!,1$%0('-T<F7%OFYI:V]M(&YI(&UO9V_$C6$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<R(*;7-G<W1R(").:2!M;V=OQ(UE(&MO;G1R;VQI<F%T:2`_/S\_/S\@)7,N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V-@IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E!O=F5Z879A
M('H@3$1!4"!S=')EQ;YN:6MO;2!N:2!M;V=OQ(UA+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS
M9W-T<B`B3F4@;6]R96T@=GIP;W-T879I=&D@<&]V97IA=F4@<R!S=')EQ;YN
M:6MO;2!<(B5S7"(@>B!U<&]R86)O($944#H@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(").92!M;W)E;2!U<W1V87)I=&D@<V5Z;F%M82!Z82!D
M:7-T<FEB=6-I:F\N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z
M("(*;7-G<W1R(").:2!M;V=OQ(UE(&1EQ:%I9G)I<F%T:2!01U`@<&]D871K
M;W8Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R
M(").:2!M;V=OQ(UE(&1EQ:%I9G)I<F%T:2!3+TU)344@<&]D871K92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!S=&EK;W8N("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES
M871I(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M82X@)7,B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B3F4@;6]R96T@:7IB<FES871I(&YA<W1A=FET=F5N92!AQ;YU<F%C
M:6IS:V4@<VMR:7!T92!<(B5S7"(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").:2!M;V=OQ(UE(&1O;&_$
MC6ET:2!E;&5K=')O;G-K96=A(&YA<VQO=F$@<')E:F5M;FEK82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B3FD@;6]G;\2-92!D;VQOQ(UI=&D@8V5L;W1N96=A(&EM96YI
M:V$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3FD@;6]G;\2-92!D;VQOQ(UI=&D@
M8V5L;W1N96=A(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M82XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3FD@;6]G;\2-92!D;VQOQ(UI=&D@
M8V5L;W1N96=A('-E>FYA;6$@9&ES=')I8G5C:6IS:VEH('-E>FYA;6]V(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM
M<V=S='(@(DYI(&UO9V_$C64@;F%L;\6^:71I('-T<F%T96=I:F4@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N
M<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<
M(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M('1V;W)I=&D@;6%P92!<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED
M(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+B(*;7-G<W1R(").:2!M;V=OQ(UE(&1O8FET:2!J879N96=A(&ML:G7$
MC6$@;V0@:VQJ=<2-;F5G82!S=')EQ;YN:6MA+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").:2!M;V=OQ(UE(&]D<')E
M=&D@7"(E<UPB('IA('!I<V%N:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").:2!M;V=OQ(UE(&]D
M<')E=&D@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3FD@;6]G
M;\2-92!O9'!R971I(&UO9'5L82!O(&]P<F%V:6QU7W9Z9'+%OF5V86YJ82`E
M<R`B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M3FD@;6]G;\2-92!P<F5B<F%T:2!I;65N:6L@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3FD@;6]G;\2-92!D;W-EQ(UI($Q$05`@<W1R
M9<6^;FEK82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS
M9W-T<B`B3FD@;6]G;\2-92!P<F5B<F%T:2`E<RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYI(&UOQ;YN;R!P;VYA
M<W1A=FET:2!G97-L82!Z82!Z86AT979A;F5G82!U<&]R86)N:6MA+B!.96MA
M=&5R92!A;&D@(@HB=G-E<&]D<F]B;F]S=&D@;FES;R!P<F%V:6QN92X@4&]S
M:W5S:71E('IN;W9A(&%L:2!K;VYT86MT:7)A:G1E("(*(G9AQ:%E9V%U<')A
M=FET96QJ82P@Q(UE('!O=')E8G5J971E(&YA9&%L:FYJ;R!P;VUOQ(TN(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").:2!U<W!E;&\@=GIP;W-T
M879I=&DZ("5S("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DYI('5S<&5L
M;R!V>G!O<W1A=FET:2!I;65N:6MA.B`E<R`B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DYI('5S<&5L;R!V>G!O<W1A=FET:2!D:7-T<FEB=6-I
M:G-K96=A('-E>FYA;6$Z("5S("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(DYI('5S<&5L;R!V>G!O<W1A=FET:2!D:7-T<FEB=6-I:G-K96=A
M('-E>FYA;6$Z("5S("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@
M8V%P86)I;&ET:65S(@IM<V=S='(@(DYI('5S<&5L;R!V>G!O<W1A=FET:3H@
M)7,@(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("):86AT979A
M;FD@)R5S)R!N:2!P;V1R;V)N;R!O8FQI:V]V86X@=B`E<R!P;V1O8FDN(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I
M<V%T:2!M87!E(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!K;VYF:6=U<F%C:6IE(&YI(&UO
M9V_$C64@<VAR86YI=&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DMO;F9I9W5R
M86-I:F4@=F%R;F]S=&YE(&MO<&EJ92!N:2!M;V=OQ(UE('-H<F%N:71I+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M(@IM<V=S='(@(DMO;F9I9W5R86-I:F4@=F%R;F]S=&YE(&MO<&EJ92!N:2!M
M;V=OQ(UE('-H<F%N:71I.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").92!M
M;W)E;2!S:')A;FET:2!N87-T879I='9E;F4@8<6^=7)A8VEJ<VME('-K<FEP
M=&4@;F$Z(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(").92!M;W)E;2!S
M:')A;FET:2!K;VYF:6=U<F%C:6IS:V\@9&%T;W1E:V\@)7,L('9A<FYO<W1N
M92!K;W!I:F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H
M92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B
M"B).92!M;W)E;2!S:')A;FET:2`@:V]N9FEG=7)A8VEJ<VME(&1A=&]T96ME
M("5S+B!,86AK;R!U<&]R86)I=&4@86QI(&5N;R!O9"`B"B)O<&-I:B!Z82!S
M:')A;FET:2!K;V1O('IA9&%J(&YA("5S(&%L:2!R;\2-;F\@:V]P:7)A=&4@
M<W!O9&YJ;R!K;V1O(&YA("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3FD@;6]G;\2-92!I<VMA;FIE($Q$05`@<W1R
M9<6^;FEK82XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYI
M(&UO9V_$C64@;V1S=')A;FET:2!P;W9E>F%V92!Z(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(DYI(&UO9V_$C64@8<6^=7)I<F%T:2!S=&EK+B`E<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").:2!M;V=OQ(UE(&'%OG5R
M:7)A=&D@9&ES=')I8G5C:6IS:VD@<V5Z;F%M+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M(").:2!M;V=OQ(UE(&YA<&ES871I(&MO;F9I9W5R86-I:F4@>F$@7"(E<UPB
M.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(DYE(&YA:F1E;2!-;WII;&QA
M(%-I9&5B87(N(%!R979E<FD@86QI(&IE(&]D<')T+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B7"(E<UPB('5P;W)A8FYI:W4@;F4@;6]R96T@9&]D96QI=&D@<VQE9&7$
MC6EH('!R879I8R!Z82!M87!O(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#,R"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T
M<B`B4')EQ:%T971O(&)E<V5D:6QO("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(D1R
MQ;YA=F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(E1EQ(UA:FDB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@
M(D-R96%T92(*;7-G<W1R(")5<W1V87)I(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-@IM<V=I9"`B0W)E871E(&$@;F5W(&]N
M92(*;7-G<W1R(")5<W1V87)I(&YO=F\B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S
M(@IM<V=S='(@(E5S='9A<FD@<&]D;6%P92(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(D%V=&]R(&1O=F]L:F5N:B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,T.3D*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G
M<W1R("+%H'1E=FEL:V$@:W)E9&ET;F4@:V%R=&EC92`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")(<G9AQ:%K82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")3
M961A;FIE(#0@<F%Z=F]J;F4@<W1O<&YJ92(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HT.`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")3961A
M;FIE('-E:F4B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO
M=&EM92YP:'`Z,S4*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")3961A
M;FII(,2-87,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U
M<G)E;G0@57-E<G,B"FUS9W-T<B`B4V5D86YJ:2!U<&]R86)N:6MI(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!796%T:&5R
M(@IM<V=S='(@(E-E9&%N:F4@=G)E;64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM
M<V=S='(@(E-E9&%N:F4@<W1A;FIE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(").87-T879I=&4@
M86MT:79N;W-T:2P@:VD@<V4@8F]D;R!I>G9RQ:%I;&4@;V(@<')I:F%V:2!N
M82`E<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B0VEP
M97(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL
M:6,@*$M/23@M4BDB"FUS9W-T<B`B0VER:6QI8V$H2T])."U2*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*2(*;7-G<W1R(")#:7)I;&EC82`H5VEN9&]W<RTQ,C4Q*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0VER:6QI8V$O56MR86II;G-K:2`H
M2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM
M<V=S='(@(L2-9<6A:V$@<F5P=6)L:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS-34Y"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I(@IM<V=S='(@(B(*(D1.4R`H<&]G;&5J(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$;F5V;F\B"@HC.B!A
M9&UI;B]D871A=')E92YP:'`Z-C,*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B
M"FUS9W-T<B`B4')E9VQE9&]V86QN:6L@9')E=F5S;F4@<W1R=6MT=7)E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S4U-PIM<V=I9"`B1&%T86)A
M<V4@3&]O:W5P(@IM<V=S='(@(E!O:7IV961B82!B87IE('!O9&%T:V]V(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C@V"FUS9VED(")$871E(@IM<V=S
M='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T=6T@<')E
M:F5M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P-S<*;7-G:60@
M(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(DEZ8FER82!D871U;6$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,30*;7-G:60@(D1A>2(*;7-G<W1R(")$86XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$W"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW.`IM<V=I
M9"`B1&5C96UB97(B"FUS9W-T<B`B1&5C96UB97(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I
M9"`B1&5F875L="(*;7-G<W1R(")0<FEV>F5T;R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT
M($-O;&]R(@IM<V=S='(@(E!R:79Z971A($)A<G9A(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N
M=&ET>2(*;7-G<W1R(")0<FEV>F5T82!I9&5N=&ET971A(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<U"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S
M='(@(E!R:79Z971A(&QU<&EN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.`IM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B3W!R961E;&ET=F4B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<P(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B6F)R:<6A:2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DW(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")$96QE=&4@
M1W)O=7`B"FUS9W-T<B`B6F)R:<6A:2!S:W5P:6YO(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S
M='(@(EIB<FG%H6D@9&YE=FYI:R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*
M;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(EIB<FG%H6D@9&]V
M;VQJ96YJ92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(DEZ8G)IQ:%I(&EN('!R9<2-:7-T:2!S<&]R;\2-:6QA(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#<*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B27IB<FG%H6D@;V)S=&]J9<2-
M:2!A;'1E<FYA=&EV;FD@=GIO<F5C(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*
M;7-G<W1R("))>F)R:<6A:2!S<&]R;\2-:6QA(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B27IB<FG%H6D@
M9&]V;VQJ96YJ82!Z82!<(B5S7"(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B
M"FUS9W-T<B`B27IB<FG%H65M(&1O=F]L:F5N:F4@>F$@7"(E<UPB(&EN('9S
M82!P;V1D;W9O;&IE;FIA/R(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I
M9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R("))>F)R:<6A:2!I>F)R86YO(&ED96YT:71E=&\B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B
M1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(DEZ8G)IQ:%I('!O9"!M87!E
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!N87-T879I='9E;F4@8<6^
M=7)A8VEJ<VME('-K<FEP=&4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G
M:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BQ(QA<R!D;W-T879E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$86YS:V$B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR-PIM<V=I9"`B1&5S8W)I
M8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B3W!IQ:%I=&4@=&7%OF%V;R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDT-PIM<V=I9"`B1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B3W!I<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,C`V"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL
M92DZ(@IM<V=S='(@(E!O9')O8FYO<W1I("AT=61I('8@2&]R9&]V:2!L;V<@
M9&%T;W1E:VDI.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C$P
M"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R(")0;V1R;V)N;W-T:2!S;R!B:6QE('!R:6IA
M=FQJ96YE('IA('5P<F%V;&IA;&-A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,S4*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(E)A>G9O
M:B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Y"FUS9VED(")$97<@4&]I
M;G0B"FUS9W-T<B`B4F]S:<6AQ(UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,#8*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B4F]S:<6AQ(UE('IA('!R96K%H6YJ;R!U<F\Z(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(R,0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS
M9W-T<B`B4F]S:<6AQ(UE.B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y
M"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B26UE;FEK(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I
M;65S/R(*;7-G<W1R(")0<FEK8<6^96T@Q(UA<R!P;R`R-"!U<FYE;2!S:7-T
M96UU/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R(").87-T879I='9E('!R:6MA>F]V86YJ
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-`IM<V=I9"`B
M1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")0<FEK8<6^:2!P
M;V1R;V)N;R!N87!O=F5D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY-PIM
M<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<FEK8<6^
M:2!N87!O=F5D("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S`X-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B4')I:V'%OFD@
M=F5L:6MO<W0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ
M"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B3V)V
M97-T:6QO(&\@9&]S=&%V;&IE;FD@<&_%H71I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&II8F]U=&DB"FUS9W-T<B`B1,6^:6)U=&DB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*
M;7-G<W1R(").92!Z8G)IQ:%I(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R(").92!D;W-T;W!A:B!N97!O<W)E9&YO(&1O(&]H
M<F%N:F%N:F$N<&AP("(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(D%L:2!P<G9A('9R<W1A('9S
M96)U:F4@:6UE;F$@<&]L:C\@Q(UE(&II:"P@<')E=F5R:2!N86)I<F%L;FEK
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN
M:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(D1O;6EN:6MA;G-K82!297!U8FQI:V$B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C@X"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N(@IM<V=S='(@(DYI<W1E(')E9VES=')I<F%N:3\@4F5G
M:7-T<FER86IT92!S92X@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S
M(@IM<V=S='(@(E!R96YE<VD@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38Q"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")0<F5N97-I=&4@9V5N97)I<F%N
M;R!K;VYF:6=U<F%C:6IO(&MO="!02%`@<VMR:7!T;RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,SDU"FUS9VED(")$<F]P(&1O=VX@;&ES="(*
M;7-G<W1R(")0861A:F_$C6D@;65N:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.0IM<V=I9"`B1')U9W,B"FUS9W-T<B`B6F1R879I;&$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(D1Y;F%M:6,@36%I
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%;&5K=')O;G-K:2!N87-L
M;W8B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@
M8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@
M(E!R96YO<R!E;&5K=')O;G-K:6@@<W!O<F_$C6EL('8@4TU3+6IE('IA(&]P
M97)A=&5R:F4L(&MI('1O(&]M;V=OQ(UA:F\N(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5C=6%D;W(B"FUS9W-T<B`B16MV861O<B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")5<F5D:2(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB
M"FUS9W-T<B`B57)E9&D@<W1O;'!E8R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DV(&%D;6EN+V=R;W5P<RYP:'`Z,C(T"FUS9VED(")%9&ET($=R;W5P(@IM
M<V=S='(@(E5R961I('-K=7!I;F\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B57)E9&D@9&]V;VQJ
M96YJ92(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR-#(*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B57)E9&D@9&]V;VQJ96YJ82(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B57)E
M9&D@9&]V;VQJ96YJ82!Z82`E<R`B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")5<F5D
M:2!M;\6^;F]S=&D@>F$Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5R961I(&1O=F]L:F5N:F$@>F$@7"(E
M<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M(")5<F5D:2!D;W9O;&IE;FIA('IA("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0P"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B27IO8G)AQ;YE
M=F%N:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9VEP
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B
M4V%L=F%D;W(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#<*;7-G:60@
M(D5M86EL(@IM<V=S='(@(D5L96MT<F]N<VMA('!OQ:%T82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHV.0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%
M;&5K=')O;G-K:2!N87-L;W8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C4Q"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS
M9W-T<B`B16QE:W1R;VYS:VD@;F%S;&]V('-E(&UO<F$@=6IE;6%T:2XB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0U,`HC+"!F=7IZ
M>0IM<V=I9"`B16UA:6P@861D<F5S<V5S('1O(&-O;F9I<FT@;F]T(&9O=6YD
M+B(*;7-G<W1R(")%;&5K=')O;G-K:2!N87-L;W8@<V4@;6]R82!U:F5M871I
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-S<*;7-G:60@(D5M
M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D5L96MT<F]N<VMA('!O
MQ:%T82!S('!O=')D:71V:6IO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E
M=V%Y(@IM<V=S='(@(D5M86EL+5--4R!0<F5H;V0B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S`S"FUS9VED(")%;6]T:6-O
M;G,B"FUS9W-T<B`B4VUEQ:%K:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G
M92XB"FUS9W-T<B`B4')A>F5N;R!S<&]R;\2-:6QO+B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M
M<'1Y(')E<W5L="XB"FUS9W-T<B`B4')A>F5N(')E>G5L=&%T+B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y
M('-E87)C:"!T97)M<R(*;7-G<W1R(")0<F%Z96X@:7-K86QN:6LB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30U"FUS9VED(")%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*
M;7-G<W1R("))>FML;W!I;2!V<W1A=FQJ86YJ92!S;&EK(&EZ($9O=&\@1V%L
M97)I:F4@=B!T96MS=#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$R
M"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G
M<W1R("))>FML;W!I;2!M96YI('H@9&5S;FEM(&ML:6MO;3\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#<V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,P.#$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(DMO;F5C(&QE=&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E
M<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D
M(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB
M5FYE<VET92!V87)N;W-T;F\@=G!R8<6A86YJ92P@:VD@8F\@<&]S=&%V;&IE
M;F\L(,2-92!B;W-T92`B"B)P;W1R96)O=F%L:7!O;F%S=&%V:71I('9AQ:%E
M(&=E<VQO+"!N<'(N(,."XH">:6UE('9AQ:%E9V$@;&IU8FQJ96[$C6MA(&IE
M/SHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M5FYE<VET92!S<&]D;FIE(,2-<FME.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q
M=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W)I86QN82!'=FEN96IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5J
M82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-3,*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HT,0IM<V=I9"`B17)R;W(B
M"FUS9W-T<B`B3F%P86MA(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L
M871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I
M;F<@8FQO8VLZ("5S(@IM<V=S='(@(DYA<&%K82!P<FD@=7-T=F%R:F%N:G4@
M<W1O;'!A.B`E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,B"FUS9W-T<B`B3F%P86MA('!R:2!B<FES86YJ=2!P;W9E>F%V
M92!S:6YH<F]N(&EZ86-I:F4Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(DYA<&%K82!P<FD@8G)I<V%N:G4@
M9&YE=FYI:V$@<VEN:')O;FEZ86-I:F4Z("5S+B(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B3F%P86MA('!R
M:2!P;W9E>F]V86YJ=3H@)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R(").87!A:V$@<')I(&'%OG5R:7)A;FIU
M(&=E<VQA.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92XB"FUS9W-T<B`B3F%P86MA('H@96QE:W1R;VYS:VEM('-P;W)OQ(UI
M;&]M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(DYA<&%K82!P
M<FD@<&ES86YJ=2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI
M82(*;7-G<W1R(")%<W1O;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO
M<&EA(@IM<V=S='(@(D5T:6]P:6IA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0Q"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B17-T;VYI:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R(")%=G)O<&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3`Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y
M(#$U(&UI;G5T97,B"FUS9W-T<B`B5G-A:VEH(#$U(&UI;G5T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S
M(@IM<V=S='(@(E9S86MI(#(@;6EN=71I(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDX(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C
M;VYD<R(*;7-G<W1R(")6<V%K:6@@,S`@<V5K=6YD(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$P,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y
M(#4@;6EN=71E<R(*;7-G<W1R(")6<V%K:6@@-2!M:6YU="(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V
M97)Y($QO9VEN(@IM<V=S='(@(E9S86MA('!R:6IA=F$B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`R(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")6<V%K92!P
M;VP@=7)E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,PHC
M+"!F=7IZ>0IM<V=I9"`B179E<GD@:&]U<B(*;7-G<W1R(")6<V%K92!P;VP@
M=7)E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(E9S86MO(&UI;G5T
M;R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%
M>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B4')I;65R('9R961N;W-T:3HB"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#`@861M:6XO8VUD<VAE;&PN<&AP.C0Y
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C8*;7-G:60@(D5X96-U=&4B"FUS9W-T
M<B`B27IV961I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")0;W9EQ(UA
M:B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*(RP@9G5Z
M>GD*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(DMO;F5C(&QE=&$B
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED
M(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B4')IQ(UA:V]V86X@)RDG(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M(")0<FG$C6%K;W9A;F$@:F4@8FEL82!B97-E9&$@86QI(&)E<V5D;F$@>G9E
M>F$@=B!N879E9&YI8V%H(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T
M=6T@>F%P861L;W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("):87-T;W!N:6LB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<V"FUS9VED(")&5%`@=7!L
M;V%D(&]F('-E='5P(@IM<V=S='(@(D944"!N86QOQ;YI=&5V(&YA;65S=&ET
M=F4N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C4Q"FUS
M9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B
M3FD@=7-P96QO('9Z<&]S=&%V:71I('!R969E<F5N8V4N(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")0;W9E>F%V82!Z($Q$05`@<W1R9<6^;FEK
M;VT@;FD@=7-P96QA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HQ,#$*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M(@IM<V=S='(@(E!O=F5Z879A(',@4TU"('-T<F7%OFYI:V]M(&YI('5S<&5L
M82`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q,2!F<F%M97=O
M<FLO5D93+U9&4R]S<V@R+G!H<#HW,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DMO<&ER86YJ
M92!I>B!<(B5S7"(L(&YI('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<Q-B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R(")+;W!I<F%N:F4@;F$@7"(E<UPB+"!N:2!U<W!E;&\N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX.0IM<V=I9"`B1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(").
M:2!U<W!E;&\@=GIP;W-T879I=&D@;F]V;R!305-,('!O=F5Z879O+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`V(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S8U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP
M.C<W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<
M(B5S7"(N(@IM<V=S='(@(DYI('5S<&5L;R!P<F5M86MN:71I(&LZ("5S("(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#4U"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B3F5M
M;V=OQ(UE('!R96)R871I.B`E<R`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")/9&1A
M;&IN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA
M;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9'-K:2!O=&]K:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F5R<VMI(&]T;VMI
M("(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L
M($5R<F]R.B(*;7-G<W1R(")(=61A(&YA<&%K82$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V-0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X:2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R(")&96)R=6%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G
M:60@(D9E96QS($QI:V4B"FUS9W-T<B`B4&_$C75T:71I('-E(&MO="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C4*;7-G:60@(D9E96QS
M(&QI:V4Z("(*;7-G<W1R(")0;\2-=71I=&D@<V4@:V]T.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@
M4VAO=V5R<R(*;7-G<W1R(").96MA:B!N86QI=F]V(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B3F5K86H@<VYEQ;YN:6@@;65T9<6^978B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B36%T<FEC82!P;VQJ82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,V,3(*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S
M='(@(D9I9VQE="!#05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S8Q-@IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B1FEG;&5T('!I
M<V%V82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEDQ;YI
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&
M:6QE(@IM<V=S='(@(D1A=&]T96MA(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL92(*;7-G<W1R("+%H'1E=&IE($1A=&]T96LZ("5S(&1A=&]T96LB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("+%H'1E=&IE($1A
M=&]T96LZ("5S(&1A=&]T96LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,P"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B57!R879I=&5L
M:B!D871O=&5K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G
M:60@(D9I;&4@3F%M92(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C8U"FUS9VED(")&:6QE('-E;&5C=&EO
M;B(*;7-G<W1R("))>F)I<F$@9&%T;W1E:V4N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30Y.0IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B
M3F%L;\6^:2!D871O=&5K;R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.CDP-PIM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(D1O9&%N82!D871O=&5K82!N:2!P;V1P<G1A+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R(")&:6QT<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S
M='(@(D9I;G-K82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B4')V82!P;VQO=FEC82(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@
M(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B4')V82#$C65T<G1I;F$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED
M(")&:7@@<F%T:6\B"FUS9W-T<B`B4W1A;&YE('9E;&EK;W-T:2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@
M(D9L:7`B"FUS9W-T<B`B3V)R;FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(DUE9VQA
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR-C`@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B)7,@;6%P82!N92!O
M8G-T86IA("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B
M1F]O9"(*;7-G<W1R(")(<F%N82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0V"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(").87!O=F5D("A4
M048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<W"FUS9VED
M("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E
M(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM
M<V=S='(@(D1N979I(&YA<&]V961I+B`H3F%P;W9E9&$@;&4@;&%H:V\@>F5L
M;R!D;VQG82DB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDT"FUS
M9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B4W1E('!O>F%B
M:6QI('9AQ:%E(&=E<VQO/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.#4*;7-G:60@(D9O<FUS(@IM<V=S='(@(F]B;&EK92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR-@IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")3
M<F7$C6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,3`T"FUS9VED(")&
M;W)T=6YE('1Y<&4B"FUS9W-T<B`B4W)EQ(UE(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")3<F7$C64B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(D9O<G1U;F5S
M(#(B"FUS9W-T<B`B4W)EQ(UE(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<V"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B5&%B;&$@<&]G;W9O
M<F]V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B
M1F]R=V%R9',B"FUS9W-T<B`B4')E=7-M97)I=&5V92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(D9R(@IM
M<V=S='(@(D9R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@
M(D9R86YC:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N8VEJ
M82P@2V]L;VYI86QN82!M971R;W!O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&
M<F5N8V@@1W5I86YA(@IM<V=S='(@(D9R86YC;W-K82!'=F%J86YA("(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R
M86YC;W-K82!0;VQI;F5Z:6IA("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YC;W-K:2!J
M=<6^;FD@=&5R:71O<FEJ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S`*;7-G:60@(D9R;VTB"FUS9W-T<B`B3V0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-3(*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Y.`IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D]D("(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0R"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!O;&X@3W!I<SHB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B
M1G5L;"!-;V]N(@IM<V=S='(@(E!O;&YA(&QU;F$B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHV,0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(E!O;&YO(&EM92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I:F$B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B57-T=F%R:2`E<R!.
M87-T879I='9E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH
M=&UL.C8*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D=E;F5R:7)A
M:B!K;V1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'
M<G5Z:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(").
M96W$C6EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=A
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB
M<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B1&%N;R!I;64B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<Y('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS
M9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")3<&QOQ:%N92!-;\6^;F]S
M=&DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B
M"FUS9W-T<B`B4&]J9&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*
M;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B
M"FUS9W-T<B`B1V]O9VQO=F4@;6%P92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B2<6AQ(UI
M('H@1V]O9VQO;2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("),97-T=FEC
M82!S:79I;F4@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R
M(")'<L2-:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@
M(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<L6A:VD@*$E33RTX.#4Y
M+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R
M96YL86YD:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R
M(")'<F5N861A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-S@*;7-G:60@(D=R
M;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E-K=7!I;G-K82!A9&UI;FES
M=')A8VEJ82(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B26UE;F$@4VMU<&EN
M(&YE('-M96IO(&)I=&D@<')A>FYA(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!.92!M;W)E;2!D
M;V1A=&D@<VMU<&EN92`E<RX@4W!O<F_$C6EL;R!S=')EQ;YN:6MA.B`B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(E-K
M=7!?;&1A<#H@3F4@;6]R96T@:7IB<FES871I('-K=7!I;F4@)7,B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R
M(")3:W5P7VQD87`Z($YE(&UO<F5M(&YA9&=R861I=&D@<VMU<&EN92`E<R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B4VMU<&EN92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L;W5P92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y
M(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I
M9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1&]V;VQJ96YJ82!Z82!G
M;W-T92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3,*;7-G:60@
M(D=U97-T8F]O:R(*;7-G<W1R(")+;FII9V$@9V]S=&]V(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=V:6YE:F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W9I;F5J82U":7-S
M86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=F%J
M86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38Y"FUS9VED(")(
M5$U,(@IM<V=S='(@(DA434PB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT
M='`N<&AP.C$U-`IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D]V97)J96YE9V$@2%144"!.:7-E;2!N8<6A96PN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S:"!!;&=O<FET96TB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,V"FUS9VED("(B"B)(879E(&$@8G5T=&]N
M(&EN('1H92!T;V]L8F%R('1H870@<&]P<R!U<"!A('=I;F1O=R!W:71H('-P
M96-I86P@8VAA<F%C=&5R<S\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T
M<B`B365G;&EC82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDR."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C`R"FUS9VED(")(96%D97(B"FUS
M9W-T<B`B1VQA=F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(D=L879E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',B"FUS9W-T<B`B2&5A<F0@;W1O:R!I;B!-8T1O;F%L9&]V;R!O
M=&_$C6IE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B36_$C6YA(&YE
M=FEH=&$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B
M<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E:G-K:2`H25-/+3@X
M-3DM."U)*2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`B5FG%H6EN82(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92](96QP+G!H<#HQ.#$@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N
M<&AP.C$X,@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T
M97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R(")0;VUO
MQ(TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S@T"FUS9VED(")(
M96QP97(B"FUS9W-T<B`B4&]M;\2-;&YI:R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")0;VQO8FQA(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B5'5K86H@:F4@>F'$C65T96L@9&%T
M;W1E:V4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S$*;7-G:60@(DAI9V@B"FUS9W-T<B`B5FES;VMO(@H*(SH@=&5M<&QA
M=&5S+VUE;G4O;65N=2YI;F,Z-PIM<V=I9"`B2&]?;64B"FUS9W-T<B`B1&]M
M;W8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#
M:71Y(%-T871E*2(*;7-G<W1R(")6871I:V%N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E
M<W,B"FUS9W-T<B`B1&]M8<2-:2!N87-L;W8B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S`*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(DEM
M96YI:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B1&]M8<2-:2!T96QE
M9F]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(
M;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S
M='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV
M-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.979E;&IA=F5N("5S
M(%A-3"!P;V1A=&5K(&YA:F1E;B!V('-P;W)OQ(UI;'4@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YO8F5N;R!S<&]R;\2-:6QO
M('-E(&YE('5J96UA(',@<')E9&UE=&]M("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%8@<W!O<F_$C6EL=2`E<R!N:2!N
M86ID96X@;F]B96X@<')E9&UE="!T:7!A("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(%5S<&7%H6YO(&]D<W1R86YJ96X@)7,@7"(E<UPB
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!);G1E9W)A8VEJ<VMA(&YA<')A=F$@>F%H=&5V82`G9&]M>&UL)R!02%`@
M96MS=&5N>FEJ;R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3$R
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!.92!M;W)E('5S='9A<FET:2!N;W9O(%A-3"!D<F5V;R!Z
M82`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.92!M;W)E
M;2!O9'-T<F%N:71I("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T
M(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE(&UO<F5M('!O
M:7IV961E=&D@>F$@34E-12!)1"!Z82!D96P@;V0@=G)S=&4@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.92!M;W)E;2!S:6YH
M<F]N:7II<F%T:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,S,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@3F4@;6]R96T@<VEN:')O;FEZ:7)A=&D@9&5L93H@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S
M7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE>FYA;F$@9&5L:71E=B!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@
M(DMO;&EK;R!P;VQJ("AS=&]L<&-E=BEJ92!T86T_(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y,R!L:6(O0FQO8VLO;65T87(N<&AP.C(T
M,@IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B5FQAQ;YN;W-T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,PIM<V=I9"`B2'5M:61I='DZ
M("(*;7-G<W1R(")6;&'%OFYO<W0Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-@IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")-863%OF%R
M<VMA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<P(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B57-T=F%R:F%N:F4@24U!4"!N86)I<F%L;FEK82!N:2!U<W!E;&\Z
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B0G)I<V%N:F4@24U!4"!N86)I<F%L;FEK82!N:2!U<W!E;&\Z("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<W(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B57-T=F%R:F%N:F4@:W9O=&4@24U!4"!N86)I<F%L;FEK82P@
M;FD@=7-P96QO.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M,C4*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@3F%S;&]V(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!.87-L;W8@;FD@
M;F$@<F%Z<&]L86=O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I
M8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D
M($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0($YA<VQO=B!N:2!V(&1O=F]L:F5N
M:2!#2412('-K=7!I;FDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(EIA:VQE;FIE;B!)4"XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD:6IA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R
M(")386UO(&EK;VYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N
M92!Z82`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@
M(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]N92!Z(&)E<V5D:6QO;2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y
M)W,@;F%M93HB"FUS9W-T<B`B261E;G1I9FEK86-I:G-K;R!I;64Z(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P"B,L('!H<"UF
M;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B)7,@
M>F$@;V1P<F5T:2!V(&YO=F5M(&]K;G4L(,2-92!N:2!P<F%V:6QN;R!P<FEK
M87IA;F\N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T
M(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T
M(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*
M(L2-92!V:61I=&4@=&\@<W!O<F_$C6EL;R!I;B!S;&G$C6EC92!N92P@<&]M
M96YI+"!D82!V8<6A(&)R<VMA;&YI:R!N92!M;W)E("(*(F]D<')E=&D@<VQI
MQ(UI8V4L(&MI(&IO(,6^96QI=&4@;F%L;\6^:71I+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-S0*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G
M<W1R(")$;V1A:B!S;&EK;R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W
M"FUS9VED("));6%G97,B"FUS9W-T<B`B4VQI:V4B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M="P@4W1E<"`E9"(*;7-G<W1R(")6;F]S+"!+;W)A:R`E9"(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")6;F7%H65N;R!P;VQJ93H@
M)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("))
M;7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(E9N9<6A96YA('!O;&IA.B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")0;W-R
M961O=F%N(&YE<')A=FEL96X@=6MA>BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5P<F%V:6QN
M;R!U<&]R86)N:<6A:V\@:6UE(&EN+V%L:2!G97-L;RXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"B).97!R879I;&YO('5P;W)A8FYIQ:%K;R!I
M;64@86QI(&%L=&5R;F%T:79E;B!N87-L;W8N(%!O<VMU<VET92!Z;F]V82!A
M;&D@(@HB:V]N=&%K=&ER86IT92!V8<6A96=A('-K<F)N:6MA+"#$C64@<&]T
M<F5B=6IE=&4@;F%D86QJ;FIO('!O;6_$C2XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DEN9&EA(@IM<V=S='(@(DEN9&EJ82(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E!O<V%M97IN
M:2!5<&]R86)N:6MI("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA
M(@IM<V=S='(@(DEN9&]N97II:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<S"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA
M8VEJ92!O('-E<W1A;FMU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,R,@IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`B26YF;W)M86-I:F4@;FES;R!V9<2-(&1O<V5G;&II=F4N
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#D*;7-G:60@(DEN<V5R="!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B5G-T879I(&%L=&5R;F%T:79E
M;B!V>F]R96,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED
M("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B5G-T879I=&4@96QE
M:W1R;VYS:VD@;F%S;&]V(&YA(&MA=&5R96=A(&QA:&MO('!R96IM971E(&YO
M=F\@9V5S;&\Z(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R(")6<W1A=FET
M92!S<&]R;\2-:6QO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM
M<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.B(*;7-G<W1R(")6<&G%H6ET92!Z86AT979A;B!O9&=O
M=F]R(&YA('9A<FYO<W1N;R!V<')AQ:%A;FIE.B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R(")3=&%N:F4@;F$@<F'$C75N=2!N92!Z861O<W1U:F4@
M>F$@<&_%H6EL:F%N:F4@;F$@Q;YE;&IE;B!S<&ES96LN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@
M(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(E-T86YJ92!N82!R8<2-
M=6YU(&YE('IA9&]S='5J92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#@T"FUS9VED("));G1E9V5R(@IM<V=S='(@(D-E;&\@Q:%T979I;&\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,30R"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`B4V5Z;F%M(&-E;&EH(,6A=&5V:6PB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*
M;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S
M='(@(DYE=F5L:F%V96X@541(+B`H57-E<B!$871A($AE861E<BDN(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN
M=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B3F5V96QJ879E;B!:25`@<&]D871E
M:RX@(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV
M86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B3F5V96QJ879N82!A<&QI:V%C
M:6IA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B
M3F5V96QJ879N:2!)1"!P86ME="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4R,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3@W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S
M='(@(DYE=F5L:F%V;FD@<&]D871K:2!S;R!B:6QI(&]D<&]S;&%N:2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T
M<B`B3F5V96QJ879E;B!N87-L;W8@;F%S;&]V;FEK82XB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F
M:6QE(&9O<FUA="(*;7-G<W1R("(@3F5V96QJ879N82!O8FQI:V$@9&%T;W1E
M:V4@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,`IM<V=I
M9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3F5V96QJ879E;B!L
M:6-E;L2-;FD@:VQJ=<2-+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C0*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(D]D<F5J96X@;F5V96QJ879E;B!K<F%J+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B
M26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B3F5V96QJ879E;B!T:7!?;7-G
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS
M9W-T<B`B3F5V96QJ879E;B!A;&D@;6%N:FMA:F_$C2!A<&E?:60N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`B3F5V96QJ879N:2!A;&D@;6%N:FMA:F_$C6D@<&%R86UE=')I+B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-@IM<V=I9"`B26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5V96QJ879N;R!D;W9O;&IE
M;FIE('-T87+%H65V+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C8*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B3F5V
M96QJ879E;B!P87)T;F5R:F5V(&ED+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C@*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*
M;7-G<W1R(").979E;&IA=FYA(&MO9&$@87)T:6ML82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(DYE=F5L:F%V96X@<')O=&]K
M;VPN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*
M;7-G<W1R(").979E;&IA=F5N(&YA<VQO=FYI:SH@7"(E<UPB(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#@P(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS
M9W-T<B`B($YE=F5L:F%V96X@;V)J96MT(&1E;&IE;FIA("(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I
M9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B3F5V96QJ879E
M;B!I>G9O<FYI(&YA<VQO=BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R("(@3F5V96QJ879E;B!U;FEK;V0@<&]D871E:R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S,*;7-G:60@(DEN=F5N
M=&]R>2(*;7-G<W1R("));G9E;G1U<F$O<&]P:7,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C@P"FUS9VED("));G9E<G0@
M<V5L96-T:6]N(@IM<V=S='(@(D]B<FYI(&EZ8F]R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER
M86XL($ES;&%M<VMA(%)E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B
M27)A<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L
M86YD(@IM<V=S='(@(DER<VMA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))
M<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")0;W-A;65Z;F4@;F5V:6AT92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DEZ<F%E;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED
M("))<W-U97(B"FUS9W-T<B`B27ID86IA=&5L:B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:FMA(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DIA;G5A<GDB
M"FUS9W-T<B`B2F%N=6%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*
M;7-G<W1R(")*87!O;G-K82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N
M<VMI("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A;FEJ82(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED
M(")*=6QY(@IM<V=S='(@(DIU;&EJ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N
M:6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B
M2V%Z86AS=&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B3V)D
M<L6^:6T@:7IV:7)N:6L_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R(")+96YI:F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@V"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S('-T<F7%OFYI:R!Z879R;FEL
M(&]V97)I=&5V+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I
M9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L(&YO=FEN8VDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!#<F5A=&EO;B(*;7-G<W1R(")5<W1V87)I($ML:G7$C2`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG
M97)P<FEN="(*;7-G<W1R(")/9'1I<R!+;&IUQ(UA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM
M<V=S='(@(D1O;,6^:6YA($ML:G7$C6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E1I
M<"!+;&IUQ(UA("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B57!O<F%B82!+;&IU
MQ(UA("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM
M<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R(")+;&IUQ(T@Q;YE(&]B<W1A:F$@;F$@:F%V;F5M(&ML
M:G7$C6YE;2!S=')EQ;YN:6MU+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B2VED<R(*;7-G<W1R(")/=')O8VDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I("(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B2V]R96IA+"!$96UO:W)A=&G$C6YA(&QJ=61S
M:V$@<F5P=6)L:6MA("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5J82P@4F5P=6)L:6MA("(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB
M"FUS9W-T<B`B2V]R96IS:VD@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(DMU=V%I="(*;7-G<W1R(")+=79A:G0@(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=I>FEJ82`B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<U"FUS9VED("),86YG=6%G92(*;7-G
M<W1R(")*97II:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<R!L:G5D<VMA(&1E
M;6]K<F%T:<2-;F$@<F5P=6)L:6MA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(EIA9&YJ82!P;VQO=FEC
M82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM<V=I9"`B3&%S="!0
M87-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B6F%D;FIA('-P<F5M96UB82!G97-L
M83H@(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N
M+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(EIA9&YJ82#$
MC65T<G1I;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B
M3&%S="!5<&1A=&5D.B(*;7-G<W1R("):861N:F4@8<6^=7)I<F%N:F4Z(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(EIA9&YJ82!P<FEJ879A
M.B`E<R`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R
M("):861N:F$@<')I:F%V83H@)7,@:7H@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(EIA9&YJ82!P<FEJ879A.B!.:6MO;&DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQA='9I82(*;7-G<W1R("),871V:6IA("(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.0IM<V=I9"`B3&%W(@IM<V=S='(@(E!R879O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S@X"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R("),979O(&]G;&%V;&IE(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,X-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B
M5G)E9&YO<W1I(&YA(&QE=FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`B3&5S;W1O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R(")2879E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6)E<FEJ82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G
M<W1R("),:6)I:F$@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T
M96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6X@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ
M;&4B"FUS9W-T<B`B4F%H96P@<'+%H65C(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS
M9W-T<B`B4F%H96P@9&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S
M='(@(EIG;V1A:B!R86AE;"!D9<6^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*
M;7-G<W1R(")0;WIN;R!R86AE;"!D9<6^(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO
M=V5R(@IM<V=S='(@(E!L;VAA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R(@IM<V=S='(@(E!L;VAA('H@9W)M96YJ96TB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO
M=R(*;7-G<W1R(")286AE;"!S;F5G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(E-N9<6^;FD@;65T9<6^(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4P"B,L(&9U>GIY"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),
M:6)E<FEJ82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,C<*;7-G
M:60@(DQI;FLB"FUS9W-T<B`B4&]V97IA=F$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#$S"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@
M(E!O=F7%OFD@92UN87-L;W8@<R!O8G)A>F-E;2!Z82!S97-T879O(&YO=F4@
M<&_%H71O(&UE('!R:6MA>F]V86YJ96TB"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*
M;7-G<W1R(")0;W9E>F%V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X('!IQ:%K;W1E
M:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0V
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS
M9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B
M4V5Z;F%M("T@=7!O<F%B;FEK(&QA:&MO('9I9&D@;6%P;R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S
M='(@(E-E>FYA;2!P;V1A=&MO=FYI:"!B87HB"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R
M(")397IN86T@5&5M(%!O;6_$C6D@(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,0IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B4V5Z;F%M('1A8F5L
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,38*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(@4V5Z;F%M($%R:&EV82`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Q,0IM<V=I9"`B
M3&ES="U(96QP(@IM<V=S='(@(E-E>FYA;2!0;VUOQ(UI("(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3$X"FUS9VED("),:7-T+4ED
M(@IM<V=S='(@(E-E>FYA;2!)9&5N=&ET970@(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU,30*;7-G:60@(DQI<W0M3W=N97(B"FUS
M9W-T<B`B4V5Z;F%M($QA<W1N:6MO=B`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Q-0IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(E-E>FYA;2!0;\6A=&4@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU,3,*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(E-E
M>FYA;2!0<FEJ878@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU,3(*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B4V5Z
M;F%M($]D:F%V("(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B4W!I<V5K('-E>FYA;6$@<V5J(&YI('5S<&5L.B`E<RXB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(E-E>FYA;2!U<&]R86)N
M:6MO=B!N:2!M;V=OQ(UE.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`B4V5Z;F%M('5P;W)A8FYI:V]V(&YI(&UO9V_$C2XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*;7-G:60@(DQI=&5R871U<F4B
M"FUS9W-T<B`B3&ET97)A='5R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET
M:'5A;FEA(@IM<V=S='(@(DQI='9A("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS
M9W-T<B`B3F%L86=A;2XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#4*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("),;VMA;&YI
M(,2-87,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),
M;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B3&]K86QI>F%C:6IA(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8R"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C<W"FUS9VED("),;V-A=&EO;B(*;7-G
M<W1R(")-97-T;R(*"B,Z(&QO9VEN+G!H<#HQ.#@@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C(P-"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.#(*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")0<FEJ
M879A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED
M("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(D]D:F%V
M82!S('!R961H;V1N92!S>6YC('-E:F4@(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Y.`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")/9&IA
M=F$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$*;7-G:60@(DQO9VEN
M(@IM<V=S='(@(E!R:6IA=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")0<FEJ879A(&YA(&]P
M<F%V:6QA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS9VED
M("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W
M;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R(")0<FEJ879A
M(&YI('5S<&5L82X@57!O<F%B;FG%H6MO(&EM92!A;&D@9V5S;&\@;F5P<F%V
M:6QN;R!V;F7%H65N;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")0<FEJ879A(&YI('5S
M<&5L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S@*;7-G:60@
M(DQO;F<@=&5X="(*;7-G<W1R(")$;VQG;R!"97-E9&EL;R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3&]V92(*;7-G<W1R("),:G5B
M97IE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B3FEZ96LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5K<V5M8G5R9R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,R!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDW"FUS9VED(")-3U1$(@IM<V=S
M='(@(E-P;W)OQ(UI;&\@9&YE=F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&(%!R:7!O;FMA
M(&YI('9S96)O=F%L82!P;V1A=&MO=BXB"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS
M9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M86-A;R(*;7-G<W1R(")-86-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(DUA:V5D;VYI:F$L(&9O<FUA;&YA($IU9V]S;&]V86YS:V$@<F5P=6)L
M:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@
M(DUA9&%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G
M:60@(DUA9VEC(@IM<V=S='(@(L2-87)O8F5N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.CDP"FUS9VED(")-86EL(@IM<V=S='(@(D5L96MT<F]N
M<VMI(&YA<VQO=B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU-#8*
M;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B061M:6YI<W1R871O<B!P;\6A
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA
M=FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA
M;&5Z:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R
M(")-86QD:79I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@
M(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA
M;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)5<F5D:71E('-E>FYA;2!K
M871E9V]R:6H@<R!K871E<FEM:2!B;W-T92!O>FYAQ(UI;&D@<&]S=&%V:V4@
M:6X@<')I<&%D86IOQ(UE("(*(F)A<G9E('IA('1E(&MA=&5G;W)I:F4N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-38*
M;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("):96UL:F5V:60@36%P,C0B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM
M<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(EIE;6QJ979I9"!-87!1<F5S
M="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B
M36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")3:')A;FIE;F4@<&]V97IA=F4B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM
M<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R96,B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S(@IM<V=S='(@(D]Z;F'$C6D@>B!Z87-T879I8V%M:2!6
M:61E;F\O3F5V:61E;F\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HT.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N
M($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B3WIN8<2-:2!Z(&]S=&%L
M:6UI('IA<W1A=FEC86UI*&YP<BX@4&]M96UB;F\O3V1G;W9O<FIE;F\I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@
M(DUA<G-H86QL;W9O(&]T;\2-:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA
M<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS
M9W-T<B`B56IE;6%N:F4@<&]L:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U
M<FET86YI82(*;7-G<W1R(")-879R971A;FEJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=G)I8VEU<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I
M9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(").96IV9<2-(&1O=F]L
M:F5N:2!Z;F5S96LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X
M8V5E9&5D+B(*;7-G<W1R(")-86MS:6UA;&YI(&1E;&D@<W!O<F_$C6EL82!P
M<F5K;W)AQ(UE;FDN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3@*;7-G
M:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")-86MS:6UA
M;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@,C0@=7(Z(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(DUA:W-I;6%L;F$@=&5M<&5R871U<F$@>F%D;FII:"`V('5R
M.B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O
M9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DUA:W-I;6%L;F\@Q:%T979I;&\@
M8FQO:V]V('!O<G1A;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M,#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C0X"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G
M<W1R(")-86MS:6UA;&YA(&1O;,6^:6YA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DUA>2(*;7-G<W1R(")-
M86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA
M>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(DUE
M9&EC:6YE(@IM<V=S='(@(EID<F%V:6QO("A-961I8VEN82DB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S
M(@IM<V=S='(@(L2-;&%N:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B5&EP(&UE;FEJ83HB"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")3<&]R;\2-:6QO(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*
M(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("(B"B)3<&]R;\2-:6QO(&IE(&)I;&\@=7-P9<6A;F\@<')E=F5R:F5N
M;RP@=&]D82!P;V1P:7-N:6MO=F5G82!P;W1R9&EL82!N:2!B:6QO("(*(FUO
M9V_$C64@<')E=F5R:71I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D
M+B(*;7-G<W1R(")3<&]R;\2-:6QO(&IE('!O=&5K;&\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1I<"!3<&]R;\2-
M:6QA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!7
M96%T:&5R(@IM<V=S='(@(DUE=&%R('9R96UE(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HT,@IM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B365T87(@8FQO:R!N:2!N82!R87IP;VQA9V\N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,C0*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E!O9')O8FYO<W1I('-O(&)I;&4@
M<')I:F%V;&IE;F4@>F$@=7!R879L:F%L8V$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U.`IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R(")-971A<D1"(&YI('!O=F5Z86XN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS
M9W-T<B`B4&]S=&]P96LB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N
M<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HX.`HC.B!F<F%M
M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#D@9G)A;65W;W)K+U)00R]24$,O
M<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S
M7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B)R5S)R!P;W-T;W!E:R!N:2!D
M;VQOQ(UE;BXB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE
M9"!M971H;V0Z("5S(@IM<V=S='(@(E!O<W1O<&5K(&YI(&1O;&_$C65N+B!0
M;W-T;W!E:R!C96QI8V4Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<R(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(DUE=')I
M8R(*;7-G<W1R(")-971R:<2-;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE
M>&EC;R(*;7-G<W1R(")-96AI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;VYE
M>FEJ82P@1F5D97)A=&EV;F$@9'+%OF%V82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B5&EP(&1A=&]T96ME(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,C(*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")-
M:6YI;6%L;F$@=&5M<&5R871U<F$@>F%D;FII:"`R-"!U<CHB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q-`IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B36EN:6UA;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@
M-B!U<CHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.`IM
M<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9"(*;7-G<W1R(")-:6YI;6%L;F$@<W1A<F]S="!G97-L82#%H64@;FD@<&]T
M96ML82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")/9VQE9&%L;R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B36ES8V5L;&%N96]U<R(*
M;7-G<W1R(")-;F]G;W-T<F%N<VMA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!O9W)EQ:%A;B!0
M14%2('!A:V5T+"!(5%10('IA:'1E=F%N+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,30*(RP@9G5Z>GD*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&UU<W0@9V5N97)A=&4@:70@8F5F;W)E('5S:6YG('1H
M:7,@87!P;&EC871I;VXN(@IM<V=S='(@(B(*(E!O9W)EQ:%A;F$@:V]N9FEG
M=7)A8VEJ82X@Q(UE(,6^96QI=&4@=7!O<F%B;&IA=&D@=&\@87!L:6MA8VEJ
M;RP@;6]R871E("(*(F=E;F5R:7)A=&D@:V]N9FEG=7)A8VEJ;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*
M;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B4&]G<F7%H6%N
M;R!)1"!S<&]R;\2-:6QO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")0;V=R9<6A86YO('-P
M;W)OQ(UI;&\@;R!Z86AT979A;F5M(%!%05(@<&%K971U+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I
M9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")0;V=R9<6A86YA($E$
M('-E:F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`IM<V=I9"`B36\B"FUS9W-T<B`B4&\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@
M(DUO8FEL;F$@<&_%H71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(EIM97)N
M;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I
M9FEE9"!$871E(@IM<V=S='(@(D1A='5M('-P<F5M96UB92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S
M(@IM<V=S='(@(DUO9'5L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&%V:6IA+"!R97!U8FQI:V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA:V\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O
M;&EJ82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-S(*;7-G:60@
M(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUE<V5C(&EN(&QE=&\B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(DUE<V7$C6YO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(DQU;FEN92!M96YE(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R
M(")6('9R<W1I("5D(&IE(&YA:F1E;FEH('9EQ(T@<&]L:B!O9"!P<F5D=FED
M96YI:"`E9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T
M<B`B36%R;VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")0<F5T9<6^
M;F\@:F%S;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")0<F5T9<6^
M;F\@;V)L8<2-;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS
M9W-T<B`B4')E=&7%OFYO(&]B;&'$C6YO(&EN('9E=')O=FYO(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO
M<W1L>2!3=6YN>2(*;7-G<W1R(")0<F5T9<6^;F\@<V]NQ(UN;R(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS
M9VED(")-;W9E($1O=VXB"FUS9W-T<B`B4&]M86MN:2!S92!D;VPB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM
M<V=I9"`B36]V92!,969T(@IM<V=S='(@(E!O;6%K;FD@<V4@=B!L979O(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B4&]M86MN:2!S92!V(&1E
M<VYO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B4&]M86MN:2!S92!G
M;W(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3,P"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B4&]M86MN:2!S92!D;VPB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(Y
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,S`*
M;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4&]M86MN:2!S92!G;W(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:6LB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#<R"FUS9VED(")-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B5F7$C2!N:79O:FYI
M('!A9&%J;\2-:2!S<&ES:VDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM
M<V=S='(@(DUU;'1I;6%P(%5+('IE;6QJ979I9"XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3,P"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB
M"FUS9W-T<B`B36YO9V]K<F%T96X@:7IB;W(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUO
M:B!R8<2-=6XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@
M(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B4&]D871K:2!M;VIE
M9V$@<F'$C75N82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-C0*
M;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-;VH@<&]R=&%L(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C,T"FUS9VED(")->2!0;W)T86P@3&%Y
M;W5T(@IM<V=S='(@(D]B;&EK82!M;VIE('!R=F4@<W1R86YI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUJ86YM87(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I
M9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DYE+"!S92!N92!S=')I
M;FIA;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").
M86UE(@IM<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I
M82(*;7-G<W1R(").86UI8FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U
M<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L
M(@IM<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L
M86YD<R(*;7-G<W1R(").:7IO>F5M<VMA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(DYI>F]Z96US:VD@06YT
M:6QI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(DYE='-C87!E(&]S
M;F]V;FD@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(B!.971S8V%P92!#02!54DP@>F$@<')E:VQI8R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#
M02!P;VQI8WD@55),(@IM<V=S='(@(DYA<VQO=B!.971S8V%P92!C97)T:69I
M:V%T82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U
M"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(@3F5T<V-A
M<&4@;V)N;W9I='9E;FD@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(B!.971S8V%P92!54DP@>F$@<')E:VQI8R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P
M92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A<&4@4U-,(&EM92!S
M=')EQ;YN:6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS
M9W-T<B`B3F5T<V-A<&4@=7)A9&YI(&MO;65N=&%R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B5&EP($YE='-C87!E(&-E<G1I9FEK
M871A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-PIM<V=I9"`B
M3F5T=V]R:R(*;7-G<W1R(")/;7)EQ;YJ92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-2!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(").:6MO;&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B
M3F]V82!+86QE9&]N:6IA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G
M<W1R(").;W9A(&MA=&5G;W)I:F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYO=F$@3'5N82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8*;7-G:60@(DYE=R!5
M<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=F\@=7!O<F%B;FG%H6MO
M(&EM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T
M<B`B3F]V82!:96QA;F1I:F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").;W9O(&=E
M<VQO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(T.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N(@IM<V=S='(@(DYO=F\@9V5S;&\@8F\@<&]T96ML;R`E>"XB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S
M=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DYO=F\@9V5S;&\@<V4@;F4@
M=6IE;6$N(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#4*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]V:6-E(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R,0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R
M(").;W9IQ(UA<G-K82!S:W5P:6YA(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B3F%S;&5D;FII
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA
M<V5S(@IM<V=S='(@(DYA<VQE9&YJ92`T('-T;W!N:F4B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(DYA
M<VQE9&YJ82!M;\6^;F]S="(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(").87-L961N:FD^(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEK87)A9W9A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEJ
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S(*;7-G:60@
M(DYI9VAT(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").;V)E9&5N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED
M(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+B(*;7-G<W1R(").:2!D;W-T;W!N:6@@<&]D871K;W8@
M;R!K;VYF:6=U<F%C:6II(&1A(&)I('!O:V%Z86P@<F%Z;&EK92XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I
M9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RXB"FUS9W-T<B`B4W1R871E9VEJ82!Z82!I>F1E;&%V;R!)4T\@<VQI:RP@
M;FD@9&]S=&]P;F$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB
M"FUS9W-T<B`B3FD@<&%K971N92!P<F5D;&]G92(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED
M(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*
M;7-G<W1R(").82#%OF5L96YE;2!M97-T(&)E;&7%OFMA(&YE(&]B<W1A:F$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV-PIM<V=I9"`B
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B6F$@34-!3"!O=F5R:71E=B!N:2!K;VQE9&%R<VME
M9V$@:6UE;F$B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B
M3F\@8VAA;F=E+B(*;7-G<W1R(")N:2!S<')E;65N:F5N;R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(").
M82!T96H@<W1O<&YJ:2!N92!D;V1A:F%M;R!O=')OQ:%K:6@@9&]V;VQJ96YJ
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<X(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3$S"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN
M<&AP.C<X,@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(EIA("5S
M(&YI('-P96-I9FEC:7)A;FEH(&MO;F9I9W5R86-I:G-K:6@@:6YF;W)M86-I
M:BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-@IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(EIA($944"!61E,@;FD@<&]S96)N:6@@:6YF;W)M
M86-I:BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C<Q,`IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(B!:82!344P@5D93(&YI('!O<V5B;FEH(&EN
M9F]R;6%C:6HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<W-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(%IA(&1A=&]T96MO
M+5-13"!61E,@;FD@<&]S96)N:6@@:6YF;W)M86-I:BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<V@R+G!H<#HX-S`*(RP@9G5Z>GD*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!34T@R(%9&
M4RXB"FUS9W-T<B`B(%IA(%-13"!61E,@;FD@<&]S96)N:6@@:6YF;W)M86-I
M:BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(").:2!S
M=&%N:F$@;F$@<F'$C75N=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N(@IM<V=S='(@(DYI(&1E<W1I;F%C:6IE(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(U"FUS9VED(").;R!F:6QE('5P
M;&]A9&5D(@IM<V=S='(@(DYI(&YA;&_%OF5N:6@@9&%T;W1E:RXB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R(").92!N86ID96T@:6MO;BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(Q(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S-0IM<V=I9"`B3F\@;&]C871I;VX@
M:7,@<V5T+B(*;7-G<W1R(")-97-T;R!N:2!N87-T879L:F5N;RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38R"FUS9VED(").;R!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B365S=&\@;FD@;F%S=&%V;&IE;F\N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYO
M8F5N;R!S<&]R;\2-:6QO(&1O<W1A=FQJ96YO+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3FD@<W!E8VEF:6-I<F%N;R!N;V)E
M;F\@:6UE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G
M<W1R(").:2!S<&5C:69I8VER86YO(&YO8F5N;R#%H71E=FEL;RXB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(DYO(&]F9F5N<VEV92!F
M;W)T=6YE<R(*;7-G<W1R(").;V)E;FEH(&]F96YZ:79N:6@@<W)EQ(TN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B)0;W0@9&\@8FEN87)N92!D
M871O=&5K92!/<&5N4U-,(&YI(&)I;&$@;F%S=&%V;&IE;F$N($]P96Y34TP@
M8FEN87)N82`B"B)D871O=&5K82!J92!P;W1R96)N82!Z82!D96QO(',@4$M#
M4R`Q,B!P;V1A=&MI+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B
M3F4@<W!R96IE;6%M;R!Z8<2-87-N:6@@<')I:F%V(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@Q.`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R
M(")+=F]T82!N:2!N87-T879L:F5N82]D;VQOQ(UE;F$N(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@
M<W!E8VEF:65D+B(*;7-G<W1R(").:2!S<&5C:69I8VER86YO(&QOQ(UI;&\N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU-S8*;7-G:60@(DYO
M('-U8V@@9FEL92(*;7-G<W1R(").:2!T86ME(&1A=&]T96ME(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S,0IM<V=I9"`B3F\@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(").
M92!N86ID96T@>F'$C6%S;F4@;6%P92!Z82!P<F5D<&]M;FEL;FEK+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS
M9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T
M<B`B3F]B96YO('5P;W)A8FYIQ:%K;R!I;64@:6XO86QI(&=E<VQO(&YI(&)I
M;&\@<&]S;&%N;RXB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T,"!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3<U"FUS9VED(").
M;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(")0;W9R871N:6@@
M=F5L:F%V;FEH(%A-3"!P;V1A=&MO=B!N:2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS
M9W-T<B`B0G)E>B!V<F5D;F]S=&DB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$Y"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HB5B!O<FEG:6YA;&YI(&MO;F9I9W5R86-I:FD@;F4@;F%J9&5M(&YO
M8F5N92!R87IL:<2-:6-E+B!/8FYO=FET:2`B"B)K;VYF:6=U<F%C:6IO+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E8@=F'%H6D@:V]N9FEG=7)A8VEJ
M:2!N92!N86ID96T@;F]B96YE(')A>FQIQ(UI8V4N($]B;F]V:71E(&MO;F9I
M9W5R86-I:F\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(W('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.34*;7-G
M:60@(DYO;F4B"FUS9W-T<B`B3F]B961E;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R
M(").;W)D:6IS:VD@*$E33RTX.#4Y+3$P(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VS%H6MI(&]T;VMI(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")3979E<FYA
M('!O;&]B;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA
M;F$@27-L86YD<R(*;7-G<W1R(")3979E<FYI($UA<FEA;G-K:2!O=&]K:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G9EQ:%K
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS
M9VED(").;W0@069T97(B"FUS9W-T<B`B3F4@:V%S;F5J92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F
M;W)E(@IM<V=S='(@(DYE('!R96HB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HT-#<*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(").
M:2!I;65N:6LB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T
M(&EM<&QE;65N=&5D+B(*;7-G<W1R(").:2!I>G9E9&5N;RXB"@HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T-0HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C(S-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#@@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(S-`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR-CD*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,V."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S@U"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HT,3@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0W.`HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-34W(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HV,C8*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8T,R!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-S(Q"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E
M+G!H<#HX,B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3,Q"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HQ-3$@9G)A;65W;W)K+U9&4R]6
M1E,O:&]R9&4N<&AP.C$W,`HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP
M:'`Z,3@Y(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR,#<*(SH@9G)A
M;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C(R-R!F<F%M97=O<FLO5D93+U9&
M4R]H;W)D92YP:'`Z,S,P"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M(").92!P;V1P:7)A;2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$Q,C(@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B3F]T97,B"FUS9W-T<B`B6F%P:7-K:2(*
M"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYI('9P:7-A;FEH
M(&)E<V5D('IA(&ES:V%N:F4L('9R;FET92!S92!N87IA:BXB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-30*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-PIM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`B3F]V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#4U"FUS9VED(").=6UB97(B"FUS9W-T<B`BQ:!T979I;&\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,X"FUS9VED(").=6UB
M97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+%H'1E=FEL;R!Z;F%K;W8B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S@R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,S8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30U
M.`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`BQ:!T979I;&\@
M<W1O;'!C978B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S@P(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S0*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30U-@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B
MQ:!T979I;&\@=G)S=&EC(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(DYI('-P96-I9FEC:7)A;FEH(,6A=&5V:6QK('IA(&'%OG5R:7)A;FIE
M(&EN(&1I<W1R:6)U8VEJ<VMI('-E>FYA;2XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS
M9W-T<B`B6F%D979A(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(E5S='9A<FIA;&5C
M('!R961M971O=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,3,*
M;7-G:60@(D]C=&%L(@IM<V=S='(@(D]S;6G%H6MI(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-PIM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T,@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@
M(E!I<V%R;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*
M;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N
M="XB"FUS9W-T<B`B4W1A<F\@:6X@;F]V;R!G97-L;R!M;W)A=&$@8FET:2!R
M87IL:<2-;F$N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V
M"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4W1A<F\@1V5S;&\B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P
M87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B4W1A<F\@9V5S;&\@
M;FD@<')A=FEL;F\N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S
M='(@(D]M86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B36%P92!V('-K=7!N:2!U<&]R86)I('!O
M9'!I<F$@<V%M;R!)34%0('-T<F7%OFYI:RXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,3`P"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R(")386UO(&YE<W)A;6YE(&EZ:F%V92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-3D*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"XB"FUS9W-T<B`B1&]V;VQJ96X@:F4@;&4@96X@96QE:W1R
M;VYS:VD@;F%S;&]V+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-C<*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@:7,@
M86QL;W=E9"XB"FUS9W-T<B`B1&]V;VQJ96X@:F4@;&4@96X@96QE:W1R;VYS
M:VD@;F%S;&]V+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HW,`IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB3&4@;&%S=&YI:R!A;&D@=7!R
M879N:6L@<VES=&5M82!L86AK;R!Z86UE;FIA(&QA<W1N:<6A='9O(&%L:2!L
M87-T;FEK;W9O("(*(F1O=F]L:F5N:F4@>F$@9&5L9<6^+B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,V"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R(")/9'!R:2!V(&YO=F5M(&]K;G4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B3V1P<G1A4U-,(&YA<&%K83H@3F4@;6]R96T@<&]V
M>F5T:2!D871U;6$@:7H@;WIN8<2-96YE9V$@4R]-24T@9&5L82XB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`B3W!E<F%T:79N:2!S:7-T96TB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,34U"FUS9VED(")/<'1I;VYS(@IM<V=S='(@
M(DUOQ;YN;W-T:2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I
M;VYS(&9O<B`E<R(*;7-G<W1R(")-;\6^;F]S=&D@>F$@)7,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI
M<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IA8VEJ82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA
M;"!5;FET(@IM<V=S='(@(D]R9V%N:7IA8VEJ<VMA(&5N;W1A(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W)G86YI>FEN9R(*
M;7-G<W1R(")/<F=A;FEZ86-I:F$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$S-`IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS
M9W-T<B`B27IV:7)N92#%H6%B;&]N92!A<&QI:V%C:6HB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(DEZ=FER;FD@Q:%A8FQO;F4@
M=B`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*;7-G:60@(D]T:&5R(@IM<V=S='(@
M(D1R=6=O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B
M3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B3W-T86QE(&EN9F]R;6%C:6IE
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N
M97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1&]V;VQJ96YJ82!L87-T;FEK82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HX,`IM<V=I9"`B4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D]V
M97)J96YJ92!N:2!U<W!E;&\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N
M9"(*;7-G<W1R(")014%2.CH@9V]N:6QN:6L@4&_%H71E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET
M86P@4VEG;F%T=7)E(@IM<V=S='(@(D1I9VET86QE;B!P;V1P:7,@4$=0(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B
M4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(DMO9&ER86YI(%!'4"!P;V1A
M=&MI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W-`IM
M<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B2F%V;FD@:VQJ=64@4$=0
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I
M9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")0;V1P:7-A
M;FDO:V]D:7)A;FD@4$=0('!O9&%T:VDB"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-C<*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!K;V1A(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C$X"FUS9VED(")02%`@4VAE;&PB"FUS9W-T
M<B`B4$A0(&QU<&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,X"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(E!O
M<&]L9&YE(')A:&5L(&1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")0;W!O
M;&1N92!D9<6^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B4&]P;VQD;F4@
M;F%L:79I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B4&]P;VQD;F4@<VYE9RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM
M<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E!O<&]L9&YE('-N9<6^
M;FD@;65T9<6^:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B4&]P;VQD;F4@<V]N
M8V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-`IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B4&]P;VQD;F4@;F5V:6AT
M92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!O9W)EQ:%A;F$@4$]3
M25@@96MS=&5N>FEJ82(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](
M4"!3:&5L;"(*;7-G<W1R(")02%`@;'5P:6YA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G
M<W1R(")086QE<W1I;FMI(&]K=7!I<F%N:2!T97)I=&]R:6HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$@
M3F]V82!'=FEN96IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB
M"FUS9W-T<B`B4&%R86=V86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M(")$96QN;R!O8FQAQ(UN;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,#8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV.2!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0T"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(D=E
M<VQO(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED
M(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B1V5S
M;&\@=7-P9<6A;F\@<W!R96UE;FIE;F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C
M="(*;7-G<W1R(").97!R879I;&YO(&=E<VQO(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$U-PIM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B6F$@4D%$
M2553(&]V97)I=&5V(&IE('IA:'1E=F%N;R!G97-L;RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S0Q"FUS9VED(")087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")'97-L;R!I;B!P;W1R9&ET978B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R(")'97-L;SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")'97-L;SH@(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,C(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM
M<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D=E<VQO('-E
M(&UO<F$@=6IE;6%T:2XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$X"FUS
M9VED(")087-T92(*;7-G<W1R(")0<FEL97!I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS
M9W-T<B`B3F5P;W1R:F5N92!P<FEJ879E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Y"FUS9VED(")096]P;&4B"FUS9W-T<B`B3&IU9&IE(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G
M:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("))
M>G9RQ:%I('9Z9'+%OF5V86QN82!D96QA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R("))>G9RQ:%I;2!V>F1RQ;YE=F%L;F$@
M9&5L82!O8B!P<FEJ879I/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(D1O=F]L:F5N
M:F4B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G
M<W1R(")<(B5S7"(@9&]V;VQJ96YJ92!N:2!I>F)R:7-A;F\N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU-SD*;7-G:60@(E!E<FUI<W-I;VX@
M1&5N:65D(@IM<V=S='(@(D1O=F]L:F5N:F4@:F4@>F%V<FYJ96YO+B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G
M<W1R(")$;W9O;&IE;FIA(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`X
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU.0HC.B!A9&UI;B]P97)M<R]I
M;F1E>"YP:'`Z,C$@861M:6XO<&5R;7,O9&5L971E+G!H<#HU-PIM<V=I9"`B
M4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B57!R879N:<6A
M:V$@9&]V;VQJ96YJ82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM
M<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B3W-E8FYE(&EN
M9F]R;6%C:6IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@
M(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E!E
M=',B"FUS9W-T<B`B3&IU8FQJ96[$C6MI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<&EN:2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE
M(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3`Q"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;V=R869I:F4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4&QA=&ET
M=61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#4P"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*
M;7-G<W1R(")0<F]S:6UO+"!D82!V;F5S971E(&UE<V5C(&EN(&QE=&\N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(@IM<V=S='(@(E!R;W-I;6\L(&1A('9N97-E=&4@:6UE(&YO=F4@:V%T
M96=O<FEJ93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$P"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M(")0<F]S:6UO+"!D82!V;F5S971E('9E;&IA=F5N($E0(&YA<VQO=BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+B(*;7-G<W1R(")0<F]S:6UO+"!D82!V;F5S971E('9E
M;&IA=F5N(&1A='5M.B!P<F5V97)I=&4@Q:%T979I;&\@9&YI('8@;65S96-U
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W,S4*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E!R;W-I;6\L(&1A
M('9N97-E=&4@<')A=FEL96X@Q(UA<RXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E!R;W-I;6\L(&1A('!R:7!R
M879I=&4@<&]V>F5T96L@=&7%OF%V+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I
M9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B
M"FUS9W-T<B`B4')O<VEM;RP@9&$@<VD@:7IB97)E=&4@=7!O<F%B;FG%H6MO
M(&EM92!I;B!G97-L;RXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*(E!R;W-I;6\L('!R96)E<FET92!S;&5D9<2-
M92!B97-E9&EL;RX@Q(UE(,6^96QI=&4@=7!O<F%B;&IA=&D@=&$@<VES=&5M
M+"!S92`B"B)M;W)A=&4@<W1R:6YJ871I(',@<&]G;VII+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED
M(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@
M(E!R;W-I;2P@=FYE<VET92!I;64@;F]V92!K871E9V]R:6IE.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&IS:V$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(E!O;&ET:6MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q
M,`IM<V=I9"`B4&]L;',B"FUS9W-T<B`B06YK971E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QS:V$B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S
M='(@(D]D9&%J('8@=&\@;6%P;R`H;FD@>F%H=&5V86YO(&]D($E-05`I(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4&%D879I;F4@=B!Z861N:FEH
M("5S('5R86@Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M,0IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")0
M861A=FEN93QB<B`O/F-H86YC92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]L9&%P+G!H<#HQ,SD*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(%!R969S7VQD87`Z
M('IA:'1E=F%N96=A($Q$05`@<F%Z=&5G82!N92!N86ID96TN(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@
M(E1L86LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0IM<V=I9"`B4')E
M<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B5&QA:R!N82!M;W)S:VD@
M=FG%H6EN:3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(Y
M"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E1L86LZ("(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B4')E9&]G;&5D(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-3(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-38*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4')E:L6A
M;FIE(&UOQ;YN;W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B6F%S96)E;B!K
M;&IUQ(TB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y
M"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96TB"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B6B!O<&ES;VT@<V\@=&7%OF%V92XN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,X-0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B
M4')O:F5K=&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-S8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S4V,PIM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5&%K
M;VK%H6YJ92!B97-E9&EL;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")*879N:2!K
M;&IUQ(TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I
M=&5M(&IA=FYE9V$@:VQJ=<2-82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T
M<B`B26YF;W)M86-I:F4@:F%V;F5G82!K;&IUQ(UA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M(")*879N:2]Z87-E8FYI('!A<B!K;&IUQ(UE=B!N:2!B:6P@=7-P9<6A;F\@
M9V5N97)I<F%N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O
M(@IM<V=S='(@(E!O<G1O<FEK;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*;7-G
M<W1R(")0<F7$C6ES=&D@<W!O<F_$C6EL82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E%A=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8R"FUS9VED(")1=65R>2(*;7-G<W1R(")0;VEZ=F5D8F$B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*;7-G:60@(E%U;W1A(@IM<V=S='(@
M(DMV;W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I
M="DB"FUS9W-T<B`B4E-!(&IA=FYI(&ML:G7$C2`H)60@8FET;W8I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4U,@IM<V=I9"`B4F%D:6\@<V5L
M96-T:6]N(@IM<V=S='(@(DEZ8F5R:71E(')A9&EO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS
M9W-T<B`B1&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0V"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(D1EQ;X@>FIU
M=')A:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0W"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B1&7%OB!P;W!O;&1N92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R(").86QI=B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN(&%N
M9"!3;F]W(@IM<V=S='(@(D1EQ;X@:6X@<VYE9R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O(%-N
M;W<B"FUS9W-T<B`B1&7%OB!V('-N96<B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B4W)EQ(UA
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2
M871I;R(*;7-G<W1R(")287IM97)J92(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(D)E<FDB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I
M9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(")"97)I('-P;W)OQ(UI;&\B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B4W1E('!R97!R:<2-86YI+"!D
M82#%OF5L:71E('IB<FES871I("5S/R!)>F)R:7-A(&YI(&UO9V_$C64@<')E
M:VQI8V%T:2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92XB"FUS9W-T<B`B(@HB4W1E('!R97!R:<2-86YI+"!D82#%OF5L:71E('IB
M<FES871I('5P;W)A8FYI:V]V92!P;V1A=&ME('IA('5P;W)A8FYI:V$E<S\@
M(@HB27IB<FES82!N:2!M;V=OQ(UE('!R96ML:6-A=&DN(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*
M;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B3W-V9<6^:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.B(*;7-G<W1R(")/<W9EQ;YI(&1I;F%M:<2-;FD@;65N:2!E
M;&5M96YT;W8Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I
M9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B3W-V9<6^:2!P;W)T
M86PZ(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDT"B,L(&9U
M>GIY"FUS9VED(")2969R97-H(')A=&4Z(@IM<V=S='(@(D]S=F7%OFD@<&]R
M=&%L.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C(R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-#0*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E9V5X(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S4Q.`IM<V=I9"`B4F5L871I;VYS:&EP
M($)R;W=S97(B"FUS9W-T<B`B27-K86QN:6L@<F%Z;65R:6HB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B4&]N;W9N;R!N
M86QOQ;YI(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S@*;7-G:60@(E)E
M;6%R:W,B"FUS9W-T<B`B4')I<&]M8F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")/9&1A
M;&IE;FD@<W1R9<6^;FEK:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ(@IM<V=S='(@(D]D9&%L:F5N(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C@@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED
M(")296UO=F4B"FUS9W-T<B`B3V1S=')A;FDB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-38Q"FUS9VED(")296UO=F4@8V]L
M=6UN(@IM<V=S='(@(D]D<W1R86YI('-T;VQP96,B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T
M<B`B3V1S=')A;FD@<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P
M,0IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(D]D<W1R86YI('-H<F%N:F5N
M;R!S:W)I<'1O(&EZ('-T<F7%OFYI:V]V92!Z8<2-87-N92!M87!E(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`B3V1S=')A;FD@=7!O<F%B;FEK82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B3V1S=')A;FD@=7!O
M<F%B;FEK83H@)7,@(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HQ,S@@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$W,PIM<V=I9"`B
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B`B"FUS9W-T<B`B6F%H=&5V:2!N92!M;W)E;2!U9V]D:71I+B!6<FYJ
M96YA(&IE(&YA<&'$C6YA(&MO9&$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3`*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B3F4@;F%J9&5M('IA:'1E=F%N96=A
M('-E<G9I<V$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#4@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B6F%H=&5V86YI(%PB)7-<(B!N:2!P;V1R
M;V)N;R!O8FQI:V]V86X@=B`E<R!K;VYF:6=U<F%C:6II+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-S$V(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#4R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C@W-B!F
M<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z-#$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B6F%H=&5V86YI(%PB)7-<(B!N:2!P;V1R;V)N;R!O
M8FQI:V]V86X@=B!62%,@:V]N9FEG=7)A8VEJ:2XB"@HC.B!F<F%M97=O<FLO
M571I;"]5=&EL+G!H<#HW.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B6F%H=&5V86YI("<E<R<@;FD@<&]D<F]B;F\@;V)L:6MO=F%N+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B6F%H=&5V86YA(&1A=&]T96MA
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R
M,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHW.`IM<V=I9"`B4F5S970B"FUS9W-T
M<B`B4&]N87-T879I(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E!O;F%S=&%V:2!G
M97-L;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED
M(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E!O;F%S=&%V:71E('9A
MQ:%E(&=E<VQO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B
M4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(D]B;F]V:71E('IA9&YJ;R!P
M;VEZ=F5D8F\B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S`@861M:6XO8VUD
M<VAE;&PN<&AP.C(W(&%D;6EN+W-Q;'-H96QL+G!H<#HV-0IM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R("):861E=&MI(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED
M(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")6<FYI('-E(&YA($UOQ;YN
M;W-T:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I
M9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")0;VYO=FYO('9P:<6A
M:71E(&YO=F\@9V5S;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N
M(@IM<V=S='(@(E!O;F]V;F\@>F1R=<6^:2(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B
M4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B4&]V<FYI(&MO;F9I9W5R
M86-I:F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B5G)N:2!S92!N82!M
M;\6^;F]S=&D@=7)E:F5V86QN:6MA(&)E<V5D:6QA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8S"FUS9VED(")2:61D;&5S(@IM<V=S='(@(D5N:6=M
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.3`*;7-G:60@(E)I
M9VAT(&AE861E<B(*;7-G<W1R(")$97-N;R!O9VQA=FIE(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,X-@IM<V=I9"`B4FEG:'0@=F%L=65S(@IM
M<V=S='(@(D1E<VYE('9R961N;W-T:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B
M1G5N:V-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S
M='(@(E)O;75N:6IA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")/8G)N
M:2!Z82`Q.#`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")/8G)N:2!N
M82!L979O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(D]B<FYI(&YA
M(&1E<VYO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.0IM<V=I9"`B4G5N
M(@IM<V=S='(@(EIAQ;YE;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S:6IA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(%,O34E-12!K<FEP=&]G
M<F%F<VMI('!O9'!I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS
M9W-T<B`B4R]-24U%(&MO9&ER86YO('-P;W)OQ(UI;&\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@R"FUS9VED(")305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@3W9E<FIA
M;FIE(&YI('5S<&5L;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C@*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3('-P;W)OQ(UI
M;&\B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3D*;7-G:60@(E-13"!3:&5L
M;"(*;7-G<W1R(")344P@;'5P:6YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S4V,0IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<R(*;7-G<W1R(")344P@<W1A=F5K('IA('!O:7IV961B;R!V<F5D;F]S
M=&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4T"FUS9VED(")3
M4T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#
M0T534R(*;7-G<W1R(")54U!%2"(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I
M9"`B4U]13"!3:&5L;"(*;7-G<W1R(")344P@;'5P:6YA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,PIM<V=I9"`B4V$B
M"FUS9W-T<B`B4V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B4W9E=&$@2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED
M(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I;G0@2VET=',@
M86YD($YE=FES("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B
M"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")3
M86EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VX@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN
M8V5N="!I;B!'<F5N861I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO
M82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-
M87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G
M:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!I
M;B!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")3871E;&ET
M<VMI(&]S:W)B;W9A;&5C(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@
M07)A8FEA(@IM<V=S='(@(E-A=61S:V$@07)A8FEJ82(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,34*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M4VAR86YI(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")3
M:')A;FD@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")3:')A
M;FD@)7,@(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B
M4V%V92!/<'1I;VYS(@IM<V=S='(@(E-H<F%N:2!-;\6^;F]S=&DB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38V"FUS9VED("(B"B)3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-H
M<F%N:71E(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;R!K;W0@4$A0('-K<FEP
M=&\@;F$@>F'$C6%S;FD@;6%P:2`B"B)V8<6A96=A<W1R9<6^;FEK861I<F5C
M=&]R>2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")3:')A;FIE;F$@)7,@:V]N9FEG=7)A8VEJ82(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(E-H<F%N
M:F5N82!N87-T879I='9E;F4@<VMR:7!T82!N861G<F%D;FIE(&YA.B!<(B5S
M7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3$*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")287ID:79J
M86YA(&YE=FEH=&$@>B!G<FUE;FIE;2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-`IM<V=I9"`B4V-I96YC92(*;7-G<W1R("):;F%N;W-T(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("))
MQ:'$C6DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,V"FUS9VED
M(")396%R8V@@16YG:6YE<R(*;7-G<W1R("))<VMA;&YI:VDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0S"FUS9VED(")396QE8W0@1FEL97,B
M"FUS9W-T<B`B27IB97)I(&1A=&]T96MO(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X.0IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R("))>F)E<FD@9&%T=6TB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM
M<V=S='(@(DEZ8F5R:2!S:W5P:6YO+"!K:2!J;R#%OF5L:<6A(&1O9&%T:2XB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE
M8W0@82!N97<@;W=N97(B"FUS9W-T<B`B27IB97)I(&YO=F5G82!L87-T;FEK
M82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B
M4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(DEZ8F5R:2!S=')EQ;YN:6LB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T
M(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B27IB97)I('5P;W)A8FYI:V$L(&MI
M(&=A(,6^96QIQ:$@9&]D871I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R
M("))>F)E<FD@=G-E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS
M,0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@
M(DEZ8F5R:2!P;W!O;&X@9&%T=6TB"@HC.B!S97)V:6-E<R]E9&ET;W(O>&EN
M:&$O<&QU9VEN<R]!;G-E;$EM86=E+VEN<V5R=%]I;6%G92YP:'`Z,3,R"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86X@:6UA9V4B"FUS9W-T<B`B27IB97)I
M(&1A='5M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("))>F)E
M<FD@<')E9&UE="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-SD*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(D]D:VQJ
M=6MA:B!V<V4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B):;F%K92P@:VD@
M:FEH('!O=')E8G5J971E(&EZ8F5R:71E(&EZ(&]K=FER:F5V('-P;V1A:BX@
M3F%T;R!J:6@@;&%H:V\@(@HB:V]P:7)A=&4@:6X@<')I;&5P:71E('8O:7H@
M8F5S961I;&$N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(D1O;&_$
MC6D@:V]NQ(UN:2!D871U;3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B
M27IB97)I(&]B;&EK;R!D871U;6$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,@IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(DEZ8F5R:71E(&ED96YT
M:71E=&\L(&MA=&5R;R#%OF5L:71E('-P<F5M96YI=&DZ(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z(@IM<V=S='(@(D1O;&_$C6D@:V]NQ(UN;R!U<F\Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(DEZ8F5R:2!O8FQI:V\@=7)E.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("))>F)E<FD@9'9E('5J96UA
M:F_$C6D@<V4@<&]L:FDZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q
M,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("))
M>F)E<FET92!V8<6A92!B87)V;F\@:V]M8FEN86-I:F\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z(@IM<V=S='(@(DEZ8F5R:71E(&IE>FEK.B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Q"FUS9VED(")396YD(%!R
M;V)L96T@4F5P;W)T(@IM<V=S='(@(E!OQ:%L:FD@<&]R;\2-:6QO(&\@;F%P
M86MA:"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R(")0;\6A;&II(%--4R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A
M;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(X"FUS9VED(")396YS;W(Z
M("(*;7-G<W1R(")396YZ;W(Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")3
M97!R96UB97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-R
M8FEJ82!I;B#$C7)N82!G;W)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B
M4V5R:6IS:V$@Q:%T979I;&MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U-`IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B4W1R9<6^;FEK;W8@9&%T=6T@:F4@;F%P8<2-
M96X@86QI(&YI(&YA(')A>G!O;&%G;RXB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C8*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B061M:6YI<W1R
M86-I:F$@<V5J92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*
M;7-G<W1R("))1"!S96IE(&IE('!O=&5K;&$N(@H*(SH@;&EB+V%P:2YP:'`Z
M,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")396IE(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8P,@IM<V=I9"`B4V5T(@IM<V=S='(@(DYA
M;65S=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E
M="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB3F%S=&%V:2!O
M<&-I:F\L(&1A('8@<')I;65R=2P@9&$@<&]Z86)I=&4@=F'%H64@9V5S;&\L
M(&QA:&MO('!O;F%S=&%V:71E(&QE+2(*(G1O+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G
M<W1R("(B"B)5<F5D:71E(&]D9&%L:F5N92!S=')EQ;YN:6ME(&YA(&MA=&5R
M92#%OF5L:71E(&1O<W1O<&%T:2!Z('9AQ:%E9V$@<&]R=&%L82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G
M<W1R(").87-T879I=&4@<')I=GIE="!J97II:R!I;B!N87-T879I='9E(&1A
M='5M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*
M(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS
M+B(*;7-G<W1R(")5<F5D:2!Z8<2-971N92!B87)V;F4@<VAE;64L(&%P;&EK
M86-I:F4L(&]S=F7%OFET=F4@<W1R86YI+BXN(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`B3F%M97-T:2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,U"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(DYA
M<W1A=FD@<VMR:7!T;R!Z82!O<W9EQ;YI=&5V(&MO="!R87IP;VQOQ;YL:FEV
M;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@P"FUS9VED
M(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z("(*;7-G<W1R(")-;\6^;FEH(&IE('9EQ(T@;&]K86-I:B!S('!A<F%M
M971R;VTZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G
M<W1R(")396K%H65L:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,3D*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(DYA:W5P;W9A;FIE(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(E-H;W)T
M(%-U;6UA<GDB"FUS9W-T<B`B2W)A=&5K('!O=GIE=&5K(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(DYA=&%V:6T@
M=&EP:V%R<VME(&)L:<6^;FEC92!N82!P;W9E>F%V93\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G
M<W1R(")0;VMAQ;YI(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-`IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"B)0;VMAQ;YI(')A>FQI:V4@;65D('-E9&%J('-H<F%N
M:F5N;R!I;B!N86IN;W9E:L6A;R!G96YE<FER86YO(&MO;F9I9W5R86-I:F\N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-0IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")0<FEK
M8<6^:2!D871U;2!Z861N:F4@<')I:F%V92!P;R!V<W1O<'4_(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W.`IM<V=I9"`B4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")0<FEK8<6^:2!O<&-I:F4@>F$@
M;V)D<L6^871I(&]R:6=I;F%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S`X,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B4&]K8<6^:2!T
M:7-T96=A+"!K:2!S<')E:F5M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,C`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B
M"FUS9W-T<B`B4')I:V'%OFD@;65N:6IS:V\@=G)S=&EC;R!D96QO=F%N:F$@
M=&%B96QE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*
M;7-G<W1R(")0<FEK8<6^96T@)7,@;65N:2!N82!L979I('-T<F%N:3\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S<V"FUS9VED(")3:&]W('5P
M;&]A9"(*;7-G<W1R(")$;V1A:B!N86QA9V%N:F4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R(*
M;7-G<W1R(")0;&]H92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(EIJ
M=71R86H@<&QO:&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(E!O<&]L
M9&YE('!L;VAE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S
M='(@(E8@8FQIQ;YI;FD@<&QO:&4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S
M='(@(E-K<L2-:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B3F%J<')E:B!S:W+$C6D@86QI
M('!R96UA:VYI('-O<V5D;FIE(&)E;&7%OFME+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8W"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(E!R:6IA=FD@<V4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S
M='(@(E!O9'!I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L
M9V]R:71M:<2-96X@<&]D<&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN
M9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`U"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(T-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,#`*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,Y,@IM<V=I9"`B4VEZ92(*;7-G<W1R(")696QI:V]S="(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R
M"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(E!R97-K;\2-:2!V
M>F1RQ;YE=F%N:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*
M;7-G<W1R(")3;&]V8<6A:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M96YI82(*;7-G<W1R(")3;&]V96YI:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R(")3
M;F5G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3<*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(E-N9<6^;F$@<&QO:&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM
M<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N9<6^;F4@<&QO:&4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I
M9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(EIJ=71R86H@<VYEQ;YN
M92!P;&]H92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")0;W!O
M;&1N92!S;F7%OFYE('!L;VAE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3`*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")6:<6A:6YA('-N96=A
M.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")3;F]W(&5Q
M=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")3;F5G=2!E:W9I=F%L96YT
M;F$@:V]L:<2-:6YA('9O9&4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L
M;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-A;&]M;VYO=FD@;W1O:VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:6IA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")3;VYG<R`F(%!O
M96US(@IM<V=S='(@(E!E<VUI(&EN('!O97II:F4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3DV"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO
M;B(*;7-G<W1R(")6<G-T82!U<F5J96YE9V$@:7IB;W)A(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM
M<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B3F%S;&]V('9I<F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B2G7%
MOFYA($%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED
M(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B2G7%OFYO
M+65V<F]P<VMI("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B
M"FUS9W-T<B`B2G7%OFYA($=E;W)G:6$@:6X@;W1O:VD@2G7%OFYI(%-A;F1W
M:6-H(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")*
M=<6^;F$@<&]L;V)L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@R
M-`IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(E!R97-L961N:6-A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(L6@<&%N:6IA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-PIM<V=I9"`B4W!A;2(*;7-G<W1R
M(").97IAQ;YE;&5N82!P;\6A=&$B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@
M(E9H;V0@>F$@<&]S96)N92!Z;F%K92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-@IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(L6@<&]R=&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("+%H')I($QA;FMA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Q(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#8*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD
M87)D96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C<*;7-G:60@(E-T
M87(@5')E:R(*;7-G<W1R("):=F5Z9&YE('-T97IE(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@W-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,#<Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(EIAQ(UE=&YO(&QE=&\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I
M9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B1'+%OF%V82!A;&D@<')O
M=FEN8V$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ
M,`IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,P.#4*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM
M<V=S='(@(D]B;&EK82!P;VUN:6QN:6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(DYA<VQO=B!U;&EC92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-#(*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(E-P:7-E:R!B
M97-E9&YI:"!Z=F5Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q
M,0IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T
M<B`B/S\_/S\_/S\_/V1O;65N82!I>B!N87-L;W9A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-`IM<V=I9"`B4W4B"FUS
M9W-T<B`B3F4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(DYE(&YA:F1E;2!P;V1M87!E(%PB)7-<(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-CD*;7-G:60@(E-U
M8FIE8W0B"FUS9W-T<B`B6F%D979A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S0Q(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q
M-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E!R961L;\6^:2(*"B,Z('-I9VYU
M<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T
M(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V
M960N(@IM<V=S='(@(B(*(E-P<F5J96QI('-M;R!Z86AT979E:R!Z82!V<&ES
M(%PB)7-<(BX@3F4@;6]R971E('-E('!R:6IA=FET:2!D;VML97(@=F'%H6$@
M(@HB>F%H=&5V96L@;F4@<&\@<&]T<FIE;BXB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3`S"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B57-P96@B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(@IM<V=S='(@(EPB)7-<(B!S96T@=7-P9<6A;F\@9&]D86P@:R!S
M:7-T96UU+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@<V5M('5S<&7%
MH6YO(&]D<W1R86YI;"!I>B!S:7-T96UA+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-SD@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@
M(EPB)7-<(B!S96T@=7-P9<6A;F\@:7IB<FES86PN(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B!S96T@=7-P9<6A;F\@;V1S=')A;FEL(&EZ('-I<W1E;6$N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB
M"FUS9W-T<B`B(@HB57-P9<6A;F\@;V)R;FIE;F$@:V]N9FEG=7)A8VEJ82X@
MQ(UE(,6^96QIQ:$@=FED971I('-P<F5M96UB92P@<&]N;W9N;R!N86QOQ;YI
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")5<W!EQ:%N;R!S:')A;FIE;F$@
M=F%R;F]S=&YA(&MO<&EJ82!K;VYF:6=U<F%C:6IE+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R(")5<W!EQ:%N;R!S:')A;FIE;F$@=F%R;F]S=&YA(&MO<&EJ
M82!K;V9I9W5R86-I:F4@9&%T;W1E:V4@)7,N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,38W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A
M=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@:F4@8FEL('5S<&7%H6YO('!O
M<V]D;V)L:F5N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!S96T@=7-P9<6A;F\@
M>F%P:7-A;"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R
M(")3=61A;B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B
M4W5N(%)I<V4B"FUS9W-T<B`B4V]NQ(UN:2!V>FAO9"(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")3;V[$
MC6YI('IA:&]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-O;L2-;F\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$P"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(E-O;L2-;FD@=GIH;V0B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I
M<V4O4W5N<V5T(@IM<V=S='(@(E-O;L2-;FD@=GIH;V0O>F%H;V0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`Y"FUS9VED(")3=6YR:7-E
M.B`B"FUS9W-T<B`B4V]NQ(UN:2!V>FAO9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3,*;7-G:60@(E-U;G-E="(*;7-G<W1R(")3;V[$
MC6YI('IA:&]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,@IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B4V]NQ(UN:2!Z86AO9#HB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDT"FUS9VED(")3=7!P;W)T
M(@IM<V=S='(@(E!O9'!O<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I
M;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4')I
M:6UE:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@
M36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@:6X@2F%N($UA>65N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-V87II(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(L6@=F5D<VMA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(L6@=FEC
M82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3
M>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(DEZ8G)I<V%N('-I;FMR;VYI>F%C
M:6IS:VD@9&YE=FYI:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*
M;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3:6YK<F]N:7IA8VEJ82(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X
M(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(").87!A:V$@=B!S:6YT
M86MS:2!I<VMA;&YI:"!P;V=O:F5V(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4VER:6IS:V$@87)A8G-K
M82!R97!U8FQI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")'<FUE;FIE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G
M:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(DYE=FEH=&$@>B!G<FUE
M;FIE;2!I;B!V971R;VTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B3F5V:6AT
M82!Z(&=R;65N:F5M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM
M<V=S='(@(EIJ=71R86H@<&QO:&4B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")44U8@9&%T
M;W1E:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B3F%S=&%V:71E=B!T
M86)E;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS
M9W-T<B`B5&%J=F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS
M9W-T<B`B5&%I=V%N+"!D9<6^96QA($MI=&%J<VME(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4863%OFEK:7-T86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(E1A;GIA;FEJ82P@6F1R=<6^96YA(')E<'5B;&EK82(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,R(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,3`W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.38*;7-G:60@(E1A<VMS(@IM<V=S='(@(D]P<F%V:6QA(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N
M92!.=6UB97(B"FUS9W-T<B`B5&5L969O;G-K82#%H71E=FEL:V$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B5&5M<"!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@=B!Z861N:FD@=7)I.B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(V"FUS9VED(")496UP97)A='5R92(*
M;7-G<W1R(")496UP97)A='5R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3<*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M
M<&5R871U<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")496UP97)A='5R83QB<B`O
M/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB('9Z;W)C
M82!N92!N86ID96TN(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-C@*;7-G
M:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E5R96IE=F%L
M;FEK(,6A86)L;VXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(P
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,V,30*;7-G:60@(E1E>'0B"FUS
M9W-T<B`B0F5S961I;&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y
M"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B4V%M;R!"97-E9&EL;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G
M:60@(E1H(@IM<V=S='(@(E1O(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.30*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A:G-K82(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0R"FUS9VED(")4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/=F5R:F5N:F4@
M;FD@=7-P96QO(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z
M-C,*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B6F=O9&]V:6YA(&IE(&EZ:VQO<&QJ96YA+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(@:6YT96=R86-I:F$@
M;F4@<&]D<&ER82!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T
M(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")0;W-O9&]B;&IE;B!D871O=&5K
M92!N92!M;W)E;2!S:')A;FET:2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B5GID<L6^979A;FIE.B!R
M87IR960@;FD@8FEL('5S<&7%H6YO(&YA;&_%OF5N+B(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")/:VYO($UO
MQ;YN;W-T:2!J92!B:6QO('IA<')T;RX@6F%K;&IU975J96TN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")4
M:&4@4U-(,B!014-,(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")/=F5R:F5N:F4@;FD@=7-P96QO(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B061M
M:6YI<W1R871O<B!M;W)A(&YA:G!R96H@;F%S=&%V:71I('-I<W1E;2!Z82!P
M<F%V:6-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(DMO;G1A:W1N:2!)1"!N
M:2!B:6P@<&]S<F5D;W9A;B!A;&D@;FD@8FEL(&YA:F1E=B!V(&)A>FD@<&]D
M871K;W8N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")3=&EK(&IE(&)I
M;"!U<W!EQ:%N;R!D;V1A;B!K('9AQ:%I;2!N87-L;W9O;2X@2VQI:VYI=&4@
M<W!O9&%J('IA(&]G;&5D.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(E!O=')E8G5J96T@;&_$C65N;R!01U`@<&]D
M<&ES86YO(&)E;&7%OFYI8V\L(&1A('!R979I<FEM('!O9'!I<V%N;R!S<&]R
M;\2-:6QO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO
M="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(DE$('-E>FYA
M;6$@;FD@8FEL('!O<W)E9&]V82!A;&D@;FD@8FEL(&YA:F1E;B!V(&)A>FD@
M<&]D871K;W8N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B5&\@9&5J86YJ92!N:6UA('!O
M9'!O<F4N(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5M86EL(&%D9')E<W,@
M)7,@:&%S(&)E96X@861D960@=&\@>6]U<B!I9&5N=&ET:65S+B!9;W4@8V%N
M(&-L;W-E('1H:7,@(@HB=VEN9&]W(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M(@IM<V=S='(@(DMO9&ER86YA('9S96)I;F$@>F%H=&5V82!V87)N;R!I;G1E
M<FYE=&YO('!O=F5Z879O+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RXB"FUS9W-T<B`B)7,@9&%T;W1E:V$@8FD@;6]R86QA('9S96)O
M=F%T:2`E<R!N87-T879I='9R+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$T"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O
M;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B5S(&1A=&]T96MA(&)I(&UO<F%L
M82!V<V5B;W9A=&D@)7,@;F%S=&%V:71V92X@(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@
M9&%T82XB"FUS9W-T<B`B1&%T;W1E:V$@;F4@=G-E8G5J92!N;V)E;FEH('!O
M9&%T:V]V+B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R(")3=')EQ;YN:6L@7"(E<UPB(&IE(&)I;"!I>F)R:7-A
M;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G
M:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R(")-
M97-T;R!';G501R!P<F]G<F%M82!M;W)A(&)I=&D@<&]S<F5D;W9A;F\@<F%Z
M<F5D=2!#<GEP=%]P9W`N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN
M<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S
M96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@
M9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@
M(B(*(E-P;W)OQ(UI;&\@<&]S;&%N;R!D;F4@)7,@>F$@)7,@>B!N87-L;W9O
M;2!<(B5S7"(@:F4@8FEL('!R96)R86XN7&XB"B).:2!Z86=O=&]V:6QA(&1A
M(&IE(&)I;&\@9&5J86YS:V\@<')E8G)A;F\@86QI(')A>G5M;&IE;F\N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q-0IM<V=I9"`B5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM
M<V=S='(@(DEM92!Z82!P;W9E>F%V;R!N82!S=')A;B!Z82!S97-T879L:F%N
M:F4@<W!O<F_$C6EL82XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3`V"FUS
M9VED(")4:&4@;F5W(&9R;VT@861D<F5S<R!C86XG="!B92!V97)I9FEE9"P@
M=')Y(&%G86EN(&QA=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD
M<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(E1A('9R961N;W-T(&UO<F$@
M8FET:2#%H71E=FEL:V$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R(")0;W1R96)U:F5M(&]P96YS<VP@;6]D=6P@>F$@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!R87IR960N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H
M<#HR.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@
M7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@
M(B(*(DYA<W1A=FEE;F4@9&%T;W1E:V4@7"(E<UPB(&YE(&UO<F4@<VAR86YI
M=&DL(&ME<B!N:F5N:2!P;V1A=&MI("(*(G!R97-E9V%J;VYA:G9EQ(UJ:2!D
M;W9O;&IE;B!O8G-E9RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A
M<"YP:'`Z,S`U(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C$T-0IM
M<V=I9"`B(@HB5&AE('!R969E<F5N8V5S(&)A8VME;F0@:7,@8W5R<F5N=&QY
M('5N879A:6QA8FQE(&%N9"!Y;W5R('!R969E<F5N8V5S(&AA=F4@(@HB;F]T
M(&)E96X@;&]A9&5D+B!9;W4@;6%Y(&-O;G1I;G5E('1O('5S92!T:&4@<WES
M=&5M('=I=&@@9&5F875L="!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+B(*;7-G<W1R(")0<F]G<F%M82P@:VD@;V1P:7)A('!O9&%T:V4@=&4@=G)S
M=&4@*"5S*2!N92!N86ID96T@=B!S:7-T96UU+B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")287IM
M96II=&5V(&UO<F$@8FET:2!S97-T879L:F5N82!L92!I>B!E;F5G82!Z;F%K
M82XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-SD*;7-G:60@
M(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB
M"FUS9W-T<B`B3&_$C6ET978@;6]R82!B:71I('-E<W1A=FQJ96YA(&QE(&EZ
M(&5N96=A('IN86MA+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-T<F7%OFYI:R!<(B5S7"(@:F4@
M8FEL(&EZ8G)I<V%N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R(")3=')EQ;YN:6L@7"(E<UPB(&IE('-H
M<F%N:F5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+B(*;7-G<W1R("):86AT979E:R!Z82!P<FEJ879O(&IE
M(&)I;"!O9'-T<F%N:F5N+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(DEZ8G)A;F$@=G)S=&EC82`H)60I(&YE(&]B<W1A:F$N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR,#(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(EIAQ(UA<VYA(&1A=&]T96MA(&YE(&]B<W1A:F$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S4X.0IM<V=I9"`B5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+B(*;7-G<W1R(")6;F7%H65N;R!B97-E9&EL;R!N92!U<W1R97IA
M(&)E<V5D:6QO(&YA(&5K<F%N=2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I
M;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")0;W-O9&]B;&IE;FD@
M<&]D871K:2!S;R!B:6QI(&EZ9W5B;&IE;FD@<')I('!R96K%H6YJ96T@:V]R
M86MU+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A
M;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")0;W-O9&]B
M;&IE;B!D871O=&5K92!N92!M;W)E;2!S:')A;FET:2XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-30@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(G=E871H97(N8V]M(&YI(&YA('9O;&IO
M+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DYE(&YA:F1E;2!M87!E(&]B;&EK(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0T-"!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.C0T.`IM<V=I9"`B5&AE<F4@87)E(&YO(&5M
M86EL(&%D9')E<W-E<R!T;R!C;VYF:7)M+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").:2!M;\6^;F]S=&D@
M;F$@<F%Z<&]L86=O+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C,T-`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D1E;&D@;F4@;6]R96IO
M(&)I=&D@<')I:V%Z86YI+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@
M)7,N(@IM<V=S='(@(B(*(E8@<&]L:G4@:F4@<')E=F7$C2!Z;F%K;W8N(%9T
M:7!K86QI('-T92`E<R!Z;F%K;W8N(%9T:7!K871I(&UO<F%T92!M86YJ(&MO
M="`E(@HB<R!Z;F%K;W8N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B
M4')IQ:%L;R!J92!D;R!N87!A:V4@<')I(&1O9&%J86YJ=2`G)7,G(&L@<VES
M=&5M=3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")0<FG%
MH6QO(&IE(&1O(&YA<&%K92!P<FD@;V1S=')A;FIA;FIU("<E<R<@:7H@<VES
M=&5M82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')IQ:%L;R!J92!D;R!N87!A:V4@
M<')I(&]D<W1R86YJ86YJ=2`G)7,G(&EZ('-I<W1E;6$N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34X"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")0<FG%H6QO
M(&IE(&1O(&YA<&%K92!P<FD@<&]S;V1A8FQJ86YJ=2`G)7,G.B`E<R`B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")0<FD@;F%L
M86=A;FIU(&1A=&]T96ME(&IE('!R:<6A;&\@9&\@;F%P86ME+B!.;V)E9&5N
M("5S(&YI(&)I;"!N86QOQ;YE;BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HY,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2XB"FUS9W-T<B`B(@HB4')I(&YA;&%G86YJ=2!D871O=&5K92!J
M92!P<FG%H6QO(&1O(&YA<&%K92X@)7,@>F%S961A('9EQ(T@<')O<W1O<F$L
M(&MO="!J92`B"B)D;W9O;&IE;F\N($1O=F]L:F5N;R!J92`H)60@8GET;W8I
M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R(")0<FD@;F%L86=A;FIU(&1A=&]T96ME(&IE('!R
M:<6A;&\@9&\@;F%P86ME+B`E<R!J92!L92!D96QN;R!N86QOQ;YE;F$N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B5B!S<&]R;V5I;'4@<V4@:F4@<&]J879I;&$@
M;F5Z;F%N82!N87!A:V$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")0<FD@<W!R96IE;6%N
M:G4@:V]N=&%K=&$@:F4@<')IQ:%L;R!D;R!N87!A:V4N(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M4')I('-P<F5J96UA;FIU(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G
M<W1R("(B"B)+;VYF:6=U<F%C:6IS:VD@;V)R87IE8R!V<V5B=6IE(&YA<&%K
M;RX@5F5R:F5T;F\@<W1E('!O>F%B:6QI(&YA<W1A=FET:2`B"B)Z86AT979A
M;F\@<&]L:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)0<FG%
MH6QO(&IE(&1O(&YA<&%K92!P<FD@<')O8V5S:7)A;FIU(&EZ8G)A;F5G82!I
M;65N:6MA+B!0<F]S:6UO('!O<VMU<VET92`B"B)Z;F]V86YE:V]L:6MO(&MA
M<VYE:F4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(E!R:2!S<')E:F5M86YJ=2!K;VYT86MT82!J92!P
M<FG%H6QO(&1O(&YA<&%K92X@4')O<VEM;R!P;W-K=7-I=&4@>FYO=F$@(@HB
M:V%S;F5J92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@HB4')I('-P<F5J96UA;FIU(&MO;G1A:W1A(&IE
M('!R:<6A;&\@9&\@;F%P86ME+B!0<F]S:6UO('!O<VMU<VET92!K87-N96IE
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T
M.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B5F'%H2!B<G-K86QN:6L@;F4@<&]D
M<&ER82!T92!P;W1E>F4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B5&\@;FD@=F5L:F%V
M96X@4D%2(&%R:&EV+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(E1O(&YI('9E;&IA=FYA('II
M<"!D871O=&5K82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-#$T
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`BQ(+B@)K%H'1E=FEL:V$@:V%R=&EC92!N:2!V
M96QJ879N82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(D=O;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA;FIE
M('-P;W)OQ(UI;"!P<F5K;R!O<&5R871E<FIA($-L:6-K871E;&PN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R(")';VYI;&YI:R!O;6]G;\2-
M92!P;\6A:6QJ86YJ92!S<&]R;\2-:6P@<')E:V\@;W!E<F%T97)J82!724XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R(")';VYI;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S<&]R;\2-:6P@
M<')E:V\@;W!E<F%T97)J82!S;7,R96UA:6PN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!3
M3510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N
M;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@
M86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN(@IM<V=S='(@(B(*(D=O;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA
M;FIE('-P;W)OQ(UI;"!P<F5K;R!I=&%L:F%N<VME9V$@;W!E<F%T97)J82!6
M;V1O869O;F4N(@HB6F$@<&_%H6EL:F%N:F4@;6]R971E(&EM971I(')E9VES
M=')I<F%N:2!N82!H='1P.B\O=W=W+C$Y,"YI="(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$R-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3DQ(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C4*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-S`@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(T-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,CDS(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,3<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,V-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,#D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-S,X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C4*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS-#`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,U.#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z-#`Y,@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HT,3`P"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*
M;7-G<W1R(")0;W1R96)U:F5M('1O('!O;&IE+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-S0*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B5&\@<&]L:F4@;&%H:V\@=G-E
M8G5J92!L92!C96QA(,6A=&5V:6QA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(W,#0*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(E1O('!O;&IE(&QA
M:&MO('9S96)U:F4@;&4@Q:%T979I;&$@:6X@<W1O;'!E8RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`S"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")4;R!P;VQJ
M92!L86AK;R!V<V5B=6IE(&QE(,6A=&5V:6QA+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,S(*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM
M<V=S='(@(E!O;&IE(&UO<F$@=G-E8F]V871I('-E>FYA;2#%H71E=FEL+"!L
M;\2-96YI:"!Z('9E:FEC;R!A;&D@<')E<VQE9&MO;2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY.3@*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B5&$@=G)E9&YO<W0@;6]R82!B
M:71I(,6A=&5V:6QK82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3`V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G
M(S$R,S1A9B<N(@IM<V=S='(@(B(*(E1O('!O;&IE(&UO<F$@=G-E8F]V871I
M(&)A<G9N;R!K;V1O('8@4D="($AE>"!F;W)M871U+"!N82!P<FEM97(@)R,Q
M,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4W,0IM<V=I
M9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G
M<W1R(")482!O8FQI:V$@:F4@8FEL82#%OF4@;V)D96QA;F$N(@H*(SH@=&5M
M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!I<R`E<RXB"FUS9W-T<B`B5&\@:F4@)7,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*(E1O(&IE('!O9&%T96L@<VMU<&EN<VMA('5P<F%V
M;&IA;FIE($MO;&%B+B!:82!P<F5G;&5D('1E9V$@<&]D871K82`B"B)P;W1R
M96)U:F5T97!R96=L961L;W9A;&YI:RP@:VD@<&]D<&ER82!N8<2-:6X@>F%P
M:7-A($MO;&%B($=R;W5P=V%R92X@6F$@(@HB<V5Z;F%M(&]D:F5M86QC979K
M:2!T;R!P;V1P:7)A:F\@;V)IQ:'$C6ET92`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B4W!O<F_$C6EL
M;R!J92!B:6QO(&YA<&ES86YO('8@:V]D;FD@=&%B96QI(&1R=6=AQ(UN92!O
M9"!V8<6A92`H)7,I+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92XB"FUS9W-T<B`B5&\@Q:%T979I;&\@;6]R82!B:71I('9S86H@96YA+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N(@IM<V=S='(@(E1A('-T<F7%OFYI:R!N92!M;W)E(&]D<')E
M=&D@>FEP(&EN(&=Z:7`@9&%T;W1E:RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$W.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@
M8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")3:7-T96T@:F4@=')E
M;G5T;F\@;F5A:VET:79E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+B(*;7-G<W1R(")482!V<F5D;F]S="!M;W)A(&)I=&D@Q:%T979I;&MA+B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@
M(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<B"FUS9W-T<B`B5&\@;VMN;R!M;W)A=&4@<&]G;F%T:2!Z(&]K;F$@
M36_%OFYO<W1I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(D)L:7-K(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,`IM<V=I9"`B5&EC:V5T<R(*
M;7-G<W1R(")0<FEJ879E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C<Q,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I
M;64B"FUS9W-T<B`BQ(UA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#(*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B4VQE9&YJ92#$
MC6%S82(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,@IM<V=I9"`B5&EM92!F
M;W)M870B"FUS9W-T<B`B3V)L:6MA(,2-87-A(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T
M<B`B27IB:7)A(&5A<V$N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M
M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`B3F%S;&]V(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,0IM<V=I9"`B5&\B"FUS9W-T<B`B
M6F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*
M(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)EQ(T@Q;YE;&ET92!I>F)R
M871I('9EQ(T@<')E9&UE=&]V+"!P<FET:7-N:71E($-O;G1R;VP@*%!#*2!A
M;&D@0V]M;6%N9"`H36%C*2`B"B)T:7!K;RP@;65D=&5M(&MO(&YA;FIE(&ML
M:6MA=&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,PIM
M<V=I9"`B5&]D87DB"FUS9W-T<B`B9&%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&]K96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P-0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B2V]M
M;W)I("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O
M;F=A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K;VQA8BYP:'`Z,3`U"FUS
M9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@
M;6EN=71E<RXB"FUS9W-T<B`B4')E=F7$C2!N975S<&5L:6@@<&]V97IA=B!V
M('IA9&YJ:6@@;6EN=71A:"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C@*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")/<F=A;FEZ86-I:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(E1R:6YI9&%D(&EN(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,#,*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B
M1&$@86QI(&YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.0IM<V=I9"`B5'4B"FUS9W-T<B`BQ(QE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI>FEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)E:6IA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(E1U<L6A:VD@*$E33RTX.#4Y+3DI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI
M<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<R(*;7-G<W1R(")4=7+%H6MI(&EN($-A:6-O<R!O=&]K:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@
M8VAO:6-E.B`B"FUS9W-T<B`B5G1I<&MA:G1E('9AQ:%O(&EZ8FER;SH@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B52Y6
M+B!I;F1E>#H@(@IM<V=S='(@(E4N5BX@:6YD96MS.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I
M9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M(@IM<V=S='(@(E523"!V8<6A92!S:W)I<'1E('IA('!O<F_$C6%N:F4@<W1A
M='5S82!D;W-T879E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM
M<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B
M"FUS9W-T<B`B56MR86II;F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT-3$*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3FEM86T@9&]S=&]P82!D;R!61E,@:6UE;FEK82XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y-B!F<F%M97=O<FLO5D93
M+U9&4R]S<V@R+G!H<#HS.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(DYE(&UO<F5M('-P<F5M96YI=&D@<')A=FEC92!Z82!61E,@9&%T
M;W1E:V\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0R-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#@P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D1O=F]L:F5N:F$@>F$@5D93("5S
M+R5S(&YE(&UO<F5M('-P<F5M96YI=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW.38@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z.#$Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M(@IM<V=S='(@(DYE(&UO<F5M('-P<F5M96YI=&D@;F$@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<@9G)A;65W;W)K+U9&4R]61E,O
M<W-H,BYP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(").92!M;W)E;2!S
M<')E;65N:71I(&YA(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HW,S,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#<U"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HY,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T
M;W1E:V4@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M-C$*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R
M(").92!M;W)E;2!S92!P;W9E>F%T:2!S(%-33"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-C0@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C8Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,S8@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(T,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C0Y"FUS9VED(")5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1A=&]T96ME(&YE(&UO<F5M
M(&MO<&ER871I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<S
M(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C,V-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R(").92!M;W)E;2!U<W1A=G)I=&D@:6UE;FEK82!<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,SDS(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(Y-@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@:6UE;FEK82!N92!M;W)E;2!U<W1A
M=G)I=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B5D93
M(&1A=&]T96ME(&YE(&UO<F5M('5S='9A<FET:2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").92!M
M<F]E;2!U<W1V87)I=&D@:6UE;FEK82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S`T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&%T;W1E:V4@;F4@;6]R
M96T@=7-T=F%R:71I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G
M>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB
M"FUS9W-T<B`B4&]D871K;W8@;F4@;6]R96T@<W!R;W-T:71I+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S`S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C(Y
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DYE(&UO
M<F5M(&EZ8G)I<V%T:2`E<RP@:6UE;FEK(&YI('!R87IE;BXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<W(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@)R5S)SH@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S<P(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A
M=&D@)7,L(&EM96YI:R!N:2!P<F%Z96XN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C0P-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-#$P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!I
M;65N:6MA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,W-B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,T"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS-#<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,U-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#`R
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!I;65N:6MA+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#4U(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#8W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T
M:2!61E,@:6UE;FEK83H@)7,@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR,3(@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z,C$Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@9&%T;W1E:V4N7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T,B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Q-`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#0Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HT-#D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4N(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!61E,@9&%T
M;W1E:V4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I(&1A=&]T96ME
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!61E,Z
M("5S("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(U"FUS9VED
M(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G
M<W1R(").92!M;W)E;2!D;VQOQ(UI=&D@<V5D86YJ96=A(&EM96YI:V$N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@
M(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T
M<B`B3F4@;6]R96T@:7IP:7-A=&D@<&]T<FIE;FEH('!O9')O8FYO<W1I+B(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R(").92!M;W)E;2!S<')E;65N:71I(&YA("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(R,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,C@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y
M,"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DU"FUS9VED(")5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B3F4@;6]R96T@<')E
M;6%K;FET:2!61E,@9&%T;W1E:V4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T,2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.CDX"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.CDW
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@;V1P<F5T:2!D871O=&5K95PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,38@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3F4@;6]R96T@;V1P
M<F5T:2!61E,@9&%T;W1E:V4@;F%M96YJ96YE('!I<V%N:G4N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#$@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z.#8*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,30P
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E
M=&D@5D93(&1A=&]T96ME+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92XB"FUS9W-T<B`B3F4@;6]R96T@;V1P<F5T:2!Z9V_%H<2-
M96YE9V$@87)H:79A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,#@*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A
M:6QE9"DN(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T
M;W1E:V4@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDS.0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I
M;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V
M871I(%9&4R!D871O=&5K92`E<R\E<RXB"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N
M86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N
M;W9A=&D@5D93(&1A=&]T96ME+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C<Q-`IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@
M9&ER96-T;W)Y+B(*;7-G<W1R(").92!M;W)E;2!P<F5B<F%T:2!61E,@;W-N
M;W9N96=A(&EM96YI:V$N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*
M;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@)7,@=B`E<SH@;6%P82#%
MOF4@;W-T86IA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,T-0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&EM96YI:V$N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!I;65N:6MA.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,U,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<V@R+G!H<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M('!R96EM
M96YO=F%T:2!61E,@9&%T;W1E:V4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8U-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T
M:2!61E,@9&%T;W1E:V4@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS-C$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8T(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,U.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92XB"FUS9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!D871O
M=&5K92XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R(").92!M;W)E;2!S<')E;65N:71I(&YA("5S+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@
M(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S
M='(@(DYE(&UO<F5M('!R979E<W1I('1E9V$@5V]R9&]V96=A(&1O:W5M96YT
M82XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$X,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P
M9&%T92!F;W(@)7,B"FUS9W-T<B`B3F4@;6]R96T@<W!R;\6^:71I('!R;W-T
M;R]Z87-E9&5N;R!P;W-O9&]B:71E('IA("5S(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-3<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z,30Y(&9R86UE=V]R
M:R]61E,O5D93+W-S:#(N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").92!M
M;W)E;2!N87!I<V%T:2!61E,@9&%T;W1E:V4@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$X.0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F4@;6]R
M96T@;F%P:7-A=&D@5D93('!O9&%T:V]V;FEH(&1A=&]T96LN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S(P(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(@IM<V=S='(@(DYE(&UO<F5M(&YA<&ES871I(%9&4R!P;V1A=&MO=FYI
M:"!D871O=&5K+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,30*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"XB"FUS9W-T<B`B3F4@;6]R96T@;F%P:7-A=&D@5D93(&1A=&]T
M96ME+"!K=F]T82!B;R!P<F5S9<6^96YA+B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")287IV
M96QJ879I('-P<F5M96UB92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(DYE<')IQ(UA:V]V
M86X@;V1G;W9O<B!S('-T<F7%OFYI:V$@=B!P;W9E>F]V86YJ=3HB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(").97!R
M:<2-86MO=F%N(&YE<')IQ(UA:V]V86X@;V1G;W9O<B!S=')EQ;YN:6MA('IA
M.B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYE:7IP;VQN:F5N;R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A5
M5$8M."DB"FUS9W-T<B`B56YI:V]D("A55$8M."DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B6F1R=<6^96YI
M(&%R86)S:VD@96UI<F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D
M($MI;F=D;VTB"FUS9W-T<B`B6F1R=<6^96YO(&MR86QJ97-T=F\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(EID<G7%
MOF5N92!D<L6^879E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(EID<G7%OF5N
M92!D<L6^879E($]T;VMI($UI;F]R($]U=&QY:6YG(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z.#,*
M;7-G:60@(E5N:71S(@IM<V=S='(@(D5N;W1E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0S,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DYE<&]Z;F%N;R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*
M;7-G<W1R(").97!O>FYA;F$@87!I;7-G:60@*$E$($%022!S<&]R;\2-:6QA
M*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2XB"FUS9W-T<B`B3F5P;WIN86YA(&-L:6US9VED("A)1"!U<&]R
M86)N:<6A:V5G82!S<&]R;\2-:6QA*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3(*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(DUE<W1O(&YI(&YA<W1A=FQJ96YO+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I
M9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5Z
M;F%N;R!U<&]R86)N:<6A:V\@:6UE(&%L:2!G97-L;RXB"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C,Q.0IM<V=I9"`B56YN86UE9"(*
M;7-G<W1R(")"<F5Z(&EM96YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S,*
M;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(").97!O9'!R
M=&$@<F%ZQ:%I<FET978B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I
M9"`B57!D871E(@IM<V=S='(@(E!O<V]D;V)I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&4@)7,B"FUS9W-T<B`B4&]S;V1O8FD@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")5<&1A=&4@=7-E<B(*
M;7-G<W1R(")0;W-O9&]B;&IE;B!U<&]R86)N:6LB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$T,R!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#$@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&5D(%PB)7-<(BXB"FUS9W-T<B`B4&]S;V1O8FQJ96X@)R5S)RXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX.0IM<V=I9"`B57!G<F%D92!S8W)I
M<'0@9&5L971E9"XB"FUS9W-T<B`B27IB<FES86YA('-K<FEP=&$@>F$@;F%D
M9W)A9&YJ;RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P
M;&]A9"(*;7-G<W1R(").86QA9V%M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$X-0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(DYA;&_%OFD@;F$@<W1R
M9<6^;FEK('9S92!N86UE<W1I='9E;F4@9&%T;W1E:V4@87!L:6MA8VEJ+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W9A
M:B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*
M;7-G<W1R(")5<&]R86)I('-E9&%N:FDZ("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!3
M4TPB"FUS9W-T<B`B57!O<F%B:2!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")5<&]R86)I+"#$C64@
M:F4@=7!O<F%B;FG%H6MO(&EM92]G97-L;R!D<G5G8<2-;F\@;V0@24U34"!S
M=')EQ;YN:6MA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")5<&]R86)N:6LB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<V-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B57!O<F%B;FEK("5S(&YI;6$@9&]S=&]P82!D;R`E<R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(P,@IM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")5<')A=F$@>F$@=7!O<F%B;FEK92(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B
M"FUS9W-T<B`B57!O<F%B;FG%H6ME(&YA<W1A=FET=F4B"@HC.B!S:6=N=7`N
M<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")296=I
M<W1R86-I:F$@=7!O<F%B;FEK82(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@
M(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N(@IM<V=S='(@(E)E9VES=')I<F%N:F4@=7!O<F%B;FEK;W8@:F4@
M;F$@=&5J('-T<F%N:2!O;F5M;V=OQ(UE;F\N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0Y-`IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*
M;7-G<W1R(").92!N86ID96T@=7!O<F%B;FEK;W8@<F'$C75N+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,T(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-C0@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(E5P;W)A
M8FYIQ:%K;R!I;64B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,3(U"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B57!O<F%B;FG%H6MO(&EM92!<(B5S
M7"(@:F4@Q;YE('8@=7!O<F%B:2XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")5<&]R86)N
M:<6A:V\@:6UE.B`B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(E5P;W)A8FYIQ:%K;R!I;64Z
M("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5P;W)A8FYI:VDL(&MI
M('-O('8@<VES=&5M=3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES
M=&%N(@IM<V=S='(@(E5Z8F5K:7-T86XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-S,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,CDT
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")61E,@:6UE;FEK(&YE(&]B<W1A:F$N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$R-PIM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B3V1S;W1N
M;W-T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#<U"FUS9VED(")6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(DYA:F1E
M;F$@=F5L:F%V;F$@;&]K86-I:F$@>F%J96UA.B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G
M<W1R(")696QJ879N;W-T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")6<F5D;F]S="!V(&UI;G5T86@@;V0@
M<V5D86H@9&%L:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M(@IM<V=S='(@(E9R961N;W-T('!R97-E9V$@;6%K<VEM86QN;R!D;VS%OFEN
M;R`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8P-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3DX"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@
M(E9A;'5E<R(*;7-G<W1R(")6<F5D;F]S=&DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,SDW(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-S0*
M;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")6<F5D;F]S
M=&D@;V0@:V]D97(@:7IB:7)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")6
M86YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,X"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)I
M86)I;&YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B
M4')E=F5R:F%N:F4@;F5U<W!EQ:%N;R`M(&UO9V_$C64@:F4@8FEL;R!S<&]R
M;\2-:6QO('-P<F5M96YJ96YO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E)A>FQI
MQ(UI8V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0R"FUS9VED
M(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B4F%Z;&G$C6EC82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B6F5L;R!V:7-O:V\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB
M"FUS9W-T<B`B5FEE=&YA;7-K:2`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.CDU,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(@IM<V=S='(@(E!O9VQE:B`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@R-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5FEE=R`E<R!;)7-=(@IM<V=S='(@(E!O9VQE:B!K;W0@)7,B
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E!O9VQE9"!N82!Z=6YA;FIO('-P
M;&5T;F\@<W1R86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R(")$979IQ:%K:2!O=&]K:2`H8G)I=&%N
M<VMI*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5
M+E,N(@IM<V=S='(@(D1E=FG%H6MI(&]T;VMI("A:1$$I(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B
M5FED;&II=F]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3<*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:61L:FEV;W-T.B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R
M(")6;V1A9F]N($ET86QI:F$@<')E:V\@4TU44"(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B3U!/6D]224Q/(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S
M='(@(D]03UI/4DE,3R$A(2!23\2-3D\@3T135%)!3DE-(%-+4DE05$\@25H@
M)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@<')E:V\@2%14
M4"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM
M<V=S='(@(E=A;&QI<R!I;B!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z.34*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B
M3W!O>F]R:6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,`IM<V=I9"`B5V4B"FUS9W-T<B`B36DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0*;7-G:60@(E=E871H97(@1F]R96-A
M<W0B"FUS9W-T<B`B5G)E;65N<VMA(&YA<&]V960B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#$Y"FUS9VED(")796%T:&5R(&1A=&$@<')O
M=FED960@8GDB"FUS9W-T<B`B5G)E;65N<VMI('!O9&%T:VD@<R!S<&QE=&$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#$*;7-G:60@(E=E871H
M97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")3<&QE="(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C`*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(E-P;&5T;F$@<W1R86XB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B
M5&5D96YS:V\B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM
M<V=I9"`B5V5L8V]M92(*;7-G<W1R(")$;V)R;V1OQ:%L:2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM
M<V=S='(@(D1O8G)O9&_%H6QI(&YA('-P;&5T;FEH('-T<F%N96@@<')O9W)A
M;6$@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")$;V)R;V1O
MQ:%L:2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B6F%H;V1N:2`H25-/+3@X
M-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(EIA:&]D;FD@*$E33RTX.#4Y
M+3$U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S
M='(@(EIA:&]D;F$@4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")+871E<F\@
M87!L:6MA8VEJ;R!N86H@<')I:V'%OF4@)7,L('!O('!R:6IA=FD_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(DMA:\6A96X@:F4@
M;&_$C6EL;FD@>FYA:S\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R(")+86O%H65N(&IE(&YA=F5D96YI('IN86L_(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E
M:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("):96UL:F5V:60@(%=H97)E:7,@
M075S=')A;&EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7
M:&EC:"!P:&%S97,B"FUS9W-T<B`B4F%Z=F]J;F$@<W1O<&YJ82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M2V%T97)E(&1O9&%T:V4@;F%J(&]M;V=OQ(UI;2!P<FD@=7)E:F%N:G4@8F5S
M961I;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SDT"FUS9VED
M(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`BQ:!I<FEN82!V(&5N;W1A
M:"!#4U,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T
M("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("+%H&ER
M:6YA("5S(&UE;FEJ82!N82!L979I("AO9')A>FEL82!S92!B;R!O8B!N87-L
M961N:FD@<')I:F%V:2DZ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4S-PIM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y,R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"(*;7-G<W1R(")6971E<CH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B2G5T<F%N:FD@=F5T97(Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B2&ET<F]S="!V971R82!V('9O>FQI:"(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,38X"FUS9VED(")7:6YD.B(*;7-G<W1R
M(")6971E<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,V
M"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5F5T97(Z("(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV.0IM<V=I9"`B5VES9&]M(@IM<V=S='(@(DUO9')O
M<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$R"FUS9VED(")7
M:7-H;&ES="(*;7-G<W1R("),:7-T82#%OF5L:F$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-S`*;7-G:60@(E=O<FLB"FUS9W-T<B`B4VQUQ;YB82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(E-L=<6^8F5N:2!N87-L;W8B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR
M"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E-L=<6^8F5N:2!T96QE9F]N
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B3F%P8<2-;F\@Q:%T979I;&\@<&]L:B!V
M("5D('9R<W1I+B!0<FG$C6%K;W9A;FEH("5D+"!N86ID96YI:"`E9"XB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(").87!AQ(UN;R#%H71E=FEL;R!P;VQJ+B!0
M<FG$C6%K;W9A;FEH("5D+"!N86ID96YI:"`E9"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T
M<B`B3F%P8<2-96X@;V1M:6L@)60@;65D(&)R86YJ96T@9&%T;W1E:V4@5D93
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R(")8-3`Y=C,@;W-N;W9N82!O;65J:71E=B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!287K%H6ER:F5N
M82!U<&]R86)A(&ML:G7$C6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@6F%D979A(&%L=&5R;F%T:79N;R!I
M;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B
M6#4P.78S($MJ=64@>F$@9&]L;V5I=&D@>F%D979O(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!R87K%H6ER:71E=B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("),3"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0V,`IM<V=I9"`B
M65E962(*;7-G<W1R("),3$Q,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T
M<B`B66%H;V\A('IE;6QJ979I9"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("),
M971N;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE
M;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV-@IM<V=I9"`B665S(@IM<V=S='(@(D1A+B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@
M06=R964B"FUS9W-T<B`B1&$L('-E('-T<FEN:F%M+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(DYI;6%T92!D;W9O;&IE;FIA
M('5S='9A<FET:2!V9<2-(&MO="`E9"!B;&]K;W8N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,SDU"FUS9VED(")9;W4@87)E(&YO="!A=71H
M96YT:6-A=&5D+B(*;7-G<W1R(").:7-T92!P<FEJ879L:F5N:2(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S(U"FUS9VED(")9;W4@
M8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N
M86UE+B(*;7-G<W1R(")6(&EM96YU(&YE(&UO<F5T92!I;65T:2!Z;F%K;W8@
M)UQ<)R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ,3<*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!D:60@;F]T(&%U=&AE;G1I8V%T92XB"FUS9W-T
M<B`B3FES=&4@<')I:F%V;&IE;FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C8S"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N(@IM<V=S='(@(DYI<W1E('9S=&%V:6QI('9E;&IA=FYE
M9V$@96QE:W1R;VYS:V5G82!N87-L;W9A+B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED
M;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@
M=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B
M"B)-960@<W!R96IE=&EM:2!D871O=&5K86UI(&YI<W1E(&]Z;F'$C6EL:2!N
M;V)E;F5G82!P;VQJ82P@:VD@<V4@=6IE;6$@<R!P;VQJ:2`B"B)V)7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D)I;&D@<W1E(&]D:F%V;&IE
M;FDN(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&AA=F4@<F5Q=65S=&5D('1O
M(&%D9"!T:&4@96UA:6P@861D<F5S<R!<(B5S7"(@=&\@=&AE(&QI<W0@;V8@
M>6]U<B`B"B)P97)S;VYA;"!E;6%I;"!A9&1R97-S97,N7&XB"B)<;B(*(D=O
M('1O('1H92!F;VQL;W=I;F<@;&EN:R!T;R!C;VYF:7)M('1H870@=&AI<R!I
M<R!R96%L;'D@>6]U<B!A9&1R97-S.EQN(@HB)7-<;B(*(EQN(@HB268@>6]U
M(&1O;B=T(&MN;W<@=VAA="!T:&ES(&UE<W-A9V4@;65A;G,L('EO=2!C86X@
M9&5L971E(&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C<P"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@HB5FYE<W1I(&UO<F%T92!V96QJ879N;R!G<VT@Q:%T
M979I;&MO+D1V;VQJ96YI('IN86MI('-O(&QE(,6A=&5V:6QK92!I;B`G*R<@
M:V]T("(*(G!R961P;VYA(&UE9&YA<F]D;FEM(,6A=&5I=FQK86TN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y-PIM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B5G-T879I=&D@;6]R
M871E('9E;&IA=FYO('9R961N;W-T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B3V)L
M:6MO=F%T:2!M;W)A=&4@4VEG;G5P(&)A8VME;F0L(,6A96QE(&YA=&\@<V4@
M;&%H:V\@<')I:F%V;&IA=&4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HT-C<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+B(*;7-G<W1R(")/8FQI:V]V871I(&UO<F%T92!61E,@8F%C:V5N9"XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B
M66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@
M<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(DYA:G!R96H@;W!I
MQ:%I=&4@=&7%OF%V92P@Q:%E;&4@;F%T;R!L86AK;R!P;\6A;&IE=&4@<&]R
M;\2-:6QO(&\@=&7%OF%V86@N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@X.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@96YT97(@86X@96UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B3FES=&4@=G-T879I;&D@=F5L:F%V;F5G
M82!E;&5K=')O;G-K96=A(&YA<VQO=F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@X-@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@96YT97(@
M870@;&5A<W0@;VYE(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYI<W1E('9S
M=&%V:6QI('9E;&IA=FYE9V$@96QE:W1R;VYS:V5G82!N87-L;W9A+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(DEZ
M8G)A=&D@;6]R871E('-T<F7%OFYI:RP@:VD@8F\@:7IB<FES86XN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3$X"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(").871A;L2-;F5J92!N
M879E9&ET92!U<&]R86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L:71E(&EZ8G)I
M871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.CDY"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(").871A;L2-
M;F5J92!N879E9&ET92!U<&]R86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L:71E
M(&]D<W1R86YI=&DN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C$@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DYA=&%NQ(UN96IE
M(&YA=F5D:71E('5P;W)A8FYIQ:%K;R!I;64L(&MI(&=A(,6^96QI=&4@9&]D
M871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(").871A
M;L2-;F5J92!N879E9&ET92!U<&]R86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L
M:71E('!O<V]D;V)I=&DN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@
M86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DYA=&%NQ(UN96IE(&YA=F5D
M:71E(&MA:B#%OF5L:71E(&YA<F5D:71I+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S
M="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(E9T:7!K86IT
M92!I;64@;F]V92!K871E9V]R:6IE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@
M(E9N97-T:2!M;W)A=&4@:71A;&EJ86YS:V\@=&5L969O;G-K;R#%H71E=FEL
M:V\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E9AQ:%A('!R:6IA=FET=F5N
M82!S96IA("5S(&IE('!O=&5K;&$N(%!R;W-I;6\L(&1A('-E('!O;F]V;F\@
M<')I:F%V:71E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C,T"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B5F'%H2!E
M;&5K=')O;G-K:2!N87-L;W8Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")68<6A
M(&YA<VQO=CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M
M871I;VXB"FUS9W-T<B`B5F'%H6D@<&]D871K:2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D]D
M('IAQ(UE=&MA("5S('-E:F4L('-E(&IE('9AQ:$@<W!L971N:2!N87-L;W8@
M<W!R96UE;FEL+B!)>B`B"B)V87)N;W-T;FEH<F%Z;&]G;W8L('-E(&UO<F%T
M92!P;VYO=FYO('!R:6IA=FET:2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS,`IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E9AQ:%E
M(&EM93HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@
M2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U
M<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS
M9W-T<B`B(@HB5F'%H64@;WIA9&IE('IA(&]V97)J96YE(&YE('!O9'!I<F$@
M9&]D86IA;FIA('5P;W)A8FYI:V]V+B#$C64@Q;YE;&ET92`B"B)U<&]R86)I
M=&E(;W)D92!Z82!A9&UI;FES=')I<F%N:F4@=7!O<F%B;FG%H6MI:"!R8<2-
M=6YO=BP@;6]R871E('5P;W)A8FET:2`B"B)D<G5G;R!O>F%D:F4@>F%O=F5R
M:F%N:F4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU
M"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S
M='(@(B(*(E9AQ:%E(&]Z861J92!Z82!O=F5R:F%N:F4@;F4@<&]D<&ER82!N
M879A:F%N:F$@=7!O<F%B;FEK;W8@86QI('!A(&IE(&)I;&$@(@HB;6_%OFYO
M<W0@;VYE;6]G;\2-96YA(&EZ(&1R=6=I:"!R87IL;V=O=BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B)+8<6^92P@9&$@<V4@:F4@;V0@>F'$C65T:V$@)2!S96IE+"!V
M8<6A(&)R<VMA;&YI:R!S<')E;65N:6PN($EZ=F%R;F]S=&YI:"`B"B)R87IL
M;V=O=BP@<V4@;6]R871E('!O;F]V;F\@<')I:F%V:71I+B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E9AQ:$@8G)S:V%L
M;FEK(&YE('!O9'!I<F$@=&4@9G5N:V-I:F4N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT
M<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)68<6A
M(&)R<VMA;&YI:R!N92!P;V1P:7)A(&1O;&_$C65N:6@@;6_%OFYO<W1I('!R
M:2!P<FEN=&%N:G4N(%IA('!R:6YT86YJ92`B"B)P<FET:7-N:71E($-O;G1R
M;VPO36_%OFYO<W1I("L@4"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")6
M8<6A('1R96YU=&YI(,2-87-O=FYI('!A<SHB"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z,3,P"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"XB"FUS9W-T<B`B5F'%H6$@<')I=GIE=&$@:61E;G1I=&5T
M82!J92!B:6QA('-P<F5M96YJ96YA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T
M<B`B4')I=GIE=&$@:61E;G1I=&5T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")68<6A
M92!I;64Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED
M(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")68<6A82!P<FEJ
M879A(&IE('!O=&5K;&$N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<R(*;7-G<W1R(")68<6A92!N;W9E(&=E<VQO('IA("5S
M(&IE.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E9AQ:%E(&YA
M<W1A=FET=F4@<V\@8FEL92!P;W-O9&]B;&IE;F4@>F$@Q(UA<R!T92!S96IE
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED
M(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E9A
MQ:%E(&YA<W1A=FET=F4@<V\@8FEL92!P;W-O9&]B;&IE;F4N(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B5F'%H64@9V5S;&\@:F4@8FEL
M;R!P;VYA<W1A=FQJ96YO+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B
M"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB5F'%H64@9V5S;&\@:F4@8FEL;R!P
M;VYA<W1A=FQJ96YO+B!.82!V8<6A(&4M;F%S;&]V('-M;R!V86T@<&]S;&%L
M:2!N;W9O9V5S;&\@(@HB<R!K871E<FEM('-E('!R:6IA=FET92XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E9AQ:%E(&=E<VQO(&IE('!O=&5K
M;&\N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED
M(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")68<6A:2!P;W-R961N
M:2!S=')EQ;YN:6MI.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L879I:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):
M86ER(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA
M;6)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R
M(")::6UB86)V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HW,0IM<V=I
M9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(EM3:W)I:B!C:71I<F%N;R!B97-E9&EL;UTB
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@
M4F5P;W)T72(*;7-G<W1R(");<&]R;\2-:6QO(&\@;F%P86MI72(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM0;VMAQ;YI(&-I=&ER86YO
M(&)E<V5D:6QO("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@
M(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM0;VMA
MQ;YI(&-I=&ER86YO(&)E<V5D:6QO("T@)7,@=G)S=&EC72(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@
M(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");)7,@=G)S=&EC82!O9"`E<UTB
M"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,
M22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S
M='(@(D1R979E<VYA("(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R
M;W5P<R(*;7-G<W1R(")?4VMU<&EN92(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E!O;6_$
MC2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G
M:60@(E],;V<@:6XB"FUS9W-T<B`B4')I:F%V82(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S
M='(@(D]D:F%V82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(DUOQ;YN;W-T:2(*"B,Z
M(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@
M(D1O=F]L:F5N:F$B"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U
M<"(*;7-G<W1R(")?3F%M97-T:2(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I
M9"`B7U5S97)S(@IM<V=S='(@(E]5<&]R86)N:6MI(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G
M<W1R("));65N:6LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B3F%S
M;&]V;FEK(&YE>FYA;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$W"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")+;VQE9&%R(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.#0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")-:7)N;R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(DYE(&UO<F5M('5S
M='9A<FET:2!I>FAO9&YE(&1A=&]T96ME(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T
M(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E=&D@=FAO9&$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE
M<F4B"FUS9W-T<B`B:VQI:VYI('1U(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E
M<G)O<B(*;7-G<W1R(")N87!A:V$@=B!U<&]R86)N:2!U:V%Z;F4@=G)S=&EC
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS
M9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(DYA<&%K82!V(&MO
M;F9I9W5R86-I:FDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*
M;7-G<W1R(").92!N86ID96T@>F%H=&5V86YE('-I<W1E;7-K92!D871O=&5K
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS
M9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(").87!AQ(UN82!O8FQI
M:V$@9&%T=6UA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM
M<V=I9"`B961I="(*;7-G<W1R(")5<F5D:2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B
M"FUS9W-T<B`B3F4@;F%J9&5M('9N97-E;FEH('!O9&%T:V]V(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(F9A
M;&QI;F<B"FUS9W-T<B`B4&%D879I;F4B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HY,#,*;7-G:60@(F9I;&4B"FUS9W-T<B`B9&%T;W1E
M:V$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X-B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@
M(FEZ("5S("@E<RD@:R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#0*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B9V]S=&EM(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM
M<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S8S"FUS9VED(")H:"(*;7-G<W1R(")H:"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED
M(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(").97IN86YO(&EM92!G;W-T
M:71E;&IA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B=&%K
M;VHB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(DUE9"!V<G-T:6-A
M;6DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM
M<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(E9H;V1N82]I>FAO
M9&YA(&YA<&%K82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M("));G1E<FYA(&YA<&%K82!V('!R;V=R86UU(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")V<G-T:6-E(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R
M(")M:VES;V9S(&YA<&%K82!K;V1E("5D+"!M960@<')I<')A=FQJ86YJ96T@
M25-/+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-S0*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR.#$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$W-`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0S"FUS
M9VED(")N86UE(@IM<V=S='(@(FEM92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")N:2!D
M;VMO;L2-86YO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(L6A
M92!N:2!P;V1P<G1A(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B0F5L9<6^:V$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B1&]V;VQJ96YJ92!J92!Z879R;FIE;F\N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G
M:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")N87!A:V$@
M=B!O9&1L:F5N96T@<')O=&]K;VQU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")V
M>FAA:F%J;\2-92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(E-E
M<G9I<R!N:2!N82!V;VQJ;RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C$P,@IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")0;VMAQ;YI
M(')A>FQI:V4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(G-M<S)E;6%I;"!P<F5K;R!(5%10(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y,0IM<V=I9"`B<W,B"FUS9W-T<B`B
M<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M-`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(E-T86)I;&YO(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E
M<G)O<B(*;7-G<W1R(")3:7-T96US:V$@;F%P86MA+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B4V5Z;F%M(&]P<F%V:6PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S
M='(@(GIAQ(UA<VYA(&]D<&]V960B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<Q"FUS9VED(")T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(GIA('!O
M=')D:71E=B!V=&EP:V%J=&4@9V5S;&\@9'9A:W)A="(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(F5N;W1E;B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VAO<F1E+G!H<#HR-SD*(RP@9G5Z>GD*;7-G:60@(G5N:VYO=VX@97)R
M;W(B"FUS9W-T<B`B<&]J879I;&$@<V4@:F4@;F%P86MA(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R(")B<F5Z(&EM96YA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*
M;7-G<W1R("))>F)I<F$@=7!O<F%B;FEK82`B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S
M='(@(G8@2V%R=&EC82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M
M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V)G7T)'+G!O
M````````````````````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`V-#,W,3$`,3`U,34T,S$P-C,`,#$V,S0Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@0G5L9V%R:6%N('1R86YS;&%T
M:6]N<R!F;W(@2&]R9&4@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@
M2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E
M<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($UI
M<F]S;&%V(%!E;F1E=B`\;6ER;T!C>6)E<G-H861E+G5S/BP@,C`P,BX*(PIM
M<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@
M,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U
M.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,3$M,3D@,C`Z
M-#0M,#4P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!-:7)O<VQA=B!096YD978@
M/&UI<F]`8WEB97)S:&%D92YU<SY<;B(*(DQA;F=U86=E+51E86TZ(&DQ.&Y`
M;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U,5QN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S
M(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(.3MZ"#MX.?@Y"DB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("@E<R#D[>@@[>#GX.0I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB
M"FUS9W-T<B`B("CD[>7Q*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*
M;7-G<W1R("(@*.+WY?#@*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G
M<W1R("(G)7,G(.WE(.4@ZN[M].CC\_#H\.#M(.(@2&]R9&4@4F5G:7-T<GDN
M(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)^'E^.4@Y.[AX.+E[>`@ZOKL(./P\^_H
M\N4N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P
M97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@X>7XY2#D[N'@XN7M
M(.KZ["#QZ/'RY>S@\N`@Y^`@[_#@XN`@[>`@[^[R\.7AZ/+EZ^CRY2XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E<R?MY2#AY?CE(/'ZY^3@Y.7M
M.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N
M,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@Q^#AY>OEYNK@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R#.X?'K\^;B
MX/GH(.[OY?#@]NCH("T@S^[RXOKPYN3E[>CE(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@
M;V8@06=R965M96YT(@IM<V=S='(@(B5S(-/QZ^[BZ/\@[^X@T>_N\.#G\^SE
M[>CE\NXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B
M"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N(@IM<V=S='(@(LCGX>7PY?+E(.[OY?#@]NCH\N4L
M(.KNZ?+N(.CQZN#RY2#DX"#HY^+Z\/CH\N4@\>7CX"XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(.WE[N'U[N3H["(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!M:6YU=&5S(@IM<V=S='(@(L+QY>KH(#4@[.CM\_+H(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+M
MY2#AY?CE(.W@[.7PY>TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O
M9B`E<R(*;7-G<W1R(");Z^CMZ/\@)7,@[O(@)7-=(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(L#D\.7QY>T@X>7KY>;M
MZ.HB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("+*
MX.OE[>3@\"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`B)7,@+2#'X.'EZ^7FZN`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<^W@[.7PY>TZ)7,@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T
M:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B,3(@2&]U
M<B!&;W)M870B"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#"X/$B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@1F]R
M;6%T(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T
M(/?@\>`B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/LWE[_#E[N3NZ^CLX"#C\.7XZN`Z
M/"]B/B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`BQ^`@Y.`@ZO#H[_+H\.#RY2#OZ/'L[B#E
M(.WE[N'U[N3H["#O\^'KZ/?E[2!01U`@ZNO^]RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("+'X"#DX"#O\.[BY?#H\N4@[^[D[^CQX.WN(._H\>SN(.4@[>7N
MX?7NY.CL(%!'4"#JZ_[W+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B+'X"#DX"#DY>KPZ._R
MZ/#@\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@Z^CW
MY>T@ZNO^]R#H(.KK_O?NXN`@(@HB]/#@Y^`N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(L?@(.3@
M(._NY._H^.7RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH.B#O\^'KZ/?E[2#JZ_[W
M+"#KZ/?E[2#JZ_[W(.@@ZNO^]^[BX"`B"B+T\.#GX"XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(L?@(.3@(.3EZO#H[_+H\.#RY2#OZ/'L[B#Q
MX"#MY>[A]>[DZ.SH.B#O\^'KZ/?E[2!334E-12#JZ_[W+"#KZ/?E[2!334E-
M12`B"B+JZ_[W(.@@ZNO^]^[BX"#T\.#GX"XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0HC+"!F=7IZ>0IM<V=I9"`B(@HB02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(L?@(.3@(._NY._H^.7RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH
M.B#O\^'KZ/?E[2!334E-12#JZ_[W+"#KZ/?E[2!334E-12#JZ_[W(.@@(@HB
MZNO^]^[BX"#T\.#GX"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+'X"#DX"#J\.CO
M\NCPX/+E(._H\>SN(.4@[>7NX?7NY.CL(._SX>OH]^7M(%--24U%(.KK_O<N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM
M<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!
M8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R
M("+/[O+B^O#DY?+E(._@\.[KX/+@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R
M;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,S,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("+,[O_R
MX"#/[OG@(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B
M"FUS9W-T<B`BQ.[AX.+JZ"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(U"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@
M1W)O=7`B"FUS9W-T<B`BQ.[AX.+_[>4@[>`@[>[BX"#C\//OX"(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD(%!E
M<FUI<W-I;VXB"FUS9W-T<B`BQ.[AX.+_[>4@[>`@[>[BZ"#O\.#BX"(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!
M9&0@2&5R93HB"FUS9W-T<B`BP.3PY?$B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R("+$[N'@XO_MY2#MX"#M[N+@(./P\^_@(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T
M<B`BQ.[AX.+_[>4@[>`@[>[BZ"#O\.#BX"(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("+$
M[N'@XN@@[>#QZ^7DY>W@(./P\^_@(.KZ["`G)7,G(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S
M='(@(L3NX>#BZ"#MX/'KY>3E[>@@[_#@XN`@ZOKL("<E<R<B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@
M(L3NX>#BZ"#M[N(@[^[R\.7AZ/+EZSHB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("+$
M[N'@XN@@[>[B(/?KY>TB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.CDU"B,L(&9U>GIY"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("+$[N'@XN@@
M\.7G_NSE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I
M9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("+$[N'@XN@@ZOKL(.SN__+@(.#D\.7Q[>`@ZNWH
MX^`Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM
M<V=S='(@(L3NX>#BZ"#J^NP@[.[_\N`@X.3PY?'MX"#J[>CCX#HB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS
M9W-T<B`BQ.[AX.+H(.WNXB#O[O+PY>'H\N7K.B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I
M9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU
M<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BQ.[AX.+_[>7R[B#M
MX"#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M[BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("+`Y/#E\2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@
M0F]O:R(*;7-G<W1R("+`Y/#E\>7M(.'EZ^7F[>CJ(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M(@IM<V=S='(@(M#EY.#J]NC_(.W@(._PX.+@\N`@Y^`@)R5S)R(*"B,Z(&%D
M;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H
M\.#MY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@
M(D%D<R(*;7-G<W1R("+$[N'@XNKH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G
M:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I
M9"`B06QB86YI82(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L
M(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*(RP@9G5Z>GD*
M;7-G:60@(D%L:6=N(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N
M;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W
M"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM
M<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R("+"\>CWZN@@X_#S[^@B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]0
M97)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*
M;7-G<W1R("+"\>CWZN@@[_#@XN`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S
M:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED
M(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!
M;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`BPN#XZ/\@16UA:6P@X.3PY?$Z(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("+"^N+EY.7MX/+@(/'R
M[NGM[O'R(.WE(.4@Y.[O\_'RZ.S@+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R
M;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(NWE[_#E[N3NZ^CLX"#C\.7XZN`Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED
M(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C
M=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N
M9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ-@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`BPN#J
MX.WVZ/\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*
M;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BS>#LY?#E[>@@[_#H
MZ^[FY>WH_SH@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS
M9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H
M:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@
M(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B
M:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(M#@Y^SE\"#MX"#@\/7HXNWH_R#TX.GK(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("+(
M[.4@[>`@X/#UZ.+@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQZN#R
MY2#DX"#HY_+PZ.7RY2`G)7,G(.@@XO'H]^KH(._NY._PX.+@/R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(M'HX_/P
M[>@@Z^@@\?+E+"#WY2#H\>K@\N4@Y.`@Z.?R\.CE\N4@)R5S)R#H(.+QZ/?J
MZ"#O[N3C\//OZ#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@
M*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM
M<V=S='(@(L3@(/'E(.CQZN`@Z^@@[^[RXOKPYN3E[>CE(._PY>3H(.[A\>OS
MYN+@^>CRY2#N[^7PX/;HZ#\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(L/PY?CJX"#O\.@@
MZ.?R\.CBX.WE(.W@(.WE\?KYY?'RXO/BX/G@(./P\^_@+B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(L/PY?CJX"#O
M\.@@Z.?R\.CBX.WE(.WE(.WE\?KYY?'RXO/BX/GH(._PX.+@+B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#PY>3@ZO+H\.#MY2#MX"#MY?'Z^>7Q\N+SXN#YZ"#O\.#BX"XB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B
MP_#E^.K@(._PZ"#PY>3@ZO+H\.#MY2#MX"#MY?'Z^>7Q\N+SXN#YZ"#O\.#B
MX"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R("+`\O#HX?/RZ"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"B,L(&9U>GIY"FUS9VED(")!=6=U
M<W0B"FUS9W-T<B`BP?KC[N+E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A
M;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V
M.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T
M:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*
M;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED
M(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"(*;7-G<W1R("+#\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I
M;&5D+B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G
M<W1R("+(Y.7M\NCTZ.K@]NC_\N`@X>7XY2#N\O7B^O#KY>W@(.[R(%)!1$E5
M4R#Q^O#B^O#@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q
M"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY.7M\NCTZ.K@]NC_(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("+"\/KGZN#RX"#Q^O$@1E10(/'Z\.+Z\.`@\>4@[_#NXN#KZ"XB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I
M;&%B;&4@9FEE;&1S.B(*;7-G<W1R("+-X.OH]^WH(._NZ^7RX#HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I
M9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S
M<W=O<F0N(@IM<V=S='(@(LWEXN#KZ.3MX"!K97)B97)O<R`@[^#P[NO@+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A
M9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`BS>7BX.OHY.WN(&ME<F)E
M<F]S(._N\O#EX>CRY>OQZNX@Z.SE+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A
M:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B
M0F%H<F%I;B(*;7-G<W1R(")"87)B:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM
M<V=I9"`B0F5L:7IE(@IM<V=S='(@(M#@Y^SE\"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(M#NYN3E[2#DY>TB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P
M;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BT>OS^.#RY>O_
M\B`E<R#MY2#E(.W@[.7PY>TN(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K
M(%1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(M/DY>'EZ^7M
MZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS
M(@IM<V=S='(@(L[R[.7RZN@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z
M96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ
M>0IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0G)O=VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@
M(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(D)R87II;"(*;7-G<W1R("+/[OG@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"B,L(&9U>GIY
M"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(L_NY/#EY.7M(/'OZ/'Z
MZB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R
M(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`BRN#KY>WDX/`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0V"B,L(&9U>GIY"FUS9VED(")#86QM(@IM<V=S='(@(L[RZN#F
MZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E
M="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@
M=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I
M;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?BX.WE
M(/$@[.7IZR#Q^O#B^O`Z("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G
M:60@(D-A;F%D82(*;7-G<W1R("+*X.OE[>3@\"(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(L[RZN#FZ"(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(._PY>S@]>+@[>4[("@E
M<RD@XN7WY2#Q^OGE\?+B\^+@(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#O\.7LX/7BX.WE.R`H)7,I(.+E]^4@\?KYY?'RXO/BX"(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED
M(")#87!T:6]N(@IM<V=S='(@(L[O]NCH(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")#
M87)R:65R(@IM<V=S='(@(D)A<F)I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(LSNX>CKY>T@\N7KY?3N
M[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G
M<W1R("+,[N'HZ^7M(/+EZ^7T[NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L
M;'!H;VYE(@IM<V=S='(@(LSNX>CKY>T@\N7KY?3N[2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")#96YT97(B"FUS9W-T
M<B`BUN7M\O#H\.#M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B
M0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O
M;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I
M9"`B0VAA9"(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R(")/<F%N9V4B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L_N\N+Z\.3E\N4@[^#P
M[NO@\N`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*
M(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*
M;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F
M=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I
M9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F
M=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B].#IZR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H
M:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@
M(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(L_N\N+Z\.3E\N4@[^#P[NO@
M\N`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS
M9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L
M:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+1
MZ_/XX/+EZ__R("5S(.WE(.4@[>#LY?#E[2XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE
M87(B"FUS9W-T<B`BRN#KY>WDX/`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G
M:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`BS_#E[.#U[>@@[^[R\.7A
MZ/+EZSH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R("+(Y^'E\.@@[^[R\.7AZ/+EZR#GX"#D[N'@
MXO_MY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#
M;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K
M871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"B,L(&9U
M>GIY"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`BQ^#RXN[PZ"#O\.[G
M[O#E]B!<(L_N[.[Y7"(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM
M<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G<W1R("+*[N_H\.#I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR
M,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS
M9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B
M0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(LCGX>CPX.WE(.W@
M(/;B__(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED
M(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS
M9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R("+*[NSH
MZO'H(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED
M(")#;VUM86YD(@IM<V=S='(@(LKN[.#MY.@Z(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(P"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S
M='(@(LKN[.#MY.@Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")#;VUM96YT(@IM<V=S='(@(LKN[.#M
MY.@Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*
M;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L
M(&9U>GIY"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(LKN[.CJ\>@B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PHC+"!F=7IZ>0IM<V=I
M9"`B0V]N9&ET:6]N(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VYS
M(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@
M=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`BRN[M
M].CC\_#@]NC_(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@
M(LKN[?3HX_/PX/;H_R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`BS^[R
MXOKPY.7RY2#OX/#NZ^#RX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(L+P^N?JX/+@(/'Z\2!&5%`@
M\?KPXOKPX"#QY2#O\.[BX.OH+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D.B`B"FUS9W-T<B`BPO#ZY^K@\N`@\?KQ($944"#Q^O#B^O#@(/'E
M(._P[N+@Z^@N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(L3N\?+Z[^`@Y.X@[_/AZ^CW[>C_(/'Z\.+Z
M\"#AY?CE(.[RZN#GX.TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*2(*;7-G<W1R("+$[O'R^N_@(.3N(._SX>OH]^WH_R#Q^O#B^O`@
MX>7XY2#N\NK@Y^#M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#0U"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("+"\/KGZN#RX"#Q^O$@1E10(/'Z\.+Z\.`@\>4@
M[_#NXN#KZ"XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I
M9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@HBTN7GZ"#DX.WMZ"#GX"#J[NWRX.KR(.'_]>`@\_'O
MY?CM[B#D[N'@XN7MZ"#J^NP@PN#XX/+@(._P[N/PX.S@+B#*Z^CJ[>7RY2#O
M[BTB"B+D[NOS(.?@(.3@(.+HY.CRY3HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N
M=',@;V8@7"(E<UPB(@IM<V=S='(@(M'ZY/KPYN#MZ.4@[>`@)R5S)R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R("+*[N_H\.#I(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("+([._N
M\/+H\.#M[B#O[NOE.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU
M"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R("+#\.7XZN`@[_#H(%!'4"#J\.CO\NCPX.WE\NX@
M[>`@[^CQ[.XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@4$=0(._NY._H\>+@[>7R[B#MX"#OZ/'L[BXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@4TU)344@ZO#H[_+H\.#MY?+N(.W@(._H\>SN
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`BP_#E^.K@(._PZ"!334E-12#O[N3OZ/'BX.WE\NX@[>`@[^CQ
M[.XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E
M(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@[O'Z^>7Q\N+H(.+P^N?J
MX"#Q($Q$05`@\?KPXOKP+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-3<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R
M=F5R(@IM<V=S='(@(L/PY?CJX"#O\.@@[^[K\_?@XN#MY?+N(.W@(._SX>OH
M]^WH_R#JZ_[W(.[R(.KK_O<M\?KPXOKPX"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<R(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@
M(L/PY?CJX"#O\.@@\>+Z\.?BX.WE(/'Z\2!334(@\?KPXOKP+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN
M9R!&5%`Z("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?BX.WE(/$@4E!#
M(/'Z\.+Z\#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BP_#E^.K@(._PZ"#Q^N?DX.+@[>4@[>`@Z^[JX.OMX"#DZ/#EZO+N\.C_
M(.?@(.ONZN#KZ.?@]NC_("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$N(@IM<V=S='(@(L/PY?CJX"#O\.@@Y.7J\.CO\NCPX.WE\NX@[>`@4$=0
M(.3@[>WH+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3(R"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`BP_#E^.K@(._PZ"#DY>KPZ._RZ/#@[>7R[B#MX"!3
M34E-12#DX.WMZ"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("+-Y>+ZY^SN
MYNWN\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("+-Y>KN
M\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._NZ_/WX/+EZ_\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(LWEZN[PY>KRY>T@96UA:6P@X.3PY?$@[>`@[^[K\_?@
M\N7K_RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@
MY.`@\>4@ZN[OZ/#@("5S(/+N("5S+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ
M,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS
M9W-T<B`BP_#E^.K@(._PZ"#O[NOS]^#BX.WE\NX@[>`@[_/AZ^CW[>C_(.KK
M_O<@[O(@ZNO^]RWQ^O#B^O#@+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB
M)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E
M(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("+-Y>+ZY^SNYNWN
M\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#N\N+N\.@@SN'QZ_/FXN#Y
MZ%_GX.3@]^@@[.[D\^L@)7,@(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[O
MZ/#@("5S(/+N("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE\?+BZ"#B\/KGZN`@\2!,
M1$%0(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP
M.C(S.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M860@)7,N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@
M\NX@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G
M:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("+-Y>KN\.7J\N7M(&5M86EL(.#D
M\.7Q(.W@(._NZ_/WX/+EZ_\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(DAO<F1E(.WE(.4@ZN[M].CC\_#H\.#M(.KN\.7J\NWN(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-Y>[A]>[DZ.SH
M_R`G<&]R="<@[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@ZN[M].CC\_#@]NC_\N`N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@
M\>4@[O'Z^>7Q\N+H(.+P^N?JX"#Q($Q$05`@\?KPXOKP+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@4$=0
M(._NY._H\>+@[>7R[B#MX"#OZ/'L[BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G
M<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`BP_#E^.K@(._PZ"#Q^N?DX.+@[>4@[>`@Z^[JX.OMX"#DZ/#EZO+N\.C_
M(.?@(.ONZN#KZ.?@]NC_("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S
M7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*(RP@9G5Z>GD*;7-G:60@
M(D-O=6YT<GDB"FUS9W-T<B`BZ.?PY>;H(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@
M(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871E
M(&$@;F5W(&]N92(*;7-G<W1R("+(Y^'E\.7RY2#M[N(@[_#H\N7FX/+EZR#M
MX"#C\//OX"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*(RP@9G5Z>GD*
M;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`@[^X@
M[^[D\.#GX>CPX.WE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S
M,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!3
M97-S:6]N<R(*;7-G<W1R("+/\.#BX"#GX"#C[O'RZ"(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R
M<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!5
M4DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"B,L
M(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(L+@^.CRY2#Q
M^O#B^O#H.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U
M<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(NCG\.7FZ"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*
M;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G
M<W1R("+$Q"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G
M:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N
M+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`BQ>;EY.WEXNWN(@H*(SH@861M:6XO
M9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@
M(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S.3D*(RP@9G5Z>GD*;7-G:60@(D1A=&4B"FUS9W-T<B`BQ.#M
M[>@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM
M<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@
M(D1A>2(*;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(LCGX>7PY?+E(.KNZ^[MZ#HB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@HC
M+"!F=7IZ>0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`BU^OE[>[BY2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"B,L(&9U
M>GIY"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`BS>#LX.OH(//E
MY.W@ZN+_XN#MY?+N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`BR.?R\.CI(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@
M0V]L;W(B"FUS9W-T<B`BR.?O[NOGXN#I(._NY/#@Y^'H\.#YX/+@(/'E(/'R
M[NGM[O'R(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY
M,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+(Y.7M\NCW[>[Q
M\B#O[B#O[N3PX.?AZ/#@[>4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`BR.3E
M[?+H]^WN\?(@[^X@[^[D\.#GX>CPX.WE(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$
M96QE=&4B"FUS9W-T<B`BR.?R\.CI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@0V5L;"(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E($=R;W5P(@IM<V=S='(@(LCG\O#HZ2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M($QO9R(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("+/
M\.#BX"#O[B#O[N3PX.?AZ/#@[>4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@8V5L;"(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(LCGX>7PY?+E(.KNZ^[MZ#HB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`BT.7DX.KVZ/\@[>`@[_#@XN#RX"#GX"`G)7,G(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("+1Z./S\.WH(.OH(/'RY2P@]^4@
MZ/'JX/+E(.3@(.CG\O#HY?+E("<E<R<@Z"#B\>CWZN@@[^[D[_#@XN`_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R("+(Y_+P
MZ.DB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS
M9W-T<B`BR.3E[?+H]^WN\?(@[^X@[^[D\.#GX>CPX.WE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L
M:79E<GD@=&EM92(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F
M=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BS_KK[>X@[N_H\>#M
MZ.4Z(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@
M(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(L3E\N#IZ^CRY2#A__7@(/#EX^CQ\O#H\.#MZ"#GX"#@Y.SH
M[>CQ\O#@\N[PX"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y
M"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*
M;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G
M:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES
M<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M("+$Z/'OZ^7I(,[O]NCH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T(@IM<V=S='(@(L3H\>_KY>D@SN_VZ.@B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z
M>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(L3H\>_KY>D@SN_V
MZ.@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO
M="!D96QE=&4B"FUS9W-T<B`BR.?R\.CI(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM
M<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A
M;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B
M"FUS9W-T<B`BS>7HY^+E\?+MX"#J[NS@[>3@.B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L
M:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`HC
M+"!F=7IZ>0IM<V=I9"`B1')U9W,B"FUS9W-T<B`BP?KC[N+E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED
M(")%+4UA:6PB"FUS9W-T<B`BS^[YX"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@
M9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H
M:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I
M9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B
MT.7DX.KVZ/\B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P
M('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO
M8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO
M9W)O=7!S+G!H<#HR,C8*(RP@9G5Z>GD*;7-G:60@(D5D:70@1W)O=7`B"FUS
M9W-T<B`BP_#S[^@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"B,L(&9U>GIY
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BS_#@XN`B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"B,L(&9U>GIY"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BT.7DX.KVZ/\@
M[>`@[_#@XN#RX"#GX"`G)7,G(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T
M<B`BT.7DX.KVZ/\@[>`@[_#@XN#RX"#GX"`G)7,G(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("+0
MY>3@ZO;H_R#MX"#O\.#BX/+@(.?@("<E<R<B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+0Y>3@ZO;H_R#MX"#O
M\.#BX/+@(.?@("<E<R<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*
M(RP@9G5Z>GD*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("+"X.K@[?;H_R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@
M2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L
M96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T
M<B`BS^CQ[.XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL
M($%D9')E<W,B"FUS9W-T<B`BQ6UA:6P@X.3PY?$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"XB"FUS9W-T<B`B16UA:6P@X.3PY?'H\N4@\O#_X>+@(.3@(/'Z
MXN_@Y.#R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@
M9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(L3P\^/@(.CM].[P[.#VZ/\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S
M='(@(L[O]NCH(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R("+/\.#GY>T@\.7G\^ORX/(N(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@
M<F5S=6QT+B(*;7-G<W1R("+/\.#GY>T@\.7G\^ORX/(N(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC
M:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM
M<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET
M;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM
M<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@
M=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E
M(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S
M(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R
M:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET
M<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O
M<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(L/PY?CJ
MX"(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO
M<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN
M8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]4
M96UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@
M(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W
M<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G
M:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S
M(@IM<V=S='(@(L+QY>KH(#$U(.SH[?/RZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*
M;7-G<W1R("+"\>7JZ"`U(.SH[?/RZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E
M<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+"\>7JZ"`S,"#QY>KS[>3H(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`BPO'EZN@@
M-2#LZ.WS\N@B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+"\?_J[B#K
M[N/BX.WE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B
M179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(LW@(.+QY>KH(._NZ^[BZ.T@]^#Q
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BPO'_
MZN`@[.CM\_+@(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*
M;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("+/\.CLY?#MZ"#Q\N[I
M[>[Q\N@Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"B,L(&9U>GIY"FUS
M9VED(")%>&5C=71E(@IM<V=S='(@(LCG[_KK[?_BX.WE(.W@.B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP
M86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI
M;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C
M=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O
M=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&
M1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<W"B,L(&9U>GIY"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S
M='(@(LCG[_#@^>#MY?+N(.W@(/3@Z>ONXN4@[>4@\>4@[^[DY/KPYN`N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BS>7B^N?L
M[N;M[O'R(.3@(/'E(.?@\.7D__(@[_#E].7PY>WVZ.CRY2XB"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#N\?KY
MY?'RXN@@XO#ZY^K@(/$@3$1!4"#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+B(*;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#MY2#Q
M^O$@4TU"(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@
M[>4@\?KQ(%--0B#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E
M<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#MY2#Q^O$@4TU"(/'Z
M\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E
M<R(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@Y^#PY>3_\B#O\.7TY?#E
M[?;HZ/+E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(D9A
M=&%L($5R<F]R.B(*;7-G<W1R("+#\.7XZN`B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T
M<B`BU.#J\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*(RP@
M9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(M3@ZO$B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A
M<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G
M:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y
M"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#
M2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S
M.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B].#I
MZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`BP?#NZ2#T
MX.GK[N+E.B`E<R#TX.GK(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B
M"FUS9W-T<B`BP?#NZ2#TX.GK[N+E.B`E<R#TX.GKX"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G
M<W1R("+4X.GK(.SE[>#FY?`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(LCLY2#MX"#TX.GK(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30X-@HC+"!F=7IZ>0IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B
MR.SE(.W@(/3@Z>LB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R("+(Y^_PX/G@[>7R[B#MX"#TX.GK[N+E(.WE(/'E(._NY.3Z\.;@+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R
M<R(*;7-G<W1R("+4Z.OR^O`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I
M9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@
M<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R
M9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-C(*(RP@9G5Z>GD*;7-G:60@(D9O<FUS(@IM<V=S
M='(@(M3N\//LZ"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("+4[O#S[.@B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(M3N\//LZ"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,@,B(*
M;7-G<W1R("+4[O#S[.@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`BU.[P\^SH(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$P.0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`BS_#E[_#@^>#MZ/\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`BU.[P\^SH
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;F-E(@IM<V=S='(@
M(D]R86YG92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")&<F]M(@IM<V=S='(@(M3N\//L
MZ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BS_KK[>X@[N_H\>#M
MZ.4Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(LCLY2#MX"#T
MX.GK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(LKN[?3H
MX_/PX/;H_R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M
M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<U"B,L(&9U>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(LCLY2#M
MX"#TX.GK(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@
M(D=O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM
M<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@36%P<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED
M(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B1W)E96-E
M(@IM<V=S='(@(D=R965N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*
M;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"B,L(&9U>GIY"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)E96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")'<F5N861A(@IM<V=S='(@
M(D=R965N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE(.W@(./P
M\^_H(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R("+#\.7X
MZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I
M9"`B1W)O=7!S(@IM<V=S='(@(L/P\^_H(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*(RP@
M9G5Z>GD*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=R97DB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R
M("+/\.#BX"#GX"#C[O'RZ"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z
M,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B2%144"#HY.7M\NCTZ.K@]NC_(.WE(.4@[>#LY?#E[>`N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED(")(86ET:2(*;7-G<W1R("+*[N7T
MZ/;HY>WR(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@HC+"!F=7IZ>0IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(L?@X^O@XNC_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R
M<R(*;7-G<W1R("+'X./KX.+H_R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED
M(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*
M;7-G<W1R("+/[NSN^2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z
M>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R("+/[NSN^2(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D
M;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE
M(@IM<V=S='(@(LW@]^#K[B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@
M4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R
M("+-X/?@Z^XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+$[NS@^.7M
M(.#D\.7Q(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(
M;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM
M<V=S='(@(L3N[.#XY>T@\N7KY?3N[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG
M($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB
M)7-<(B(*;7-G<W1R("+3\>_E^.WN(._PY>S@]>W@\B`G)7,G(.[R(/'H\?+E
M[.#RX"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I
M9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED
M(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R
M92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N
M<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU
M;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#Q^N?DX.+@[>4@[>`@24U!
M4"#O[OGE[?'JX"#J\_+H_SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2#M
MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(L/PY?CJX"#O[O#@
MY.@@ZN+N\N`@[_#H(/'ZY^3@XN#MY2#MX"!)34%0(._N^>7M\>K@(.KS\NC_
M.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z
M>GD*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`BP.3PY?$B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"B,L(&9U>GIY"FUS9VED
M("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0(.#D\.7Q
MX"#MY2#E(.(@[^[GXN[KY>WH_R!#2412(.'K[NHN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@X.3P
MY?'@(.WE(.4@XB#O[N?B[NOE[>C_($-)1%(@X>ONZBXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@
M(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"B,L
M(&9U>GIY"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`BPNSZ
MZNWH(._NY/#@XNWH\N7K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G
M:60@(DEC;VYS($]N;'DB"FUS9W-T<B`BT>#L[B#HZN[MZ"(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N
M<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(LCJ[NWH(/$@
M\N7J\?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))
M9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@
M=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W
M"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T+"!3=&5P("5D(@IM<V=S='(@(LCL[^[P\NCPX.WN(._NZ^4Z("5S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(LCL[^[P\NCP
MX.WN(._NZ^4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV
M-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("+([._N\/+H\.#M
MZ"#O[NOE\N`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED("));E]S97)T(%)O
M=R!!9G1E<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@
M9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(LWEZN[PY>KR[>`@[^#P[NO@(.CKZ"#O[O+PY>'H\N7K
M\>KN(.CLY2$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"B,L(&9U
M>GIY"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`BT^+EZ^CWX.+@
M[>4@[>`@\^7D[>#JXO_BX.WE\NXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN
M9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("))
M;F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F
M=7IZ>0IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(LW@[_#@XN7M[B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B
MR.WT[O#LX/;H_R#GX"#"X/$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*(RP@9G5Z>GD*;7-G:60@(DEN<V5R
M="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S
M='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R
M="!486)L92(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"B,L(&9U>GIY"FUS
M9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`BPNSZZNWH(._N
MY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@
M(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL
M(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S
M<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R
M="!C96QL(&%F=&5R(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R
M("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+E
MZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C4*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R
M87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I
M9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CR
MY>LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*
M;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@
M(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I
M9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW
M"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q
M,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("+(
MY^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS-`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`BS>#LY?#E[>@@[_#HZ^[FY>WH_SH@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@
M(LCG[_#@\N7MZ/+E(.3@[>WH(/'@(.WEXN#KZ.3MZ"XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M
M:71T960N(@IM<V=S='(@(LCG[_#@\N7MZ/+E(.3@[>WH(/'@(.WEXN#KZ.3M
MZ"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+(Y^_PX/+E[>CRY2#DX.WMZ"#Q
MX"#MY>+@Z^CD[>@N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R("+(Y^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD
M[>@N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`BR.?O
M\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("))
M;G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@
M(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))
M<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`BS>#JZ^[M
MY>WH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G
M<W1R("+-X.KK[NWE[>@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I
M9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R
M;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@
M8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,@HC+"!F=7IZ>0IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(D=R
M97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I
M9"`B2G5L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X
M"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(NO_XNX@[^[D\.#B
M[?_BX.WE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,34*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@0V5N=&5R
M(@IM<V=S='(@(NO_XNX@[^[D\.#B[?_BX.WE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU
M<W1I9GD@1G5L;"(*;7-G<W1R("+O^NOM[B#O[N3PX.+M_^+@[>4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(NO_XNX@[^[D\.#B[?_B
MX.WE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`BY/_Q
M[>X@[^[D\.#B[?_BX.WE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PHC+"!F=7IZ>0IM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`BQ^#A\.#MZ"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@\?KPXOKPX"#N\O7B^O#KZ"#HY.7M
M\NCTZ.K@]NC_\N`N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS
M9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")-:6UE
M(/+H[R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX
M"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`BR.?O[NOGXN#M
MY3HZ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS
M9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(LKK_O?@(.+E]^4@\?KYY?'RXO/BX"#B(._SX>OH]^WH
M_R#JZ_[W\?KPXOKP+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM
M<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI
M<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A
M;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU
M=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T
M86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX
M"B,L(&9U>GIY"FUS9VED("),85]Y;W5T(@IM<V=S='(@(LCG]>[D(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B
M"FUS9W-T<B`BQ>?HZB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L
M92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B
M3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`BS^#P[NO@.B`B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS
M9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`BSN_PY?'MZ"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@
M;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ
M>0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(L3@[>WH(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,L
M(&9U>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`BR.?U[N0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE
M9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU
M97,B"FUS9W-T<B`BS?_LX"#Q\N[I[>[Q\N@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*(RP@
M9G5Z>GD*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`BS.7R[N0B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(LWHZN[CX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"B,L(&9U>GIY"FUS9VED("),:6=H
M="!$<FEZ>FQE(@IM<V=S='(@(DQI9VAT($)L=64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B
M3&EG:'0@4F%I;B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM
M<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"B,L(&9U>GIY"FUS9VED("),
M:6=H="!3;F]W(@IM<V=S='(@(DQI9VAT($)L=64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO
M=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S
M='(@(L+U[N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED
M("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@
M=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I
M9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L
M<"!4;W!I8W,B"FUS9W-T<B`BS^[L[OD@\N7LZ"(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*
M;7-G<W1R("+/[NSN^2#RY>SH(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI
M<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B
M3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,B"FUS9W-T<B`BT>_H\?KJX"#Q(._N\O#EX>CRY>OH(.4@Y^#A\.#MY>TN
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B
MT>_H\?KJX"#Q(._N\O#EX>CRY>OH(.4@Y^#A\.#MY>TN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+1[^CQ^NK@(/$@[^[R\.7AZ/+E
MZ^@@Y2#GX.'PX.WE[2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*
M;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PHC+"!F=7IZ>0IM<V=I9"`B3&]A
M9&EN9RXN+B(*;7-G<W1R("+GX/#EYN3@[>4@[>`@X>CAZ^CN\N7JZ/+E+BXN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B
M3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`BPN#JX.WVZ/\B"@HC.B!L;V=I;BYP:'`Z,3<R
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@
M:6XB"FUS9W-T<B`BPO7NY"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(LCG]>[D(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R
M("+"]>[D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ
M>0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BQ^#DX/?H(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.3(*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS
M9W-T<B`B[_#NXN#KY>WN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(LCG]>[D
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"B,L(&9U>GIY"FUS9VED
M("),;W9E(@IM<V=S='(@(L_PY>S@]>WH(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R
M("+,S"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@
M(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B#O\.CJ\.7OY>WH__(@
M].#IZR#MY2#Q^N3Z\.;@^.4@Y.#M[>@N(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PHC
M+"!F=7IZ>0IM<V=I9"`B35-'(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@HC+"!F=7IZ>0IM<V=I9"`B36%C86\B"FUS9W-T<B`BPN#JX.WVZ/\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R("+/[OG@
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL
M(@IM<V=S='(@(L_N^>`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I
M9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@
M9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R("+/[OG@(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F
M=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R("+/[OG@(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R("+/[OG@(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI
M<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H
M+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R
M:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X
M"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U
M>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S
M"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`BT?KB[^#DX/GH(._N
MZ^7RX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@
M3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B
M36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("+7Z^7M[N+E(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R
M("+"Z.0@[>`@[.7M_O+N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(L_H\>SN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*(RP@
M9G5Z>GD*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*
M(G9E<FEF:65D+B(*;7-G<W1R("(B"B+/Z/'L[O+N(.'E^.4@[_#NXN7PY>WN
M(//Q[^7X[>XL(.WN(/'E\/+H].CJX/+@(.W@(._NY._H\>`@[>4@X>7XY2#O
M[O+B^O#DY>TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER
M960N(@IM<V=S='(@(L_H\>SN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM
M<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(L_H\>SN(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+$Y?+@Z>OH\N4@X?_UX"#PY>/H
M\?+PZ/#@[>@@Y^`@X.3LZ.WH\?+PX/+N\.`N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("+,Y?+NY"(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]2
M4$,O<V]A<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(LSE\N[D("<E
M<R<@[>4@Y2#DY?3H[>CPX.TB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN
M960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U
M"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L
M(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`B].#IZR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE
M(%1Y<&4B"FUS9W-T<B`B36EM92#RZ.\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R
M9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY
M"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BP_#E^.K@(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U
M"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE
M<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS
M9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B36]D
M97)A=&4B"FUS9W-T<B`BQ.#RX"#MX"#O\.[LY>W_[>4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G
M<W1R("+$X/+@(.W@(._P[NSE[?_MY2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("+,Y?'E]^WN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM
M<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I
M;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO
M<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0HC+"!F=7IZ>0IM<V=I
M9"`B36]V92!$;W=N(@IM<V=S='(@(N_PY>SE\?+H(.W@(.3NZ_,OY/_Q[>XB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(RP@
M9G5Z>GD*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("+O\.7LY?'RZ"#MX"#C
M[O#E+^O_XNXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HU,3<*(RP@9G5Z>GD*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B[_#E
M[.7Q\N@@[>`@Y.[K\R_D__'M[B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4P-0HC+"!F=7IZ>0IM<V=I9"`B36]V92!5<"(*;7-G
M<W1R("+O\.7LY?'RZ"#MX"#C[O#E+^O_XNXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"B,L(&9U>GIY"FUS9VED(")-
M;W9E(&1O=VXB"FUS9W-T<B`B[_#E[.7Q\N@@[>`@Y.[K\R_D__'M[B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`HC+"!F
M=7IZ>0IM<V=I9"`B36]V92!U<"(*;7-G<W1R("+O\.7LY?'RZ"#MX"#C[O#E
M+^O_XNXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED
M(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`BS.[_\N`@S^[YX"(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N
M="!);F9O<FUA=&EO;B(*;7-G<W1R("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A
M;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V
M"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@
M1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(LCLY2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N
M9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM
M<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B
M3F5T=V]R:R(*;7-G<W1R("+,\.7FX"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(LWHZN[CX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED
M(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L
M*2(*;7-G<W1R("+-[N+N(._N\O#EX>CRY>OQZNX@Z.SE("CN[_;H[NW@Z^WN
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY
M"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO@(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ
M>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B
MS>7J[O#EZO+MX"#OX/#NZ^`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R("+!Y>OEYNKH
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0HC+"!F=7IZ>0IM
M<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("+#\//OZ"(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H
M87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F
M=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(L[O]NCH(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS
M9W-T<B`BS>CJ[N/@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*
M;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ
M>0IM<V=I9"`B3FEU92(*;7-G<W1R("+1^N[A^>7MZ.4B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*
M;7-G<W1R("+-Y2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT
M;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L
M;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@[^#P[NO@
M(.?@($E-05`@Z.3E[?+H].CJX/;H_RXB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B)R5S)R#AY?CE(.3NX>#BY>T@ZOKL(/'H\?+E[.#RX"#GX"#O
M\.#BX"#MX"#O[O+PY>'H\N7KZ/+E+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z
M(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.KN[?3HX_/P
MX/;H_R#GX"!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#J
M[NWTZ./S\.#VZ/\@Y^`@1E10(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(LW_[.`@Y^#D
MX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB
M"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,+49I
M;&4@5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS
M9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+-_^S@(.?@Y.#D
MY>W@(.ONZN#KZ.?@]NC_+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,L(&9U>GIY"FUS9VED(").;R!M97-S
M86=E('-U<'!L:65D+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.ONZN#KZ.?@
M]NC_+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,V"B,L(&9U>GIY"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB
M"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#K[NK@Z^CGX/;H_RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC+"!F
M=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BS?_L
MX"#GX.3@Y.7MX"#K[NK@Z^CGX/;H_RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"B,L(&9U
M>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#OX/#NZ^`@Y^`@
M24U!4"#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#O
MX/#NZ^`@Y^`@24U!4"#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_L
MX"#GX.3@Y.7MX"#OX/#NZ^`@Y^`@2V5R8F5R;W,@Z.3E[?+H].CJX/;H_RXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-_^S@
M(.KN[?3HX_/PX/;H[NWMX"#H[?3N\.S@]NC_(.?@($Q$05`@Z.3E[?+H].CJ
MX/;H_RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-_^S@(.KN[?3HX_/PX/;H
M[NWMX"#H[?3N\.S@]NC_(.?@(%--0B#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
MS?_LX"#J[NWTZ./S\.#VZ.[M[>`@Z.WT[O#LX/;H_R#GX"!334(@Z.3E[?+H
M].CJX/;H_RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y
M('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O
M("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E
M;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM
M<V=S='(@(LW_[.`@\?+NZ>WN\?+H(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E
M8VEF:65D+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.ONZN#KZ.?@]NC_+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(L'EZ^7F
MZN@B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B
M3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G
M:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R
M("+-Y>KN\.7J\NW@(._@\.[KX"#HZ^@@[^[R\.7AZ/+EZ_'J[B#H[.4A(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(L+Z\.W@\NCRY2#D
MX.WMZ"#MY2#QX"!834PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(LW_[.`@
M\?+NZ>WN\?+H(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`BS>#O
M\.#BY>WN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)
M4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R
M=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*
M;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-#`X"B,L(&9U>GIY"FUS9VED(").;W0@82!D:7)E
M8W1O<GDB"FUS9W-T<B`BT?KGY.#BX.WE(.W@(.3H\.7J\N[PZ/\@)7,B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S='(@
M(L'EZ^7FZN@B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V
M-0HC+"!F=7IZ>0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BR.?O
M\.#YX.WE\NX@[>`@].#IZ^[BY2#MY2#QY2#O[N3D^O#FX"XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(L'EZ^7FZN@B"@HC.B!S97)V
M:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`BU^OE[>[BY2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R("+7
MZ^7M[N+E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I
M9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU
M;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@
M<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R("+.RB(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I
M9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@
M(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"B,L(&9U>GIY"FUS9VED(")/9F9I
M8V4B"FUS9W-T<B`BR.?JZRXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E
M(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS
M9W-T<B`BS^#P[NO@(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N(@IM<V=S='(@(LWEZN[PY>KR[>`@[^#P[NO@(.CKZ"#O[O+PY>'H\N7K
M\>KN(.CLY2$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D]M86XB
M"FUS9W-T<B`BPNKK+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@
M;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS
M(@IM<V=S='(@(L[O]NCH(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("+.[_;HZ"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@
M(D]R9&5R960@3&ES="(*;7-G<W1R("+/[N3PY>3E[2#Q[^CQ^NHB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ>0IM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@
M(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI>FEN
M9R(*;7-G<W1R(")/<F%N9V4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S
M-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M
M871I;VXB"FUS9W-T<B`BQ/#SX^`@Z.WT[O#LX/;H_R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(L_PX.+@(.W@(._PZ/+EYN#RY>O_(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BP_#E^.K@
M(._PZ"#HY.7M\NCTZ.K@]NC_(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME
M;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC
M($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM
M<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")01U`@4VAE
M;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B
M4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3
M=6XB"FUS9W-T<B`B4W5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X
M=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$T.0HC+"!F=7IZ>0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")01U`@
M4VAE;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BPNSZ
MZNWH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/
M8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U
M87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM
M<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO@(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`BS^#P[NO@.B`B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")087-S
M=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("+-_^S@(.KN[?3HX_/PX/;H[NWMX"#H[?3N\.S@]NC_(.?@(%)!1$E5
M4R#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I
M9"`B4&%S<W=O<F0Z(@IM<V=S='(@(L_@\.[KX#HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M("+/X/#NZ^`Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R("+-Y>KN\.7J\NW@(._@\.[KX"XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BPNSZZNWH(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I
M9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM
M<V=I9"`B4&%T:"(*;7-G<W1R("+"[/KJ[>@B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*
M;7-G:60@(E!E;W!L92(*;7-G<W1R("+0[NO_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-#D*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+$X"#QY2#HY^+Z\/CBX/(@Z^@@[N'Q
MZ_/FXN#YZ/+E(.[OY?#@]NCH(._PZ"#"]>[D/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,#8*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BQ.`@\>4@Z.?B^O#XXN#R(.OH
M(.[A\>OSYN+@^>CRY2#N[^7PX/;HZ"#O\.@@PO7NY#\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4&5R
M;6ES<VEO;B(*;7-G<W1R("+/\.#BX"(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S
M7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R("+/\.#BX"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T
M"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE(.W@(._PX.+@\N`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C4*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L
M($EN9F]R;6%T:6]N(@IM<V=S='(@(L3P\^/@(.CM].[P[.#VZ/\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`BTN7KY?3N[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM
M<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q
M"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G
M<W1R("+,[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CMX"XB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@HC+"!F=7IZ
M>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3HB"FUS9W-T<B`BS.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H[>`N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0HC+"!F=7IZ>0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T
M<B`BS.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H[>`N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0U,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92XB"FUS9W-T<B`BS.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H[>`N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@HBS.[K_RP@[_#N]^7RY?+E(/'KY>3MZ/_R(/+EZO'R+B`@PNCE(-+0W\'"
MP"#DX"#QY2#Q^N/KX/'H\N4@\2#S\>ONXNC_\N`@Y^`@(@HBZ.?O[NOGXN#M
MY2#MX"#QZ/'RY>S@\N`N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L
M(&9U>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`BT^3EX>7KY>WH(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED
M(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T
M=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG
M(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F
M;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA
M;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P
M+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S
M=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS
M9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"B,L(&9U>GIY"FUS9VED
M(")0<F5S<W5R93H@(@IM<V=S='(@(L_@\.[KX#H@(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G
M:60@(E!R979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S
M(&]P=&EO;G,B"FUS9W-T<B`BS_#EY^7M\N#VZ.@B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D
M;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*
M;7-G:60@(E!R;V)L96TB"FUS9W-T<B`BS_#NX>OE[#\B"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,C8*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96T@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`BS_KK[>X@[N_H\>#MZ.4Z(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(LKK_O?NXN`@Y.+NZ>K@(._SX>OH]^7M+_?@\?+E[2#JZ_[W(.WE(.'E
M^.4@X^7MY?#H\.#MX"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@
M4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED
M(")1871A<B(*;7-G<W1R("+$X.WMZ"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS9W-T
M<B`BRN[E].CVZ.7M\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN
M('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T
M<B`BRN[E].CVZ.7M\B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(M?E\N7MY2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY
M"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(L_H\>SN(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(LCQZN#RY2#DX"#HY_+PZ.7RY2`E<R#K
MZ#\@TN#GZ"#N[^7PX/;H_R#MY2#L[N;E(.3@(/'E(.+Z\.WE(.W@Y^#D+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`BR/'JX/+E(.3@(.CG\O#HY?+E("5S(.OH/R#2X.?H(.[OY?#@
M]NC_(.WE(.SNYN4@Y.`@\>4@XOKP[>4@[>#GX.0N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@
M(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@9G5Z
M>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(L[O\.7Q
M[>@@T.7G_NSE(.CGX^OEY.`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L
M871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(M?E\N7MY2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"B,L(&9U>GIY"FUS9VED(")2
M96UA<FMS(@IM<V=S='(@(L[R[.7RZN@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$T"B,L(&9U>GIY"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G
M<W1R("+"X/CH\N4@\?KPXOKPZ#HB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("+`Y/#E\2!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(L_PY>S@]>WH(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@0FQO8VLB"FUS9W-T<B`BS_#E[.#U[>@B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(L_PY>S@]>WH(/#EY_[LY2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(LCM
M].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,C@*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(L_P
MY>S@]>WH(/#EY_[LY2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*
M;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BS_#E[.#U[>@B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*
M;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`BS_#E[.#U
M[>@@[^[R\.7AZ/+EZSH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(L_PY>S@]>WH(._N\O#EX>CRY>LZ("5S(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G:60@
M(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@(@IM<V=S='(@(LW@(.?@[^CRXN#MY?+N(.WE(.'E^.4@[O+C[N+N
M\.7M[CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PHC
M+"!F=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+B(*;7-G<W1R("+-X"#GX._H\N+@[>7R[B#MY2#AY?CE(.[RX^[B
M[O#E[>XZ("(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-Y>[A]>[DZ.SH_R`G<&]R="<@
M[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@ZN[M].CC\_#@]NC_\N`N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(LWE[N'U[N3H[.C_("=P;W)T)R#MY2#E(.?@Y.#DY>T@XOKB(%9&4R#J
M[NWTZ./S\.#VZ/_RX"XB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW
M.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(LWE
M[N'U[N3H[.C_("=P;W)T)R#MY2#E(.?@Y.#DY>T@XOKB(%9&4R#J[NWTZ./S
M\.#VZ/_RX"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO@(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E)E<V5T
M(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BS^[RXOKPY.7RY2#OX/#NZ^#RX"(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S
M="!1=65R>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@
M861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM
M<V=I9"`B4F5S=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G
M:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F5V97)T
M($-O;F9I9W5R871I;VXB"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D1(5$U,(%)I8V@@5&5X="#P
MY>3@ZO+N\"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B
M4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I
M9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$W"B,L(&9U>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T
M<B`B3&EG:'0@0FQU92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`BT.[K_R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B
M4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM
M<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B
M4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(M#N
MZ_\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*
M(RP@9G5Z>GD*;7-G:60@(E)U;B(*;7-G<W1R(")3=6XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(M?E
M\N7MY2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U
M"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*
M(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R("+#\.7XZN`@[_#H(%--24U%(.KPZ._RZ/#@[>7R[B#MX"#OZ/'L[BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"B,L(&9U>GIY
M"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H_R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-
M97-S86=I;F<B"FUS9W-T<B`BS^CQ[.XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@4VAE;&PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R(")3
M4T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B4U]13"!3
M:&5L;"(*;7-G<W1R(")344P@4VAE;&PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI
M=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E("5S(@IM<V=S='(@(L[O\.7Q[>@@)7,B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHU"B,L(&9U>GIY"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`BSN_VZ.@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W
M"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM
M<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@
M(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y-S,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R("+(Y^'E\.@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E
M(@IM<V=S='(@(LCGX>7PY?+E(/'Z\.+Z\"(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B
M"FUS9W-T<B`BR.?AY?#E\N4@X_#S[^`@Y^`@Y.[AX.+_[>4B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@
M;W=N97(B"FUS9W-T<B`BR.?AY?#E\N4@[>[B(._PZ/+EYN#RY>L@[>`@X_#S
M[^`B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@
M(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("+(Y^'E\.7RY2#Q^O#B^O`B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T
M(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BR.?AY?#H(._N\O#EX>CRY>L@Y^`@
MY.[AX.+_[>4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<W"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@
M(LCGX>7PZ"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G
M<W1R("+(Y^'E\.7RY2#T[O#LX/(@Y^`@Q.#RX/+@.B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`BR.?AY?#E\N4@[>[B(._P
MZ/+EYN#RY>L@[>`@X_#S[^`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N
M92(*;7-G<W1R("+(Y^'E\.7RY2#M[N(@[_#H\N7FX/+EZR#MX"#C\//OX"(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B
M(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O
M>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE
M;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(LCGX>7PY?+E(.WE
M[N'U[N3H[.CRY2#"Z"#QZ.SB[NOH+B#1Z^7D(/+NXN`@X^@@ZN[OZ/#@Z?+E
M(.[R(/+EZO'R[N+N\NX@[^[KY2XB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS
M9W-T<B`BR.?AY?#E\N4@Q.#RX"#PX.?DY>OH\N7K.B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R
M;6%T.B(*;7-G<W1R("+(Y^'E\.7RY2#T[O#LX/(@Y^`@Q.#RX/+@.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@
M(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B
MR.?AY?#E\N4@Q.#RX"#PX.?DY>OH\N7K.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*
M;7-G<W1R("+(Y^'E\.7RY2#T[O#LX/(@Y^`@U^#QX#HB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RXB"FUS9W-T<B`BR.?AY?#E\N4@Y.+E(/'ZXN_@Y.#YZ"#O
M[NOE\N`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("+(Y^'E\.7RY2#B
MX/C@\N`@\?7E[.`@Y^`@]N+E\N[BY?+E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93HB"FUS9W-T<B`BR.?AY?#E\N4@[_#EY._N]^CRX.WH__(@[O(@PN#Q
M(.7GZ.HZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*
M;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@
M(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*
M;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"B,L(&9U>GIY"FUS9VED(")397!T
M96UB97(B"FUS9W-T<B`BU^OE[>[BY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G
M<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N
M($%D;6EN(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE(.W@(._PX.+@\N`B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G
M<W1R("+/\.#BX"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*
M(RP@9G5Z>GD*;7-G:60@(E-E="(*;7-G<W1R("+(Y^'E\.@B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O
M<'1I;VYS+B(*;7-G<W1R("+(Y^'E\.7RY2#O\.7D[^[WZ/+@[>C_\B#N\B#"
MX/$@Y>?HZCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@
M(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R("(B"B+'X.3@Z?+E(,+@^.7R[B#MX/?@Z^WN(._PZ.ON
MYN7MZ.4L(/'UY>S@(.?@(/;BY?+NXN4L(.[O\.7Q[?_BX.WE(.W@("(*(O'R
M\.#MZ/;@\N`@Z"#D\//CZ"#N[_;HZ"#GX"#DZ/'OZ^7_+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM
M<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA
M<GDB"FUS9W-T<B`BRO#@\NKN(/#EY_[LY3HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T
M<B`BS^[JX.?BX.WE(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS
M9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G
M:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PHC+"!F=7IZ>0IM<V=I
M9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BR.?AZ/#@[>4@[>`@]N+_\B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G
M:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G
M:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W
M97)S(@IM<V=S='(@(L_NZN#GXN#MY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H
M;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T
M=7)E($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R("+0X.?LY?`B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I
M9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R(*
M;7-G<W1R("+/[NK@Y^+@[>4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*
M;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W
M97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B
M4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O
M;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B
M"FUS9W-T<B`BP>CG[>7Q(.#D\.7Q(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS
M9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED
M(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("+"^N+EYN3@[>4@[>`@
M\>_E]NC@Z^WH(/'H[.+NZ^@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C8*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-O;'5M;B(*
M;7-G<W1R("+(Y^'E\.7RY2#J[NON[>@Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS
M9VED(")3=&%N9&%R9"(*;7-G<W1R("(E<R#1\N#MY.#P\B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L
M(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("+([?3N\.S@
M]NC_(.?@(,+@\2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R
M("+!Z.?MY?$@X.3PY?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T
M<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C(*(RP@9G5Z>GD*;7-G:60@(E-U(@IM<V=S='(@(E-U;B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M'K
M\_C@\N7K__(@)7,@[>4@Y2#MX.SE\.7M+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(E-U
M8FIE8W0B"FUS9W-T<B`BR.?AY?#H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q
M-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(LCG[_#@\N@B"@HC.B!S:6=N=7`N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@
M;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S
M='(@(LCG[_#@\N@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BT_'OY?4B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*
M;7-G<W1R("+3\>_E^.WN(.3NX>#BY>T@)R5S)R#J^NP@\>CQ\N7LX/+@+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("+3\>_E^.WN(._PY>S@]>W@
M\B`G)7,G(.[R(/'H\?+E[.#RX"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T
M<B`BT_'OY?CM[B#HY_+PZ/(@)R5S)RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(M/Q[^7X
M[>X@[_#E[.#U[>#R("<E<R<@[O(@\>CQ\N7LX/+@+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B
M"FUS9W-T<B`BT_'OY?CM[B#AY?CE(.[A[>[BY>T@)R5S)RXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R
M;W1E("5S(@IM<V=S='(@(M/Q[^7X[>X@X>7XY2#NX>WNXN7M("<E<R<N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M4W5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+*
M\.#RZNX@\.7G_NSE.B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM
M<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8X"B,L(&9U>GIY"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(E-U
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED(")3=6YN>2(*;7-G<W1R(")3=6XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"B,L(&9U>GIY"FUS9VED(")3
M=6YR:7-E(@IM<V=S='(@(E-U;B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3
M=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(E-U
M;G-E="(*;7-G<W1R(")3=6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3
M=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(N'EYR#H
M[.4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC
M+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("+AY><@Z.SE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L
M;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@
M:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G
M:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T
M;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(O3@Z>LB
M"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B5&%B;&4B"FUS9W-T<B`BQ.OZYNWN\?(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")4
M86)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R("+(Y^_NZ^?BX.WE.CHB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS
M(@IM<V=S='(@(L?@Y.#WZ"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^
M*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE
M(.W@(._N\O#EX>CRY>OH\N4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*(RP@9G5Z>GD*
M;7-G:60@(E1E>'0B"FUS9W-T<B`BT>#L[B#RY>KQ\B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("+1
MX.SN(/+EZO'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="!A;&EG;B(*
M;7-G<W1R("+1X.SN(/+EZO'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y
M"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O
M;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@
M:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N
M<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU
M;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T
M(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"B,L(&9U>GIY
M"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"B+2Y>?H(.3@[>WH(.?@
M(.KN[?+@ZO(@X?_UX"#S\>_E^.WN(.3NX>#BY>WH(.KZ["#"X/C@\N`@[_#N
MX_#@[.`N(,KKZ.KMY?+E(._N+2(*(N3NZ_,@Y^`@Y.`@XNCDZ/+E.B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*
M(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D
M('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(L_P
MZ.KPY>_E[>C_\B!01U`@[^[D[^CQ(.4@[>7NX?7NY.CL(.?@(.3@(/'E(._P
M[N+E\.@@[^[D[^CQX.WN\NX@[^CQ[.XN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D
M:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(LKPZ._RZ/#@[>7R[B#HY^CQZN+@(.KPZ._RZ/#@[>`@=V5B(.+P^N?JX"XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM
M<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(DU3+51.148@[_#HZO#E[^7MZ/_R(/3@Z>L@[>4@\?KD^O#FX/CE
M(.3@[>WH+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*
M;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@HBS.7Q\N[O[NONYN7MZ.7R[B#MX"!';G50
M1R#TX.GKX"#R\/_AXN`@Y.`@X?KDY2#DX.3E[6\@[>`@0W)Y<'1?<&=P.CH@
M8VQA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY
M"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M(@IM<V=S='(@(M+@Y^@@\?+NZ>WN\?(@\O#_X>+@(.3@(.4@]^CQZ^XN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"B,L(&9U
M>GIY"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("+,[N3S
MZ_KR($]P96Y34TP@Y2#MY>[A]>[DZ.P@Y^`@0W)Y<'1?<VUI;64Z.B!C;&%S
M<RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@
M;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*
M(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*
M;7-G<W1R("(B"B+/\.[C\.#LX/+@+"#J[O_R[B#QZ_/FZ"#GX"#O[NK@Y^+@
M[>4@[>`@\N[GZ"#RZ.\@Y.#M[>@@*"5S*2#MY2#AY?CE(.[RZO#H\N`@(@HB
MXB#QZ/'RY>S@\N`B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I
M9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF
M:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(DAO<F1E(%!/(/3@Z>L@Y^`@Z^[JX.OHY^#VZ/\@)7,@
M[>4@\?KYY?'RXO/BX#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H
M('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G
M:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A
M9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I
M9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N(@IM<V=S='(@(LW_[.`@Y.+NZ>KH+"#J[NCR[B#DX"#A^N3@
M\B#O[NK@Y^#MZ"#B(.OH[>C_\N`N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`BS?_LX"#D
MXN[IZN@L(.KNZ/+N(.3@(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_RX"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B+([.`@
M\N+Z\.3E(.SM[N/N(/'H[.+NZ^@@XB#R[N+@(._NZ^4N(,+ZXN7KZ"#Q\N4@
M)7,@\>CLXN[KX#L@\O#_X>+@(.3@("(*(N+ZXN7DY?+E(._N+>S@Z^KN(.[R
M("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+#\.7X
MZN`@[_#H(.3NX>#B_^WE(.W@("<E<R<@ZOKL(/'H\?+E[.#RX"XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BP_#E^.K@(._PZ"#O
M\.7LX/7BX.WE\NX@[>`@)R5S)R#N\B#QZ/'RY>S@\N`N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R("+#\.7XZN`@[_#H(._PY>S@]>+@[>7R[B#MX"`G)7,G
M(.[R(/'H\?+E[.#RX"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D
M871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(.[O\.7Q[?_B
MX.WE(.W@("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"XB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX#H@
M)7,@[>4@X>7XY2#HY^_PX/+E[2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2XB"FUS9W-T<B`B(@HBR.S@^.4@[_#NX>OE["#O\.@@Z.?O\.#Y
MX.WE\NX@[>`@].#IZ^`N("5S(.4@[^XMX^[K_^P@[O(@[.#J\>CLX.OM[B`B
M"B+D[N_S\?+H[.C_(/#@Y^SE\"`H)60@X>#I\N`I+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@+B`E<R#AY?CE(/'@
M[.X@[O+WX/'RZ"#HY^_PX/+E[2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G
M<W1R("+#\.7XZN`@[_#H(._P[N+E\.K@\N`@[>`@\N[BX"#OZ/'L[BXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.SO[O#R(.W@(.3@[>WH(.?@(.KN
M[?+@ZO+H+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.SO[O#R
MZ/#@[>4@[>`@Z.?A\.#MZ/+E(.3@[>WH(.?@(.K@Z^7MY.#P+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BP_#E
M^.K@(._PZ"#H[._N\/(@[>`@Y.#M[>@@Y^`@ZN[M\N#J\N@N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*(RP@9G5Z
M>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Z.SO[O#R(.W@(.3@[>WH(.?@(.KN[?+@ZO+H
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T
M.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`BTN[B
MX"#MY2#E(.+@Z^CDY>T@<F%R(.#P]>CB+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(M+NXN`@
M[>4@Y2#BX.OHY.7M('II<"#TX.GK+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E
M;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("+2[N+@(.WE
M(.4@XN#KZ.3E[2!R87(@X/#UZ.(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#
M;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R
M96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510
M('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@
M=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI
M="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q
M-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N(@IM<V=S='(@(M+NXN`@[^[KY2#E(.WE[N'U[N3H[.XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("+2
M[N+@(._NZ^4@[.[FY2#DX"#Q^N3Z\.;@(/'@[.X@]N7KZ"#WZ/'KX"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*
M;7-G<W1R("+2[N+@(._NZ^4@[.[FY2#DX"#Q^N3Z\.;@(/'@[.X@]^CQZ^`@
MZ"#DXN[E\N[WZ.4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y
M-`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`BTN[BX"#O[NOE(.SNYN4@Y.`@\?KD
M^O#FX"#QX.SN(.WN[.7PX"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("+2[N+@
M(._NZ^4@\O#_X>+@(.3@(.4@Y^#OY?+@_R#HZ^@@Z.WRY?#BX.L@\.#GY.7K
MY>T@\>_H\?KJ(._P[NSE[>OHXN@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BTN#GZ"#Q\N[I[>[Q\B#R\/_AXN`@
MY.`@Y2#WZ/'K[BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V
M"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R
M,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S
M<V5D+B(*;7-G<W1R("+2X.?H(/3N\.S@(.+E]^4@X>7XY2#NX?#@X>[RY>W@
M+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H
M870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O
M<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`BTN[BX"#WZ/'K[B#R\/_AXN`@Y.`@Y2#O
M[NWE(.7DZ.WH]N`N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`BTN[GZ"#Q^O#B^O`@
M[>4@[.[FY2#DX"#DY>KN[._PY?'H\.`@>FEP(.@@9WII<"#TX.GK[N+E+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS
M9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T
M"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@
M(M+@Y^@@\?+NZ>WN\?(@\O#_X>+@(.3@(.4@]^CQZ^XN(@H*(SH@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD
M;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S
M='(@(L3K^N;M[O'R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X
M-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("+/\.[QZ^7D_^+@[>4@
M[>4@XO#E[.4B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I
M;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(L3K
M^N;M[O'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS
M9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP
M;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"B,L(&9U>GIY"FUS
M9VED(")4;V1A>2(*;7-G<W1R("(@*.3MY?$I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A4
M34P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*
M;7-G:60@(E1O9V\B"FUS9W-T<B`BR.?U[N0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U>GIY
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`BS_#EY^7M\N#VZ.@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@
M(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"B,L(&9U>GIY"FUS9VED(")4=7)K97DB"FUS9W-T<B`B
M1W)E>2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K
M:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM
M<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM
M<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`B
M55),(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T
M<B`BS^[D]^7P\N#MZ"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O
M;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#GX"#B
M\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`BP_#E^.K@
M(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q
M-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP
M.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("+-
MY>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@4U%,(/'Z\.+Z\"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BS>7B^N?L
M[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE
M\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F
M<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7R
MY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#GX"#B
M\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]G>FEP+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E
M8V]M<')E<W,@9&%T82XB"FUS9W-T<B`BP_#E^.K@(._PZ"#N\N+@\/_MY?+N
M(.W@(.KN[._PY?'H\.#M(.#P]>CB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(L/P
MY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB.B`E<RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B
MP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,U,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
MP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L/P
MY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB
M+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R
M>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@
M[^K@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S
M"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT
M-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@
M)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E
M(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@
M4U%,(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PHC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7QZ/#@[2#@\/7H
MXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB"FUS9W-T<B`BP_#E^.K@(._PZ"#N\N+@\/_MY?+N(.W@
M(.KN[._PY?'H\.#M(.#P]>CB+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`BP_#E^.K@(._PZ"#N\N+@\/_MY?+N
M(.W@(.KN[._PY?'H\.#M(.#P]>CB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE
M<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@
M=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E
M\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@
M[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T
M(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')U
M;B`G;6MI<V]F<R<N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#EXN[DX"#MX"#R[N?H
M(%=O<F0@Y.[J\^SE[?(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5
M;F1E<FQI;F4B"FUS9W-T<B`BS^[D]^7P\N#MZ"(*"B,Z('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"B,L(&9U
M>GIY"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R("+-Y>+@Z^CDY>T@[O+C[N+N\"#N\B#Q
M^O#B^O#@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T
M"B,L(&9U>GIY"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B`B"FUS9W-T<B`BS>7BX.OHY.7M(.[RX^[B[O`@[O(@\?KPXOKP
MX"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8Q"B,L(&9U>GIY"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(N_P[N+@
MZ^7M[B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N
M:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*(RP@9G5Z
M>GD*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(LWEZN[PY>KR[>`@[^#P[NO@(.CKZ"#O[O+PY>'H\N7K\>KN(.CLY2$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(N'EYR#H[.4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y
M"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL
M;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@
M(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R
M"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("+.
M[_#E\>WH(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`BSN_P
MY?'MZ"`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S8*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(L[O\.7Q
M[>@@)7,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(L[O\.7Q[>7M82`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED
M(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G
M:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B
MS^[R\.7AZ/+EZ^@B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO
M="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(L#D[.CMZ/'R\.CPX.WE(.W@(._N\O#EX>CRY>OH\N4B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC+"!F=7IZ>0IM<V=I9"`B57-E
M<B!/<'1I;VYS(@IM<V=S='(@(L[O]NCH(@H*(SH@<VEG;G5P+G!H<#HV,@HC
M+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`BP.3L
MZ.WH\?+PZ/#@[>4@[>`@[^[R\.7AZ/+EZ^CRY2(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`BR.SE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(LCL
MY3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5
M<V5R;F%M93H@(@IM<V=S='(@(LCLY3H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`BS^[R\.7AZ/+EZ^@@XB#QZ/'RY>S@\N`Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X
M"FUS9VED(")686-A=&EO;B(*;7-G<W1R("+"X.K@[?;H_R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"B,L
M(&9U>GIY"FUS9VED(")686QU97,B"FUS9W-T<B`BS?_LX"#Q\N[I[>[Q\N@B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*
M;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE
M9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#NXN7PZN#RX"`M(/+NXN`@[^CQ[.X@
M[.[FY2#DX"#E(.'HZ^X@[^[D[_#@XN7M[BXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO
M;B(*;7-G<W1R("+/\.#BX"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T
M:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*(RP@9G5Z>GD*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(LCLY2#MX"#T
MX.GK(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N
M86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM
M<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I
M9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B
M5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B
M5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(M'E
MY.SH]^WN(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@
M9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`BQ.[A\.4@Y.[XZ^@L("5S
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O
M;64@=&\@)7,B"FUS9W-T<B`BQ.[A\.4@Q.[XZ^@@XB`E<R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G
M<W1R("+$[N'PY2#D[OCKZ"P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("+(Y^'E
M\.7RY2#O\.CK[N;E[>CE\NXL(.KNY?+N("5S(.3@(._NZN#FY2#QZ^7D(.+U
M[N0N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@
M(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7
M:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@
M=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*
M;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED
M(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"B,L(&9U>GIY"FUS9VED
M(")7:6YD.B`B"FUS9W-T<B`BPNWH[.#MZ.4Z("(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B
M5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+!
MZ.?MY?$@X.3PY?$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(L'HY^WE
M\2#RY>OE].[M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R
M96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M65DB"FUS9W-T<B`BP\,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`B
MP\,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R
M;'DB"FUS9W-T<B`BP^[DZ/CM[B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*
M;7-G:60@(EEE;65N(@IM<V=S='(@(D=R965N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S
M='(@(L3@(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED
M(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B
M;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS
M,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D
M<F5S<RXB"FUS9W-T<B`BS>4@XOKBY>3N]?+E(.+@Z^CDY>T@96UA:6P@X.3P
MY?$N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O
M;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L
M9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+B(*;7-G<W1R("+"X/CH\N4@ZN[M].CC\_#@]NCN[>WH(.[O]NCH
M(.'_]>`@[N'M[N+E[>@N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(LWE(.+ZXN7D[O7RY2#BX.OHY.7M(&5M86EL(.#D\.7Q+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+2\/_AXN`@
MY.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#HY_+PZ.+@[>4N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("+2\/_AXN`@
MY.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#HY_+PZ.+@[>4N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("+2\/_AXN`@Y.`@Y^#DX.3E\N4@
M[^[R\.7AZ/+EZR#GX"#HY_+PZ.+@[>4N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@
M(M+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.3NX>#B_^WE+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("+2\/_AXN`@Y.`@
MY^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#N[_#E\>W_XN#MY2XB"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@
MZ.?R\.CBX.WE+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(M+P_^'BX"#DX"#GX.3@
MY.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R
M($5M86EL($%D9')E<W,B"FUS9W-T<B`BPN#XZ/\@16UA:6P@X.3PY?$Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("+"X/CH_R!%;6%I;"#@Y/#E
M\3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB
M"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#"X/$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!.86UE(@IM<V=S='(@(L+@^.7R[B#H[.4Z(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M(L+@^.C_\B#HY.7M\NCTZ.K@]NCN[>7M(.3PX.GBY?`@[>4@[^[DY/KPYN`@
MY.[AX.+_[>4@[>`@[^[R\.7AZ/+EZ^@L(.CKZ"`B"B+RX.?H(.+ZY^SNYNWN
M\?(@Y2#GX.'PX.WE[>`N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(@IM<V=S='(@(B(*(L+@^.C_\B#HY.7M\NCTZ.K@]NCN[>7M(.3PX.GB
MY?`@[>4@[^[DY/KPYN`@\>_H\?KJ(.W@(._N\O#EX>CRY>OH\N4L(.CKZ"`B
M"B+RX.?H(.+ZY^SNYNWN\?(@Y2#GX.'PX.WE[>`N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS
M9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("+"X/CH
M\N4@ZN[M].CC\_#@]NCN[>WH(.[O]NCH(.'_]>`@[N'M[N+E[>@N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("+(Y.7M\NCW[>[Q\B#O[B#O
M[N3PX.?AZ/#@[>4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BPN#XY?+N
M(.CLY3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("+"
MX/CH\N4@ZN[M].CC\_#@]NCN[>WH(.[O]NCH(.'_]>`@[N'M[N+E[>@N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+"
MX/CH\N4@ZN[M].CC\_#@]NCN[>WH(.[O]NCH(.'_]>`@[N'M[N+E[>@N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BPN#XZ/+E
M(.KN[?3HX_/PX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S
M='(@(L+@^.CRY2#Q^O#B^O#H.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O
M<G1=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EOKZ.WH_R`E<R#N\B`E<UTB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B7T%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE(@H*(SH@;&EB+V%P:2YP:'`Z
M,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M,0HC+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(L3@[>WH(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Q"B,L(&9U>GIY"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R("+(
MY_+PZ.DB"@HC.B!L:6(O87!I+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E]'
M<F]U<',B"FUS9W-T<B`BP_#S[^@B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")?2&5L<"(*;7-G<W1R
M("+/[NSN^2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("+"]>[D(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ
M>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BR.?U[N0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G
M:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R("+.[_;HZ"(*"B,Z(&QI8B]A<&DN<&AP.C$S-PHC+"!F
M=7IZ>0IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S
M"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M("+/[O+PY>'H\N7KZ"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BP.3P
MY?'E[2#AY>OEYNWHZB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ>0IM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BRN#KY>WDX/`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E
M871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N
M9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I
M=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F
M;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F
M;W5N9"(*;7-G<W1R("+MY2#AY?CE(.W@[.7PY>TB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M-34*;7-G:60@(F9I;&4B"FUS9W-T<B`B].#IZR(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y
M"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B
M:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I
M;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(FEN
M;&EN92(*;7-G<W1R("+/[N3WY?#RX.WH(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*(RP@9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R("+'X./KX.+H_R(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O
M9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR
M.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N86UE
M(@IM<V=S='(@(LCLY2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*
M;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@
M:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM
M<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`BS_#@XN`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,PHC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(L+MZ.S@[>CE(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@
M(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB
M"FUS9W-T<B`BU^7RY>WE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I
M9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@
M(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB
M"FUS9W-T<B`BPO'_ZNX@Z^[CXN#MY2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B[_#NXN#K
MY>WN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I
M9"`B=6YN86UE9"(*;7-G<W1R("+AY><@Z.SE(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U
M<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#
M87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O9G)?1E(N
M<&\`````````````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#<T-3<V,P`Q,#4Q-30S,3`V,P`P,38T,3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!(;W)D92`S+C$N,2!&<F5N
M8V@@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`Q+3(P,#(@5&AE
M($AO<F1E(%!R;VIE8W0N"B,@4&EE<G)E($QA8VAA;F-E(#QP;$!P:65R<F5L
M86-H86YC92YN970^(&5T($)E;F]I="!3="U!;F1RZ2`H8F5N0&)E;F]I='-T
M+6%N9')E+FYE="DL(#(P,#,L(#(P,#0N"B,@1G)E9&5R:6,@5')U9&5A=2`\
M9G1R=61E875`8V%M+F]R9SXL(#(P,#$N"B,@5&AI97)R>2!4:&]M87,@/'1H
M:65R<GE`<&]M<&\N;F5T/BP@,C`P,BP@,C`P-2P@,C`P-BX*(R!#;W5N=')Y
M('1R86YL871I;VYS(&9R;VT@36EG=65L(%1R96UB;&%Y(#QK8F%B96PN;6EG
M=65L0'!T869F+F-A/BP@,C`P-"X*(R!"96YO:70@4W0M06YD<ND@/&)E;D!B
M96YO:71S="UA;F1R92YN970^+"`R,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!F<E]&4EQN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#,M,S$@,C(Z,S`K,#(P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!4:&EE<G)Y(%1H;VUA<R`\=&AI97)R>4!P;VUP;RYN970^7&XB"B),
M86YG=6%G92U496%M.B!&<F5N8V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN
M(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([
M('!L=7)A;#TH;B`^(#$I.UQN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,V-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*
M;7-G<W1R("(@*&EL('D@82`E<R!J;W5R<RDB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$S.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B`H5&]U8VAE(&0G86-CZ',@<F%P:61E("5S
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&1A;G,@)7,@
M:F]U<G,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,`IM<V=I
M9"`B("AT;V1A>2DB"FUS9W-T<B`B("AA=6IO=7)D)VAU:2DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<R"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("(@*&1E;6%I;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S8X"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AH:65R*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B#@("(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(JN@)7.@
MNR!N)V5S="!P87,@=6X@9&]S<VEE<B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M('9A;&ED(&-H;VEC92XB"FUS9W-T<B`BJZ`E<Z"[(&XG97-T('!A<R!U;B!C
M:&]I>"!V86QI9&4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HW,3`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(JN@
M)7.@NR!N)V5S="!P87,@8V]N9FEG=7+I(&1A;G,@;&4@<F5G:7-T<F4@9&4@
M2&]R9&4N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"XB"FUS9W-T<B`B3"=I;G1E<G!RZ71E=7(@9"=A<F)R92"KH"5SH+L@;B=A
M('!A<R#I=.D@=')O=7;I+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2XB"FUS9W-T<B`BJZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S
M>7-TZ&UE(&1E<R!G<F]U<&5S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(JN@)7.@NR!A
M(.ETZ2!A:F]U=.D@874@<WES=.AM92!D97,@<&5R;6ES<VEO;G,N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(JN@)7.@NR!N)V$@<&%S(.ETZ2!C<NGIH#H@)7,N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I
M(@IM<V=S='(@(B4N,F:@36\@=71I;&ESZ7,@<W5R("4N,F:@36\@<&5R;6ES
M("@E+C)FH"4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@
M(B5D("5S(&5T("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB
M"FUS9W-T<B`B)60@:F]U<G,@879A;G0@;"=E>'!I<F%T:6]N(&1E('9O=')E
M(&UO="!D92!P87-S92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(E9"UP<NEV:7-I;VX@9'4@:F]U<B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO
M=&EC92(*;7-G<W1R("(E<R`M($YO=&EC92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($9I;F=E<G!R:6YT(@IM<V=S='(@(D5M<')E:6YT92!01U`@9&4@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($M"(@IM<V=S='(@(B5SH$MO(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@
M;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92`F;F1A<V@[($-O;F9I<FUA=&EO
M;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*
M;7-G<W1R(")#;VYF:6=U<F%T:6]N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M:6=N(%5P(@IM<V=S='(@(DEN<V-R:7!T:6]N(&1E("5S(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R(")#;VYD:71I;VYS(&0G=71I
M;&ES871I;VX@9&4@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T
M<RXB"FUS9W-T<B`B)7,@97AI<W1E(&3I:N`N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M870@)7,@)7,B"FUS9W-T<B`B("5SH.`@)7,@)7,B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*
M;7-G<W1R("(B"B(E<R!E<W0@<'+J="#@(&5F9F5C='5E<B!L97,@;W#I<F%T
M:6]N<R!D92!M86EN=&5N86YC92!C;V-HZ65S(&-I+61E<W-O=7,N("(*(E/I
M;&5C=&EO;FYE>B!L82!O=2!L97,@;W#I<F%T:6]N*',I('%U92!V;W5S('9O
M=6QE>B!E9F9E8W1U97(@8V5T=&4@9F]I<RUC:2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S,W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES
M(')E<75I<F5D(@IM<V=S='(@(B5S(&5S="!O8FQI9V%T;VER92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71E<R(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N;VX@=')O=7;I(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<Z#@("5S(&1E
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B0V%R
M;F5T(&0G861R97-S97,@9&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(D%G96YD82!D92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A
M9"(*;7-G<W1R(")";&]C+6YO=&5S(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!4
M87-K;&ES="(*;7-G<W1R("),:7-T92!D92!TXF-H97,@9&4@)7,B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G
M<W1R("(E<Z`Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7.@.B!L)^EM971T975R(&1E(&-E(&UE
M<W-A9V4@82!P=2#J=')E(&9A;'-I9FGI+B!!='1E;G1I;VX@96X@<W5I=F%N
M="!L97,@(@HB;&EE;G,@<74G:6P@8V]N=&EE;G0@;W4@96X@9F]U<FYI<W-A
M;G0@9&5S(&EN9F]R;6%T:6]N<R!P97)S;VYN96QL97,@X"`B"B)L)^EM971T
M975R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG
M("(*;7-G<W1R("(L(&5N(')A9F%L92`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B<F%F86QE("5S("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(G9A<FEA
M8FQE(&1U("5S(&%U("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HW-#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!3
MZ6QE8W1I;VYN97(@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G
M:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA="`Q,B!H975R97,B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R
M;6%T(@IM<V=S='(@(D9O<FUA="`R-"!H975R97,B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@
M:&5U<F5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I
M9"`B/%!R979I;W5S(@IM<V=S='(@(CQ0<NECZ61E;G0B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")5;F4@8F%S92!D
M92!D;VYNZ65S('!R:6YC:7!A;&4@*&)A8VME;F0I(&5S="!NZ6-E<W-A:7)E
M('!O=7(@8V4@8FQO8R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R
M(")5;F4@97)R975R(&9A=&%L92!S)V5S="!P<F]D=6ET92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B56YE(&-L968@<'5B;&EQ=64@4$=0(&5S="!NZ6-E<W-A:7)E('!O
M=7(@8VAI9F9R97(@=6X@;65S<V%G92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("(B"B)5;F4@8VQE9B!P=6)L:7%U92!01U`@97-T(&[I8V5S<V%I<F4@<&]U
M<B!VZ7)I9FEE<B!L82!S:6=N871U<F4@9"=U;B!M97-S86=E+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B)5;F4@8VQE9B!P=6)L:7%U92!01U`L('5N92!C;&5F('!R:7;I
M92!01U`L(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I
M<F5S('!O=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)5
M;F4@8VQE9B!P=6)L:7%U92!01U`L('5N92!C;&5F('!R:7;I92!01U`L(&5T
M('5N92!P:')A<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I<F5S('!O=7(@
M<VEG;F5R('5N(&UE<W-A9V4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@
M8VQE9B!P=6)L:7%U92!3+TU)344L('5N92!C;&5F('!R:7;I92!3+TU)344L
M(&5T('5N92!P:')A<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I<F5S('!O
M=7(@9.EC:&EF9G)E<B!U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB
M56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-
M24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="`B"B)NZ6-E<W-A:7)E
M<R!P;W5R('-I9VYE<B!U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(E5N92!C;&5F('!U8FQI<75E(%,O34E-12!E<W0@;NEC97-S86ER92!P;W5R
M(&-H:69F<F5R('5N(&UE<W-A9V4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@
M(DYU86=E<R!L92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@
M(E!L=6EE(&SI9^AR92!L92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@
M(E!L=6EE(&QE(&UA=&EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B079E
M<G-E<R!L92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M0VAU=&5S(&1E(&YE:6=E(&QE(&UA=&EN(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P
M"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@
M=&AI<R!E9&ET;W(B"FUS9W-T<B`BP"!P<F]P;W,@9&4@8V5T(.ED:71E=7(B
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N
M+BXB"FUS9W-T<B`BP"!P<F]P;W,N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS
M9W-T<B`B0F%S(&%B<V]L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")-
M:6QI974@86)S;VQU(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(")!8V/H<R!R969U<^D@;&]R<R!D92!L82!C<NEA=&EO
M;B!D92!RZ7!E<G1O:7)E(%9&4R`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92XB"FUS9W-T<B`B06-CZ',@<F5F=7/I(&QO<G,@9&4@;&$@8W+I
M871I;VX@9&4@9FEC:&EE<B!61E,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B1&]N
M;NEE<R!P97)S;VYN96QL97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B36]T(&1E('!A
M<W-E(&1U(&-O;7!T92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM
M<V=S='(@(D-O;7!T92!I;F%C=&EF(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")#;VUP=&5S
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B06IO=71E
M<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B06IO=71E<B!U
M;B!S;W5S+6=R;W5P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B
M061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B06IO=71E<B!U;F4@;F]U
M=F5L;&4@<V]U<RUP97)M:7-S:6]N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!:F]U=&5R(&EC
M::`Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H
M<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B06IO=71E<B!U
M;B!N;W5V96%U(&=R;W5P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I
M9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D%J;W5T97(@=6YE(&YO
M=79E;&QE('!E<FUI<W-I;VXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")!:F]U=&5R('5N(&=R;W5P
M92!F:6QS(.`@JZ`E<Z"[(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B06IO=71E<B!U;F4@<&5R;6ES
M<VEO;B!F:6QL92#@(*N@)7.@NR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS
M9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B06IO=71E<B!U;B!N;W5V
M96P@=71I;&ES871E=7*@.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M06IO=71E<B!U;F4@8V]L;VYN92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R
M(")!:F]U=&5R(&1E(&YO=79E875X(&UE;6)R97,B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")!
M:F]U=&5R('5N92!P86ER92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(D%J;W5T97(@;&4@;65N=2`E<R#@
M(&QA(&)A<G)E(&1E($UO>FEL;&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O
M;VLZ(@IM<V=S='(@(D%J;W5T97(@874@8V%R;F5T(&0G861R97-S97.@.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM
M<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!:F]U=&5R
M(.`@;6]N(&-A<FYE="!D)V%D<F5S<V5S(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D%J;W5T97(@=6X@=71I;&ES
M871E=7(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD
M(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S
M+B(*;7-G<W1R("(B"B*KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64L
M(&UA:7,@;"=A:F]U="!D)VEN9F]R;6%T:6]N('-U<'!LZ6UE;G1A:7)E<R`E
M(@HB<R!N)V5S="!P87,@<&]S<VEB;&4N(@H*(SH@<VEG;G5P+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("*KH"5SH+L@82#I=.D@
M86IO=73I+B!6;W5S('!O=79E>B!V;W5S(&-O;FYE8W1E<BXB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),82!F;VYC=&EO;B!D)V%J;W5T
M(&0G=71I;&ES871E=7)S(&5S="!DZ7-A8W1I=NEE+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#,X"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S
M<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`B0V%R;F5T(&0G861R97-S97,B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS
M9W-T<B`B061M:6YI<W1R871E=7(@+2!A:G5S=&5R(&QE<R!P97)M:7-S:6]N
M<R!P;W5R(&0G875T<F5S('5T:6QI<V%T975R<R(*"B,Z(&%D;6EN+VEN9&5X
M+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G
M<W1R(")0=6)S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B069G:&%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA
M(@IM<V=S='(@(D%L8F%N:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA
M(@IM<V=S='(@(D%L9^ER:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L:6=N97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED
M(")!;&EG;FUE;G0Z(@IM<V=S='(@(D%L:6=N96UE;G2@.B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E1O=70B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E
M9"!5<V5R<R(*;7-G<W1R(")4;W5S(&QE<R!P87)T:6-I<&%N=',@875T:&5N
M=&EF:>ES(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N
M<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")4;W5S(&QE<R!G
M<F]U<&5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!
M;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&]U=&5S(&QE<R!P97)M:7-S:6]N
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(DQE<R!Q
M=6%T<F4@8_1TZ7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8X
M"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B4&5R
M;65T=')E(&1E<R!A9')E<W-E<R!D92!C;W5R<FEE;"!M=6QT:7!L97,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")!=71O<FES97(@
M;&$@;6ES92!E;B!P;&%C92!D92!L:7-T97,@;G5MZ7)O=.EE<Z`_(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED
M(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")%>&ES=&4@9.EJX"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0
M($QO9VEN(@IM<V=S='(@(DYO;2!D)W5T:6QI<V%T975R($E-4U`@86QT97)N
M871I9B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L
M=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(DUO="!D92!P87-S92!)
M35-0(&%L=&5R;F%T:68B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S
M"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(").;VT@
M9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`B061R97-S92!D92!C;W5R<FEE;"!A;'1E<FYA=&EV
M92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%U=')E<R!M;V3H;&5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B5&5X=&4@86QT
M97)N871I9J`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`B4V%M;V$@06WI<FEC86EN(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*
M;7-G<W1R(")5;F4@=F%L975R(&EL;.EG86QE(&$@Z73I('-PZ6-I9FGI92XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")5;F4@97)R
M975R(&EN8V]N;G5E(',G97-T('!R;V1U:71E+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*
M;7-G<W1R(")0<F]X>2!A;F]N>6UE(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")2Z7!O;G-E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<F-T
M:7%U92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B
M"FUS9W-T<B`B06YT:6=U82UE="U"87)B=61A(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S8*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<'!L
M:6-A=&EO;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B
M07!P;&EC871I;VX@3&ES="(*;7-G<W1R("),:7-T92!D)V%P<&QI8V%T:6]N
M<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI
M8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("),)V%P<&QI8V%T:6]N(&5S="!P
M<NIT92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED
M(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B07!P;&EQ=65R(&%U
M>"!P87)T86=E<R!F:6QS(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!P<F]U=NDB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`*;7-G
M:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B5&%I;&QE(&%P<')O>&EM
M871I=F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B079R:6PB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I
M(@IM<V=S='(@(D%R86)E("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM
M<V=S='(@(E1A:6QL92!D=2!F:6-H:65R(&%R8VAI=F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S
M='(@(DYO;2!D92!L)V%R8VAI=F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*(LIT97,M=F]U<R!C97)T86EN(&1E
M('9O=6QO:7(@<W5P<')I;65R(&-E='1E(')E<77J=&4@9"=I;G-C<FEP=&EO
M;B`@<&]U<B`E<Z`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*
M;7-G<W1R("+*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L;VER(&5F9F%C97(@
MJZ`E<Z"[(&5T('-E<R!S;W5S+6=R;W5P97.@/R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;>EN:64B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB
M"FUS9W-T<B`B07)MZ6YI96X@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")!<G0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B07-C96YS:6]N("C.;&4I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07)T($%3
M0TE)(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(E+I9VEO;B!!<VEE+U!A
M8VEF:7%U92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@
M(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/R(*;7-G<W1R("(B"B)$96UA;F1E<B!U;F4@8V]N9FER
M;6%T:6]N(&%V86YT(&1E(&QA;F-E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN
M=&5N86YC9:`_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y,@IM
M<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D-O;&]N;F5S(&1E
M<R!TXF-H97,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B
M5&5N=&%T:79E(&0G969F86-E;65N="!D)W5N(&=R;W5P92!I;F5X:7-T86YT
M+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(E1E;G1A=&EV92`@9"=E9F9A8V5M96YT(&0G=6YE('!E<FUI<W-I;VX@
M:6YE>&ES=&%N=&4N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")496YT871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6YE('!E
M<FUI<W-I;VX@:6YE>&ES=&%N=&4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N(@IM<V=S='(@(E1E;G1A=&EV92!D92!M;V1I9FEC871I;VX@
M9"=U;B!P87)T86=E(&EN97AI<W1A;G0N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B4')O<')I
MZ73I<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B06_[="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(D%U=')I8VAE(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]C>7)U<Z`Z($5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N
M('1R;W5VZ64N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@
M<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7.@.B!L
M92!B86-K96YD(&XG82!P87,@;&5S(&-A<&%C:73I<R!R97%U:7-E<RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U
M=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]C>7)U<Z`Z(&5X=&5N<VEO;B!R97%U:7-E($E-05`@
M;F]N('1R;W5VZ64B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='"@.B!E>'1E;G-I;VX@
M<F5Q=6ES92!&5%`@;F]N('1R;W5VZ64N($EL(&9A=70@8V]M<&EL97(@4$A0
M(&%V96,@(@HB;"=O<'1I;VX@+2UE;F%B;&4M9G1P+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q
M=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VEM87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VMR8C6@.B!E>'1E;G-I;VX@<F5Q=6ES92!K<F(U(&YO
M;B!T<F]U=NEE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?
M;&1A<*`Z(&PG86IO=70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U<'!O
M<G3I(&%V96,@06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@HB075T:%]L9&%PH#H@;&4@<F5T<F%I="!D)W5T:6QI<V%T
M975R<R!N)V5S="!P87,@<W5P<&]R=.D@879E8R!!8W1I=F4@(@HB1&ER96-T
M;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I
M9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?;&1A<*`Z(&5X=&5N<VEO;B!R97%U:7-E($Q$
M05`@;F]N('1R;W5VZ64N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87"@.B!I;7!O<W-I8FQE(&0G86IO
M=71E<B!L)W5T:6QI<V%T975R("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U
M("(*(G-E<G9E=7*@.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87"@.B!I;7!O
M<W-I8FQE(&1E('-U<'!R:6UE<B!L)W5T:6QI<V%T975R("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS
M9W-T<B`B075T:%]L9&%PH#H@;6]D:69I8V%T:6]N(&EM<&]S<VEB;&4@9&4@
M;"=U=&EL:7-A=&5U<B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(D%U=&A?;&1A<*`Z(&QA(&UO9&EF:6-A=&EO;B!D97,@=71I;&ES871E
M=7)S(&XG97-T('!A<R!S=7!P;W)TZ64@879E8R!!8W1I=F4@(@HB1&ER96-T
M;W)Y+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G
M:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VUC86R@.B!E>'1E;G-I;VX@<F5Q=6ES92!-
M0T%,(&YO;B!T<F]U=NEE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:*`Z
M(&5X=&5N<VEO;B!R97%U:7-E('-M8F%U=&@@;F]N('1R;W5VZ64N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H
M96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(LEC
M:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;B!A=2!S97)V975R($E-05`N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BR6-H
M96,@9&4@;"=A=71H96YT:69I8V%T:6]N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+)
M8VAE8R!D92!L)V%U=&AE;G1I9FEC871I;VX@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("),92!S97)V
M975R(%)!1$E54R!A(')E:F5TZ2!L)V%U=&AE;G1I9FEC871I;VXN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D
M92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U<B!&5%`N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D
M92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U<B!334(N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I
M96QD<SHB"FUS9W-T<B`B0VAA;7!S(&1I<W!O;FEB;&5SH#HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B8>]D:F%N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S
M97,B"FUS9W-T<B`B17AC=7-E<R!"3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R
M;W5N9"(*;7-G<W1R(")#;W5L975R(&1E(&9O;F0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O
M=6YD($-O;&]R(@IM<V=S='(@(D-O=6QE=7(@9&4@9F]N9"(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`B36]T(&1E('!A<W-E($ME<F)E<F]S(&5R
M<F]NZ2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS
M9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(DYO;2!D92!C
M;VYN97AI;VX@2V5R8F5R;W,@97)R;V[I+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)A:')A:6XB"FUS9W-T<B`B0F%H<F7O;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R
M(")"86QT92`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N
M9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D92(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H
M:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")2Z7!E
M<G1O:7)E(&1E<R!G<F%P:&EQ=65S(*N@)7.@NR!N;VX@=')O=7;I+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B3&EG;F4@9&4@8F%S92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B0NEL87)U<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEQ=64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0NEN:6XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&5S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H;W5T86XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")"
M:7)T:&1A>2(*;7-G<W1R(")!;FYI=F5R<V%I<F4B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8T"B,L('!H<"UF;W)M870*
M;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")";&]C(*LE<R"[(&1E(&PG87!P;&EC871I;VX@
MJZ`E<Z"[(&EN8V]N;G4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(E!RZ6;I<F5N
M8V5S(&1E(&)L;V,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5'EP92!D92!B;&]C(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS
M9VED(")";VQD(@IM<V=S='(@(D=R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(D)O;&EV:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B4VEG;F5T
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")";W)D=7)E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`BR7!A:7-S975R(&1E(&QA
M(&)O<F1U<F6@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0F]R
M9',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA
M(@IM<V=S='(@(D)O<VYI92U(97)ZZ6=O=FEN92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("),97,@9&5U>"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B0F%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G+I<VEL(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*
M;7-G<W1R(")497)R:71O:7)E<R!B<FET86YN:7%U97,@9&4@;"=/8^EA;B!)
M;F1I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*
M;7-G<W1R(")3=6QT86YA="!D=2!"<G5NZ6DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=6QG87)I82(*;7-G<W1R(")"=6QG87)I92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B3&ES=&4@X"!P=6-E<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T
M<B`B1V5S=&EO;B!D92!C;VYT96YU(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED
M(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")$:7-T<FEB=71I
M;VX@9&5S('!O:6YT<R!,4D,@*$QI<W1E(&1E('+I=F]C871I;VX@9&5S(&-E
M<G1I9FEC871S*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")0<F]P<FGI=.ES(&1E(&QA($-?96QL=6QE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B3"=I;FET:6%L:7-A=&EO
M;B!D=2!C86-H92!N92!S)V5S="!P87,@=&5R;6ENZ64N(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,38@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`T,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(D-A;&UE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A;6)O9&=E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M97)O=6XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D92!R
MZ6EN:71I86QI<V5R(&QE(&UO="!D92!P87-S92!A=71O;6%T:7%U96UE;G0L
M(&-O;G1A8W1E>B!V;W1R92`B"B)A9&UI;FES=')A=&5U<B!S>7-TZ&UE+B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9&4@<W5P<')I;65R(&QE(&9I8VAI97(@JZ`E<Z"[
M+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&0G861M:6YI<W1R97(@9&5S(&=E<W1I;VYN86ER97,@9&4@
M<V5S<VEO;B!E>'1E<FYE<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<R(*;7-G<W1R("+)8VAE8R!D92!L82!C;VYN97AI;VX@874@
M<V5R=F5U<B!)34%0H#H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V]U=G)I<B!L92!F:6-H
M:65R(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B0V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N
M<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS
M9W-T<B`B06YN=6QE<B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B
M06YN=6QE<B!L92!R87!P;W)T(&1U('!R;V)LZ&UE(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!S=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S
M:6)L92!D92!T<F]U=F5R('5N('+I<&5R=&]I<F4@=&5M<&]R86ER92(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G
M:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M
M971E<BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!P<F]CZ61E<B!S86YS(&QE
M('!A<F%MZ'1R92"K('1A<F=E=$9I;&4@NR(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!S=7!P<FEM97(@;&4@<NEP97)T;VER92"KH"5SH+LN(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")3
M=7!P<F5S<VEO;B!I;7!O<W-I8FQE+"!I;"!Y(&$@)60@96YR96=I<W1R96UE
M;G1S(&9I;',N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F
M(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@
M;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D92!R
MZ6]R9&]N;F5R+"!L92!N;VUB<F4@9"?I;.EM96YT<R#@('+I;W)D;VYN97(@
M;F4@8V]R<F5S<&]N9"`B"B)P87,@874@;F]M8G)E(&0GZ6SI;65N=',@96YR
M96=I<W1RZ7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T
M;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(").92!P975T(&1I<FEG97(@
M;&4@;65S<V%G92!V97)S(&QE(&YO;6)R92!S<.EC:69IZ2XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<"U697)T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("),Z6=E;F1E(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#
M87)R:65R(@IM<V=S='(@(E1R86YS<&]R=&5U<B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM
M<V=S='(@(D-A=.EG;W)I97,@970@R71I<75E='1E<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("+.;&5S($-A[VUA;B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*
M;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE(&-E;&QU;&%I
M<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O
M<')IZ73I<R!D92!L82!C96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B4F5M<&QI<W-A9V4@875T;W5R(&1E(&QA(&-E;&QU;&6@.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI
M=.ES(&1E(&QA(&-E;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R(")%<W!A8V5M96YT(&1E(&QA(&-E;&QU;&6@.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-S$*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R
M(")4Z6SI<&AO;F4@8V5L;'5L86ER92`B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B
M0V5L=&4@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G
M<W1R(")#96YT<F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(E+I<'5B;&EQ=64@8V5N=')A9G)I8V%I
M;F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B175R;W#I96X@8V5N
M=')A;"`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R(")$Z71A:6QS(&1U(&-E<G1I9FEC870B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N
M97(B"FUS9W-T<B`B4')O<')IZ71A:7)E(&1U(&-E<G1I9FEC870B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R
M=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]L:71I<75E(&1E(&-E<G1I
M9FEC871I;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B
M5&-H860B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS
M9W-T<B`B36]D:69I97(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(DUO
M9&EF:65R('9O=')E(&UO="!D92!P87-S92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(D-H86YG97(@;&4@;F]M
M+"!L)V%D<F5S<V4@970@;&$@<VEG;F%T=7)E('%U92!L97,@<&5R<V]N;F5S
M('9O:65N="!Q=6%N9"`B"B)E;&QE<R!L:7-E;G0@970@<NEP;VYD96YT(.`@
M=F]S(&UE<W-A9V5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*
M(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B),82!M
M;V1I9FEC871I;VX@9&4@=F]T<F4@;6]T(&1E('!A<W-E(&XG97-T('!A<R!S
M=7!P;W)TZ64@879E8R!L82`B"B)C;VYF:6=U<F%T:6]N(&%C='5E;&QE+B!#
M;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B
M0VAA<B(*;7-G<W1R(")#:&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN
M:RXN+B(*;7-G<W1R(")6Z5]R:69I97(@;&4@;&EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0VAI;F$B"FUS9W-T<B`B0VAI;F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM
M<V=S='(@(D-H:6YO:7,@<VEM<&QI9FGI("A'0C(S,3(I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I(@IM<V=S='(@(D-H:6YO:7,@=')A9&ET:6]N;F5L("A":6<U*2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!
M<'!L:6-A=&EO;CHB"FUS9W-T<B`B0VAO:7-I<B!L)V%P<&QI8V%T:6]NH#HB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED
M(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")#:&]I<VER('5N(&UO="!D
M92!P87-S92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(D-H;VES:7(@
M=6X@;F]M(&1E(&-O;FYE>&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS
M9W-T<B`B0VAO:7-I<B!L92!M;V1E(&0G869F:6-H86=E(&1E<R!D871E<Z`Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I(@IM<V=S='(@(D-H;VES:7(@;&4@<W1Y;&4@9&4@
M;&ES=&4@*'!O=7(@;&5S(&QI<W1E<R!N=6WI<FEQ=65S*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`BSFQE<R!#:')I
M<W1M87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")$Z69I
M;FET:6]N(&1E(&QA(&-L87-S92!D92`E<R!N;VX@=')O=7;I92XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B
M0VQE87(B"FUS9W-T<B`B169F86-E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E
M('1A9W,B"FUS9W-T<B`B3F5T=&]Y97(@;&5S(&)A;&ES97,@35,M3V9F:6-E
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E
M<GDB"FUS9W-T<B`B169F86-E<B!L82!R97%UZG1E(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E)E=&ER97(@;"=U=&EL:7-A
M=&5U<CH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B169F86-E<B!L)W5T:6QI
M<V%T975R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*
M;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")%9F9A8V5R(&QE<R!D
M;VYNZ65S(&1E(&PG=71I;&ES871E=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*
M;7-G<W1R("+)8VQA:7)C:65S('1A<F0@9&%N<R!L82!J;W5R;NEE(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G
M:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(D-L:7%U97(@<&]U<B!P
M;W5R<W5I=G)E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM
M<V=S='(@(D-L:6-K871E;&P@=FEA($A45%`B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G
M:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")&97)M97(@;&$@9F5NZG1R92(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS
M9W-T<B`B3G5A9V5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(").=6%G
M97,@;6%T:6YA=7@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DYU86=E=7@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G
M<W1R("+.;&5S($-O8V]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R
M+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")297!L
M:65R(&QA(&)A<G)E(&1E(&/T=.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@
M8F]R9&5R<R(*;7-G<W1R(")2Z61U:7)E(&QE<R!B;W)D<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(D-O;&]M8FEE(@H*(SH@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D-O=6QE=7(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,R!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS
M9W-T<B`B4&%L971T92!D92!C;W5L975R<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,C4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T
M<B`B4^EL96-T:6]N(&0G=6YE(&-O=6QE=7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS
M9W-T<B`B0V]L<Z`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M,PIM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")4:71R97,@9&4@8V]L
M;VYN92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@
M(D-O;6EC<R(*;7-G<W1R(")"+D0N(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O;6UA;F1E(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S
M='(@(D-O;6UA;F1E('-H96QL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;6UE;G1A
M:7)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*
M;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(DYO;2!U<W5E;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R97,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(E-O8VGI=.DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")/<F1I;F%T
M975R<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G
M:60@(D-O;F1I=&EO;B(*;7-G<W1R(")#;VYD:71I;VXB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#
M;VYD:71I;VYS(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@
M(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1&EF9NER96YC
M97,@9&4@8V]N9FEG=7)A=&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!0
M1$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB4WEN
M8VAR;VYI<V%T:6]N(&1E<R!A<W-I<W1A;G1S('!E<G-O;FYE;',L(#Q)/G-M
M87)T<&AO;F5S/"])/B!E="!/=71L;V]K+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N(@IM<V=S='(@(DQA(&-O;F9I9W5R871I;VX@;B=E<W0@<&%S(.`@:F]U
M<BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")#;VYF:6=U<F5R("5S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I
M9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")#;VYF:7)M97(@;&4@;6]T
M(&1E('!A<W-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B
M0V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T
M:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(E+I<'5B;&EQ=64@9.EM;V-R
M871I<75E(&1U($-O;F=O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S
M='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`B"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]NH#H@(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D-O;FYE>&EO;B!A=2!S97)V975R(&1E(&-L969S('!U8FQI8R!R969U
M<^EE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")#
M;VYN97AI;VX@874@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@<F5F=7/I92X@
M4F%I<V]NH#H@("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@W-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@
M1E10(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@
M(D-O;G1A8W1S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B0V5S(&-O;G1A
M8W1S(&]N="!B:65N(.ETZ2!A:F]U=.ES(.`@=F]T<F4@8V%R;F5T(&0G861R
M97-S97,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@
M(@IM<V=S='(@(E1Y<&4@9&4@8V]N=&5N=2!D=2!F:6-H:65R(&-O;7!R97-S
MZ:`Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")#;VYT
M96YU(&1E(*N@)7.@NR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N
M=&EN=64B"FUS9W-T<B`B4&]U<G-U:79R92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O;VL@27-L86YD<R(*;7-G<W1R("+.;&5S($-O;VLB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")4Z6UO
M:6X@*&-O;VMI92DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P
M:65R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(LEC:&5C
M(&1E(&QA(&-O<&EEH#H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G
M<W1R(")3Z6QE8W1I;VX@9"=U;F4@8V]P:64B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R
M("))9"X@8V_[="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS
M9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)
M=F]I<F4B"FUS9W-T<B`B0_1T92!D)TEV;VER92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-H:69F
M<F5R(&QE(&UE<W-A9V6@.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@(@IM<V=S='(@(E-I9VYA='5R92!01U`@9'4@;65S<V%G92!I;7!O<W-I
M8FQEH#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R("));7!O<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE<W-A9V4@879E
M8R!3+TU)344N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*
M;7-G<W1R(")3:6=N871U<F4@4R]-24U%(&1U(&UE<W-A9V4@:6UP;W-S:6)L
M92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(D%J;W5T(&1U(&-O;G1A8W0@)7,@:6UP;W-S
M:6)L92X@(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(").92!P975T('-E(&-O;FYE8W1E<B!A=2!S
M97)V975R($Q$05`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")6Z7)I9FEC871I
M;VX@9&4@;&$@8F%L86YC92`E<R!I;7!O<W-I8FQE+B`B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N
M(&%U('-E<G9E=7(@3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(LEC:&5C(&1E
M(&QA(&-O;FYE>&EO;B!A=2!S97)V975R(*N@)7.@NR!V:6$@1E10H#H@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")#<NEA=&EO;B!D92!L:7-T
M92!D92!D:7-T<FEB=71I;VX@:6UP;W-S:6)L92X@)7,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@9.EC
M:&EF9G)E<B!L97,@9&]N;NEE<R!01U"@.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@9.EC:&EF
M9G)E<B!L97,@9&]N;NEE<R!3+TU)344N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").
M92!P975T('!A<R!S=7!P<FEM97(@;&4@8V]N=&%C="`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DYE('!E=70@<&%S('-U<'!R:6UE<B!L82!L
M:7-T92!D92!D:7-T<FEB=71I;VX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F4@
M<&5U="!P87,@<W5P<')I;65R(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B"K
MH"5SH+LN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RXB"FUS9W-T<B`B1.ET97)M:6YA=&EO;B!D92!L)V%D<F5S<V4@9'4@
M9&5S=&EN871A:7)E(&EM<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYE('!E
M=70@<NEC=7#I<F5R('1O=70@;&4@8V%R;F5T(&0G861R97-S92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R(").92!P975T('+I8W5PZ7)E<B!T;W5T92!L82!L:7-T
M92!D92!D:7-T<FEB=71I;VXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM
M<V=S='(@(DXG82!P87,@<'4@<NEC=7#I<F5R(&QA(&QI<W1E(&-O;7!LZ'1E
M(&1E(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9&4@8VAA<F=E<B!L82!S=')A=.EG:64@JZ`E<Z"[+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9&4@8W+I97(@;&4@<NEP97)T;VER92"KH"5SH+LN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED
M(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+B(*;7-G<W1R("));7!O<W-I8FQE(&0G;V)T96YI<B!L82!C;&5F('!U
M8FQI<75E(.`@<&%R=&ER(&1U('-E<G9E=7(@9&4@8VQE9G,N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(D]U=F5R='5R
M92!D92"KH"5SH+L@:6UP;W-S:6)L92!E;B#I8W)I='5R92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@
M(D]U=F5R='5R92!D92`E<R!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=O=79R:7(@;&4@;6]D=6QE($UA
M:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB
M)7-<(BXB"FUS9W-T<B`B3W5V97)T=7)E(&1U(&1O<W-I97(@JZ`E<Z"[(&EM
M<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("));7!O<W-I
M8FQE(&0G871T96EN9')E(&QE('-E<G9E=7(@3$1!4"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B3&5C='5R92!D92`E<R!I
M;7!O<W-I8FQE+B`B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX
M-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*(DXG82!P=2!R96UE='1R92#@('KI<F\@;&4@;6]T(&1E
M('!A<W-E('!O=7(@;"=U=&EL:7-A=&5U<B!D96UA;F3I+B!#97)T86EN<R`B
M"B(H;W4@=&]U<RD@;&5S(&3I=&%I;',@;F4@<V]N="!P87,@8V]R<F5C=',N
M(%+I97-S87EE>B!O=2!C;VYT86-T97H@=F]T<F4@(@HB861M:6YI<W1R871E
M=7(@<&]U<B!D92!L)V%I9&4N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,S.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S4*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R(")2Z6-U<.ER871I;VX@9&5S($%#3"!I;7!O<W-I8FQE(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B"FUS9W-T<B`B3F4@<&5U="!RZ6-U<.ER97(@;&4@8V%R;F5T
M(&0G861R97-S97,N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M(").92!P975T('+I8W5PZ7)E<B!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B3F4@<&5U="!R
MZ6-U<.ER97(@;&5S(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN("5S(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`B3F4@<&5U="!RZ6-U<.ER97(@;&5S('!O<W-I8FEL:73I<R!D=2!S97)V
M975R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").92!P975T
M('!A<R!R979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(")%9F9A8V5M96YT(&1U
M(&1O<W-I97(@JZ`E<Z"[(&EM<&]S<VEB;&4N("(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE('!E=70@<&%S
M(&5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I;VX@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*
M;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB
M"FUS9W-T<B`B3F4@<&5U="!P87,@96YR96=I<W1R97(@=6YE('-A=79E9V%R
M9&4@9&4@;&$@8V]N9FEG=7)A=&EO;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("));7!O<W-I8FQE
M(&0G96YR96=I<W1R97(@=6YE(&-O<&EE(&1E(&QA(&-O;F9I9W5R871I;VZ@
M.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=E;G)E9VES
M=')E<B!L92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@9&%N<Z`Z(*N@)7.@NRXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R("));7!O<W-I8FQE(&0G96YR96=I<W1R97(@
M=6YE(&-O<&EE(&1U(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@
M=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@
M=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DEM<&]S<VEB;&4@
M9"=E;G)E9VES=')E<B!L92!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N
M(%9O=7,@<&]U=F5Z('-O:70@(@HB=71I;&ES97(@=6YE(&1E<R!O<'1I;VYS
M('!O=7(@<V%U=F5R(&QE(&-O9&4@<W5R("5S('-O:70@8V]P:65R(&UA;G5E
M;&QE;65N="`B"B)L92!C;V1E(&-I+61E<W-O=7,@9&%N<R`E<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE('!E=70@
M<&%S(')E8VAE<F-H97(@;&4@<V5R=F5U<B!,1$%0+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL
M:6YK(%PB)7-<(BXB"FUS9W-T<B`B4W5P<')E<W-I;VX@9&4@JZ`E<Z"[(&EM
M<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(")-:7-E(.`@:F]U<B!D=2!C
M;VYT86-T(&EM<&]S<VEB;&4N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B3F4@<&5U="!M971T<F4@X"!J;W5R(&QA(&QI<W1E(&1E(&1I<W1R
M:6)U=&EO;BX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I
M;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F4@<&5U="!P87,@96YR96=I
M<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!P;W5R(*N@)7.@NZ`Z("5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`B3F4@<&5U="!T<F]U=F5R(&QA(&)A<G)E(&1E
M($UO>FEL;&$N("!!<W-U<F5Z+79O=7,@<74G96QL92!E<W0@86-T:79E+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E
M<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B(@HB3F4@<&5U="!A='1R:6)U97(@8V5S(&1R;VET
M<R#@(&PG=71I;&ES871E=7(@JZ`E<Z"[("!S=7(@;&4@9&]S<VEE<B"KH"5S
MH+N@.B`B"B(E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,38*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")497AT92!C;VUP=.DB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B
M0V]U;G1R>2(*;7-G<W1R(")087ES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")#;W5R<R(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(D-RZ65R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D-RZ65R('5N(&QI96XB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D-RZ65R('5N(&YO=79E
M874B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D-RZ65R('5N('-O
M=7,M9&]S<VEE<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI
M<W-I;VYS($1E($-RZ6%T975R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(P.0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DYU
M;>ER;R!D92!C87)T92!D92!C<NED:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M0W)O871I82(*;7-G<W1R(")#<F]A=&EE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0W5B82(*;7-G<W1R(")#=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V
M"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(C0@<&AA<V5S(&-O
M=7)A;G1E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R
M<F5N="!397-S:6]N<R(*;7-G<W1R(")397-S:6]N<R!E;B!C;W5R<R(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM
M<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(DAE=7)E(&%C='5E;&QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("),)V%D<F5S
M<V4@55),(&%C='5E;&QE(&5S="(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")5=&EL:7-A=&5U<G,@
M86-T=65L<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U
M<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")/8G-E<G9A=&EO;G,@86-T=65L;&5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")#;VYD:71I;VX@86-T=65L
M;&6@.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(E-T>6QE(&-O
M=7)A;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RXB"FUS9W-T<B`B1.EF:6YI<B!L97,@=.)C:&5S(.`@969F96-T
M=65R(&QO<G,@9&4@;&$@8V]N;F5X:6]N(.`@)7,N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED
M(")#=70B"FUS9W-T<B`B0V]U<&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*
M;7-G<W1R(")#;W5P97(@;&$@<^EL96-T:6]N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0WEP<G5S(@IM<V=S='(@(D-H>7!R92(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#
M>7)I;&QI<75E("A+3TDX+5(I(@H*(R!C;VYF:6<O;FQS+G!H<"YD:7-T.@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2DB"FUS9W-T<B`B0WER:6QL:7%U92`H5VEN9&]W<RTQ,C4Q
M*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI
M8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0WER:6QL:7%U92]5:W)A
M:6YI96X@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U
M8FQI8R(*;7-G<W1R(")2Z7!U8FQI<75E(%1C:.AQ=64B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")*2B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-CD*;7-G:60@(B(*(D133B`H<V5E(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("A#9BX@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D-H87%U92!J
M;W5R(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E
M92!"<F]W<V5R(@IM<V=S='(@(DYA=FEG871E=7(@9&4@1&%T851R964B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C8W"FUS9VED(")$871A8F%S
M92!,;V]K=7`B"FUS9W-T<B`B06QI87,@9&4@;&$@8F%S92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Y-0IM<V=I9"`B1&%T92(*;7-G<W1R(")$871E
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G
M:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T92!D92!RZ6-E<'1I;VXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-S@V"FUS9VED(")$871E
M('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@9"=U;F4@9&%T92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@(DIO=7(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E-U<'!R
M:6UE<B!?;&$@8V]L;VYN92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$Z6-E
M;6)R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M(").;VUB<F5S(&3I8VEM875X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM
M<V=S='(@(D1I;6EN=65R(&PG:6YD96YT871I;VXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I
M9"`B1&5F875L="(*;7-G<W1R(")$Z69A=70B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#
M;VQO<B(*;7-G<W1R(")#;W5L975R('!A<B!DZ69A=70B"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED
M96YT:71Y(@IM<V=S='(@(DED96YT:73I('!A<B!DZ69A=70B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS
M9W-T<B`B26YT97)P<NET975R(&1E(&-O;6UA;F1E('!A<B!DZ69A=70B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS
M(@IM<V=S='(@(D3I9FEN:71I;VYS(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(D5F
M9F%C97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(D5F
M9F%C97(@;&$@8V5L;'5L92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T
M<B`B4W5P<')I;65R('5N(&=R;W5P92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")%9F9A
M8V5R(&QA('1R86-E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B
M1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4W5P<')I;65R('5N92!P97)M
M:7-S:6]N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T
M<B`B4W5P<')I;65R(&5T('!U<F=E<B!L97,@;65S<V%G97,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS
M9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")%9F9A8V5R(&QA(&-E;&QU;&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(D5F9F%C97(@
M;&$@8V]L;VYN92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(E-U<'!R:6UE<B!U;B!A=71R92!M;V3H;&4@97AI<W1A;G0B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L
M971E(&UE<W-A9V5S(@IM<V=S='(@(E-U<'!R:6UE<B!L97,@;65S<V%G97,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*
M;7-G<W1R(")3=7!P<FEM97(@;&5S('!E<FUI<W-I;VYS('!O=7(@JZ`E<Z"[
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(LIT97,M=F]U<R!C
M97)T86EN(&1E('9O=6QO:7(@969F86-E<B"KH"5SH+L@970@<V5S('-O=7,M
M<&5R;6ES<VEO;G.@/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T
M<B`B169F86-E<B!L82!R86YGZ64B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L
M971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E
M;G1I='DB"FUS9W-T<B`B4W5P<')I;65R(&PG:61E;G1I=.D@<^EL96-T:6]N
M;NEE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")3=7!P<FEM
M97(@=6X@<V]U<RUD;W-S:65R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(D5F9F%C97(@;&$@8V]L;VYN92!A
M8W1U96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O
M=R(*;7-G<W1R(")%9F9A8V5R(&QA(')A;F?I92!A8W1U96QL92(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M(")38W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!S=7!P
M<FEMZ2"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@
M=&EM92(*;7-G<W1R(")(975R92!D92!L:79R86ES;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1A;F5M87)K(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H
M92!0<F]B;&5M(@IM<V=S='(@(D3I8W)I<F4@;&4@<')O8FSH;64B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S4@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B1&5S8W)I<'1I;VXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C(P-@IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.B(*;7-G<W1R(")$Z71A:6QS("AA=7-S:2!D86YS(&QE(&9I
M8VAI97(@9&4@=')A8V5S(&1E($AO<F1E*:`Z(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DQE<R!DZ71A
M:6QS(&]N="#I=.D@8V]N<VEG;NES('!O=7(@;"=A9&UI;FES=')A=&5U<BXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E
M;&]P;65N="(*;7-G<W1R(")$Z79E;&]P<&5M96YT(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")0;VEN
M="!D92!R;W/I92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED
M(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E!O:6YT(&1E
M(')O<^EE('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*
M;7-G<W1R(")0;VEN="!D92!R;W/I9:`Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(D1E(&=A=6-H92#@(&1R;VET92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G
M:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(D1E(&1R;VET
M92#@(&=A=6-H92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED
M(")$:7)E8W1O<GDB"FUS9W-T<B`B4NEP97)T;VER92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE
M<S\B"FUS9W-T<B`B069F:6-H97(@<W5R(#(T(&AE=7)E<Z`_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS
M(@IM<V=S='(@(D]P=&EO;G,@9"=A9F9I8VAA9V4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0B"FUS9W-T<B`B069F:6-H97(@;&$@<'+I=FES:6]N(&3I=&%I
M;&SI92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L
M87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B069F:6-H97(@;&$@<'+I=FES
M:6]N("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-@IM
M<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;6%T(&0G869F:6-H
M86=E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D%V:7,@9&4@
M;&EV<F%I<V]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T
M<B`B1&II8F]U=&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").92!P87,@<W5P
M<')I;65R(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED
M(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G
M<W1R(").92!P87,@86-CZ61E<B!D:7)E8W1E;65N="#@(&UA:6YT96YA;F-E
M+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z(@IM<V=S='(@(B(*(DQE('!R96UI97(@96YR96=I<W1R96UE
M;G0@8V]N=&EE;G0M:6P@;&4@;F]M(&1E<R!C:&%M<'.@/R!$86YS("(*(FPG
M869F:7)M871I=F4L(&-O8VAE>B!C971T92!B;^YT9:`Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI<75E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E+I<'5B
M;&EQ=64@9&]M:6YI8V%I;F4B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(E9O=7,@;B=A=F5Z('!A<R!D92!C;VUP=&6@/R!%;G)E9VES
M=')E>BUV;W5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@U,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B5.ELZ6-H87)G97(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B5.ELZ6-H
M87)G97(@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED
M(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R
M:7!T+B(*;7-G<W1R(")4Z6SI8VAA<F=E<B!L82!C;VYF:6=U<F%T:6]N(&?I
M;NERZ64@8V]M;64@=6X@<V-R:7!T(%!(4"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,#0*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@
M(DQI<W1E(&3I<F]U;&%N=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=U97,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G
M<W1R(")#;W5R<FEE<B#I;&5C=')O;FEQ=64B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M
M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED
M92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(E!I;&]T92!D92!P87-S97)E
M;&QE(&-O=7)R:65R("\@4TU3+"!P;W5R(&QE<R!F;W5R;FES<V5U<G,@9&4@
M8V4@<V5R=FEC92XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R
M("+)<75A=&5U<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B
M161I="(*;7-G<W1R(")-;V1I9FEE<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`BR61I
M=&5R(&QE(&)L;V,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G
M<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("+)9&ET
M97(@=6X@9W)O=7!E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B
M161I="!097)M:7-S:6]N(@IM<V=S='(@(LED:71E<B!U;F4@<&5R;6ES<VEO
M;B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`BR61I=&5R(&QE<R!P97)M:7-S:6]N
M<R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
MR61I=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NR(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z
M(@IM<V=S='(@(LED:71E<B!L97,@;W!T:6]N<R!P;W5RH#HB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BR61I
M=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NR(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BR61I=&5R(&QE<R!P97)M
M:7-S:6]N<R!P;W5R("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U
M"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`BR61U8V%T:6]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`BR6=Y<'1E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")386QV861O<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("+);.EM96YT+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*
M;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#8V"FUS9VED(")%;6%I;"(*;7-G<W1R(")!9')E<W-E(.EL96-T<F]N
M:7%U92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D
M<F5S<R(*;7-G<W1R(")!9')E<W-E(.EL96-T<F]N:7%U92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C`*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R("),97,@861R97-S97,@Z6QE8W1R;VYI
M<75E<R!D;VEV96YT(&-O<G)E<W!O;F1R92XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3@V"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")#;W5R<FEE<B!A=F5C(&-O;F9I<FUA=&EO;B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED
M(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")087-S97)E;&QE(&-O
M=7)R:65R("\@4TU3(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(LEM;W1I
M8_1N97,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(DUE
M<W-A9V4@=FED92XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@
M(E+I<W5L=&%T('9I9&4N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(E1E<FUE<R!D92!R96-H97)C:&4@=FED92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(D%C=&EV
M97(@;"=I;G-E<G1I;VX@9"=I;6%G97,@=F5N86YT(&1E<R!A;&)U;7,@<&AO
M=&]S(&1A;G,@;&4@=&5X=&6@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_
M(@IM<V=S='(@(D%C=&EV97(@;&4@;65N=2!C;VYT97AT=65L(&%V96,@=6X@
M8VQI8R!D<F]I=*`_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDP"FUS9VED(")%;F0@>65A
M<B(*;7-G<W1R(")&:6X@9&4@;"=A;F[I92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I
M=&]R(@IM<V=S='(@(D%G<F%N9&ER(&PGZ61I=&5U<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B+)8W)I=F5Z('5N92!Q
M=65S=&EO;B!D92!SZ6-U<FETZ2!Q=2=O;B!V;W5S('!O<V5R82!S:2!V;W5S
M(&1E=F5Z(')E;65T=')E(.`@(@HB>NER;R!V;W1R92!M;W0@9&4@<&%S<V4L
M('!A<B!E>&5M<&QE(*L@475E;"!E<W0@;&4@;F]M(&1E('9O=')E(&%N:6UA
M;"`B"B)P<NEFZ7+IH#^@NZ`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B26YS8W)I=F5Z(&PG861R97-S
M92!54DP@9&4@;"=I;6%G92!I8VDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R
M<R!B96QO=SHB"FUS9W-T<B`B16YT<F5Z(&QE<R!L971T<F5S(&-I+61E<W-O
M=7.@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM
M<V=S='(@(D=U:6[I92#I<75A=&]R:6%L92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`BR7)Y=&ARZ64B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F5U<B(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R
M(")%<G)E=7(@;&]R<R!D92!L82!C<NEA=&EO;B!D=2!B;&]CH#H@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T
M<B`B17)R975R(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;"=A;F-R92!D
M92!S>6YC:')O;FES871I;VZ@.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")%<G)E=7(@;&]R<R!D92!L82!S
M=7!P<F5S<VEO;B!D=2!J;W5R;F%L(&1E('-Y;F-H<F]N:7-A=&EO;J`Z("5S
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R(")%<G)E=7(@;&]R<R!D92!L82!RZ6-U<.ER871I;VX@9'4@8V]N
M=&5N=:`Z("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D
M.B`E<R(*;7-G<W1R(")%<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D
M=2!M;W0@9&4@<&%S<V6@.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+B(*;7-G<W1R(")%<G)E=7(@879E8R!L92!M97-S86=E
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R<F5U<B!L;W)S
M(&1E(&PG96YR96=I<W1R96UE;G0@9&4@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T;VYI92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(LET:&EO<&EE(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171H
M;FEQ=64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@
M(E1O=7,@;&5S("9F<F%C,30[(&0G:&5U<F4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B
M5&]U=&5S(&QE<R`R(&UI;G5T97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`B5&]U=&5S(&QE<R`S,"!S96-O;F1E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(E1O
M=71E<R!L97,@-2!M:6YU=&5S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`BP"!C:&%Q=64@8V]N;F5X:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E1O=71E
M<R!L97,@)F9R86,Q,CL@:&5U<F5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R
M>2!M:6YU=&4B"FUS9W-T<B`B5&]U=&5S(&QE<R!M:6YU=&5S(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L
M=65S.B(*;7-G<W1R(")%>&5M<&QE(&1E('9A;&5U<G.@.B(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO
M<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")%>.EC
M=71E<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B1.EV96QO<'!E<B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X
M<&%N9"!3:61E8F%R(@IM<V=S='(@(D3I<&QI97(@;&$@8F%R<F4@9&4@8_1T
MZ2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G
M:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("*K("D@NR!A='1E;F1U92(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X
M<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T
M<B`B56X@<V5U;"!M;W0@;W4@97AP<F5S<VEO;B!E;G1R92!G=6EL;&5M971S
M(&%T=&5N9'5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T92!D)V5X
M<&ER871I;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B4F5P<NES96YT86YT(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B0V]U;&5U<B!D)V%V86YT
M+7!L86XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(E3I;.EC:&%R9V5M96YT('9E
M<G,@;&4@<V5R=F5U<B!D92!L82!C;VYF:6=U<F%T:6]N('!A<B!&5%`B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,C`*;7-G:60@(D9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("),96-T=7)E
M(&1E<R!P<NEFZ7)E;F-E<R!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E
M=7(@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S
M='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R(%--0BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B
MR6-H96,@9&4@;&$@8V]P:64@9&5P=6ES(*N@)7.@NRXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(LEC:&5C(&1E(&QA
M(&-O<&EE('9E<G,@(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8W+I97(@=6YE
M(&YO=79E;&QE(&-O;FYE>&EO;B!305-,(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB
M+B(*;7-G<W1R("+)8VAE8R!D=2!DZ7!L86-E;65N="!V97)S(*N@)7.@NRXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(LEC
M:&5C(&QO<G,@9&4@;&$@<NEC=7#I<F%T:6]NH#H@)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*
M;7-G<W1R(")"96%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(@IM<V=S='(@(LYL97,@1F%L:VQA;F0@*$UA;&]U
M:6YE<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S
M='(@(LYL97,@1NER;^DB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X
M"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R975R(&9A=&%L9:`Z
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(E3I;.EC;W!I
M97,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1NEV<FEE<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(E1E;7#I<F%T=7)E(')E<W-E;G1I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")4
M96UPZ7)A='5R92!R97-S96YT:66@.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS
M9W-T<B`B475E;'%U97,@879E<G-E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(E%U96QQ=65S(&-H=71E<R!D92!N96EG92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#$*;7-G:60@(D9I96QD(&UA=')I>"(*
M;7-G<W1R(")-871R:6-E(&1E<R!C:&%M<',B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S(R"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M(")&:6=L970@0T%05$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,C8*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(E!O;&EC92!D92!L
M82`\23YF:6=L970\+TD^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G
M<W1R(")&:61J:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6-H:65R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL92(*;7-G<W1R(").;VUB<F4@9&4@9FEC:&EE<G.@.B`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(DYO;6)R
M92!D92!F:6-H:65R<Z`Z("5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D=E<W1I;VYN
M86ER92!D92!F:6-H:65R<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B3F]M(&1U(&9I8VAI97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<T"FUS9VED(")&:6QE
M('-E;&5C=&EO;B(*;7-G<W1R(")#:&]I>"!D92!F:6-H:65R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X,PIM<V=I9"`B1FEL92!U<&QO860B
M"FUS9W-T<B`B5.ELZ6-H87)G96UE;G0@9&4@9FEC:&EE<B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B1FEL92!U<&QO
M861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(DPG96YV;VD@9&4@9FEC:&EE
M<G,@;B=E<W0@<&%S('!R:7,@96X@8V]M<'1E+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT
M<F5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL
M86YD92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T
M($AA;&8B"FUS9W-T<B`B4')E;6GH<F4@9&5M:64B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S
M="!1=6%R=&5R(@IM<V=S='(@(E!R96UI97(@<75A<G1I97(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&
M:7@@<F%T:6\B"FUS9W-T<B`B1FEX97(@;&4@<F%T:6\B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP
M(@IM<V=S='(@(E)E=&]U<FYE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S
M='(@(D9L;W1T86YT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")"<F]U:6QL87)D(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S<@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD
M97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B1&]S<VEE<B`E<R!I;F5X
M:7-T86YT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B0V]U;&5U<B!D
M92!P;VQI8V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@
M(D9O;V0B"FUS9W-T<B`B3F]U<G)I='5R92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T
M<B`B4&]U<B!L97,@;F%V:6=A=&5U<G,@;F4@<W5P<&]R=&%N="!P87,@;&5S
M(&EM86=E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&
M;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<NEV:7-I;VX@*%1!1BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB
M2F]U<G,@9&4@<'+I=FES:6]N("AN;W1E>B!Q=64@;&5S('!RZ79I<VEO;G,@
M9F]U<FYI97,@9&]N;F5N="!L92!J;W5R(&5T(&QA("(*(FYU:72@.R!U;B!G
M<F%N9"!N;VUB<F4@:6-I('!E=70@9F%I<F4@=6X@8FQO8R!T<NAS(&QA<F=E
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")6;W5S(&%V97H@;W5B;&GI
M('9O=')E(&UO="!D92!P87-S9:`_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;75L86ER97,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B
M"FUS9W-T<B`B0VET871I;VXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")4>7!E(&1E(&-I=&%T
M:6]N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T
M=6YE<R(*;7-G<W1R(")#:71A=&EO;G,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B0VET871I;VYS
M(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&
M;W)U;7,B"FUS9W-T<B`B1F]R=6US(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4F5D:7)E8W1I
M;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"FUS9VED(")&<B(*;7-G<W1R(")692(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE
M<R(*;7-G<W1R(")#861R97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B
M"FUS9W-T<B`B1G)A;F-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&
M<F%N8V4@;>ET<F]P;VQI=&%I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N
M8V@@1W5I86YA(@IM<V=S='(@(D=U>6%N92!F<F%NYV%I<V4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0;VQY;NES
M:64@9G)A;N=A:7-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B5&5R<F5S(&%U<W1R86QE<R!E
M="!A;G1A<F-T:7%U97,@9G)A;N=A:7-E<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B1&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@
M(D1U("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS
M9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!T:6]N(&-O
M;7!LZ'1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")0;&5I;F4@
M;'5N92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS
M9W-T<B`B3F]M(&-O;7!L970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*
M;7-G<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T
M86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B06QB=6T@9"=O<FEG:6YE(&1E(&PG
M:6UA9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D%L
M8G5MH#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M
M8FEE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(D?I;NER97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@
M0V]D92(*;7-G<W1R(")#;V1E(&?I;NERZ2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D=E;W)G:6$B"FUS9W-T<B`B1^EO<F=I92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D=E<FUA;GDB"FUS9W-T<B`B06QL96UA9VYE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M:6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS
M9W-T<B`B4'+I;F]M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T
M<B`B3W!T:6]N<R!G;&]B86QE<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$W"FUS9VED(")';R(*;7-G<W1R(")!;&QE<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E
M;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")#87)T97,@1V]O9VQE
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R(")296-H97)C:&4@1V]O9VQE(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A
M>7-C86QE(@IM<V=S='(@(DYI=F5A=2!D92!G<FES(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=R965C92(*;7-G<W1R(")'<NAC92(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`B1W)E8R`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E
M;FQA;F0B"FUS9W-T<B`B1W)OZVYL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1W)E;F%D82(*;7-G<W1R(")'<F5N861E(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D
M;6EN:7-T<F%T:6]N(&1E<R!G<F]U<&5S(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G
M<W1R("),97,@;F]M<R!D92!G<F]U<&4@;F4@<&5U=F5N="!P87,@ZG1R92!V
M:61E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D
M9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM
M<V=S='(@(B(*(D=R;W5P7VQD87"@.B!I;7!O<W-I8FQE(&0G86IO=71E<B!L
M92!G<F]U<&4@)7,N($-E8VD@97-T(&QA('+I<&]N<V4@9'4@(@HB<V5R=F5U
M<J`Z(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G
M<W1R(")'<F]U<%]L9&%PH#H@<W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!G
M<F]U<&4@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G
M<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%PH#H@;6]D:69I8V%T:6]N(&EM
M<&]S<VEB;&4@9'4@9W)O=7!E("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G
M<W1R(")'<F]U<&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*
M;7-G<W1R(")'=6%D96QO=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB
M"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B
M"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYE<V5Y(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B4&5R;6ES<VEO;G,@9&5S(&EN=FETZ7,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T
M<B`B3&EV<F4@9"=O<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G
M<W1R(")'=6ENZ64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S
M874B"FUS9W-T<B`B1W5I;NEE+4)I<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B1W5Y86YA(@IM<V=S='(@(D=U>6%N82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDU-PIM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(')E9G5S
M92!BZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@8V5L;'5L92!D
M92!L82!R86YGZ64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM
M<V=S='(@(DA434Q!<F5A(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@
M;&$@9&5R;FGH<F4@8V]L;VYN92!D=2!T86)L96%U(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!R969U<V4@8NIT96UE
M;G0@9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E(')A;F?I92!D=2!T86)L96%U
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M96YT:69I8V%T:6]N($A45%`@;F]N('1R;W5VZ64N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R(")(8>]T:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB
M"FUS9W-T<B`B06QG;W)I=&AM92!D92!H86-H86=E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS
M9W-T<B`B0G)U;64@<^AC:&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,0IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(D5N+73J=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@
M(D5N+73J=&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@
M86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`BSFQE<R!(96%R9"!E="!-
M8T1O;F%L9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(D]R86=E<R!V
M:6]L96YT<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(
M96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2.EB<F5U("A)4T\M.#@U
M.2TX+4DI(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B
M2&5I9VAT(@IM<V=S='(@(DAA=71E=7(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B06ED
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D%I9&4@<&]U
M<B!L)^ED:71E=7(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8X
M"FUS9VED(")(96QP97(B"FUS9W-T<B`B06ED92(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(Z6UI<W!H
MZ')E(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B5F]I8VD@;&4@9.EB=70@
M9'4@9FEC:&EE<J`Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S$*;7-G:60@(DAI9V@B"FUS9W-T<B`B2&%U=&4B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(D%?8V-U
M96EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@
M0VET>2!3=&%T92DB"FUS9W-T<B`B0VETZ2!D=2!6871I8V%N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM<V=S
M='(@(D%C8W5E:6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E
M<W-E('!E<G-O;FYE;&QE(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T
M"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")2Z7!E<G1O:7)E('!E
M<G-O;FYE;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE
M('!E<G-O;FYE;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N
M9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8J`Z(&1O;F[I
M97,@6$U,("5S(&EN=F%L:61E<R!R971R;W5VZ65S(&1A;G,@;&4@;65S<V%G
M92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8J`Z(&%U
M8W5N(&UE<W-A9V4@;F4@8V]R<F5S<&]N9"!A=2!S=6IE="`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@<&%S(&0G;V)J
M970@9&4@='EP92`E<R!T<F]U=ND@9&%N<R!L92!M97-S86=E("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B`E<R!S=7!P<FEMZ2"KH"5S
MH+L@879E8R!S=6-CZ',B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T
M<B`B(@HB2&]R9&4O2V]L86*@.B!L92!M;W1E=7(@9"=I;G3I9W)A=&EO;B!N
MZ6-E<W-I=&4@;"=E>'1E;G-I;VX@)V1O;7AM;"<@9&4@4$A0(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!I;7!O<W-I
M8FQE(&1E(&-RZ65R('5N(&YO=79E;"!A<F)R92!834P@<&]U<B!L)V]B:F5T
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!I;7!O<W-I
M8FQE(&0G96YL979E<B`E<R"KH"5SH+N@.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8J`Z(&EM<&]S
M<VEB;&4@9&4@<NEC=7#I<F5R(&PG:61E;G1I9FEA;G0@34E-12!P;W5R(&QA
M('!A<G1I92!D92`B"B)T>7!E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<WEN8VAR;VYI<V5R("5S
M(*N@)7.@NZ`Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,S,W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8J`Z(&EM<&]S<VEB;&4@9&4@<WEN8VAR;VYI<V5R(&QE<R!P87)T86=E<Z`Z
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E
M<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@<&%R=&%G92!I;F-O;FYU(*N@
M)7.@NR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("),:6=N92!H
M;W)I>F]N=&%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R
M(")296UP;&ES<V%G92!H;W)I>F]N=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB
M"FUS9W-T<B`B2&]R:7IO;G1A;*`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")#;VUM
M96YT(.IT97,M=F]U<R!A<G)I=ND@:6-IH#\@*%-64"!R87!P;W)T97HM;&6@
M(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R(")#;VUB:65N(&1E(&-O;&]N;F5S('9O
M=6QE>BUV;W5S(&9U<VEO;FYE<J`_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/R(*;7-G<W1R(")#;VUB:65N(&1E(&-H86UP<R`H8V]L;VYN
M97,I('D@82UT+6ELH#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")#;VUB:65N(&1E(')A
M;F?I97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5RH#\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W
M"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")(=6UI9&ETZ2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B
M"FUS9W-T<B`B2'5M:61I=.F@.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&5S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DAO;F=R:64B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("+)8VAE8R!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1E(&QA(&)O[G1E($E-05"@
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(LEC:&5C(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;&$@8F_N
M=&4@24U!4*`Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BR6-H96,@;&]R<R!D92!L82!C<NEA=&EO
M;B!D=2!Q=6]T82!S=7(@;&$@8F_N=&4@24U!4*`Z("5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q,PIM<V=I9"`B25`@061D<F5S<R(*;7-G
M<W1R(")!9')E<W-E($E0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A
M<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")!9')E<W-E($E0(&YO;B!D:7-P;VYI8FQE+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(D%D
M<F5S<V4@25`@:&]R<R!D=2!B;&]C($-)1%(@86QL;W7I+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I
M9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")6:6]L871I;VX@
M9&4@8FQO8V%G92!)4"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E
M9F]R92(*;7-G<W1R("))7VYSZ7)E<B!R86YGZ64@879A;G0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS
M9W-T<B`B26/T;F5S('-E=6QE;65N="(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS
M9W-T<B`B26/T;F5S('!O=7(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26/T;F5S
M('!L=7,@=&5X=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS
M9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DYO;2!D=2!C;VUP=&6@
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O
M<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S
M='(@(B(*(E-I(&PG869F:6-H86=E(&XG97-T('!A<R!C;W)R96-T+"`E<R!P
M;W5R(&PG;W5V<FER(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O
M;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO
M=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)3:2!V;W5S(&YE('9O>65Z
M(&%U8W5N(&EC]&YE(&5N('5T:6QI<V%N="!);G1E<FYE="!%>'!L;W)E<BP@
M=F]U<R!P;W5V97H@(@HB879O:7(@X"!C;V-H97(@8V5T=&4@8V%S92!P;W5R
M(&3I<V%C=&EV97(@;&$@=')A;G-P87)E;F-E(&1E<R!03D<N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B
M(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E-I('9O=7,@=F]Y97H@
M8V4@;65S<V%G92!M86ES(&%U8W5N92!I;6%G92P@;"=I;6%G92!Q=64@=F]U
M<R!V;W5L97H@96YV;WEE<B`B"B)N92!P975T(.IT<F4@869F:6-HZ64@<&%R
M('9O=')E(&YA=FEG871E=7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0
M<F5V:65W.B(*;7-G<W1R(")!<&5RYW4@9&4@;"=I;6%G9:`Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM
M<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D%D<F5S<V4@55),(&1E(&PG:6UA
M9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B061R
M97-S92!54DP@9&4@;"=I;6%G9:`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G
M92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B26UA9V4@9&4@;"=A;&)U;2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("))
M;6%G92!D92!L)V%L8G5MH#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S4X"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B5.ELZ6-H87)G
M96UE;G0@9"=I;6%G97,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM
M<V=I9"`B26UA9V5S(@IM<V=S='(@(DEM86=E<R(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&%T:6]N+"#I=&%P92`E9"(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")#:&%M<"!I;7!O
M<G3IH#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS
M9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(D-H86UP<R!I;7!O<G3I
M<Z`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R
M("));E]SZ7)E<B!R86YGZ64@87!RZ',B"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0V]D92!D)V%C=&EO;B!I;F-O<G)E
M8W0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(DYO;2!D)W5T:6QI<V%T975R(&5T+V]U('9O=')E
M(&UO="!D92!P87-S92!I;F-O<G)E8W0N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@HB3F]M(&0G=71I;&ES871E=7(@;W4@861R97-S92!A;'1E
M<FYA=&EV92!I;F-O<G)E8W0N("!2Z65S<V%Y97H@;W4@8V]N=&%C=&5Z("(*
M(G9O=')E(&%D;6EN:7-T<F%T975R('-Y<W3H;64@<&]U<B!D92!L)V%I9&4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(D%U9VUE;G1E<B!L
M)VEN9&5N=&%T:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G
M<W1R("));F1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`B571I;&ES871E=7)S(&EN9&EV:61U96QS
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD
M;V[I<VEE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS
M9W-T<B`B26YF;W)M871I;VYS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL
M86)L92XB"FUS9W-T<B`B3"=I;F9O<FUA=&EO;B!N)V5S="!P;'5S(&1I<W!O
M;FEB;&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*
M;7-G<W1R("));G/I<F5R(&-?;VQO;FYE(&%P<NAS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS
M9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B26YSZ7)E<B!I;6%G92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G
M:60@(DEN<V5R="!486)L92(*;7-G<W1R("));G/I<F5R('5N('1A8FQE874B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U
M"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B26YSZ7)E<B!U;B!L
M:65N('=E8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E
M(@IM<V=S='(@(DEN<^ER97(@7V-O;&]N;F4@879A;G0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(DEN<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N;F4@87!RZ',@
M;&$@8V]L;VYN92!A8W1U96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN
M<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N;F4@879A;G0@;&$@8V]L;VYN92!A
M8W1U96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YSZ7)E<B!U;F4@;F]U=F5L
M;&4@<F%N9^EE(&%P<NAS(&QA(')A;F?I92!A8W1U96QL92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(DEN<^ER97(@=6YE(&YO=79E;&QE(')A;F?I92!A=F%N="!L
M82!R86YGZ64@86-T=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<^ER
M97(@=6X@<&%R86=R87!H92!A<'+H<R!L92!N)F]E;&EG.W5D(&%C='5E;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<^ER97(@=6X@<&%R86=R87!H92!A
M=F%N="!L92!N)F]E;&EG.W5D(&%C='5E;"(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM
M<V=S='(@(DEN<^ER97(@=6X@875T<F4@;6]DZ&QE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E
M<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z
M(@IM<V=S='(@(B(*(DEN<V-R:79E>B!U;F4@861R97-S92!D92!C;W5R<FEE
M<B#@(&QA<75E;&QE('9O=7,@<F5C979R97H@;&4@;F]U=F5A=2!M;W0@9&4@
M(@HB<&%S<V6@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM
M<V=S='(@(DEN<^ER97(@8V5L;'5L92!A<'+H<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN
M<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("));G/I<F5R(&-E;&QU;&4@879A
M;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@
M(DEN<^ER97(@8V]L;VYN92!A<'+H<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C
M;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN<^ER97(@8V]L;VYN92!A=F%N="(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED
M("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B26YSZ7)E<B!L97,@;65S<V%G
M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS
M9W-T<B`B26YSZ7)E<B!P87)A9W)A<&AE(&%P<NAS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("));G/I<F5R('!A
M<F%G<F%P:&4@879A;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R
M(@IM<V=S='(@(DEN<^ER97(@<F%N9^EE(&%P<NAS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B
M26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B26YSZ7)E<B!R86YGZ64@879A
M;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ(@IM<V=S='(@(DEN<V-R:79E>B!L82!RZ7!O;G-E(.`@;&$@<75E<W1I
M;VX@9&4@<^EC=7)I=.F@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B
M"FUS9W-T<B`B26YSZ7)E<B]-;V1I9FEE<B!U;F4@:6UA9V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YSZ7)E<B]-;V1I9FEE<B!U
M;B!L:65N('=E8B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")#<NED
M:70@:6YS=69F:7-A;G0@<&]U<B!E;G9O>65R(.`@;&$@;&ES=&4@9&4@9&ES
M=')I8G5T:6]N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*
M;7-G<W1R(")#<NED:70@:6YS=69F:7-A;G0N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`W,@IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")%;G1I
M97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,P"FUS9VED("))
M;G1E9V5R(&QI<W0B"FUS9W-T<B`B3&ES=&4@8V]M<&SH=&4B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G
M:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@
M(E5$2"`H57-E<B!$871A($AE861E<BD@:6YV86QI9&4B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:
M25`@9&%T82(*;7-G<W1R(")$;VYNZ64@6DE0(&EN=F%L:61E+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC
M871I;VXN(@IM<V=S='(@(D%P<&QI8V%T:6]N(&EN=F%L:61E+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM
M<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B1W)O=7!E($E$(&EN
M=F%L:61E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B16YV;VD@9&4@
M9&]N;NEE<R!I;G9A;&ED97,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(D%D<F5S<V4@9&4@9&5S=&EN871I
M;VX@:6YV86QI9&4N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B
M1F]R;6%T(&1E(&9I8VAI97(@:6YV86QI9&4N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME
M>2XB"FUS9W-T<B`B0VQE9B!D92!L:6-E;F-E(&EN=F%L:61E+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D5M<&QA8V5M96YT(&EN9&EQ
M=>D@:6YV86QI9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R("*K;7-G7W1Y<&6[(&EN=F%L:61E+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`BJV%P:5]I9+L@:6YV
M86QI9&4@;W4@;6%N<75A;G0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B4&%R86WH=')E<R!I;G9A;&ED
M97,@;W4@;6%N<75A;G1S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B4&5R;6ES<VEO;B!I;G9A;&ED92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM
M<V=S='(@(DED+B!D92!P87)T96YA:7)E(&EN=F%L:61E+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O
M9'5C="!C;V1E+B(*;7-G<W1R(")#;V1E(&1E('!R;V1U:70@:6YV86QI9&4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")0<F]T
M;V-O;&4@:6YV86QI9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R(")$97-T:6YA=&%I<F4@:6YV86QI9&6@.B"K
MH"5SH+LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H
M87)E(&]B:F5C="(*;7-G<W1R(")/8FIE="!D92!P87)T86=E(&EN=F%L:61E
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R
M(")!9')E<W-E('-O=7)C92!I;G9A;&ED92XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L
M:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")$;VYNZ64@56YI8V]D92!I;G9A
M;&ED92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED
M("));G9E;G1O<GDB"FUS9W-T<B`B26YV96YT86ER92(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R
M="!S96QE8W1I;VXB"FUS9W-T<B`B26YV97)S97(@;&$@<^EL96-T:6]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DER86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS
M9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("))<FQA;F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(LYL92!D92!-86XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I
M9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<.IT97,@:7-O;.EE
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F'K
M;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS
M9VED("))<W-U97(B"FUS9W-T<B`BR6UE='1E=7(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*
M;7-G<W1R("))=&%L:7%U92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB
M"FUS9W-T<B`B271A;&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A
M(@IM<V=S='(@(DIA;6'O<75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N
M=FEE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P
M;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B2F%P86YE
M<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!O;F%I<R`H25-/+3(P,C(M
M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@
M(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIO<F1A;B(*;7-G<W1R(")*;W)D86YI92(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@
M(DIU:6QL970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6EN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I
M9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-T:69I97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B
M2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B0V5N=')E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED
M(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B2G5S=&EF:65R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")!;&EG;F5R(.`@9V%U8VAE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B06QI9VYE<B#@
M(&1R;VET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G
M<W1R(")+87IA:VAS=&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`B1V%R9&5R(&PG;W)I9VEN86R@/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2V5N>6$B"FUS9W-T<B`B2V5N>6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DQE('-E<G9E=7(@2V5R8F5R;W,@
M82!R96IE=.D@;"=A=71H96YT:69I8V%T:6]N+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B
M1.EB=71A;G1S(&1U(&YO>6%U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B0W+I
M871I;VX@9&4@8VQE9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(D5M<')E
M:6YT92!D92!L82!C;&5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(DQO;F=U975R
M(&1E(&QA(&-L968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E1Y<&4@9&4@8VQE9B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED
M(")+97D@57-A9V4B"FUS9W-T<B`B571I;&ES871I;VX@9&4@;&$@8VQE9B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R("),82!C;&5F('-E('1R;W5V92!DZ6K@('-U<B!L92!S97)V975R
M(&1E(&-L969S('!U8FQI8RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B16YF86YT<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(D-O<NEE(&1U($YO<F0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")#;W+I92!D=2!3
M=60B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N
M("A%54,M2U(I(@IM<V=S='(@(D-O<NEE;B`H155#+4M2*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMO=V7O="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:&EZ:7-T86XB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B4'+I7W-E;G1A=&EO;B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DQA;F=U
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")$97)N:>AR92!D
M96UI92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S
M="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B1&5R;FGH<F4@;6]D:69I8V%T
M:6]N(&1U(&UO="!D92!P87-S92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R(")$97)N:65R('%U87)T:65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3@*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B1&5R;FGH
M<F4@;6ES92#@(&IO=7*@.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G
M<W1R(")$97)N:>AR92!C;VYN97AI;VZ@.B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(D1E<FYIZ')E(&-O;FYE>&EO;J`Z
M("5S(.`@<&%R=&ER(&1E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")$97)N
M:>AR92!C;VYN97AI;VZ@.B!J86UA:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQA='9I82(*;7-G<W1R("),971T;VYI92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DQO:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I
M9"`B3&%Y;W5T(@IM<V=S='(@(E!RZ7-E;G1A=&EO;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E
M(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B3&%I<W-E<B!V:61E('!O
M=7(@;F4@<&%S(&%V;VER(&1E(&)O<F1U<F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B1V%U8VAE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S`Y.`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B16YTZG1E(&=A=6-H
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.30*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(E9A;&5U<G,@9&4@9V%U8VAE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM
M<V=S='(@(DYI=F5A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*
M;7-G<W1R("),:6+I<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@
M07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8GEE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM
M<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")"<G5I;F4@;.EGZ')E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G
M:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B4&QU:64@;.EGZ')E(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B4&QU:64@;.EGZ')E('3T="!D86YS
M(&QA(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(E!L
M=6EE(&SI9^AR92!T87)D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(D%V97)S97,@;.EGZ')E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU
M;F1E<B(*;7-G<W1R(")0;'5I92!LZ6?H<F4@879E8R!T;VYN97)R92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED
M("),:6=H="!3;F]W(@IM<V=S='(@(DYE:6=E(&EN=&5R;6ET=&5N=&4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I
M9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B079E<G-E(&1E(&YE:6=E
M(&SI9^AR92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B
M3&EM97)I8VLB"FUS9W-T<B`B4FEM97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#$Q"FUS9VED("),:6YK(@IM<V=S='(@(DQI96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("),92!L:65N('!O
M:6YT92!V97)SH#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<R
M"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*(DQI92!L)V%D<F5S
M<V4@9&4@8V]U<G)I96P@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N(&1U(&UE
M<W-A9V4@96X@;"=A9F9I8VAA;G0B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G
M<W1R("),:65N<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I
M9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(D)I<V-U:70@3&EN=7@B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W1E("T@
M=71I;&ES871E=7(@<&5U="!V;VER(&QE(&1O<W-I97(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M("),:7-T92!D97,@8F%S97,@9&4@9&]N;NEE<R(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S
M='(@(DEN9&5X(&1E(&PG86ED92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(D%F9FEC:&5R(&QE<R!T
M86)L97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(D%R8VAI=F5S(&1E(&QA
M(&QI<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R(")!:61E(&1E(&QA(&QI<W1E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`B260N(&1E(&QA(&QI<W1E(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M
M3W=N97(B"FUS9W-T<B`B4')O<')IZ71A:7)E(&1E(&QA(&QI<W1E(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI
M<W0M4&]S="(*;7-G<W1R(")%;G9O:2#@(&QA(&QI<W1E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B
M<V-R:6)E(@IM<V=S='(@(D%B;VYN96UE;G0@X"!L82!L:7-T92(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T
M+55N<W5B<V-R:6)E(@IM<V=S='(@(D3I<V%B;VYN96UE;G0@9&4@;&$@;&ES
M=&4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(LEC
M:&5C(&1E(&QA(&QI<W1E(&1E<R!S97-S:6]N<Z`Z("5S(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("+)8VAE8R!D92!L82!L:7-T92!D
M97,@=71I;&ES871E=7)SH#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(DPG869F:6-H86=E(&1E(&QA(&QI<W1E(&1E<R!U=&EL
M:7-A=&5U<G,@97-T(&3I<V%C=&EVZ2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET=.ER871U
M<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),
M:71U86YI92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B0VAA<F=E;65N
M="XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G
M:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")(975R92!L;V-A;&6@.B`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R(")(975R92!E="!L;V-A;&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DQI
M974B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B0V]N;F5X:6]N(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(E1R86-E(&1E(&QA
M(&1E<FYIZ')E('-E<W-I;VX@9&4@<WEN8VAR;VYI<V%T:6]N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*
M;7-G<W1R(")$Z6-O;FYE>&EO;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B0V]N;F5X:6]N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS
M9W-T<B`B5.)C:&5S(&1E(&-O;FYE>&EO;B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2XB"FUS9W-T<B`B(@HB3&$@8V]N;F5X:6]N(&5S="!R969U<^EE+B!);"!E
M<W0@<')O8F%B;&4@<75E('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&]U("(*
M(G9O=')E(&UO="!D92!P87-S92!A(.ETZ2!M86P@<V%I<VDB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`BR6-H96,@9&4@8V]N;F5X:6]N+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C(*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")4
M97AT92!L;VYG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED
M("),;W9E(@IM<V=S='(@(D%M;W5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R(")&86EB
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S
M='(@(DQE='1R92!G<F5C<75E<R!M:6YU<V-U;&5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I
M9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),971T<F4@;&%T:6YE
M<R!M:6YU<V-U;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R(").;VUB<F4@<F]M86EN<R!M:6YU<V-U;&5S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8F]U
M<F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,SD@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@
M(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B
M34]41"(*;7-G<W1R(")-97-S86=E(&1U(&IO=7(@*$U/5$0I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
M3&$@<&GH8V4@:F]I;G1E($U3+51.148@;F4@8V]N=&5N86ET(&%U8W5N92!D
M;VYNZ64N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@
M(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C
M86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")2Z7!U8FQI<75E(&1E
M($UA8^ED;VEN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*
M;7-G<W1R(")-861A9V%S8V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R(")#;W5R
M<FEE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G:60@
M(DUA:6P@061M:6XB"FUS9W-T<B`B061M:6YI<W1R871I;VX@9'4@8V]U<G)I
M96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B1F%I
M<F4@=6X@;&EE7VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G
M<W1R(")-86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM
M<V=S='(@(DUA;&%I<VEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E
M<R(*;7-G<W1R(")-86QD:79E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L
M:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*
M;7-G<W1R(")-86QT92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM
M<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB061M:6YI
M<W1R97H@;&$@;&ES=&4@9&4@8V%TZ6=O<FEE<R!E="!L97,@8V]U;&5U<G,@
M;&GI97,@X"!C97,@8V%TZ6=O<FEE<RXB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM
M<V=S='(@(D-A<G1E(*L@36%P,C0@NR(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B
M"FUS9W-T<B`B0V%R=&4@JR!-87!Q=65S=""[(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM
M<V=S='(@(D-O<G)E<W!O;F1A;F-E<R!E;G)E9VES='+I97,N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(DUA<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T
M<B`B36%R9V4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(DUA<G%U97(@879E8R!D97,@Z71I<75E='1E<R!6=2].;VX@=G4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB"FUS9W-T<B`B36%R<75E<B!A=F5C(&0G875T<F5S(.ET:7%U971T97,@
M*&5X+CH@26UP;W)T86YT+U+I<&]N9'4I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(LYL97,@36%R<VAA;&PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN
M:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B0VAA;7!S(&%P<&%R96YTZ7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U
M<FET86YI92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(LYL92!-875R:6-E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D
M:70N(@IM<V=S='(@(D-RZ61I="!M87AI;75M(&%L;&]UZ2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("),:6UI
M=&4@9'4@;65S<V%G92!DZ7!A<W/I92XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q,PIM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(E1E;7#I<F%T=7)E(&UA>&EM86QE(&1E<R`R-"!D97)N:>AR97,@:&5U
M<F5SH#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7#I<F%T=7)E(&UA
M>&EM86QE(&1E<R`V(&1E<FYIZ')E<R!H975R97.@.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R(").;VUB<F4@;6%X:6UU;2!D92!B;&]C<R!D=2!P;W)T86EL
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DU(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S-@IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B3&]N9W5E=7(@
M;6%X:6UU;2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-
MZ61I8V%M96YT(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-96UB<F5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G
M<W1R(")4>7!E(&1E(&UE;G6@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS
M(@IM<V=S='(@(D9U<VEO;FYE<B!L97,@8V5L;'5L97,B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I
M9"`B365S<V%G92(*;7-G<W1R(")-97-S86=E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)6Z7)I
M9FEC871I;VX@9'4@;65S<V%G92!RZ75S<VEE+"!M86ES(&QE(&-E<G1I9FEC
M870@9'4@<VEG;F%T86ER92!N)V$@<&%S('!U("(*(NIT<F4@=NER:69IZ2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365S<V%G
M92!E>'!I<NDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E
M(@IM<V=S='(@(E1Y<&4@9&4@;65S<V%G92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-Z73I;R!-
M971A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DQE(&)L;V,@JR!-971A
M<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"B),92!B;&]C(*L@365T87(@NR!N)V5S="!P87,@
M9&ES<&]N:6)L92X@($QE<R!DZ71A:6QS(&]N="#I=.D@8V]N<VEG;NES('!O
M=7(@(@HB;"=A9&UI;FES=')A=&5U<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(DUE=&%R1$(@;B=E<W0@<&%S(&-O;FYE8W3I+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D
M(@IM<V=S='(@(DWI=&AO9&4B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D
M(@IM<V=S='(@(DQA(&WI=&AO9&4@JZ`E<Z"[(&XG97-T('!A<R!DZ69I;FEE
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<R(*;7-G<W1R(")-Z71H;V1E(&YO;B!DZ69I;FEE+B!-Z71H;V1E(&%P
M<&5LZ66@.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T
M<B`B3>ET<FEQ=64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G
M<W1R(")-97AI<75E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`BR71A=',@9NEDZ7+I<R!D
M92!-:6-R;V[I<VEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B36EL
M:65U(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")4>7!E($U)344B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R
M-"!H;W5R<SH@(@IM<V=S='(@(E1E;7#I<F%T=7)E(&UI;FEM=6T@9&5S(#(T
M(&1E<FYIZ')E<R!H975R97.@.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M5&5M<.ER871U<F4@;6EN:6UU;2!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@
M(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS
M9W-T<B`B3&$@9'5RZ64@;6EN:6UA;&4@9'4@;6]T(&1E('!A<W-E(&XG82!P
M87,@96YC;W)E(&5X<&ERZ2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")-:7)O
M:7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E
M;&QA;F5O=7,B"FUS9W-T<B`B5F%R:>ES(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(DQE('!A<75E
M=&%G92!(5%107W)E<75E<W0@4$5!4B!E<W0@;6%N<75A;G0N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M(D-O;F9I9W5R871I;VX@:6YE>&ES=&%N=&4N(%9O=7,@9&5V97H@;&$@9^EN
MZ7)E<B!M86EN=&5N86YT('-I('9O=7,@=F]U;&5Z("(*(G5T:6QI<V5R(&-E
M='1E(&%P<&QI8V%T:6]N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R("))1"!D=2!M97-S86=E(&UA;G%U86YT+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X
M"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*
M;7-G<W1R("),92!P87%U971A9V4@4$5!4B!-86EL(&5S="!M86YQ=6%N="XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B240@
M9&4@<V5S<VEO;B!M86YQ=6%N="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("),=2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B0V]U<G)I96P@<V%N<R!F:6PB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B36]D97)A
M=&4B"FUS9W-T<B`B36]DZ7+I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T92!D92!M
M;V1I9FEC871I;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T
M<B`B36]D:69I97(@;"=54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;&\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DUO;&1A=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B
M"FUS9W-T<B`B36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI
M82(*;7-G<W1R(")-;VYG;VQI92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U.#$*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUO:7,@
M970@86YNZ64B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DUE;G-U96QL96UE
M;G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B
M36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B4&AA
M<V5S(&1E(&QA(&QU;F4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA
M;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(D-H86UP<R!S=7!P;.EM96YT
M86ER97,@=')O=7;I<R#@(&QA(&QI9VYE("5D("AA='1E;F1U<R`E9"DN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]C(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G
M:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")'Z6[I<F%L96UE;G0@96YS;VQE
M:6QLZ2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(D?I;NER86QE;65N
M="!N=6%G975X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S
M='(@(E!R:6YC:7!A;&5M96YT(&YU86=E=7@@970@=F5N=&5U>"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-
M;W-T;'D@4W5N;GDB"FUS9W-T<B`B1^ENZ7)A;&5M96YT(&5N<V]L96EL;.DB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(E9E<G,@;&4@8F%S(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")$Z7!L86-E<B#@(&=A=6-H
M92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(D3I<&QA8V5R(.`@
M9')O:71E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B5F5R<R!L92!H
M875T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E9E<G,@;&4@8F%S(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(E9E<G,@;&4@:&%U="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I<75E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X,0IM<V=I9"`B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(DQI<W1E<R!DZ7)O=6QA
M;G1E<R!M=6QT:2UN:79E875X(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*
M;7-G<W1R(")#87)T92"KH$UU;'1I;6%P(%5+H+LB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C,Y"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB
M"FUS9W-T<B`B4^EL96-T:6]N(&UU;'1I<&QE(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")0
M87)A;>ET<F%G92!D=2!C;VUP=&4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B
M365S(&1O;F[I97,@<&5R<V]N;F5L;&5S(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HT-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUO;B!P
M;W)T86EL(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED
M(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(E!RZ7-E;G1A=&EO;B!D92!M
M;VX@<&]R=&%I;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G
M<W1R(")":7)M86YI92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS
M9W-T<B`B3D].+"!J92!N)V%C8V5P=&4@<&%S(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB:64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").Z7!A;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B4&%Y<RU"87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS
M9W-T<B`B06YT:6QL97,@;NEE<FQA;F1A:7-E<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E
M(%523"(*;7-G<W1R(")54DP@9&4@8F%S92!D92!.971S8V%P92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S
M8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@<NEV;V-A
M=&EO;B!D92!L)T$N0RX@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R(")54DP@9&4@;&$@<&]L:71I<75E(&0G02Y#+B!.971S
M8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U
M"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(")54DP@9&4@
M<F5N;W5V96QL96UE;G0@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO
M;B!54DPB"FUS9W-T<B`B55),(&1E('+I=F]C871I;VX@3F5T<V-A<&4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYO;2!D=2!S97)V
M975R(%-33"!.971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT(@IM<V=S='(@(D-O;6UE;G1A:7)E(&1U(&-E<G1I9FEC870@3F5T<V-A
M<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4>7!E
M(&1U(&-E<G1I9FEC870@3F5T<V-A<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(E+I<V5A=2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DIA;6%I<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W5V96QL92U#86SI
M9&]N:64B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=79E
M;&QE(&-A=.EG;W)I92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I
M9"`B3F5W($UO;VXB"FUS9W-T<B`B3F]U=F5L;&4@;'5N92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=79E874@;F]M(&1E(&-O;FYE
M>&EO;B`H9F%C=6QT871I9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:
M96%L86YD(@IM<V=S='(@(DYO=79E;&QE+5KI;&%N9&4B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*
M;7-G<W1R(").;W5V96%U(&UO="!D92!P87-S92(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("),92!N;W5V
M96%U(&UO="!D92!P87-S92!E>'!I<F5R82!L92`E>"XB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@
M9&]N)W0@;6%T8V@N(@IM<V=S='(@(DQE<R!N;W5V96%U>"!M;W1S(&1E('!A
M<W-E(&1I9F;H<F5N="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM
M<V=S='(@(DYO=79E;&QE(&9E;NIT<F4@*%]B;&%N:RDB"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G
M<W1R(").;W5V96QL97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D9O<G5M<R(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM
M<V=S='(@(E-U:79A;G0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G
M:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B-"!P:&%S97,@<W5I=F%N=&5S
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N
M<R(*;7-G<W1R(")/<'1I;VYS('-U:79A;G1E<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")3=6EV
M86YT/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@
M(DYI8V%R86=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T
M<B`B3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T
M<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYU:70B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@
M(DYO;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM
M<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB4&%S(&1E(&1O;F[I97,@
M9&4@8V]N9FEG=7)A=&EO;B!P;W5R(&QE<W%U96QL97,@;6]N=')E<B!L97,@
M9&EF9NER96YC97,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(E!A<R!D92!S=')A=.EG
M:64@9&ES<&]N:6)L92!P;W5R(&9A:7)E(&1E<R!I;6%G97,@25-/+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(E!A<R!D92!G
M86)A<FET(&5N('1R86ET96UE;G0@<&%R(&QO="XB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I
M9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB
M"FUS9W-T<B`B075C=6X@8FQO8R!N)V5X:7-T92#@(&QA('!O<VET:6]N(&1E
M;6%N9.EE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM
M<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B4&%S(&1E(&YO;2!D92!C86QE;F1R:65R
M(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@34-!3"XB"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*
M;7-G<W1R(").;VX@;6]D:69IZ2XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B075C=6YE('-O=7,M<&5R
M;6ES<VEO;B!N)V$@8F5S;VEN(&0GZG1R92!A:F]U=.EE('-O=7,@8V4@;FEV
M96%U+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<X(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$W"B,Z(&9R86UE=V]R:R]5=&EL+U5T
M:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(D%U
M8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N('-PZ6-I9FGI92!P
M;W5R("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4U"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B075C=6YE(&EN9F]R;6%T:6]N(&1E(&-O
M;F9I9W5R871I;VX@9F]U<FYI92!P;W5R($944"!61E,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R
M(")!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE
M('!O=7(@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")!=6-U;F4@
M:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,
M+49I;&4@5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S
M='(@(D%U8W5N(&-RZ61I="!D:7-P;VYI8FQE+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B075C=6YE(&1E<W1I;F%T
M:6]N('1R;W5VZ64N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.3(P"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(D%U8W5N
M(&9I8VAI97(@96YV;WGI(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q
M"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B075C=6X@:6/T;F4@
M=')O=7;I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(D%U
M8W5N(&QI974@;B=E<W0@<^EL96-T:6]N;NDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B075C=6X@96UP;&%C96UE;G0@;B=E<W0@:6YD:7%UZ2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B075C
M=6X@;65S<V%G92!F;W5R;FDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I
M960N(@IM<V=S='(@(D%U8W5N(&YO;2!S<.EC:69IZ2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B
M3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B075C=6X@;F]M8G)E('-P
MZ6-I9FGI+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B
M3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E!A<R!D)V%P:&]R:7-M
M97,@8VAO<75A;G1S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D%U8W5N(&UO="!D92!P87-S92!F;W5R
M;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($A45%`N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")!=6-U;B!M;W0@9&4@<&%S<V4@9F]U<FYI('!O=7(@;"=A=71H96YT:69I
M8V%T:6]N('!A<B!)34%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B075C=6X@;6]T(&1E('!A
M<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@2V5R8F5R
M;W,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M
M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B075C=6X@;6]T
M(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(D%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R
M(&PG875T:&5N=&EF:6-A=&EO;B!005-35T0N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@
M9&4@<&%S<V4@<W#I8VEF:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@4TU"
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM
M<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB075C=6X@8VAE;6EN
M('9E<G,@;&4@8FEN86ER92!/<&5N4U-,(&9O=7)N:2X@3&4@8FEN86ER92!D
M)T]P96Y34TP@97-T("(*(F[I8V5S<V%I<F4@<&]U<B!F;VYC=&EO;FYE<B!A
M=F5C(&1E<R!D;VYNZ65S(%!+0U,@,3(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S
M+B(*;7-G<W1R(")!=6-U;F4@8V]N9FER;6%T:6]N(&5N(&%T=&5N=&4B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S
M970N(@IM<V=S='(@(E!A<R!D92!Q=6]T82!P;W-I=&EO;F[I+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*
M;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E!A<R!D92!RZ&=L97,B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R
M871O<B!S<&5C:69I960N(@IM<V=S='(@(D%U8W5N('/I<&%R871E=7(@<W#I
M8VEF:>DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B4&%S(&1E
M(&/T=.ES(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G
M:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")&:6-H:65R(&EN97AI<W1A;G0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(D%U8W5N('+I<&5R=&]I<F4@=&5M<&]R86ER92!E<W0@9&ES<&]N
M:6)L92!P;W5R(&QA(&-A8VAE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")!=6-U;B!N;VT@9"=U=&EL:7-A
M=&5U<B!E="`O;W4@;6]T(&1E('!A<W-E(&5N=F]YZ2XB"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B075C=6YE(&1O;F[I92!834P@=F%L
M:61E(&XG82#I=.D@<F5T;W5R;NEE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R
M(")087,@9&4@=F%L975R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(E!A<R!D92!V97)S:6]N('1R;W5VZ64@9&%N<R!L82!C;VYF:6=U<F%T:6]N
M(&]R:6=I;F%L92X@4NEGZ6[I<F5Z(&QA("(*(F-O;F9I9W5R871I;VXN(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB4&%S(&1E('9E<G-I;VX@=')O=7;I
M92!D86YS('9O=')E(&-O;F9I9W5R871I;VXN(%+I9^ENZ7)E>B!L82!C;VYF
M:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B075C=6XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE
M("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(D%U8W5N("AU=&EL:7-E<B!I;7!L
M:6-I=&5M96YT*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED
M(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(").;W)D:7%U92`H25-/
M+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N
M9"(*;7-G<W1R("+.;&4@3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B2.EM:7-P:.AR92!.;W)D(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B
MSFQE<R!-87)I86YN97,@9'4@;F]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F]R=V%Y(@IM<V=S='(@(DYO<G;H9V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@
M(E!A<R!A<'+H<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(E!A<R!A=F%N="(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T
M(&$@9&ER96-T;W)Y(@IM<V=S='(@(E!A<R!U;B!D;W-S:65R(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`B3F]N(&EM<&SI;65N=.DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R
M("));F%C=&EF(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C`X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S0*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(U,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#4@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,P,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V
M-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(V"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W-`HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3DQ(&9R86UE=V]R:R]61E,O5D93+G!H<#HV
M-CD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYO;B!P<FES(&5N
M(&-O;7!T92XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP."!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&5S(@H*(SH@<V5R
M=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O
M(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B4FEE;B#@(&YA=FEG=65R+"!R
M971O=7)N97H@96X@87)R:>AR92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
M3F]V96UB<F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0S"FUS
M9VED(").=6UB97(B"FUS9W-T<B`B3F]M8G)E(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R,@IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B
M"FUS9W-T<B`B3F]M8G)E(&1E(&-A<F%C=.AR97,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`B3F]M8G)E(&1E(&-O;&]N;F5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#$X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#`@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(DYO;6)R92!D92!R86YGZ65S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYO;6)R92!N;VX@
M<W#I8VEF:>D@<&]U<B!L82!M:7-E(.`@:F]U<B!D92!L82!L:7-T92!D92!D
M:7-T<FEB=71I;VXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B
M:F5C="(*;7-G<W1R(")/8FIE="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")#<NEA
M=&5U<B!D)V]B:F5T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P
M,0IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3V-T86PB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*
M;7-G<W1R(")/8W1O8G)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR
M"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT<F4@86YT:2UO
M9F9E;G-A;G0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS
M9VED(")/9F9I8V4B"FUS9W-T<B`B0G5R96%U(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R
M9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(DPG86YC:65N(&5T(&QE
M(&YO=79E874@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@9&EF9NER96YT
M<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@
M(D]L9"!P87-S=V]R9"(*;7-G<W1R(")!;F-I96X@;6]T(&1E('!A<W-E(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@
M<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(DPG86YC:65N(&UO
M="!D92!P87-S92!E<W0@:6YC;W)R96-T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")/;6%N(@IM<V=S='(@(D]M86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@
M<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B4V5U;"!L97,@<V5R
M=F5U<G,@24U!4"!S=7!P;W)T96YT(&QE<R!D;W-S:65R<R!P87)T86?I<RXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E-E=6QE;65N="!L97,@JZ!F;W)T
M=6YE<Z"[(&]F9F5N<V%N=&5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38X"FUS9VED(")/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E5N92!S
M975L92!A9')E<W-E(&1E(&-O=7)R:65L('!E<FUI<V4N(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R
M("(B"B)3975L<R!L92!P<F]P<FGI=&%I<F4@;W4@;"=A9&UI;FES=')A=&5U
M<B!S>7-TZ&UE('!E=70@;6]D:69I97(@;&5S("(*(G!E<FUI<W-I;VYS(&0G
M=6X@<&%R=&%G92XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B3W5V<FER(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I
M9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB17)R975R($]P96Y3
M4TR@.B!I;7!O<W-I8FQE(&0G97AT<F%I<F4@;&5S(&1O;F[I97,@9&4@;&$@
M<&%R=&EE('-I9V[I92!3+TU)344B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H
M:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W5V<FER(&QE<R!L
M:65N<R!D86YS('5N92!N;W5V96QL92!F96[J=')E(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S
M='(@(E-Y<W3H;64@9"=E>'!L;VET871I;VXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P
M=&EO;G,B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B3W!T:6]N<R!P;W5R("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E
M9"!,:7-T(@IM<V=S='(@(DQI<W1E(&YU;>ER;W3I92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I
M;VXB"FUS9W-T<B`B3W)G86YI<V%T:6]N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B56YI=.D@;W)G86YI<V%T:6]N;F5L;&4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM
M<V=S='(@(D]R9V%N:7-A=&EO;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G
M<W1R(")-;V3H;&4@;W)I9VEN86P@9"=A<'!L:6-A=&EO;B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I
M;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B36]DZ&QE<R!O<FEG:6YA
M=7@@9&%N<R`E<Z`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM
M<V=S='(@(D%U=')E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM
M<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B075T<F5S(&EN9F]R
M;6%T:6]N<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G
M:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W-I;VYS(&1U
M('!R;W!R:>ET86ER92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H
M<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DPG875T:&5N=&EF:6-A=&EO;B!004T@;B=E<W0@<&%S
M(&1I<W!O;FEB;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS
M9W-T<B`B36]D=6QE(%!%05(Z.DUA:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U
M<F4B"FUS9W-T<B`B4VEG;F%T=7)E(&YU;>ER:7%U92!01U`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B1&]N;NEE<R!01U`@8VAI9F9RZ65S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B
M4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B0VQE9B!P=6)L:7%U92!01U`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D1O;F[I97,@4$=0
M('-I9V[I97,O8VAI9F9RZ65S(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y
M"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")#;V1E(%!(4"(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(DEN
M=&5R<'+I=&5U<B!02%`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0
M;'5I92!LZ6?H<F4@;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T
M<B`B4&QU:64@;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T
M<B`B079E<G-E<R!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R
M(").96EG92!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(D-H=71E<R!D92!N96EG92!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@
M4W5N(@IM<V=S='(@(E-O;&5I;"!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B3W)A9V5S(&PG87!RZ',M;6ED:2(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I
M<R!M:7-S:6YG(@IM<V=S='(@(D5X=&5N<VEO;B!03U-)6"!A8G-E;G1E(@H*
M(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@
M(DEN=&5R<'+I=&5U<B!07TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G
M<W1R(")296UP;&ES<V%G92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T
M86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QA=2(*;7-G<W1R(")"96QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T
M:6YE("AT97)R:71O:7)E(&]C8W5PZ2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B4&%P;W5A<VEE+4YO=79E;&QE
M+4=U:6[I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S
M='(@(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4&%R
M=&EE;&QE;65N="!N=6%G975X(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`Q-0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B
M36]T(&1E('!A<W-E(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B0VAA;F=E;65N="!D=2!M;W0@9&4@<&%S<V4@969F96-T=>DN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED
M(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B36]T(&1E('!A<W-E(&EN
M8V]R<F5C="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DUO="!D92!P87-S92!R97%U:7,@<&]U<B!L
M)V%U=&AE;G1I9FEC871I;VX@4D%$2553+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-3`*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N(@IM<V=S='(@(DUO="!D92!P87-S92!A=F5C(&-O;F9I<FUA=&EO;B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S
M<W=O<F0Z(@IM<V=S='(@(DUO="!D92!P87-S9:`Z(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T
M<B`B36]T(&1E('!A<W-EH#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S$*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(DQE<R!M;W1S(&1E('!A<W-E(&1O:79E;G0@ZG1R92!I
M9&5N=&EQ=65S+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS
M9VED(")087-T92(*;7-G<W1R(")#;VQL97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M
M(&-L:7!B;V%R9"(*;7-G<W1R(")#;VQL97(@9&5P=6ES(&QE('!R97-S92UP
M87!I97)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")#:&5M:6XB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N
M=7!S.B(*;7-G<W1R(")#;VYF:7)M871I;VYS(&5N(&%T=&5N=&6@.B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S
M='(@(E!E<G-O;FYE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!O=7)C
M96YT86=E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R(*;7-G<W1R(")%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E
M;F%N8V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S
M='(@(D5F9F5C='5E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92#@
M(&QA(&-O;FYE>&EO;J`_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4&5R;6ES<VEO
M;B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S
M='(@(DQA('!E<FUI<W-I;VX@JZ`E<Z"[(&XG97-T('!A<R!S=7!P<FEMZ64N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E
M<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUI<W-I;VX@<F5F=7/I92(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R(")097)M:7-S:6]N<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G
M:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-T<F%T:6]N(&1E<R!P97)M:7-S:6]N<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T
M<B`B1&]N;NEE<R!P97)S;VYN96QL97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(E!E<G4B"FUS9W-T<B`B4.ER;W4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B06YI;6%U>"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B4&AI;&EP<&EN97,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV
M"FUS9VED(")0:&]N92(*;7-G<W1R(")4Z6SI<&AO;F4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B
M4&AO=&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T
M<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I>&5L<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E
M<R(*;7-G<W1R(")0;&%T:71U9&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L
M:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(E-64"!C;&EQ=65Z(&1A;G,@
M=6YE(&-E;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B
M4U90(&-O;F9I<FUE>B!L82!S=7!P<F5S<VEO;B!D92!C970@Z6SI;65N=*`Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E-64"!C;VYF:7)M
M97H@<75E('9O=7,@=F]U;&5Z(&3I;&EE<B!C970@Z6SI;65N="XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-34Y"FUS9VED(")0;&5A<V4@96YT
M97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R(")6975I;&QE>B!S86ES
M:7(@=6X@;6]I<R!E="!U;F4@86YNZ64N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E9E=6EL
M;&5Z('-A:7-I<B!U;B!N;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R:66@
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.3@*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E9E=6EL
M;&5Z(&5N=')E<B!U;F4@861R97-S92!)4"!V86QI9&4N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8S-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B(@HB5F5U:6QL97H@96YT<F5R('5N92!D871E('9A
M;&ED9:`[(';I<FEF:65Z(&QE(&YO;6)R92!D92!J;W5R<R!D=2!M;VES+B`B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0T"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")6975I;&QE>B!E;G1R
M97(@=6YE(&AE=7)E('9A;&ED92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E9E=6EL;&5Z(&9O=7)N:7(@=6X@
M<NES=6WI(&1U('!R;V)LZ&UE+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS
M9W-T<B`B5F5U:6QL97H@9F]U<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U
M<B!E="!V;W1R92!M;W0@9&4@<&%S<V4B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E
M('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E9E=6EL;&5Z(&QI<F4@;&4@
M=&5X=&4@<W5I=F%N="X@5F]U<R!D979E>B!A8V-E<'1E<B!L97,@8V]N9&ET
M:6]N<R!P;W5R("(*(G5T:6QI<V5R(&QE('-Y<W3H;64N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@
M(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B
M5F5U:6QL97H@96YT<F5R(&QE(&YO=79E874@;F]MH&1E(&QA(&-A=.EG;W)I
M9:`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L
M;V=N92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B4&]L:71I<75E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B4V-R=71I;G,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T
M=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R(")0;W-I=&EO;B!D92!C971T92!I;6%G92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VET:6]N
M(&1E(&-E('1A8FQE874B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(D5N=F]Y97(@X"!C92!D;W-S:65R
M("AN;VX@87!P;&EQ=>D@<&%R($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B
M"FUS9W-T<B`B4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R;FGH<F5S
M(&AE=7)E<Z`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B
M4')O8F%B:6QI=.D\8G(@+SYD92!P;'5I92(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L
M9&%PH#H@97AT96YS:6]N(')E<75I<V4@3$1!4"!N;VX@=')O=7;I92XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@
M(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;J`Z(&5X=&5N<VEO;B!R
M97%U:7-E(*N@<V5S<VEO;J"[(&YO;B!T<F]U=NEE+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")0<F5S
M<VEO;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S
M<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R(")0<F5S<VEO;B!A=2!N:79E
M874@9&4@;&$@;65RH#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")0<F5S<VEO;J`Z
M("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D%P97+G=2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(D%P97+G=2!D92!L)VEM86=E(&1A;G,@=6YE(&YO
M=79E;&QE(&9E;NIT<F4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,`IM<V=I
M9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS('!RZ6/I9&5N
M=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B26UP<FEM97(@
M;&4@9&]C=6UE;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(D-L968@<')I=NEE
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;.AM92(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G
M<W1R(")$97-C<FEP=&EO;B!D=2!P<F]B;.AM92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R
M;VIE=',B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(W,PIM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5&5X=&4@
M8V]U<G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*
M;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B0VQE9B!P=6)L:7%U92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0
M=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET:&UE(&1E(&-L
M968@<'5B;&EQ=64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R
M;6%T:6]N<R!S=7(@;&$@8VQE9B!P=6)L:7%U92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
MR6-H96,@9&4@;&$@9^ENZ7)A=&EO;B!D92!L82!P86ER92!D92!C;&5F<R!P
M=6)L:7%U92]P<FEVZ64N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O
M(%)I8V\B"FUS9W-T<B`B4&]R=&\@4FEC;R(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E
M<R(*;7-G<W1R(")0=7)G97(@;&5S(&UE<W-A9V5S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@(E)E<77J=&4B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S
M='(@(E%U;W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="DB"FUS9W-T<B`B0VQE9B!P=6)L:7%U92!24T$@*"5D(&)I=',I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,0IM<V=I9"`B4F%D:6\@
M<V5L96-T:6]N(@IM<V=S='(@(E/I;&5C=&EO;B!R861I;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN
M(@IM<V=S='(@(E!L=6EE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B4&QU
M:64@=/1T(&QE(&UA=&EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")0;'5I
M92!T87)D(&1A;G,@;&$@:F]U<F[I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(%-H;W=E<B(*;7-G
M<W1R(")!=F5R<V5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4&QU
M:64@970@;F5I9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(E!L=6EE
M('!U:7,@;F5I9V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I
M9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B07!H;W)I<VUE(&%U(&AA<V%R
M9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B
M4F%T:6\B"FUS9W-T<B`B5&%U>"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQI<F4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B
M4F5A9"!M97-S86=E<R(*;7-G<W1R(")-97-S86=E<R!L=7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`B4W5P<')E<W-I;VX@9.EF:6YI=&EV92!D
M92`E<Z`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*(E-U<'!R97-S:6]N(&3I9FEN:71I=F4@9&5S(&1O;F[I
M97,@<&]U<B!L)W5T:6QI<V%T975R("5SH#\@0V5T=&4@;W#I<F%T:6]N("(*
M(F5S="!DZ69I;FET:79E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(E)E<')E;F1R92!V;W1R92!D97)N:>AR92!A8W1I;VXB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")2869R8>YC:&ER
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S
M:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(E)A9G)A[F-H:7(@
M;&5S(.ELZ6UE;G1S(&1U(&UE;G4@9'EN86UI<75EH#HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W
M.B(*;7-G<W1R(")2869R8>YC:&ER(&PGZ6-R86X@9'4@<V]M;6%I<F6@.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S(*;7-G:60@(E)E9V5X(@IM<V=S='(@(D5X<')E<W-I;VX@<F%T:6]N;F5L
M;&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C(X"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(").879I9V%T975R(')E;&%T
M:6]N;F5L(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM
M<V=S='(@(E)E8VAA<F=E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S
M"FUS9VED(")296UA<FMS(@IM<V=S='(@(E)E;6%R<75E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM
M<V=S='(@(E-E<G9E=7)S(&1I<W1A;G1S(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),(&1I<W1A;G1E("AH
M='1P.B\O=W=W+F5X96UP;&4N8V]M+VAO<F1E+RF@.B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(E)E=&ER
M97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@
M(E)E;6]V92!";&]C:R(*;7-G<W1R(")2971I<F5R(&QE(&)L;V,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED
M(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E)E=&ER97(@;&$@8V]L;VYN92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*
M;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E)E=&ER97(@;&4@
M9F]R;6%T86=E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*
M;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E)E=&ER97(@;&$@<&%I<F4B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B16YL979E<B!L92!S8W)I<'0@96YR96=I<W1RZ2!D=2!R
MZ7!E<G1O:7)E('1E;7!O<F%I<F4@9'4@<V5R=F5U<BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G
M:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4F5T:7)E<B!L92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R(")2971I<F5R(&-E(&YO975D(&1U(&1O8W5M96YT(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S
M97(B"FUS9W-T<B`B4F5T:7)E<B!L)W5T:6QI<V%T975R(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")2971I<F5R(&PG=71I;&ES
M871E=7*@.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(")!=6-U;F4@<NEP;VYS92#@('9O
M=')E(')E<77J=&4N($-O9&4@9"=E<G)E=7(@<F5T;W5R;NF@.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T
M960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(DQE('-E
M<G9I8V4@9&5M86YDZ2!E<W0@:6YT<F]U=F%B;&4N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
M3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I
M8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C<X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#8Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DQE('!A
M<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@;B=E<W0@<&%S('-PZ6-I9FGI
M(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B!D=2`B"B)61E,N(@H*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*(DQE('!A<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@
M;B=E<W0@<&%S('-PZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@
M(E)E<75I<F5D($9I96QD(@IM<V=S='(@(D-H86UP(&]B;&EG871O:7)E(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
M4L!:(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@
M(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E)E;6ES92#@('KI<F\@9'4@;6]T
M(&1E('!A<W-E(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4F5M971T<F4@
MX"!ZZ7)O('9O=')E(&UO="!D92!P87-S92(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S$*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")2
M979E;FER(.`@;&$@9&5R;FGH<F4@<F5Q=>IT92(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HW,B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<W%L<VAE
M;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM<V=S='(@(E+I<W5L=&%T<R(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS
M9W-T<B`B4F5V96YI<B!A=7@@;W!T:6]N<R(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*
M;7-G<W1R(")2Z2UE;G1R97(@;&4@;F]U=F5A=2!M;W0@9&4@<&%S<V4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E+I=6YI;VXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(E)E=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N('!RZ6/I9&5N=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,B"FUS9W-T<B`B3W!T:6]N<R!D92!L)^ED:71E=7(@
M4FEC:"!497AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED
M(")2:61D;&5S(@IM<V=S='(@(D1E=FEN971T97,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I
M9VAT(@IM<V=S='(@(D1R;VET92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,#`*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")%;G3J=&4@
M9&4@9')O:71E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-@IM
M<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E9A;&5U<G,@8V]R<F5C=&5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M4')O<')IZ73I<R!D92!L82!R86Y?9^EE("XN+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS
M9W-T<B`B4O1L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS
M9W-T<B`B4F]U;6%N:64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(E!I
M=F]T97(@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B4&EV;W1E
M<B#@(&=A=6-H92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")0:79O
M=&5R(.`@9')O:71E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<')IZ73I<R!D92!L82!R86YGZ64B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2
M;W<@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1E(&QA(')A;F?I
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")286YGZ65SH#HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS
M9VED(")2=6QE<R(*;7-G<W1R(")2Z&=L97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM
M<V=S='(@(D1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N=')E('1O=71E<R!L
M97,@<F%N9^EE<R!E="!L97,@8V]L;VYN97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R(")$
M97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@8V]L;VYN97,@<V5U
M;&5M96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!R;W=S(&]N;'DB"FUS9W-T<B`B1&5S(&9I;&5T<R!A<'!A<F'N=')O;G0@
M96YT<F4@;&5S(')A;F?I97,@<V5U;&5M96YT(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(DQA;F-E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2
M=7-S:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B
M4G=A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G
M<W1R(")3:6=N871U<F4@Z6QE8W1R;VYI<75E(%,O34E-12(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B365S<V%G92!C:&EF9G+I(%,O
M34E-12(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G
M:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B3"=A=71H96YT:69I8V%T:6]N(%-!4TP@;B=E<W0@<&%S(&1I<W!O
M;FEB;&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED
M(")335,@365S<V%G:6YG(@IM<V=S='(@(DUE<W-A9V5R:64@4TU3(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T
M<B`B26YT97)P<NET975R(%-13"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R-S$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU
M<',B"FUS9W-T<B`B3W)D<F4@4U%,('!O=7(@<F5T;W5R;F5R(&QE<R!V86QE
M=7)S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B
M4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-5
M0T-%4U,B"FUS9W-T<B`B4U5#0\A3(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS
M9VED(")37U%,(%-H96QL(@IM<V=S='(@(DEN=&5R<'+I=&5U<B!37U%,(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM
M<V=I9"`B4V$B"FUS9W-T<B`B4V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M86EN="!(96QE;F$B"FUS9W-T<B`B4V%I;G1E+4CI;.AN92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A
M:6YT+4-H<FES=&]P:&4M970M3FGI=NAS(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M(")386EN="!,=6-I82(*;7-G<W1R(")386EN=&4M3'5C:64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(E-A:6YT+5!I97)R92!E="!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*
M;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S
M='(@(E-A:6YT+59I;F-E;G0M970M;&5S($=R96YA9&EN97,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")3
M86UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B3>IM92!C861R92`H7W-E;&8I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$@
M;V-C:61E;G1A;&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN
M;R(*;7-G<W1R(")386EN="U-87)I;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\M5&]MZ2UE="U0
M<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")&;W5R;FES<V5U
M<B!S871E;&QI=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B
M:6$B"FUS9W-T<B`B07)A8FEE(%-A;W5D:71E(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(D5N<F5G
M:7-T<F5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")%
M;G)E9VES=')E<B"KH"5SH+LB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(D5N<F5G:7-T<F5R("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QE
M<R!O<'1I;VYS(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I
M9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"B)%;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N(&?I
M;NERZ64@8V]M;64@=6X@<V-R:7!T(%!(4"!D86YS(&QE('+I<&5R=&]I<F4@
M(@HB=&5M<&]R86ER92!D92!V;W1R92!S97)V975R+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QA(&-O
M;F9I9W5R871I;VX@9&4@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")38W)I<'0@9&4@;6ES92#@
M(&IO=7(@9&4@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I('-O=7.@.B"K("5S
MH+LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(D]R86=E<R!I
M<V]LZ7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C
M:65N8V4B"FUS9W-T<B`B4V-I96YC92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B4F5C:&5R8VAE(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN
M97,B"FUS9W-T<B`B36]T975R<R!D92!R96-H97)C:&4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.34R"FUS9VED(")396QE8W0@1FEL97,B"FUS
M9W-T<B`B0VAO:7-I<W-E>B!L97,@9FEC:&EE<G,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@
M82!D871E(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!U;F4@9&%T92(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B4^EL96-T:6]N;F5Z('5N(&=R;W5P92#@
M(&%J;W5T97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS
M9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4^EL96-T:6]N;F5Z
M('5N(&YO=79E874@<')O<')IZ71A:7)E(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T
M<B`B4^EL96-T:6]N;F5Z('5N('-E<G9E=7(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B
M"FUS9W-T<B`B4^EL96-T:6]N;F5Z('5N('5T:6QI<V%T975R(.`@86IO=71E
M<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5&]U="!SZ6QE8W1I;VYN
M97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0P"FUS9VED(")3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4^EL96-T:6]N
M;F5Z('1O=71E<R!L97,@8V]M<&]S86YT97,@9&4@;&$@9&%T92XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED
M(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(D-H;VES:7-S97H@=6X@;V)J
M970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<W"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(").92!SZ6QE8W1I;VYN
M97(@875C=6XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)3Z6QE8W1I;VYN
M97H@;&5S(&-A<F%C=.AR97,@9&]N="!V;W5S(&%V97H@8F5S;VEN(.`@;"=A
M:61E(&1E(&PG;W5T:6P@8VDM(@HB9&5S<V]U<RX@5F]U<R!P;W5V97H@96YS
M=6ET92!L97,@8V]P:65R(&5T(&QE<R!C;VQL97(@9&%N<R!V;W1R92!T97AT
M92XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4^EL96-T:6]N;F5Z
M(&QE(&3I;&EM:71E=7(@9&4@9&%T9:`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM
M<V=S='(@(E/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@9&%T9:`Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S
M='(@(E/I;&5C=&EO;FYE<B!L92!P<F]F:6P@<75E('9O=7,@9.ES:7)E>B!M
M;V1I9FEE<CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4^EL96-T
M:6]N;F5Z(&QE(&3I;&EM:71E=7(@9"=H975R9:`Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M
M870Z(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@;"=H975R
M9:`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E/I;&5C=&EO
M;FYE>B!D975X(&-H86UP<R!A<'!A<F5N=.ES+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M
M92XB"FUS9W-T<B`B4^EL96-T:6]N;F5Z('9O=')E('1HZ&UE(&1E(&-O=6QE
M=7)S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4^EL96-T
M:6]N;F5Z('9O=')E(&QA;F=U92!P<NEFZ7+I9:`Z(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`B16YV;WEE<B!L92!R87!P;W)T(&0G86YO;6%L:64B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T
M,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B16YV;WEE<B!335,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E/I;NEG86PB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`B4V]N9&6@.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E
M;6)R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY
M"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEE
M(&5T($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").=6WI
M<F\@9&4@<^ER:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("),97,@9&]N;NEE<R!D=2!S97)V975R('-O;G0@9F%U<W-E
M<R!O=2!N;VX@9&ES<&]N:6)L97,N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%T
M:6]N(&1E<R!S97-S:6]N<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I
M<F5D+B(*;7-G<W1R("))9"X@9&4@<V5S<VEO;B!E>'!I<NDN(@H*(SH@;&EB
M+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")397-S:6]N
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,3$*;7-G:60@(E-E
M="(*;7-G<W1R(")3Z6QE8W1I;VYN97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@HB0V]N9FEG=7)E<B!L97,@;W!T:6]N<R!P;W5R('9O=7,@<&5R
M;65T=')E(&1E(')E;65T=')E(.`@>NER;R!V;W1R92!M;W0@9&4@(@HB<&%S
M<V4@<VD@:F%M86ES('9O=7,@;"=O=6)L:65Z+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G
M<W1R(")#;VYF:6=U<F5R(&QE<R!S97)V975R<R!D:7-T86YT<R!A8V-E<W-I
M8FQE<R!D97!U:7,@=F]T<F4@<&]R=&%I;"XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4^EL
M96-T:6]N;F5Z('9O=')E(&QA;F=U92!P<NEFZ7+I92P@9G5S96%U(&AO<F%I
M<F4@970@;&5S(&]P=&EO;G,@9&4@9&%T92XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB1.EF:6YI<W-E
M>B!L82!P<F5M:>AR92!A<'!L:6-A=&EO;B!L86YCZ64L(&QE('1HZ&UE(&1E
M(&-O=6QE=7)S+"!L92`B"B)R869R8>YC:&ES<V5M96YT(&1E<R!P86=E<RP@
M970@9"=A=71R97,@;W!T:6]N<R!D)V%F9FEC:&%G92XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")#;VYF
M:6=U<F%T:6]N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B
M"FUS9W-T<B`B4V-R:7!T(&1E(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO
M=7(@9&ES<&]N:6)L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@(@IM<V=S='(@(E!L=7-I975R<R!E;F1R;VET<R!P
M;W-S:6)L97,@879E8R!L92!P87)A;>AT<F6@.B`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL97,B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*
M;7-G<W1R(")!8VAA="(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(E+I<W5MZ2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A
M8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R
M(")$;VET+6]N(&3I9FEN:7(@9&5S('1O=6-H97,@9&4@<F%C8V]U<F-I<R!P
M;W5R(&QA('!L=7!A<G0@9&5S(&QI96YSH#\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")!
M9F9I8VAE<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@
M(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@
M86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HB36]N=')E<B!L97,@9&EF9NER96YC97,@96YT<F4@;&$@8V]N
M9FEG=7)A=&EO;B!E;G)E9VES='+I92!A8W1U96QL96UE;G0@970@(@HB8V5L
M;&4@;F]U=F5L;&5M96YT(&?I;NERZ64N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/R(*;7-G<W1R(")-;VYT<F5R(&PG:&5U<F4@9&4@;&$@9&5R
M;FGH<F4@8V]N;F5X:6]N(.`@;"=E;G1RZ66@/R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C(*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@
M;W)I9VEN86PB"FUS9W-T<B`B36]N=')E<B!L)V]P=&EO;B!D92!C;VYS97)V
M97(@;"=O<FEG:6YA;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W
M.3(*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(DUO;G1R97(@;&4@<^EL
M96-T975R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")!9F9I
M8VAE<B!L82!B87)R92!D92!M96YU(&1E('1A8FQE875XH#\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(D%F9FEC:&5R
M(&QE(&UE;G4@)7,@X"!G875C:&6@/R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")!9F9I
M8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!T86)L96%U(&-E;&QU;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(D%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P
M<F]P<FGI=.ES(&1U('1A8FQE874B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")!9F9I8VAE
M<B!L82!B;^YT92!D92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D92!L82!R
M86YGZ64@9'4@=&%B;&5A=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B069F:6-H97(@;&$@8F_N
M=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ETZ7,@9&4@;"=I;6%G92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C`*;7-G:60@(E-H;W<@=7!L
M;V%D(@IM<V=S='(@(D%F9FEC:&5R(&PG96YV;VD@9&4@9FEC:&EE<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3:&]W97)S(@IM<V=S='(@(D%V97)S97,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L
M>2(*;7-G<W1R(")!=F5R<V5S('3T="!D86YS(&QA(&IO=7)NZ64B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B
M4VAO=V5R<R!,871E(@IM<V=S='(@(D%V97)S97,@=&%R9"!E;B!J;W5R;NEE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*
M;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(D%V97)S
M97,@875X(&%L96YT;W5R<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M4F5S<V5R<F5R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G
M:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")297-S97)R97(@;W4@9.EG86=E
M<B!D)V%B;W)D(&QE*',I(&)L;V,H<RD@=F]I<VEN*',I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N
M92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G
M:60@(E-I9VX@=7`B"FUS9W-T<B`B4R=I;G-C<FER92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B
M"FUS9W-T<B`B4VEG;F%T=7)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS
M9W-T<B`B06QG;W)I=&AM92!D92!S:6=N871U<F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W5R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#DS"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,#D*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,@IM<V=I9"`B4VEZ92(*;7-G<W1R
M(")486EL;&4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")!
M;FYU;&5R(&QA(&UA:6YT96YA;F-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F%Q=6EE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=NEN:64B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*
M;7-G<W1R(").96EG92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")!=F5R
M<V4@9&4@;F5I9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(D%V97)S
M97,@9&4@;F5I9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@
M(D%V97)S97,@9&4@;F5I9V4@=/1T(&1A;G,@;&$@:F]U<F[I92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3
M;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")!=F5R<V5S(&1E(&YE:6=E('1A
M<F0@96X@:F]U<F[I92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS
M9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B2&%U=&5U<B!D92!N96EG9:`Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q
M=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")1=6%N=&ETZ2!D)V5A=2#I
M<75I=F%L96YT92#@(&QA('%U86YT:73I(&1E(&YE:6=EH#H@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(LYL97,@
M4V%L;VUO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T
M<B`B4V]M86QI92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I
M9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")#:&%N<V]N<R!E="!P;^AM97,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`U"FUS9VED(")3;W)T
M(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@9&4@;"=O<F1R
M92!D92!T<FDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G
M<W1R(")!9')E<W-E('-O=7)C92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O
M=71H($%F<FEC82(*;7-G<W1R(")!9G)I<75E(&1U('-U9"(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RDB"FUS9W-T<B`B4W5D+65U<F]PZ65N("A)4T\M.#@U.2TS*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B1^EO<F=I92UD=2US=60@
M970@[FQE<R!386YD=VEC:"UD=2US=60B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(DCI;6ES<&CH<F4@4W5D(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P
M86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B17-P86-E(&5N
M=')E(&-E;&QU;&5S(&%D:F%C96YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")%<W!A8V4@
M96YT<F4@;&4@8V]N=&5N=2!E="!L82!B;W)D=7)E(&1A;G,@=6YE(&-E;&QU
M;&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,3(*;7-G:60@(E-P
M86-E<B(*;7-G<W1R(")%<W!A8V5U<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*
M;7-G<W1R(")%<W!A8V5M96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@
M<&%D9&EN9R(*;7-G<W1R(")%<W!A8V5M96YT(&5T(')E;7!L:7-S86=E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(D5S<&%G;F4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM
M<V=S='(@(E!O=7)R:65L(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")#87)A
M8W3H<F5S('-PZ6-I875X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G
M<W1R(")38VEN9&5R(&QA(&-E;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C
M;VQU;6XB"FUS9W-T<B`B4V-I;F1E<B!L82!C;VQO;FYE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I
M9"`B4W!L:70@<F]W(@IM<V=S='(@(E-C:6YD97(@;&$@<F%N9^EE(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T
M<B`B4W!O<G1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS
M9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z.#$*;7-G:60@(E-T86YD87)D
M(@IM<V=S='(@(E-T86YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-S@X"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%N;NEE
M(&1E(&3I8G5T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(LET870@
M;W4@<')O=FEN8V4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U="(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.30*;7-G:60@(E-T;W)A9V4@9F]R
M;6%T(@IM<V=S='(@(D9O<FUA="!D92!S875V96=A<F1E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(E)U92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS
M9W-T<B`B0F%R<NDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,P
M"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("),:7-T92!D92!C:&'N;F5S
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,`IM<V=I9"`B4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B4F5T:7)E<B!L
M92!D;VUA:6YE(&1E(&PG861R97-S92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#
M4U-=(@IM<V=S='(@(E-T>6QE(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B
M1&DB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(E-O=7,M<NEP97)T;VER92"KH"5SH+L@;F]N('1R;W5VZ2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@
M(E-U8FIE8W0B"FUS9W-T<B`B4W5J970B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,CD@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B16YV;VDB"@HC.B!S:6=N=7`N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D
M+B(*;7-G<W1R("(B"B),82!D96UA;F1E(&0G86IO=70@9&4@JZ`E<Z"[(&%U
M('-Y<W3H;64@82#I=.D@<V]U;6ES92X@5F]U<R!N92!P;W5R<F5Z('!A<R`B
M"B)V;W5S(&-O;FYE8W1E<B!J=7-Q=2?@('-O;B!A<'!R;V)A=&EO;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS
M9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B26YD:6-E(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$P-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S
M(@IM<V=S='(@(E-U8V/H<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@86IO=73I
M*&4I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(DQE<R!D;VYNZ65S(&1E(&PG
M=71I;&ES871E=7(@JZ`E<Z"[(&]N="!B:65N(.ETZ2!R971I<NEE<R!D=2!S
M>7-TZ&UE+BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("*KH"5SH+L@82!B:65N(.ET
MZ2!S=7!P<FEMZ2AE*2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@<F5T
M:7+I*&4I+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(E)E=&]U<B#@(&QA(&-O;F9I
M9W5R871I;VX@:6YI=&EA;&4@<NEU<W-I+B`@4F%F<F'N8VAI<B!L82!P86=E
M('!O=7(@=F]I<B!L97,@(@HB;6]D:69I8V%T:6]N<RXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B16YR96=I<W1R96UE;G0@9&4@;&$@8V]N9FEG=7)A=&EO
M;B!D92!L82!S875V96=A<F1E('+I=7-S:2XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`B(@HB16YR96=I<W1R96UE;G0@<NEU<W-I(&1E(&QA(&-O<&EE(&1E
M('-A=79E9V%R9&4@9'4@9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("4B"B)S
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`BJZ`E<Z"[
M(&$@8FEE;B#I=.D@;6ES*&4I(.`@:F]U<BXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B
MR6-R:71U<F4@9&4@)7,@<NEU<W-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W5D86XB"FUS9W-T<B`B4V]U9&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*
M;7-G<W1R(")3;VUM86ER92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B3&5V97(@9'4@4V]L96EL(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM
M<V=S='(@(D-O=6-H97(@9'4@4V]L96EL(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@
M(D5N<V]L96EL;.DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(DQE=F5R(&1U(%-O;&5I;"(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B3&5V97(O
M0V]U8VAE<B!D=2!3;VQE:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B3&5V97(@9'4@
M4V]L96EL.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X
M"FUS9VED(")3=6YS970B"FUS9W-T<B`B0V]U8VAE<B!D=2!3;VQE:6PB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R(")#;W5C:&5R(&1U(%-O;&5I;*`Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U
M<&5R<V-R:7!T(@IM<V=S='(@(D5X<&]S86YT(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")!<W-I
M<W1A;F-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T
M<B`B4W5R:6YA;2!O=2!'=7EA;F4@:&]L;&%N9&%I<V4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*
M;7-G<W1R(").;VT@9&4@9F%M:6QL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`BSFQE<R!3=F%L8F%R
M9"!E="!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA
M;F0B"FUS9W-T<B`B4W=A>FEL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W=E9&5N(@IM<V=S='(@(E-UZ&1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W
M:71Z97)L86YD(@IM<V=S='(@(E-U:7-S92(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(DIO=7)N86P@9&4@<WEN8VAR;VYI<V%T:6]N('-U<'!R:6WI(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S
M='(@(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H
M<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G
M<W1R(")%<G)E=7(@9&4@<WEN=&%X92!D86YS(&QE<R!T97)M97,@9&4@<F5C
M:&5R8VAE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P
M=6)L:6,B"FUS9W-T<B`B4WER:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")/
M<F%G97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,PIM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B3W)A9V4@
M970@=F5N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8T"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")/<F%G97,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B
M5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B3W)A9V5S(&UA=&EN875X(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I
M;&4B"FUS9W-T<B`B1FEC:&EE<B!44U8B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0
M<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:>ETZ7,@9'4@=&%B;&5A=2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G
M:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)L96%U(&1E('9A;&5U<G,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:>ET
MZ7,@9'4@=&%B;&5A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A
M:7=A;B(*;7-G<W1R(")48>]W86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN82(*;7-G<W1R(")48>]W86XL('!R;W9I;F-E(&1E($-H:6YE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")486II:VES
M=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9B(*;7-G<W1R(")486YZ86YI92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB
M"FUS9W-T<B`B0VEB;&6@.B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,R(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(E3B
M8VAE<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T
M"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(DYU;>ER;R!D92!T
MZ6SI<&AO;F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B
M5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<.ER871U<F4@<&]U
M<B!L82!D97)N:>AR92!H975R9:`Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")496UPZ7)A='5R
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@
M(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<.ER871U<F6@.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,B"FUS9W-T<B`B5&5M<.ER871U<F4\8G(@+SXH)7-(825S+R5S0F$E<RD@
M)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z
M-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R;V9I;""KH"5SH+L@;F]N('1R;W5VZ2(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B!D97,@;6]DZ&QE
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,R-`IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@
M3VYL>2(*;7-G<W1R(")497AT92!S975L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R(")!;&EG;F5M96YT(&1U('1E>'1E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X
M='1O<"(*;7-G<W1R(")497AT92!E;B!H875T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T
M<B`B2F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA[R`H5$E3+38R,"DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&'O;&%N9&4B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=E>'1E
M;G-I;VX@1E10(&XG97-T('!A<R!D:7-P;VYI8FQE+B(*"B,Z(&9R86UE=V]R
M:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S
M>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(DPG:&ES=&]R:7-A=&EO;B!E
M<W0@9.ES86-T:7;I92XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S
M='(@(DQE(&UO=&5U<B!D)VEN=.EG<F%T:6]N($AO<F1E+TMO;&%B(&YE('-U
M<'!O<G1E('!A<R"KH"5SH+LB"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T
M(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("),92!J;W5R;F%L($E-4U`@;B=A
M('!A<R!P=2#J=')E(&EN:71I86QI<^DN(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DQA(&-L87-S92!-
M86EN=&5N86YC93HZ(&XG82!P87,@Z73I(&-H87)GZ64@8V]R<F5C=&5M96YT
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I
M9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(DQA(&9E;NIT<F4@9&5S(&]P=&EO;G,@<R=E<W0@9F5R;>EE+B!3
M;W)T:64N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*
M(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S
M92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB3"=A9&UI;FES=')A=&5U<B!D
M;VET(&-O;F9I9W5R97(@=6X@8F%C:V5N9"!P97)M86YE;G0@<&]U<B!L97,@
M<&5R;6ES<VEO;G,@(@HB<VD@=F]U<R!V;W5L97H@;&5S(&5M<&QO>65R+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DQA
M(&)O<F1U<F4@9'4@8F%S('-E=6QE;65N="(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@
M8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S
M='(@(B(*(DPG240@9'4@8V]N=&%C="!N)V$@<&%S(.ETZ2!S<.EC:69IZ2P@
M;&%I<W/I('9I9&4@;W4@;B=A('!A<R#I=.D@=')O=7;I(&1A;G,@(@HB;&$@
M8F%S92!D92!D;VYNZ65S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M0V4@8V]N=&%C="!A(&)I96X@Z73I(&%J;W5TZ2#@('9O=')E(&-A<FYE="!D
M)V%D<F5S<V5S+B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"B),92!B;&]C(&1E('-I9VYA='5R92!01U`@<^EP87+I
M(&5S="!NZ6-E<W-A:7)E('!O=7(@=NER:69I97(@;&$@<VEG;F%T=7)E+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B
M"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(DPG240@9&4@;&$@;&ES
M=&4@;B=A('!A<R#I=.D@<W#I8VEF:>DL(&QA:7-SZ2!V:61E(&]U(&YO;B!T
M<F]U=ND@9&%N<R!L82`B"B)B87-E(&1E(&1O;F[I97,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS
M9W-T<B`B3&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N(&XG82!P87,@Z73I('-P
MZ6-I9FGI92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3&4@8VAI9F9R96UE;G0@;NEC
M97-S:71E('5N92!C;VYN97AI;VX@<^EC=7)I<^EE+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B3&4@9FEC:&EE<B`E
M<R!D;VET(&-O;G1E;FER(&QE<R!O<'1I;VYS("5S+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(DQE(&9I8VAI
M97(@)7,@9&]I="!C;VYT96YI<B!C97)T86EN97,@;W!T:6]N<R`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C8*;7-G:60@(E1H92!F
M:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(DQE
M(&9I8VAI97(@;F4@<&5U="!P87,@ZG1R92!C;W!IZ2!S=7(@;'5I+6WJ;64N
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B3&4@9FEC:&EE<B!N
M92!C;VYT96YA:70@875C=6YE(&1O;F[I92XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W
M:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M
M97-S86=E+B(*;7-G<W1R(")#92!Q=6D@<W5I="!S;VYT(&QE<R!E;BUTZG1E
M<R!P;W5R(&-E(&UE<W-A9V4@;65S<V%G92]21D,X,C(N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F
M(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H
M97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R
M("(B"B),92!M;V1E('!L96EN(.EC<F%N(&-A=7-E(&1E<R!P<F]B;.AM97,@
M879E8R!);G1E<FYE="!%>'!L;W)E<B!D^R#@(&1E<R`B"B)B;V=U97,@9'4@
M;F%V:6=A=&5U<B!Q=6D@;B=O;G0@<'4@ZG1R92!C;VYT;W5R;NES+B!6;W5S
M('!O=79E>B#J=')E("(*(F-O;F9R;VYTZ7,@X"!D92!L)V%F9FEC:&%G92!D
M92!C87)A8W3H<F5S(.ET<F%N9V5S+"!A=2!N;VXM9F]N8W1I;VYN96UE;G0@
M(@HB9&5S(&-E<G1A:6YE<R!F;VYC=&EO;G,@970O;W4@874@<&QA;G1A9V4@
M86SI871O:7)E(&1U(&YA=FEG871E=7(N(%-I('9O=')E("(*(G-Y<W3H;64@
M97-T('5N(%=I;F1O=W,@.7@L(&EL(&5S="!T<NAS('!O<W-I8FQE('%U92!V
M;W5S(&%U<F5Z('5N92`G1F%U=&4@(@HB9^ENZ7)A;&4@9&4@<')O=&5C=&EO
M;B<@970@<75E('9O=7,@9&5V<F5Z(')E9.EM87)R97(@=F]T<F4@;W)D:6YA
M=&5U<BY<7&XB"B)<7&Y6;W5S(&%V97H@Z73I('!RZ79E;G5S+B!35E`@87!P
M=7EE>B!S=7(@3TL@<VD@=F]U<R!V;W5L97H@=&]U:F]U<G,@(@HB97-S87EE
M<B!L92!M;V1E('!L96EN(.EC<F%N(&1E(&PGZ61I=&5U<B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),)VED
M96YT:73I(*N@)7.@NR`@82#I=.D@<W5P<')I;>EE+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@
M(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DQE(&/T=.D@9V%U
M8VAE('-E=6QE;65N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M(@IM<V=S='(@(B(*(DPG96UP;&%C96UE;G0@9'4@<')O9W)A;6UE($=N=5!'
M(&1O:70@ZG1R92!F;W5R;FD@X"!L82!C;&%S<V4@0W)Y<'1?<&=P.CHN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(DQE(&UE<W-A9V4@96YV
M;WGI(&QE("5S(.`@)7,@879E8R!C;VUM92!S=6IE=""KH"5SH+L@82#I=.D@
M869F:6-HZ2X@7&XB"B));"!N)WD@82!A=6-U;F4@9V%R86YT:64@<75E(&-E
M(&UE<W-A9V4@82#I=.D@;'4@;W4@8V]M<')I<RXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<T"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3&4@;F]M
M(.`@=71I;&ES97(@96X@;&EA;G0@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@
M(DQE(&YO;6)R92!D92!C:&%M<',@9&]I="#J=')E('5N(&YO;6)R92!V86QI
M9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R
M"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("),92!M;V1U
M;&4@3W!E;E-33"!E<W0@<F5Q=6ES('!O=7(@;&$@8VQA<W-E($AO<F1E7T-R
M>7!T7W-M:6UE.CHN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E
M<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E
M9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*
M(DQA('!RZ6;I<F5N8V4@JZ`E<Z"[(&XG82!P87,@<'4@ZG1R92!E;G)E9VES
M='+I92!C87(@<V$@=&%I;&QE(&3I<&%S<V4@;&4@(@HB;6%X:6UU;2!A=71O
M<FESZ2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP
M.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN
M="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z
M,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN
M<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB3&4@<')O9W)A;6UE('5T:6QI
M<^D@<&]U<B!V:7-U86QI<V5R(&-E('1Y<&4@9&4@9&]N;NEE<R`H)7,I(&XG
M82!P87,@Z73I("(*(G1R;W5VZ2XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B3&4@8V%R86-TZ')E
M(&1E('!R;W1E8W1I;VX@9&]I="#J=')E('5N(&-A<F%C=.AR92!U;FEQ=64N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB
M"FUS9W-T<B`B3&5S(&/T=.ES(&=A=6-H92!E="!D<F]I="!S975L96UE;G0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B3&4@8_1TZ2!D<F]I="!S975L96UE;G0B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B3&4@<^EP87)A=&5U
M<B!D;VET(.IT<F4@=6X@8V%R86-TZ')E('5N:7%U92XB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),
M92!S97)V975R(*N@)7.@NR!A(.ETZ2!S=7!P<FEMZ2XB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B3&4@
M<V5R=F5U<B"KH"5SH+L@82#I=.D@96YR96=I<W1RZ2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("),82!R
M97%UZG1E(&0G96YR96=I<W1R96UE;G0@<&]U<B`E<R!A(.ETZ2!DZ7!L86/I
M92XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O
M=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("),82!L:6=N92!D96UA
M;F3I92`H)60I(&XG97AI<W1E('!A<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R
M87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("),92!F
M:6-H:65R('1E;7!O<F%I<F4@JR`E<Z"[(&XG97AI<W1E('!A<RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDY"FUS9VED(")4:&4@=&5X="!Y
M;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E
M96XN(@IM<V=S='(@(DQE('1E>'1E(&5N='+I(&YE(&-O<G)E<W!O;F0@<&%S
M(&%U('1E>'1E('-U<B!L)^EC<F%N+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(DQE(&AA=70@970@;&4@
M8F%S('-E=6QE;65N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY
M(@IM<V=S='(@(DQE(&AA=70@<V5U;&5M96YT(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@HB3&5S
M(&1O;F[I97,@=.ELZ6-H87)GZ65S('9E<G,@;&4@<V5R=F5U<B!O;G0@Z73I
M('!E<F1U97,@9&5P=6ES(&PGZ71A<&4@(@HB<'+I8^ED96YT92X@(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(DQE(&9I8VAI97(@Z6UI<R!N
M)V$@<&%S('!U(.IT<F4@96YR96=I<W1RZ2XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(DQE(&)L;V,@JZ!W96%T:&5R+F-O;:"[(&XG97-T
M('!A<R!D:7-P;VYI8FQE+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(E+I<&5R=&]I<F4@9&5S('1HZ&UE<R"K
MH"5SH+L@;F]N('1R;W5VZ2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(DEL(&XG>2!A('!A<R!D)V]P=&EO;G,@9&ES<&]N:6)L
M97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#@*
M;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R(")!=6-U;F4@<&%R=&EE(&YE('!E=70@ZG1R
M92!A9F9I8VCI92!E;B!L:6=N92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,SDX"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"B));"!Y("!A('1R;W`@9&4@8V%R86-TZ')E
M<R!D86YS(&-E(&-H86UP+B!6;W5S(&5N(&%V97H@96YT<ND@)7.@.R!I;"!E
M;B!F875T("(*(FUO:6YS(&1E("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M
M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM
M<V=S='(@(E5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V%J;W5T
M(&1E(*N@)7.@NZ`Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B(@HB56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA('-U<'!R
M97-S:6]N(&1E<R!D;VYNZ65S(&1E(&PG=71I;&ES871E=7(@(@HBJZ`E<Z"[
MH#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(E5N('!R;V)LZ&UE(&5S="!A<'!A<G4@
M;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D92"KH"5SH+N@.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(E5N('!R
M;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D92"K
MH"5SH+N@.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM
M<V=S='(@(B(*(E5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V5N
M=F]I(&1U(&9I8VAI97*@.B!A=6-U;B`E<R!N)V$@Z73I("(*(G1R86YS;6ES
M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B
M"B)5;F4@97)R975R(&5S="!S=7)V96YU92!L;W)S(&1E(&PG96YV;VD@9'4@
M9FEC:&EE<J`Z(&QE("5S(.ET86ET('!L=7,@9W)O<R`B"B)Q=64@;&4@;6%X
M:6UU;2!A=71O<FESZ2`H)60@;V-T971S*2XB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB
M56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I
M8VAI97*@.B!L92`E<R!A(.ETZ2!T<F%N<VUI<R`B"B)P87)T:65L;&5M96YT
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@<')O
M9'5I=&4@;&]R<R!D92!L)V%F9FEC:&%G92!D92!C971T92!P87)T92!D=2!M
M97-S86=E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M8V]N=&%C="!D871A+B(*;7-G<W1R("(B"B)5;F4@97)R975R(',G97-T('!R
M;V1U:71E(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<R!D92!C
M92!C;VYT86-T+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@<')O
M9'5I=&4@;&]R<R!D92!L)VEM<&]R=&%T:6]N(&1E(&-E='1E(&-A<G1E(&E#
M86QE;F1A<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L
M9"XB"FUS9W-T<B`B(@HB26P@>2!A=F%I="!U;F4@97)R975R(&1A;G,@;&4@
M9F]R;75L86ER92!D92!C;VYF:6=U<F%T:6]N+B!0975T+>IT<F4@879E>BTB
M"B)V;W5S(&QA:7-SZ2!U;B!C:&%M<"!R97%U:7,@=FED92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I
M=&4@;&]R<R!D92!L)V5XZ6-U=&EO;B!D92!C971T92!F;VYC=&EO;B!D=2!C
M87)N970@(@HB9"=A9')E<W-E+B!35E`@97-S87EE<B#@(&YO=79E874@<&QU
M<R!T87)D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@HB26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D
M92!L82!M:7-E(.`@:F]U<B!D97,@:6YF;W)M871I;VYS('-U<B!L92`B"B)C
M;VYT86-T+B`@5F5U:6QL97H@97-S87EE<B#@(&YO=79E874N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(DEL('D@82!E=2!U;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@
M9&4@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`@(@HB5F5U:6QL97H@97-S
M87EE<B!D92!N;W5V96%U+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B3&4@<'+I
M<V5N="!S97)V975R($E-05`@;F4@<W5P<&]R=&4@<&%S(&QE('!A<G1A9V4@
M9&4@9&]S<VEE<G,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`BQV$@;F4@<V5M8FQE('!A
M<R#J=')E('5N92!A<F-H:79E(%)!4B!V86QI9&4N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B
MQV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&9I8VAI97(@6DE0('9A;&ED92XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(T"FUS9VED(")4:&ES
M(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS
M9W-T<B`BQV$@;F4@<V5M8FQE('!A<R#J=')E('5N(&YU;>ER;R!D92!C87)T
M92!V86QI9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"B)#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@
M9&4@;65S<V%G97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@0VQI8VMA=&5L
M;"`B"B(H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!E;B!U=&EL:7-A;G0@;"=!
M4$D@2%144"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB
M0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('9I82!L82!P
M87-S97)E;&QE(%=)3B`H:'1T<#HO+W=I;G!L8RXB"B)C;VTI(&5N('5T:6QI
M<V%N="!L)T%022!(5%10(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"B)#92!P:6QO=&4@<&5R;65T(&PG96YV
M;VD@9&4@;65S<V%G97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@<VUS,F5M
M86EL("(*(BAH='1P.B\O<VUS,F5M86EL+F-O;2D@96X@=71I;&ES86YT(&PG
M05!)($A45%`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HB
M0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('!A<B!33510
M(.`@=')A=F5R<R!L82!P87-S97)E;&QE("(*(E9O9&%F;VYE($ET86QI92P@
M<V5U;&5M96YT(&%U>"!N=6WI<F]S(%9O9&%F;VYE+B!#96QA(&[I8V5S<VET
M92!U;B!C;VUP=&4@9&4@(@HB8V]U<G)I96P@5F]D869O;F4@271A;&EE("AH
M='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3<U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-30*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`X,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3$R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-SD@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(U,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S`R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.34*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-34@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P,@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#(V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S4*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C$X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,#4@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C,T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,CDT"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X
M,#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q,`IM<V=I9"`B5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B0V4@8VAA;7`@97-T(&]B;&EG
M871O:7)E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C(*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS
M9W-T<B`B0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S(&5N=&EE
M<G,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,PIM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BXB"FUS9W-T<B`B0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@
M9&5S(&YO;6)R97,@970@;&5S(&1E=7@M<&]I;G1S+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P.3$*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D-E(&-H86UP(&YE
M(&1O:70@8V]N=&5N:7(@<75E(&1E<R!V86QE=7)S(&]C=&%L97,N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,`IM<V=I9"`B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@
M:6YT96=E<G,B"FUS9W-T<B`B(@HB0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U
M;F4@;&ES=&4@9"=E;G1I97)S('/I<&%RZ7,@<&%R(&1E<R!V:7)G=6QE<R!O
M=2!D97,@(@HB97-P86-E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDX-@IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(*;7-G<W1R(")#92!C:&%M<"!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED("(B
M"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE
M(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM
M<V=S='(@(B(*(D-E(&-H86UP(&1O:70@8V]N=&5N:7(@=6X@8V]D92!D92!C
M;W5L975R(&%U(&9O<FUA="!21T(@:&5X863I8VEM86PL('!A<B`B"B)E>&5M
M<&QE("<C,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU
M-3@*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"XB"FUS9W-T<B`B0V4@9F]R;75L86ER92!A(&3I:N`@Z73I('1R86ETZ2XB
M"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")#)V5S="`E<RXB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L
M:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R
M;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A
M<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB0V5C:2!E<W0@=6X@;V)J970@2V]L
M86(@1W)O=7!W87)E+B!0;W5R('9O:7(@8V5T(&]B:F5T+"!V;W5S(&1E=G)E
M>B!A=F]I<B!U;B`B"B)C;&EE;G0@9&4@8V]U<G)I96P@<75I(&-O;7!R96YD
M(&QE(&9O<FUA="!+;VQA8B!'<F]U<'=A<F4N(%!O=7(@=6YE(&QI<W1E(&1E
M("(*(F-E<R!C;&EE;G1S(&1E(&-O=7)R:65L+"!V:7-I=&5Z("5S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DW"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M("(B"B)#92!M97-S86=E(&$@Z73I(.EC<FET(&1A;G,@=6X@8V]D92!D92!C
M87)A8W3H<F5S("@E<RD@875T<F4@<75E(&QE(';T=')E+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B0V4@;F]M8G)E(&1O
M:70@ZG1R92!S=7#I<FEE=7(@X"!U;BXB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A
M;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")#
M92!S97)V975R(&YE('!E=70@<&%S(&3I8V]M<')E<W-E<B!L97,@9FEC:&EE
M<G,@6DE0(&5T(&=Z:7`N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"XB"FUS9W-T<B`B0V4@<WES=.AM92!E<W0@<'+I<V5N
M=&5M96YT(&3I<V%C=&EVZ2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+B(*;7-G<W1R(")#971T92!V86QE=7(@9&]I="#J=')E('5N(&YO;6)R92XB
M"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W(@IM<V=S='(@(D-E='1E(&9E;NIT<F4@9&]I="#J=')E(&%P<&5L
MZ64@9&5P=6ES('5N92!F96[J=')E(&1E<R!O<'1I;VYS(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E1H=6YD
M97(B"FUS9W-T<B`B5&]N;F5R<F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(E1I8VME=',B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(R('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R(")(975R92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@
M5')A8VMI;F<B"FUS9W-T<B`B4W5I=FD@:&]R86ER92(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B1F]R
M;6%T(&0G:&5U<F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3(X
M"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@9&4@
M;"=H975R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM
M<V=S='(@(E1I;6]R(&]R:65N=&%L(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET<F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H
M=&]O;'1I<"DZ(@IM<V=S='(@(E1I=')E("AI;F9O8G5L;&4IH#HB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED
M(")4;R(*;7-G<W1R("+`(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&]U
M<B!SZ6QE8W1I;VYN97(@<&QU<VEE=7)S(&ET96US(.`@;&$@9F]I<RP@;6%I
M;G1E;F5Z(&5N9F]N8^D@;&4@8F]U=&]N("(*(JN@0W1R;*"[("A00RD@;W4@
MJZ!#;VUM86YD9:"[("A-86,I(&5N(&-L:7%U86YT+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@
M(D%U:F]U<F0G:'5I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(E9O:7(@;&$@<V]U<F-E($A434PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED
M(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")$96UA
M:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I
M9"`B5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI
M;G5T97,N(@IM<V=S='(@(E1R;W`@9&4@8V]N;F5X:6]N<R!I;F9R=6-T=65U
M<V5S(&1A;G,@;&5S(&1E<FYIZ')E<R!M:6YU=&5S+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B
M5&]P(@IM<V=S='(@(DAA=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM
M<V=S='(@(D-A9')E(&1U(&AA=70@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B5')A
M9'5C=&EO;G,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@
M5&]B86=O(@IM<V=S='(@(E1R:6YI=.DM970M5&]B86=O(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<X-PIM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R(")6<F%I(&]U(&9A=7@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")-82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N:7-I
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)Q
M=6EE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI
M<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<F,@*$E33RTX.#4Y+3DI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U
M<FMMZ6YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*;7-G<W1R("+.;&5S(%1U<G%U97,@970@0V'O<75E
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A
M;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E
M('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B16YT<F5Z('9O=')E(&-H;VEXH#H@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(DEN9&EC92!55J`Z("(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM
M<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T(@IM<V=S='(@(E523"!P;W5R('9O=')E(')A<'!O<G0@9&4@;&EV<F%I
M<V]N(&1U('-C<FEP="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")/=6=A;F1A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:6YE
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S
M<VEB;&4@9"=A='1E:6YD<F4@;&4@<NEP97)T;VER92!61E,N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+B(*;7-G<W1R("));7!O<W-I8FQE(&0G86IO=71E<B!D97,@:6YF;W)M871I
M;VYS(&-O;7!LZ6UE;G1A:7)E<R#@(&PG:6YS8W)I<'1I;VXN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@;6]D:69I97(@;&5S('!E
M<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9&4@;6]D:69I97(@;&5S('!E<FUI<W-I;VYS('!O
M=7(@;&4@9FEC:&EE<B!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!C:&%N9V5R
M('!O=7(@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@=NER:69I97(@
M;&$@=&%I;&QE(&1U(&9I8VAI97(@9&4@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$P,C@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!VZ7)I
M9FEE<B!L82!T86EL;&4@9'4@9FEC:&EE<B!D92"K("5S+R5S(+LN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B0V]N;F5X:6]N
M(&EM<&]S<VEB;&4@874@<V5R=F5U<B!344PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+B(*;7-G<W1R(")#;VYN97AI;VX@:6UP;W-S:6)L92!E;B!34TPB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S(@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S
M:6)L92!D92!C;W!I97(@=6X@9FEC:&EE<B!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M26UP;W-S:6)L92!D92!C<NEE<B!U;B!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8Q(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-RZ65R('5N('+I
M<&5R=&]I<F4@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!61E,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B26UP;W-S:6)L92!D92!C<NEE<B!L92!RZ7!E<G1O:7)E(%9&4R"K
MH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R
M("));7!O<W-I8FQE(&1E(&-RZ65R('5N(&9I8VAI97(@5D93('9I9&4N("(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I
M9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B3W5V97)T
M=7)E(&EM<&]S<VEB;&4@9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N("(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(X(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB
M"FUS9W-T<B`B4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92"KH"5SH+LL(&QE
M(&1O<W-I97(@;B=E<W0@<&%S('9I9&4N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B
M4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92"KH"5SH+N@.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS.34*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(E-U<'!R97-S:6]N(&EM<&]S
M<VEB;&4@9&4@)7,L(&QE(&1O<W-I97(@;B=E<W0@<&%S('9I9&4B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B4W5P<')E
M<W-I;VX@<NEC=7)S:79E(&1U(&1O<W-I97(@5D93(&EM<&]S<VEB;&4N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B4W5P<')E
M<W-I;VX@9'4@<NEP97)T;VER92!61E,@:6UP;W-S:6)L92XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));7!O<W-I8FQE(&1E
M('-U<'!R:6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")3
M=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93(*N@)7.@NRXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HR.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I8VAI
M97(@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(E-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@
M<NEP97)T;VER92!61E,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B4W5P<')E<W-I
M;VX@5D93('+I8W5R<VEV92!I;7!O<W-I8FQEH#H@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB;&4@
M9&4@9.ET97)M:6YE<B!L92!D;W-S:65R(&-O=7)A;G0N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B26UP;W-S
M:6)L92!D)V5X=')A:7)E(&QE<R!DZ71A:6QS(&1U(&-E<G1I9FEC870B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B26UP;W-S:6)L92!D92!C:&%R9V5R(&QA(&3I9FEN:71I;VX@9&4@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R
M("));7!O<W-I8FQE(&1E(&3I<&QA8V5R(&QE(&9I8VAI97(@5D93+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HQ,#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV
M-3(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9"=O=79R:7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X-"!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("));7!O<W-I8FQE(&0G;W5V
M<FER('5N(&9I8VAI97(@5D93(&5N(.EC<FET=7)E+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("));7!O
M<W-I8FQE(&0G;W5V<FER('5N(&9I8VAI97(@5D93+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T
M;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3W5V97)T=7)E
M(&EM<&]S<VEB;&4@9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S
M:6)L92!D92!L:7)E(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!F:6QE<VEZ
M92@I*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#@W"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I
M+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE<B!61E,@
M*.EC:&5C(&1E(&=E=$9I;&53:7IE*"DI+B(*"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B
M56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@
M;&ER92!L92!F:6-H:65RH#H@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN(@IM<V=S='(@(DQE8W1U<F4@9'4@<NEP97)T;VER92!R86-I
M;F4@5D93(&EM<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<R(*;7-G<W1R("));7!O<W-I8FQE(&1E(')E;F]M;65R("5S(&5N("5SH#H@
M;&4@9&]S<VEE<B!C:6)L92!E>&ES=&4@9.EJX"(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!R96YO
M;6UE<B!L92!RZ7!E<G1O:7)E(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));7!O<W-I8FQE
M(&1E(')E;F]M;65R(&QE('+I<&5R=&]I<F4@5D93H#H@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@
M<F5N;VUM97(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<F5N
M;VUM97(@;&4@9FEC:&EE<B!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS,C8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!R96YO;6UE<B!L
M92!F:6-H:65R(%9&4RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+B(*;7-G<W1R("));7!O<W-I8FQE(&0G97CI8W5T97(@)VUK
M:7-O9G,G+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@=')A9'5I<F4@8V4@
M9&]C=6UE;G0@5V]R9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C$U-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("));7!O<W-I8FQE(&0GZ6-R:7)E(&QE(&9I8VAI97(@5D93(*N@
M)7.@NRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M(@IM<V=S='(@(DEM<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O;F[I97,@9'4@
M9FEC:&EE<B!61E,@*&-O<'DH*2!I;7!O<W-I8FQE*2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B26UP;W-S:6)L92!D)^EC<FER92!L97,@9&]N;NEE<R!D=2!F
M:6-H:65R(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@
M97AC965D960N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"?I8W)I<F4@;&4@9FEC
M:&EE<B!61E,L(&QE('%U;W1A('-E<F%I="!DZ7!A<W/I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N
M9&5R;&EN92(*;7-G<W1R(")3;W5L:6=N97(B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B06YN
M=6QE<B!L97,@8VAA;F=E;65N=',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R(")!;FYU;&4@=F]T<F4@9&5R;FGH<F4@86-T:6]N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B4NEP;VYS92!I;F%T=&5N9'5E(&1U('-E<G9E
M=7(@;&]R<R!D92!L82!C;VYN97AI;VZ@.B`B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W-@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")2Z7!O;G-E(&EN871T96YD
M=64@9'4@<V5R=F5U<B#@H#H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T
M<B`B2&]R<R!C873I9V]R:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%54
M1BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E
M<R(*;7-G<W1R("+);6ER871S($%R86)E<R!5;FES(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")2;WEA=6UE+55N:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B
MR71A=',M56YI<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("+.;&5S(&5X=.ER
M:65U<F5S(&1E<R#)=&%T<RU5;FES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N
M:71S(@IM<V=S='(@(E5N:73I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM
M<V=I9"`B56YK;F]W;B(*;7-G<W1R("));F-O;FYU(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(F%P
M:6US9VED(&EN8V]N;G4@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@
M(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T
M<B`B8VQI;7-G:60@:6YC;VYN=2`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO
M=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D5M<&QA8V5M96YT('/I
M;&5C=&EO;F[I(&EN8V]N;G4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N
M86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<B!O
M=2!M;W0@9&4@<&%S<V4@:6YC;VYN=2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN
M:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(D3I;&EE<B!L)^ELZ6UE
M;G0@8V]U<F%N="(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP
M:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-A;G,@;F]M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I
M9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B),
M97,@<V-R:7!T<R!N;VXM<')I=FELZ6=IZ7,@;F4@<&5U=F5N="!A8V/I9&5R
M(&%U>"!F;VYC=&EO;G,@8V]U<&5R+V-O<&EE<B\B"B)C;VQL97(@<&]U<B!D
M97,@<F%I<V]N<R!D92!SZ6-U<FETZ2X@07!P=7EE>B!S=7(@3TL@<&]U<B!V
M;VER('5N92!N;W1E("(*(G1E8VAN:7%U92!S=7(@;6]Z:6QL82YO<F<@<75I
M('9O=7,@97AP;&EQ=65R82!C;VUM96YT(&%U=&]R:7-E<B!U;B!S8W)I<'0@
MX"`B"B)U=&EL:7-E<B!L92!P<F5S<V4M<&%P:65R<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@
M(E5N<V5T(&-O;&]R(@IM<V=S='(@(E)E;65T=')E(&QA(&-O=6QE=7(@X"!Z
MZ7)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R
M=&5D($5X=&5N<VEO;B(*;7-G<W1R(")%>'1E;G-I;VX@;F]N('!R:7-E(&5N
M(&-O;7!T92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A
M=&4B"FUS9W-T<B`B36]D:69I97(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E
M<R(*;7-G<W1R(")-;V1I9FEE<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@
M(DUO9&EF:65R(&PG=71I;&ES871E=7(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B36ES92#@(&IO=7(@9&4@JZ`E<Z"[+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP
M="!D96QE=&5D+B(*;7-G<W1R("),92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@
M97-T('-U<'!R:6WI(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED
M(")5<&QO860B"FUS9W-T<B`B0VAA<F=E<B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"B)4;W5S(&QE
M<R!F:6-H:65R<R!D92!C;VYF:6=U<F%T:6]N(&1E<R!A<'!L:6-A=&EO;G,@
M;VYT(.ETZ2!E;G9O>>ES('-U<B!L92`B"B)S97)V975R+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*
M;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&5T=')E<R!L
M871I;F5S(&UA:G5S8W5L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA
M;B!N=6UB97)S(@IM<V=S='(@(DYO;6)R97,@<F]M86EN<R!M86IU<V-U;&5S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G
M=6%Y(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(D5M<&QO>>D@86-T=65L;&5M96YTH#H@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I
M9"`B57-E(%-33"(*;7-G<W1R(")5=&EL:7-E<B!34TPB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R
M9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B)5
M=&EL:7-E<B!S:2!L92!N;VT@9"=U=&EL:7-A=&5U<B]M;W0@9&4@<&%S<V4@
M97-T(&1I9F;I<F5N="!D=2!S97)V975R($E-4U`N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R
M(")5=&EL:7-A=&5U<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("),)W5T:6QI<V%T975R
M("5S(&XG82!P87,@;"=A=71O<FES871I;VX@<&]U<B`E<RXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B061M:6YI<W1R871I;VX@9&5S('5T:6QI<V%T975R<R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P
M=&EO;G,B"FUS9W-T<B`B4'+I9NER96YC97,@<&5R<V]N;F5L;&5S(@H*(SH@
M<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T
M<B`B16YR96=I<W1R96UE;G0@9&5S('5T:6QI<V%T975R<R(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(DPG96YR96=I<W1R96UE
M;G0@9"=U=&EL:7-A=&5U<B!E<W0@9.ES86-T:7;I('-U<B!C92!S>7-TZ&UE
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@
M86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B0V]M<'1E('5T:6QI<V%T975R
M(&YO;B!T<F]U=NDB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("),
M92!N;VT@9&4@8V]N;F5X:6]N(*N@)7.@NR!E>&ES=&4@9.EJX"XB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE
M.B(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<J`Z(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R
M(").;VT@9"=U=&EL:7-A=&5U<J`Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM
M<V=S='(@(E5T:6QI<V%T975R<R!DZ69I;FESH#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(D]U>F+I:VES=&%N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<P(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B4NEP97)T;VER92!61E,@:6YE>&ES=&%N="XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A
M=&EO;B(*;7-G<W1R(")!8G-E;F-E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@V,PIM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z("(*;7-G<W1R("),97,@96UP;&%C96UE;G1S('9A;&ED97,@=')O=7;I
M<R!I;F-L=65N=*`Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")686QI9&ETZ2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS
M9W-T<B`B5F%L975R(&5N(&UI;G5T97,@X"!P87)T:7(@9&4@;6%I;G1E;F%N
M="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-3,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M5F%L975R('-U<.ER:65U<F4@X"!L82!L;VYG=65U<B!M87AI;6%L92!D92`E
M<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Q,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A
M;'5E<R(*;7-G<W1R(")686QE=7)S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$P-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@S"FUS9VED
M(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L975R<R#@('/I
M;&5C=&EO;FYE<B!D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B
M"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A<FEA8FQE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E;I;NEZ
M=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`BR6-H96,@9&4@
M;&$@=NER:69I8V%T:6]N("9M9&%S:#L@8V4@;65S<V%G92!A('!E=70MZG1R
M92#I=.D@9F%L<VEF:>DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEO;B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I
M;VX@0V]N=')O;"(*;7-G<W1R(")#;VYT<O1L92!D92!V97)S:6]N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B06QI9VYE;65N="!V
M97)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B4F5M
M<&QI<W-A9V4@=F5R=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B
M5F5R=&EC86R@.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<R"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B5'+H<R!H875T
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I
M971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE
M=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:>IT+6YA;6EE;B`H5DE30TE)
M*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9O:7(@)7,B
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E9O:7(@=6YE('!A9V4@=V5B(&5X
M=&5R;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")6
M;VER(&-O;6UE("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES
M;&%N9',L($)R:71I<V@B"FUS9W-T<B`BSFQE<R!6:65R9V5S(&)R:71A;FYI
M<75E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5
M+E,N(@IM<V=S='(@(LYL97,@5FEE<F=E<R!D97,@R71A=',M56YI<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM
M<V=S='(@(E9I<VEB:6QI=.DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I
M;&ETZ:`Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B3D]424-%(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM
M<V=S='(@(D%45$5.5$E/3B$A(2`@4U504%))3452($Q%(%-#4DE05"!-04Y5
M14Q,14U%3E0@1$4@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)
M3B!V:6$@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@
M1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!E="!&=71U;F$B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B
M"FUS9W-T<B`B071T96YT:6]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B364B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H
M97(@1F]R96-A<W0B"FUS9W-T<B`B4'+I=FES:6]N<R!MZ73I;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")$;VYNZ65S(&WI=.EO(&9O=7)N
M:65S('!A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@X.0IM<V=I
M9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3
M:71E(@IM<V=S='(@(E-I=&4@=V5B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@
M(D-H87%U92!S96UA:6YE(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0FEE;G9E;G5E(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@
M)7,B"FUS9W-T<B`B0FEE;G9E;G5E(.`@)7,B"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0FEE
M;G9E;G5E+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")/8V-I9&5N=&%L("A)
M4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V-C:61E;G1A;"`H
M25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H
M87)A(@IM<V=S='(@(E-A:&%R82!/8V-I9&5N=&%L(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G
M<W1R(")1=65L;&4@87!P;&EC871I;VX@)7,@9&]I="UI;"!P<NES96YT97(@
M87!RZ',@;&$@8V]N;F5X:6]NH#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\B"FUS9W-T<B`B475E;"!E<W0@;&4@8V%R86-TZ')E(&1E('/I<&%R
M871I;VZ@/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS
M9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E%U
M96P@97-T(&QE(&-A<F%C=.AR92!D92!C:71A=&EO;J`_(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H
M97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")#87)T92!7:&5R96ES($%U
M<W1R86QI92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI
M8V@@<&AA<V5S(@IM<V=S='(@(E%U96QL97,@<&AA<V5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")1=65L
M;&5S(&5X=&5N<VEO;G,@86-T:79E<B!P;W5R(&PGZ61I=&5U<B!2:6-H(%1E
M>'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B3&%R9V5U<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#0*;7-G:60@(E=I9'1H(&EN
M($-34R!U;FET<R(*;7-G<W1R("),87)G975R(&5N('5N:73I<R!#4U,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"B),87)G975R(&1U
M(&UE;G4@9&4@9V%U8VAE("5S("`H;&$@8V]N9FEG=7)A=&EO;B!P<F5N9')A
M(&5F9F5T(.`@;&$@<')O8VAA:6YE("(*(F-O;FYE>&EO;BF@.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED
M(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B3&%R9V5U<B!D=2!T86)L
M96%U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B56YI=.D@9&4@;&%R
M9V5U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B3&%R9V5U<J`Z(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G
M<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B5VEN9"(*;7-G<W1R(")696YT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T
M<B`B5F5N="!T]'0@;&4@;6%T:6XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E9I=&5S
M<V4@9'4@=F5N="!E;B!N)F]E;&EG.W5D<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R(")696YTH#HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B
M"FUS9W-T<B`B5F5N=*`Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E-A9V5S<V4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R
M("),:7-T92!D92!V)F]E;&EG.W5X(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(E1R879A:6PB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O
M<FL@061D<F5S<R(*;7-G<W1R(")!9')E<W-E('!R;V9E<W-I;VYN96QL92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*
M;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE('!R;V9E<W-I
M;VYN96PB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").;VUB<F4@9&4@8VAA;7!S(&EN
M8V]R<F5C="#@(&QA(&QI9VYE("5D+B`E9"!A='1E;F1U<RP@)60@=')O=7;I
M<RXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").;VUB<F4@9&4@8VAA;7!S(&EN
M8V]R<F5C="X@)60@871T96YD=7,L("5D('1R;W5VZ7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM
M<V=S='(@(D3I8V%L86=E("5D(&EN8V]R<F5C="!L;W)S(&1E(&QA(&QE8W1U
M<F4@9&4@9FEC:&EE<B!61E,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(D-O;G1R86EN=&5S(&)A<VEQ
M=65S(%@U,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S
M='(@(E5T:6QI<V%T:6]N(&1E(&-LZ2#I=&5N9'5E(%@U,#EV,R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(D%U=')E(&YO
M;2!D=2!S=6IE="!8-3`Y=C,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(B"FUS9W-T<B`B261E;G1I9FEA;G0@9&4@8VSI(&1U('-U:F5T(%@U
M,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S
M"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")%>'1E;G-I;VYS
M(%@U,#EV,R(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*
M;7-G<W1R(")!02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U-@IM<V=I9"`B65E962(*;7-G<W1R(")!04%!(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@
M(EEA:&]O(2!M87`B"FUS9W-T<B`B0V%R=&4@JZ!986AO;Z`AH+LB"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B06YN=65L;&5M96YT(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B665M96XB"FUS9W-T<B`B6>EM96XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B"FUS
M9W-T<B`B3W5I(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")/=6DL
M(&HG86-C97!T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*
M;7-G<W1R("(B"B)6;W5S(.IT97,@96X@;6]D92"KH%1E>'1EH+LN(%5T:6QI
M<V5Z(&QE(&)O=71O;B!;/#Y=('!O=7(@<F5V96YI<B!A=2!M;V1E("(*(JN@
M5UE325=91Z"[+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM
M<V=S='(@(E9O=7,@;B?J=&5S('!A<R!A=71O<FESZ2#@(&-RZ65R('!L=7,@
M9&4@)60@8FQO8W,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-#(T"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R
M(")6;W5S(&XGZG1E<R!P87,@875T:&5N=&EF:>DN(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@
M:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM
M<V=S='(@(E9O=7,@;F4@<&]U=F5Z('!A<R!A=F]I<B!L92!C87)A8W3H<F4@
MJUQ<NR!D86YS('9O=')E(&YO;2!C;VUP;&5T+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW
M,@IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R(")6;W5S(&XG879E>B!P87,@<V%I<VD@=6YE(&%D<F5S
M<V4@Z6QE8W1R;VYI<75E('9A;&ED92XB"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB
M5F]U<R!N)V%V97H@<&%S(&%S<V]C:>D@;&5S(&-H86UP<R!D=2!F:6-H:65R
M(&EM<&]R=.D@875X(&-H86UP<R`B"B)C;W)R97-P;VYD86YT<R!D86YS("5S
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")6;W5S(&%V97H@Z73I
M(&3I8V]N;F5C=.DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U
M.`IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B
M"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S
M='(@(B(*(E9O=7,@9&5V97H@:6YS8W)I<F4@=6X@;G5MZ7)O(&1E(&-E;&QU
M;&%I<F4@=F%L:61E+"!S975L<R!D97,@;F]M8G)E<R!E="!U;B`B"B*KH"N@
MNR!O<'1I;VYN96P@<&]U<B!L97,@87!P96QS(&EN=&5R;F%T:6]N875X+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#4*;7-G:60@(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E9O=7,@;B=A
M=F5Z('!A<R!S86ES:2!U;F4@96YT<NEE('9A;&ED92XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM
M<V=S='(@(B(*(E9O=7,@9&5V97H@8V]N9FEG=7)E<B!U;B!B86-K96YD($1A
M=&%4<F5E('!O=7(@=71I;&ES97(@;&5S(&EN<V-R:7!T:6]N<R(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B5F]U<R!D979E>B!C
M;VYF:6=U<F5R('5N(&UO9'5L92!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+B(*;7-G<W1R("(B"B)6;W5S(&1E=F5Z(&3I8W)I<F4@;&4@<')O8FSH
M;64@879A;G0@9&4@;F]U<R!F86ER92!P87)V96YI<B!L92!R87!P;W)T+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*
M;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;R(*;7-G<W1R(")6;W5S(&1E=F5Z(&5N=')E<B!U;F4@55),
M(&_Y('!O:6YT92!D92!L:65N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N(@IM<V=S='(@(DEL(&9A=70@<^EL96-T:6]N;F5R('5N
M('-E<G9E=7(@X"!S=7!P<FEM97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@
M;W5T+B(*;7-G<W1R(")6;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U=&EL:7-A
M=&5U<B#@(')E=&ER97(N("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS
M9W-T<B`B5F]U<R!D979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!R
M971I<F5R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")6;W5S(&1E=F5Z('-PZ6-I
M9FEE<B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N(@IM<V=S='(@(E9O=7,@9&5V97H@<W#I8VEF:65R(&QE
M(&YO;2!D92!L)W5T:6QI<V%T975R(.`@;6]D:69I97(N(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@
M(E9O=7,@9&5V97H@:6YD:7%U97(@<75E;&QE(&%C=&EO;B!A8V-O;7!L:7(N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M
M92XB"FUS9W-T<B`B5F]U<R!D979E>B#I8W)I<F4@=6X@;F]M('!O=7(@;&$@
M;F]U=F5L;&4@8V%TZ6=O<FEE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T
M;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(E9O
M=7,@9&5V97H@9F]U<FYI<B!U;B!NL"!D92!TZ6SI<&AO;F4@:71A;&EE;B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B5F]T<F4@<V5S<VEO;B`E<R!A(&5X<&ER
MZ2X@5F5U:6QL97H@=F]U<R!R96-O;FYE8W1E<BXB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(E9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96PB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D
M9')E<W,Z(@IM<V=S='(@(E9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96P@JR!$
M93H@NZ`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E9O<R!D;VYNZ65S('!E<G-O;FYE;&QE<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(E9O=')E(&%D<F5S<V4@26YT97)N970@82!C:&%N9^D@9&5P=6ES
M(&PG;W5V97)T=7)E(&1E('9O=')E('-E<W-I;VX@)7,N("`B"B)0;W5R('9O
M=')E('/I8W5R:73I+"!V;W5S(&1E=F5Z('9O=7,@<F5C;VYN96-T97(N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO
M=7(@3F%M92(*;7-G<W1R(")6;W1R92!N;VTB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB5F]T<F4@;6]D=6QE(&0G
M875T:&5N=&EF:6-A=&EO;B!N92!S=7!P;W)T92!P87,@;"=A:F]U="!D)W5T
M:6QI<V%T975R<RP@4VD@(@HB=F]U<R!S;W5H86ET97H@=71I;&ES97H@2&]R
M9&4@<&]U<B!A9&UI;FES=')E<B!L97,@8V]M<'1E<R!U=&EL:7-A=&5U<G,L
M("(*(G9O=7,@9&5V97H@=71I;&ES97(@=6X@875T<F4@;6]D=6QE(&0G875T
M:&5N=&EF:6-A=&EO;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BXB"FUS9W-T<B`B(@HB5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO
M;B!N)V5S="!P87,@96X@;65S=7)E(&0GZ71A8FQI<B!U;F4@;&ES=&4@9&5S
M("(*(G5T:6QI<V%T975R<RP@;W4@8V5T=&4@9F]N8W1I;VX@82#I=.D@<F5T
M:7+I92!P;W5R('5N92!A=71R92!R86ES;VXN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB
M5F]T<F4@;F%V:6=A=&5U<B!S96UB;&4@879O:7(@8VAA;F?I(&1E<'5I<R!L
M92!DZ6)U="!D92!V;W1R92!S97-S:6]N("5S+B`@(@HB4&]U<B!V;W1R92!S
MZ6-U<FETZ2P@=F]U<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E9O=')E(&YA
M=FEG871E=7(@;F4@<W5P<&]R=&4@<&%S(&-E='1E(&]P=&EO;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@
M4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T
M<B`B(@HB5F]T<F4@;F%V:6=A=&5U<B!N92!P<F5N9"!P87,@96X@8V]M<'1E
M(&-E='1E(&]P=&EO;B!D)VEM<')E<W-I;VXN(%!R97-S97H@(@HB0V]N='+T
M;&4O0V]M;6%N9&4@*R!0('!O=7(@:6UP<FEM97(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE
M.B(*;7-G<W1R(")6;W1R92!F=7-E874@:&]R86ER92!A8W1U96R@.B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")6;W1R92!P<F]F
M:6P@<&%R(&3I9F%U="!A(.ETZ2!M;V1I9FGI+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB
M"FUS9W-T<B`B4')O9FEL('!A<B!DZ69A=72@.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R
M(")6;W1R92!N;VT@8V]M<&QE=*`Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G
M<W1R(")6;W1R92!C;VUP=&4@82!E>'!I<NDN(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")6;W1R92!N;W5V
M96%U(&UO="!D92!P87-S92!P;W5R("5S(&5S=*`Z)7,B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+B(*;7-G<W1R(")6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S(.`@
M:F]U<B!P;W5R(&QA(&1U<NEE(&1E(&-E='1E('-E<W-I;VXN(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B5F]S(&]P=&EO;G,@
M;VYT(.ETZ2!M:7-E<R#@(&IO=7(N(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970B"FUS9W-T<B`B5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES(.`@
M>NER;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED
M("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R
M(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB
M"FUS9W-T<B`B(@HB5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES(.`@
M>NER;RP@=NER:69I97(@=F]T<F4@8V]U<G)I97(@970@8V]N;F5C=&5Z+2(*
M(G9O=7,@879E>B!V;W1R92!N;W5V96%U(&UO="!D92!P87-S92XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E9O=')E(&UO="!D92!P87-S92!A
M(&5X<&ERZ2XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*
M;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9O<R!S97)V
M975R<R!D:7-T86YT<Z`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M675G;W-L879I82(*;7-G<W1R(")9;W5G;W-L879I92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@
M(EIA[W)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@
M(EIA;6)I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S
M='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS
M9VED(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(
M:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");0V%C:&5R(&QE<R!C:71A=&EO
M;G-=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B
M;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U)A<'!O<G0@9&4@<')O8FSH;65=(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6T%F9FEC:&5R(&QE
M('1E>'1E(&-I=.D@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6T%F
M9FEC:&5R(&QE('1E>'1E(&-I=.D@+2`E<R!L:6=N97-=(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6=N92`E<R!D92`E<UTB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-30@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(E]!9&UI;FES=')A=&EO;B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I
M9"`B7T-,22(*;7-G<W1R("),:6=N92!D92!?8V]M;6%N9&4B"@HC.B!L:6(O
M87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R
M964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E-U<'!R
M:6UE<B!L82!?<F%N9^EE(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?
M1W)O=7!S(@IM<V=S='(@(E]'<F]U<&5S(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7T%I
M9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(E!R;W!R7VGI=.ES(&1E(&PG:6UA9V4N+BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S
M='(@(E]#;VYN97AI;VXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?1.EC;VYN97AI
M;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?
M36]D:69I97(@=6X@;&EE;B!W96(N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?
M3W!T:6]N<R(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I
M;VYS(@IM<V=S='(@(E]097)M:7-S:6]N<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(E]2971I<F5R('5N(&QI96XB"@HC.B!L
M:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?0V]N9FEG
M=7)A=&EO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B4')O<')IZ73I<R!D=2!?=&%B;&5A=2(*"B,Z(&QI8B]A<&DN
M<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]5=&EL:7-A=&5U<G,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D
M<F5S<R!B;V]K(@IM<V=S='(@(F-A<FYE="!D)V%D<F5S<V5S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E
M<W-E92!U;FMN;W=N(@IM<V=S='(@(F1E<W1I;F%T86ER92!I;F-O;FYU(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(F%G96YD82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G
M:60@(F-A;&TB"FUS9W-T<B`B8V%L;64B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL92(*;7-G<W1R(")I;7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I8VAI
M97(@9&4@<V]R=&EE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(FEM
M<&]S<VEB;&4@9"=O=79R:7(@;"=E;G1RZ64B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HU.3@*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`B8VQI<75E>B!I8VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(F5R<F5U<B!D)W5T:6QI<V%T:6]N(&1E(&QA(&QI9VYE(&1E
M(&-O;6UA;F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B97)R
M975R(&1E(&-O;F9I9W5R871I;VXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R(")A8G-E;F-E(&-R:71I<75E(&0G=6X@9FEC:&EE
M<B!S>7-TZ&UE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(F5R<F5U
M<B!D92!F;W)M870@9&4@9&]N;NEE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E
M9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R(")M;V1I9FEE<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E
M;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B96YT<NEE(&YO;B!T<F]U=NDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I
M9"`B9F%L;&EN9R(*;7-G<W1R(")T;VUB86YT(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@(F9I
M8VAI97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S
M='(@(F1E<'5I<R!L92`E<R`H)7,I(.`@)7,@)7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@
M(F5N(')A9F%L92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(FB@.B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH
M(@IM<V=S='(@(FAH(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(FYO
M;2!D)VCT=&4@:6YC;VYN=2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM
M<V=S='(@(FEM;>ED:6%T96UE;G0B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM
M<V=S='(@(FEN8V]R<&]RZ64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S
M='(@(F5R<F5U<B!D)V5N='+I92]S;W)T:64B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A
M<F4@97)R;W(B"FUS9W-T<B`B97)R975R(&QO9VEC:65L;&4@:6YT97)N92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B;&EG;F5S72(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K
M:6YG($E33RXB"FUS9W-T<B`B97)R975R(&UK:7-O9G,@8V]D92`E9"!E;B!C
M<NEA;G0@;"=)4T\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N;VTB"@HC.B!F<F%M97=O<FLO
M4E!#+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T
M<B`B;F]N('!R:7,@96X@8V]M<'1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(G!A<R!E;F-O<F4@<')I<R!E;B!C;VUP=&4B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A9"(*;7-G
M<W1R(")B;&]C+6YO=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R
M(")P;W5R8V5N=&%G92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")P
M97)M:7-S:6]N(')E9G5SZ64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T
M<B`B<&EX96QS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M(")E<G)E=7(@9&ES=&%N=&4@9&%N<R!L92!P<F]T;V-O;&4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES
M:6YG(@IM<V=S='(@(G,GZ6QE=F%N="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE
M(@IM<V=S='(@(G-E<G9I8V4@;F]N(&1I<W!O;FEB;&4N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B;6]N=')E<B!L97,@9&EF9NER96YC97,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B
M<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%14
M4"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#<*;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G-T96%D>2(*;7-G<W1R
M(")F:7AE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")E<G)E=7(@<WES=.AM
M92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"FUS9VED(")T
M87-K(&QI<W0B"FUS9W-T<B`B;&ES=&4@9&4@=.)C:&5S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R
M>2!F86EL=7)E(@IM<V=S='(@(NEC:&5C('1E;7!O<F%I<F4B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C<P"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M
M(@IM<V=S='(@(F5N=')E>B!L92!M;W0@9&4@<&%S<V4@9&5U>"!F;VES('!O
M=7(@8V]N9FER;65R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B
M=6YI9FGI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM
M<V=I9"`B=6YN86UE9"(*;7-G<W1R(")S86YS(&YO;2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I
M9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B4^EL96-T:6]N(&0G=71I;&ES871E
M=7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS
M9W-T<B`B;*`Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]A<E]362YP
M;P``````````````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-C$V,34W`#$P-3$U-#,Q,#8S`#`Q-C0R,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C($A/4D1%($%R86)I8R!T<F%N
M<VQA=&EO;@HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($-O<'ER:6=H
M="`H0RD@,C`P,R!0;&%T:6YU;2!);F,N(#QP;$!T:6YU;2YI;F9O/@HC($-U
M<W1O;2!796(@07!P;&EC871I;VYS(#QH='1P.B\O<&QA=&EN=6TM<WDN8V]M
M/@HC(%!L871I;G5M($1E=F5L;W!M96YT(%1E86T@/&1E=G1E86U`<&QA=&EN
M=6TM<WDN;F5T/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!(3U)$12!V,BXP+C!<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`S+3`T+3,P(#$R.C`P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@4&QA
M=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\9&5V=&5A;4!P;&%T:6YU;2US>2YN
M970^7&XB"B),86YG=6%G92U496%M.B!!<F%B:6,@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]H=&UL.R!C:&%R<V5T/4-0,3(U-EQN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS
M9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R
M964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-
M0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M+2!.;W1I8V4B"FUS9W-T<B`BRN3([>4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&
M:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;B(*;7-G<W1R("+*Y-WMT"#:X^'MQ\H@Q^'5[<?DR2(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U
M,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R
M871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N(@IM<V=S='(@(M;:(-KAQ^/)(-WM(./1R-H@Q^':X^'MR2`HQ^':X^'M
MQ\HI(,?ARNT@RM'MSR#*Y-WMT.7'(,W'X<?P+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS
M9W-T<B`BW^$@-2#/WNW>R2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HQ,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`BV^W1(./FS.;/(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B6\?AT]C1("5S(./D
M("5S72(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G
M<W1R("+/W<K1(-KDQ^;MY"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(L/,Y,_)(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE
M<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"
M97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P
M<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED
M("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*
M;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*
M;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(;W5R
M($9O<FUA="(*;7-G<W1R("+([<?DQ\K?.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"#3Q]K)
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38P"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9"(*;7-G<W1R("(\8CX@S=7A(,[8PSH@(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS
M9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G
M:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`BY.7'T<?P+^'MX<?P(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI
M<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O
M='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("+([<?DQ\K?.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!0
M87-S=V]R9"(*;7-G<W1R("+?X>/)(,?AX]'FT2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C
M;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,S,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T
M<B`BRN3=[=`Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!
M9&0B"FUS9W-T<B`BQ^':Y.;'Y"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S
M='(@(L?AVN3FQ^0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G
M<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES
M<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(L/6W2#+Y,?&[2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS
M9W-T<B`BS]W*T2#:Y,?F[>0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B
MP];=(,ODQ\;M(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B
M"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM
M<V=I9"`B061D<F5S<R(*;7-G<W1R("+'X=KDYL?D(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S
M='(@(L_=RM$@VN3'YNWD(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES
M<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN
M9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS
M9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS9W-T
M<B`BQ^':Y.;'Y"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED
M(")!;&EA<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O
M=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@
M9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(MKDYL?D(,C1[<_?(,?AQ>'?RM'FY.TZ(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("+*XR#*S<_MSR#>[>/)(-OM
MT2#CWLCFX<DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W
M"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+B(*;7-G<W1R("+-U>$@SMC#.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R
M<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N
M;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*(RP@9G5Z>GD*;7-G:60@(D%P<&QI
M8V%T:6]N(@IM<V=S='(@(L?ARMC([=['RB#'X>/FS.;/R3H@)7,B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`BQ^'*V,CMWL?*(,?AX^;,YL_).B`E<R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T
M:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@
M4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ
M,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU3
M0TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R
M=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R
M("+*P]_MSR#'X=CAR"#>R.$@Q^'(S\$@R-KCX>W'RB#'X=7MQ^3)OR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE
M;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T
M"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*
M;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T
M"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@
M57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R
M861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`BRN,@T=W6(,?ARLW>WB#CY"#'
MX>7F[<D@X^0@WLCA(,?AX\[/XR#1Q\_MYM,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-3$*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+-U>$@SMC#(,[A
MQ^$@Q^'%RM7'X2#(X\[/XR#'X=P@1E10+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BS=7A(,[8PR#.
MX<?A(,?AQ<K5Q^$@R./.S^,@Q^'<($944"XB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G
M<W1R("+'X<W>YN$@Q^'CRN;=T<DZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE
M<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED
M(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("+?
MX>/)(./1YM$@V\C1(./>R.;AR2`HW^W1R.W1YM,I(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S
M97)N86UE+B(*;7-G<W1R("+'T^,@Q^'CT\K.S^,@V\C1(./>R.;A("C?[='(
M[='FTRDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("+MYN,@Q^'C[>''SR(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L
M:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+AXR#MVLO1(-KA
M["#'X>/3RN/:("5S+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`BY>;1S^TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS
M9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"B,L(&9U
M>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(N7FT<_M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U
M>GIY"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`BQ^'(T>W/(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-#0*(RP@9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#
M5E,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U
M"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`BP\SDS\DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V
M"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#
M86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI
M;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*
M;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C($Q$05`N(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*;7-G<W1R("+#S.3/
MR2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#
M86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BQ>';Q\$@Q^'(X<?;(-KD
M(./4W^')(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("+%Y-3'P2#'X>/,X<\@)7,B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED
M(")#87!T:6]N(@IM<V=S='(@(L[MQ]''RB(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@
M(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R("+'X>7'RMT@Q^',YL?A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(L?AY<?*W2#'X<SF
MQ^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS
M9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@
M<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(L?A
MY<?*W2#'X<SFQ^$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R
M86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*
M;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I
M8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z
M>GD*;7-G:60@(D-H860B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDV"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BRM''S-H@
MVN0@Q^'*V^WMT<?*(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*
M(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H
M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I
M9"`B0VAA<B(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B0VAI;&4B"FUS9W-T<B`BQ^'AWL@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM
M<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@
M(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R("+AXR#MVLO1(-KA["#'X>/3RN/:("5S+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED
M(")#;&5A<B(*;7-G<W1R("+#S.3/R2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E
M('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM
M<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I
M9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T
M<B`BQ=OAQ]X@Q^'DQ]W0R2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T
M"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA
M<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D
M(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O
M0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O
M;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S
M"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC
M<R(*;7-G<W1R("+1T^;CQ\HB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*
M(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BQ^'#YL?CT3HB"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D-O;6UA
M;F0@4VAE;&PB"FUS9W-T<B`BQ^'#YL?CT3HB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D-O;6UE;G0B
M"FUS9W-T<B`BQ^'#YL?CT3HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B
MT=/FX\?*(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+'X=31W\DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"B,L
M(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`BRN3=[=`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S
M>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@
M(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O;F9I<FT@
M4&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@
M9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+-U>$@
MSMC#(,[AQ^$@Q^'%RM7'X2#(X\[/XR#'X=P@1E10+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?A
MQ<K5Q^$@R./.S^,@Q^'<($944"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BS=7A(,[8
MPR#.X<?A(,?AQ<K5Q^$@R./.S^,@Q^'<($944"XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX-#4*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<7*
MU<?A(,CCSL_C(,?AW"!&5%`N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S
M7"(B"FUS9W-T<B`BX\W*YNW'RB`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S
M"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L
M(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(L?AU-'?R2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`BQ^'-WN;A(,?AX]/*
MYM'/R3H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B
M0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT
M-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@
M)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!,1$%0+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M(&QD87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(N''(,7CW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%
MRM7'X2#(Q^'CSL_C(%--0BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+AQ\7CW\?D[<D@X<7DU,?!
M(./,X<\@X\WA[2`H;&]C86PI(./D(,/,X2#CX=T@Q^'AV\D@)7,Z(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0HC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(N''
M(,7CW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(N''(,7CW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I
M8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(N''(,7C
MW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N
M(@IM<V=S='(@(N''(,7CW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<R(*;7-G<W1R("+AQ\7CW\?D[<D@X=W*S2!-86EN=&5N86YC
M95]487-K(.'AR-'MX\P@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(N''(,7CW\?D[<D@X>33SB`E<R#%X>P@
M)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(N''Q>/?
MQ^3MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(N''(,7CW\?D[<D@X>33
MSB`E<R#%X>P@)7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX
M-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(N''Q>/?Q^3MR2#AQ>34
MQ\$@X\SASR#CS>'M("AL;V-A;"D@X^0@P\SA(./AW2#'X>';R2`E<SHB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BX>,@[<KC(,7:S\?/(.7FT<_M(,C4
MW^$@U<WMS2(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BX>,@[=K+T2#:X>P@)W!O<G0G(-WM(,7:S\?/Q\H@5D93+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@
MR,?AX\[/XR!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.
M("5S(,7A["`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`BX<?%X]_'Y.W)(.'%Y-3'P2#CS.'/(./-X>T@
M*&QO8V%L*2#CY"##S.$@X^'=(,?AX=O)("5S.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E
M('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED
M(")#;W5N=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A
M=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E
M871O<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R
M96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R
M96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$
M1"(*;7-G<W1R("+MYN,@+2#1WN/MY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B[>;C[2(*
M"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O
M=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y
M(@IM<V=S='(@(NWFX^TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS
M9VED(")$969A=6QT(@IM<V=S='(@(L?ARLW>WB#'X<?=RM''UNTB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("+'T\K.S^,@Q^'>
M[>,@Q^'%W<K1Q];MR2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`BQ^'*
MS=[>(,?AQ]W*T<?6[2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC
M+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("+'X<K-WMX@
MQ^''W<K1Q];M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED
M(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I
M9"`B1&5L971E($=R;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES
M<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$
M96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R("+'X<K-WMX@Q^''W<K1Q];M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("+4T<T@
MQ^'CU-_AR2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L
M(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("+'X=31S2#'X<K=
MU>WA[3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I
M9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`BRN,@S=W9(,?ARMW'U>WA(.'CS^W1(,?AY-G'XR(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M
M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS
M9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM
M<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L[MQ]''RB#'X=K1UB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM
M<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("+.[<?1
MQ\H@Q^':T=8B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$
M:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@
M9F]R;6%T(@IM<V=S='(@(L[MQ]''RB#'X=K1UB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF
M:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T
M:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(N''(,K/SN$@X\C'
MU-')\"#%X>P@Q^'CX=T@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T
M(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N
M;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1O=VYL
M;V%D("5S(@IM<V=S='(@(L/CT2#;[=$@X]K1YMT@)7,Z(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T
M"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G
M<W1R("+'X<C1[<\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I
M=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E
M9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I
M9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*
M;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T
M:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA
M:6PB"FUS9W-T<B`BQ^'(T>W/(,?AQ>'?RM'FY.TB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`BVN3FQ^0@R-'MS]\@Q^'%X=_*T>;D[3HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`BX]KAYN/'RB#"SM'L(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'
M871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR.3@*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*
M;7-G<W1R("+.[<?1Q\HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE
M<W-A9V4N(@IM<V=S='(@(N''RN;,SR#DRL?&S"XB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T
M>2!R97-U;'0N(@IM<V=S='(@(N''RN;,SR#DRL?&S"XB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS
M9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I
M86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R
M96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R
M=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BSMC#(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L
M871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN
M9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I
M;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O
M;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B
M171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS
M9W-T<B`BW^$@,34@S][MWLDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B
MW^$@-2#/WNW>R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD
M<R(*;7-G<W1R("+?X2`S,"#/WNW>R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E
M<GD@-2!M:6YU=&5S(@IM<V=S='(@(M_A(#4@S][MWLDB"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R
M>2!,;V=I;B(*;7-G<W1R("+?X2#/SN;A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(M_A
M(.35W2#3Q]K)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`BW^$@S][MWLDB"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(L/CR^')(-KA
M["#'X=[MXSHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD
M<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*(RP@9G5Z>GD*
M;7-G:60@(D5X96-U=&4B"FUS9W-T<B`BRN3=[=`Z(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM
M<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H
M<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A
M<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G
M:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G
M:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BX<?%X]_'Y.W)(.'AVLOF
MT2#:X>P@Q^'*W=;MX<?*+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!,1$%0+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5
MQ^$@R,?AX\[/XR!334(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O
M;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*U<?A
M(,C'X>/.S^,@4TU"+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB
M"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!334(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
MX<?%X]_'Y.W)(.'AVLOFT2#:X>P@Q^'*W=;MX<?*+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O
M92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR,S@*(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("+-
MU>$@SMC#.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("+=Q]_3(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B
M"FUS9W-T<B`BW<??TR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS
M9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD
M(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ
M>0IM<V=I9"`B1FEL92(*;7-G<W1R("+'X>'>R"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA
M;64B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED
M(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G
M:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&
M;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("+CX<?-
MV<?*(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T
M=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P
M"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&
M<F%M97,B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N
M8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L
M;"!$97-C<FEP=&EO;B(*;7-G<W1R("+'X=31S2#'X<K=U>WA[3HB"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM
M<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P
M"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BQ]/CWSHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*
M;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B
M1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS
M9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@
M(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)
M4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E
M;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O
M=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z
M,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM
M<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM
M<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](
M;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE
M;'`B"FUS9W-T<B`BQ^'CT\?:S\DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q
M"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`BQ^'CT\?:S\DB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E
M;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS
M9VED(")(;U]M92(*;7-G<W1R("+'X<C/Q^W)(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM
M<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED(")(
M;VUE(@IM<V=S='(@(L?AR,_'[<DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G
M<W1R("+:Y.;'Y"#'X>/DTN$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO
M;64@4&AO;F4B"FUS9W-T<B`BY<?*W2#'X>/DTN$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`BY>;1S^TB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB
M)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@
M;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S
M:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G
M:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M
M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B
M25`@061D<F5S<R(*;7-G<W1R("+'X=KDYL?D(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0
M(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED
M("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`BP^W>YN3'
MRB#=WM@B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*
M;7-G<W1R("+#[=[FY,?*(./:(.35YM4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E
M8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO
M<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@
M55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(L?AS=[F
MX2#'X>/3RN;1S\DZ("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S
M(@IM<V=S='(@(L?AS=[FX2#'X>/3RN;1S\DZ("5S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*
M;7-G<W1R("+'X<W>YN$@Q^'CT\KFT<_).B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?
M<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED
M("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R
M("+.V,,@W>T@Q]/C(,?AX]/*SL_C(.8OP^8@W^'CR2#'X=/1+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L
M(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I
M9"`B26YD;VYE<VEA(@IM<V=S='(@(LKC(,CDS,?-(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"B,L
M(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+([<?DQ\K?.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN
M9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I
M9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@
M3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN
M($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T
M(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E
M;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M
M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@
M(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN
M=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S0*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S
M='(@(L?ARMC([=['RB#'X>/FS.;/R3H@)7,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L
M:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B
M26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W,PIM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED
M("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED
M("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I
M9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E
M9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES
M<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A
M;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B
M271A;'DB"FUS9W-T<B`B[>;C[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M
M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P
M"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO
M=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA
M>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B
M2G5S=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+
M965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`BQ^'CSL_C(-_MT<CMT>;3(-'=UB#'X<K-
MWMX@X^0@Q^'EYNW)+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM
M<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N
M9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@
M(DME>2!5<V%G92(*;7-G<W1R("+-S.,@Q^''T\K.S\?C.B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E
M;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM
M<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`HC+"!F=7IZ>0IM<V=I
M9"`B3&%?>6]U="(*;7-G<W1R("+.T>;,(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BQ^'AV\DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO
M9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R("+.T>;,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A
M9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(L/CR^')
M(-KA["#'X=[MXSHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R("+#R,_'\"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED
M("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H
M="!286EN(@IM<V=S='(@(L_.YN$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED
M("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I
M;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F
M=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("+/SN;A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED
M("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S
M<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X
M="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@
M1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(M['QN/)
M(-KDQ^;MY"#'X>/3Q]K/R2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*
M;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("+>Q\;C
MR2#:Y,?F[>0@Q^'CT\?:S\DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES
M="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),
M:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX
M,PHC+"!F=7IZ>0IM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("+*S>/MX2#'
MX>/?RLC'RBXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@
M(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R("+/SN;A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U
M"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@
M(DQO9R!O=70B"FUS9W-T<B`BSM'FS"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`BS\[FX2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(L?AX^7CQ\HB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(LW5X2#.V,,@X=/(R"#CQR##
MR^3'P2#'X<_.YN$N(-KA["#'X</1S,T@P^0@Q]/C(,?AX]/*SL_C(,/F(-_A
MX\D@Q^'CT>;1X>W3RB`B"B+5S>W-R2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY,@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G
M<W1R("+=U.$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L
M(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`BSM'FS"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM
M<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R
M965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@
M;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E
M<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(DU-(@IM<V=S='(@(M3ET2`M(-'>X^WD(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM
M<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R("+'X<C1
M[<\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA
M:6PB"FUS9W-T<B`BQ^'(T>W/(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*
M;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`BQ^'(T>W/(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R("+'X<C1[<\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(L?AR-'M
MSR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN
M9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(LKDR.WE(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I
M9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L
M;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R
M=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(N/8Q\C>
MR2#'X<W>YN$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G
M:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BX]#?T<?*
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M
M;V1E.B(*;7-G<W1R("+FUMH@Q^'CT-_1Q\HZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R
M9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`BT=/'X<DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("+1T\?AR2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("+1T\?A
MR2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A
M=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS
M9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B(@HB
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`BRN,@S=W9
M(,?ARMW'U>WA(.'CS^W1(,?AY-G'XR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H
M<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N
M;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R
M97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP
M.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V
M"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`BQ^'(T>W/(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A
M9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS
M9VED(")-:7)R;W(B"FUS9W-T<B`BSMC#(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U
M,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED
M("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@
M240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI
M<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-
M;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF
M:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(M3ET>W'\"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG
M:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO
M=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE
M=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM
M87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!
M8V-O=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR
M.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G
M<W1R("+([<?DQ\K?.B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S
M='(@(L?AQ]/C(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B
M3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE
M='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G
M:60@(DYE=F5R(@IM<V=S='(@(L/(S\?P(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T
M96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O
M;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA
M;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@(N/AQ\W9
MQ\HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I9"`B
M3F5X="!O<'1I;VYS(@IM<V=S='(@(MKFS\D@Q>'L(,?ASNW'T<?*(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS
M9W-T<B`BP\C/Q_`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM
M<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY
M"FUS9VED(").:75E(@IM<V=S='(@(LKDR.WE(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T
M<B`BX<<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*
M;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS
M9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB!3
M34(^(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-H86YG92XB"FUS9W-T<B`BRM''S-H@VN0@Q^'*V^WMT<?*(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R("+AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'X=P@4U%,(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(N''RN;,SR#CVN'FX\?*(,WFX2#%VL_'S\?*(,?A
MW"!&5%`@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BX<?*YLS/(./:X>;CQ\H@S>;A(,7:
MS\?/Q\H@Q^'<(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`BX<?*
MYLS/(./:X>;CQ\H@S>;A(,7:S\?/Q\H@X^'=Q\H@4U%,(%9&4RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*
M;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U
M<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`BX>,@[<KC(,K-S^W/(.';R2#CS>'MR2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS
M9W-T<B`BX>,@[<KC(,K-S^W/(.';R2#CS>'MR2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM
M<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(N'C(.W*XR#*S<_M
MSR#AV\D@X\WA[<DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S
M<&5C:69I960N(@IM<V=S='(@(N'C(.W*XR#*S<_MSR#AV\D@X\WA[<DN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]H='1P+G!H<#HY,0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,
MSR#?X>/)(./1YM$@X>'*S=[>($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+A
MQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB!,1$%0+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*
MYLS/(-_AX\D@X]'FT2#AX<K-WMX@W^W1R.W1YM,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G
M:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC
M+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'A
MRLW>WB!,1$%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?X>/)
M(./1YM$@X>'*S=[>(%--0CXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?X>/)(./1YM$@X>'*
MS=[>(%--0CXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y
M('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O
M("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E
M;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM
M<V=S='(@(N/AQ\W9Q\HB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#D*(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N
M(@IM<V=S='(@(N'C(.W*XR#*S<_MSR#AV\D@X\WA[<DN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`BX^''S=G'RB(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@
M9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(L[8PR#=[2#'
MT^,@Q^'CT\K.S^,@YB_#YB#?X>/)(,?AT]$N(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`BRN,@R.3,Q\TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS
M9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L
M86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I
M86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M;W)W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T
M($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,#@*(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G
M<W1R("+%Y-3'P2#'X>/,X<\@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU
M.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"B,L(&9U>GIY
M"FUS9VED(").;W0@<V5T(@IM<V=S='(@(N/AQ\W9Q\HB"@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U
M.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G
M<W1R("+CX<?-V<?*(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP
M.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(L/(S\?P(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I
M9"`B3G5M8F5R(@IM<V=S='(@(L?AQ]/C(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM
M<V=S='(@(MK/SR#'X</:X\_)(-WM(,?AX^'.U3HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R
M(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`BX^;'W=XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE
M8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("+?
MX>/)(,?AX]'FT2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT
M-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+B(*;7-G<W1R("+.V,,@W>T@Q]/C(,?AX]/*SL_C(.8OP^8@W^'CR2#'X=/1
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS
M9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N
M<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G
M:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I
M9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN
M9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("+.[<?1Q\HB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R
M("5S(@IM<V=S='(@(L[MQ]''RB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I
M;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T
M:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*
M;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(N/:X>;CQ\H@PL[1
M["(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W
M;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I
M;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0
M(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@
M9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(N7FT<_M(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*
M;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES
M<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?
M2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED
M(")086YA;6$B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q
M.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'X>/1
MYM$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@
M(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z
M>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("+?X>/)(,?A
MX]'FT2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?X>/)(./1YM$@X>'*
MS=[>(-''S^WFTRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S
M"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*
M;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+?X>/)(,?AX]'FT2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")0
M87-S=V]R9#H@(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O
M<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")0
M87-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS
M9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S
M='(@(L?AS^;1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@
M(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+*Y-WM
MT"#:X^'MQ\H@Q^'5[<?DR2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,#8*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BRN3=[=`@VN/A[<?*(,?AU>W'Y,DB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B
M4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C4X-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD
M97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-0HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@
M26YF;W)M871I;VXB"FUS9W-T<B`BX]KAYN/'RB#"SM'L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE
M(@IM<V=S='(@(N7'RMTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L
M871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`BQ^'1S,?!(,K2YNW/Y,<@X^'.
MU2#'X>/4W^')+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`BQ^'1
MS,?!(,K2YNW/Y,<@R,?3XR#'X>/3RL[/XR#FW^'CR2#'X=/1+B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H
M92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*
M;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W
M"FUS9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R
M("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@
M(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0
M<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM
M<V=S='(@(MKFS\D@Q>'L(,?ASNW'T<?*(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED
M(")0<F]B;&5M(@IM<V=S='(@(EO*WM'MT2#'X>/4W^')72(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO
M;B(*;7-G<W1R("+4T<T@Q^'CU-_AR2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS
M9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*
M;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L
M:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I
M9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED
M(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@
M(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E
M860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS
M9W-T<B`BT=/'X<DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-
M96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E
M<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO
M860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G
M:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"B,L(&9U>GIY"FUS9VED
M(")296UO=F4B"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T
M=&EN9R(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B
MQ=+AR2#'X<ODQ\;M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM
M<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`BQ=+A
MR2#'X<ODQ\;M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@
M)7,B"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E
M<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(N'C(.W:R]$@VN'L("=P;W)T)R#=[2#%VL_'S\?*
M(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`BX>,@[=K+T2#:X>P@)W!O<G0G(-WM(,7:S\?/
MQ\H@5D93+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BX>,@[=K+T2#:
MX>P@)W!O<G0G(-WM(,7:S\?/Q\H@5D93+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("+?
MX>/)(,?AX]'FT2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W
M"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R
M>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO
M8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B
M4F5S=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E
M='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(MKFS\D@Q>'L(,?ASNW'T<?*(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y
M<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E
M<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,B"FUS9W-T<B`BVN;/R2#%X>P@Q^'.[<?1Q\HB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B
M4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B
MQ^'/YM$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E
M($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2
M;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*
M;7-G<W1R("+'X<_FT2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N
M8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN
M9R(*;7-G<W1R("+1T\?AR2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM
M<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E
M(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N
M9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`BS=W9(,?ASNW'T<?*(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS
M(@IM<V=S='(@(LW=V2#'X<[MQ]''RB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+'SLK1(,KDT^W>(,?ARL?1
M[<XZ(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@
M(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S
M97(@=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@
M(L?.RM$@RN33[=X@Q^'*Q]'MSCHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B(@HB
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(LW/SR#'X<W1YMTOQ^'1X^;2
M(,?ARNT@RM'MS^7'(,//Y,?E+B#FX^0@R^,@[>/?Y"#DT\[EQ^;AU=[EQR#6
MX^0@Q^'DU2XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`BQ\[*T2#'
MX=WFQ]7A(.'ARL?1[<XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(L?.
MRM$@RN33[=X@Q^'*Q]'MSCHB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z(@IM<V=S='(@(L?.RM$@Q^'=YL?5X2#AX<K'T>W..B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@
M=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("+'SLK1(,KDT^W>(,?AYM[*.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+%SLK1(,W>X>WD(./*
MX\?+X>WD+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@
M(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("+%SLK1(.';RM\@Q^'CW=;AR3HB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B
M4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+#T=/A(,K>T>W1Q_`@R./4
MW^')(,W5X<HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G
M:60@(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE
M9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E
M<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")3
M97-S:6]N<R(*;7-G<W1R("+-W=D@Q^'.[<?1Q\HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@
M(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RXB"FUS9W-T<B`BQ\[*T2#*S<_MRR#'X=7=S<D@YL[MQ]''
MRB#'X=3'U,D@Q^'#SM'L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A
M=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE
M<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(L?.RM$@RLW/[<L@Q^'5
MW<W)(.;.[<?1Q\H@Q^'4Q]3)(,?AP\[1["XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@
M=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H
M;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S
M='(@(L?AY,KMS,D@Q^'CSLK5T<DZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@
M9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q
M-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED
M(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC
M92(*;7-G<W1R("+%Y>/A(,?AU>W'Y,DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B
M4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED
M(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O
M<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM
M<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@Q^':X^$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM
M<V=S='(@(L7/SL?1(,W1YMT@SL?5R2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R("+'T\KMT<?/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@
M3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@
M(E-T86YD87)D(@IM<V=S='(@(L/,Y,_)(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T
M92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*(RP@9G5Z>GD*;7-G
M:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G
M:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(MKDYL?D(,?AVN/A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS
M9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("+AXR#MVLO1(-KA["#'X>/3RN/:("5S+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U
M8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I
M9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@
M>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM
M<V=S='(@(LKC(,CDS,?-(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T
M960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D
M(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C
M:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(L?ASN''U<DB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B
M4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G
M:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED
M(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B
M4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("+'
MT\KMT<?/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA
M;64B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R
M("+'X<?3XR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A
M>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*
M;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED
M(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*
M;7-G<W1R("+'X>'>R"(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z
M,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R("+'X>'>R"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B
M5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"B,L(&9U>GIY"FUS9VED(")4
M87)G970Z(@IM<V=S='(@(LW,XR#'X<?3RL[/Q^,Z(@H*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W
M"FUS9VED(")487-K<R(*;7-G<W1R("+'X>/EX\?*(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.
M=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*
M;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS
M9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I
M9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,V"B,L(&9U>GIY"FUS9VED(")497AT(@IM<V=S='(@(N35(-W>
MV"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@
M3VYL>2(*;7-G<W1R("+DU2#=WM@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED(")4
M97AT(&%L:6=N(@IM<V=S='(@(N35(-W>V"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B
M5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("+*XR#'
MX<[1YLP@R.3,Q\TN(#QB<B`O/B#4W]''\"#AQ]/*SL_'X]_C(.70QR#'X>39
MQ^,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@
M(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE
M($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%
M>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P
M,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG
M=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*
M(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS
M9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I
M9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B
M87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@
M(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B
M"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4
M:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A
M("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B
M92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES
M(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R
M97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A
M<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O
M<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@
M:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E
M="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O
M(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B
M"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@
M<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@
M;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B[<S((,/D(,K?
MYN0@Y=#E(,?AWNWCR2#1WN,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@
M<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HBX>,@[<KC(,?AVLOFT2#:X>P@Q^'(
MT>3'X\P@Q^'CT\K.S^,@X<79Y<?1(,?AT=/'QN$@X^0@Y.;:("@E<RD@UN/D
M(.39Q^/?+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM
M<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@
M86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H
M87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`BQ>0@X^'=Q\H@4$\@X>';R2`E<R#;[=$@X^;,YL_)(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I
M;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ>0IM<V=I
M9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("+A
MQ\KFS,\@P^W)(,K=UNWAQ\HN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P
M+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y
M<W1E;3H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(NW,R"##Y"#*W^;D(.70
MY2#'X=[MX\D@T=[C+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L
M;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T
M<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H
M('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F
M;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET
M:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E
M<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S
M(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(*;7-G<W1R("+MS,@@P^0@RM_FY"#ET.4@Q^'>[>/)(-'>XRXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I
M96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@
M9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N(@IM<V=S='(@(NW,R"##Y"#MW^;D(.70QR#'X='>XR##W\C1(./D
M(,?AU=W1(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N
M<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B[<S((,/D(,K?YN0@Y=#E
M(,?AWNWCR2#1WN,N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS
M9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(L?AX=[((@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I
M;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(L?A
MX=[((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED
M(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R
M("+.T>;,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED
M(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M;VYG82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS
M9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM
M<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/
M+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R
M:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U
M<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G
M:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`BVN3FQ^0@Q^'%Y,K1Y.W*(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S
M='(@(MKDYL?D(,?AQ>3*T>3MRB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G
M86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q
M,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,X.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(N''(,7CW\?D[<D@X<K;[>W1(,?AT^/'S>W'RB#AX^'=(%9&4R`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'*V^WMT2#'X=/CQ\WMQ\H@
MX>/AW2!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N(@IM<V=S='(@(N''(,7CW\?D[<D@X>'%RM7'X2#(X\[/
MXR!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;
M[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)
M(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(N''(,7CW\?D[<D@X>'%RM7'
MX2#(X\[/XR!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M,SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("+A
MQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@
M=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(N''(,7CW\?D
M[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1
M(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(N''
M(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S
M='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H
M<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z
M-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@
M=F9S<F]O="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`BX<<@RN;,SR#%
MX]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(N''(,7CW\?D[<D@
MX=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''
MP<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@
M=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./A
MW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(N''(,KF
MS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./A
MW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(N''(,KFS,\@
MQ>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS
M9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1
M(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PHC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#C
MX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,SR#%
MX]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AX<7*U<?A(,CCSL_C(%-13"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R
M("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@
M(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(N''(,KFS,\@Q>/?
MQ^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`BX<<@Q>/?Q^3M
MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/
M('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#A
MRMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,T,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3M
MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@
MX<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'
MY.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S
M='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N="(*;7-G<W1R("+;[=$@WL?/T2#:X>P@RM',X\D@X]/*Y,\@Q^'F
MT<\@Y=#'(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&
M4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P
M>2@I(&9A:6QE9"DN(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@
MQ]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@
M5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@
M0VAA;F=E<R(*;7-G<W1R("+*T<?,VB#:Y"#'X<K;[>W1Q\HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV,0HC+"!F=7IZ>0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R
M("+=U.$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI
M8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5
M;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,L(&9U
M>GIY"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G
M<W1R("+.V,,@W>T@Q]/C(,?AX]/*SL_C(.8OP^8@W^'CR2#'X=/1+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*
M(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BQ^''T^,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED
M("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS
M9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@
M(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("+'
MT^,@Q^'CT\K.S^,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO
M="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED
M(")5<V5R($]P=&EO;G,B"FUS9W-T<B`BSNW'T<?*(,?AX]/*SL_C(@H*(SH@
M<VEG;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I
M;VXB"FUS9W-T<B`BSNW'T<?*(,?AX]/*SL_C(@H*(SH@<VEG;G5P+G!H<#HR
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@
M9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*
M;7-G<W1R("+'T^,@Q^'CT\K.S^,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE
M(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`BQ]/C(,?AX]/*SL_C(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R("+'T^,@Q^'CT\K.S^,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B
M5F5R<VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R
M=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*
M;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G
M:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D
M869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G
M:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B
M"FUS9W-T<B`BRN3([>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R
M96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B
M5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED(")7965K;'DB"FUS9W-T<B`BP]/(YMKMQ_`B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*
M;7-G<W1R("+#Y>''(.;3Y>''("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BP^7AQR#(
MW^,@Q>'L("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E;&-O;64L("5S(@IM<V=S='(@(L/EX<<@YM/EX<<@)7,B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A
M9G1E<B!L;V=I;C\B"FUS9W-T<B`BX\<@Q^'(T>3'X\P@Q^'CRM'6(-K1UN4@
MX^0@Y>;1S^T@R-K/(,?AS\[FX;\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H
M87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S
M"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G
M:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H
M(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@
M;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE
M('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V
M"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#(*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G<W1R("+*Y,CMY3HB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED
M(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E
M<W,B"FUS9W-T<B`BVN3FQ^0@Q^':X^$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM
M<V=S='(@(N7'RMT@Q^':X^$B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN
M92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O
M=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D
M('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*
M;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B
M6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S
M(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S
M(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E
M>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")962(*;7-G<W1R("+3Y,D@+2#7UR(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B
M65E962(*;7-G<W1R("+3Y,D@+2#7UR(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+3Y.;MQ_`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B
M"FUS9W-T<B`BY-KC(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R
M"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@
M;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@
M8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("+*XR#*S<_MRR#'
MX<[MQ]''RB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G
M:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("+M
MS,@@U-'-(,?AX]3?X<D@WLCA(,?1T\?A(,K>T>W1Q_`@R.7'+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@
M(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT
M<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T
M-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("+'Y,KE
MRB#5X<?-[<D@Q^''RM7'X2`E<RX@Q^'1S,?!(,7:Q\_)(,?AS\[FX2XB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(MKDYL?D(,C1[<_?
M(,?AQ>'?RM'FY.TZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("+:
MY.;'Y"#(T>W/WR#'X<7AW\K1YN3M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I
M9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+([<?DQ\K?.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"B,L
M(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BQ]/CWSHB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M
M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E
M;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T
M;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T
M<B`BRN,@RLW/[<L@Q^'.[<?1Q\HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M(@IM<V=S='(@(L?ARLW>WB#'X<?=RM''UNTB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB
M"FUS9W-T<B`BQ]/CWSHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ
M,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*
M;7-G<W1R("+*XR#*S<_MRR#'X<[MQ]''RB(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`BRN,@RLW/[<L@Q^'.[<?1Q\HB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("+*XR#*
MS<_MRR#'X<[MQ]''RB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED
M("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R
M(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@
M<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE
M;2!297!O<G1=(@IM<V=S='(@(EO*WM'MT2#'X>/4W^')72(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO
M=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@
M(EO'X=/8T2`E<R#CY"`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B
M7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U
M-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$
M96QE=&4@4F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I
M9"`B7T=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")?2&5L<"(*;7-G<W1R
M("+'X>/3Q]K/R2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("+/SN;A
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F
M=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BSM'FS"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM
M<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/
M<'1I;VYS(@IM<V=S='(@(L[MQ]''RB(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM
M<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ
M>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(L72X<D@Q^'+Y,?&
M[2(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z
M>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+/W<K1(-KDQ^;MY"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED
M(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B
M"FUS9W-T<B`BP\SDS\DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C
M86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L
M:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I
M9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B
M9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y
M(&YO="!F;W5N9"(*;7-G<W1R("+;[=$@X^;,YL\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`BW=3A(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X
M"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*
M;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL
M:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G
M:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L
M:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@
M(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G
M:60@(FYA;64B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED
M(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I
M;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L
M(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BRN3([>4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC
M92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I
M9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F
M9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@
M(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@
M9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("+?X2#/SN;A(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A
M9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B=6YI9FEE
M9"(*;7-G<W1R("+=U.$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N
M<&AP.C(W"B,L(&9U>GIY"FUS9VED(")U;FYA;65D(@IM<V=S='(@(L?AQ]/C
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@
M(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H
M97(N8V]M(@IM<V=S='(@(B(*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+W5K
M7U5!+G!O````````````````````````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`V,#4U-C,`,3`U,34T,S$P-C,`,#$V-#$P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",@2&]R9&4@56MR86EN
M:6%N($M/23@M52!T<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,B!!
M;F1R:7D@2V]P>7-T>6%N<VMY+@HC($%N9')I>2!+;W!Y<W1Y86YS:WD@/&%N
M<FE`<&]L>6YE="YL=FEV+G5A/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@=C(N,5QN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#(M,#$M,#4@,38Z,34K,#(P,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!!;F1R:7D@2V]P>7-T>6%N<VMY(#QA;G)I0'!O;'EN970N
M;'9I=BYU83Y<;B(*(DQA;F=U86=E+51E86TZ(%5K<F%I;FEA;B`\=V5B;6%S
M=&5R0'!O;'EN970N;'9I=BYU83Y<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]2T])."U57&XB
M"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS
M9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E
M<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$P-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C
M;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y
M<W1E;2XB"FUS9W-T<B`B]=/0IMO.SR#$S\3!SL\@)R5S)R#$SR#3R=/4Q<W)
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M("T@3F]T:6-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E
M<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VXB"FUS9W-T<B`B[]#%TL'#IM$@T-+/QJ;,P<O4R=[.S\?/(,_"T\S5Q\_7
MU=?!SL[1("5S("T@\*;$U-?%TL36Q<[.T2(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F
M($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P
M97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L
M;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(O>FQ,VF
MU-C4Q2#/T,72PZ;`**<I+"#1RZ8@T\RFQ"#:Q*;*T\[)U,D@UR##Q<H@WL'3
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;6EN=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O
M;VLB"FUS9W-T<B`BX<32Q=/.P2#+SLG'P2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L
M96YD87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V
M:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L
M(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G
M:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO
M=7(@1F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@
M(C(T(,?/Q,G.R2(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*
M;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@
M(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!
M8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U
M;G0@4&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0P=+/S,`B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D
M(@IM<V=S='(@(N'$TL73P2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI
M;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@
M(N3/Q,'4R2#+S]+)T]35U\'>P2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE
M=R!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E
M<CHB"FUS9W-T<B`BY,_$P=3)(,[/U\_'SR#+S]+)T]35U\'>P3HB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED
M(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M
M8F5R<R(*;7-G<W1R("+DS\3!U,D@SL_7S\?/(,O/TLG3U-77P=[!.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER
M(@IM<V=S='(@(N3/Q,'4R2#0P=+5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED
M(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("+AQ-+%T\[!(,O.R<?!
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X
M"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S
M='(@(N'$TL73SL$@R\[)Q\$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I
M9"`B061D('5S97(B"FUS9W-T<B`BY,_$P=3)(,O/TLG3U-77P=[!(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D
M960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+D
MS\3!U\'.SM$@R\_2R=/4U=?!WJ;7(-K!PL_2S\[%SL4N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BX<32
MQ=/!(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0HC+"!F=7IZ
M>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(N'$TL73SL$@R\[)Q\$B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM
M<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77P<[.T2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R
M("+AQ-+%T\$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM
M<V=S='(@(O#3Q=?$S\ZFS2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@
M(D%L9V5R:6$B"FUS9W-T<B`B\-/%U\3/SJ;-(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS
M9W-T<B`B\-/%U\3/SJ;-(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B\-/%U\3/SJ;-(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T
M:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I
M9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L
M;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED
M(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU
M,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO
M9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@
M861D<F5S<R(*;7-G<W1R("+WP=O!(,'$TL73P2#%+=#/V]3).B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA
M=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E
M>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A
M;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@
M(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PIM<V=I9"`B06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO
M<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP
M:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T
M:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@
M4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ
M,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU3
M0TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R
M=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!
M<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I
M9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G
M:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W
M:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@
M(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H
M7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@
M34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A
M=&EO;B!F86EL960N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE
M;&1S.B(*;7-G<W1R("+DS]/4U=#.IB#0S\S1.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O
M=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM
M<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")"
M:7)T:&1A>2(*;7-G<W1R("+DQ<[8(,[!TL_$UL7.SM$B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M
M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO
M8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO
M<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(DE-4"W0S]+4P<PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$
M87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A
M<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3
M(@IM<V=S='(@(D-64R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L
M;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX
M-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+WIL3-IL[)U,D@T,_7IL3/
MS<S%SL[1(-#2S\+,Q<W)(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP
M:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E
M<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E
M<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y
M"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M
M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS
M9W-T<B`B^L+%TL7'U,D@S]##IJ<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E
M9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO
M;F4B"FUS9W-T<B`B\]2FS-C.R<O/U\G*(-3%S,7&S\XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U
M>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B\]2FS-C.R<O/
MU\G*(-3%S,7&S\XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G
M:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM
M<V=S='(@(O/4ILS8SLG+S]?)RB#4Q<S%QL_.(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T
M92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R("+SR\'3
MU=?!U,D@VLVFSLDB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S$*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S
M='(@(O"FQ-37Q=+$UL7.SM$@T,'2S\S`(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U
M"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R("+TR=35S"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q
M,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G
M:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*(RP@9G5Z>GD*
M;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(O"FQ-37Q=+$UL7.
MSM$@T,'2S\S`(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM
M<V=I9"`B0VQE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS
M9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A
M<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED
M(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R
M("+ZP<O2R=3)(->FR\[/(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*
M;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM
M<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P
M<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@
M8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L
M;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*
M;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ
M>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("+KS\W0P<ZFT2(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G
M:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G
M:60@(D-O;7!A;GDB"FUS9W-T<B`BZ\_-T,'.IM$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"FUS9VED(")#;VYD
M:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*
M;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS
M9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(O"FQ-37Q=+$UL7.SM$@
MT,'2S\S`(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED
M(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("+WS:;3U"`G
M)7,G(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K
M:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM
M<V=S='(@(NO/S=#!SJ;1(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D
M.B`E<R(*;7-G<W1R("*VS=#/TM3/U\'.Q2#0S\S%.B`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B2&]R9&4@SL4@T\O/SL:FQ]72S]?!SL$@T-+!U\G,
MV,[/(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV
M92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I
M9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E
M871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R
M96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R
M<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R
M<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C
M;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M1$0B"FUS9W-T<B`BY.0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(OW/Q,7.SL\B"@HC.B!A
M9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM
M<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Y.0HC+"!F=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R
M("+WR=3%TM3)(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY
M"FUS9VED(")$87DB"FUS9W-T<B`B_<_$Q<[.SR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ
M>0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED
M(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W
M(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(O?)U,72U,DB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO
M<B(*;7-G<W1R("+WR<O/TLG3U,_7U=?!U,D@VL[!WL7.SM$@VL$@VL'-S]?>
MU=?!SL[1S2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B[]/.S]?.P2"F
MT,_3U,'3V"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("+OT\[/U\[!(*;0S]/4
MP=/8(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW
M,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B]\G4Q=+4
MR2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T
M<B`B]\G4Q=+4R2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@1W)O=7`B"FUS
M9W-T<B`B]\G4Q=+4R2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("+WR=3%
MTM3)(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(&-E;&PB"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E
M<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@<F]W(@IM<V=S='(@(O?)U,72U,DB"@HC.B!T96UP;&%T97,O<')E
M9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B[]/.S]?.P2"FT,_3U,'3
MV"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R
M;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C
M<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z
M>GD*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H
M92!0<F]B;&5M(@IM<V=S='(@(N_0R=NFU-@@T-+/PLS%S=4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B\,_7SLG*(,_0R=,Z(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED
M(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I
M9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PHC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(OK"Q=+%Q]3)
M(,_0PZ:G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"FUS
M9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@9&5L971E
M(@IM<V=S='(@(O?)U,72U,DB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R
M;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA
M:6PB"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@
M9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H
M:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I
M9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T
M97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M
M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%
M9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E
M<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I
M9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y
M"FUS9VED(")%;6%I;"(*;7-G<W1R("+E+=#/V]3!(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(O?!V\$@P<32Q=/!(,4MT,_;U,DZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DV,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(O#!TL_,V"#-U=/)U-@@T]"FU]#!T]3)
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M
M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I
M;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R("+PS]+/ULZFRB#2Q=K5S-C4P=0N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP
M='D@<F5S=6QT+B(*;7-G<W1R("+PS]+/ULZFRB#2Q=K5S-C4P=0N(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP
M='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G
M92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC
M:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R
M("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE
M(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L
M971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%
M<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@
M(O#/S<G,R\$B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C
M:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN
M8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B
MZ\_6SL_'SR#7R,_$U2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C
M;VYD<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*(RP@9G5Z>GD*;7-G:60@(D5V
M97)Y(#4@;6EN=71E<R(*;7-G<W1R("+KS];.S\?/(-?(S\35(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B
M179E<GD@3&]G:6XB"FUS9W-T<B`BZ\_6SL_'SR#7R,_$U2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#@*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(&UI
M;G5T92(*;7-G<W1R("+KS];.S\?/(-?(S\35(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G
M<W1R("+DP<ZF(,3,T2#0TLG+S,'$U3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM
M<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H
M<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A
M<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G
M:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G
M:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T
M;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(D9A
M=&%L($5R<F]R.B(*;7-G<W1R("+PS\W)S,O!(+;-T,_2U-4Z("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@
M(D9A>"(*;7-G<W1R("+FP<O3(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T<B`BYL'+TR(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS
M9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED
M(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&
M:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*
M;7-G<W1R("+TR=35S"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL
M92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`BMLU@
MT2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I
M;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS
M9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM
M<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@
M(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U
M;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(N[/U,'4R\DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R("*V
MS6#1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS
M9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B\,_7SLG*(,_0R=,Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L
M;"!.86UE(@IM<V=S='(@(O?!V\4@ILTGT3HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I
M9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M
M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG
M+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=H86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N
M<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R("+AQ-+%T\[!(,O.R<?!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@
M(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H
M;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@
M86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M
M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*
M;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T
M"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L
M<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L
M871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(N3/
MT,_-S\?!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I
M9"`B2&5L<&5R(@IM<V=S='(@(N3/T,_-S\?!(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO
M8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS
M9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U,S4*(RP@9G5Z>GD*;7-G:60@(DAO;64B"FUS
M9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+DS\W!
MV\[1(,'$TL73P2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I
M9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R("+DS\W!V\ZFRB#4Q<S%QL_.(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@7"(E<UPB(@IM<V=S='(@(O73T*;;SL\@U\G$P<S%SL\@)R5S)R#:(-/)
MT]3%S<DN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I
M9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E
M<W,B"FUS9W-T<B`BX<32Q=/!(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T
M(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W
M"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*
M;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G
M92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D
M:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G
M:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G
M92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R("*VS=#/TM3/U\'.Q2#0S\S%.B`E<R(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D
M(&9I96QD.B`E<R(*;7-G<W1R("*VS=#/TM3/U\'.Q2#0S\S%.B`E<R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D
M(&9I96QD<SHB"FUS9W-T<B`BMLW0S]+4S]?!SJ8@T,_,T3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*
M;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC
M;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F
M=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"XB"FUS9W-T<B`BXM7$V"W,P=/+P2P@U\O!UJ;4V"#.P=K7U2#+S]+)T]35
MU\'>P2"F(-#!TL_,V"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*
M;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN
M9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@
M;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("))
M;G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G
M:60@(DEN<V5R="!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B
M;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E
M<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*
M;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I
M9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV
M86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A
M;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M
M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S,*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I
M9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T
M960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M<W)A96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET
M86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@
M(DET86QY(@IM<V=S='(@(OW/Q,7.SL\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R
M+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O
M;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I
M<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*
M=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G
M:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@
M0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I
M9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+
M97D@0W)E871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS
M9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@
M9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("+LR=/4(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y
M;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(
M86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I
M9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(O?)
MRM3)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G
M:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(N3!SJ8@Q,S1(-#2R<O,P<35.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I
M>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T
M96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L
M(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(O?7ILK4R2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED
M("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN
M($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM
M<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3
M:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U
M"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@
M(O?7ILK4R2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@
M(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W
M:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED
M("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A
M;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP
M(%1O<&EC<R(*;7-G<W1R("+PQ=+%S*;+(-+/VL2FS*;7(.3/T,_-S\?)(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I
M9"`B3&ES="U(96QP(@IM<V=S='(@(O#%TL7,ILL@TL_:Q*;,IM<@Y,_0S\W/
MQ\DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM
M<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("+PQ=+%
MQ\S1Q"#3T,G3R]4@R\_2R=/4U=?!WJ;7(-K!PL_2S\[%SLG*+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(O#%TL7'S-'$
M(-/0R=/+U2#+S]+)T]35U\'>IM<@VL'"S]+/SL7.R<HN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+PQ=+%Q\S1Q"#3T,G3R]4@R\_2
MR=/4U=?!WJ;7(-K!PL_2S\[%SLG*+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ-S(@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R("+WUZ;*U,DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X
M-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("+WR<K4R2(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`B]]>FRM3)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I
M9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*
M;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT
M(@IM<V=S='(@(O?)RM3)(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X
M"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B
M[>TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-
M3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G
M:60@(DU31R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(DE-4"W0S]+4P<PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I
M(@IM<V=S='(@(DE-4"W0S]+4P<PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA
M;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-
M86QI(@IM<V=S='(@(DE-4"W0S]+4P<PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z
M>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(DE-4"W0S]+4P<PB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES
M="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L
M(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*
M;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z
M>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+UU\''P2(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I
M=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G
M:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("+WIL30S]>FQ,ZF(-#/S-$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U
M"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM
M<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM
M=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G
M:60@(DUE;6)E<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S
M<V%G92(*;7-G<W1R("+LR=/4(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B[,G3U"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R
M("+LR=/4(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A
M<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES
M(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)0
M0R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@
M(DE-4"W0S]+4P<PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R("+PS\W)S,O!
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL
M86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS
M9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS
M9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I
M9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED
M(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM
M<V=S='(@(OW/S:;3T</1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R
M<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-
M;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B
M36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@
M57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I
M9"`B36]V92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO
M>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP
M;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E
M>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y
M;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE
M(@IM<V=S='(@(K;-8-$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS
M9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I
M9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T
M96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`B\,'2S\S8(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D
M<R!D;VXG="!M871C:"XB"FUS9W-T<B`B\,'2S\S8(,W5T\G4V"#3T*;7T,'3
MU,DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ
M>0IM<V=I9"`B3F5W<R(*;7-G<W1R("+NS]3!U,O)(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I
M9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*
M;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G
M<W1R("+PS]?%TL[5U,G3T2#$SR#OT,.FRB(*"B,Z(&9R86UE=V]R:R]522]5
M22]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY
M"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H
M;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@
M97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*(RP@
M9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B\\O!T]77P=3)(-K-
MIL[)(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R
M:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"FUS9VED
M(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU
M;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T
M:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S
M='(@(N[/U,'4R\DB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(N[/U,'4
MR\DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B
M3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G
M:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R
M("+BU<38+<S!T\O!+"#7R\'6IM38(,[!VM?5(,O/TLG3U-77P=[!(*8@T,'2
MS\S8(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G
M:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED
M(").;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B
M"FUS9W-T<B`B],7,Q<;/SB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@
M(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B
M3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F
M=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS
M9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G
M:60@(DYO="!S970B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R
M,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(N[/U,'4R\DB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*
M;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM
M<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@
M(K;-8-$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M
M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R
M;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B
M3V)J96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C
M=&]B97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR
M"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F
M=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(O#!TL_,V"(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@
M(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R
M<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-
M12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*(RP@
M9G5Z>GD*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"B,L(&9U>GIY
M"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G
M:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B
M3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-
M86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")0
M1U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC
M+"!F=7IZ>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B
M4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B
M4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/
M8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U
M87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM
M<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B\,'2S\S8(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`B\,'2S\S8(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@
M=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`B\,'2S\S8(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B\,'2
MS\S8(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(O#!
MTL_,V"#-U=/)U-@@T]"FU]#!T]3)+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T
M92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(O+/S-@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(O?)R\_.P=3)
M(-#2S\:FS,'+U,G>SJ8@S]#%TL'#IJ<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(O?)R\_.P=3)(-#2S\:F
MS,'+U,G>SJ8@S]#%TL'#IJ<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-@IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*
M(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77P<[.T2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(O3%S,7&S\XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@
M(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS
M9W-T<B`BXM7$V"W,P=/+P2P@Q,'*U,4@R\_2S]3+R<H@S]#)TR#0TL_"S,7-
MR2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(N+5Q-@MS,'3R\$L
M(-?+P=:FU-@@SL':U]4@R\_2R=/4U=?!WL$@IB#0P=+/S-@B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D
M('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@
M=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS
M9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM
M<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O
M/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S
M:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0
M<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E
M<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G
M<W1R("+PS]?%TL[5U,G3T2#$SR#OT,.FRB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R(");\,_7IL3/S<S%SL[1(/#2S\+,Q<W)72(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$
M97-C<FEP=&EO;B(*;7-G<W1R("+OT,G3(-#2S\+,Q<W)(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H
M)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@
M(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G
M:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A
M:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R("+LR=/4(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE
M=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T
M<B`B[][)T]3)U,DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y
M"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M
M;W1E(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B
M]\G4Q=+4R2#0P=+5(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B]\G4
MQ=+4R2#0P=+5(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"B,L
M(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("+WR=3%
MTM3)(-#!TM4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM
M<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B]\G4Q=+4R2#0P=+5(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D
M('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*
M;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B]\G4Q=+4R2#0P=+5(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B]\G4Q=+4
MR2#0P=+5(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*
M;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM
M<V=S='(@(N_>R=/4R=3)(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@
M(O#!TL_,V"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"B,L
M(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(O"F
MQ-37Q=+$UL7.SM$@T,'2S\S`(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M
M:6XO<W%L<VAE;&PN<&AP.C8V"B,L(&9U>GIY"FUS9VED(")297-U;'1S(@IM
M<V=S='(@(N_>R=/4R=3)(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U
M<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+PS]?%TL[5U,G3T2#$SR#OT,.FRB(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T
M>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V
M97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(O#/U\72SM74R=/1(,3/(._0PZ;*(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G
M:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O
M7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S
M='(@(O+/S-@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T
M871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED
M(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE
M<R(*;7-G<W1R("+RS\S8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@
M;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G
M:6YG(@IM<V=S='(@(NS)T]0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*
M;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU
M92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A
M;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN
M="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN
M="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(OK"Q=+%Q]3)(,_0PZ:G(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I
M;VYS(@IM<V=S='(@(OK"Q=+%Q]3)(,_0PZ:G(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B
M4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C
M:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(O?)PL72IM38(,;/
MTLW!U"#$P=3).B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX
M"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@
M;F5W(&]W;F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE
M8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*
M;7-G<W1R("+WR<+%TJ;4V"#&S]+-P=0@Q,'4R3HB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@
M86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM
M<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@
M=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(O?)PL72
MIM38(,[%S\+(IL3.IB#WP<T@T\G-U\_,R2#:(-#/S*;7(,[)UM[%+B#WR2#:
MS<_6Q=3%(-/+S]"FP-?!U,D@I\@@IB`B"B+7T]3!U\G4R2#:(-#/S-$@U]?/
MQ-4@U,7+T]35+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+WR<+%
MTJ;4V"#2S]K$ILS`U\'>(,3!U,DZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S
M='(@(O?)PL72IM38(,;/TLW!U"#$P=3).B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B]\G"Q=*FU-@@TL_:Q*;,
MP-?!WB#$P=3).B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS
M9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("+WR<+%TJ;4
MV"#&S]+-P=0@WL'3U3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"B,L(&9U>GIY"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RXB"FUS9W-T<B`B]Z;$T,_7IL3.IB#0S\S1(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS
M9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED
M(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(O>FQ*;3S,'4R2#0S]>F
MQ,_-S,7.SM$@T-+/(-#2S\+,Q<W5(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I
M82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q
M"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E
M<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$
M(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F
M=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED
M(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*
M;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@
M(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS
M9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R
M>2(*;7-G<W1R("+KS]+/U,O)RB#:S:;3U"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED
M(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM
M<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN
M('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM
M<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R
M"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E
M;F%N8V4B"FUS9W-T<B`B\-+/T-73U,G4R2#0TL_&ILS!R]3)R]4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T
M:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS
M9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E
M;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR
M-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M\L_"S][!(,'$TL73P2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F
M<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#
M:&%R86-T97(@26YP=70B"FUS9W-T<B`B]]>FQ"#ST,7#IL',V,[)R"#3R<W7
MS\RFUR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R("*VS=#/TM0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P
M"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*
M;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3
M=')E970@061D<F5S<R(*;7-G<W1R("+RS\+/WL$@P<32Q=/!(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B
M4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED
M(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N
M<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E
M<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L
M;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(O73T*;;SL\B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("+UT]"FV\[/
M(,3/Q,'.SR`G)7,G(,3/(-/)T]3%S<DN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(O73T*;;SL\@U\G$P<S%SL\@)R5S)R#:(-/)T]3%S<DN(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(O73T*;;SL\@Q,_$P<[/("<E<R<@
MQ,\@T\G3U,7-R2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(O73T*;;SL\@U\G$P<S%SL\@
M)R5S)R#:(-/)T]3%S<DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN
M(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("+UT]"FV\[/
M(,3/Q,'.SR`G)7,G(,3/(-/)T]3%S<DN(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G
M<W1R("+UT]"FV\[/(,3/Q,'.SR`G)7,G(,3/(-/)T]3%S<DN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ
M>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+KS]+/U,O)RB#:S:;3U"(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM
M<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS
M9VED(")3=7!P;W)T(@IM<V=S='(@(K;-T,_2U"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*
M(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(N[!VM?!(,O/TLG3
MU-77P=[!(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S0*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B[L':U\$@R\_2
MR=/4U=?!WL$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@
M2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W
M87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D
M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V
M"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@
M(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD
M(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I
M9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B
M"FUS9W-T<B`B],G4U<PB"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP
M.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B],G4U<PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@
M(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P
M97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS
M9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B
M5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77P<[.T2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@
M(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T
M=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*
M;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E
M96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#$*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I
M9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF
M:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I
M9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X
M="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS
M9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM
M<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*
M;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S
M97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M"FUS9W-T<B`B]-+!T,G,P=/1(-#2S\+,Q<W!(-#2R2#$S\3!U\'.SJ8@)R5S
M)R#$SR#3R=/4Q<W)+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("+TTL'0R<S!T]$@T-+/PLS%S<$@T-+)(-?)Q,',Q<[.IB`G)7,G
M(-H@T\G3U,7-R2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(O32P=#)S,'3
MT2#0TL_"S,7-P2#0TLD@U\G$P<S%SLZF("<E<R<@VB#3R=/4Q<W)+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM
M<V=S='(@(O32P=#)S,'3T2#0TL_"S,7-P2#0TLD@Q,_$P=?!SLZF("<E<R<@
MQ,\@T\G3U,7-R2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N
M<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN
M('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T
M(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U
M-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H
M:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@
M(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE
M(@IM<V=S='(@(O3)U-7,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I
M;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(O3)U-7,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@
M*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS
M9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T
M:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE
M(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4
M;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&]G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED
M860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*
M;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U
M;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED
M(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@
M8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS
M9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"FUS9VED(")5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*
M;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@
M9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N
M92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E
M<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X
M-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y
M"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T
M.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X
M,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G
M:60@(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B\\O!T]77
MP=3)(-K-IL[)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O
M;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL
M960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G
M:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI
M;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I
M9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED
M(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G
M:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+NP=K7
MP2#+S]+)T]35U\'>P2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P
M<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92!U<V5R
M(@IM<V=S='(@(N3/Q,'4R2#+S]+)T]35U\'>P2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I
M9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-3
M3"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS
M9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@
M(N[!VM?!(,O/TLG3U-77P=[!(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E
M<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C(P,PHC+"!F=7IZ>0IM<V=I9"`B57-E<B!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$@R\_2R=/4U=?!WJ;7
M($AO<F1E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*
M(RP@9G5Z>GD*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("+ZPL72Q<?4
MR2#/T,.FIR(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S
M97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77P<[.T2#+S]+)
MT]35U\'>IM<@2&]R9&4B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS
M9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(N[!VM?!
M(,O/TLG3U-77P=[!(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM
M<V=S='(@(N[!VM?!(,O/TLG3U-77P=[!(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G
M<W1R("+NP=K7P2#+S]+)T]35U\'>P2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM
M<V=S='(@(NO/TLG3U-77P=ZF(-<@T\G3U,7-ICHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G
M:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U
M"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N
M($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI
M9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y
M"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B]=?!Q\$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED
M(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED
M(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B
M_<_4R=;.T2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L
M(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(O>FU,'`(/?!TRP@)7,B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B]Z;4P<`@]\'3+"`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R("+WIM3!P"#WP=,L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E
M<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@
M:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES
M($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I
M9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@
M(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD
M('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D
M;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y
M-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R
M:R!!9&1R97-S(@IM<V=S='(@(O+/PL_>P2#!Q-+%T\$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K
M(%!H;VYE(@IM<V=S='(@(O+/PL_>R<H@U,7,Q<;/SB(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED
M(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM
M<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(O+R(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY
M"FUS9VED(")965E9(@IM<V=S='(@(O+R(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(OW/TJ;>SL\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")9
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R
M"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@
M;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@
M8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG
M('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="XB"FUS9W-T<B`B]\D@T,_7R<[.IB#/T,G3P=3)(-#2S\+,Q<W5
M+"#0Q=+;(,ZFUB#7IL33R<S!U,D@T,_7IL3/S<S%SL[1(-#2SR#.Q:<N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM
M<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(O?!S2#3S*;$(-?+P=K!
MU,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(-?)Q,',Q<[.T2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(O?!S2#3S*;$
M(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(-?)Q,',Q<[.T2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(O?!S2#3S*;$(-?+P=K!
MU,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(-?)Q,',Q<[.T2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35U\'>
MP2#$S-$@Q,_$P=?!SL[1+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+B(*;7-G<W1R("+WP<T@T\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3
MU-77P=[!(,3,T2#$S\3!U\'.SM$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(O?!
MS2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(-?)Q,',Q<[.
MT2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+B(*;7-G<W1R("+WP<T@T\RFQ"#7R\':P=3)(,[!VM?5
M(,O/TLG3U-77P=[!(,3,T2#7R<3!S,7.SM$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(O?!V\$@P<32Q=/!(,4MT,_;U,DZ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("+WP=O!(,'$TL73P2#%+=#/
MV]3).B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM
M<V=S='(@(O?!V\4@ILTGT3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S
M+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@
M8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@
M0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R
M96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.CDV"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@
M8VAA;F=E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*
M;7-G<W1R("+OT\[/U\[!(*;0S]/4P=/8(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM
M<V=S='(@(O?!V\4@ILTGT3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HQ,#`P"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R
M('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII
M;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI
M9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EOP
MS]>FQ,_-S,7.SM$@\-+/PLS%S<E=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G
M:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R("+WR=3%TM3)(@H*(SH@;&EB+V%P:2YP
M:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](
M96QP(@IM<V=S='(@(N3/T,_-S\?!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM
M<V=S='(@(O?7ILK4R2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(O?)
MRM3)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F
M=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B
M"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@3&EN:RXN
M+B(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!L:6(O87!I+G!H<#HQ,C4*
M;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R
M.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB
M"FUS9W-T<B`BX<32Q=/.P2#+SLG'P2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PIM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR
M"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U
M>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(O3)U-7,(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED
M(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O
M9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y
M"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*
M;7-G:60@(FYA;64B"FUS9W-T<B`BMLU@T2(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G
M:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*
M(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R("+UU\''P2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V
M:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS
M9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@
M;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I
M9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC
M+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(NO/UL[/Q\\@U\C/
MQ-4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z
M,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U
M<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#$*
M;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:71?250N<&\`````````
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8W,34T
M-``Q,#4Q-30S,3`V,P`P,38T,38`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!)=&%L:6%N('1R86YS;&%T:6]N<R!F;W(@
M:&]R9&4@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#8@2&]R9&4@4')O
M:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M
M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E+@HC($%U=&]M871I8V%L
M;'D@9V5N97)A=&5D+"`R,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!H;W)D92`S+C$N,5QN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`T+3$S(#$T.C$V*S`R,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#0M,3,@,30Z,38K,#(P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A;F]`=6YI8F]C8V]N
M:2YI=#Y<;B(*(DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',]
M,CL@<&QU<F%L/2AN("$](#$I.UQN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B("@E<R!G:6]R;FD@<V-O<G-I*2(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3,X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS
M9W-T<B`B("A#:&EA=F4@9&D@86-C97-S;R`E<RDB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A
M>7,I(@IM<V=S='(@(B`H:6X@)7,@9VEO<FYI*2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&]G9VDI
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R
M;W<I(@IM<V=S='(@(B`H9&]M86YI*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AI97)I*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B!A(&$B"@HC.B!L
M:6(O5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N;VX@Z"!U
M;F$@9&ER96-T;W)Y+B(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+B(*;7-G<W1R(")<(B5S7"(@;F]N(.@@=6YA('-C96QT82!V86QI9&$N(@H*
M(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`@;&EB+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@
M(EPB)7-<(B!N;VX@Z"!C;VYF:6=U<F%T;R!N96D@4F5G:7-T<FD@9&D@2&]R
M9&4N(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S
M='(@(EPB)7-<(B!A;&)E<F\@<F5N9&5R97(@;F]N('1R;W9A=&\N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<
M(B5S7"(@Z"!S=&%T;R!A9V=I=6YT;R!A:2!G<G5P<&D@9&D@<VES=&5M82XB
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@
M<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@Z"!S=&%T;R!A9V=I=6YT;R!A:2!P
M97)M97-S:2!D:2!S:7-T96UA+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S
M7"(@;F]N(.@@<W1A=&\@8W)E871O.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@
M;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"('5S
M871I(&1I("4N,F9-0B!D:7-P;VYI8FEL:2`H)2XR9B4E*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&4@)7,B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-3DT(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C(V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@
M<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B)60@9VEO<FYI(&%L;&\@<V-A
M9&5R92!D96QL82!T=6$@<&%S<W=O<F0N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@
M9F]R96-A<W0B"FUS9W-T<B`B)60M9VEO;F\@<')E=FES:6]N92(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($YO=&EZ:6$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!&:7)M82!$:6=I=&%L92(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($]P97)A>FEO
M;FD@9&D@36%N=71E;GII;VYE("T@0V]N9F5R;6$B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@26UP;W-T
M87II;VYE(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!&:7)M
M82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@
M5&5R;6EN:2!D:2!!8V-O<F1O(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8Y,"!L
M:6(O5D93+V9T<"YP:'`Z-S8S(&QI8B]61E,O<VUB+G!H<#HT-#$*(SH@;&EB
M+U9&4R]S;6(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@9VG@(&5S:7-T96YT92XB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!A("5S("5S(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F
M;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H
M:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@Z"!P<F]N=&\@<&5R(&5S96=U:7)E
M(&QE(&]P97)A>FEO;FD@9&D@;6%N=71E;GII;VYE('-O='1O('-E;&5Z:6]N
M871E+B`B"B)396QE>FEO;F$@;&$@8V%S96QL82!P97(@;V=N:2!O<&5R87II
M;VYE*&DI(&-H92!V=6]I(&5S96=U:7)E(&]R82XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U
M:7)E9"(*;7-G<W1R("(E<R#H(')I8VAI97-T;R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B
M"FUS9W-T<B`B)7,@;6EN=71I(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C$S,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(B5S(&YO;B!T<F]V871O+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@82`E<R!D:2`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M061D<F5S<R!";V]K(@IM<V=S='(@(E)U8G)I8V$@9&D@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R:6\@9&D@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($YO=&5P860B"FUS9W-T<B`B3F]T92!D:2`E<R(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI
M<W0B"FUS9W-T<B`B3&ES=&$@071T:79I=.`@9&D@)7,B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@
M475E<W1O(&UE<W-A9V=I;R!P;W1R96)B92!N;VX@87)R:79E(&1A(&-H:2!D
M:6-H:6%R82!D:2!E<W-E<F4N("(*(D%T=&5N>FEO;F4@86D@;&EN:R!P<F5S
M96YT:2!I;B!E<W-O(&\@9F]R;FES8VD@;V=N:2!I;F9O<FUA>FEO;F4@86P@
M;6ET=&5N=&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U
M-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U
M<W1I;F<@(@IM<V=S='(@(BP@<V]F9FEA;F1O("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF
M;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L('-O9F9I
M86YD;R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H
M<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G
M<W1R("(L('9A<FEA8FEL92!D82`E<R!A("5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,C@*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T."!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,T.`IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('-E;&5Z:6]N82`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B1F]R;6%T;R`Q,B!O<F4B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA
M=&\@,C0@;W)E(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G
M:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&]R92(*"B,Z(&QI8B](;W)D92]5
M22]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\4')E
M8V5D96YT92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(E5N(&1A=&%B87-E(&1I(&)A8VME;F0@Z"!R:6-H:65S=&\@
M<&5R('%U97-T;R!B;&]C8V\N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S$*;7-G
M:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D4G(&%C
M8V%D=71O('5N(&5R<F]R92!F871A;&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E5N82!C:&EA=F4@
M<'5B8FQI8V$@4$=0(.@@<FEC:&EE<W1A('!E<B!C:69R87)E(&EL(&UE<W-A
M9V=I;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)5;F$@8VAI879A('!U8F)L:6-A
M(%!'4"#H(')I8VAI97-T82!P97(@=F5R:69I8V%R92!I;"!M97-S86=G:6\@
M9FER;6%T;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S
M<V%G92XB"FUS9W-T<B`B(@HB56YA(&-H:6%V92!P=6)B;&EC82!01U`L('5N
M82!C:&EA=F4@<')I=F%T82!01U`L(&4@=6YA('!A<W-W;W)D('-O;F\@(@HB
M<FEC:&EE<W1E('!E<B!D96-I9G)A<F4@=6X@;65S<V%G9VEO(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E5N
M82!C:&EA=F4@<'5B8FQI8V$@4$=0+"!U;F$@8VAI879E('!R:79A=&$@4$=0
M+"!E('5N82!P87-S=V]R9"!S;VYO("(*(G)I8VAI97-T92!P97(@9FER;6%R
M92!U;B!M97-S86=G:6\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5N82!C:&EA=F4@<'5B
M8FQI8V$@4R]-24U%+"!U;F$@8VAI879E('!R:79A=&$@4R]-24U%(&4@=6YA
M('!A<W-W;W)D('-O;F\@(@HB<FEC:&EE<W1E('!E<B!D96-I9G)A<F4@=6YA
M(&UE<W-A9V=I;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S
M,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B
M"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5N82!C:&EA=F4@<'5B8FQI8V$@
M4R]-24U%+"!U;F$@8VAI879E('!R:79A=&$@4R]-24U%(&4@=6YA('!A<W-W
M;W)D('-O;F\@(@HB<FEC:&EE<W1E('!E<B!F:7)M87)E('5N(&UE<W-A9V=I
M;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R(")5;F$@8VAI879E('!U8F)L:6-A(%,O34E-12#H
M(')I8VAI97-T82!P97(@8VEF<F%R92!U;B!M97-S86=G:6\N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(D%-($YU8FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*
M;7-G<W1R(")!32!0:6]G9VEA($QE9V=E<F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R(")!32!0:6]G9VEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B04T@
M06-Q=6%Z>F]N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B04T@
M3F5V:6-A=&4B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%0
M22!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(E)I9W5A
M<F1O('%U97-T;R!E9&ET;W(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B4FEG=6%R9&\N+BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS
M9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(X,@IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!
M8V-E<W-O(&YE9V%T;R!C<F5A;F1O(&QA(&1I<F5C=&]R>2!61E,N(@H*(SH@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")!8V-E<W-O(&YE9V%T;R!C<F5A
M;F1O(%9&4R!F:6QE+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS
M9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N
M:2!!8V-O=6YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED
M(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-O=W)D($%C8V]U;G0B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I
M9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(D%C8V]U;G0@8V]N9V5L871O
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C
M8V]U;G1I;F<B"FUS9W-T<B`B06-C;W5N=&EN9R(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I
M9"`B061D(@IM<V=S='(@(D%G9VEU;F=I(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'
M<F]U<"(*;7-G<W1R(")!9V=I=6YG:2!'<G5P<&\@1FEG;&EO(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")!9V=I
M=6YG:2!097)M97-S:2!&:6=L:6\B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D%G9VEU;F=I('%U
M:3HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP
M.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")!9V=I=6YG:2!.
M=6]V;R!'<G5P<&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES
M<VEO;B(*;7-G<W1R(")!9V=I=6YG:2!.=6]V;R!097)M97-S;R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S
M='(@(D%G9VEU;F=I('5N(&=R=7!P;R!F:6=L:6\@82!<(B5S7"(B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")!
M9V=I=6YG:2!U;B!P97)M97-S;R!F:6=L:6\@82!<(B5S7"(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@
M(D%G9VEU;F=I('5N(&YU;W9O('5T96YT93HB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM
M<V=S='(@(D%G9VEU;F=I(&-O;&]N;F$B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS
M9W-T<B`B06=G:75N9VD@;G5O=FD@;65M8G)I(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B06=G
M:75N9VD@;&$@8V]P<&EA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B06=G:75N9VD@:6P@)7,@365N=2!C
M;VUE('5N82!-;WII;&QA(%-I9&5B87(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K
M.B(*;7-G<W1R(")!9V=I=6YG:2!A;&QA(')U8G)I8V$Z(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY
M(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!9VEU;F=I(&%L;&$@<G5B<FEC82!P
M97)S;VYA;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S
M97(B"FUS9W-T<B`B06=G:75N9VD@=71E;G1E(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB06=G:75N=&D@
M7"(E<UPB(&%L('-I<W1E;6$L(&UA(&YO;B!S:2!P;W-S;VYO(&%G9VEU;F=E
M<F4@=6QT97)I;W)I("(*(FEN9F]R;6%Z:6]N:3H@)7,N(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")!9V=I
M=6YT;R!<(B5S7"(@86P@<VES=&5M82X@3W)A('!U;VD@86-C961E<F4N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3"=A9V=I=6YT82!D
M:2!U=&5N=&D@Z"!D:7-A8FEL:71A=&$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T-#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@
M(D%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@
M(E)U8G)I8V$B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.30@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"FUS9VED(")!
M9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*
M;7-G<W1R(")!;6UI;FES=')A=&]R92`M(&EM<&]S=&$@:2!P97)M97-S:2!P
M97(@86QT<FD@=71E;G1I(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3<*;7-G:60@(D%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%M;6EN:7-T<F%Z:6]N92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X"FUS9VED
M(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S0*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L;&EN96$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS
M9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(D%L;&EN96%M96YT;SHB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")4
M=71T:2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D
M(%5S97)S(@IM<V=S='(@(E1U='1I(&=L:2!U=&5N=&D@875T96YT:6-A=&DB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E1U='1I(&D@9W)U<'!I(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-2!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.CDQ"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B5'5T=&D@:2!P97)M97-S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I
M9&5S(@IM<V=S='(@(E1U='1I(&4@<75A='1R;R!I(&QA=&DB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D
M<F5S<V5S(@IM<V=S='(@(E1U='1I(&=L:2!I;F1I<FEZ>FD@;75L=&EP;&DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")097)M971T
M97)E(&QE(&EM<&]S=&%Z:6]N:2!D:2!L:7-T92!O<F1I;F%T92!P97(@=&EP
M;S\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@
M(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D5S:7-T92!G:>`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,
M;V=I;B(*;7-G<W1R("),;V=I;B!)35-0(&%L=&5R;F%T:79A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@
M4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O<F0@24U34"!A;'1E<FYA=&EV82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T
M92!)35-0(%5S97)N86UE(@IM<V=S='(@(E5T96YT92!)35!3(&%L=&5R;F%T
M:79O(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@
M(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!E
M;6%I;"!A;'1E<FYA=&EV;R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R
M"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(DUA<V-H97)E
M(&%L=&5R;F%T:79E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B5&5S=&\@86QT97)N871I=F\Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-PIM<V=I9"`B06UE<FEC
M86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")%)R!S=&%T;R!S
M<&5C:69I8V%T;R!U;B!V86QO<F4@;F]N('9A;&ED;RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R
M<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")%<G)O<F4@<V-O;F]S8VEU=&\N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-@IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T"FUS9VED(")!;F=O;&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,`IM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*
M;7-G:60@(D%N<W=E<B(*;7-G<W1R(")2:7-P;W-T82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4*;7-G:60@(D%N=&%R
M8W1I8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.0IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,S8@861M:6XO=&5M
M<&QA=&5S+G!H<#HW-"!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI
M8V%T:6]N(@IM<V=S='(@(D%P<&QI8V%Z:6]N92(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R
M("),:7-T82!!<'!L:6-A>FEO;FDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B
M3"=A<'!L:6-A>FEO;F4@Z"!P<F]N=&$N(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*
M;7-G<W1R(")!<'!L:6-A(&%I(&9I9VQI(&-O;F1I=FES:2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E
M(@IM<V=S='(@(D%P<')O=F$B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#0R"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(D1I
M;65N<VEO;F4@07!P<F]S<VEM871I=F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B07!R:6QE(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW
M.`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@IM<V=I9"`B
M07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B1&EM96YS:6]N92!F:6QE(&EN
M(&%R8VAI=FEO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*;7-G:60@(D%R8VAI=F4@3F%M
M92(*;7-G<W1R(").;VUE($%R8VAI=FEO(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")396D@<VEC=7)O(&1I('9O;&5R
M(')I;75O=F5R92!L92!R:6-H:65S=&4@9FER;6%T92!P97(@)7,@/R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B07-E:2!S:6-U
M<F\@9&D@=F]L97(@96QI;6EN87)E(%PB)7-<(B!E(&]G;FD@<V]T=&\M9W)U
M<'!O/R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C8*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!<FUE
M;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS
M9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P"FUS
M9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@
M(B(*(E)I8VAI961E<F4@;&$@8V]N9F5R;6$@<')I;6$@9&D@97-E9W5I<F4@
M;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4_(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,P.34*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G
M<W1R(")!<W-E9VYA;65N=&\@8V]L;VYN92(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+B(*;7-G<W1R(")3:2#H(&-E<F-A=&\@9&D@96QI;6EN87)E('5N
M(&=R=7!P;R!N;VX@97-I<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E-I(.@@8V5R8V%T;R!D:2!E;&EM
M:6YA<F4@=6X@<&5R;65S<V\@;F]N(&5S:7-T96YT92XB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E-I(.@@8V5R8V%T;R!D
M:2!P=6)B;&EC87)E('5N('!E<FUE<W-O(&YO;B!E<VES=&5N=&4N(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E-I(.@@8V5R
M8V%T;R!D:2!P=6)B;&EC87)E('5N82!C;VYD:79I<VEO;F4@;F]N(&5S:7-T
M96YT92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-"!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PHC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW,0IM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R(")!='1R:6)U=&DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%G;W-T;R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD*;7-G:60@(D%U
M<W1R86QI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(X"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7V-Y<G-Q;#H@97-T96YS:6]N92!I;6%P(')I8VAI97-T
M82!N;VX@=')O=F%T82XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z
M,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@
M<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z(&EL
M(&)A8VME;F0@;F]N(&AA(&QE(&-A<&%C:73@(')I8VAI97-T92XB"@HC.B!L
M:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?8WER=7,Z(&5S=&5N<VEO;F4@:6UA<"!R:6-H:65S=&$@;F]N('1R
M;W9A=&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B
M(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H
M+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@17-T96YS:6]N92!&5%`@<FEC:&EE
M<W1A(&YO;B!T<F]V871A+B!#;VUP:6QA(%!(4"!C;VX@;"=O<'II;VYE("TM
M(@HB96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV
M-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@($5S=&5N<VEO;F4@24U!
M4"!R:6-H:65S=&$@;F]N('1R;W9A=&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z($5S=&5N
M<VEO;F4@:W)B-2!R:6-H:65S=&$@;F]N('1R;W9A=&$N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M(@IM<V=S='(@(D%U=&A?;&1A<#H@;"=A9V=I=6YT82!D:2!U=&5N=&D@;F]N
M(.@@<W5P<&]R=&%T82!P97(@06-T:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO
M=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@;&$@8V%N8V5L;&%Z:6]N92!D
M:2!U=&5N=&D@;F]N(.@@<W5P<&]R=&%T82!P97(@06-T:79E($1I<F5C=&]R
M>2(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]L9&%P.B!%<W1E;G-I;VYE($Q$05`@<FEC:&EE<W1A(&YO
M;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*(D%U=&A?;&1A<#H@26UP;W-S:6)I;&4@86=G:75N9V5R92!L)W5T
M96YT92`E<RX@475E<W1A(.@@;&$@<FES<&]S=&$@9&5L("(*(G-E<G9E<CHB
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B
M"FUS9W-T<B`B075T:%]L9&%P.B!);7!O<W-I8FEL92!C86YC96QL87)E(&PG
M=71E;G1E("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@26UP;W-S:6)I;&4@86=G
M:6]R;F%R92!L)W5T96YT92`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B
M"B)!=71H7VQD87`Z(&PG86=G:6]R;F%M96YT;R!D96=L:2!U=&5N=&D@;F]N
M(.@@<W5P<&]R=&%T;R!P97(@06-T:79E("(*(D1I<F5C=&]R>2XB"@HC.B!L
M:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;#H@97-T96YS:6]N92!-0T%,(')I8VAI97-T82!N;VX@=')O=F%T
M82XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H
M7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!E<W1E;G-I;VYE('-M8F%U=&@@
M<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D92])34%0+T%D
M;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B3"=A=71E;G1I8V%Z:6]N92!A;"!S97)V
M97(@24U!4"#H(&9A;&QI=&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*
M;7-G<W1R(")!=71E;G1I8V%Z:6]N92!F86QL:71A(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B075T96YT:6-A>FEO;F4@9F%L
M;&ET82X@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BXB"FUS9W-T<B`B075T96YT:6-A>FEO;F4@<FEF:75T871A(&1A;"!S97)V
M97(@4D%$2553+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX.34*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!
M=71E;G1I8V%Z:6]N92!A;"!S97)V97(@1E10(&9A;&QI=&$N(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@
M4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&EC87II;VYE(&%L
M('-E<G9E<B!334(@9F%L;&ET82XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#
M86UP:2!D:7-P;VYI8FEL:3HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%
M>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS
M9W-T<B`B4V9O;F1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R
M(")#;VQO<F4@<V9O;F1O(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B4&%S
M<W=O<F0@:V5R8F5R;W,@;F]N('9A;&ED82XB"@HC.B!L:6(O2&]R9&4O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R(")5=&5N=&4@:V5R8F5R;W,@;F]N('9A;&ED;RXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U"FUS9VED(")"
M86AA;6%S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H25-/
M+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS,PIM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D1I
M<F5C=&]R>2!G<F%F:6-A(&1I(&)A<V4@7"(E<UPB(&YO;B!T<F]V871A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ.0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,U"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`*;7-G:60@
M(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0P"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Q"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8*;7-G:60@(D)H=71A;B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM
M<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B0V]M<&QE86YN;R(*"B,Z(&QI8B](
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D)L;V-C;R!<(B5S7"(@9&5L;"=A<'!L:6-A>FEO
M;F4@7"(E<UPB(&YO;B!T<F]V871O+B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M26UP;W-T87II;VYI($)L;V-C;R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4:7!O($)L
M;V-C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")'<F%S<V5T=&\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")396=N86QI8G)I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(D)O<F1O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R
M9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4W!E<W-O<F4@9&5L(&)O<F1O.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0F]R9&DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R"FUS9VED(")"
M;W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI82!E($AE<GIE
M9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")"
M;W1H(@IM<V=S='(@(D5N=')A;6)E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(R"FUS9VED(")";W1T;VTB"FUS9W-T<B`B0F%S<V\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0*;7-G:60@(D)R87II;"(*;7-G
M<W1R(")"<F%S:6QE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,3<*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,W"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(D5L96YC;R!P=6YT871O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-@IM<V=I9"`B
M0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD*;7-G:60@(D)U<G5N9&DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B
M0TU3(@IM<V=S='(@(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(E!U;G1I($1I<W1R:6)U>FEO;F4@0U),(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R
M;W!R:65TX"!#7V5L;&4N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D
M+B(*;7-G<W1R("),82!C86-H92!I;FEZ:6%L92!N;VX@Z"!S=&%T82!C;VUP
M;&5T871A+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$V(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P-#`@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM
M<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T
M<B`B0V%L;6\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R.`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B0V%M8F]G:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P
M"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C(S,B!L:6(O5D93+V9T<"YP:'`Z-C<V(&QI8B]61E,O<VUB+G!H<#HT
M,S4*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`S"FUS9VED(")#86X@;F]T
M(&-O<'D@9FEL92AS*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H
M92!S86UE+B(*;7-G<W1R("(B"B));7!O<W-I8FEL92!C;W!I87)E(&9I;&4H
M<RD@+2!L82!S;W)G96YT92!E(&QA(&1E<W1I;F%Z:6]N92!S;VYO('5G=6%L
M:2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,B!L:6(O5D93+V9T<"YP:'`Z
M-S4R(&QI8B]61E,O<VUB+G!H<#HU,#$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,38X"FUS9VED(")#86X@;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T
M:6]N(&ES('=I=&AI;B!S;W5R8V4N(@IM<V=S='(@(B(*(DEM<&]S<VEB:6QE
M('-P;W-T87)E(&EL(&9I;&4H<RD@+2!L82!D97-T:6YA>FEO;F4@Z"!A;&PG
M:6YT97)N;R!D96QL82`B"B)S;W)G96YT92XB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@<F5I;7!O<W1A<F4@;&$@<&%S<W=O
M<F0@875T;VUA=&EC86UE;G1E+"!C;VYT871T82`B"B)L)V%M;6EN:7-T<F%T
M;W)E+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B
M26UP;W-S:6)I;&4@<V-I=F5R92!N96P@9FEL92!<(B5S7"(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@
M9V5S=&ER92!S97-S:6]N:2!E<W1E<FYE+B(*"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,S$Y(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]L;&5G87)S:2!A;"!S
M97)V97(@24U!4#H@)7,B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("));7!O<W-I8FEL92!A<')I<F4@:6P@9FEL92!<(B5S7"(N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,0IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A
M9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,0IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(D-A;F-E;&QA(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R(")#86YC96QL82!I;"!297!O<G0@<')O8FQE;6$B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D
M96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI
M;F%R92!I;"!F:6QE(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*;7-G:60@(D-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP
M;W-S:6)I;&4@=')O=F%R92!U;F$@9&ER96-T;W)Y('1E;7!O<F%N96$N(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O
M8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE('!R;V-E9&5R92!S96YZ82!I;"!P87)A;65T<F\@)W1A
M<F=E=$9I;&4G+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("));7!O<W-I8FEL92!R:6UU;W9E<F4@;&$@9&ER96-T;W)Y("!<
M(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!R:6UU;W9E<F4L(&5S:7-T;VYO("5D(&9I9VQI+B(*"B,Z
M(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N
M;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R
M96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S
M='(@(B(*(DEM<&]S<VEB:6QE(')I;W)D:6YA<F4L(&PG96QE;F-O(&9O<FYI
M=&\@;F]N(&-O<G)I<W!O;F1E(&-O;B!L)V5L96YC;R`B"B)M96UO<FEZ>F%T
M;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM
M<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@:6YS=')A9&%R92!I;"!M97-S86=G
M:6\@86P@;G5M97)O('-P96-I9FEC871O+B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4*;7-G:60@(D-A<&4@5F5R9&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R(")#87)R:65R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@
M(D-A=&5G;W)I92!E($5T:6-H971T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U"FUS9VED(")#87EM86X@27-L86YD
M<R(*;7-G<W1R("))<V]L92!#87EM86XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R
M(")#96QL=6QA<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<')I973@($-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B4FEE;7!I;65N=&\@8V5L;&4Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L
M;"!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65TX"!C96QL92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED
M(")#96QL('-P86-I;F<Z(@IM<V=S='(@(E-P87II;R!C96QL93HB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S
M='(@(D-E;&QU;&%R92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS
M9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS
M9VED(")#96YT97(B"FUS9W-T<B`B0V5N=')O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-`IM<V=I9"`B0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*2(*;7-G<W1R(")%=7)O<&$@0V5T<F%L92`H25-/+3@X-3DM,BDB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")$971T86=L:2!D96P@0V5R=&EF:6-A=&\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R
M=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B4')O<')I971A<FEO(&1E;"!#97)T
M:69I8V%T;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS
M9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")0;VQI=&EC:&4@
M9&5L($-E<G1I9FEC871O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(Q"FUS9VED(")#:&%D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")#86UB
M:6$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D-A;6)I82!L82!T=6$@
M4&%S<W=O<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"B)#86UB:6$@:6P@;F]M92!E(&PG:6YD:7)I>GIO(&-H
M92!L92!P97)S;VYE('9E9&]N;R!Q=6%N9&\@;&5G9V]N;R!E("(*(G)I<W!O
M;F1O;F\@86QL92!T=64@96UA:6PN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D
M(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T
M:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(B(*(DEL(&-A;6)I;R!D96QL82!T=6$@<&%S<W=O<F0@;F]N(.@@<W5P<&]R
M=&%T;R!C;VX@;&$@8V]N9FEG=7)A>FEO;F4@(@HB8V]R<F5N=&4N("!#;VYT
M871T82!L)V%M;6EN:7-T<F%T;W)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS
M9W-T<B`B0V%R8F]N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB
M"FUS9W-T<B`B0VAE8U]K($QI;FLN+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y"FUS9VED(")#:&EL92(*;7-G<W1R
M(")#:6QE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B0VEN82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S
M92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B4V-E9VQI(&PG87!P;&EC87II;VYE
M.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#
M:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")38V5G;&D@=6YA('!A<W-W;W)D
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H
M;V]S92!A('5S97)N86UE(@IM<V=S='(@(E-C96=L:2!U;B!N;VUE('5T96YT
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B4V-E9VQI(&-O;64@
M=FES=6%L:7IZ87)E(&QA(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@
M(E-C96=L:2!I;"!T:7!O(&1I('-T:6QE(&1E;&QA(&QI<W1A("AP97(@;&ES
M=&4@;W)D:6YA=&4I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-@IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O5D93+G!H<#HY,30@;&EB+TYE="]335,N<&AP.C(Y-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"XB"FUS9W-T<B`B3&$@9&5F:6YI>FEO;F4@9&D@8VQA<W-E(&1I
M("5S(&YO;B#H('-T871A('1R;W9A=&$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@
M(D-H:6%R;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E
M<GDB"FUS9W-T<B`B06YN=6QL82!$;VUA;F1A(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M87(@;W5T('5S97(Z("5S(@IM<V=S='(@(D5L:6UI;F$@;"=U=&5N=&4Z("5S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED
M(")#;&5A<B!U<V5R(@IM<V=S='(@(D5L:6UI;F$@=71E;G1E(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S
M97(@9&%T82(*;7-G<W1R(")%;&EM:6YA(&EN9F]R;6%Z:6]N:2!U=&5N=&4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM
M<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")%;&EM:6YA<F4@1&]P;R`B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV
M,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B0VQI8VL@<&5R
M($-O;G1I;G5A<F4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")#
M:&EU9&D@1FEN97-T<F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM
M<V=I9"`B0VQO=61S(@IM<V=S='(@(DYU8FDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY
M(@IM<V=S='(@(DYU8FD@<')E<W1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(").
M=79O;&]S;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3(*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G
M:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B0VAI=61I(%-I9&5B87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")#:&EU
M9&D@:2!B;W)D:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-C(*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")#;VQO<F4B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S(&QI8B](;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,S@*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,S.2!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B36%P<&$@0V]L;W)I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C@*;7-G:60@(D-O;&]U<B!S
M96QE8W1I;VXB"FUS9W-T<B`B4V5L97II;VYE(&-O;&]R:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#
M;VQS.B(*;7-G<W1R(")#;VQO;FYE.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(E1I=&]L;R!C
M;VQO;FYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I
M9"`B0V]M:6-S(@IM<V=S='(@(D-O;6EC:&4B"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C8*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M86YD;R(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*
M;7-G<W1R("),:6YE82!D:2!C;VUA;F1O(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;6UE;G1O
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O
M;6UO;B!.86UE(@IM<V=S='(@(DYO;64@0V]M=6YE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`*;7-G:60@(D-O;6]R
M;W,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B07II96YD82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM
M<V=S='(@(D-O;7!U=&5R<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")#;VYD:7II;VYE
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-O;F1I=&EO
M;G,B"FUS9W-T<B`B0V]N9&EZ:6]N:2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(D1I9F9E<F5N>F4@;F5L;&$@8V]N9FEG=7)A>FEO;F4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O
M<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN
M(@IM<V=S='(@(B(*(D-O;F9I9W5R87II;VYE('!E<B!L82!S:6YC<F]N:7IZ
M87II;VYE(&-O;B!01$%S+"!3;6%R='!H;VYE<R!E($]U=&QO;VLN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B3&$@8V]N9FEG=7)A>FEO;F4@
MZ"!V96-C:&EA+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(D-O;F9I
M9W5R82`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0V]N9F5R;6$@
M;&$@4&%S<W=O<F0B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4U"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960N(@IM<V=S='(@(D-O;&QE9V%M96YT;R!F86QL:71O+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960Z("(*;7-G<W1R(")#;VQL96=A;65N=&\@9F%L;&ET;SH@(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(D-O;FYE<W-I;VYE(&%L(&ME>7-E<G9E<B!O=6)B;&EC;R!R:69I=71A=&$N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D-O;FYE<W-I;VYE
M(&%L(&ME>7-E<G9E<B!P=6)B;&EC;R!R:69I=71A=&$N($UO=&EV;SH@)7,@
M*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX.#D*;7-G:60@(D-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D-O;FYE<W-I;VYE
M(&%L('-E<G9E<B!&5%`@9F%L;&ET82XB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDR-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N
M=&%C=',B"FUS9W-T<B`B0V]N=&%T=&DB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M22!C;VYT871T:2!S;VYO('-T871I(&%G9VEU;G1I(&-O;B!S=6-C97-S;R!A
M;&QA('1U82!R=6)R:6-A+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F
M:6QE.B`B"FUS9W-T<B`B5&EP;R!D:2!C;VYT96YU=&\@9&5L(&9I;&4@8V]M
M<')E<W-O.B`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU
M-B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B0V]N=&5N=71I(&1I(%PB
M)7-<(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,R!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN=64B"FUS
M9W-T<B`B0V]N=&EN=6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4X"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EA
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0X,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B0V]P:6$@9F%L;&ET83H@)7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V
M"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")#;W!I82!S96QE>FEO
M;F4B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3<P(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W"FUS9VED(")#;W1E(&0G
M279O:7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*
M;7-G<W1R(").;VX@<VD@<'7R(&-I9G)A<F4@:6X@4$=0(&EL(&UE<W-A9V=I
M;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B3F]N('-I('!U
M\B!F:7)M87)E(&EN(%!'4"!I;"!M97-S86=G:6\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYO;B!S:2!P=?(@8W)I9G)A<F4@
M:6X@4R]-24U%(&EL(&UE<W-A9V=I;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92XB"FUS9W-T<B`B3F]N('-I('!U\B!F:7)M87)E(&EN(%,O34E-12!I
M;"!M97-S86=G:6\B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B3F]N('-I('!U\B!A9V=I=6YG97)E(&EL(&-O
M;G1A='1O+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT.#(@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.CDV"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DYO;B!S:2!P=?(@:6YT97)R;V=A<F4@:6P@<V5R=F5R
M($Q$05`N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M-S,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`B3F]N('-I('!U\B!V97)I9FEC87)E(&PG97%U:6QI8G)I;RX@)7,B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8V"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B26UP;W-S:6)I
M;&4@8V]L;&5G87)S:2!A;"!S97)V97(@3$1!4"XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&-O;&QE9V%R<VD@86P@<V5R=F5R(%PB)7-<(B!U
M<V%N9&\@1E10.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@
M8W)E87)E('5N82!L:7-T82!D:2!D:7-T<FEB=7II;VYE+B`E<R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B26UP;W-S:6)I;&4@9&5C:69R
M87)E(&EL(&1A=&\@:6X@9F]R;6%T;R!01U`Z("(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82XB"FUS9W-T<B`B26UP;W-S:6)I;&4@9&5C:69R87)E(&EL
M(&1A=&\@:6X@9F]R;6%T;R!3+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&5L:6UI;F%R92!I;"!C;VYT871T;RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!L92!L:7-T82!D:2!D:7-T<FEB=7II
M;VYE+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"B));7!O<VEB:6QE(&5L:6UI
M;F%R92!L;R!S8W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96QL)VEM<&]S=&%Z
M:6]N92!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34S
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S@Q"FUS9VED(")#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@9&5T97)M:6YA<F4@9VQI(&EN9&ER:7IZ
M:2!E;6%I;"!D96D@9&5S=&EN871A<FDN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B:4EM<&]S<VEB:6QE('-C
M87)I8V%R92!I;B!M;V1O(&-O;7!L971O(&QA(')U8G)I8V$N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("));7!O<W-I8FEL92!S8V%R:6-A<F4@:6X@;6]D;R!C;VUP;&5T;R!L82!L
M:7-T82!D:2!D:7-T<FEB=7II;VYE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@
M8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@
M(B(*(DEM<&]S<VEB:6QE('-C87)I8V%R92!I;B!M;V1O(&-O;7!L971O(&QA
M(&QI<W1A(&1E;&QE(&QI<W1E(&1I(&1I<W1R:6)U>FEO;F4N(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E
M<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!C87)I8V%R92!L82!S=')A=&5G
M:6$@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I
M8FEL92!C<F5A<F4@;&$@9&ER96-T;W)Y(%PB)7-<(BXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DEM<&]S
M<VEB:6QE(&]T=&5N97)E(&QA(&-H:6%V92!P=6)B;&EC82!D86P@<V5R=F5R
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%P
M<FER92!<(B5S7"(@<&5R(&QA(')I<V-R:71T=7)A+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S<*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E("5S+B(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&%P<FER92!I;"!M;V1U;&\@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&%P<FER92!L82!D:7)E8W1O<GD@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C,W(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]N=&%T=&%R92!I;"!S97)V97(@3$1!
M4"XB"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("));7!O<W-I8FEL
M92!L96=G97)E("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D
M971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@87IZ97)A<F4@;&$@<&%S<W=O
M<F0@<&5R(&PG=71E;G1E(')I8VAI97-T;RX@06QC=6YI(&\@='5T=&D@:2`B
M"B)D971T86=L:2!N;VX@<V]N;R!C;W)R971T:2X@4FEP<F]V82!A;F-O<F$@
M;R!C;VYT871T82!L)V%M;6EN:7-T<F%T;W)E('-E("(*(FYE8V5S<VET:2!D
M:2!U;'1E<FEO<F4@86EU=&\N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S,X"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,(@IM<V=S='(@(DEM<&]S<VEB:6QE(')E8W5P97)A<F4@04-,
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!R96-U<&5R87)E(&QA(')U
M8G)I8V$N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE(')E
M8W5P97)A<F4@;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@)7,B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M=',N("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE(')E8W5P97)A<F4@;&4@;&ES
M=&4@9&D@9&ES=')I8G5Z:6]N92X@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DW(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<R(*;7-G<W1R("));7!O<W-I8FEL92!R96-U<&5R87)E(&QE('!O<W-I
M8FEL:73@(&1E;"!S97)V97(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(DEM<&]S<VEB:6QE(&EN=F5R=&ER92!L82!C;VYF:6=U<F%Z:6]N
M92XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD
M:7(@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!C86YC96QL87)E(&QA
M(&1I<F5C=&]R>2!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V%L=F%R92!L
M82!C;VYF:6=U<F%Z:6]N92!D:2`E<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P:6$@9&5L;&$@8V]N9FEG=7)A
M>FEO;F4N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@<V%L=F%R92!U;F$@8V]P
M:6$@9&5L;&$@8V]N9FEG=7)A>FEO;F4Z("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B(@HB26UP;W-S:6)I;&4@<V%L=F%R92!L;R!S8W)I<'0@9&D@86=G:6]R
M;F%M96YT;R!D96QL92!I;7!O<W1A>FEO;FD@<W4Z(%PB)7-<(BXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R("));7!O<W-I8FEL92!S86QV87)E(&EL(&9I;&4@9&D@
M<V%L=F%T86=G:6\@9&5L;&$@8V]N9FEG=7)A>FEO;F4@9&D@)7,N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B));7!O<W-I8FEL92!S
M86QV87)E(&EL(&9I;&4@9&D@8V]N9FEG=7)A>FEO;F4@9&D@)7,N(%!U;VD@
M=7-A<F4@;F$@9&5L;&4@(@HB;W!Z:6]N:2!P97(@<V%L=F%R92!I;"!C;V1I
M8V4@<W4@)7,@;R!C;W!I87)E(&UA;G5A;&UE;G1E(&EL(&-O9&EC92!S;W1T
M;R!S=2`B"B(E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-#,*
M;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("));7!O<W-I8FEL92!F87)E('5N82!R=6-E<F-A(&YE;"!S97)V97(@
M3$1!4"XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&%G9VEO<FYA<F4@:6P@8V]N=&%T=&\N("5S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("));7!O<W-I8FEL92!A9V=I;W)N87)E(&QA(&QI<W1A(&1I(&1I<W1R:6)U
M>FEO;F4N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N
M(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE('-C<FEV97)E
M(&QA(&-O;F9I9W5R87II;VYE('!E<B!<(B5S7"(Z("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@=')O=F%R92!L82!3:61E8F%R(&1I
M($UO>FEL;&$N($%S<VEC=7)A=&D@8VAE('-I82!A<&5R=&$N(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@HB26UP;W-S:6)I;&4@9&%R92!A;&PG=71E;G1E(%PB)7-<(B!I('-E
M9W5E;G1I(&1I<FET=&D@<&5R(&QA(&-A<G1E;&QA(%PB)7,B"B)<(CH@)7,B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T
M97AT(@IM<V=S='(@(E1E<W1O(&-O;G1A=&\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(").87II
M;VYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B
M0V]U<G-E<R(*;7-G<W1R(")#;W)S:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(D-R96$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B0W)E82!U;B!L:6YK(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N
M92(*;7-G<W1R(")#<F5A('5N;R!N=6]V;R(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")#
M<F5A<F4@<V]T=&\@8V%R=&5L;&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")#
M<F5A=&]R92!D:2!P97)M97-S:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C$R"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B3G5M97)O
M(&-A<G1A(&1I(&-R961I=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T
M"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")#;W)R96YT
M92`T($9A<VDB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U
M<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B4V5S<VEO;FD@8V]R<F5N=&DB"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*
M;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")496UP;R!!='1U86QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("),82!54DP@
M871T=6%L92#H(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#
M=7)R96YT(%5S97)S(@IM<V=S='(@(E5T96YT:2!!='1U86QI(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM
M<V=S='(@(E1E;7!O($%T='5A;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S
M='(@(D-O;F1I>FEO;F4@8V]R<F5N=&4Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y
M;&4B"FUS9W-T<B`B4W1I;&4@8V]R<F5N=&4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T
M87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B4&5R<V]N
M86QI>GIA(&QE(&]P97)A>FEO;FD@9&$@97-E9W5I<F4@86QL)V%V=FEO(&1I
M("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B5&%G;&EA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I
M9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")486=L:6$@;&$@<V5L97II;VYE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M-PIM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-I<')O(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX
M+54I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C@*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<R"FUS9VED("(B"B)$4TX@*'-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D=I
M;W)N86QM96YT92(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B
M1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S(W,`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,SDX(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I
M9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")$871A(%)I8V5V=71A(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(W.#D*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(E-E;&5Z:6]N82!L82!D871A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B1VEO<FYO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS
M9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")%7VQI;6EN82!#;VQO;FYA
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,R!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E
M8V5M8F5R(@IM<V=S='(@(D1I8V5M8G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C
M:6UA;"!N=6UB97)S(@IM<V=S='(@(DYU;65R:2!D96-I;6%L:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@
M(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")$:6UI;G5I<V-I(&QA(')I96YT
M<F%N>F$B"@HC.B!L:6(O<')E9G,N<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B
M1&5F875L="!#;VQO<B(*;7-G<W1R(")#;VQO<F4@<W1A;F1A<F0B"@HC.B!L
M:6(O2&]R9&4O261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT
M:71Y(@IM<V=S='(@(DED96YT:73@(&1I(&1E9F%U;'0B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T
M<B`B4VAE;&P@9&D@9&5F875L="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6YI>FEO;FDB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(V(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-#,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"FUS9VED(")$96QE=&4B"FUS9W-T
M<B`B16QI;6EN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T
M<B`B16QI;6EN82!#96QL82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T
M<B`B16QI;6EN82!'<G5P<&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B16QI;6EN82!,
M;V<B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<W(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G
M<W1R(")%;&EM:6YA(%!E<FUE<W-O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S(@IM<V=S='(@(D5L:6UI;F%R92!E('-V=6]T87)E(&D@;65S86=G:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(D5L:6UI;F$@8V5L
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(D5L:6UI
M;F$@8V]L;VYN82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(D5L:6UI;F$@;&$@;6%S8VAE<F$@86QT97)N871I=F$@97-I<W1E;G1E(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4T"FUS9VED(")$
M96QE=&4@;65S<V%G97,B"FUS9W-T<B`B16QI;6EN82!I(&UE<W-A9V=I(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B
M16QI;6EN82!I('!E<FUE<W-I('!E<B!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\B"FUS9W-T<B`B16QI;6EN82!I('!E<FUE<W-I('!E<B!<(B5S7"(@92!O
M9VYI('-O='1O+7!E<FUE<W-O/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B
M"FUS9W-T<B`B16QI;6EN82!R:6=A(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E
M;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y(@IM<V=S='(@(D5L:6UI;F$@;"=I9&5N=&ETX"!S96QE>FEO;F%T
M82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I
M9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(D5L:6UI;F$@;&4@<V]T
M=&\@8V%R=&5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6XB"FUS9W-T<B`B16QI;6EN82!L82!C;VQO;FYA(&-O<G)E;G1E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S
M='(@(D5L:6UI;F$@;&$@<FEG82!C;W)R96YT92(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")%;&EM:6YA
M(&QO('-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM<&]S=&%Z:6]N
M:2!D:2!<(B5S7"(N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"FUS9VED(")$96QI=F5R>2!T
M:6UE(@IM<V=S='(@(E1E;7!O(&0G:6YV:6\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q"FUS9VED(")$96YM87)K(@IM
M<V=S='(@(D1A;FEM87)C82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")$97-C<FEV:2!I;"!P<F]B;&5M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I>FEO
M;F4B"@HC.B!L:6(O2&]R9&4N<&AP.C(P-@IM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971T86=L:2`H86YC
M:&4@;F5L(&9I;&4@9&D@;&]G(&1I($AO<F1E*3HB"@HC.B!L:6(O2&]R9&4N
M<&AP.C(Q,`IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B22!D971T86=L:2!S;VYO('-T
M871I('-C<FET=&D@;F5L(&9I;&4@9&D@;&]G('!E<B!L)V%M;6EN:7-T<F%T
M;W)E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@
M(D1E=F5L;W!M96YT(@IM<V=S='(@(E-V:6QU<'!O(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")0=6YT
M;R!D:2!R=6=I861A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G
M:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4'5N=&\@
M9&D@<G5G:6%D82!P97(@;"=U;'1I;6$@;W)A.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G
M<W1R(")0=6YT;R!D:2!R=6=I861A.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R(")$:7)E>FEO;F4@9&$@<VEN:7-T<F$@82!D
M97-T<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R
M(")$:7)E>FEO;F4@9&$@9&5S=')A(&$@<VEN:7-T<F$B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B5FES=6%L:7IZ82!I;"!T96UP;R!N
M96P@9F]R;6%T;R`R-"!O<F4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P>FEO;FD@
M9&D@=FES=6%L:7IZ87II;VYE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(E9I<W5A;&EZ>F$@<')E=FES:6]N92!D971T86=L:6%T82(*"B,Z
M(&QI8B]B;&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(F1I<W!L87D@9F]R96-A
M<W0@*'1A9BDB"FUS9W-T<B`B=FES=6%L:7IZ82!P<F5V:7-I;VYE("AT868I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3D*;7-G:60@(D1I<W!L87D@
M9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&D@=FES=6%L:7IZ87II;VYE(@H*
M(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R(").;W1I9FEC82!D:2!D:7-P;W-I
M>FEO;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<P"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R(").;VX@96QI;6EN87)E(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R(").;VX@86-C961E<F4@9&ER971T86UE;G1E(&UA
M:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$R('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*(DQA<')I;6$@<FEG82!C
M;VYT:65N92!I;"!C86UP;R!D96D@;F]M:3\@4V4@<VDL('-E;&5Z:6]N82!Q
M=65S=&$@8V%S96QL83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<R"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S"FUS
M9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R(").;VX@:&%I('5N)W5T96YZ83\@
M:7-C<FEV:71I+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M-3,*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E-C87)I8V$B"@HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E-C87)I8V$@)7,B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38Q"FUS9VED(")$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("),82!C
M;VYF:6=U<F%Z:6]N92!G96YE<F%T82#H('-T871A('-C87)I8V%T82!C;VUE
M('-C<FEP="!02%`N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,#<*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9VAE(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY
M,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R
M<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4*;7-G:60@(D5C=6%D;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S
M='(@(E!U8F)L:6-A(@H*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,`IM
M<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")6:7-U86QI>GIA(&)L;V-C;R(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V
M"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(E9I<W5A;&EZ>F$@1W)U<'!O
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@
M(E9I<W5A;&EZ>F$@4&5R;65S<V\B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E9I
M<W5A;&EZ>F$@4&5R;65S<VDB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(E9I<W5A;&EZ>F$@4&5R;65S<VD@<&5R("5S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I
M;VYS(&9O<CHB"FUS9W-T<B`B5FES=6%L:7IZ82!L92!O<'II;VYI('!E<CHB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B
M5FES=6%L:7IZ82!I('!E<FUE<VD@<&5R(%PB)7-<(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B5FES=6%L:7IZ82!I('!E
M<FUE<W-I('!E<B`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM
M<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<*;7-G:60@(D5G>7!T(@IM<V=S
M='(@(D5G:71T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G1O+BXN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#8Y(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS
M9VED(")%;6%I;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*;7-G:60@
M(D5M86EL($%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO($5M86EL(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R("),)VEN9&ER:7IZ;R!%;6%I;"!D979E
M(&-O<G)I<W!O;F1E<F4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.#D*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D5M86EL
M(&-O;B!C;VYF97)M82(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR.3D*;7-G
M:60@(D5M;W1I8V]N<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS
M9W-T<B`B365S<V%G9VEO('9U;W1O+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HR-#,@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C8R(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HW,#4*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,34P"FUS
M9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E)I<W5L=&%T;R!V=6]T;RXB
M"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M
M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")2:6-E<F-A(&1E:2!T97)M:6YI
M('9U;W1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B(@HB06)I;&ET82!L)VEN<V5R:6UE;G1O
M(&1I(&EM;6%G:6YI(&YE;"!T97-T;R!D86QL82!'86QL97)I82!D96QL92!&
M;W1O9W)A9FEE/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(D%B:6QI=&%R92!I;"!M96YU(&1I(&-O;G1E<W1O(&-L:6-C86YD;R!I;"!T
M87-T;R!D97-T<F\@9&5L(&UO=7-E/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-3@X(&QI8B](;W)D92]&;W)M+G!H<#HR-SDS"FUS9VED(")%;F0@>65A
M<B(*;7-G<W1R(")&:6YE(&%N;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*
M;7-G<W1R("));F=R861I<V-I(&PG961I=&]R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(DEN<V5R:7-C:2!U;F$@9&]M
M86YD82!S:6-U<F$@8VAE('1I('9E<G+@(&-H:65S=&$@<V4@879R86D@;F5C
M97-S:73@(&1I("(*(F%Z>F5R87)E(&QA('1U82!P87-S=V]R9"P@97,@)W%U
M86PGZ"!I;"!N;VUE(&1E;"!T=6\@8W5C8VEO;&\_)SHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("));G-E
M<FES8VD@;"=54DP@9&5L;"=I;6UA9VEN92!Q=6DB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B26YS97)I<V-I(&QE(&QE='1E<F4@
M<V]T=&\@<FEP;W)T871E.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3D*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#@*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(W"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`Z.30*
M;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F]R92(*"B,Z(&QI8B](;W)D92]4
M96UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R
M96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")%<G)O<F4@8W)E86YD;R!I;"!B
M;&]C8V\Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H
M;W(Z("5S(@IM<V=S='(@(D5R<F]R92!E;&EM:6YA;F1O(&PG86YC;W)A(&1I
M('-I;F-R;VYI83H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,B"FUS9W-T<B`B17)R;W)E(&5L:6UI;F%N9&\@:6P@;&]G(&1I
M('-I;F-R;VYI83H@)7,B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S(@IM<V=S='(@(D5R<F]R92!O='1E;F5N9&\@:6P@8V]N=&5N=71O.B`E
M<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS
M9W-T<B`B17)R;W)E(&%G9VEO<FYA;F1O(&QA('!A<W-W;W)D.B`E<R(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%
M<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D5R<F]R92!C;VX@
M:6P@;65S<V%G9VEO(&5M86EL+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B17)R;W)E('-C
M<FEV96YD;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW-@IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q"FUS
M9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`B3V=N:2`Q-2!M:6YU=&DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS
M9W-T<B`B3V=N:2`R(&UI;G5T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@
M,S`@<V5C;VYD<R(*;7-G<W1R(")/9VYI(#,P('-E8V]N9&DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")/9VYI(#4@;6EN
M=71I(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B
M179E<GD@3&]G:6XB"FUS9W-T<B`B060@;V=N:2!A8V-E<W-O(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(D]G;FD@;65Z>B=O<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V
M97)Y(&UI;G5T92(*;7-G<W1R(")/9VYI(&UI;G5T;R(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB
M"FUS9W-T<B`B5F%L;W)I(&0G97-E;7!I;SHB"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3$@861M:6XO<&AP<VAE;&PN<&AP.C@R(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B17-E9W5I(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R(")%<W!A;F1I(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T
M<B`B17-P86YD:2!3:61E8F%R(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B4')E=FES
M=&\@)RDG(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS
M9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M(@IM<V=S='(@(FE087)O;&$@<')E=FES=&$@;R!T97)M:6YE(&-I=&%T;R!D
M:2!R:6-E<F-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS
M9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T82!D:2!S8V%D96YZ
M82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R(")%<W!O;F5N=&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#
M;VQO<B(*;7-G<W1R(")#;VQO<F4@1D<B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<V"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@
M(D%G9VEO<FYA;65N=&\@1E10(&1E;&QE(&EM<&]S=&%Z:6]N:2(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]S<6PN<&AP.C(R,`IM<V=I9"`B1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(E1E;G1A=&EV;R!F86QL:71O
M(&YE;"!R96-U<&5R;R!D96QL92!P<F5F97)E;GIE+B(*"B,Z(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HW-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY
M.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(D-O;&QE9V%M96YT;R!A;"!S97)V97(@3$1!4"!F86QL:71O+B(*
M"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(D-O;&QE9V%M96YT
M;R!A;"!S97)V97(@4TU"(&9A;&QI=&\N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C<R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M
M(%PB)7-<(BXB"FUS9W-T<B`B3F]N(.@@<FEU<V-I=&\@82!C;W!I87)E(&1A
M(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S,P"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B
M3F]N(.@@<FEU<V-I=&\@82!C;W!I87)E(&$@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E
M(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(DYO;B#H(')I=7-C:71O
M(&$@8W)E87)E('5N82!N=6]V82!C;VYN97-S:6]N92!305-,+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW-C@@;&EB+U9&4R]S;6(N<&AP.C4Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S
M='(@(DYO;B#H(')I=7-C:71O(&$@<W!O<W1A<F4@82!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DYO;B#H(')I=7-C:71O(&$@
M<F5C=7!E<F%R93H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")':75S=&\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T"FUS
M9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-@IM
M<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%<G)O
M<F4@1F%T86QE.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y
M(@IM<V=S='(@(D9E8F)R86EO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B4VEM:6QE(&$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L
M:6ME.B`B"FUS9W-T<B`B4VEM:6QE(&$Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C4*;7-G:60@
M(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,S(Y"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S"FUS9VED
M(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HW.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(D-O;G1E9V=I;R!F:6QE.B`E<R!F:6QE(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B
M"FUS9W-T<B`B0V]N=&5G9VEO(&9I;&4Z("5S(&9I;&5S(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM
M<V=S='(@(D=E<W1I;VYE($9I;&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,`IM<V=I9"`B
M1FEL92!.86UE(@IM<V=S='(@(DYO;64@1FEL92(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.3<W"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")3
M96QE>FEO;F4@9FEL92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#@V"FUS
M9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")#87)I8V$@1FEL92(*"B,Z(&QI
M8B](;W)D92]"<F]W<V5R+G!H<#HY,#`*;7-G:60@(D9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")#87)I8V%M96YT;R!F:6QE(&YO;B!S
M=7!P;W)T871O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS
M9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R:2(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(*;7-G:60@(D9I;FQA;F0B
M"FUS9W-T<B`B1FEN;&%N9&EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")0<FEM;R!-97IZ;R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*
M;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B4')I;6\@475A<G1O(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I
M9"`B1FEX(')A=&EO(@IM<V=S='(@(E)A<'!O<G1O(&9I<W-O(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI
M<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I
M9"`B1F]G(@IM<V=S='(@(DYE8F)I82(*"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C$P-R!L:6(O5D93+W-Q;"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("),82!#87)T96QL
M82`E<R!N;VX@97-I<W1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")#
M;VQO<F4@9&5L;&$@9F]N=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B0VEB;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PIM<V=I
M9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS
M9W-T<B`B4&5R(&)R;W=S97(@8VAE(&YO;B!S=7!P;W)T86YO(&QE(&EM;6%G
M:6YI(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C
M87-T("A4048I(@IM<V=S='(@(E!R979I<VEO;F4@*%1!1BDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y
M;W5R('!A<W-W;W)D/R(*;7-G<W1R(")(86D@9&EM96YT:6-A=&\@;&$@<&%S
M<W=O<F0_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I
M9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G
M<W1R("));F]L=')I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B5F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS
M9VED(")&<F%M97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX-PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@
M(D9R86YC:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,0IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X-`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I
M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1&$@:6P@(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I>FEO;F4@0V]M<&QE=&$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM
M<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(DQN82!0:65N82(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B3F]M92!#;VUP
M;&5T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#@*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L;&5R
M:6$@9&%L;&$@<75A;&4@<')E;F1E<F4@;&4@:6UM86=I;FDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&QE<FEA.B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38*;7-G:60@
M(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B1V5N97)A("5S($-O;F9I9W5R87II;VYE(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E
M;F5R871E9"!#;V1E(@IM<V=S='(@(D-O9&EC92!'96YE<F%T;R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`*;7-G:60@
M(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")'
M97)M86YI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3,*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30*;7-G:60@(D=I8G)A
M;'1A<B(*;7-G<W1R(")':6)I;'1E<G)A(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B3F]M
M92!$871O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W.2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B3W!Z
M:6]N:2!';&]B86QI(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*
M;7-G:60@(D=O(@IM<V=S='(@(E9A:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@
M36%P<R(*;7-G<W1R(")-87!P92!';V]G;&4B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G
M:60@(D=R87ES8V%L92(*;7-G<W1R(")38V%L92!D:2!G<FEG:2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B1W)E8VEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.0IM<V=I9"`B1W)E;F%D82(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O
M=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B06UM:6YI<W1R87II;VYE($=R
M=7!P:2(*"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N
M;VXM96UP='DB"FUS9W-T<B`B22!N;VUI(&1E;"!G<G5P<&\@;F]N(&1E=F]N
M;R!E<W-E<G)E('9U;W1I(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B(@HB1W)O=7!?;&1A<#H@26UP;W-S:6)I;&4@86=G:75N
M9V5R92!I;"!G<G5P<&\@)7,N(%%U97-T82#H(&QA(')I<W!O<W1A(&1E;"`B
M"B)S97)V97(Z("(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD
M87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?
M;&1A<#H@26UP;W-S:61I;&4@96QI;6EN87)E(&EL(&=R=7!P;R`E<R(*"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD
M87`Z($EM<&]S<VEB:6QE(&%G9VEO<FYA<F4@:6P@9W)U<'!O("5S(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HS,30*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@
M(D=R;W5P<R(*;7-G<W1R(")'<G5P<&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX"FUS9VED(")'=6%D96QO=7!E(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`S"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R"FUS9VED(")'=6%T
M96UA;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR
M"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS
M9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")097)M97-S:2!D96=L
M:2!O<W!I=&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS
M9VED(")'=65S=&)O;VLB"FUS9W-T<B`B3&EB<F\@9&5G;&D@;W-P:71I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-PIM
M<V=I9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-`IM<V=I9"`B1W5I;F5A+4)I<W-A
M=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#4*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,30*
M;7-G:60@(DAE861E<B(*;7-G<W1R("));G1E<W1A>FEO;F4B"@HC.B!L:6(O
M2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R
M<R(*;7-G<W1R("));G1E<W1A>FEO;FDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@
M5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G
M<W1R(")!;'1E>GIA(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O
M2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W
M"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM
M<V=S='(@(D%I=71O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T
M<B`B06EU=&\@=7-A;F1O(&PG961I=&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")!:75T86YT92(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G
M<W1R(")%;6ES9F5R;R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$P('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E
M(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(E%U97-T
M;R#H(&PG:6YI>FEO(&1E;"!F:6QE.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H(@IM<V=S='(@(D%L
M=&\B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S
M+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S
M='(@(DAO7W)D92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#,*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I(@IM<V=S='(@(E-A;G1A(%-E9&4@*$-I='1A)R!D96P@5F%T:6-A
M;F\I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM<V=S
M='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G
M:60@(DAO;64@061D<F5S<R(*;7-G<W1R("));F1I<FEZ>F\@9&D@8V%S82(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B2&]M92!$:7)E
M8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)Y(&1I(&-A<V$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R(")496QE9F]N;R!D:2!C87-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`X"FUS9VED(")(;VYD=7)A
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#8*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0U"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D
M92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@
M)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB
M)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T
M<B`B4F5G;VQA(&]R:7IZ;VYT86QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D
M:6YG(@IM<V=S='(@(E)I96UP:6UE;G1O(&]R:7IZ;VYT86QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B
M2&]R:7IO;G1A;#HB"FUS9W-T<B`B3W)I>GIO;G1A;&4Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS
M9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*
M;7-G<W1R(")#;VUE('-E:2!A<G)I=F%T;R!Q=6D_("A396D@<')E9V%T;R!D
M:2!F87)E('5N(')A<'!O<G1O(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N
M=&4@8V]L;VYN92!V=6]I('5N:7)E/R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\B"FUS9W-T<B`B475A;G1I(&-A;7!I("AC;VQO;FYE*2!C
M:2!S;VYO(#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N=&4@<FEG:&4@=G5O:2!U
M;FER93\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S-R!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R
M(")5;6ED:73@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")5;6ED:73@.B`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3$*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B56YG:&5R:6$B"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-2!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D-R96%Z:6]N92!D
M96QL82!C87-E;&QA($E-05`@9F%L;&ET83H@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)S<6PN<&AP.C(Y-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z
M,C$T"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(D-A;F-E;&QA>FEO;F4@9&5L;&$@8V%S
M96QL82!)34%0(&9A;&QI=&$Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR-#(@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R(")#<F5A>FEO;F4@9&5L;&$@<75O=&$@9&5L
M;&$@8V%S96QL82!)34%0(&9A;&QI=&$Z("5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B26YD:7)I
M>GIO($E0(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G
M:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B26YD:7)I
M>GIO($E0(&YO;B!D:7-P;VYI8FEL92XB"@HC.B!L:6(O2&]R9&4O075T:"]I
M<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B3"=I;F1I<FEZ>F\@25`@;F]N
M(.@@86QL)VEN=&5R;F\@9&5L(&)L;V-C;R!#2412(&-O;G-E;G1I=&\N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@
M(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS
M9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B25]N<V5R:7-C:2!L
M82!226=A('!R:6UA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N
M9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(E-O;&\@26-O;F4B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S
M(@IM<V=S='(@(DEC;VYE('!E<B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("))8V]N
M92!C;VX@=&5S=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS
M9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DYO;64@9&5L;"=)9&5N
M=&ETX"(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HV,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R
M("(B"B)392!N;VX@Z"!S=&%T;R!V:7-U86QI>GIA=&\@8V]R<F5T=&%M96YT
M92P@)7,@87!R:7)E(&EN('5N82!N=6]V82!F:6YE<W1R82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(E-E(&YO;B!V961I(&YE<W-U;F$@
M:6-O;F$@=7-A;F1O($EN=&5R;F5T($5X<&QO<F5R+"!P;W1R97-T:2!D;W9E
M<B`B"B)S96QE>FEO;F%R92!Q=65S=&$@8V%S96QL82!P97(@86YN=6QL87)E
M(&QA('1R87-P87)E;GIA(&1E;&QE(&EM;6%G:6YI(%!.1RXB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y
M('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB4V4@=F5D:2!Q=65S=&\@;65S
M<V%G9VEO(&UA(&YO;B!L)VEM;6%G:6YE+"!L)VEM86=I;F4@8VAE('9U;VD@
M8V%R:6-A<F4@;F]N("(*(G!U\B!E<W-E<F4@=FES=6%L:7IZ871A(&1A;"!T
M=6\@8G)O=W-E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*;7-G:60@(DEM86=E(%!R979I97<Z
M(@IM<V=S='(@(E!R92U6:7-U86QI>GIA>FEO;F4@9&5L;"=);6UA9VEN93HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B55),($EM;6%G:6YE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$X"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!)
M;6UA9VEN93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R("));6UA9VEN92!D86QL82!G86QL97)I82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("));6UA9VEN
M92!D86QL82!G86QL97)I83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V
M,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D-A<FEC86UE;G1O($EM
M;6%G:6YE(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM
M86=E<R(*;7-G<W1R("));6UA9VEN:2(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-`HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P
M("5D(@IM<V=S='(@(DEM<&]R=&$L(%!A<W-O("5D(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-A;7!I(&EM<&]R=&%T:3H@)7,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O
M<G1E9"!F:65L9',Z(@IM<V=S='(@(D-A;7!I(&EM<&]R=&%T:3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(DEN7W-E<FES
M8VD@<FEG82!D;W!O(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(D-O9&EC92!D:2!A>FEO;F4@97)R871O(&1A=&\N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M92!U=&5N
M=&4@92]O('!A<W-W;W)D(&YO;B!C;W)R971T;RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B).;VUE('5T96YT92!O(&EN9&ER:7IZ;R!A;'1E
M<FYA=&EV;R!N;VX@=F%L:61O+B!2:7!R;W9A(&%N8V]R82!O(&-O;G1A='1A
M("(*(FPG86UM:6YI<W1R871O<F4@<V4@;F5C97-S:71I(&1I('5L=&5R:6]R
M92!A:75T;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B075M
M96YT82!L82!R:65N=')A;GIA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G
M<W1R(")5=&5N=&D@26YD:79I9'5A;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(*;7-G:60@(DEN9&]N97-I82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FUA>FEO;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*
M;7-G<W1R("));F9O<FUA>FEO;F4@;F]N('!I^2!D:7-P;VYI8FEL92XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN
M<V5R:7-C:2!#7V]L;VYN82!$;W!O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B26YS97)I<V-I($EM;6%G:6YE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(DEN<V5R:7-C:2!486)E;&QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I
M9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN<V5R:7-C:2!L:6YK('=E
M8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S
M='(@(DEN<V5R:7-C:2!?0V]L;VYN82!0<FEM82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YS97)I<V-I('5N82!N=6]V82!C;VQO;FYA(&1O<&\@<75E;&QA
M(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)I<V-I('5N
M82!N=6]V82!C;VQO;FYA('!R:6UA(&1I('%U96QL82!C;W)R96YT92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B26YS97)I<V-I('5N82!N=6]V82!R:6=A(&1O<&\@
M<75E;&QA(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)I<V-I
M('5N82!N=6]V82!R:6=A('!R:6UA(&1I('%U96QL82!C;W)R96YT92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`B26YS97)I<V-I('5N('!A<F%G<F%F;R!D;W!O
M(&EL(&YO9&\@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E
M<FES8VD@=6X@<&%R86=R869O('!R:6UA(&1E;"!N;V1O(&-O<G)E;G1E(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B26YS97)I<V-I('5N82!M87-C:&5R
M82!A;'1E<FYA=&EV82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*
M;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"B));G-E
M<FES8VD@=6X@:6YD:7)I>GIO(&5M86EL(&%L('%U86QE('!O=')A:2!R:6-E
M=F5R92!L82!N=6]V82!P87-S=V]R9#HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@
M8V5L;"!A9G1E<B(*;7-G<W1R("));G-E<FES8VD@=6YA(&-E;&QA(&1O<&\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B26YS
M97)I<V-I('5N82!C96QL82!P<FEM82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C
M;VQU;6X@869T97(B"FUS9W-T<B`B26YS97)I<V-I('5N82!C;VQO;FYA(&1O
M<&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R
M("));G-E<FES8VD@=6YA(&-O;&]N;F$@<')I;6$B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S0S,30N<&AP.C4P"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B
M26YS97)I<F4@;65S<V%G9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@869T97(B"FUS9W-T<B`B26YS97)I<V-I('5N('!A<F%G<F%F;R!D
M;W!O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R("));G-E<FES8VD@=6X@<&%R86=R869O('!R:6UA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));G-E<FES8VD@=6YA
M(')I9V$@9&]P;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM
M<V=S='(@(DEN<V5R:7-C:2!U;F$@<FEG82!P<FEM82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B26YS
M97)I<V-I(&QA(')I<W!O<W1A(')I8VAI97-T82!A;&QA(&1O;6%N9&$@9&D@
M<VEC=7)E>GIA.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T
M<B`B26YS97)I<V-I+TU/9&EF:6-A(&PG:6UM86=I;F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YS97)I<V-I+TU/9&EF:6-A(&EL
M(&QI;FLB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S
M"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")#<F5D:71I(&EN<W5F9FEC:65N
M=&D@<&5R('-P961I<F4@86QL82!L:7-T82!D:2!D:7-T<FEB=7II;VYE+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@
M(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(D-R961I=&D@:6YS=69F
M:6-I96YT:2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W-0IM<V=I9"`B
M26YT96=E<B(*;7-G<W1R("));G1E<F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(DQI<W1A(&EN
M=&5R82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW
M"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G
M<W1R(")51$@@;F]N('9A;&ED82`H57-E<B!$871A($AE861E<BDN(@H*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#;VUP
M<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B1&%T82!:
M25`@;F]N('9A;&ED82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*
M;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(D%P<&QI8V%Z
M:6]N92!N;VX@=F%L:61A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R
M(")"871C:"!)1"!N;VX@=F%L:61O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P.#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3@@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R,S(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R.3D@;&EB+TAO<F1E
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T
M82!S=6)M:71T960N(@IM<V=S='(@(FE,)VEN9F]R;6%Z:6]N92!S;W1T;VUE
M<W-A(&YO;B#H('9A;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+B(*;7-G<W1R("),)VEN9&ER:7IZ;R!D:2!D9&5S=&EN87II;VYE(&YO
M;B#H('9A;&ED;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ
M,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O
M<FUA="(*;7-G<W1R("));"!F;W)M871O(&1E;"!F:6QE(&YO;B#H('9A;&ED
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DQA(&-H:6%V92!D96QL
M82!L:6-E;GIA(&YO;B#H('9A;&ED82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("));"!L;V=O(&9O<FYI=&\@;F]N(.@@=F%L:61O+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")M<V=?='EP92!N;VX@=F%L
M:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")A
M<&E?:60@;F]N('9A;&ED;R!O(&UA;F-A;G1E+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B4&%R86UE=')O(&YO;B!V86QI
M9&\@;R!M86YC86YT92XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(E!E<FUE<W-O(&1E;"!G96YI=&]R92!N;VX@=F%L:61O+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R
M=&YE<B!I9"XB"FUS9W-T<B`B:60@9&5L('!A<G1N97(@;F]N('9A;&ED;RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("))
M;G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B0V]D:6-E('!R;V1O='1O
M(&YO;B!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E!R
M;W1O8V]L;&\@;F]N('9A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C<Q"B,Z
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D1E<W1I
M;F%T87)I;R!N;VX@=F%L:61O.B!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$P.#`@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C8S"FUS9VED("))
M;G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")/9V=E='1O(&-O;F1I=FES
M;R!N;VX@=F%L:61O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S
M='(@(DEN9&ER:7IZ;R!S;W)G96YT92!N;VX@=F%L:61O+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED
M('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N
M=&%R:6\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DEN=F5R=&D@
M;&$@<V5L97II;VYE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$Y"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q.`IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,*;7-G
M:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES
M;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-`IM<V=I9"`B27-R865L(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(V"FUS
M9VED("))<W-U97(B"FUS9W-T<B`B16UI='1E;G1E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(Q"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,*
M;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B1V5N;F%I
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R-0IM<V=I9"`B2F%P86XB"FUS9W-T<B`B1VEA<'!O;F4B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R
M+4I0*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R
M"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T"FUS9VED(")*;W)D86XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G
M:60@(DIU;'DB"FUS9W-T<B`B3'5G;&EO(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B1VEU9VYO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")':75S=&EF:6-A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(D=I=7-T:69I8V$@
M86P@8V5N=')O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R
M(")':75S=&EF:6-A('1U='1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F
M="(*;7-G<W1R(")':75S=&EF:6-A(&$@<VEN:7-T<F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I
M9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")':75S=&EF:6-A(&$@9&5S=')A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I
M9VEN86P_(@IM<V=S='(@(DUA;G1E;F5R92!L)V]R:6=I;F%L93\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8*;7-G
M:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DEL('-E<G9E<B!+97)B97)O<R!H82!R:69I
M=71A=&\@;"=A=71E;G1I8V%Z:6]N92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T
M:6]N(@IM<V=S='(@(D-R96%Z:6]N92!C:&EA=F4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G
M<W1R("));7!R;VYT82!D:6=I=&%L92!D96QL82!C:&EA=F4B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS
M9W-T<B`B3'5N9VAE>GIA(&1E;&QA(&-H:6%V92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5&EP
M;R!D96QL82!C:&EA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E5S;R!D96QL82!C:&EA
M=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B3&$@8VAI879E(.@@9VG@('!R97-E;G1E('-U;"!K97ES97)V97(@
M<'5B8FQI8V\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED
M(")+:61S(@IM<V=S='(@(D)A;6EB:6YI(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y"FUS9VED(")+:7)I8F%T:2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,S(*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,PIM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(W"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?
M>6]U="(*;7-G<W1R(")$:5]S<&]S:7II;VYE(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B3&EN
M9W5A9V=I;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM
M<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E5L=&EM;R!M97IZ;R(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`B56QT:6UA('!O<W-I8FEL:73@('!E<B!I;"!C86UB
M:6\@9&5L;&$@<&%S<W=O<F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS
M9W-T<B`B56QT:6UO('%U87)T;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E5L=&EM;R!A9V=I
M;W)N86UE;G1O.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B56QT:6UA
M(&-O;FYE<W-I;VYE.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*
M;7-G<W1R(")5;'1I;6$@8V]N;FYE<W-I;VYE.B`E<R!D82`E<R(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R
M(@IM<V=S='(@(E5L=&EM82!C;VYN97-S:6]N93H@36%I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),
M871V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T
M"FUS9VED("),87<B"FUS9W-T<B`B3&5G9V4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*;7-G:60@(DQA>6]U
M="(*;7-G<W1R(")$:7-P;W-I>FEO;F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R(@IM<V=S='(@(DQA<V-I86QO('9U;W1O('!E<B!A=F5R
M;&\@<V5N>F$@8F]R9&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S@*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB
M86YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0P"FUS9VED("),969T(@IM<V=S='(@(E-I;FES=')A(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE9G0@:&5A9&5R(@IM
M<V=S='(@(DEN=&5S=&%Z:6]N92!D:2!S:6YI<W1R82(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,#DW"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")6
M86QO<FD@9&D@<VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#,*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),
M979E;"(*;7-G<W1R("),:79E;&QO(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R"FUS9VED("),:6)E<FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T-PIM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#`*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI
M9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T
M<B`B4&EO9V=I82!L96=G97)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK
M(@IM<V=S='(@(D-O;&QE9V%M96YT;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P
M;VEN=',@=&\Z(@IM<V=S='(@(DEL(&-O;&QE9V%M96YT;R!P=6YT82!A.B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E
M;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y
M:6YG(@IM<V=S='(@(B(*(D-O;&QE9V$@;"=I;F1I<FEZ>F\@96UA:6P@86QL
M82!P86=I;F$@9&D@8V]M<&]S:7II;VYE('%U86YD;R!V:65N92`B"B)V:7-U
M86QI>GIA=&\B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT
M+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(D-O;&QE9V%M96YT:2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O
M:VEE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*;7-G
M:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R(")%
M;&5N8V\@+2!L)W5T96YT92!P=?(@=F5D97)E(&QE(&-A<G1E;&QE(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B
M"FUS9W-T<B`B16QE;F-O(&1E:2!D871A8F%S92(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S
M='(@(D5L96YC;R!D96D@<V]G9V5T=&D@9&5L;"=A:75T;R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@
M(D5L96YC;R!486)E;&QE(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-C`Q"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B07)C:&EV:6\@
M9&5L;&$@3&ES=&$B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU
M.38*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R(")!:75T;R!D96QL82!,:7-T
M82(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8P,PIM<V=I9"`B
M3&ES="U)9"(*;7-G<W1R("))9&5N=&EF:6-A=&EV;R!D96QL82!,:7-T82(*
M"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y.0IM<V=I9"`B3&ES
M="U/=VYE<B(*;7-G<W1R(")0<F]P<FEE=&%R:6\@9&5L;&$@;&ES=&$B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,#`*;7-G:60@(DQI<W0M
M4&]S="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.3@*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DES8W)I>FEO
M;F4@86QL82!,:7-T82(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP
M.C4Y-PIM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R(")!;FYU;&QA
M(&PG:7-C<FEZ:6]N92!A;&QA($QI<W1A(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@
M9F%I;&5D.B`E<R(*;7-G<W1R("),)V5L96YC;R!D96QL92!S97-S:6]N92#H
M(&9A;&QI=&\Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G
M<W1R("),)V5L96YC;R!D96=L:2!U=&5N=&D@Z"!F86QL:71O.B`E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3"=E;&5N8V\@9&5G
M;&D@=71E;G1I(.@@9&ES86)I;&ET871O+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),971T97)A
M='5R82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T-`IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG
M+BXN(@IM<V=S='(@(D-A<FEC86UE;G1O+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S
M='(@(D]R82!L;V-A;&4Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQI;F=U82!E($]R
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S(@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C(R"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`B3'5O9V\B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HR,#0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY,`HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U"FUS9VED("),;V<@:6XB"FUS9W-T<B`B
M16YT<F$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G
M:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y.`IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R(")%<V-I(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8Q"FUS9VED("),;V=I;B(*;7-G<W1R(")%;G1R82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@
M(D]P97)A>FEO;FD@9&D@06-C97-S;R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S
M='(@(B(*(DPG86-C97-S;R#H(&9A;&QI=&\@<&5R8VCH(&EL(&YO;64@=71E
M;G1E(&\@;&$@<&%S<W=O<F0@:6YS97)I=&D@;F]N('-O;F\@(@HB8V]R<F5T
M=&DN(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@
M9F%I;&5D+B(*;7-G<W1R(")!8V-E<W-O(&9A;&QI=&\N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")4
M97-T;R!L=6YG;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I
M9"`B3&]V92(*;7-G<W1R(")!;6]R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B0F%S
M<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S
M='(@(DQE='1E<F4@9W)E8VAE(&UI;G5S8V]L92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&5T=&5R92!L871I;F4@
M;6EN=7-C;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R(").=6UE<FD@<F]M86YI(&UI;G5S8V]L:2(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-0IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("),=7-S96UB=7)G;R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!L
M)V%L;&5G871O(&YO;B!C;VYT:65N92!I;F9O<FUA>FEO;FDN(@H*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS
M9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34W"FUS9VED(")-86-A;R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3$*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I
M8R(*;7-G<W1R(")-86=I8V\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`B4&]S=&$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S
M='(@(DEN9&ER:7IZ;R!A;6UI;FES=')A=&]R92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%K92!L:6Y?:RXN+B(*;7-G<W1R(")#<F5A(&-O;&QE9V%M96Y?=&\N+BXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C4*;7-G:60@(DUA;&%W:2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<*;7-G:60@(DUA;&%Y<VEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T"FUS
M9VED(")-86QI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V,@IM<V=I9"`B36%L=&$B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)'97-T:7-C:2!L)V5L96YC;R!D
M96QL92!C871E9V]R:64@971I8VAE='1A;F1O(&=L:2!A<G1I8V]L:2P@92!C
M;VX@:2!C;VQO<FD@(@HB87-S;V-I871I(&%L;&4@8V%T96=O<FEE+B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS9VED
M(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@
M(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<GIO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA<F=I;F4B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C0X"FUS9VED(")-87)K('=I=&@@4V5E;B]5
M;G-E96X@9FQA9W,B"FUS9W-T<B`B0V]N=')A<W-E9VYA<F4@8V]N(&D@9FQA
M9W,@5FES=&\O3F]N5FES=&\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y
M"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT
M+T%N<W=E<F5D*2(*;7-G<W1R(")#;VYT<F%S<V5G;F%R92!C;VX@86QT<FD@
M9FQA9W,@*&5S.B!);7!O<G1A;G1E+U)I<W!O<W1O*2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,@IM<V=I9"`B36%R
M<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3D*;7-G:60@(DUA<G1I;FEQ=64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*
M;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")#86UP:2!C;W)R:7-P
M;VYD96YT:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V,`IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET
M+B(*;7-G<W1R(")#<F5D:71O(&UA<W-I;6\@<&5R;65S<V\N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")%8V-E9'5T92!L82!P
M87)T:2!M87-S:6UE(&1E;"!M97-S86=G:6\N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,3,*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R(")496UP;R!M87-S:6UO('5L=&EM92`R-"!O<F4Z("(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L87-T(#8@
M:&]U<G,Z("(*;7-G<W1R(")496UP;R!M87-S:6UO('5L=&EM92`V(&]R93H@
M(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F
M(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B3G5M97)O(&UA<W-I;6\@9&5L(%!O
M<G1A($)L;V-K<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G
M:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DQU;F=H97IZ82!M87-S:6UA
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA
M>2(*;7-G<W1R(")-86=G:6\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S"FUS9VED(")-87EO='1E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`B365D:6-I;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE;6)R
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@
M;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS
M9W-T<B`B56YI<V-I(&QE(&-E;&QE(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-97-S
M86=G:6\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I
M9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(B(*(DEL(&UE<W-A9VEO(.@@<W1A=&\@=F5R:69I8V%T;R!C
M;W)R971T86UE;G1E+"!M82!I;"!F:7)M871A<FEO(&1E;"`B"B)C97)T:69I
M8V%T;R!N;VX@<'7R(&5S<V5R92!V97)I9FEC871O+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X
M<&ER960N(@IM<V=S='(@(DUE<W-A9V=I;R!S8V%D=71O+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8P,@IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1I<&\@;65S<V%G
M9VEO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!7
M96%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*
M;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO
M="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B365T;V1O(@H*(SH@;&EB+TAO
M<F1E+U)00R]S;V%P+G!H<#HQ,3<@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP
M.C@Q"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T
M(&1E9FEN960B"FUS9W-T<B`B26P@;65T;V1O("!<(B5S7"(@;F]N(.@@9&5F
M:6YI=&\B"@HC.B!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,B"FUS9W-T<B`B365T;V1O(&YO;B!D969I;FET;RX@365T;V1O(&-H
M:6%M871A.B`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8W"FUS9VED(")-971R:6,B"FUS9W-T
M<B`B365T<FEC82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V-@IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE<W-I8V\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M-0IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#(*;7-G:60@(DUI9&1L92(*;7-G<W1R(")-97IZ;R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM
M92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W
M"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M
M<&\@;6EN:6UO('5L=&EM92`R-"!O<F4Z("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R(")496UP;R!M:6YI;6\@=6QT:6UE(#8@;W)E.B`B"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B26P@=&5M<&\@9&D@
M9'5R871A(&UI;FEM;R!D96QL82!P87-W;W)D(&YO;B#H('-C861U=&\B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED
M(")-:7)R;W(B"FUS9W-T<B`B4W!E8V-H:6\B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B5F%R
M:6\B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,"!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B26P@<&%C8VAE='1O(%!%05(@
M2%144%]297%U97-T(.@@;6%N8V%N=&4N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$Q-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D-O;F9I9W5R87II
M;VYE(&UA;F-A;G1E+B!$979I(&=E;F5R87)N92!U;F$@;G5O=F$@<V4@=G5O
M:2!U<V%R92!Q=65S=&$@(@HB87!P;&EC87II;VYE+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE
M<W-A9V4@240N(@IM<V=S='(@(DE$(&1E;"!M97-S86=G:6\@;6%N8V%N=&4N
M(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM
M<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS
M9W-T<B`B26P@<&%C8VAE='1O(%!%05(@36%I;"!R:6-H:65S=&\@Z"!M86YC
M86YT92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("))1"!D96QL
M82!S97-S:6]N92!M86YC86YT92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("),=2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DUO9&5R
M871O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S,*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS
M9W-T<B`B1&%T82!D96QL82!M;V1I9FEC82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R(")-;V1I9FEC82!54DPB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-
M;V1U;&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T.0IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-@IM<V=I9"`B36]N9V]L
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#0*;7-G
M:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUE<V4@92!A;FYO(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R(")-96YS:6QM96YT92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V,0IM<V=I9"`B36]N='-E<G)A="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(D9A<VD@;'5N
M87)I(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O0U-6+G!H
M<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@HB
M4V]N;R!S=&%T:2!T<F]V871I('!I^2!C86UP:2!N96QL82!L:6YE82`E9"!R
M:7-P971T;R!A('%U96QL:2!I<')E=FES=&D@)60N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G
M:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U
M9'D@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")3<&]S=&$@4V]T=&\B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM
M<V=I9"`B36]V92!,969T(@IM<V=S='(@(E-P;W-T82!A(%-I;FES=')A(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G
M:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B4W!O<W1A(&$@1&5S=')A(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`B4W!O<W1A(%-O<')A(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(E-P;W-T82!S;W1T;R(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")3<&]S=&$@
M<V]P<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C@*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0R"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L97II;VYE(&UU;'1I<&QA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@
M06-C;W5N="(*;7-G<W1R(")-:6\@06-C;W5N="(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*
M;7-G<W1R("));F9O<FUA>FEO;FD@9&5L($UI;R!!8V-O=6YT(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HT-`IM<V=I9"`B37D@4&]R=&%L(@IM
M<V=S='(@(DUI;R!0;W)T86QE(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N
M<&AP.C0R"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(D1I<W!O
M<VEZ:6]N92!D96P@36EO(%!O<G1A;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34*;7-G:60@(DUY86YM87(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").
M3RP@;F]N('-O;F\@9"=A8V-O<F1O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1N968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`R"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M3F%M92(*;7-G<W1R(").;VUE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y"FUS9VED(").86UI8FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W.`IM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W"FUS9VED(").97!A;"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S"FUS
M9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED
M(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE
M=V%L(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(E)E=&4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*
M;7-G<W1R(")-86DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S`*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*
M;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").=6]V82!#871E9V]R:6$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM
M<V=S='(@(DQU;F$@3G5O=F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*
M;7-G<W1R(").=6]V;R!.;VUE(%5T96YT92`H;W!Z:6]N86QE*2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B
M3G5O=F$@<&%S<W=O<F0B"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N(@IM<V=S='(@(DQA(&YU;W9A('!A<W-W;W)D('-C861RX"!I
M;B`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G
M:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DQA(&YU
M;W9A('!A<W-W;W)D(&YO;B!C;W)R:7-P;VYD92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN
M9&]W("A?8FQA;FLI(@IM<V=S='(@(DYU;W9A(&9I;FES=')A("A?=G5O=&$I
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0P"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G
M:60@(DYE=W,B"FUS9W-T<B`B3F]T:7II92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1W)U
M<'!I(&1I($YO=&EZ:64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-2!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.0HC.B!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHT,2!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ-0IM<V=I9"`B3F5X="(*;7-G<W1R(")0<F]S<VEM;R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G
M<W1R(")0<F]S<VEM92`T($9A<VDB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C,V-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X
M="!O<'1I;VYS(@IM<V=S='(@(E!R;W-S:6UE(&]P>FEO;FDB"@HC.B!L:6(O
M2&]R9&4O54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B
M4')O<W-I;6\^(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<T"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q"FUS
M9VED(").:6=E<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S,*;7-G:60@(DYI9V5R:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I
M9"`B3FEG:'0B"FUS9W-T<B`B3F]T=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD*;7-G:60@(DYI=64B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M-@IM<V=I9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B
M"B).;VX@<V]N;R!D:7-P;VYI8FEL:2!I;F9O<FUA>FEO;FD@<FEG=6%R9&\@
M;&$@8V]N9FEG=7)A>FEO;F4@<&5R(&UO<W1R87)E(&QE("(*(F1I9F9E<F5N
M>F4N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS
M9W-T<B`B3F]N(.@@9&ES<&]N:6)I;&4@=6YA('-T<F%T96=I82!P97(@8W)E
M87)E(&EM;6%G:6YI($E33RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3`Q"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS
M9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;B(*;7-G<W1R(").;VX@97-I<W1E('5N(&)L;V-C;R!A;&QA('!O<VEZ:6]N
M92!R:6-H:65S=&$B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM
M<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3F]N(.@@<W1A=&\@9F]R;FET;R!I;"!N
M;VUE(&1E;"!C86QE;F1A<FEO('!E<B!L)V%U=&5N=&EC87II;VYE($U#04PN
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG
M92XB"FUS9W-T<B`B3F5S<W5N82!M;V1I9FEC82XB"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5S<W5N(&9I9VQI
M;R!P=?(@97-S97)E(&%G9VEU;G1O(&$@<75E<W1O('!E<FUE<W-O+B(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3<X(&QI8B](;W)D92YP:'`Z-3$W(&QI8B](;W)D
M92]5=&EL+G!H<#HW.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R
M("(B"B).;VX@Z"!S=&%T82!S<&5C:69I8V%T82!A;&-U;F$@:6YF;W)M87II
M;VYE('-U;&QA(&-O;F9I9W5R87II;VYE('!E<B`E<RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z.#8X"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@HB3F]N(.@@
M<W1A=&$@<W!E8VEF:6-A=&$@86QC=6YA(&EN9F]R;6%Z:6]N92!S=6QL82!C
M;VYF:6=U<F%Z:6]N92!P97(@1E10(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z-C@T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@HB3F]N(.@@<W1A=&$@
M<W!E8VEF:6-A=&$@86QC=6YA(&EN9F]R;6%Z:6]N92!S=6QL82!C;VYF:6=U
M<F%Z:6]N92!P97(@4U%,(%9&4RXB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HW-3,*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*(DYO;B#H('-T
M871A('-P96-I9FEC871A(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N
M9FEG=7)A>FEO;F4@<&5R(%-13"TB"B)&:6QE(%9&4RXB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(DYO;B#H(')I;6%S=&\@;F5S<W5N(&-R961I=&\N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I
M9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DYO;B#H('-T
M871A(&9O<FYI=&$@;&$@9&5S=&EN87II;VYE+B(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HY,3@*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T
M<B`B26P@9FEL92!N;VX@Z"!S=&%T;R!C87)I8V%T;R(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S
M='(@(DYO;B!S;VYO('-T871E('1R;W9A=&4@;&4@:6-O;F4N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,S`@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38*;7-G:60@(DYO
M(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B3F]N(.@@<W1A=&\@:6UP;W-T
M871O(&QA('!O<VEZ:6]N92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B3F]N(.@@<W1A=&\@:6YD:6-A=&\@;&$@<&]S:7II;VYE+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE
M<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYO;B#H('-T871O(&9O<FYI=&\@
M:6P@;65S<V%G9VEO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").
M;VX@Z"!S=&%T;R!S<&5C:69I8V%T;R!I;"!N;VUE+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S
M<&5C:69I960N(@IM<V=S='(@(DYO;B#H('-T871O('-P96-I9FEC871O(&EL
M(&YU;65R;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@
M(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B#H('-T
M871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@
M2%144"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A<W-W;W)D('!E
M<B!L)V%U=&5N=&EC87II;VYE($E-05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F]N(.@@<W1A=&$@
M9F]R;FET82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z:6]N92!+97)B
M97)O<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0@;&EB+TAO
M<F1E+T%U=&@O<&%M+G!H<#HW-0HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H
M<#HW-PIM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@Z"!S=&%T82!F;W)N:71A(&QA
M('!A<W-W;W)D('!E<B!L)V%U=&5N=&EC87II;VYE($QO9VEN+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(").;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A<W-W;W)D('!E<B!L)V%U=&5N
M=&EC87II;VYE(%!!4U-71"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP
M.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A
M<W-W;W)D('!E<B!L)V%U=&5N=&EC87II;VYE(%--0BXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA
M<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M(@IM<V=S='(@(B(*(DYO;B#H(&1I<W!O;FEB:6QE(&%L8W5N82!P871C:"!P
M97(@;&$@=F5R<VEO;F4@8FEN87)I82!D:2!/<&5N4U-,+B!,82`B"B)V97)S
M:6]N92!B:6YA<FEA(&1I($]P96Y34TP@Z"!N96-E<W-A<FEO(&-H92!O<&5R
M:2!C;VX@;&4@:6YF;W)M87II;VYI(%!+0U,@(@HB,3(N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN
M9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+G!H<#HW-C8*;7-G
M:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3F]N(.@@<W1A=&$@:6UP;W-T
M871A(&QA('%U;W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@
M(DYE<W-U;F$@<F5G;VQA(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#(*;7-G
M:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYO;B#H('-T
M871O('-P96-I9FEC871O(&EL('-E<&%R871O<F4N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B
M3F\@<VED97,B"FUS9W-T<B`B3F5S<W5N82!L871O(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C8P,`IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(DYE<W-U
M;B!T:7!O(&1I(&9I;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N(@IM<V=S='(@(DYO;B#H(&1I<W!O;FEB:6QE('5N82!D
M:7)E8W1O<GD@=&5M<&]R86YE82!P97(@;&$@8V%C:&4N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,2!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="XB"FUS9W-T<B`B3F]N(.@@<W1A=&$@:6YV:6%T;R!I;"!N;VUE
M('5T96YT92!E+V\@<&%S<W=O<F0N(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR
M<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B
M"FUS9W-T<B`B3F]N('-O;F\@<FET;W)N871E(&EN9F]R;6%Z:6]N:2!834P@
M=F%L:61E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO
M('9A;'5E<R(*;7-G<W1R(").97-S=6X@=F%L;W)E(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$Q.0IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O
M<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(DYO;B#H('-T871A('1R;W9A=&$@;&$@=F5R<VEO
M;F4@;F5L;&$@8V]N9FEG=7)A>FEO;F4@;W)I9VEN86QE+B!2:6=E;F5R82!L
M82`B"B)C;VYF:6=U<F%Z:6]N92XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B).;VX@Z"!S=&%T82!T<F]V871A(&QA('9E<G-I;VYE(&YE;&QA('1U82!C
M;VYF:6=U<F%Z:6]N92X@4FEG96YE<F$@;&$@(@HB8V]N9FEG=7)A>FEO;F4N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0IM<V=I9"`B3F]N92(*
M;7-G<W1R(").97-S=6YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*
M;7-G<W1R(").97-S=6YO("]U<V\@:6UP;&EC:71O*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S(*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B16UI<V9E
M<F\@4V5T=&5N=')I;VYA;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3@*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S8*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").
M;W)V96=I82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS
M9VED(").;W0@069T97(B"FUS9W-T<B`B3F]N($1O<&\B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G
M<W1R(").;VX@4')I;6$B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0R,0IM<V=I
M9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DYO;B!U;F$@9&ER96-T;W)Y
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"FUS9VED(").;W0@
M:6UP;&5M96YT960N(@IM<V=S='(@(DYO;B!I;7!L96UE;G1A=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED
M(").;W0@<V5T(@IM<V=S='(@(DYO;B!I;7!O<W1A=&\B"@HC.B!L:6(O5D93
M+G!H<#HQ.3,@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP.C(S-"!L:6(O
M5D93+G!H<#HR-3(*(SH@;&EB+U9&4RYP:'`Z,C8Y(&QI8B]61E,N<&AP.C(X
M-2!L:6(O5D93+G!H<#HS,#$@;&EB+U9&4RYP:'`Z,S$V"B,Z(&QI8B]61E,N
M<&AP.C,S,R!L:6(O5D93+G!H<#HS-C8@;&EB+U9&4RYP:'`Z-#(V(&QI8B]6
M1E,N<&AP.C4P-0HC.B!L:6(O5D93+G!H<#HU-S0@;&EB+U9&4RYP:'`Z-3DQ
M(&QI8B]61E,N<&AP.C8V.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N
M<&AP.C$T-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!L
M:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-2!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L
M97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F]N
M('-U<'!O<G1A=&\N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#@@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-3@@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B07!P=6YT:2(*"B,Z('-E<G9I8V5S
M+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYU;&QA(&1A('9I<W5A;&EZ>F%R92P@
M=&]R;F$@:6YD:65T<F\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8G)E(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R
M(").=6UE<F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-0IM<V=I9"`B
M3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B3G5M97)O(&1I(&-A<F%T
M=&5R:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#(S(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(").=6UE<F\@9&D@8V]L;VYN92(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8W(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#(Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R(").=6UE<F\@9&D@<FEG:&4B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R("(B"B))(&YU;65R:2!N;VX@<V]N;R!S=&%T:2!S<&5C:69I
M8V%T:2!P97(@;"=A9V=I;W)N86UE;G1O(&YE;&QA(&QI<W1A(&1I("(*(F1I
M<W1R:6)U>FEO;F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B
M"FUS9W-T<B`B3V=G971T;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")#<F5A=&]R
M92!D96QL)T]G9V5T=&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$P-`IM
M<V=I9"`B3V-T86PB"FUS9W-T<B`B3W1T86QE(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3W1T
M;V)R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F
M96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(E5F9FEC:6\B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A
M;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B
M3&4@<&%S<W=O<F0@=F5C8VAI92!E(&YU;W9E(&1E=F]N;R!E<W-E<F4@9&EF
M9F5R96YT:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM
M<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E9E8V-H:6$@<&%S<W=O<F0B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B3&$@=F5C8VAI
M82!P87-S=V]R9"!N;VX@Z"!C;W)R971T82XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$*;7-G:60@(D]M86XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R(")3;VQO(&D@<V5R=F5R($E-05`@<W5P<&]R=&%N;R!L
M92!C87)T96QL92!C;VYD:79I<V4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+B(*;7-G<W1R(")%)R!P97)M97-S;R!S;VQO('5N(&EN9&ER:7IZ;R!E
M;6%I;"XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@
M(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E(@IM<V=S='(@(B(*(E-O;&\@:6P@<')O<')I971A<FEO(&\@
M;"=A;6UI;FES=')A=&]R92!D:2!S:7-T96UA('!U\B!C86UB:6%R92!L82!P
M<F]P<FEE=.`@(@HB;R!I('!E<FUE<W-I(&1E;"!P<F]P<FEE=&%R:6\@<&5R
M('5N82!C;VYD:79I<VEO;F4B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT
M,2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B07!R92!I;B!U;F$@;G5O=F$@9FEN:7-T<F$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB17)R;W)E($]P96Y34TPZ(&YO
M;B!S:2!P;W-S;VYO(&5S=')A<G)E(&QE(&EN9F]R;6%Z:6]N:2!D86QL82!P
M87)T92!F:7)M871A("(*(E,O34E-12XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B07!R92!Q=65S
M=&\@8V]L;&5G86UE;G1O(&EN('5N82!N=6]V82!F:6YE<W1R82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E
M;2(*;7-G<W1R(")3:7-T96UA($]P97)A=&EV;R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-34*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B
M3W!Z:6]N:2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS
M(&9O<B`E<R(*;7-G<W1R(")/<'II;VYI('!E<B`E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R
M960@3&ES="(*;7-G<W1R(")%;&5N8V\@;W)D:6YA=&\B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM
M<V=S='(@(D]R9V%N:7IZ87II;VYE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T
M<B`B56YI=.`@3W)G86YI>GIA=&EV82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B06=E;F1A
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(DUA<V-H97)A(&]R:6=I
M;F%L92!D96QL)V%P;&EC87II;VYE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.B(*;7-G<W1R(")-87-C:&5R82!O<FEG:6YA;&4@:6X@)7,Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B06QT<F\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")!;'1R92!);F9O<FUA>FEO;F4B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R(")097)M97-S:2!D96P@<')O<')I971A<FEO(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG875T96YT:6-A>FEO
M;F4@4$%-(&YO;B#H(&1I<W!O;FEB:6QE+B(*"B,Z(&QI8B].970O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(W-@IM
M<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T
M960@1&%T82(*;7-G<W1R("));F9O<FUA>FEO;F4@0VEF<F%T82!01U`B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R(")#:&EA=F4@4'5B8FQI8V$@4$=0(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T82(*;7-G<W1R("));F9O<FUA>FEO;F4@1FER;6%T82]#
M:69R871A(%!'4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B
M4$A0($-O9&4B"FUS9W-T<B`B0V]D:6-E(%!(4"(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E-H96QL(%!(
M4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X
M"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0P"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")0
M32!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#,*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3=&]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X-@IM<V=I
M9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B17-T96YS
M:6]N92!03U-)6"!M86YC86YT92(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I
M9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG
M(@IM<V=S='(@(E)I96UP:6UE;G1O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W"FUS9VED(")086MI<W1A;B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DT"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR"FUS9VED(")0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,@IM
M<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-0IM<V=I9"`B4&%P=6$@3F5W($=U
M:6YE82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DU"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM
M<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")087)Z:6%L;65N=&4@3G5V
M;VQO<V\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$U,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&%S<W=O<F0@8V%M
M8FEA=&$@8V]N('-U8V-E<W-O+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@
M(E!A<W-O=W)D(&YO;B!C;W)R971T82(*"B,Z(&QI8B](;W)D92]!=71H+W)A
M9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")%)R!R:6-H:65S=&$@;&$@
M<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@4D%$2553+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")087-S=V]R9"!C;VX@8V]N9F5R;6$B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W
M;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(DQE('!A<W-W;W)D(&1E=F]N;R!C;W)R
M:7-P;VYD97)E+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS
M9VED(")087-T92(*;7-G<W1R("));F-O;&QA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O
M;2!C;&EP8F]A<F0B"FUS9W-T<B`B26YC;VQL82!D86QL82!C;&EP8F]A<F0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"FUS9VED(")0871H(@IM<V=S='(@(E!E<F-O<G-O(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED
M(")096]P;&4B"FUS9W-T<B`B4&5R<V]N92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM
M<V=S='(@(E!E<F-E;G1U86QE(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")%<V5G=6D@;&4@3W!E<F%Z:6]N:2!D
M:2!-86YU=&5N>FEO;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P
M"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_(@IM<V=S='(@(D5S96=U:7)E(&QE(&]P97)A>FEO;FD@9&D@;6%N='5T
M96YZ:6]N92!A;&PG86-C97-S;S\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")097)M97-S;R(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@
M(E!E<FUE<W-O(%PB)7-<(B!N;VX@8V%N8V5L;&%T;RXB"@HC.B!L:6(O5D93
M+W-M8BYP:'`Z-C`S"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R
M(")097)M97-S;R!.96=A=&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$V,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4&5R;65S<VDB"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-C`@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'
M97-T:6]N92!097)M97-S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M87II;VYI(%!E<G-O;F%L:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@V"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`B5&5L969O;F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;V=R869I92(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`*
M;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0
M;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")3:2!P<F5G82!D:2!C;&EC8V%R
M92!I;B!A;&-U;F4@8V5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS
M9W-T<B`B4VD@<')E9V$@9&D@8V]N9F5R;6%R92!C:&4@<VD@=G5O;&4@<FEM
M=6]V97)E('%U97-T;R!E;&5M96YT;SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="XB"FUS9W-T<B`B4VD@<')E9V$@9&D@8V]N9F5R;6%R92!C:&4@<VD@=G5O
M;&4@<V-O;&QE9V%R92!Q=65S=&\@96QE;65N=&\Z(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U-C(*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N(@IM<V=S='(@(E-I('!R96=A(&1I(&EN<V5R:7)E('5N(&UE
M<V4@92!U;B!A;FYO+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")3:2!P<F5G82!D:2!I;G-E
M<FER92!U;B!N;VUE('!E<B!L82!N=6]V82!G871E9V]R:6$Z(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E-I('!R96=A(&1I(&EN<V5R:7)E
M('5N(&EN9&ER:7IZ;R!)4"!V86QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(V-#`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@
M(B(*(E-I('!R96=A(&1I(&EN<V5R:7)E('5N82!D871A('9A;&ED82P@8V]N
M=')O;&QA(&EL(&YU;65R;R!D:2!G:6]R;FD@;F5L(&UE<V4N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(T-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED('1I;64N(@IM<V=S='(@(E-I('!R96=A(&1I(&EN<V5R:7)E('5N)V]R
M82!V86QI9&$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+B(*;7-G<W1R(")3:2!P<F5G82!D:2!F;W)N:7)E('5N(')I87-S=6YT
M;R!D96P@<')O8FQE;6$N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R
M(")3:2!P<F5G82!D:2!F;W)N:7)E(&EL('!R;W!R:6\@;F]M92!U=&5N=&4@
M92!P87-S=V]R9"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E
M;2XB"FUS9W-T<B`B(@HB4VD@<')E9V$@9&D@;&5G9V5R92!I;"!S96=U96YT
M92!T97-T;RX@1$5622!E<W-E<F4@9"=A8V-O<F1O(&-O;B!I('1E<FUI;FD@
M(@HB9"=U<V\@9&5L('-I<W1E;6$N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4VD@<')E9V$@9&D@<V-R:79E
M<F4@:6QN;VUE(&1E;&QA(&YU;W9A(&-A=&5G;W)I83HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#@*;7-G:60@(E!O
M;&%N9"(*;7-G<W1R(")0;VQO;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI=&EC82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM
M<V=S='(@(E-C<G5T:6YI;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3,*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@
M(E!O<G1O9V%L;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4B"FUS9W-T<B`B4&]S:7II;VYA;65N=&\@9&D@<75E<W1A
M(&EM;6%G:6YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B
M"FUS9W-T<B`B4&]S:7II;VYA;65N=&\@9&D@<75E<W1A('1A8F5L;&$B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"FUS9VED(")0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B4&]S=&%R
M92!A('%U97-T82!C87)T96QL82`H;F]N(&%P<&QI8V%T;R!D82!)34%0*2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!R96-I<&ET87II;VYE('!E
M<B!L)W5L=&EM82`E<R!O<F$H92DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM
M<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!%<W1E;G-I;VYE($Q$05`@
M<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S
M97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S
M97-S:6]N.B!E<W1E;G-I;VYE(&1E;&QA('-E<W-I;VYE(')I8VAI97-T82!N
M;VX@=')O=F%T82XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I
M9"`B4')E<W-U<F4B"FUS9W-T<B`B4')E<W-I;VYE(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@
M(@IM<V=S='(@(E!R97-S:6]N92!A;"!L:79E;&QO(&1E;"!M87)E.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S
M<W5R93H@(@IM<V=S='(@(E!R97-S:6]N93H@(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B06YT97!R:6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"FUS9VED(")0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B06YT
M97!R:6UA(&1E;&PG:6UM86=I;F4@:6X@=6YA(&YU;W9A(&9I;F5S=')A(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-38@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B
M3W!Z:6]N:2!P<F5C9&5N=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G
M<W1R(")3=&%M<&$@9&]C=6UE;G1O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")#:&EA=F4@
M4')I=F%T82(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R
M;V)L96TB"FUS9W-T<B`B4')O8FQE;6$B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)I>FEO;F4@9&5L('!R;V)L96UA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O9V5T
M=&DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-@IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D-H:6%V92!0=6)B
M;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;6\@9&5L
M;&$@0VAI879E(%!U8F)L:6-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("));F9O
M<FUA>FEO;FD@<W5L;&$@0VAI879E(%!U8F)L:6-A(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP
M86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("),82!C
M;W!P:6$@8VAI879E(%!U8F)L:6-A+U!R:79A=&$@;F]N(.@@<W1A=&$@9V5N
M97)A=&$@8V]N('-U8V-E<W-O+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T;R!2:6-O(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B16QI;6EN82!I(&UE
M<W-A9V=I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C8T"FUS9VED(")1=65R>2(*;7-G<W1R(")$;VUA;F1A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P"FUS9VED(")1=6]T82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-`IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5Z:6]N92!R861I;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN(@IM<V=S='(@(E!I;V=G:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM
M<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV."!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T
M<B`B4F%P<&]R=&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),96=G:2(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3&5G
M9V5R92!I(&UE<W-A9V=I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@
M(D5L:6UI;F%R92!R96%L;65N=&4@)7,_($PG;W!E<F%Z:6]N92!N;VX@<'7R
M(&5S<V5R92!R96-U<&5R871A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)%;&EM:6YA<F4@<F5A;&UE;G1E
M(&QE(&EN9F]R;6%Z:6]N:2!R96QA=&EV92!A;&PG=71E;G1E("5S/R!,)V]P
M97)A>FEO;F4@;F]N("(*(G!U\B!E<W-E<F4@<F5C=7!E<F%T82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED
M(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")2:65S96=U92!L
M82!T=6$@=6QT:6UA(&%Z:6]N92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H
M(@IM<V=S='(@(D%G9VEO<FYA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM
M<V=S='(@(D%G9VEO<FYA(&=L:2!E;&5M96YT:2!D:6YA;6EC:2!D96P@;65N
M=3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R
M97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!9V=I;W)N87)E(&QA('9I<W1A
M(&1E;"!P;W)T86QE.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*
M;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C,Q"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B
M4FEC87)I8V$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B
M4F5M87)K<R(*;7-G<W1R(")/<W-E<G9A>FEO;FDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R
M(")397)V97(@<F5M;W1I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),(')E;6]T82`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,R!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(R"FUS9VED(")296UO=F4B"FUS9W-T<B`B4FEM=6]V:2(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K
M(@IM<V=S='(@(E)I;75O=FD@:6P@8FQO8V-O(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M
M;B(*;7-G<W1R(")2:6UU;W9I(&QA(&-O;&]N;F$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R(")2:6UU;W9I(&QA(&9O<FUA='1A>FEO;F4B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`B4FEM=6]V:2!L82!C;W!P:6$B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C`Q"FUS9VED(")296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B4FEM=6]V:2!L;R!S8W)I<'0@<V%L=F%T;R!D86QL82!D:7)E8W1O<GD@
M=&5M<&]R86YE82!D96P@<V5R=F5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E
M('1H92(*;7-G<W1R(")2:6UU;W9I(&EL(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E)I;75O
M=FD@<75E<W1O(&YO9&\@9&%L(&1O8W5M96YT;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(E)I;75O=FD@;"=U=&5N=&4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E
M('5S97(Z("5S(@IM<V=S='(@(E)I;75O=FD@;"=U=&5N=&4Z("5S(@H*(SH@
M;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B3&$@<FEC:&EE<W1A(&YO;B!P=?(@97-S97)E(&5V87-A+B!#;V1I
M8V4@9&D@97)R;W)E(&1I(')I=&]R;F\Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O
M=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B26P@<V5R=FEZ:6\@<FEC:&EE
M<W1O(&]N('!U\B!E<W-E<F4@=')O=F%T;RXB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$X-2!L:6(O2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")<(B5S7"(@<FEC:&EE<W1O(&YO;B#H('-P96-I9FEC
M871O(&YE;&QA(&-O;F9I9W5R87II;VYE(&1I("5S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HX-S0@;&EB+U9&4R]S<6PN<&AP.C8Y,"!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(EPB)7-<(B!R:6-H:65S=&\@;F]N(.@@<W!E8VEF:6-A=&\@;F5L;&$@
M8V]N9FEG=7)A>FEO;F4@9&D@5D93+B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H
M<#HW.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB
M(')I8VAI97-T;R!N;VX@Z"!S<&5C:69I8V%T;R!N96QL82!C;VYF:6=U<F%Z
M:6]N92XB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,V"FUS
M9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")#86UP;R!2:6-H:65S=&\B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,Y
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`@;&EB
M+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,0HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(D%Z>F5R82(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S
M=V]R9"(*;7-G<W1R(")!>GIE<F$@;&$@<&%S<W=O<F0B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S
M=V]R9"(*;7-G<W1R(")!>GIE<F$@;&$@='5A('!A<W-W;W)D(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y
M(@IM<V=S='(@(E)I<')I<W1I;F$@;"=U;'1I;6$@9&]M86YD82(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]P:'!S:&5L;"YP:'`Z-S(@861M
M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM<V=S='(@(E)I
M<W5L=&%T:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`B4FET;W)N82!A;&QE($]P>FEO;FDB"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@
M<&%S<W=O<F0B"FUS9W-T<B`B4FES8W)I=FD@;&$@;G5O=F$@<&%S<W=O<F0B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DW"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)I=6YI;VYE(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("));G9E
M<G1I(&QA($-O;F9I9W5R87II;VYE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S
M='(@(D]P>FEO;FD@<&5R(&EL(%)I8V@@5&5X="!%9&ET;W(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M26YD;W9I;F5L;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*;7-G:60@(E)I9VAT(@IM<V=S='(@(D1E<W1R
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H="!H
M96%D97(B"FUS9W-T<B`B26YT97-T87II;VYI(&1I(&1E<W1R82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,#DY"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B5F%L;W)I(&1I(&1E<W1R82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65TX"!D96QL82!2:5]G82XN
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS
M9VED(")2;VQE(@IM<V=S='(@(E)E9V]L82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")2;W5T82!D:2`Q
M.#`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S
M"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")2;W5T82!A('-I;FES=')A
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM
M<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(E)O=71A(&$@1&5S=')A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I973@
M(&1E;&QA(%)I9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R(")0<F]P<FEE=.`@9&5L;&$@<FEG82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G
M<W1R(")2:6=H93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")296=O
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(DQE(')E9V]L92!A<'!A<FER
M86YN;R!T<F$@='5T=&4@;&4@<FEG:&4@92!L92!C;VQO;FYE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB
M"FUS9W-T<B`B3&4@<F5G;VQE(&%P<&%R:7)A;FYO('-O;&\@=')A(&QE(&-O
M;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R("),92!R96=O;&4@87!P87)I<F%N;F\@<V]L
M;R!T<F$@;&4@<FEG:&4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS
M9VED(")2=6XB"FUS9W-T<B`B17-E9W5I<F4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,`IM<V=I9"`B4G=A;F1A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B1FER
M;6$@8VEF<F%T82!3+TU)344B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S
M='(@(DUE<W-A9V=I;R!C:69R871O(%,O34E-12(*"B,Z(&QI8B](;W)D92]!
M=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG875T96YT:6-A>FEO;F4@4T%3
M3"!N;VX@Z"!D:7-P;VYI8FEL92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(DUE<W-A
M9V=I;R!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-1
M3"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W
M-`IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G
M<W1R(")$:6-H:6%R87II;VYE(%-13"!P97(@:6P@=F%L;W)E(&1I(&QO;VMS
M=7`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")3
M4T@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,Q"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,Y"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y
M"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#0*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")3
M=&5S<V$@<W1R=71T=7)A("A?875T;RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q"FUS9VED(")386UO82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$R"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38*;7-G
M:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V
M:61E<B(*;7-G<W1R(")P<F]V:61E<B!S871E;&QI=&%R92(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$*;7-G:60@
M(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B4V%L=F$B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E-A;'9A(%PB)7-<
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4V%L=F$@)7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`B4V%L=F$@;&4@3W!Z:6]N:2(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C8*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB3&$@8V]N9FEG=7)A>FEO
M;F4@9V5N97)A=&$@Z"!S=&%T82!S86QV871A(&-O;64@<V-R:7!T(%!(4"!N
M96QL82!D:7)E8W1O<GD@(@HB=&5M<&]R86YE82!D96P@='5O('-E<G9E<BXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")S86QV
M871E("5S(&-O;F9I9W5R87II;VYI+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(E-A;'9A=&\@;&\@
M<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L;&4@:6UP;W-T87II;VYI(&EN
M.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3$*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B
M"FUS9W-T<B`B4V-I96YZ82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B4FEC97)C82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S
M='(@(DUO=&]R:2!D:2!2:6-E<F-A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y-34*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")&:6QE('-E;&5Z
M:6]N871I(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE>FEO;F$@
M=6YA(&1A=&$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM
M<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E-E;&5Z:6]N
M82!U;B!G<G5P<&\@9&$@86=G:75N9V5R92(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G
M<W1R(")396QE>FEO;F$@=6X@;G5O=F\@<')O<')I971A<FEO(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S
M97)V97(B"FUS9W-T<B`B4V5L97II;VYA('5N('-E<G9E<B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R
M('1O(&%D9"(*;7-G<W1R(")396QE>FEO;F$@=6X@=71E;G1E(&1A(&%G9VEU
M;F=E<F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E-E;&5Z:6]N82!T=71T
M;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0S"FUS9VED(")396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L97II;VYA('1U='1I
M(&D@8V]M<&]N96YT:2!D96QL82!D871A+B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE
M8W0B"FUS9W-T<B`B<V5L97II;VYA('5N(&]G9V5T=&\B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@
M;F]N92(*;7-G<W1R(").97-S=6YA('-E;&5Z:6]N92(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M(@IM<V=S='(@(B(*(E-E;&5Z:6]N82!I(&-A<F%T=&5R:2!D:2!C=6D@:&%I
M(&)I<V]G;F\@9&%L;&4@8V%S96QL92!S;W1T;R!R:7!O<G1A=&4N(%!U;VD@
M(@HB8V]P:6%R;&D@92!I;F-O;&QA<FQI(&1A;&PG87)E82!D:2!T97-T;RXB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L97II;VYA(&EL('1E
M<FUI;F4@9&5L;&$@9&%T83HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B
M4V5L97II;VYA(&EL(&9O<FUA=&\@9&5L;&$@9&%T83HB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B4V5L
M97II;VYA(&PG:61E;G1I=.`@8VAE('9U;VD@;6]D:69I8V%R93HB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L97II;VYA(&EL(&QI;6ET92!D
M96QL)V]R83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V5L97II;VYA
M(&EL(&9O<FUA=&\@9&5L;"=O<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M(@IM<V=S='(@(E-E;&5Z:6]N82!D=64@8V%M<&D@8VAE(&-O<G)I<W!O;F1O
M;F\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")396QE>FEO;F$@;&\@
M<V-H96UA(&1E:2!C;VQO<FDN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*
M;7-G<W1R(")396QE>FEO;F$@;&$@;&EN9W5A('!R969E<FET83HB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0
M<F]B;&5M(%)E<&]R="(*;7-G<W1R("));G9I82!I;"!297!O<G0@9&5L('!R
M;V)L96UA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(DEN=FEA(%--4R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3,*
M;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<F4Z("(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T
M96UB97(B"FUS9W-T<B`B4V5T=&5M8G)E(@H*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R
M"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(DYU;65R;R!D:2!397)I
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@
M(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DEN9F]R;6%Z:6]N92!D96P@<V5R=F5R('-B86=L:6%T82!O(&YO;B!D:7-P
M;VYI8FEL92XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E
M<W-I;VX@061M:6XB"FUS9W-T<B`B06UM:6YI<W1R871O<F4@9&D@<V5S<VEO
M;F4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM
M<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("),82!S97-S:6]N
M92!)1"#H('-C861U=&$B"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E
M<W-I;VYS(@IM<V=S='(@(E-E<W-I;VYI(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("));7!O<W1A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A
M;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F
M;W)G970@:70N(@IM<V=S='(@(B(*(DEM<&]S=&$@;&4@;W!Z:6]N:2!P97(@
M<&5R;65T=&5R=&D@9&D@87IZ97)A<F4@;&$@<&%S<W=O<F0@;F5L(&-A<V\@
M9&]V97-S:2`B"B)D:6UE;G1I8V%R=&5L82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA
M="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T
M<B`B26UP;W-T82!I;"!S97)V97(@<F5M;W1O(&%L('%U86QE('9U;VD@86-C
M961E<F4@9&%L('1U;R!P;W)T86QE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("));7!O<W1A(&QA
M(&QI;F=U82!P<F5F97)I=&$@92!L92!O<'II;VYI('!E<B!L)V]R82!E(&QA
M(&1A=&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B
M(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO
M;G,N(@IM<V=S='(@(B(*(DEM<&]S=&$@;&4@87!P;&EC87II;VYI(&1I(&%V
M=FEO+"!L;R!S8VAE;6$@9&5I(&-O;&]R:2P@:6P@=&5M<&\@9&D@(@HB86=G
M:6]R;F%M96YT;R!D96QL82!P86=I;F$@92!A;'1R92!O<'II;VYI(&1I('9I
M<W5A;&EZ>F%Z:6]N92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W
M"FUS9VED(")3971U<"(*;7-G<W1R("));7!O<W1A>FEO;F4B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@
M=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")38W)I<'0@9&D@
M86=G:6]R;F%M96YT;R!D96QL92!I;7!O<W1A>FEO;FD@9&ES<&]N:6)I;&DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M("(*;7-G<W1R(")$:79E<G-E('!O<VEZ:6]N:2!D:7-P;VYI8FEL:2!C;VX@
M:6P@<&%R86UE=')O.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`S"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H
M;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(D)R979E
M(%-O;6UA<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I
M9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_(@IM<V=S='(@(DQA(&-H:6%V92!D)V%C8V5S<V\@9&]V<N`@97-S97)E
M(&1E9FEN:71A('!E<B!P:?D@8V]L;&5G86UE;G1I/R(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(DUO
M<W1R82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-30*;7-G:60@(B(*
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HB36]S=')A(&QE(&1I9F9E<F5N>F4@=')A(&QA(&-O;F9I9W5R87II
M;VYE(&%T='5A;&UE;G1E('-A;'9A=&$@92!L82!N=6]V82`B"B)G96YE<F%T
M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(DUO
M<W1R82!L)V]R82!D96QL)W5L=&EM;R!A8V-E<W-O('%U86YD;R!E;G1R:3\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")-;W-T<F$@;"=O<'II;VYE
M('!E<B!M86YT96YE<F4@<75E;&QA(&]R:6=I;F%L92(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-SDU"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")-
M;W-T<F$@:6P@<F%C8V]G;&ET;W)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R
M/R(*;7-G<W1R(")-;W-T<F%R92!L82!T86)E;&QA(&1E;&QE(&]P97)A>FEO
M;FD@9&5L(&UE;G4@8F%R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\B"FUS9W-T<B`B36]S=')A(&EL(&UE;G4@9&D@)7,@<W5L;&$@
M<VEN:7-T<F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B36]S
M=')A(&EL(&-A<FEC86UE;G1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3$X,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$R,C,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,C4R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3$*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R
M(")#;VYT<F%S<V5G;F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D9I<FUA(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!
M;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO(&1I(&9I<FUA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-@IM<V=I
M9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HX.38@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Y,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#0*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S(*;7-G:60@(E-I>F4B"FUS9W-T<B`B1&EM96YS:6]N92(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS
M9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(E-A;'1A(&QE(&]P97)A
M>FEO;FD@9&D@;6%N=71E;GII;VYE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,`IM<V=I9"`B4VQO=F%K:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P.`IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N
M;W<B"FUS9W-T<B`B3F5V92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM
M<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E
M<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED(")3
M;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.#D*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#(*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$T
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDP.`IM<V=I9"`B4V]R="!O<F1E<B!S
M96QE8W1I;VXB"FUS9W-T<B`B3W)D:6YA(&PG;W)D:6YA;65N=&\@9&D@<V5L
M97II;VYE(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ-C8@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B
M4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO('-O<F=E;G1E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M-0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(E-U9"!!9G)I8V$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,0IM<V=I9"`B4V]U=&@@1V5O
M<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H
M<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")E;6ES
M9F5R;R!-97)I9&EO;F%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS(@IM<V=S='(@(E-P87II;R!T<F$@8V5L;&4@86ED86-E;G1I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&PB"FUS9W-T<B`B4W!A>FEO('1R82!I;"!C;VYT96YU=&\@92!I;"!B
M;W)D;R!I;B!U;F$@8V5L;&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U
M"FUS9VED(")3<&%C97(B"FUS9W-T<B`B1&ES=&%N>FEA=&]R92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0IM
M<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")3<&%Z:6%T=7)A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I
M9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")3<&%Z:6%T=7)A(&4@
M<FEE;7!I;65N=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,`IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B4W!A9VYA(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@
M(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(DEN<V5R:6UE;G1O
M($-A<F%T=&5R:2!3<&5C:6%L:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB
M"FUS9W-T<B`B4V5P87)A(&QA(&-E;&QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(E-E<&%R82!L82!C;VQO;FYA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I
M9"`B4W!L:70@<F]W(@IM<V=S='(@(E-E<&%R82!L82!R:6=H82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V
M"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y
M,0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!;FYO(&1I('!A<G1E;GIA
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T
M871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E-T871O(&\@4')O=FEN8VEA(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@
M(E-T871U<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y
M-PIM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D:2!M
M96UO<FEZ>F%Z:6]N92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R("));F1I<FEZ>F\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B5&]G;&D@:6P@9&]M:6YI
M;R!D86QL)VEN9&ER:7IZ;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM
M<V=S='(@(E-T:6QE(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B1&\B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E-O
M='1O9&ER96-T;W)Y(%PB)7-<(B!N;VX@=')O=F%T82XB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R(")/9V=E='1O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,B!L
M:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$X"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B4V]T=&]M971T:2(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*
M(D4G('-T871A(&EN=FEA=&$@;&$@<FEC:&EE<W1A('!E<B!A9V=I=6YG97)E
M(%PB)7-<(B!A;"!S:7-T96UA+B!.;VX@<'5O:2`B"B)A8V-E9&5R92!F:6YT
M86YT;R`@8VAE(&QA(')I8VAI97-T82!N;VX@=FEE;F4@87!P<F]V871A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*
M;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3`U(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B#H('-T871O(&%G9VEU;G1O(&-O;B!S=6-C97-S;R!A;"!S:7-T96UA+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*(DQE(&EN9F]R;6%Z:6]N:2!R96QA
M=&EV92!A;&PG=71E;G1E(%PB)7-<(B!S;VYO('-T871E(&-A;F-E;&QA=&4@
M8V]N("(*(G-U<W-E<W-O(&1A;"!S:7-T96UA+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B!E;&EM:6YA=&$@8V]N('-U8V-E<W-O+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<
M(B5S7"(@<FEM;W-S;R!C;VX@<W5C8V5S<V\@9&%L('-I<W1E;6$N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A>FEO;F4@:6YV97)T:71A(&-O;B!S
M=6-C97-S;RX@4FEC87)I8V$@<&5R('9E9&5R92!I(&-A;6)I86UE;G1I+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")#;W!I82!D96QL82!C;VYF:6=U<F%Z
M:6]N92!S86QV871A(&-O;B!S=6-C97-S;RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`B0V]P:6$@9&5L(&9I;&4@9&D@8V]N9FEG=7)A>FEO;F4@9&D@)7,@
M<V%L=F%T82!C;VX@<W5C8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB
M)7-<(B(*;7-G<W1R(")!9V=I;W)N871O(&-O;B!S=6-C97-S;R!<(B5S7"(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=W)O=&4@)7,B"FUS9W-T<B`B4V-R:71T;R!C;VX@<W5C8V5S<V\@)7,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T
M"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(E-O;6UA<FEO(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@
M(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS
M9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I
M9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B4W5P<&]R=&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$U"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")3
M;W!R86YN;VUE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P.0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$Y"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-0IM
M<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-V97II82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R(")3=FEZ>F5R82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--
M3"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY
M-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R
M(")%<G)O<F4@9&D@<VEN=&%S<VD@;F5I('1E<FUI;FD@9&D@<FEC97)C82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED
M(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O
M<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP
M:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED
M(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65TX"!D96QL82!4
M86)E;&QA(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("));7!O<W1A>FEO;F4@9&5L
M;&$@5&%B96QL82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<')I973@(&1E;&QA('1A8F5L;&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-`IM
M<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,U"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B3V)I971T:79O.B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,R(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HQ,#0Y"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@
M(E1A<VMS(@IM<V=S='(@(D%T=&EV:73@(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T
M<B`B3G5M97)O(&1I('1E;&5F;VYO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E
M;7!E<F%T=7)A('!E<B!L)W5L=&EM82!O<F$Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")496UP
M97)A='5R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*
M;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R871U<F$Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")-87-C:&5R82!<(B5S7"(@;F]N('1R;W9A=&$N
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D=E<W1I;VYE($UA<V-H97)A(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,S,C<*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5S=&\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M4V]L;R!497-T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B
M06QL:6YE86UE;G1O('1E<W1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y
M"FUS9VED(")4:"(*;7-G<W1R(")':2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(T"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M.#8T"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("),)V5S=&5N<VEO;F4@1E10(&YO;B#H(&1I<W!O;FEB:6QE
M+B(*"B,Z(&QI8B](;W)D92](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI
M<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),82!C<F]N:7-T
M;W)I82!D96P@<VES=&5M82#H(&1I<V%B:6QI=&%T82XB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M7"(E<UPB(@IM<V=S='(@(DEL(&UO=&]R92!D:2!I;G1E9W)A>FEO;F4@2&]R
M9&4O2V]L86(@;F]N('-U<'!O<G1A(%PB)7-<(B(*"B,Z(&QI8B].970O24U3
M4"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T
M(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("));"!L;V<@9&D@24U34"!N;VX@
M<'7R(&5S<V5R92!I;FEZ:6%L:7IZ871O+B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("),82!C;&%S<V4@
M36%I;G1E;F%N8V4Z.B!N;VX@Z"!S=&%T82!C87)I8V%T82!C;VX@<W5C8V5S
M<V\B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS
M9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB
M"FUS9W-T<B`B3&$@9FEN:7-T<F$@9&5L;&4@3W!Z:6]N:2!S:2#H(&-H:75S
M82X@57-C:7)E+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](
M;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z
M,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M
M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T
M;VT@<VED92!O;FQY(@IM<V=S='(@(E-O;&%M96YT92!I;"!L871O(&EN9F5R
M:6]R92(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*
M;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D
M871A8F%S92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B26P@
M8V]N=&%T=&\@Z"!S=&%T;R!A9V=I=6YT;R!C;VX@<W5C8V5S<V\@86QL82!T
M=6$@<G5B<FEC82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3<R
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q
M"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE
M<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I
M;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B3F]N(.@@<W1A=&$@
M<W!E8VEF:6-A=&$@;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B3&$@9G5N>FEO;F4@9&D@8VEF<F%T=7)A(')I8VAI961E('5N82!C
M;VYN97-S:6]N92!W96(@<VEC=7)A+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3@V
M(&QI8B](;W)D92YP:'`Z-3(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B
M26P@9FEL92`E<R!D;W9R96)B92!C;VYT96YE<F4@=6YA("5S(&EM<&]S=&%Z
M:6]N92XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W.2!L:6(O2&]R9&4N<&AP.C4Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("));"!F:6QE("5S(&1O
M=G)E8F)E(&-O;G1E;F5R92!A;&-U;F4@)7,@:6UP;W-T87II;VYI+B(*"B,Z
M(&QI8B](;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R("));"!F:6QE(&YO;B!C;VYT:65N92!I
M;F9O<FUA>FEO;FDN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(DQE('-E9W5E;G1I('-O;F\@;&4@:6YT97-T87II;VYI('!E<B!Q=65S=&\@
M;65S<V%G9VEO+W)F8S@R,B!M97-S86=G:6\N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B3"=I9&5N=&ETX"!<(B5S7"(@Z"!S=&%T82!C86UC96QL871A+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB
M)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*
M;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O
M;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W
M-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC
M+B(*;7-G<W1R("));"!N=6UE<F\@9&5I(&-A;7!I(&1E=F4@97-S97)E(&1I
M('1I<&\@;G5M97)I8V\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@
M9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("))
M;"!M;V1U;&\@;W!E;G-S;"#H(')I8VAI97-T;R!P97(@;&$@8VQA<W-E($AO
M<F1E7T-R>7!T7W-M:6UE.CHN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E
M<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E
M9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*
M(DQA('!R969E<F5N>F$@7"(E<UPB(&YO;B!P=?(@97-S97)E('-A;'9A=&$@
M<&5R8VCH(&PG:6YF;W)M87II;VYE(&-O;G1E;G5T82`B"B)E8V-E9&4@;&$@
M;6%S<VEM82!D:6UE;G-I;VYE(&1I<W!O;FEB:6QE(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E
M>&-E;"YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P
M;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*(DEL('!R;V=R86UM82!U<V%T;R!P97(@=FES=6%L:7IZ87)E('%U
M97-T;R!T:7!O(&1I(&EN9F]R;6%Z:6]N92`H)7,I(&YO;B#H("(*(G-T871O
M('1R;W9A=&\@;F5L('-I<W1E;6$N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT
M.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I
M9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(DEL('-E<G9E<B!<(B5S7"(@Z"!S=&%T;R!E;&EM:6YA=&\N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@
M(DEL('-E<G9E<B!<(B5S7"(@Z"!S=&%T;R!S86QV871O+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(DQA
M(')I8VAI97-T82!D:2!I<V-R:7II;VYE('!E<B`E<R#H('-T871A(')I;6]S
M<V$N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D
M*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3&$@<FEG82!S<&5C:69I8V%T
M82`H)60I(&YO;B!E<VES=&4N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("));"!F:6QE('1E;7!O<F%N96\@
M7"(E<UPB(&YO;B!E<VES=&4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S
M,#(*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@
M=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B26P@=&5S=&\@9&EG
M:71A=&\@;F]N(&-O<G)I<W!O;F1E(&%L('1E<W1O('-U;&QO('-C:&5R;6\N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N(@IM<V=S='(@(DPG:6YF;W)M87II;VYE(&-A<FEC871A(.@@<W1A=&$@
M<&5R<V$@<VEN(&1A;&PG=6QT:6UO('!A<W-O+B(*"B,Z(&QI8B](;W)D92]$
M871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"FUS
M9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM
M<V=S='(@(DEL(&9I;&4@8V%R:6-A=&\@;F]N('!U\B!E<W-E<F4@<V%L=F%T
M;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DQA
M(&1I<F5C=&]R>2!D96D@=&5M:2!<(B5S7"(@;F]N(.@@<W1A=&$@=')O=F%T
M82XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE
M<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").;VX@8VD@
M<V]N;R!O<'II;VYI(&1I<W!O;FEB:6QI+B(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HS-3`*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(").;VX@8VD@
M<V]N;R!P87)T:2!C:&4@<&]S<V]N;R!E<W-E<F4@=FES=6%L:7IZ871E(&EN
M;&EN92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB
M0VD@<V]N;R!T<F]P<&D@8V%R871T97)I(&EN('%U97-T;R!C86UP;RX@2&%I
M(&1I9VET871O("5S(&-A<F%T=&5R:3L@9&5V:2`B"B)D:6=I=&%R92!U;B!N
M=6UE<F\@9&D@8V%R871T97)I(&UI;F]R92!D:2`E<RXB"@HC.B!S:6=N=7`N
M<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES
M=&5M.B`E<R(*;7-G<W1R(")#:2!S;VYO(&%L8W5N:2!P<F]B;&5M:2!N96QL
M)V%G9VEU;F=E<F4@7"(E<UPB(&%L('-I<W1E;6$Z("5S(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB0R?H('-T871O('5N('!R;V)L96UA
M(&YE;"!C86YC96QL87)E(&QE(&EN9F]R;6%Z:6]N:2!P97(@;"=U=&5N=&4@
M7"(E<UPB(&1A;"`B"B)S:7-T96UA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R
M96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B0R?H
M('-T871O('5N('!R;V)L96UA(&YE;"!R:6UU;W9E<F4@7"(E<UPB(&1A;"!S
M:7-T96UA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(D,GZ"!S=&%T;R!U;B!P<F]B;&5M82!N96QL)V%G9VEO
M<FYA;65N=&\@9&D@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R("(B"B)#)^@@<W1A=&\@=6X@<')O8FQE;6$@8V]N(&EL(&-A
M<FEC86UE;G1O(&1E;"!F:6QE.B!.97-S=6X@)7,@Z"!S=&%T;R`B"B)C87)I
M8V%T;RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,P"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM
M=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D,G
MZ"!S=&%T;R!U;B!P<F]B;&5M82!C;VX@:6P@8V%R:6-A;65N=&\@9&5L(&9I
M;&4Z($EL("5S(&5R82!P:?D@;'5N9V\@9&5L;&$@(@HB;6%S<VEM82!D:6UE
M;G-I;VYE('!E<FUE<W-A("@E9"!B>71E<RDN(@H*(SH@;&EB+TAO<F1E+T)R
M;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)#)^@@<W1A
M=&\@=6X@<')O8FQE;6$@8V]N(&EL(&-A<FEC86UE;G1O(&1E;"!F:6QE.B!)
M;"`E<R#H('-T871O(&-A<FEC871O("(*(G-O;&\@<&%R>FEA;&UE;G1E+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@
M<&%R="(*;7-G<W1R("(B"B)#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&QA('9I
M<W5A;&EZ>F%Z:6]N92!D:2!Q=65S=&$@<&%R=&4@9&5L(&UE<W-A9V=I;R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R
M(")#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG:6UP;W)T87)E(&QE(&EN9F]R
M;6%Z:6]N:2!D96P@8V]N=&%T=&\N(@H*(SH@;&EB+TAO<F1E+T1A=&$O:6UC
M+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D,GZ"!S=&%T;R!U;B!E<G)O
M<F4@;F5L;"=I;7!O<G1A<F4@;&4@:6YF;W)M87II;VYI(&1I(&E#86QE;F1A
M<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@HB0R?H('-T871O('5N(&5R;W)E(&YE;&QA(&9O<FT@9&D@8V]N
M9FEG=7)A>FEO;F4N(%!R;V)A8FEL;65N=&4@:&%I("(*(F1I;65N=&EC871O
M('5N(&-A;7!O(')I8VAI97-T;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB0R?H
M('-T871O('5N(&5R<F]R92!N96QL)V5S96=U:7)E(&QA('-P96-I9FEC82!F
M=6YZ:6]N92!D96QL82!R=6)R:6-A+B!3:2`B"B)P<F5G82!D:2!R:7!R;W9A
M<F4@<&GY('1A<F1I+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"B)#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG86=G:6]R
M;F%M96YT;R!D96D@9&5T=&%G;&D@9&5L(&-O;G1A='1O+B!3:2!P<F5G82`B
M"B)D:2!P<F]V87)E('!I^2!T87)D:2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0U(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR
M,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(D,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L;"=A9V=I;W)N86UE
M;G1O(&1E;&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N(%-I("(*(G!R96=A
M(&1I('!R;W9A<F4@<&GY('1A<F1I+B(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(E%U97-T
M;R!S97)V97(@24U!4"!N;VX@<W5P<&]R=&$@;&$@8V]N9&EV:7-I;VYE(&1I
M(&-A<G1E;&QE+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+B(*;7-G<W1R(")1=65S=&\@<V5M8G)A(&YO;B!E<W-E
M<F4@=6X@87)C:&EV:6\@9&D@=&EP;R!R87(@=F%L:61O+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")1
M=65S=&\@<V5M8G)A(&YO;B!E<W-E<F4@=6X@9FEL92!D:2!T:7!O('II<"!V
M86QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*
M;7-G<W1R(")1=65S=&\@;F]N('-E;6)R82!E<W-E<F4@=6X@;G5M97)O(&1I
M(&-A<G1A('9A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S
M-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T
M:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O
M(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U
M;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3<X(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#4W(&QI8B](;W)D92]&;W)M+G!H<#HQ,#@V"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$U(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,C4V"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S`U(&QI8B](;W)D92]&;W)M+G!H<#HQ,SDX(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-34W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#,Y(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.34X(&QI8B](;W)D92]&;W)M+G!H<#HR,#`U"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#(Y(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#<X(&QI8B](;W)D92]&;W)M+G!H<#HR,30Y"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HR-#`X(&QI8B](;W)D92]&
M;W)M+G!H<#HR-#4P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C,W(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#$P(&QI8B](;W)D92]&;W)M+G!H<#HS,3$Y"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,CDW(&QI8B](;W)D92]&;W)M+G!H<#HS
M.#`U(&QI8B](;W)D92]&;W)M+G!H<#HS.#$S"FUS9VED(")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+B(*;7-G<W1R("(@475E<W1O(&-A;7!O('!U\B!C;VYT96YE<F4@
M<V]L;R!I;G1E<FDN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,38*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN(@IM<V=S='(@(B!1=65S=&\@8V%M<&\@<'7R(&-O;G1E;F5R
M92!S;VQO(&YU;65R:2!E(&1U92!P=6YT:2XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*
M(E%U97-T;R!C86UP;R!P=?(@97-S97)E('-O;&\@=6YA(&QI<W1A(&1I(&EN
M=&5R:2!S87!A<F%T:2!D82!V:7)G;VQA(&\@<W!A>FEO(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R(")1=65S=&\@8V%M<&\@9&5V92!E<W-E
M<F4@=6X@;G5M97)O('9A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@Q.`IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO
M<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB
M)R,Q,C,T868G+B(*;7-G<W1R("(B"B)1=65S=&\@8V%M<&\@9&5V92!C;VYT
M96YE<F4@=6X@8V]L;W)O(&EN(&9O<FUA=&\@4D="(&5S861E8VEM86QE+"!A
M9"!E<V5M<&EO("(*(B<C,3(S-&%F)RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N(@IM<V=S='(@(E%U97-T82!F;W)M(.@@9VEA('-T871A('!R;V-E
M<W-A=&$N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B475E<W1O(.@@
M)7,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B
M"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E
M(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@
M<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(E%U97-T;R!M97-S86=G
M:6\@Z"!S=&%T;R!S8W)I='1O(&EN('5N('-E="!D:2!C87)A='1E<FD@*"5S
M*2!D:79E<G-O(&1A;"!T=6\N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+B(*;7-G<W1R(")1=65S=&\@;G5M97)O(&1E=F4@97-S97)E('5N:6-O+B(*
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M(@IM<V=S='(@(E%U97-T;R!S97)V97(@;F]N('!U\B!D96-O;7!R:6UE<F4@
M9FEL92!I;B!F;W)M871O('II<"!E(&=Z:7`N(@H*(SH@;&EB+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"XB"FUS9W-T<B`B06P@;6]M96YT;R!Q=65S=&\@<VES
M=&5M82!N;VX@Z"!A='1I=F\N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`B475E<W1O('9A;&]R92!D979E(&5S<V5R92!U;B!N=6UE<F\N(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(*;7-G<W1R(")1=65S=&$@9FEN97-T<F$@9&5V92!E<W-E<F4@8VAI
M86UA=&$@9&$@=6YA(&9I;F5S=')A(&1E;&QE($]P>FEO;FDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU
M;F1E<B(*;7-G<W1R(")4=6]N;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B0FEG;&EE='1I(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C4@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(D]R82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED
M(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1E;&PG;W)A(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S$*;7-G:60@(E1I;64@<V5L96-T:6]N
M(@IM<V=S='(@(E-E;&5Z:6]N92!D96QL)V]R82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y"FUS9VED(")4
M:71L92(*;7-G<W1R(")4:71O;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")!(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T
M<B`B(@HB4&5R('-E;&5Z:6]N97)E('!I^2!V;V-I+"!T:65N:2!P<F5M=71O
M(&EL('1A<W1O($-O;G1R;VP@*%!#*2!O($-O;6UA;F0@(@HB*$UA8RD@;65N
M=')I('-T86D@8VQI8V-A;F1O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D]G9VDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED
M(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,PIM<V=I9"`B5&]G
M;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R
M<F]W(@IM<V=S='(@(D1O;6%N:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,CD*;7-G:60@(E1O;F=A(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O
M;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S
M+B(*;7-G<W1R(")4<F]P<&4@86-C97-S:2!N;VX@=F%L:61I(&1U<F5N=&4@
M9VQI('5L=&EM:2!M:6YU=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@Q"FUS9VED(")4;W`B"FUS9W-T<B`B
M06QT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B
M"FUS9W-T<B`B5')A9'5Z:6]N:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S(*;7-G:60@(E1R:6YI9&%D(&%N9"!4
M;V)A9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W.3`*
M;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5F5R;R!O(&9A;'-O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B36$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X"FUS9VED(")4=6YI<VEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)C:&EA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C<*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(P"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S,PIM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM
M<V=S='(@(D1I9VET82!L82!T=6$@<V-E;'1A.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D*;7-G:60@(E523"(*;7-G<W1R
M("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS
M9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W"FUS9VED
M(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-@IM<V=I9"`B56MR86EN92(*;7-G<W1R
M("(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0R-0IM<V=I9"`B56YA8FQE('1O
M(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FEL92!A
M8V-E9&5R92!A;&QA(&1I<F5C=&]R>2!61E,N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@HB
M26UP;W-S:6)I;&4@86=G:75N9V5R92!A;'1R92!I;F9O<FUA>FEO;FD@<W5G
M;&D@=71E;G1I(&UE;G1R92!D=7)A;G1E(&QA("(*(G-O='1O<V-R:7II;VYE
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A;6)I87)E(&D@<&5R;65S
M<VD@<&5R(&EL(&9I;&4@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,Y."!L:6(O5D93+VUU<W%L+G!H<#HT.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V%M8FEA<F4@:2!P97)M
M97-S:2!P97(@:6P@9FEL92!61E,@)7,O)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C<Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R("));7!O<W-I8FEL92!C86UB:6%R92!A("5S+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE('9E<FEF:6-A<F4@;&$@9&EM96YS:6]N92!D:2!<(B5S
M7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HW,#<@;&EB+U9&4R]S<6PN<&AP
M.C$P-#`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#<X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R("));7!O<W-I8FEL92!V97)I9FEC87)E(&QA(&1I;65N<VEO
M;F4@9&D@7"(E<R\E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z
M-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R("));7!O<W-I8FEL92!C;VYN971T97)S:2!A;"!S97)V97(@4U%,
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX.#,*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("));7!O<W-I8FEL92!C;VYN971T
M97)S:2!C;VX@4U-,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,X(&QI8B]6
M1E,O9FEL92YP:'`Z,C0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR,3D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C(W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@8V]P:6%R92!I;"!F:6QE(%9&4RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,S<S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB
M:6QE(&-R96%R92!L82!D:7)E8W1O<GD@5D93(%PB)7-<(BXB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C,V-R!L:6(O5D93+VUU<W%L+G!H<#HR-S`@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C<T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-R96%R92!L82!D
M:7)E8W1O<GD@5D93+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@8W)E87)E(&EL(&9I;&4@5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8W)E87)E
M(&QA(&-A<G1E;&QA(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR-S@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-R96%R92!I;"!F:6QE(%9&4R!V=6]T
M;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD@;&EB+TAO
M<F1E+T-O;7!R97-S+W1A<BYP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&1E8V]M<')I;65R
M92!L92!I;F9O<FUA>FEO;FDN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,P,R!L
M:6(O5D93+W-M8BYP:'`Z,C(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2XB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(%PB)7-<(BP@;&$@
M9&ER96-T;W)Y(&YO;B#H('9U;W1A+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DEM
M<&]S<VEB:6QE(&5L:6UI;F%R92!<(B5S7"(Z("5S+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,S0T(&QI8B]61E,O;75S<6PN<&AP.C,R,R!L:6(O5D93+W-Q
M;"YP:'`Z-#`W"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("));7!O<W-I8FEL92!E;&EM:6YA
M<F4@)7,L(&QA(&1I<F5C=&]R>2!N;VX@Z"!V=6]T82(*"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,X-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.#@*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2XB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(&QA(&1I<F5C=&]R
M>2!61E,@:6X@;6]D;R!R:6-O<G-I=F\N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HS-3`@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,T(&QI8B]61E,O;75S<6PN<&AP
M.C,T-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HS-34@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S@P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!L82!D:7)E8W1O
M<GD@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,S(@;&EB+U9&4R]S<6PN
M<&AP.C0T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));7!O<W-I8FEL92!E;&EM
M:6YA<F4@;&$@9&ER96-T;W)Y(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B24UP;W-S:6)I;&4@96QI;6EN
M87)E(&EL(&9I;&4@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C,Q-B!L:6(O5D93+VUU<W%L+G!H<#HQ-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3@P"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93+W-Q;"YP:'`Z
M,CDQ(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0Q.0HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HT,C<*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!I;"!F:6QE(%9&4RXB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!L82!C87)T96QL82!61E,@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G
M<W1R("));7!O<W-I8FEL92!E;&EM:6YA<F4@5D93(&EN(&UO9&\@<FEC;W)S
M:79O.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#0W"FUS9VED(")5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!D971E<FUI;F%R92!L82!D:7)E8W1O<GD@871T=6%L92XB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA
M8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("))
M;7!O<W-I8FEL92!E<W1A<G)E(&D@9&5T=&%G;&D@9&5L(&-E<G1I9FEC871O
M(@H*(SH@;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V%R
M:6-A<F4@;&$@9&5F:6YI>FEO;F4@9&D@)7,N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR,#@@;&EB+U9&4R]F:6QE+G!H<#HR,3,@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Y"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$X-`IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M('-P;W-T87)E(&EL(&9I;&4@5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HY
M."!L:6(O5D93+W-M8BYP:'`Z.3,@;&EB+U9&4R]S;6(N<&AP.C$P-@HC.B!L
M:6(O5D93+W-M8BYP:'`Z-C8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I
M;&4@87!R:7)E(&EL(&9I;&4@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C(Y,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(&EL
M(&9I;&4@5D93('!E<B!L82!S8W)I='1U<F$N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP.C$S-R!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&%P<FER92!I;"!F:6QE(%9&4RXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("));7!O<W-I8FEL
M92!A<')I92!L)V%R8VAI=FEO(&-O;7!R97-S;RXB"@HC.B!L:6(O5D93+G!H
M<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(DEM<&]S:6)I;&4@;&5G9V5R92!I;"!F
M:6QE(%9&4R`H9FEL97-I>F4@9FEL92@I(&9A:6QE9"DN(@H*(SH@;&EB+U9&
M4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T
M1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("));7!O<W-I8FEL92!L96=G
M97)E(&EL(&9I;&4@5D93("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@H*(SH@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B26UP;W-S:6)I;&4@;&5G
M9V5R92!I;"!F:6QE.B`B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8X.`IM<V=I
M9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G
M<W1R("));7!O<W-I8FEL92!L96=G97)E(&QA(&1I<F5C=&]R>2!V9G-R;V]T
M+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$P.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@HB26UP;W-S:6)I
M;&4@<FEN;VUI;F%R92`E<R!I;B`E<SH@;&$@8V%R=&5L;&$@9&D@9&5S=&EN
M87II;VYE(.@@9VEA('!R97-E;G1E(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S(S"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(')I;F]M:6YA<F4@;&$@9&ER96-T;W)Y
M(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S0T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(DEM<&]S<VEB:6QE(')I;F]M:6YA<F4@;&$@9&ER96-T;W)Y(%9&
M4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,U,2!L:6(O5D93+W-M8BYP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!R:6YO;6EN
M87)E(&EL(&9I;&4@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C8R.2!L:6(O5D93+VUU<W%L+G!H<#HR-#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@<FEN;VUI;F%R92!I;"!F:6QE(%9&4R`E<R\E<RXB"@HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8T
M(&QI8B]61E,O<W%L+G!H<#HS,S@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,S$U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,S-PIM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)I;&4@<FEN;VUI
M;F%R92!I;"!F:6QE(%9&4RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM
M<V=S='(@(DEM<&]S<VEB:6QE(&5S96=U:7)E("=M:VES;V9S)RXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA
M8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B
M26UP;W-S:6)I;&4@=')A9'5R<F4@<75E<W1O(&1O8W5M96YT;R!7;W)D(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ.#$T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A=&4@9F]R("5S
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&1A<F4@;"=A=G9I;R!A;&PG86=G:6]R
M;F%M96YT;R!F<F5E+V)U<WD@<&5R("5S(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C$U-"!L:6(O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM
M<&]S<VEB:6QE('-C<FEV97)E(&EL(&9I;&4@5D93(%PB)7-<(BXB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S:6)I;&4@
M<V-R:79E<F4@:6P@9FEL92!61E,@*&-O<'DH*2!F86EL960I+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,CDT(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T-B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+B(*;7-G<W1R("));7!O<W-I8FEL92!S8W)I=F5R
M92!L92!I;F9O<FUA>FEO;FD@;F5L(&9I;&4@5D93+B(*"B,Z(&QI8B]61E,N
M<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T
M82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("));7!O<W-I8FEL92!S8W)I
M=F5R92!I;"!F:6QE(%9&4RP@;&$@<75O=&$@8V]N<V5N=&ET82!V97)RX"!E
M8V-E9'5T82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4V]T=&]L:6YE
M871O(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD
M;R!#:&%N9V5S(@IM<V=S='(@(D%N;G5L;&$@36]D:69I8VAE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B
M56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B3F]N(&9A<F4@;&$@
M='5A('5L=&EM82!A>FEO;F4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(Q(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#@*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@(@IM<V=S='(@(E)I<W!O<W1A(&EN871T97-A(&1A;"!S
M97)V97(@9'5R86YT92!L82!C;VYN97-S:6]N93H@(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S,Y"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S8@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(E)I<W!O<W1A(&EN871T97-A(&1A;"!S97)V97(@83H@(@H*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@
M(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-PIM<V=I9"`B
M56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X"FUS9VED(")5;FET
M960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P"FUS9VED(")5;FET960@4W1A=&5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,SD*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C<X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-3@@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R
M(")38V]N;W-C:75T;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+B(*;7-G<W1R(").;VUE('5T96YT92!E('!A<W-W;W)D('-C;VYO<V-I=71I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R(").;VX@8V]L;&5G87)E(&PG96QE;65N=&\@8V]R<F5N=&4B"@HC
M.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*
M;7-G<W1R(")396YZ82!N;VUE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X
M-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(D5S=&5N<VEO;F4@;F]N('-U<'!O<G1A=&$B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%G9VEO<FYA
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B06=G:6]R;F$@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS
M9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")!9V=I;W)N82!U=&5N=&4B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B06=G:6]R;F$@7"(E
M<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5
M<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")38W)I<'0@9&D@8V%R
M:6-A;65N=&4@96QI;6EN871A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-S<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM
M<V=I9"`B57!L;V%D(@IM<V=S='(@(D-A<FEC82(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#4*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO
M;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")C87)I8V%T
M:2!T=71T:2!I(&9I;&4@9&D@:6UP;W-T87II;VYE(&1E;&QE(&%P<&QI8V%Z
M:6]N:2!S=6P@<V5R=F5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B8V%R871T97)I(&QA=&EN:2!M86EU<V-O;&DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(DYU;65R:2!R;VUA;FD@;6%I=7-C;VQI(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,0IM<V=I9"`B57)U9W5A>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B
M"FUS9W-T<B`B=7-A(&EL(&-O<G)E;G1E.B`E<R(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T
M<B`B57-A(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G
M:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N(@IM<V=S='(@(E5S82!S92!I;"!N;VUE('5T96YT92]P87-S
M=V]R9"#H(&1I9F9E<F5N=&4@9&$@<75E;&QA(&1E;"!S97)V97(@24U34"XB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED
M(")5<V5R(@IM<V=S='(@(E5T96YT92(*"B,Z(&QI8B](;W)D92]296=I<W1R
M>2YP:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T
M(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("),=71E;G1E("5S(&YO;B#H
M(&%U=&]R:7IZ871O('!E<B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*
M;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1V5S=&EO;F4@
M571E;G1I(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*;7-G:60@
M(E5S97(@3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI(%5T96YT:2(*"B,Z('-I
M9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(E)E9VES=')A>FEO;F4@571E;G1I(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92XB"FUS9W-T<B`B3&%R96=I<W1R87II;VYE(&1E9VQI('5T96YT
M:2#H('-T871A(&1I<V%B:6QI=&%T82!P97(@<75E<W1O('-I=&\N(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0Y-`IM<V=I9"`B57-E<B!A8V-O=6YT
M(&YO="!F;W5N9"(*;7-G<W1R(").;VUE('5T96YT92!N;VX@=')O=F%T;R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!L:6(O3F5T+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`B3F]M92!5=&5N=&4B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(DYO;64@571E;G1E(%PB)7-<(B#H(&=I
M82!P<F5S96YT92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").;VUE(%5T96YT93HB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(DYO;64@571E;G1E.B`B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M
M.B(*;7-G<W1R(")5=&5N=&D@;F5L('-I<W1E;6$Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,@IM<V=I9"`B57IB
M96MI<W1A;B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L
M:6(O5D93+V9I;&4N<&AP.C(V.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B3&$@9&ER96-T;W)Y(%9&4R!N;VX@97-I
M<W1E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@
M(E9A8V%T:6]N(@IM<V=S='(@(D%S<V5N>F$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@(@IM<V=S='(@(E!O<VEZ:6]N:2!V86QI9&4@=')O=F%T92!I;F-L=61O
M;F\Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED
M(")686QI9&ET>2(*;7-G<W1R(")686QI9&ETX"(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.3<*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N(@IM<V=S='(@(E9A;&]R92!I;B!M:6YU=&D@9&$@;W)A+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX-38@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(DEL('9A;&]R92#H(&UA9V=I;W)E
M(&1L;&$@;6%S<VEM82!L=6YG:&5Z>F$@9&D@)7,N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C8@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S,38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3`@
M;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A
M;'5E<R(*;7-G<W1R(")686QO<FDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O
M('-E;&5C="!F<F]M(@IM<V=S='(@(E9A;&]R:2!D86D@<75A;&D@<V5L97II
M;VYA<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0Y"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM
M<V=S='(@(E9A<FEA8FEL92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#4*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(E9E<FEF:6-A(&9A;&QI=&$@
M+2!Q=65S=&\@;65S<V%G9VEO('!U\B!E<W-E<F4@<W1A=&\@86QT97)A=&\@
M8V]N+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED
M(")697)S:6]N(@IM<V=S='(@(E9E<G-I;VYE(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S
M='(@(E9E<G-I;VYE(&1I($-O;G1R;VQL;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I
M8V%L(&%L:6=N(@IM<V=S='(@(D%L;&EN96%M96YT;R!V97)T:6-A;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS
M9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(E)I96UP:6UE;G1O('9E
M<G1I8V%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6-A;&4Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*
M;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")-;VQT;R!!;'1O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.`IM<V=I
M9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDW,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9I<W5A;&EZ>F$@)7,B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(@IM<V=S='(@(E9I<W5A;&EZ>F$@=6YA('!A9VEN82!W
M96(@97-T97)N82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")6
M:7-U86QI>GIA(&-O;64@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM
M<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")6:7-I8FEL:73@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET
M>3H@(@IM<V=S='(@(E9I<VEB:6QI=.`Z("(*"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY
M('9I82!33510(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R
M(")!5%1%3EI)3TY%(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(D%45$5.6DE/3D4A(2$@4DE-
M54]622!,3R!30U))4%0@34%.54%,345.5$4@1$$@)7,N(@H*(SH@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HY-2!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PIM<V=I9"`B5V%R;FEN9R(*;7-G
M<W1R(")!='1E;GII;VYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B364B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@
M1F]R96-A<W0B"FUS9W-T<B`B0F]L;&5T=&EN;R!M971E;W)O;&]G:6-O(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D)O;&QE='1I;F\@;65T
M96]R;VQO9VEC;R!F;W)N:71O(&1A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED(")7965K;'DB"FUS9W-T<B`B4V5T=&EM86YA;&UE;G1E(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS
M9W-T<B`B0F5N=F5N=71O(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHU-R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT"B,L('!H<"UF;W)M
M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B0F5N=F5N=71O(&$@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92P@)7,B"FUS9W-T<B`B0F5N=F5N=71O+"`E<R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X"FUS9VED(")797-T
M97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(E%U86QE
M(&%P<&QI8V%Z:6]N92!D;W9RX"!V:7-U86QI>GIA<F4@)7,@9&]P;R!L)V%C
M8V5S<V\_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G
M:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@
M(E%U86PGZ"!I;"!C87)A='1E<F4@9&D@9&5L:6UI=&%Z:6]N93\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-0IM<V=I9"`B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B475A
M;&4@<&QU9VEN<R!A8FEL:71A<F4@<&5R(&EL(%)I8V@@5&5X="!E9&ET;W(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B3&%R9VAE>GIA(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E=I9'1H(&EN($-34R!U
M;FET<R(*;7-G<W1R("),87)G:&5Z>F$@:6X@=6YI=.`@0U-3(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@HB3&%R9VAE>GIA(&1E;"!M
M96YU(&1I("5S('-U;&QA('-I;FES=')A("AA=G+@(&5F9F5T=&\@8V]L('!R
M;W-S:6UO(&%C8V5S<V\I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`B3&%R9VAE>GIA(&1E;&QA('1A8F5L;&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED
M=&@@=6YI="(*;7-G<W1R(")5;FETX"!D:2!L87)G:&5Z>F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B
M5VED=&@Z(@IM<V=S='(@(DQA<F=H97IZ83HB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS9W-T<B`B
M5F5N=&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM
M<V=S='(@(E9E;&]C:73@(&1E;"!V96YT;R!I;B!N;V1I(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9E;G1O
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@
M(E=I;F0Z("(*;7-G<W1R(")696YT;SH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B4V%G9V5Z>F$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`B3&%V;W)O(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("));F1I
M<FEZ>F\@9&5L(&QA=F]R;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F
M;VYO(&1E;"!L879O<F\B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y,R!L:6(O
M1FEL92]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B3G5M97)O(&1I(&-A;7!I(&5R<F%T;R!N96QL82!L
M:6YE82`E9"X@071T97-I("5D+"!T<F]V871I("5D+B(*"B,Z(&QI8B]&:6QE
M+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B
M3G5M97)O(&1I(&-A;7!I(&5R<F%T;RX@071T97-I("5D+"!T<F]V871I("5D
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N
M(@IM<V=S='(@(D-O;7!E;G-A>FEO;F4@<V)A9VQI871A("5D(&1U<F%N=&4@
M;&$@;&5T='5R82!D:2!U;B!F:6QE(%9&4RXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P
M.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B65E962(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B
M66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B06YN=6%L;65N=&4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4R"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B"FUS9W-T<B`B
M4VDB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(E-I+"!S;VYO(&0G
M86-C;W)D;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G
M<W1R("(B"B)396D@:6X@9F]R;6%T;R!T97-T;RX@57-A(&EL(&)O='1O;F4@
M6SP^72!P97(@=&]R;F%R92!A;"!F;W)M871O(%=94TE764<N(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B3F]N(&AA:2!I;"!P97)M97-S
M;R!D:2!C<F5A<F4@<&GY(&1I("5D(&)L;V-C:&DN(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-#(T"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R(").;VX@=&D@<V5I(&%U=&5N=&EC871O+B(*"B,Z(&QI8B](;W)D
M92])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(").
M;VX@<'5O:2!A=F5R92!I;"!C87)A='1E<F4@)UQ<)R!N96P@='5O(&YO;64@
M8V]M<&QE=&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F]N(&AA:2!I;G-E<FET
M;R!U;B!I;F1I<FEZ>F\@96UA:6P@=F%L:61O+B(*"B,Z(&QI8B](;W)D92]$
M871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB
M3F]N(&AA:2!A<W-O8VEA=&\@;F5S<W5N(&1E:2!C86UP:2!D86P@9FEL92!I
M;7!O<G1A=&\@8V]N(&D@8V%M<&D@(@HB8V]R<FES<&]N9&5N=&D@:6X@)7,N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")396D@<W1A=&\@9&ES8V]N;F5S
M<V\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG
M:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)$979I(&EN
M<V5R:7)E('5N(&YU;65R;R!D:2!C96QL=6QA<F4@=F%L:61O+"!C;VYT96YE
M;G1E('-O;&\@;G5M97)I(&-O;B`B"B)L)V]P>FEO;F4@9&5L("<K)R!P97(@
M:2!P<F5F:7-S:2!I;G1E<FYA>FEO;F%L:2XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V
M86QU92XB"FUS9W-T<B`B1&5V:2!I;G-E<FER92!U;B!V86QO<F4@=F%L:61O
M+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N(@IM<V=S='(@(D1E=FD@8V]N9FEG=7)A<F4@=6X@8F%C:V5N9"!P
M97(@:6P@1&%T851R964@<&5R('5S87)E(%-I9VYU<',N(@H*(SH@;&EB+TAO
M<F1E+G!H<#HT-S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+B(*;7-G<W1R(")$979I(&-O;F9I9W5R87)E('5N(&)A8VME;F0@
M5D93+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS
M9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B1&5V:2!P
M<FEM82!D97-C<FEV97)E(&EL('!R;V)L96UA('!R:6UA(&1I(&UA;F1A<FQO
M(&-O;64@<F5P;W)T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")$979I(&EN<V5R
M:7)E(&PG55),(&%L;&$@<75A;&4@<'5N=&$@<75E<W1O(&-O;&QE9V%M96YT
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S
M='(@(D1E=FD@<V5L97II;VYA<F4@=6X@<V5R=F5R(&1A(&5L:6UI;F%R92XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(D1E=FD@<W!E
M8VEF:6-A<F4@=6X@=71E;G1E(&1A(&%Z>F5R87)E+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92XB"FUS9W-T<B`B1&5V:2!S<&5C:69I8V%R92!U;B!U=&5N
M=&4@9&$@<FEM=6]V97)E+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")$979I('-P
M96-I9FEC87)E('5N('5T96YT92!D82!A9V=I=6YG97)E+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")$979I('-P96-I9FEC87)E('5N
M('5T96YT92!D82!A9V=I;W)N87)E+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")$979I('-P96-I9FEC87)E('5N
M)V%Z:6]N92!D82!E<V5G=6ER92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")$979I('-P96-I9FEC87)E(&EL
M(&YO;64@9&5L;&$@;G5O=F$@8V%T96=O<FEA+B(*"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O
M('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B1&5V
M:2!I;G-E<FER92!U;B!N=6UE<F\@9&D@=&5L969O;F\@:71A;&EA;F\B"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("),82!T=6$@<V5S<VEO;F4@)7,@Z"!S8V%D=71A+B!3
M:2!P<F5G82!D:2!C;VQL96=A<G-I(&YU;W9A;65N=&4N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@
M061D<F5S<R(*;7-G<W1R("));"!T=6\@:6YD:7)I>GIO($5M86EL(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A
M9&1R97-S.B(*;7-G<W1R("));"!C86UP;R!$83H@9&5L('1U;R!I;F1I<FEZ
M>F\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(DQE('1U92!I;F9O<FUA>FEO;FDB"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB26P@='5O
M(&EN9&ER:7IZ;R!);G1E<FYE="#H(&-A;6)I871O(&1A;&PG:6YI>FEO(&1E
M;&QA('1U82!S97-S:6]N92`E<RX@4&5R("(*(G!R;W1E9V=E<F4@;&$@='5A
M('-I8W5R97IZ82P@9&5V:2!R:6-O;&5G87)T:2!N=6]V86UE;G1E+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B26P@='5O($YO;64B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB26P@='5O(&)A8VME;F0@
M9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&PG86=G:75N=&$@9&D@
M;G5O=FD@=71E;G1I+B!392`B"B)V=6]I('5S87)E($AO<F1E('!E<B!G97-T
M:7)E(&=L:2!U=&5N=&DL(&1E=FD@=7-A<F4@=6X@8F%C:V5N9"!D:2`B"B)A
M=71E;G1I8V%Z:6]N92!D:69F97)E;G1E(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(DEL('1U;R!B86-K96YD(&1I(&%U
M=&5N=&EC87II;VYE(&YO;B!S=7!P;W)T82!L)V5L96YC;R!D96=L:2!U=&5N
M=&DL(&\@;&$@(@HB9G5N>FEO;F4@Z"!S=&%T82!D:7-A8FEL:71A=&$@<&5R
M(&%L=')E(')A9VEO;FDN(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E-E;6)F<F$@8VAE(&EL('1U
M;R!B<F]W<V5R('-I82!C86UB:6%T82!D86QL)VEN:7II;R!D96QL82!T=6$@
M<V5S<VEO;F4@)7,N("(*(E!E<B!P<F]T96=G97)E(&QA('1U82!S:6-U<F5Z
M>F$L(&1E=FD@86-C961E<F4@;G5O=F%M96YT92XB"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HU-PIM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("));"!T=6\@8G)O=W-E<B!N
M;VX@<W5P<&]R=&$@<75E<W1A(&9U;GII;VYE+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N
M=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB26P@
M='5O(&)R;W=S97(@;F]N('-U<'!O<G1A('%U97-T82!O<'II;VYE(&1I('-T
M86UP82X@4')E;6D@0V]N=')O;"]#;VUM86YD("(*(BL@4"!P97(@<W1A;7!A
M<F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U
M<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B26P@='5O(&9U<V\@;W)A
M<FEO.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("),
M82!T=6$@:61E;G1I=.`@9&D@9&5F875L="#H('-T871A(&UO9&EF:6-A=&$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("),82!T=6$@:61E;G1I=.`@9&D@
M9&5F875L=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED
M(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B26P@='5O(&YO;64@8V]M<&QE
M=&\Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L
M;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B3&$@='5A(&QO9VEN(.@@<V-A
M9'5T82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S(@IM<V=S='(@(DQA('1U82!N=6]V82!P87-S=V]R9"!P97(@)7,@Z#H@
M)7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("),92!T=64@;W!Z:6]N:2!S;VYO
M('-T871E(&%G9VEO<FYA=&4@<&5R(&QA(&1U<F%T82!D:2!Q=65S=&$@<V5S
M<VEO;F4N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B3&4@
M='5E(&]P>FEO;FD@<V]N;R!S=&%T92!A9V=I;W)N871E+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T(@IM<V=S='(@(DQA('1U82!P87-S=V]R9"#H('-T
M871A(&%Z>F5R871A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A
M<W-W;W)D+B(*;7-G<W1R("(B"B),82!T=6$@<&%S<W=O<F0@Z"!S=&%T82!A
M>GIE<F%T82P@8V]N=')O;&QA(&QA('1U82!E;6%I;"!E(&%C8V5D:2!C;VX@
M;&$@='5A("(*(FYU;W9A('!A<W-W;W)D+B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM
M<V=S='(@(DQA('1U82!P87-S=V]R9"#H('-C861U=&$N(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S
M97)V97)S.B(*;7-G<W1R("))('1U;VD@<V5R=F5R(')E;6]T:3HB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-38*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W"FUS9VED(")::6UB
M86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D
M(%1E>'1=(@IM<V=S='(@(EM.87-C;VYD:2!I;"!T97-T;R!C:71A=&]=(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E
M<&]R=%TB"FUS9W-T<B`B6U)E<&]R="!D96P@<')O8FQE;6%=(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6TUO<W1R82!I;"!T97-T;R!C
M:71A=&\@+2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T
M960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");36]S=')A(&EL('1E<W1O
M(&-I=&%T;R`M("5S(&QI;F5E72(*"B,Z(&QI8B](;W)D92YP:'`Z,C`T"B,L
M('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");
M;&EN96$@)7,@9&D@)7-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-34T('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")?06UM:6YI<W1R87II;VYE(@H*(SH@;&EB+V%P:2YP:'`Z
M,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B
M7T1E;&5T92!2;W<B"FUS9W-T<B`B7T-A;F-E;&QA(%)I9V$B"@HC.B!L:6(O
M87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!P:2(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S
M='(@(E]!:75T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B<')O<')I973@(&1E;&PG7TEM;6%G:6YE+BXN(@H*(SH@
M;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R
M(")?16YT<F$B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?
M3&]G(&]U="(*;7-G<W1R(")?17-C:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF
M>2!,:6YK+BXN(@IM<V=S='(@(E]-;V1I9FEC82!#;VQL96=A;65N=&\N+BXB
M"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R(")?3W!Z:6]N:2(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B
M7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]097)M97-S:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I
M9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]%;&EM:6YA($-O;&QE9V%M
M96YT;RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(E]);7!O<W1A>FEO;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65TX"!D96QL82!?5&%B96QL
M82XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S
M='(@(E5T96YT:2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(U"FUS9VED
M(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B<G5B<FEC82(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B:6YD:7)I>GII('-C;VYO<V-I=71I(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(F-A
M;&5N9&%R:6\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(F-A;&UO(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(FYO;B!P;W-S;R!C<F5A<F4@:6P@9FEL92!D:2!O=7!U="(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@
M:6YP=70B"FUS9W-T<B`B;F]N('!O<W-O(&%P<FER92!L)VEN<'5T(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P,`IM<V=I9"`B8VQI8VL@
M:&5R92(*;7-G<W1R(")P<F5M:2!Q=6DB"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O
M<B(*;7-G<W1R(")E<G)O<F4@;F5L;"=U<V\@9&5L;&$@;&EN96$@9&D@8V]M
M86YD;R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I
M9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")E<G)O<F4@9&D@8V]N
M9FEG=7)A>FEO;F4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED
M(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")E<G)O<F4@;F5L(&9O<FUA
M=&\@9&5L;&$@9&%T82(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B<'5B8FQI8V$B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N
M9"(*;7-G<W1R(")E;G1R>2!N;VX@=')O=F%T82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")F86QL:6YG(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.38*;7-G:60@
M(F9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<R(*;7-G<W1R(")D86P@)7,@*"5S*2!A;"`E<R`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R(")N;VUE(&AO<W0@<V-O;F]S8VEU=&\B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,R!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B:6UM961I871O(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")E<G)O<F4@9&D@
M:6YP=70O;W5T<'5T(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")E
M<G)O<F4@:6YT97)N;R!D96P@<V]F='=A<F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S
M='(@(FQI;F5E72(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")E<G)O<F4@9&D@8V]D:6-E
M("5D(&1I(&UK:7-O9G,@9'5R86YT92!L82!S8W)I='1O<F$@25-/+B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S`*;7-G:60@
M(FUM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C@U
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S0*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(T,PIM<V=I9"`B;F%M92(*;7-G<W1R(")N
M;VUE(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP
M;&5M96YT960B"FUS9W-T<B`B;F]N(&EM<&QE;65N=&%T;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L
M96UE;G1E9"(*;7-G<W1R(")N;VX@86YC;W)A(&EM<&QE;65N=&%D;R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S
M='(@(F)L;V-C;R!N;W1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R
M(")P97)C96YT;R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W
M-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B<&5R;65S<V\@
M;F5G871O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(F5R<F]R92!R96UO=&\@;F5L('!R
M;W1O8V]L;&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL
M86)L92(*;7-G<W1R(")S97)V:7II;R!N;VX@9&ES<&]N:6)I;&4B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E
M;F-E<R(*;7-G<W1R(")M;W-T<F$@;&4@9&EF9F5R96YZ92(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B
M<W1E861Y(@IM<V=S='(@(F-O<W1A;G1E(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B
M97)R;W)E(&1I('-I<W1E;6$B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS
M,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(F5L96YC;R!A='1I=FETX"(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M
M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B9W5A<W1O('1E;7!O<F%N96\B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;2(*;7-G<W1R(")S8W)I=FD@;&$@<&%S<W=O<F0@9'5E('9O;'1E('!E<B!C
M;VYF97)M87)E(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI
M9FEC871O(@H*(SH@;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@
M(G5N;F%M960B"FUS9W-T<B`B<V5N>F$@;F]M92(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(G5T
M96YT92!S96QE>FEO;F%T;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM
M<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O
M+VAO<F1E+G!O=```````````````````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`U-S4Q-C$`,3`U,34T,S$P-C,`,#$V-C<Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@4T]-12!$15-#
M4DE05$E612!4251,12X*(R!#;W!Y<FEG:'0@*$,I(%E%05(@2&]R9&4@4')O
M:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M
M92!L:6-E;G-E(&%S('1H92!004-+04=%('!A8VMA9V4N"B,@1DE24U0@0554
M2$]2(#Q%34%)3$!!1$1215-3/BP@645!4BX*(PHC+"!F=7IZ>0IM<V=I9"`B
M(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@4$%#2T%'12!615)3
M24].7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#<M,S$@,3@Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@645!4BU-3RU$02!(3SI-22M:
M3TY%7&XB"B),87-T+51R86YS;&%T;W(Z($953$P@3D%-12`\14U!24Q`041$
M4D534SY<;B(*(DQA;F=U86=E+51E86TZ($Q!3D=504=%(#Q,3$!L:2YO<F<^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/4-(05)3151<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<T"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDU"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y,0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y,PIM<V=I9"`B
M("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,X.0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,#<*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DU"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R
M964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-3DT"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A
M>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-3`@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU,38*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38Q(&QI8B]";&]C:R]M971A<BYP:'`Z,38W
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Q"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0W(&QI8B]";&]C:R]M971A<BYP:'`Z,S4S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDU,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDT
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDV,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,"!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@
M)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$T-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO
M=7(@1F]R;6%T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S$*;7-G
M:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDT-`IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$W-PIM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$P.`IM<V=I9"`B(@HB02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,C4*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!
M32!,:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!286EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S
M"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")!32!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4T"FUS9VED(")!8F]U
M="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM
M<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR.#$*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$S-0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT
M(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z
M96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC
M.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,S$@861M:6XO9W)O=7!S+G!H<#HR,S(*;7-G:60@(D%D9"!#:&EL9"!'
M<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@
M(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-@IM<V=I
M9"`B061D($UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!.97<@1W)O
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!
M9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE
M=R!U<V5R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D
M9"!P86ER(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E
M<W,@8F]O:SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B
M;V]K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!
M9&0@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3<*;7-G:60@(D%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!
M;&)A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B06QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8V"FUS9VED(")!;&P@075T
M:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(X"FUS9VED(")!;&P@1W)O=7!S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I
M9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L
M;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X.#D*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,Q"FUS9VED
M(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU
M,#<*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO
M9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#0*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.38*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,V"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B
M06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X
M>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT
M:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@
M3&ES="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,Y
M"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3D*;7-G:60@(D%P<&QY('1O
M($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G
M:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!
M<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED
M(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY
M('-U8BUG<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R
M9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED
M(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B
M07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(R"FUS9VED(")!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C`*;7-G:60@(D%U=&A?:6UA<#H@4F5Q
M=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*
M;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H
M7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS
M9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!9&UI;BYP:'`Z,3`S"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.30*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*
M;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"
M86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC
M:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G
M:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A
M;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED
M(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDT,B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#4P(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G
M:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S
M:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A
M9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-#0@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,U"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,C(*;7-G:60@(D-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E
M<W1I;F%T:6]N(&%R92!T:&4@<V%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@
M(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU,3`@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`U"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S4Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.#<*
M;7-G:60@(D-A;FYO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W
M:71H:6X@<V]U<F-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E
M9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ
M,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV,3$*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,0IM<V=I9"`B0V%N;F]T(')E<V5T
M('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@
M(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS
M9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)
M4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I
M9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I
M;VXZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@
M(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.34*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@
M475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E
M<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*
M;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#8*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM
M<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")#;&]U9'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R
M+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM
M<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,S.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,#,@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C0*;7-G:60@(D-O;'5M
M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y
M"FUS9VED(")#;VUP86YY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I
M9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HY,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,T"FUS9VED(")#
M;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C`T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T-PIM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(P-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-#<*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDY"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C@P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X.`IM<V=I
M9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-3`@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-S<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM
M<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O
M9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT
M<R!O9B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S`@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS
M9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#@Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B
M0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3@V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P-C0*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,3(P"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT.#(*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q,S<*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HY-C(*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W
M<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-@IM<V=I9"`B(@HB0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#8*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0Q-`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,C`*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#(V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(T"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R.`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*
M;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T
M,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V,PIM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S
M7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM
M<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R
M96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY-@IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B
M0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K
M+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R
M<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B
M0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*
M;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.3`*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B
M1&%I;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS
M9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R.#@*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,38*;7-G:60@
M(D1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS
M9VED(")$87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@
M(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B
M1&5F875L="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O261E;G1I='DN<&AP.CDX"FUS
M9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW-0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN
M:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C<*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C<Q"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3<*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-#`@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C`U(&%D;6EN+V=R;W5P<RYP:'`Z,C,S"FUS9VED(")$96QE
M=&4@1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4Q"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS
M9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@
M(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-@IM<V=I
M9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q,`IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,3D*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-@IM<V=I9"`B1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X
M"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS
M9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C(*;7-G:60@(D1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I
M9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T
M("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV
M"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U
M,PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G:60@
M(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C$*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,C4*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U
M9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL
M+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R
M;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16-U861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C(P-`IM<V=I9"`B161I="!'<F]U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N
M<R!F;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X.#<*;7-G:60@(D5M86EL(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Q
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-PIM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL
M+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-#`*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R
M;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,34*;7-G:60@(D5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V,#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%
M9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M-@IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM
M86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T
M97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY,B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#@*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R
M;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8*
M;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S,@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X-`IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@U"FUS9VED(")%=F5R>2!M:6YU=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*
M;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z.#(@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*
M;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM
M<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP
M;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-@IM<V=I9"`B1E10
M('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY
M.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4R,R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#@S"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*
M;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(T,`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B
M1F5B<G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C(*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(P"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F5W
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38R"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,T,PIM<V=I9"`B1FEG;&5T
M($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,T-PIM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-3<*;7-G:60@(D9I;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@
M3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,#`*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I
M;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&
M:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW
M-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@
M(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*
M;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(X,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`V"B,L
M('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S,V"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O
M="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T
M=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*
M;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,PIM<V=I9"`B1G)E97II;F<@1')I>GIL92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-2!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E
M9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA
M;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$W.2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I
M9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")'
M;V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES8V%L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#4*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(T
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-`HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M.`IM<V=I9"`B1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS
M9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@Y
M"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM
M<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B
M2&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HR,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-S4@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M
M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B
M2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM
M<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*
M;7-G:60@(DAO7VUE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C(Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S
M(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C@U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3,X"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3,V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I
M9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,S(*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S,*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<T"FUS9VED("))8V]N<R!W
M:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$X-0IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4R"FUS9VED("(B"B))9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E
M(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*
M;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M=&5D(&9I96QD.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T
M"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HU,PIM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T
M92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q
M"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-0IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("))
M;F9O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,S4*;7-G:60@(DEN:&5R:71E9"!-96UB
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@
M069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*
M;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G
M:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*
M;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,T"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y
M;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*
M;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM
M<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("))
M;G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R
M="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,C4*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O
M('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS
M97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D
M:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("))
M;G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G
M:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V
M-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS
M9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3<V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED
M("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G
M:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@
M(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I
M9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U
M8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O
M8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N
M=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$Q-R!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R.3<*;7-G
M:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I
M9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(V"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I
M9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N
M97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED
M(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E
M;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*;7-G:60@
M(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M($-R96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED
M(")+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@
M=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U
M86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L
M92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM<V=I9"`B3&%S="!087-S
M=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34S"FUS9VED
M("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*
M;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I
M9"`B3&%Y;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A
M;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$U"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4W"FUS9VED("),979E;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-PIM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@
M4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H
M="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*
M;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$W
M"FUS9VED("),:6YK(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#,R"FUS9VED("),:6YK(&%C8V5S<R!K97DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@R,PIM<V=I9"`B3&EN
M:R!T87)G970B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@R,`IM<V=I9"`B3&EN:R!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X.3,*;7-G:60@(DQI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@R.0IM
M<V=I9"`B3&EN:R!T:71L92!A='1R:6)U=&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM
M<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B
M3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,S"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C8P,0IM<V=I9"`B3&ES
M="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HV,#,*;7-G:60@
M(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3D*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HV,#`*;7-G:60@
M(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y.`IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3<*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W
M"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C`T('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-PIM<V=I
M9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DX"FUS9VED("),;V<@
M;W5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,0IM
M<V=I9"`B3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T
M97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM
M<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G
M:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME
M(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L
M87=I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES
M="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L
M(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*
M;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA<F=I;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HT.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C0Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@
M26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.`IM<V=I9"`B
M36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S`P"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U
M<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ.#$*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM
M<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4W
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS
M9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS
M9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F
M:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N
M($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C@R"FUS
M9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED
M(")-:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,@IM<V=I9"`B36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM
M<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,U"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$T"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I
M9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B36]D97)A
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*
M;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED
M(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`R"FUS9VED(")-;VYT:"!A
M;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*
M;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-
M;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S<*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X
M"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO
M=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V92!,969T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,#(*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C`*;7-G
M:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@
M06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C0T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0R"FUS9VED(")->2!0
M;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M
M:6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S
M8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W
M"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE
M='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@S"FUS9VED(").979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE
M=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H
M;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W
M(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I
M9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I
M9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED
M(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O
M<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z,3`V"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG
M97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S
M"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A
M;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C4Q"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W."!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,0HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V-PIM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-S(W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<W,@IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,3@*
M;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M
M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@
M<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ
M,#`*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T
M:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP
M.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS
M9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I
M9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW
M-3,*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I
M9"`B3F\@<G5L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8P.0IM<V=I9"`B3F\@<W5C
M:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T-@IM<V=I9"`B3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R-PIM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY-0IM<V=I9"`B3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU
M<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*
M;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,C0*;7-G
M:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HS-#@*;7-G:60@(DYO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HY-0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@
M(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$V,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W.`HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$Y,@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-R!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,SD@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C@S(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,#`*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S,R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-#<@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,V-`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,SDW
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HT-3<*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4S-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C`U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HV,C(*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C@@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU
M;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM
M<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU
M;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,@IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*
M;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X
M"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E
M;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@R-@IM<V=I9"`B3VYC;&EC:R!E=F5N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y.#D*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS
M9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N
M<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HT,2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U-0IM<V=I9"`B3W!T
M:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N
M:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M
M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I
M9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*;7-G:60@(D]T:&5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S(*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I
M9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R.#4*;7-G:60@(E!'4"!$:6=I=&%L
M(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S,Q"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,X
M,PIM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,V-0IM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-CD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!286EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0R"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0T"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*
M;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X-@IM<V=I9"`B
M4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,C$U"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE
M<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4&%R=&QY
M($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#,V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A
M<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<Q"FUS9VED(")087-S=V]R9"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S
M<W=O<F0Z("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C
M:"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*
M;7-G:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI
M<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@
M4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`S
M"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R
M;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C$R"FUS9VED(")097)M:7-S:6]N
M($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM
M<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A
M9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S
M;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B
M4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A
M:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#`*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4X"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#8U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B
M"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G
M:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM
M<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM
M<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8X(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<S"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET
M871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET
M871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+VQD87`N<&AP.C$P-`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@
M(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C<*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8Q"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T
M"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED
M(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.30*;7-G:60@(E!R
M;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B
M4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@
M26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E
M;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M
M97-S86=E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A
M<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@
M(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX
M,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!
M(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(X,@IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0W"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0Y"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E)A
M:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4R"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I
M9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#$*;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@
M;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE
M=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O
M<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#0@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C$P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T.`IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S.`IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30T('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(Q,`IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(X"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B
M4F5M;W9E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3D*;7-G:60@
M(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA
M='1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HR,#$*;7-G:60@(E)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ-#0*;7-G:60@(E)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@
M(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#4@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HW,S,@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<W.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z.#`P"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-@IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#@*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(X"FUS
M9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S$*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S(@861M:6XO8VUD
M<VAE;&PN<&AP.C(Y(&%D;6EN+W-Q;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R
M;B!T;R!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2
M:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C8*;7-G
M:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G
M:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E
M9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A
M;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS
M9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G
M:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y,@IM<V=I9"`B4U%,('-T871E;65N
M="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HR,3D*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM
M<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I
M;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I
M;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I
M<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38V"FUS9VED("(B"B)3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE
M;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED
M(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I
M;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3D*;7-G:60@(E-E
M;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0T"FUS9VED(")396QE8W0@82!N97<@;W=N97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P
M"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-3<*;7-G:60@(E-E;&5C="!A('5S97(@
M=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,0IM<V=I9"`B4V5L
M96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&YO;F4B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED
M("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T
M:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDR
M"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG
M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*
M;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@
M=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P
M,PIM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0T"FUS9VED(")396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$X"FUS9VED(")396YS;W(Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@
M86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM
M<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S
M:6]N($%D;6EN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E
M>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,3$*;7-G:60@
M(E-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,S(*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM
M<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I
M9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B
M4VAO<G0@4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#0S"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E-H;W<B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-`IM<V=I9"`B(@HB4VAO
M=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE
M(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W"FUS9VED(")3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,PIM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0V"B,L('!H<"UF;W)M870*;7-G:60@
M(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-34*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VAO=V5R<R!I;B!T
M:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED
M(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G
M:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-N
M;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B4VYO=R!3:&]W97)S
M($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#`*
M;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X-`IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS
M9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@
M2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM
M<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q
M"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*
M;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D
M<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T
M<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X.3$*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$X"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q
M=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L
M;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C,*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@
M(E-U<FYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A
M;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3
M=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@
M(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C0*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O<FT@86YD
M(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$W,`IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@
M<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")486EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@
M0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI
M<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E
M=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M-3@@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3D*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E
M;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3(*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")496UP97)A
M='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S0U"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S(*;7-G:60@(E1E>'0@3VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*
M;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)
M4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#8S"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H
M<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDV-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G
M:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I
M9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L
M;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HQ.3`@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3(@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,C0*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,S4@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3,*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C4@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,#0*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B
M"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3@Q
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I
M9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG
M(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B
M"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A
M;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES
M=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L
M;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS
M9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J
M96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@Y-0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN
M9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F
M:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<RYP:'`Z,C@X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F
M97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T
M+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R
M<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL
M:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<Y
M"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O
M=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(P"FUS9VED
M(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT
M(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G
M:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K
M+T1A=&$O1&%T82]T<W8N<&AP.C$W-@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O
M('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L
M;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI
M<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S`*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C
M;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,CDY"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I
M82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`T-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DV"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-C<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-C@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C8U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#(S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,S$*;7-G:60@(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0S-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F
M:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@
M;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L
M;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*
M(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T
M+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#DU"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R
M;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C
M;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED
M(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ.#8*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5&AU
M;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T-#,@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4W"FUS9VED(")4:6UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-30Y
M"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4
M:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB
M=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G
M:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4;V\@;6%N>2!I
M;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R
M86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@
M;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M-S,*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN
M9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I
M9"`B55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B
M55),.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,C@*;7-G
M:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`Q(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-C4@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HY-`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#@R"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0Q(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(T-@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C,S(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(T
M-@IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,W,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C8Y"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R,PIM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-0HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-3(*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C@R"FUS9VED(")5;F%B;&4@=&\@
M9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(S,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,T-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0U,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0P
M,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#`W"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U,R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS-#8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,U-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#<U(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#@W"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,3D@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S0*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#8@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0S.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#0V"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0V-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0V"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP
M:'`Z-#,W(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C$Q(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q-@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DX(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#,*;7-G:60@(E5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C<T(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,CDS(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-3<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$V,`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C@V(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.34*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX-#,*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX-S@*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AS:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDQ"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$T-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,@IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X,"!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C,R(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.#$@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(Q,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M-#8S(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-@IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ.#,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U
M<&1A=&4@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,3<X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,3@Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$X.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,CDW(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-C4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,`IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-3,*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#(W
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C0*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C0Q-0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HT,C$*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B
M56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")5;FET<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@
M(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+TED96YT:71Y+G!H<#HS,#0*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B
M"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR
M-PHC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<W(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3@U"FUS9VED(")5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A
M<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G
M:60@(E5S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HW-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E
M<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T
M-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP
M:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N
M;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W.`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S0*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I
M9"`B57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M
M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G
M:60@(E5S97)N86UE.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S,@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<Q"FUS9VED(")61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A
M;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-C(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(X-`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S,T(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(P-`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R
M:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU
M96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G
M:60@(E9E<G-I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<T"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.3<Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q,0IM<V=I9"`B5FES:6)I;&ET>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R
M"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@
M(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S
M"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.CDU"FUS9VED(")787)N
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E
M8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")7
M96%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(E=E96ML>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A
M=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R
M96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN
M<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI
M=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM
M<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G
M:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5VEN9"!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")7
M:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34X"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7
M:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B
M5V]R:R!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D
M:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y
M=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L
M=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME
M>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4V"FUS9VED(")965E9(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO
M;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")9
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R
M"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O261E;G1I='DN<&AP.C,Q,`IM<V=I9"`B66]U(&-A;FYO="!H879E
M('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3DS"FUS9VED(")9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#<*;7-G
M:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-C4*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G
M:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,#<*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN
M9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN
M:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT
M("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-PIM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@
M<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-3,*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34S"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.38*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@
M:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S8*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#`*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R
M96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M
M(%)E<&]R=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C(P,PHC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(R,PIM<V=I9"`B7T-,22(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,#<*;7-G:60@(E]$871A5')E92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$Y.0IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B
M7T]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,C`S"FUS9VED
M(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M
M;W9E($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3DQ"FUS
M9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ.34*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDU,0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED
M(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDT,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I
M9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N
M;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R
M"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@
M(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW-0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.38*;7-G:60@(F9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S8@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED
M(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G
M:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-"!A9&UI;B]S971U<"]D:69F+G!H<#HW
M-@IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF
M;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI
M;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3<T"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR-#,*;7-G:60@(FYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(R
M,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-0IM<V=I9"`B;F]T97!A9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE
M;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW-PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A
M:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS
M9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S8*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.34Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F
M86EL=7)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE
M('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C0@861M:6XO<V5T=7`O9&EF9BYP:'`Z-S8*
M;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A
M<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM
M<V=S='(@(B(*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]M:U]-2RYP;P``````
M````````````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C$Q
M-C0V`#$P-3$U-#,Q,#8S`#`Q-C0P,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C('1R86YS;&%T:6]N(&]F(&UK7TU++G!O
M('1O($UA8V5D;VYI86X*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD
M97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#,@175R96MA($EN9F]R;6%T:6MA"B,@4W1O:F%N
M(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SXL(#(P,#,*(PIM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@;6M?34M<;B(*(E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`S+3`V+3(V(#$U.C$X*S`R,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@4W1O:F%N(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SY<
M;B(*(DQA;F=U86=E+51E86TZ($UA8V5D;VYI86X@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TU7&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)8+4=E;F5R871O<CH@2T)A
M8F5L(#$N,"XQ7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M
M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H
M<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R
M97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(./AW]7H
MW=X@U-[4T-35W2#=T"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A
M=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(+[?U>#0YMC8
M(-?0(-[4X-;CTM#ZU2`M(+_>XM+@U-`B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!
M9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("*RVMOCY]@@
MT-K>(.'0VM#H(-30(-C7TN#HV.@@W=7:WM@@WM_5X-#FV-@@TMX@W-[<U=WB
MWM(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R("*PU.#5X=#@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M
M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O
M9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S
M=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS
M9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@
MY]#AT"(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT
M,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS
M9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO
M4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS
M"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N
M="!087-S=V]R9"(*;7-G<W1R("*_WN+2X-38(-O>U]C=VM`B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G
M:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S
M='(@(K#4X-7AT"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(K3>U-#4
MV"#:WN#8X=W8VB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A
M(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T
M<B`BM-[4T-38(-W>TB#:WN#8X=W8VCHB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("*T
MWM30U-@@W=[2(-K>X-CAW=C:.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(K3>U-#4V"#?T.`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ
M(@IM<V=S='(@(K#4X-7AT.`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`BL-3@U>'0X"(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("*TWM30U-@@VM[@V.'=
MV-HB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*
M;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(K3>U-#2T/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W
M,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S
M(@IM<V=S='(@(K#4X-7AT"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,SD*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("*P
MU.#5X=#@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ
M.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("*PU-S8W=CAXN#0YMCXT"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*
M;7-G<W1R("*PU.#5X=`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A
M;FEA(@IM<V=S='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I
M9"`B06QG97)I82(*;7-G<W1R(")!;&EA<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S
M='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T
M<B`B06QI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D
M(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M
M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B
M06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT
M97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA
M;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM
M<V=S='(@(K+0Z-`@16UA:6P@T-3@U>'0.B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-PIM<V=I9"`B06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP
M.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I
M;VXB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS
M9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!
M<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C
M:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE
M=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S
M8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF
M:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O
M;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED
M(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I
M9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM
M<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R
M("*TWN'BT-_=V"#?WMO8^M`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A
M:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*
M;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"
M86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@
M:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H
M<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM
M<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC
M<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S
M"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I
M=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM
M<V=S='(@(L#>U-7=U-7=(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<
M(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED
M(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"FUS9VED(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O
M;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z
M>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E
M<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M;W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@
M(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(D)R87II;"(*;7-G<W1R("*_WNCBT"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B
M0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I
M9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W
M<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(KW5X^'?U>C=
MT"#:WMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM
M<V=I9"`B0V%N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I
M9"`B0V%N8V5L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`BON+:T-;8(+_@WM';U=P@P-7?WN#B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I
M9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@
M(D-A<'1I;VXB"FUS9W-T<B`BM]#GX]+0^"#>W^;8V"(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*
M;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I
M9"`B0V5L;"!0:&]N92(*;7-G<W1R("*\WM'8V]7=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(KS>T=C;U=TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM
M<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#
M96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN
M9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W
M-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(KS>T=C;U=TB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)
M4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA
M;F=E(@IM<V=S='(@(K[BVM#6V"#3V"#?X-[<U=W8XM4B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(K_>XM+@U-@@V][7V-W:T"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB
M0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T
M<B`BO=#AV][2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@
M4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG
M-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`BO][BTN#4V"#;WM?8W=K0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B
M0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T
M;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE
M87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U
M<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@
M(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O
M;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@
M2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R("*WT.+2WN#8(-/>(-_@WM?>X-7FWN(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS
M9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN
M('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@
M(L38X-S0(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM
M86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R
M;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+$V.#<T"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I
M=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG
M=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B
MO][BTN#4V"#;WM?8W=K0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#0U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I
M9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R
M("+!WM3@UMC=T"#=T"`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED
M(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY
M"FUS9VED(")#;W!Y(@IM<V=S='(@(L38X-S0(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("*XW-_>X.+8X-#=WB#?WMO5.B`E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*
M;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS
M9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD
M(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(B"FUS9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5
MX-[B+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB
M('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*
M;7-G<W1R("*\WM3CV][B(-W0(-?0U-#GT.+0(-?0(-[4X-;CTM#ZU2`E<R#=
MU2#<WM;5(-30(-'8U-4@WN+2WN#5W2(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BO-[4X]O>XB#=T"#7T-30Y]#B
MT"#7T"#>U.#6X]+0^M4@)7,@W=4@W-[6U2#4T"#1V-35(-[BTM[@U=TB"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU
M,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(KW5X^'?U>C=T"#:
MWMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92#=U2#5(-_@T-+8V]W>(-K>W>38
MT^/@V.#0W2(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5
MVN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG
M="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y
M"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED
M(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I
M9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S
M97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED
M(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N
M="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@
M:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED
M(")#=7)R96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R
M96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y
M;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H
M<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`BM-W5TMW>(@H*
M(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W
M<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S.3D*(RP@9G5Z>GD*;7-G:60@(D1A=&4B"FUS
M9W-T<B`BN-?1X-CHV"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F
M=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(K3=U=+=WB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC+"!F
M=7IZ>0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`BN-?1X-CHV"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS
M9VED(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I
M;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT
M(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#
M;VQO<B(*;7-G<W1R("*ZWN#8X>+8(.'BT-W4T.#4W=`@TN#5U-W>X>(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$
M969A=6QT($ED96YT:71Y(@IM<V=S='(@(L'BT-W4T.#4U=T@V-35W>+8XM7B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED
M(")$969A=6QT(%-H96QL(@IM<V=S='(@(L'BT-W4T.#4U=T@V-35W>+8XM7B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET
M:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`BN-?1X-CHV"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B
MN-?1X-CHV"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T
M<B`BN-?1X-CHV"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("*XU]'@V.C8
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-E
M;&PB"FUS9W-T<B`BN-?1X-CHV"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!C;VQU;6XB"FUS9W-T<B`BN-?1X-CHV"(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI
M<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!T96UP;&%T97,O<')E9G,O
M9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=XMCB
MU>(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U
M>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(KC7T>#8Z-@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T
M:&4@4')O8FQE;2(*;7-G<W1R("*^W]CA(-W0(-_@WM';U=S>XB(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$
M97-C<FEP=&EO;B(*;7-G<W1R("*ZWMS?V]7BU=T@WM_8X3HB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO
M<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*
M;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W
M"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@
M<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW
M"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BM]#G
MX]+0^"#>W^;8V"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY
M-@IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O
M<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E
M;&5T92(*;7-G<W1R("*XU]'@V.C8(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<"(*;7-G<W1R("*]U2#?X-CAXM#?X]+0^"#4V.#5VN+=WB#4
MWB!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O
M=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$
M<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-
M86EL(@IM<V=S='(@(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%
M4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR
M,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O
M<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G
M:60@(D5M86EL(@IM<V=S='(@(M4MW][HXM`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
MLM#HT"!%;6%I;"#0U.#5X=`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N(@IM<V=S='(@(KO>U]C=VMCBU2#<WN#0(-30(-'8U-#B(-CAXM@N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL
M+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(K_@T-?5W2#@U=?CV^+0XBXB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R
M97-U;'0N(@IM<V=S='(@(K_@T-?5W2#@U=?CV^+0XBXB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS
M9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I
M86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R
M96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R
M=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BL^#5Z-K0
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T
M=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B
M17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R
M:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%
M<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I
M9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F
M=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(L'5VM[5(-_@
MV/C0TN/2T/K5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@
M-2!M:6YU=&5S(@IM<V=S='(@(L'5VM[5(-_@V/C0TN/2T/K5(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B
M179E<GD@3&]G:6XB"FUS9W-T<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"B,L(&9U>GIY"FUS9VED(")%=F5R
M>2!M:6YU=&4B"FUS9W-T<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU
M97,Z(@IM<V=S='(@(K_@V-S5X#HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I
M9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@
M(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"B,L(&9U>GIY"FUS9VED(")&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BO=4@W-[6U=(@
MU-`@T]@@V-?<U=W0W"#?WM35X>/2T/K0XM`N(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@
MTM7@WN(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L
M(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@
MWN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<
M(B5S7"(N(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#A
MU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W
M"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(DQ$05`@VM[=U=KFV/C0XM`@U-X@)7,@U2#=
MU>/AW]7HW=`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@
M(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G
M:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM
M<V=S='(@(K/@U>C:T"#?X-@@V-S?WN#B.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R
M("+$T-KA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F
M=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T<B`BQ-#:X2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I
M9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*
M;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(
M02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X
M"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS
M9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("*]T.';
MWM(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F
M=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(KC<U2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM
M<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T
M:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS
M9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U
M;F5S(@IM<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B
M1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(KC<U2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY
M;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L
M(&9U>GIY"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(KK>W-_;
MU>+5W2#>W]CA.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*
M;7-G<W1R("*RT.C5(-C<U3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I
M;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R
M>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM
M<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'
M97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM
M<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*
M;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S
M-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W,`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(K#4X-7A
MT.`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)
M4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BO][<WN@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP
M('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B
MO][<WN@B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES
M<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L
M(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0HC
M+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M
M92!!9&1R97-S(@IM<V=S='(@(K3>W-#HW=`@T-3@U>'0.B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("*TWMS0Z-7=(.+5
MV]7DWMTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B)R5S
M)R#CX=_5Z-W>(-[BX>+@T-W5XB#>U"#AV.'BU=S>XBXB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I
M9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT
M86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(
M;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M
M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q
M-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("*PU.#5X=`B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED
M("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D
M9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL
M>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@
M=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP
M"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'
M('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E
M=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I
M9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(KC<W][@XMC@T-W>(-_>
MV]4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@
M(KC<W][@XMC@T-W>(-_>V]4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("*X
MW-_>X.+8X-#=V"#?WMO8^M`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O
M=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R
M<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(K+5(-S>
MV]C<U2#=T-+5U-7BU2#2T.C5(-K>X-CAW=CGVMX@V-S5(-@@V][7V-W:T"(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B))
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E
M($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I
M=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM
M<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I
M9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y
M"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM
M<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS
M97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T
M('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN
M<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS
M97)T(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("))
M;G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-
M;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT
M(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@
M(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM
M<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*
M;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM
M<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED
M("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@;&EC96YS
M92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*;7-G
M:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D
M=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T
M;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS
M9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G
M:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM
M<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE
M(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G
M:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@
M(K3=U=+=WB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*
M879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A
M;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G
M:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED
M(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G
M:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED
M(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*
M;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(K_>X-#:T"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG
M=6%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S
M<W=O<F0@0VAA;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I
M9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V
M"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@
M9G5Z>GD*;7-G:60@(DQA>6]U="(*;7-G<W1R("*XU]O5UR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y
M"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E
M<R(*;7-G<W1R("*_X-C<U>`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O
M=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT
M($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB
M"FUS9W-T<B`BN][3V.#0^M4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),
M:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W
M:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ
M>0IM<V=I9"`B3&EN:R(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I
M9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E
M>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T
M($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("*XU]O8
MX>+0^"#BU=S8(-?0(-_>W-[H(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(KC7
MV]CAXM#X(.+5W-@@U]`@W][<WN@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B
M3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED
M("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB
M92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D
M.B`E<R(*;7-G<W1R("*[V.'BT/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7
MW-[6U=W>+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM
M<V=S='(@(KO8X>+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED
M("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*[V.'BT/K5
MXMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS
M9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L
M92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A
M<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN
M+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y
M;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(KC7V]77(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),
M;V=I;B(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G
M:60@(DQO;F<@=&5X="(*;7-G<W1R("*XU]O5UR(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E
M<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T
M=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB
M;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A
M8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@
M(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY
M"FUS9VED(")-86=I8R(*;7-G<W1R("*_WNCBT"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("*_WNCBT"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@
M061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L
M87=I(@IM<V=S='(@(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA
M>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L
M:2(*;7-G<W1R("*_WNCBT"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I
M9"`B36%L=&$B"FUS9W-T<B`BO][HXM`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U
M97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G
M:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA
M<F=I;B(*;7-G<W1R("*RW=C<T-W8U2(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5
M;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H
M:6YG(&9I96QD<R(*;7-G<W1R("*ZWN#5X=_>W=38X-#GVM@@W][;V/K0(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM
M<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@
M;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M
M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I
M9"`B365R9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A
M9V4B"FUS9W-T<B`BO][@T-K0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BO][@T-K0(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S
M='(@(K_>X-#:T"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B
M365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R
M:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI
M8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O
M9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G
M<W1R("*_WNCBT"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI
M;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(K/@U>C:T"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N
M96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N
M+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@
M=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I
M9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I
M9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@
M(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B
M36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G
M<W1R("*\U>'5Y]W>(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S
M=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P
M.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B
M36]V92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M
M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP
M:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM
M<V=S='(@(KC<U2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E
M(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(").979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE
M=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-
M97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE
M("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").
M97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G
M<W1R("*[WM?8W=K0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP
M.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D
M;VXG="!M871C:"XB"FUS9W-T<B`BN][7V-W:V.+5(-S>X-`@U-`@T=C4T.(@
MV.'BV"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U
M>GIY"FUS9VED(").97=S(@IM<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B
M"FUS9W-T<B`BO=#7T-0@VM[=(-[?YMC8XM4B"@HC.B!F<F%M97=O<FLO54DO
M54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ
M.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*
M;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7T"#?WM35
MX>/2T/K5(-W0(%-13"#8U-7=XMCBU>+8XM4N(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T
M<B`BON+:T-;8(-/8(-_@WMS5W=CBU2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0
MYMC8(-?0(-_>U-7AX]+0^M4@W=`@4U%,(-K0XM73WN#8V.+5+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@
MW=`@3$1!4"#<WM;=WN'BV.+5+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BO=7<
MT"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@W=`@4U%,(-K0XM73WN#8V.+5
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*(RP@
M9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(KW5W-`@V-WDWN#<
MT.;8V"#7T"#?WM35X>/2T/K5(-W0(%-13"#:T.+5T][@V-CBU2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*
M;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U
M<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38Y"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@
MW=`@4U%,(-C4U=WBV.+5XMCBU2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*]
MU=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'CTM#ZU2#=T"!344P@V-35W>+8XM7B
MV.+5+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7A
MX]+0^M4@W=`@4U%,(-C4U=WBV.+5XMCBU2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA
M<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*
M;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P87)A=&]R
M('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@<VED97,B"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED
M(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BLM4@W-[;V-S5(-W0TM74U>+5
M(-+0Z-4@VM[@V.'=V.?:WB#8W-4@V"#;WM?8W=K0(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`BPM7;U>3>W2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*
M;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM
M,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)
M<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI
M8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA
M<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").
M;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T
M<B`BM]#1U=O5Z-K8(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@
M<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*
M(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R("*XW-4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM
M<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E
M(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD
M('!A<W-W;W)D(@IM<V=S='(@(KO>U]C=VM`B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T
M(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"B,L(&9U>GIY"FUS9VED(")/
M<'1I;VYS(@IM<V=S='(@(K?0Y^/2T/@@WM_FV-@B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I
M9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES
M871I;VXB"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N
M86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS
M9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0
M($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")0
M2%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H
M="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I
M9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R("*[WM?8W=K0(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS
M9W-T<B`BN][7V-W:T"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(KO>U]C=
MVM`B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("*[WM?8W=K0(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(KO>U]C=VMCBU2#<WN#0
M(-30(-'8U-#B(-CAXM@N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@
M8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I
M;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`BP]O>T]`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(KC7TN#HV"#>W]7@T.;8
MV"#7T"#>U.#6X]+0^M4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V
M"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_(@IM<V=S='(@(KC7TN#HV"#>W]7@T.;8V"#7T"#>U.#6
MX]+0^M4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM
M<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@
M7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4X-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`BPM7;U>3>W2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B
M4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0
M;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y
M"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M
M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("*RU2#<WMO8
MW-4@W=#2U=35XM4@T]X@W^#>T=O5W-[B+B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM
M<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O
M<F0B"FUS9W-T<B`BLM4@W-[;V-S5(-W0TM74U>+5(-+0Z-4@VM[@V.'=V.?:
MWB#8W-4@V"#;WM?8W=K0(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*
M;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*
M;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N
M+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T
M('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T
M"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G
M:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`BO=#7T-0@VM[=(-[?YMC8
MXM4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@
M2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B6[C7
MTM7HXM#X(-?0(-_@WM';U=S>XETB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BOM_8
MX2#=T"#?X-[1V]7<WN(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0
M=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!)
M;F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I
M9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A
M;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@
M1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(K_>
MX-#:T"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I
M9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*
M(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E<V5T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E($)L;V-K(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E
M;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&9O<FUA='1I;F<B"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM
M<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BOM3AXN#0W=@@W]#@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S
M='(@(K[4X>+@T-W8(-_0X"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E
M('5S97(Z("5S(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED
M(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*QT.#0W=C>XB`G=6ED)R#=U2#5(-W0
MTM74U=T@TMX@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*QT.#0W=C>XB`G
M=6ED)R#=U2#5(-W0TM74U=T@TMX@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`BL=#@T-W8WN(@)W5I9"<@W=4@U2#=T-+5U-7=
M(-+>(-_>U-7AX]+0^M#BT"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G
M<W1R(")297-E="(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V
M"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("*[WM?8
MW=K0(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BO][BTN#4
MV"#;WM?8W=K0(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B
M4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE
M;&PN<&AP.C8V"B,L(&9U>GIY"FUS9VED(")297-U;'1S(@IM<V=S='(@(E)E
M<V5T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N
M<R(*;7-G<W1R("*]T-?0U"#:WMT@WM_FV-CBU2(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC
M+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S
M='(@(KW0U]#4(-K>W2#>W^;8V.+5(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(L/;WM/0(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A
M=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED
M(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@
M<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`BP]O>T]`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R
M;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G
M:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP
M.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`BO][@
MT-K0(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED
M(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#
M0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?
M44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED
M(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I
M($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92`E<R(*;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(K?0
MY^/2T/@@WM_FV-@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS
M9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS
M9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B
M4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A(&1A=&4B"FUS9W-T<B`BN-?1U>#8(.3>X-S0XB#7T"#4T.+CW-[B.B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE
M8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM
M<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O
M(&%D9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("*XU]'5
MX-@@Y-[@W-#B(-?0(-30XN/<WN(Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*
M(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B*XU]'5X-@@VM[8(-K0
MX-#:XM7@V"#BV"#BX-71T-#B+B"\WM;5Z"#?WN+>T"#=V-(@U-`@T]@@V.':
MWM_8X-#H(-[4(-_>V]7BWB`B"B+7T"#BU=KAXBXB"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM
M:71E<CHB"FUS9W-T<B`BN-?1U>#8(.'5W]#@T.+>X"#7T"#4T.+CW-[B.B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("*XU]'5X-@@Y-[@W-#B(-?0(-30
MXN/<WN(Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C
M:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.B(*;7-G<W1R("*XU]'5X-@@X=7?T.#0XM[@(-?0(-30XN/<WN(Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(KC7T=7@V"#DWN#<T.(@U]`@TN#5W-7B
MWCHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`BN-?1U>#8(-32
MU2#>U-/>TM#@T.?:V"#?WMO8^M`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(K_@T.+8(-C7TM7HXM#X(-?0(-_@
MWM';U=S>XB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I
M9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G
M<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E
M<W-I;VYS(@IM<V=S='(@(K?0Y^/2T/@@WM_FV-@B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS
M9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S
M8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@
M;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("*ZX-#B
MVMX@X-77V-S5.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G
M:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3
M:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM
M<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T
M-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,
M96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B
MO^#5X=K>VMW8(-[4X-;CTM#ZU2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E
M;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N
M;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("*PU.#5X=`@W=`@X-#1WN+0(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C
M:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R("*RW=7AX]+0^M4@W=`@X=_5YMCXT-O=V"#7W=#FV"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*
M;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L
M:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z
M>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R("*XW-_>X.(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM
M<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T
M92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A
M9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S
M<R(*;7-G<W1R("*PU.#5X=`@W=`@X-#1WN+0(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR
M;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O
M;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;
M0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@
M(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT
M:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S
M(@IM<V=S='(@(L/AW]7HW=XB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(./AW]7HW=X@U-[4
MT-35W2#=T"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B)R5S)R#CX=_5Z-W>(-[BX>+@T-W5XB#>U"#AV.'BU=S>XBXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE
M=&5D(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R#CX=_5Z-W>(-3>U-#4U=T@W=`@
MX=CAXM7<WN(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(./AW]7HW=X@WN+AXN#0
MW=7B(-[4(.'8X>+5W-[B+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S)R#C
MX=_5Z-W>(-3>U-#4U=T@W=`@X=CAXM7<WN(N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*
M;7-G<W1R("(G)7,G(./AW]7HW=X@U-[4T-35W2#=T"#AV.'BU=S>XBXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L
M(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(KK@T.+:WB#@U=?8W-4Z
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U
M;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z
M>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`BN-S?WN#B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`BNM[@V.'=
MV.?:WB#8W-4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("*ZWN#8X=W8
MY]K>(-C<U2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A
M>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*
M;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED
M(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*
M;7-G<W1R("*]T.';WM(B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP
M.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BO=#AV][2(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED
M(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")486EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM
M<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@
M(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S
M*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]4
M96UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("*PU-S8W=CAXN#0YMCXT"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@
M(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T
M=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*
M;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E
M96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#$*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I
M9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF
M:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I
M9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X
M="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS
M9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+B(*;7-G<W1R("*]U=S0(-3>X>+0W]W8(-_>U-7AX]+0^M`N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS
M9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(KW0
MX>+0W=`@W^#>T=O5W"#?X-@@U-[4T-+0^M4@W=`@)7,@TMX@X=CAXM7<WN(N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(KW0X>+0
MW=`@W^#>T=O5W"#?X-@@WN+AXN#0W>/2T/K5(-W0("5S(-[4(.'8X>+5W-[B
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BO=#AXM#=T"#?X-[1V]7<(-_@
MV"#>XN'BX-#=X]+0^M4@W=`@)7,@WM0@X=CAXM7<WN(N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B
MO=#AXM#=T"#?X-[1V]7<(-_@V"#4WM30TM#ZU2#=T"`E<R#2WB#AV.'BU=S>
MXBXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD
M87(@9&%T82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q
M=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@
M8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS
M9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*
M;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V
M"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N
M<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@
M(KW0X=O>TB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G
M:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,
M97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED
M(")4:71L92(*;7-G<W1R("*]T.';WM(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I
M<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*
M(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI
M;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(
M5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@
M5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B
M5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI
M<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO
M:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS
M9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")5
M4DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BO=4@
MW-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B
M;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG
M('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N(@IM<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,
M(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<
M(B5S+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N(@IM<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@
M4U%,(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#,Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"XB"FUS9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@
MX=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N(@IM<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,
M(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@
MTM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS
M9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@
MWN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<
M(.'>(%-13"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
MO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN
M(@IM<V=S='(@(KW5X^'?U>C=WB#@U=/8X>+@V.#0^M4@W=`@W][4U>'CTM#Z
MT.+0(-+>(.'5X=CXT.+0+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I
M8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U3
M4"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP
M:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(KW5(-S>
MUM72(-30(-/8(-C7W-7=T-P@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`BO=4@
MW-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("*]U2#<WM;5TB#4T"#3V"#8U]S5W=#<(-_>U-7AX]+0^M#BT"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I
M;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,CDS"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@
M4U%,(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("*]U2#<WM;5TB#4T"#3WB#?
MX-72U=30W"#>TM[X(%=O<F0@U-[:X]S5W>(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S
M(@IM<V=S='(@(K[BVM#6V"#3V"#?X-[<U=W8XM4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@
M>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG
M9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3
M=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T
M87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N
M="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V
M:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN
M:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5
M;FYA;65D(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED
M(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM
M<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`BM-[4T-38(-K>X-CAW=C:(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*
M;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X
M"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X
M"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I
M9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(E5S97(B"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"B,L(&9U>GIY"FUS9VED(")5
M<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DAO<F1E(+#4W-C=V.'BX-#B
MWN`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC+"!F
M=7IZ>0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(K?0Y^/2T/@@WM_F
MV-@B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E
M9VES=')A=&EO;B(*;7-G<W1R(")(;W)D92"PU-S8W=CAXN#0XM[@(@H*(SH@
M<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO
M="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z
M>GD*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G
M:60@(E5S97)N86UE.B`B"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I
M;B!T:&4@<WES=&5M.B(*;7-G<W1R("*ZWN#8X=W8YM@@TMX@X=CAXM7<WN(Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T
M:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM
M<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L
M('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P
M"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6
M:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE
M($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*
M;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")7
M24X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S
M='(@(K+=V-S0W=C5(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C
M87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E
M871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B5V5E:VQY(@IM<V=S='(@(KW5U-7;W=XB"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G
M<W1R("*TWM'@U=3>^-35+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("*T
MWM'@U=3>^-35+"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("*TWM'@U=3>^-35+"`E<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*
M;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T
M97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA
M<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*
M;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I
M9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@
M=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("*PU.#5
MX=`@W=`@X-#1WN+0(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+"U=O5
MY-[=(-W0(.#0T=[BT"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I
M9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(EE9(@IM<V=S='(@(K.S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S
M='(@(K.S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B
M665A<FQY(@IM<V=S='(@(K/>U-CHW=XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G
M:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I
M9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO
M=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O
M;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L
M9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS
M9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B
MOM_8Z-7BU2#3WB#?X-[1V]7<WN(@W^#5U"#4T"#8X=_@T.+5XM4@V-?2U>CB
MT/@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(KW0TM74U>+5
M(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(KW0TM74U>+5
M(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(KW0TM74U>+5(-K>U2#:WN#8X=W8
MY]K>(-C<U2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV
M,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B
MO=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-3>U-#4U2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`BO=#2
MU=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-3>U-#4U2XB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R
M9F]R;2XB"FUS9W-T<B`BO=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30
M(.'5(-[BX>+@T-W8+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(KW0TM74U>+5(-K>
MU2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I
M9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9
M;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`BLM#HT"!%;6%I;"#0U.#5X=`Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("*RT.C0($5M86EL(-#4
MX-7AT#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*
M;7-G<W1R("*RT.C5(-C<U3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HBLM#HV-[B(-#2XM[@V-?0
MYMC>W=7=(-_@WN+>VM[;(-W5(-_>U.#6X]+0(-3>U-#2T/K5(-K>X-CAW=CF
MV"P@V-O8(.+0T"`B"B+<WM;=WN'B(-4@WMW5TM[7W-[6U=W0(-[4(-3@X]/8
M(-_@V.?8W=@N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B
M"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM
M<V=S='(@(B(*(K+0Z-C>XB#0TN+>X-C7T.;8WMW5W2#?X-[BWMK>VR#=U2#?
MWM3@UN/2T"#;V.'BT/K5(-K>X-CAW=CFV"P@V-O8(.+0T"`B"B+<WM;=WN'B
M(-4@WMW5TM[7W-[6U=W0(-[4(-3@X]/8(-_@V.?8W=@N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R
M:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W
M"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(L'BT-W4T.#4U=T@V-35W>+8XM7B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(K+0Z-4@V-S5.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO=7(@;&]G:6X@
M:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R
M96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M
M(%)E<&]R=%TB"FUS9W-T<B`B6[C7TM7HXM#X(-?0(-_@WM';U=S>XETB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R
M"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@
M;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,0HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`BN-?1
MX-CHV"(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U
M"B,L(&9U>GIY"FUS9VED(")?2&5L<"(*;7-G<W1R("*_WMS>Z"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM
M<V=I9"`B7TQO9R!I;B(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],
M;V<@;W5T(@IM<V=S='(@(KC7V]77(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T
M<B`BM]#GX]+0^"#>W^;8V"(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B
M7U!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I
M9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z
M(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G
M:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("*PU.#5X=#@(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E
M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@
M8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I
M;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A
M=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*
M;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`BO=#AV][2(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR
M,S(*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T<B`BN-S5(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T
M97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS
M9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED
M(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(K+=
MV-S0W=C5(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E
M;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*
M;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES
M=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O
M<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T
M<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@
M(G9#87)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O
M;2(*;7-G<W1R("(B"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O;'9?
M3%8N<&\`````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#8Q,3,U,@`Q,#4Q-30S,3`V,P`P,38T,3<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!,871V:6%N('1R86YS
M;&%T:6]N(&9O<B!(;W)D92X*(R!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R
M<T!R8V,N;'8^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!(;W)D92`R+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`R+3$Q+3(X(#$T.C`P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M2V%S<&%R<R!+87!E;FEE:W,@/&MA<W!A<G-`<F-C+FQV/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@3&%T=FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4-0,3(U-UQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@."UB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO
M<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#`W"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO
M<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&YA=B!N;W+B9.YT<R!(;W)D
M92!R9>QI<W1RXB(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S
M(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!5>G1U<N?P86YA
M<R!O<&5RXF-I:F%S("T@87!S=&EP<FENXFIU;7,B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M
M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S
M("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")!
M='KN;>=J:65T(&1A<F+N8F%S+"!K;R!VYVQA=&EE<R!V96EK="XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(DMA=')A<R`U(&UI;OMT97,B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B6W)I;F1A("5S(&YO
M("5S72(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G
M<W1R(")+;VYT86MT:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(DMA;&5N9.)R<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M
M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@
M0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I
M9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I
M86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY
M"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")*^W-U(&EN9F]R;>)C
M:6IA(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED
M("(R-"!(;W5R($9O<FUA="(*;7-G<W1R(")*^W-U(&EN9F]R;>)C:6IA(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S
M(@IM<V=S='(@(C(T('-T=6YD87,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@
M(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/DER(&YO
M=&EK=7-I(&MR:71I<VMA(&OO^VUE.CPO8CXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@
M82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B
M05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED
M(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M
M871I;VXB"FUS9W-T<B`B2OMS=2!I;F9O<FWB8VEJ82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S
M=V]R9"(*;7-G<W1R(")087)O;&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O
M>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D
M+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S='(@(D%D<F5S92(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS
M9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ>0IM
M<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D%D<F5S92(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@
M3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM
M<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!
M9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS
M9W-T<B`B4&EE=FEE;F]T('#B<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(DMO;G1A:W1I(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U
M>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(DMO
M;G1A:W1I(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!U<V5R(@IM<V=S='(@(E!I979I96YO="!PXG)I(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E
M<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@
M<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I
M9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R
M(")!9')E<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"B,L
M(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B2V]N=&%K=&DB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM
M<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R(")!9')E<V4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%I>G-TXFIV
MXG)D<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B"FUS
M9W-T<B`B06EZ<W3B:G;B<F1S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06EZ
M<W3B:G;B<F1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T
M<B`B06EZ<W3B:G;B<F1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N
M=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B
M06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F
M;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*
M;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D
M<F5S<R(*;7-G<W1R(")*^W-U(&4M<&%S=&$@861R97-E.B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B3F]RXF3N
M=&$@;F5D97+N9V$@=N=R=.YB82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N(@IM<V=S='(@(CQB/DER(&YO=&EK=7-I(&MR:71I<VMA
M(&OO^VUE.CPO8CXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@
M4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L
M>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I
M9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM
M<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD
M(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M
M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM
M<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G
M:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV
M,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*
M;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E!I965J86UI92!L
M875K:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%
M>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R
M;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A
M9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L
M:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1'II;?!A
M;F%S(&1I96YA(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@
M7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(DYA=B!S=')O9&%M<R!P87II\F]J=6UU(&ML875S[G3B:G,@)7,B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K
M(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@
M(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS
M9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I
M9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K
M;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R
M<R(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL
M(@IM<V=S='(@(E!A<W1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E
M9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@
M1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*(RP@
M9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H
M92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YDXG)S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N
M;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T
M('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA
M;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F5I>F1E
M=N)S('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86QE;F3B<G,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%T8V5L="!P<F]B;.=M87,@<&EE
M=&5I:W5M=2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D]P
M8VEJ87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E
M;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B
M:6QA:7,@=.)L<G5N:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R
M;W!E<G1I97,B"FUS9W-T<B`B36]B:6QA:7,@=.)L<G5N:7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B
M0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R
M;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F
M=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL86ES('3B;')U
M;FES(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I
M8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#
M97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L
M:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED
M(")#:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC
M+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D%T8V5L="!I>FUA:?)A
M<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B
M0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B"FUS
M9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM
M<V=S='(@(E9I<G-R86MS=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X
M"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S
M92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M(").878@<W1R;V1A;7,@<&%Z:?)O:G5M=2!K;&%U<^YTXFIS("5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z
M>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(DMA;&5N9.)R<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L
M96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@
M=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED
M(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#
M;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7
M:6YD;W<B"FUS9W-T<B`B06EZ=N=R="!L;V=U(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO
M=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED
M(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ
M-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM
M<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")5>O+G;75M
M<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B57KRYVUU;7,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW
M"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H
M(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R
M92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM
M<V=S='(@(E!A<F]L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T
M-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@
M(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B
M)R5S)R!S871U<G,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I
M;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G
M:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(D-O<'DB"FUS9W-T<B`B57KRYVUU;7,B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P
M>2!F86EL960Z("5S(@IM<V=S='(@(DEE;.)DYW1A:7,@;&%U:W,Z("5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM
M<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@
M(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@
M8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(DYE:7ID97;B<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG
M($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE
M;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q
M,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M(").96EZ9&5VXG,@871VYW)T($UA:6YT96YA;F-E7U1A<VL@;6]D=6QI("5S
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(").96EZ9&5VXG,@871VYW)T($UA:6YT96YA;F-E7U1A<VL@;6]D=6QI
M("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96EZ
M9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92!N878@:V]R96MT:2!K
M;VYF:6=U<N=T82(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE:7ID97;B<R!P
M:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T
M:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@
M;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G
M:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W
M(&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS
M9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H
M87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*;7-G
M:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R
M96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%52
M3"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G
M:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U
M<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S
M='EL92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#
M=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED
M(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")):V1I96YA
M<R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@
M0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS
M9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B
M1&%Y(@IM<V=S='(@(DEK9&EE;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E
M($-O;'5M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G
M:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")087)A<W3B(&ED96YT:73B
M=&4B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("))
M>FUA;G1O="!N;VML=7/G=&\@=N=R=.YB=2(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`B4&%R87-TXB!I9&5N=&ETXG1E(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM
M<V=S='(@(E!A<F%S=.(@:61E;G1I=.)T92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B
M1&5L971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O
M=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T
M92!,;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I
M9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A
M;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L
M971E(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M
M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I
M9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4&%R87-T
MXB!I9&5N=&ETXG1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H
M92!C=7)R96YT(')O=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R(")!<')A:W-T:65T('!R;V)LYVUU(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R
M:7!T:6]N(@IM<V=S='(@(E!I;&YS(&%P<F%K<W1S.B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")3[FOB:V$@
M:6YF;W)MXF-I:F$@:7(@;F]S^W3N=&$@861M:6YI<W1R871O<F%M+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M
M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS
M9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM
M<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D5K<N)N82!I97-T873N
M:G5M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M(")%:W+B;F$@:65S=&%T[FIU;6DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G
M:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D5K<N)N82!I97-T873N:G5M
M:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@
M(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G
M:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM
M<V=S='(@(DYA=B!T:67P87,@<&EE96IA<R!M86EN=&5N86YC92YP:'`B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O
M;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM
M<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(E!A<W1S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*
M;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I
M97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM
M<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G
M:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW
M-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I
M="!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P
M=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H
M97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@
M=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT
M+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M
M<&%S=',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@
M(D5M86EL($%D9')E<W,B"FUS9W-T<B`B2OMS=2!E+7!A<W1A(&%D<F5S93HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I
M;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@
M=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B0VET82!I;F9O<FWB8VEJ82(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"B,L(&9U
M>GIY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B3W!C:6IA<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC
M+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B5'5K\',@
M<F5Z=6QTXG1S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B
M5'5K\',@<F5Z=6QTXG1S+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")+[_MD82(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMA=')A<R`Q
M-2!M:6[[=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F
M=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(DMA=')A<R`U
M(&UI;OMT97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`B2V%T<F%S(#,P('-E:W5N9&5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED
M(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B2V%T<F%S(#4@;6EN^W1E<R(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*
M;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DMA='+B('!I97-LYV?P86[B
M<R!R96EZYR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@
M(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")+871R=2!P=7-S='5N9'4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+871R=2!M
M:6[[=&DB"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I
M9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(E!A<F%U9W;G<G3N8F%S(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU
M,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W
M-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*
M;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A
M=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q
M-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S
M='(@(DYE:7ID97;B<R!S8?)E;70@:65S=&%T[FIU;75S+B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$
M05`@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.CDX"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+B(*;7-G<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S
M97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$
M05`@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G
M<W1R(").96EZ9&5VXG,@<V'R96UT(&EE<W1A=.YJ=6UU<RXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T
M<B`B265LXF1E<R!K;/MD83HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<W,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS
M9VED(")&87AE<R(*;7-G<W1R(")&86MS<R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R(")6:7)S<F%K<W1S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z
M>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")6XG)D<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM
M<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T
M:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS
M9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U
M;F5S(@IM<V=S='(@(E!I97KN;65S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`B5N)R9',B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L
M:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I
M86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L
M>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC
M+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")0:6QN
M<R!A<')A:W-T<SHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B
M"FUS9W-T<B`B2OMS=2!VXG)D<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L
M;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ
M.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")'97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M
M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@
M(D=U97-T8F]O:R(*;7-G<W1R(")+;VYT86MT:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*
M;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED
M(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED
M(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*
M;7-G<W1R(")086SN9'KN8F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L
M(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B4&%L[F1Z[F)A(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP
M;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I
M9"`B2&]?;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*(RP@9G5Z>GD*;7-G
M:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*
M;7-G<W1R(")-XFIA<R!A9')E<V4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@
M(DAO;64@4&AO;F4B"FUS9W-T<B`B3>)J87,@=&5L969O;G,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A
M;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I
M9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I
M9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM
M<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!9')E<V4B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I
M9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N
M=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS
M9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M+"!3=&5P("5D(@IM<V=S='(@(DEE;.)DYW1A:7,@;&%U:W,Z("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEE;.)DYW1A:7,@
M;&%U:W,Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM
M<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("))96SB9.=T:64@;&%U
M:VDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DS[9'IU(&YO<N)D:65T('-A=G4@
M;&EE=&]TXFIA(';B<F1U('5N('!A<F]L:2(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS
M9W-T<B`B2OMS=2!I;F9O<FWB8VEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?
M;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G
M:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y
M"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G
M:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM
M<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P
M;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C
M:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R
M,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A;&ED
M(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<S"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L
M:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@
M<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E
M;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I
M9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*
M;7-G<W1R(")):V1I96YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS
M9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@
M8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN
M9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S
M=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME
M;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME
M>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM
M<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(EII\F$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I
M9"`B3&%N9W5A9V4B"FUS9W-T<B`B5F%L;V1A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA
M;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED
M("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`B27II
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B4&%R875G=N=R=.YB87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E
M;"(*;7-G<W1R(").96MA9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B
M($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(E!I
M97-LYV=T:65S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G
M:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I
M;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED
M("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS
M9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A
M8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B4&%RXF3N="!P
M86SN9'KN8F%S('1E;6%T=7,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R
M"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B4&%R
MXF3N="!P86SN9'KN8F%S('1E;6%T=7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I
M9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS
M9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C
M<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS
M9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE
M.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS
M9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O
M9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G
M<W1R("))>FEE="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),;V=I
M;B!487-K<R(*;7-G<W1R(")5>F1E=G5M:2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2XB"FUS9W-T<B`B4&EE<VSG9W1I97,@;F5I>F1E=N)S:2Y.
M97!A<F5I>G,@;&EE=&]TXFIA(';B<F1S('9A:2!P87)O;&4N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*
M(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("))>FEE="(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-PIM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R
M(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W
M97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),
M;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R(")087-T<R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G
M<W1R(")087-T<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*
M;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-
M86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(E!A<W1S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ
M>0IM<V=I9"`B36%L:2(*;7-G<W1R(")087-T<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC
M+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B4&%S=',B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES
M="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L
M(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*
M;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z
M>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")"<NYD:6[B:G5M<R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ
M=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")387-K86YO\&EE
M(&QA=6MI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED
M(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$V"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S='(@(E1E:W-T:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D
M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B6FGR82(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B
M"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N
M(@IM<V=S='(@(EII\F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`B6FGR82(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B4^YKXFMA(&EN9F]R;>)C:6IA(&ER(&YO
M<_MT[G1A(&%D;6EN:7-T<F%T;W)A;2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D
M969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(E!A<W1S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A
M9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS
M9VED(")-:7)R;W(B"FUS9W-T<B`B2^_[9&$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G
M:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G
M92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER
M960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B
M36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@
M(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D
M:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B2V%T<G4@;>=N97-I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N
M9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@
M(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V
M92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B
M36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED
M(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DK[<W4@:6YF;W)MXF-I:F$B"@HC.B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@
M4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B3F%M92(*;7-G<W1R(")6XG)D<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA
M=7)U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED
M(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N
M97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*
M;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R(").96MA9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR
M-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV
M."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U
M"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L92(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS
M9W-T<B`B4&EE>NYM97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H
M87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F
M=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(D%T9W)I97IT:65S
M('!I92!O<&-I:N)M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ
M,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3F5K860B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ
M.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*
M;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"!A=71E;G1I9FEKXF-I:F%I(&YA
M=B!N;W+B9.YT82!K;VYF:6=U<N)C:6IA<R!I;F9O<FWB8VEJ82XB"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA
M;F=E+B(*;7-G<W1R(")!=&-E;'0@:7IM86GR87,B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(E-13"!K
M871E9V]R:6KB;2!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)M
MXF-I:F$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*(RP@
M9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("),1$%0(&EE<W1A=.YJ=6UO
M<R!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I:F$N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344P@5D93+B(*;7-G<W1R(")344P@:V%T96=O<FEJXFT@;F%V(&YO<N)D
M[G1A(&MO;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*(RP@9G5Z>GD*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM
M1FEL92!61E,N(@IM<V=S='(@(E-13"!K871E9V]R:6KB;2!N878@;F]RXF3N
M=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").
M;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I
M;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED
M(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N
M(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V.0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(E-13"!A=71E;G1I9FEKXF-I:F%I(&YA=B!N;W+B9.YT82!K;VYF
M:6=U<N)C:6IA<R!I;F9O<FWB8VEJ82XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")344P@875T96YT:69I:^)C:6IA:2!N878@;F]RXF3N=&$@:V]N9FEG=7+B
M8VEJ87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.C@T"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@875T96YT
M:69I:^)C:6IA:2!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)M
MXF-I:F$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P
M<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B
M"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD
M:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G
M<W1R(")0:65Z[FUE<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T.0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B4&EE
M>NYM97,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I
M9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O
M<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*
M;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G
M<W1R("),^V1Z=2!N;W+B9&EE="!S879U(&QI971O=.)J82!VXG)D=2!U;B!P
M87)O;&DB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM
M<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G
M:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B
M3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N
M92(*;7-G<W1R(")4XFQR=6YI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I
M="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G
M:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T
M($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@
M9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S970B"FUS9W-T<B`B4&EE>NYM97,B"@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U
M.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G
M<W1R(")0:65Z[FUE<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H
M<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<U"B,L(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").96MA9"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G
M:60@(DYU;6)E<B(*;7-G<W1R(")6XG)D<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@
M(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G
M:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T
M(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQE(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM
M<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS
M9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M
M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P
M97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-I
M:F%S(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I
M;VYS(&9O<B`E<R(*;7-G<W1R(")/<&-I:F%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM
M<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B0VET
M82!I;F9O<FWB8VEJ82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I
M9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L
M(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W
M,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO
M<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G
M:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@
M4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B
M4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M87!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E!A<F]L92(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E!A<F]L92(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@
M(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B
M4&%S<W=O<F0Z(@IM<V=S='(@(E!A<F]L92(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM
M<V=S='(@(E!A<F]L92(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I
M9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N
M=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*
M(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R("),;VUA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@
M(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R(*;7-G<W1R("))>G!I;&3N="!U>G1U<N?P86YA<R!O
M<&5RXF-I:F%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@HC+"!F
M=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/R(*;7-G<W1R("))>G!I;&3N="!U>G1U<N?P86YA<R!O<&5RXF-I
M:F%S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB
M)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU.#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M
M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS
M+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED
M(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*(RP@9G5Z>GD*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D-I=&$@:6YF;W)MXF-I:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`B5.)L<G5N:7,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@
M(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE
M;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B3/MD>G4@
M;F]RXF1I970@<')O8FSG;6%S(&%N;W3B8VEJ=2XB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(DS[9'IU(&YO<N)D:65T('-A=G4@;&EE=&]TXFIA
M(';B<F1U('5N('!A<F]L:2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT
M+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*
M(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX
M"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO
M;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY"FUS
M9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D%T9W)I97IT:65S('!I
M92!O<&-I:N)M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(EM0<F]B;.=M87,@>FGR;VIU;7-=(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@
M(E!R;V)LYVUA<R!A<')A:W-T<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED
M(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@
M2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T
M"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")2
M86EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A
M;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T
M<B`B6FGR82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM
M<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$*(RP@9G5Z>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(D%T:F%U;F]T(&MO<'-A=FEL:W5M82!S:V%T=3HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED
M(")296=E>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I
M9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS
M9W-T<B`B27ID>N=S="!PXG)I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T
M<B`B27ID>N=S="!PXG)I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R
M("))>F1ZYW-T('#B<FDB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B27ID>N=S="!PXG)I
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M('1H92(*;7-G<W1R("))>F1ZYW-T('#B<FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B
M27ID>N=S="!PXG)I(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(E!I97!R87/N=&%I<R`G=6ED)R!N878@;F]RXF3N=',@:65S=&%T[FIU
M;74@:V]N9FEG=7+B8VEJXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&EE<')A<^YT86ES("=U
M:60G(&YA=B!N;W+B9.YT<R!I97-T873N:G5M=2!K;VYF:6=U<N)C:6KB+B(*
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&EE<')A<^YT86ES("=U:60G
M(&YA=B!N;W+B9.YT<R!I97-T873N:G5M=2!K;VYF:6=U<N)C:6KB+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S
M=V]R9"(*;7-G<W1R(")087)O;&4B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E
M($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW
M"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")!=&=R:65Z=&EE
M<R!P:64@;W!C:6KB;2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D%T9W)I97IT:65S
M('!I92!O<&-I:N)M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS
M9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I
M9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T
M"FUS9VED(")2;VQE(@IM<V=S='(@(DQO;6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B
M4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P
M97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L
M(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R("),;VUA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(EII\F$B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@
M<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@
M*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N
M9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I
M9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(E-A9VQA8N)T(&]P8VEJ87,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B4V%G;&%BXG0@;W!C
M:6IA<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*
M(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T
M('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C
M:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@
M1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R("))>G;G;&EE=&EE<R!D871U;6$@9F]R;>)T=3HB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@
M9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@
M(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B27IVYVQI971I
M97,@9&%T=6UA(&9O<FWB='4Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B))>G;G;&EE=&EE<R!S:6UB
M;VQU<R!N;R!Z96WB:R!R961Z86UA:N)M(&EZ=N=L;N=M+B!0YV,@=&%M(&K[
M<R!V:?)U<R!V87)A="`B"B)PXG)N97-T(&%R(&-O<'DO<&%S=&4B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`B27IVYVQI971I97,@9&%T=6UA(&%T
M9&%L[G3B:G4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(DEZ=N=L:65T
M:65S(&1A='5M82!F;W)MXG1U.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B27IVYVQI971I97,@9&%T=6UA(&%T
M9&%L[G3B:G4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(DEZ=N=L:65T
M:65S(&QA:6MA(&9O<FWB='4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM
M<V=S='(@(DEZ=N=L:65T:65S(&1I=G5S('-A9&5R[F=U<R!L875K=7,N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z(@IM<V=S='(@(DEZ=N=L:65T:65S('9A;&]D=3HB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(").;W/[=.YT('!R;V)LYVUA<R!P:65T96EK
M=6UU(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")3
M97!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO
M;G,B"FUS9W-T<B`B4V%G;&%BXG0@;W!C:6IA<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O
M(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R
M(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+B(*;7-G<W1R("))97-TXF3N="!L87!U871J875N;_!A;N)S
M('5N(&-I=&%S(&5K<N)N82!O<&-I:F%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(DEE<W3B
M9.YT(&QA<'5A=&IA=6YO\&%NXG,@=6X@8VET87,@96MRXFYA(&]P8VEJ87,N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X
M-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@
M<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B
M4VAO<G0@4W5M;6%R>2(*;7-G<W1R("+.<V$@86YO=.)C:6IA.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B
M4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U
M"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*
M;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM
M<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W
M('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED
M(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG
M(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I
M9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@
M(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B27IL86ES="!U>G1U<N?P86YU
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@
M(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS
M9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R
M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N
M;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG
M<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM
M<V=S='(@(D1A<F)A(&%D<F5S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O
M=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I
M9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@
M(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E
M8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`BSG!A\&\@<VEM8F]L=2!I
M979A9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED
M(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T<B`B265LXF1E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@
M(DMA;&5N9.)R<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I
M9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I
M9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R(")*^W-U(&EN9F]R;>)C:6IA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T
M<F5E="!!9&1R97-S(@IM<V=S='(@(D1A<F)A(&%D<F5S92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T
M<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B3F%V('-T<F]D86US('!A>FGR;VIU;74@:VQA=7/N=.)J<R`E<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*
M;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@
M=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@
M:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(E9E:6MS;64B"@HC.B!A9&UI;B]U<V5R+G!H<#HX
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M
M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@
M(E-U;6UA<GDB"FUS9W-T<B`B36%N<R!K;W!S879I;&MU;7,B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@
M(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B
M4W5P<&]R="(*;7-G<W1R("))96SB9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U
M>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("),:65T;W3B:F$@=N)R9',B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F
M=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("),:65T;W3B:F$@=N)R9',B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3
M>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@
M(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R
M;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M5FER<W)A:W-T<R(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T
M"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED
M(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")486EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R
M(")5>F1E=G5M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q
M-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS
M9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G
M:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F
M;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B2OMS(&5S870@:7IGXFII
M<R!N;R!S:7-TYVUA<RX\8G(@+SY086QD:65S('!A<B!S:7-TYVUA<R!L:65T
M;_!A;G4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G
M:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B
M5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N
M9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U
M("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U
M"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM
M<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A
M=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G
M:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO
M="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*
M(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T
M96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL
M(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S
M92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I
M9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BT&%I(';G
M<G3N8F%I(&ER(&KB8OMT('-K86ET;&EM+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@
M7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP
M.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP
M.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G
M:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@
M(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B
M5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM
M<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V
M,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS
M9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92XB"FUS9W-T<B`B265S=&%T[FIU;6D@;F%V('!I965J86UI
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS
M9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D
M(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R
M+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC
M+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I
M;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U
M="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N(@IM<V=S='(@(M!A:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E
M;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U
M-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L
M=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BT&%I
M(';G<G3N8F%I(&ER(&KB8OMT('-K86ET;&EM+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V
M"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS
M9W-T<B`BT&EM('-K86ET;&EM(&ER(&KB8OMT('9I<VUA>B`Q+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@
M9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N
M=6UB97(N(@IM<V=S='(@(M!A:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI
M;2XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS
M9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R
M."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G
M:60@(E1I;64B"FUS9W-T<B`B5FER<W)A:W-T<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O
M<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")6:7)S<F%K
M<W1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED
M(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M
M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R
M(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U
M=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T
M"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E
M>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@
M(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C
M<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z
M>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM
M<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E5K<F%I;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I
M97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(").878@:65S<.=J
M86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z.#,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(").878@:65S<.=J
M86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE
M<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-L
MYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C4V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@
M4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E
M<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G
M=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R(").878@:65S<.=J86US('-E<VEJXB!R9>QI<W1RYW0@:65S=&%T
M[FIU;75S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H
M<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@
M<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3F%V(&EE<W#G
M:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").
M878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*
M;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@
M)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E
M<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV
M,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N="(*;7-G<W1R(").878@:65S<.=J86US(&EN=&5R<')E=.=T
M(/!O(%=O<F0@9&]K=6UE;G1U(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@
M(D%T8V5L="!I>FUA:?)A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R
M($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G
M:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34Y"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED
M96YT:71Y+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T
M<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B
M56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O
M961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E
M('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z
M>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B
M57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM
M<V=S='(@(DQI971O=.)J82!O<&-I:F%S(@H*(SH@<VEG;G5P+G!H<#HV,@HC
M+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B3&EE
M=&]TXFIA(&]P8VEJ87,B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS
M9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DQI971O
M=.)J82!VXG)D<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R("),:65T;W3B:F$@=N)R9',B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@
M(DQI971O=.)J82!VXG)D<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M
M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*
M;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M
M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS
M9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*
M;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@
M=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES
M;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B
M5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B
M5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G
M<W1R(")"<NYD:6[B:G5M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&
M;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED
M(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(E=E96ML>2(*;7-G<W1R(")+871R=2!N963G[W4B"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R("),86EP;FD@;/MD>FTL("5S(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T
M<B`B3&%I<&YI(&S[9'IA;2`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("),86EP;FD@;/MD
M>FTL("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7
M:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H
M92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7
M:61T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F
M96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H
M(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED
M(")7:6YD.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS
M9VED(")7;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S
M='(@(D1A<F)A(&%D<F5S92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
M1&%R8F$@=.)L<G5N:7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E
M9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")962(*;7-G<W1R(")'1R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G
M<W1R(")'1R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R(")+871R=2!G861U(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM
M<V=I9"`B665M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V
M"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*
M;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED
M(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED
M(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@
M;&]G9V5D(&]U="XB"FUS9W-T<B`B2OMS=2!O<&-I:F%S(&ER('-A9VQA8N)T
M87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B
M(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R
M+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM
M<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D%P<F%K
M<W1I970@<')O8FSG;74@<&ER;7,@<&EE=&5I:W5M82!S^W3N\&%N87,N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM
M<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q
M.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N
M('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(DK[<W4@)7,@<V5S:6IA(&ER(&)E:6=U<VEE<RX@3/MD>G4@<&EE<VSG9'II
M971I97,@871KXG)T;W1I+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B
M"FUS9W-T<B`B2OMS=2!E+7!A<W1A(&%D<F5S93HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D
M9')E<W,Z(@IM<V=S='(@(DK[<W4@92UP87-T82!A9')E<V4Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DK[
M<W4@:6YF;W)MXF-I:F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE
M(@IM<V=S='(@(DK[<W4@=N)R9',Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(DK[<W4@;W!C:6IA<R!I
M<B!S86=L86+B=&%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T
M<B`B4&%R87-TXB!I9&5N=&ETXG1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S
M='(@(DK[<W4@=N)R9',Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B2OMS=2!O<&-I:F%S(&ER('-A9VQA8N)T87,N(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")*^W-U(&]P
M8VEJ87,@:7(@<V%G;&%BXG1A<RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+B(*;7-G<W1R(")*^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RXB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G
M(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O
M<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G
M:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G
M<W1R(");4')O8FSG;6%S('II\F]J=6US72(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EMR:6YD82`E
M<R!N;R`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$
M871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")?2&5L<"(*;7-G<W1R(")086SN9'KN
M8F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B4&EE<VSG9W1I97,B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U
M>GIY"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("))>FEE="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM
M<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/
M<'1I;VYS(@IM<V=S='(@(D]P8VEJ87,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*
M;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("))>F1ZYW-T('#B
M<FDB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U
M>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B2V]N=&%K=&DB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B
M861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM
M<V=S='(@(DMA;&5N9.)R<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@
M(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B
M8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED
M(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I
M9"`B9FEL92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*
M;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H
M;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM
M;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV
M-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R
M"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R
M;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@
M97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS
M9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G
M:60@(FYA;64B"FUS9W-T<B`B5N)R9',B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED
M(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I
M;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L
M(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B0G+N9&ENXFIU;7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B
M<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X
M-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I
M=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*
M;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS
M,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R(")+871RXB!P
M:65S;.=G\&%NXG,@<F5I>N<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y
M"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#
M87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N
M8V]M(@IM<V=S='(@(B(*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!O+VYN7TY/+G!O````````````````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`V,C0S,S<`,3`U,34T,S$P-C,`,#$V-#$S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",@2&]R
M9&4@3F]R=V5G:6%N($YY;F]R<VL@=')A;G-L871I;VX*(R!#;W!Y<FEG:'0@
M*$,I(#(P,#(@4&5R+5-T:6%N(%9A=&YE"B,@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A
M8VMA9V4N"B,@4&5R+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N;W)G/BP@,C`P
M,BX*(R`*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($AO<F1E(#,N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3`V
M+3`X(#(R.C,P*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@4&5R+5-T:6%N
M(%9A=&YE(#QP<W9`;W)S=&$N;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@3F]R
M=V5G:6%N($YY;F]R<VL@/&YY;F]R<VM`;W)S=&$N;W)G/EQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R
M;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P
M-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@
M;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D
M92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!E<B!I:VMJ92!K;VYF:6=U<F5R
M="!I(')E9VES=&5R970@=&EL($AO<F1E+B(*"B,Z(&9R86UE=V]R:R]4<F5E
M+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B<E
M<R<@=F%R="!L86=T('1I;"!G<G5P<&5S>7-T96UE="XB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E
M;2XB"FUS9W-T<B`B)R5S)R!V87)T(&QA9W0@=&EL('1I;&=A;F=S<WES=&5M
M970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(G)7,G('9A<G0@:6MK
M:F4@;W!P<F5T=&$Z("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER
M97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($YO
M=&ES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!V
M961L:6ME:&%L9'-O<&5R87-J;VYA<B`M(%-T861F97-T:6YG(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(%9I;&OE<B!F;W(@
M879T86QE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M
M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@
M(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")+<GES<R!A=B!F;W(@;W!E<F%S
M:F]N*&%R*2!D=2!V:6P@:_AY<F4@;F\N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U
M:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R
M(")+=F%R="`U+B!M:6YU='0B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B6VQI;FIE("5S(&%V("5S72(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E8F]K
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L
M96YD97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@
M(B5S("T@3F]T:7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI
M<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B
M92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@
M;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF
M;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM
M<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V
M87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@
M+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U
M>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")$:6X@:6YF;W)M
M87-J;VXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*(RP@9G5Z>GD*;7-G
M:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R
M<R(*;7-G<W1R("(R-"!T:6UA<B(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^1&5T('-K
M:F5D9&4@96EN(&MA=&%S=')O9F%L(&9E:6PZ/"]B/B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P
M-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@
M(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS
M9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS
M9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET
M;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*
M;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")$:6X@:6YF;W)M87-J;VXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`B4W1A9&9E<W0@<&%S<V]R9"(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I
M9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B3&5G9R!T
M:6PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP
M.C(R-0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@
M(DQE9V<@=&EL('5N9&5R;W)D;F$@;V)J96MT(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDY"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*
M;7-G<W1R("),96=G('1I;"!U;F1E<F]R9&YA(&]B:F5K='1I;&=A;F<@=&EL
M("<E<R<B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ
M>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(DQE9V<@=&EL(&)R=6MA<B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y
M"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N
M(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3&5G9R!T:6P@
M=6YD97)O<F1N82!O8FIE:W1G<G5P<&4@=&EL("<E<R<B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS
M9W-T<B`B3&5G9R!T:6P@=6YD97)O<F1N82!O8FIE:W1T:6QG86YG('1I;"`G
M)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U
M<V5R.B(*;7-G<W1R("),96=G('1I;"!N>2!B<G5K87(Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`B3&5G9R!T:6P@;GET="!M961L96TB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("),
M96=G('1I;"!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A
M9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%D<F5S<V5B;VLB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B061R97-S96)O
M:R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G
M<W1R("),96=G('1I;"!B<G5K87(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DQE9V<@=&EL(&)R=6MA<F%R(&5R
M('-LY71T(&%V+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED
M(")!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
M061R97-S96)O:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")%;F1R92!T:6QG
M86YG(&9O<B`G)7,G(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%D;6EN:7-T<F5R:6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(DQE
M9V<@=&EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*;7-G
M<W1R(")!;&EA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R
M:6$B"FUS9W-T<B`B06QI87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L:6%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(R"B,L(&9U>GIY"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@
M(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ
M(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT
M97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I
M9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D%L
M=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D1I(&4M<&]S=&%D<F5S
M<V4Z(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R
M;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!
M;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*
M;7-G<W1R(")%:6X@=6QO=FQE9R!V97)D:2!V87)T('-P97-I9FES97)T+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@
M(CQB/D1E="!S:VIE9&1E(&5I;B!K871A<W1R;V9A;"!F96EL.CPO8CXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D9N
M;W)R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@
M4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L
M>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I
M9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM
M<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D5R(&1U('-I
M:VME<B!PY2!A="!D=2!V:6P@<VQE='1E("<E<R<_(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E
M<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B17(@9'4@<VEK:V5R
M('#E(&%T(&1U('9I;"!S;&5T=&4@)R5S)S\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M
M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM
M<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G
M:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_(@IM<V=S='(@(E-P^'(@;VT@<W1A9&9E<W1I;F<@9OAR
M(&OX>7)I;F<@878@=F5D;&EK96AA;&1S;W!E<F%S:F]N87(_(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C
M;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*
M;7-G<W1R(")0<OAV9&4@Y2!S;&5T=&4@96D@:6MK:F4M96MS:7-T97)A;F1E
M(&=R=7!P92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")0<OAV9&4@Y2!S;&5T=&4@96EN(&EK:VIE+65K<VES=&5R
M86YD92!T:6QG86YG+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B4'+X=F1E(.4@96YD<F4@96EN(&EK:VIE+65K<VES=&5R
M86YD92!T:6QG86YG+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU
M,PHC+"!F=7IZ>0IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+B(*;7-G<W1R(")0<OAV9&4@Y2!E;F1R92!E:6X@:6MK:F4M
M96MS:7-T97)A;F1E('1I;&=A;F<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*(RP@9G5Z>GD*
M;7-G:60@(D%U9W5S="(*;7-G<W1R("),=7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S
M=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R
M"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I
M<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K
M<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS
M9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E
M;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T
M:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@
M(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E1I;&=J96YG96QE9V4@9F5L
M=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U
M<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R
M8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN(@IM
M<V=S='(@(D)A<F)I92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS
M9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*
M;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS
M9W-T<B`B0G5R<V1A9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")&86YN(&EK:VIE('9A<G-E;&QY='1A<B`E<RXB"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I
M;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")"
M;V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R
M9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z
M>GD*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)R=6XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@
M(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(D)R87II;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@
M(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@(D-64R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-2
M0R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G
M:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*(RP@9G5Z
M>GD*;7-G:60@(D-A;&TB"FUS9W-T<B`B079B<GET(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A
M;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E
M;F%R96XN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*
M;7-G<W1R(")+86QE;F1E<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI
M;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(D%V8G)Y="(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B079B<GET('!R;V)L96UR87!P;W)T(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I
M9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@
M(D-A<'1I;VXB"FUS9W-T<B`B06QT97)N871I=B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I
M9"`B0V%R<FEE<B(*;7-G<W1R(")"87)B:64B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F
M;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS
M9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP
M:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E
M($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV
M"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`B=D-A<F0B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B
M"FUS9W-T<B`B06YG<F4@96YD<FEN9V%R(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U<B!0
M87-S=V]R9"(*;7-G<W1R(")3=&%D9F5S="!P87-S;W)D(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B
M"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE
M(@IM<V=S='(@(E1I='1E;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('!A<W-W
M;W)D(@IM<V=S='(@(E-T861F97-T('!A<W-O<F0B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R
M;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX
M"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")&86YN(&EK:VIE('9A<G-E;&QY
M='1A<B`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2V%L96YD
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*
M;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I
M9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:VL@9F]R(.4@:&%L
M9&4@9G)A;2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G
M<W1R("),=6MK('9I;F1A=6=E="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O
M;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P
M<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L
M;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@
M(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O
M;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@
M9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B1FER;6$B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS
M9VED(")#;VUP86YY(@IM<V=S='(@(D9I<FUA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS
M9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@
M(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I
M9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")3=&%D9F5S="!P87-S;W)D
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F
M('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q
M,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B3W!P:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X:VME;'1E;F%R(&YE:W1A
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T
M<B`B3W!P:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X:VME;'1E;F%R(&YE:W1A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("));FYH86QD(&D@
M)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0V]N
M=&EN=64B"FUS9W-T<B`B2VQI:VL@9F]R(.4@:&%L9&4@9G)A;2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`B1FER;6$B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(DEM
M<&]R=&5R=&4@9F5L=#H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y
M-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@4$=0+6MO9&4@;65L9&EN
M9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS
M9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@4$=0+7-I9VYE<F4@;65L9&EN9RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE(%!'4"UK;V1E(&UE;&1I;F<N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VMJ92!0
M1U`M<VEG;F5R92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DMU
M;FYE(&EK:VIE(&1E:V]D92!01U`M9&%T82XB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!
M4"UT96YA<F5N+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(DMU;FYE(&EK:VIE('-K869F92!O9F9E;G1L96<@;OAK:V5L(&9R
MY2!N^&MK96QT96YA<F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B2W5N;F4@
M:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(")+=6YN92!I:VMJ92!D96MO
M9&4@4$=0+61A=&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU,C(*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R(")+=6YN92!I:VMJ92!D96MO9&4@4$=0+61A
M=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@9&5K
M;V1E(%!'4"UD871A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(")+=6YN92!I:VMJ92!A=F=J97)E
M(&UO='1A:V%R96X@<VD@92UP;W-T861R97-S92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@879G:F5R92!M;W1T86MA<F5N('-I(&4M
M<&]S=&%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-K869F92!O9F9E;G1L96<@
M;OAK:V5L(&9RY2!N^&MK96QT96YA<F5N+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E
M<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(")+
M=6YN92!I:VMJ92!01U`M:V]D92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE(&]P;F4@36%I;G1E;F%N8V5?5&%S
M:RUM;V1U;&5N("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ92!O<&YE($UA:6YT96YA;F-E
M7U1A<VLM;6]D=6QE;B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(B<E<R<@=F%R="!I:VMJ92!O<'!R971T83H@)7,B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E
M<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE
M(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM
M<V=S='(@(DMU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E+7!O
M<W1A9')E<W-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92!E
M<B!I:VMJ92!O<F1E;G1L96<@:V]N9FEG=7)E<G0B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE(%!'4"US:6=N97)E(&UE;&1I;F<N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@9&5K;V1E(%!'4"UD871A+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@
M8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM
M<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N
M97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M5&EL9V%N9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G
M:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM
M<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N
M<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T
M"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!7
M96%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@
M(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL
M>2(*;7-G<W1R(")$86=L96<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*
M;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0HC+"!F
M=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R(")/<'!D871E<B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E
M8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@
M(D1A9VQE9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B4VQE='1E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(D1E8V5M8F5R(@IM
M<V=S='(@(DUE9&QE;6UA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB
M+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T
M<B`B4VQE='1E(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS
M9W-T<B`B0G)U:R!S=&%N9&%R9'9E<F1I(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G
M<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ
M,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L
M971E(@IM<V=S='(@(E-L971T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E($-E;&PB"FUS9W-T<B`B4VQE='1E(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!'<F]U<"(*;7-G<W1R(")3;&5T=&4B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,
M;V<B"FUS9W-T<B`B4VQE='1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B5&EL
M9V%N9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@
M(E-L971T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C;VQU;6XB
M"FUS9W-T<B`B4VQE='1E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*
M;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5N9')E('1I;&=A;F<@9F]R("<E<R<B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3;&5T=&4B"@HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4W1A
M;F1A<F1I9&5N=&ET970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@
M(E-L971T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(E-K:6QD<F4@<')O8FQE
M;65T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z
M>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&P@<VMI;&1R:6YG
M.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R(")$971A;&IA<B!E<B!L;V=G82!F;W(@861M:6YI<W1R871O<F5N
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E
M=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E9I<VEN9W-A
M;'1E<FYA=&EV(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV
M"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(E9I<VEN9W-A;'1E<FYA=&EV(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY
M"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")6:7-I;F=S86QT97)N
M871I=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G
M:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@
M;F]T(&1E;&5T92(*;7-G<W1R(")3;&5T=&4B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DEK:VIE(&)R=6L@;6%I;G1E;F%N
M8V4N<&AP(&1I<F5K=&4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O
M<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,T"B,L(&9U>GIY"FUS9VED(")$<G5G<R(*;7-G<W1R("),=7,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*
M;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM
M=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O
M=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%
M8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC
M.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM
M<V=S='(@(D5N9')E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET
M($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(V"B,L(&9U>GIY"FUS9VED(")%9&ET($=R;W5P
M(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"B,L
M(&9U>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B5&EL9V%N
M9R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*(RP@9G5Z>GD*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@
M(D5N9')E('1I;&=A;F<@9F]R("<E<R<B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHU"B,L(&9U>GIY"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*
M;7-G<W1R(")%;F1R92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")%
M;F1R92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B16YD<F4@=&EL9V%N9R!F;W(@
M)R5S)R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U
M8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L
M(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@
M(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM
M<V=I9"`B16UA:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(D1I(&4M<&]S=&%D<F5S<V4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N(@IM<V=S='(@(E!A<W-O<F1A(&WE('-A;7-V87)E+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@(D5M
M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D%N;F%N(&EN9F]R;6%S
M:F]N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*
M(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")!;'1E<FYA=&EV
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R
M(")4;VUT(')E<W5L=&%T+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS
M9W-T<B`B5&]M="!R97-U;'1A="XB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E
M<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D
M(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B1F5I;"(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@
M)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W
M;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMV87)T
M(#$U+B!M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"B,L
M(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2W9A<G0@
M-2X@;6EN=71T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S
M(@IM<V=S='(@(DMV87)T(#,P+B!S96MU;F0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@
M(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")+=F%R="`U+B!M:6YU='0B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS
M9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")+=F%R(&EN;FQO9V=I;F<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF
M(&AO=7(B"FUS9W-T<B`B2W9A<B!H86QV92!T:6UE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2W9A<G0@;6EN=71T(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@
M=F%L=65S.B(*;7-G<W1R(")%:W-E;7!E;'9E<F1I87(Z(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B
M17AP86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A
M<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X
M<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED
M(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE(&AE;G1E(&EN;G-T:6QL:6YG87(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R
M96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U
M>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@
M(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")+=6YN92!I
M:VMJ92!H96YT92!I;FYS=&EL;&EN9V%R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC
M+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(DEM<&]R=&9E
M:6PZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS
M9W-T<B`B1F%K<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED
M(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA
M=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM
M<V=I9"`B1FEL92(*;7-G<W1R(")4:71T96PB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QH86YD<V%M:6YG
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G
M:60@(D9I;&4@3F%M92(*;7-G<W1R(")&:6QH86YD<V%M:6YG(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X
M-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V
M"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R
M871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*
M;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD
M97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#
M;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*
M;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE
M(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT
M.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B
M1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q
M"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D9N;W)R92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED
M(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S
M='(@(DYA;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&<F%N8V4B
M"FUS9W-T<B`B3W)A;G-J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@
M(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1G5L;"!S:VEL9')I;F<Z(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D1I='0@
M;F%M;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A
M=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A
M>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"B,L(&9U>GIY"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B1W+X;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@
M(D=R^&XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")'<F5N861A(@IM
M<V=S='(@(D=R^&XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!E861M:6YI<W1R
M97)I;F<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(DMU
M;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I
M9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'
M=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@HC
M+"!F=7IZ>0IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W+E(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHX.`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")!
M9')E<W-E8F]K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@HC+"!F
M=7IZ>0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D]V97)S:W)I9G1E<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*(RP@
M9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B3W9E<G-K<FEF=&5R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG
M:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N
M<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(DAJ96QP(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S
M='(@(DAJ96QP(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED
M(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y
M"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z
M-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U
M,S4*(RP@9G5Z>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@
M(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E<W-E+"!P<FEV870B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L969O
M;BP@<')I=F%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO
M<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@
M(D9J97)N82`G)7,G(&9RY2!S>7-T96UE="XB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R
M:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D
M9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F
M=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E
M(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N
M965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N
M<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM
M86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1E<G1E(&9E;'0Z("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R
M=&5R=&4@9F5L=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R=&5R
M=&4@9F5L=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B4VMR:78@:6YN(&1I='0@
M8G)U:V%R;F%M;B!O9R!P87-S;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B
M"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM
M<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M(")$:6X@:6YF;W)M87-J;VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN
M($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U
M"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS
M9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T
M"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("))
M;G-E<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B
M26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("))
M;G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@
M(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I
M9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW
M"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q
M,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM
M<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G
M:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E
M;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PIM
M<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R
M;V1U8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP
M:65N=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*
M;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM
M<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q
M"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES
M;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM
M<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T
M<B`B1&%G;&5G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*
M(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R
M(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E
M8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")'<N4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED
M(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E
M;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@
M(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PHC+"!F
M=7IZ>0IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B3F5K="(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P
M<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED
M(")+97D@5'EP92(*;7-G<W1R(")-24U%+71Y<&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW-#`*(RP@9G5Z>GD*;7-G:60@(DME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B3W!P
M:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X:VME;'1E;F%R(&YE:W1A+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE
M)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED
M(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G
M:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<N5K(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA
M;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED
M("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T
M<B`B3W!P9&%T97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO
M9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R("),;V=G('5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE
M8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(D5K
M<V5M<&5L=F5R9&EA<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(")!;&1R:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"B,L
M(&9U>GIY"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(DQY<R!B;.4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC
M+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),;V=G(&EN;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS
M9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),>7,@8FSE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*
M;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM
M<V=I9"`B3&EN:R(*;7-G<W1R("),;V=G(&EN;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B
M3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N
M<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*
M;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A
M=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")6:7,@96UN
M92!F<N4@2&IE;'`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED
M("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y
M"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B5FES(&5M;F4@
M9G+E($AJ96QP(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S
M8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T="!A=BXB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("),:7-T:6YG(&%V
M(&)R=6MA<F%R(&5R('-LY71T(&%V+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T="!A
M=BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A
M;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G
M<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B3&]G9R!I;FXB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO
M9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*
M;7-G<W1R("),;V=G('5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("),;V=G(&EN;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(D]P<&?E=F5R(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DV"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)+=6YN92!A=B!E:6X@96QL97(@
M86YN86X@9W)U;FX@:6MK:F4@;&]G9V4@:6YN+B!386YN<WEN;&5G=FES(&5R
M(&)R=6MA<FYA;6X@(@HB96QL97(@<&%S<V]R9"!T87-T82!I;FX@9F5I;"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN
M(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQO
M9V<@=70B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(DQO=F4B"FUS9W-T<B`B1FIE<FXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S
M='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I
M9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&+79E9&QE9V<@:6YN
M96AE;&1T(&EN9V5N(&1A=&$N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS
M9W-T<B`B12UP;W-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q
M"FUS9VED(")-86EL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(D4M
M<&]S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B12UP
M;W-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G
M<W1R(")%+7!O<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G
M:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-
M87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G
M:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R
M("+%='9A<FEN9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM
M<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*
M;7-G<W1R(")386US=F%R86YD92!F96QT(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@
M8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A
M<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM
M<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA
M>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P
M"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@
M(DUE9&QE;6UA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G
M:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@
M8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`B365L9&EN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")-
M97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B365L
M9&EN9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B
M(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B1&5T
M86QJ87(@97(@;&]G9V$@9F]R(&%D;6EN:7-T<F%T;W)E;BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES
M(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)0
M0R]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D
M92`G)7,G(&EK:VIE(&1E9FEN97)T(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D
M969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D4M<&]S="(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED
M(")-:6UE(%1Y<&4B"FUS9W-T<B`B34E-12UT>7!E(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I
M9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC
M+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(D9E:6PB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%10
M7U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I
M;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED
M(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM
M<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@
M(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N
M9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B3>5N
M861L96<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM
M<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED
M(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS
M9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS
M9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*
M;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@
M(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@
M06=R964B"FUS9W-T<B`B3D5)+"!E9R!E<B!)2TM*12!S86UD(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B
M3F%M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C
M87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T
M:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@
M(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P
M92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").971T=F5R:R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*
M;7-G:60@(DYE=F5R(@IM<V=S='(@(D%L9')I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5
M<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O
M<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S
M=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(E!A<W-O<F1A(&WE('-A;7-V
M87)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z
M>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,#4*(RP@9G5Z>GD*;7-G:60@(DYE=W-G<F]U
M<',B"FUS9W-T<B`B1W)U<'!E<B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I9"`B
M3F5X="!O<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL(&%L=&5R;F%T:78B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X
M=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E
M<B(*;7-G<W1R(")!;&1R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S@P"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS
M9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O<FUA<VIO;B!S<&5S
M:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS
M9W-T<B`B06YG<F4@96YD<FEN9V%R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(DYO(&-H:6QD<F5N(&-A
M;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B<E<R<@
M=F%R="!L86=T('1I;"!T:6QG86YG<W-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("));F=E;B!K;VYF:6=U
M<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344P@5D93+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O
M<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@
M(DEN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E<G0@
M9F]R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C<Q-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B
M26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F
M;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W
M-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO
M(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E
M<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!
M=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP
M:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG
M=7)A<VIO;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N
M=&ES97)I;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP
M.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG
M=7)A<VIO;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N
M=&ES97)I;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N
M<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN
M9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@
M(DYO=&%T87(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*
M;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DYO=&%T87(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@
M<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@
M(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")3
M:W)I=B!I;FX@9&ET="!B<G5K87)N86UN(&]G('!A<W-O<F0B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@
M6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B26YG96X@9WEL9&EG92!834PM
M9&%T82!R971U<FYE<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,L
M(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").
M;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT
M,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DYO=&%T
M87(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I
M9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS
M9VED(").;W1E<R(*;7-G<W1R(").;W1A=&%R(@H*(SH@<V5R=FEC97,O;V)R
M;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R(@IM
M<V=S='(@(DUE9&QE;6UA<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(")-961L96UM
M87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").
M=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@
M9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*
M;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J
M96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS
M9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@
M86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ
M>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"B,L(&9U>GIY"FUS9VED(")/;6%N(@IM<V=S='(@(D]R86YS:F4B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS
M9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N
M<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G
M:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I
M9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN
M9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")!;'1E<FYA=&EV
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS
M(&9O<B`E<R(*;7-G<W1R(")!;'1E<FYA=&EV(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T
M<B`B061M:6YI<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"B,L(&9U
M>GIY"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R86YS:F4B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B
M3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B06YN86X@:6YF
M;W)M87-J;VXB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"B,L
M(&9U>GIY"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG
M86YG(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED
M(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I9"`B
M4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T
M960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED
M(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G
M:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q
M"B,L(&9U>GIY"FUS9VED(")032!3=6XB"FUS9W-T<B`B4V]L(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-
M(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*
M;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O
M<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T
M(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")0
M87-S;W)D(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@
M9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G
M:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")087-S;W)D82!M
MY2!S86US=F%R92XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM
M<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP
M8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3
M:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R(")2;VQL92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS
M9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B2_AY<B!V961L:6ME:&%L9'-O
M<&5R87-J;VYA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`B2_AY<B!V961L:6ME:&%L9'-O<&5R87-J;VYA<B!V960@:6YN
M;&]G9VEN9S\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")4:6QG86YG
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z
M>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E1I;&=A;F<B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B5&EL9V%N9R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P
M.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O
M:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@
M(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E1I;&=A;F=S
M861M:6YI<W1R97)I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*
M(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D%N;F%N(&EN9F]R;6%S:F]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I
M9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI
M<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F
M;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0
M:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I
M<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C
M96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I
M;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2XB"FUS9W-T<B`B4VMR:78@:6YN(&5I="!S86UA;F1R86<@878@<')O
M8FQE;65T+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VMR:78@
M:6YN(&1I='0@8G)U:V%R;F%M;B!O9R!P87-S;W)D(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)6
M97(@=F5N;&5G(&]G(&QE<R!F^&QG:F%N9&4@=&5K<W0N($1U($W%('9E<F4@
M<V%M9"!M960@=FEL:^5R82!F;W(@Y2!B<G5K92`B"B)S>7-T96UE="XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET
M:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T
M;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@
M9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\
M8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?
M<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I
M9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@
M(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I
M97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B
M"FUS9W-T<B`B4')E<V5N=&%S:F]N87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@
M(E!R;V)L96TB"FUS9W-T<B`B6U!R;V)L96UR87!P;W)T72(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO
M;B(*;7-G<W1R(")3:VEL9')I;F<@878@<')O8FQE;65T(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(D]F9F5N=&QE9R]P<FEV870@;OAK:V5L<&%R('9A<G0@:6MK:F4@9V5N
M97)E<G0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U
M;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y
M("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I
M9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM
M<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B
M4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQE<R(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")2
M96%D(&UE<W-A9V5S(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@
M(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")2
M969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")&<FES:R!O<'`@;W9E<G-I
M:W1V:7-I;F<Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B
M3G5L;'-T:6QL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM
M<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(DQE<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D9J97)N
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")2
M96UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")2
M96UO=F4B"FUS9W-T<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G
M<W1R(")&:F5R;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-3<*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS
M9W-T<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN
M9R(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B1FIE<FX@
M<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M
M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E('1H92(*;7-G<W1R(")&:F5R;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")&:F5R;B!P
M87(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`HC+"!F
M=7IZ>0IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T
M=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B2W5N;F4@:6MK:F4@<W9A<F4@
M<.4@9OAR97-P=7)N860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34W"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-V87)E('#E
M(&;X<F5S<'5R;F%D(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[X9'9E;F1I9R`G=&%B
M;&4G(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(").^&1V96YD:6<@)W1A8FQE)R!I:VMJ92!S<&5S:69I
M<V5R="!I(&MO;F9I9W5R87-J;VX@9F]R(%9&4RXB"@HC.B!F<F%M97=O<FLO
M571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(D[X9'9E;F1I9R`G=&%B;&4G(&EK:VIE('-P97-I9FES
M97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@5D93+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE
M;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(DYU;&QS=&EL;"(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R
M9"(*;7-G<W1R(")087-S;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B
M"FUS9W-T<B`B4W1A9&9E<W0@<&%S<V]R9"(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP
M.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G
M:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL(&%L
M=&5R;F%T:78B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*
M;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*
M;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")4:6QB86ME('1I;"!A;'1E
M<FYA=&EV(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2
M:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3<*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R
M("),>7,@8FSE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VQL92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I
M9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W
M('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)O;&QE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"B,L
M(&9U>GIY"FUS9VED(")2=6XB"FUS9W-T<B`B4V]L(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R("),97,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I
M9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED
M(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")3
M35,@365S<V%G:6YG(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M
M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q
M"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M86EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")3
M86EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'
M<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN
M8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`HC+"!F=7IZ>0IM
M<V=I9"`B4V%V92(*;7-G<W1R("),86=R92`G)7,G(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B3&%G<F4@)R5S)R(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(DQA9W)E("<E<R<B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO
M;G,B"FUS9W-T<B`B3&%G<F4@86QT97)N871I=B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@
M(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R
M8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")696P@9&%T;V9O
M<FUA=#HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I
M9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O
M=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@
M=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T
M<B`B5F5L(&1A=&]F;W)M870Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)696P@=&5I:VYA(&1U('1R
M96YG(&9RY2!B;VMS86YE('5N9&5R+B!$=2!K86X@<^4@:V]P:65R92!O9R!L
M:6UE(&1E:2!I;FX@9G+E("(*(G1E:W-T8F]K<V$N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z(@IM<V=S='(@(E9E;"!S:VEL:F5T96EK;B!F;W(@9&%T;SHB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5F5L(&1A=&]F;W)M870Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")6
M96P@<VMI;&IE=&5I:VX@9F]R(&1A=&\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM
M<V=S='(@(E9E;"!T:61S9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+B(*;7-G<W1R(")696P@=&\@<V%M<W9A<F%N9&4@9F5L="XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(E9E;"!F87)G97-K:F5M82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9E;"#X;G-K82!S<'+E:SHB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N
M9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")396YD('!R;V)L96UR87!P;W)T
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*
M;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"B,L(&9U>GIY"FUS
M9VED(")397!T96UB97(B"FUS9W-T<B`B365D;&5M;6%R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A
M;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS
M9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G
M:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B5&EL9V%N9W-A9&UI;FES=')E
M<FEN9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I
M;VYS(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B5F5L(/AN<VMA('-P<N5K.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(E-E
M="!F87)G97-K:F5M82P@<VED96]P<&9R:7-K:6YG(&]G(&%N9')E('9I<VEN
M9W-A;'1E<FYA=&EV+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*
M;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@
M9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R="!S86UA
M;F1R86<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E9I<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G
M:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H
M;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W97)S(@IM
M<V=S='(@(E9I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q
M-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED
M(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC
M92(*;7-G<W1R(")(;W!P(&]V97(@=F5D;&EK96AA;&0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4VYO
M=R(*;7-G<W1R(")6:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO
M=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S
M("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS
M9W-T<B`B061R97-S92P@87)B96ED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS
M9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED
M(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("));FYT87-T:6YG(&%V
M('-P97-I86QT96EK;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R
M("));7!O<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A<F0B
M"FUS9W-T<B`B)7,@4W1A;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R
M(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B
M4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*
M;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4L(&%R8F5I
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I
M9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@HC+"!F=7IZ>0IM
M<V=I9"`B4W4B"FUS9W-T<B`B4V]L(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B1F%N;B!I:VMJ92!V87)S
M96QL>71T87(@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R
M;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B(@H*
M(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E
M96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5K<V5S<R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S
M='(@(DQA('1I;"`G)7,G('1I;"!S>7-T96UE="XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B1FIE<FYA("<E<R<@9G+E('-Y<W1E;65T+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E
M;&5T960@7"(E<UPB+B(*;7-G<W1R(")3;&5T=&$@)R5S)RXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(D9J97)N82`G)7,G(&9RY2!S>7-T96UE="XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB
M(@IM<V=S='(@(E-L971T82`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T
M<B`B4VQE='1A("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I
M9"`B4W5D86XB"FUS9W-T<B`B4V]L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5M;6%R>2(*;7-G<W1R(")-:71T('-A;6%N9')A9R(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"B,L(&9U>GIY"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(E-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")3=6YN>2(*;7-G
M<W1R(")3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V
M"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E-O;"(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*
M(RP@9G5Z>GD*;7-G:60@(E-U;G-E="(*;7-G<W1R(")3;VPB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS9VED(")3
M=7!P;W)T(@IM<V=S='(@(DEM<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z
M>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(D)R=6MA<FYA;6XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM
M<V=I9"`B4W5R;F%M92(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L
M971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R
M"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y
M<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I
M9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*
M(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E1I='1E;"(*"B,Z
M(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED
M(")486)L92(*;7-G<W1R(")4:71T96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I
M9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(D]P<&?E=F5R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P
M:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V
M.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B0G)U:V%R861M:6YI<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*
M;7-G:60@(E1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G
M:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(D1U(&5R
M(&QO9V=A('5T+CQB<B`O/E1A:VL@9F]R(&%T(&1U(&)R=6MA<B!D971T92!S
M>7-T96UE="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N
M(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED
M(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@
M(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'DB"FUS9W-T<B`B2VQA<W-A($UA:6YT96YA;F-E.CH@=F%R="!I:VMJ
M92!L87-T82!I;FXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B
M"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM
M<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G
M:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A
M8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED
M("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E
M:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@
M(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B2W)Y<'1E<FEN9W-F=6YK<VIO;F%N92!K
M<F5V(&5I('-I:VME<B!N971T;W!P:V]P;&EN9RXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@
M8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`HC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148M
M=F5D;&5G9R!I;FYE:&5L9'0@:6YG96X@9&%T82XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L
M;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R
M,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@
M=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I
M96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO
M=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T
M('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A
M;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E
M;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B
M(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@
M:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A
M9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@
M(D1E;FYE('9E<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS
M<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI
M;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E
M<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D
M871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N
M<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P
M;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W
M;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP
M:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI
M=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC
M96PN<&AP.C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(D9A;FX@:6MK
M:F4@<')O9W)A;6UE="!S;VT@8G)U:V%S="!T:6P@Y2!V:7-E(&1E;FYE('1Y
M<&5N(&UE;&1I;F=A<B`H)7,I+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED
M(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4
M:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H
M('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G
M:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A
M9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I
M9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N(@IM<V=S='(@(DEN9V5N(&EN;G-T:6QL:6YG87(@97(@=&EL
M9VIE;F=E;&5G92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S
M(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y
M<W1E;3H@)7,B"FUS9W-T<B`B4')O8FQE;2!M960@Y2!L96=G92!T:6P@)R5S
M)R!T:6P@<WES=&5M970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L
M96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(E!R;V)L96T@=F5D(&9J97)N:6YG(&%V("<E<R<@9G+E('-Y
M<W1E;65T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')O8FQE;2!V960@
M9FIE<FYI;F<@878@)R5S)R!F<N4@<WES=&5M970N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B4')O
M8FQE;2!M960@Y2!L96=G92!T:6P@)R5S)R!T:6P@<WES=&5M970N(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB
M86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I
M96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D1E;FYE
M('9E<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I
M96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R(")$96YN92!V97)D:65N(&WE('9E<F4@
M96ET('1A;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS
M9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A
M9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V
M,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*
M(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D1E='1E('1A;&5T(&WE
M('9E<F4@;6EN<W0@96EN+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D1E;FYE
M('9E<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")4:71T
M96PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4
M:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q
M"FUS9VED(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3
M;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*
M;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&EO
M;G,B"FUS9W-T<B`B4')E<V5N=&%S:F]N87(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"B,L
M(&9U>GIY"FUS9VED(")4=7)K97DB"FUS9W-T<B`B1W+E(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N
M(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PHC
M+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC
M+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R(")/<F%N<VIE(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA
M;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R
M(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM
M<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(")+=6YN92!I
M:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I;"!344PM=&5N
M87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R
M(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:VIE
M(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT
M96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G
M<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N
M(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S
M;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMU;FYE(&EK
M:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L
M971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@
M<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DMU;FYE(&EK
M:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN
M92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:VIE(')E9VES
M=')E<F4@:6YN<W1I;&QI;F=A<B!I(/AK=&$N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R
M86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O
M24U34"]!=71H+G!H<#HQ,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R
M(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@
M:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I
M;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL
M(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H
M*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")+=6YN92!I:VMJ
M92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT
M96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X
M-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*
M;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`B2V%N(&EK:VIE(&]M<V5T:F4@9&5T=&4@5V]R9"UD;VMU;65N=&5T+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+
M=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#
M:&%N9V5S(@IM<V=S='(@(D%N9W)E(&5N9')I;F=A<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*(RP@9G5Z>GD*;7-G:60@(E5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M(@IM<V=S='(@(E5G>6QD:6<@<W9A<B!F<N4@=&5N87(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*(RP@9G5Z>GD*;7-G:60@(E5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")5
M9WEL9&EG('-V87(@9G+E('1E;F%R(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N
M:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B
M56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK
M;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I
M9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y
M-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")"<G5K87)N86UN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED
M(")5<&1A=&4B"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B3W!P9&%T97)T92`G)7,G+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z>GD*
M;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")/<'!D871E<G1E
M("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R(")"<G5K87)A<B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@
M(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B0G)U:V%R861M:6YI<W1R
M97)I;F<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM
M<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D)R=6MA<F%L=&5R;F%T:78B
M"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R(")"<G5K87)A9&UI;FES=')E<FEN9R(*"B,Z('-I
M9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B
M57-E<FYA;64B"FUS9W-T<B`B0G)U:V%R;F%M;B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA
M;64Z("(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`B0G)U:V%R87(@:2!S>7-T96UE=#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G
M:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U
M"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B(*;7-G
M<W1R(")4:6QG86YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L
M('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P
M"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6
M:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE
M($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*
M;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")7
M24X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S
M='(@(L5T=F%R:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C
M87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E
M871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B5V5E:VQY(@IM<V=S='(@(DMV87(@=F5K92(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM
M<V=S='(@(E9E;&MO;65N+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E9E;&MO;65N
M('1I;"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R(")696QK;VUE;BP@)7,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G
M:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G
M:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*
M;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7
M:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET
M;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H
M(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED
M(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7
M:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@
M(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R97-S92P@87)B
M96ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N+"!A<F)E
M:60B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@
M82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N
M871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED
M96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G
M<W1R("+%Q2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R("+%Q2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS
M9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G
M<W1R("+%<FQE9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(EEE
M;65N(@IM<V=S='(@(D=R^&XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G
M:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")*82P@96<@97(@<V%M9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G
M:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T
M97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DW-0HC+"!F=7IZ>0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")+=6YN92!I:VMJ92!A=F=J97)E
M(&UO='1A:V%R96X@<VD@92UP;W-T861R97-S92XB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D%L
M=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T(&]P<&1A=&5R=&4N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D1U(&WE('-K:6QD<F4@<')O
M8FQE;65T(&;X<B!D=2!K86X@<V5N9&4@<')O8FQE;7)A<'!O<G1E;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS
M9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P
M;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E
M<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R
M92!E:70@8G)U:V%R;F%M;B#E(&9J97)N92XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N
M86UN(.4@9FIE<FYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")$=2!MY2!S<&5S
M:69I<V5R92!E:70@8G)U:V%R;F%M;B#E(&QE9V=E('1I;"XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B1'4@;>4@<W!E
M<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!L96=G92!T:6PN(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N86UN
M(.4@9FIE<FYE+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U(&WE('-P97-I9FES
M97)E(&5I="!B<G5K87)N86UN(.4@9FIE<FYE+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BV&MT82!D:2`H)7,I(&AA
M<B!GY71T('5T('#E('1I9"X@3&]G9R!I;FX@<.4@;GET="XB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I(&4M<&]S=&%D<F5S<V4Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")$:2!E+7!O<W1A9')E
M<W-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")$:6X@:6YF;W)M87-J;VXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!.86UE(@IM<V=S='(@(D1I='0@;F%M;CHB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@
M861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F
M97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B075T
M96YT:7-E<FEN9W-B86MD96QN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN(@IM<V=S='(@(B(*(DQI<W1I;F<@878@8G)U:V%R87(@97(@:6MK
M:F4@<W3X='1A(&%V(&)A:W)E(&%U=&5N=&ES97)I;F<L(&5L;&5R(&9U;FMS
M:F]N96X@(@HB:&%R(&%V(&5I;B!E;&QE<B!A;FYA;B!G<G5N;B!B;&ET="!S
M;.5T="!A=BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE
M('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N(@IM<V=S='(@(D%L=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T
M(&]P<&1A=&5R=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R
M(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R
M(")$:71T(&YA;6XZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P
M,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B06QT97)N871I=F$@9&EN92!H87(@8FQI='0@;W!P9&%T97)T92XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@
M(D%L=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T(&]P<&1A=&5R=&4N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B06QT97)N871I
M=F$@9&EN92!H87(@8FQI='0@;W!P9&%T97)T92XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@
M(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E
M9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX
M.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FQE;7)A
M<'!O<G1=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E
M<R!O9B`E<UTB"FUS9W-T<B`B6VQI;FIE("5S(&%V("5S72(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B061M:6YI<W1R97)I;F<B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G
M:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R(")3;&5T=&4B"@HC.B!L:6(O87!I+G!H
M<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B1W)U<'!E
M<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@
M9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(DAJ96QP(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS
M9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(DQO9V<@:6YN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B3&]G9R!U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@
M(D%L=&5R;F%T:78B"@HC.B!L:6(O87!I+G!H<#HQ,S<*(RP@9G5Z>GD*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L
M(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B1FIE<FX@
M<&%R(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R(")"<G5K87)A<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B061R97-S96)O:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ
M>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@
M8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I
M;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A
M=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*
M;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B5&ET=&5L(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L
M(&9U>GIY"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B3W9E<G-K<FEF=&5R(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y
M,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(FYA;64B
M"FUS9W-T<B`B3F%M;B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*
M;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@
M:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM
M<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BQ71V87)I;F<B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I
M9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D
M>2(*;7-G<W1R("),97,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B
M=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*
M;7-G<W1R(")+=F%R(&EN;FQO9V=I;F<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T
M>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G
M:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E
M871H97(N8V]M(@IM<V=S='(@(B(*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O<&Q?4$PN<&\`````````````````
M````````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8R,#`Q-0`Q,#4Q
M-30S,3`V,P`P,38S-S<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!(3U)$12!0;VQI<V@@=')A;G-L871I;VXN"B,@0V]P
M>7)I9VAT("A#*2`R,#`Q($UA<FEU<WH@6GEN96P@/&UA<FEU<WI`;6EZ87(N
M;W)G/@HC($UA<FEU<WH@6GEN96P@/&UA<FEU<WI`;6%T:"YU=V(N961U+G!L
M/BP@,C`P,2X*(R!0:6]T<B!2;W-Z871Y8VMI(#QD97AT97)`9&5B:6%N+F]R
M9SXL(#(P,#$N"B,@2W)Z>7-Z=&]F($MO>FQO=W-K:2`\:V]Z:6LQ0&\R+G!L
M/BP@,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R
M<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$Q+3(T(#(P.C4V*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#4M,3$M,C0@,C$Z-#8K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!+<GIY
M<WIT;V8@2V]Z;&]W<VMI(#QK;WII:S%`;S(N<&P^7&XB"B),86YG=6%G92U4
M96%M.B!0;VQI<V@@/'!L0&QI+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X
M-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N(@IM<V=S='(@(B5S("T@9V]T;W=Y(&1O('=Y:V]N86YI82!C>6ML
M:6-Z;GEC:"!O<&5R86-J:2!Z87IN86-Z;VYY8V@@<&]N:;]E:BXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&1N:2!T96UU*2(*"B,Z(&QI
M8B](;W)D92YP:'`Z,3(U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S
M<VME>2`E<RDB"FUS9W-T<B`B*&ML=6-Z(&1O<W3J<'4@)7,I(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI
M;B`E<R!D87ES*2(*;7-G<W1R("(@*'<@8VFQ9W4@)7,@9&YI*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S<R"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R
M("(@*&1Z:;8I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S0*;7-G:60@
M(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H:G5T<F\I(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S-S`*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@
M*'=C>F]R86HI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(B!A="`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB
M)7-<(B!N:64@:F5S="!P<F%W:62S;W=Y;2!W>6)O<F5M+B(*"B,Z(&QI8B](
M;W)D92]296=I<W1R>2YP:'`Z-34T(&QI8B](;W)D92]296=I<W1R>2YP:'`Z
M.3,T"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!N
M:64@:F5S="!S:V]N9FEG=7)O=V%N>2!W(')E:F5S=')Z92!(;W)D92XB"@HC
M.B!L:6(O2&]R9&4O5')E92YP:'`Z,38T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B5S(&YI97IN86QE>FEO;GDN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H
M92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")59&&S;R!S:>H@9&]D8>8@7"(E
M<UPB(&1O(&=R=7`N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE
M('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ(&1O9&'F
M(%PB)7-<(B!D;R!U<')A=VYI9?$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU
M-2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB
M)7-<(B!N:64@>F]S=&&S('5T=V]R>F]N>3H@)7,N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(R-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@:2`E<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@57=A9V$B"@HC.B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-J
M82`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(&]D
M8VES:R!P86QC82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M,S`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!K0B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N(@IM<V=S='(@(B5S("T@;W!E<F%C:F4@8WEK;&EC>FYE("T@<&]T=VEE
M<F1Z96YI92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(Q.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M971U<"(*;7-G<W1R(")+;VYF:6=U<F%C:F$@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M:6=N(%5P(@IM<V=S='(@(E)E:F5S=')A8VIA("5S(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HU-C@@;&EB+U9&4R]F='`N<&AP.C8S-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M)7,@:G6_(&ES=&YI96IE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E
M<R`E<R(*;7-G<W1R("(E<R!D;R`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B)7,@:F5S="!W>6UA9V%N>2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B
M"FUS9W-T<B`B)7,@;6EN=70B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B)7,@;FEE>FYA;&5Z:6]N>2XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('1O("5S(&]F("5S(@IM<V=S='(@(B5S(&1O("5S('H@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($%D9')E<W,@0F]O:R(*;7-G<W1R(")+<VFQOVMA(&%D<F5S;W=A("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+86QE;F1A<GH@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C@W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B3F]T871N:6L@)7,B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C@Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A
M<VML:7-T(@IM<V=S='(@(DQI<W1A('IA9&'Q("5S(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4S(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.3@*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E
M<R`E<R(*;7-G<W1R("(E<R!D;R`E<R!Z("5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#<P(&QI8B](;W)D92]&;W)M+G!H<#HR,3(Y"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV.#@*;7-G:60@(BTM('-E;&5C="`M
M+2(*;7-G<W1R("(M+2!W>6)I97)Z("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUG;V1Z
M:6YN>2!F;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@
M(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+6=O9'II;FYY(&9O<FUA="(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R
M<R(*;7-G<W1R("(R-"!G;V1Z+B(*"B,Z(&QI8B](;W)D92]522]086=E<BYP
M:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\4&]P<GIE9&YI(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(D$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB
M"FUS9W-T<B`B0G)A:R!K;VYF:6=U<F%C:FD@=V5W;NIT<GIN96H@9&QA('1E
M9V\@:&]S=&$B"@HC.B!L:6(O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B3F%S=+%P:;,@8K.Q9"!K
M<GET>6-Z;GDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,C`*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(E!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI
M8WIN>2!01U`@9&\@>F%S>GEF<F]W86YI82!W:6%D;VUOMF-I+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-#4*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(E!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!0
M1U`@9&\@<W!R87=D>F5N:6$@<&]D<&ES86YE:B!W:6%D;VUOMF-I+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-S<*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B)0;W1R>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%!'4"P@:VQU8WH@
M<')Y=V%T;GD@4$=0(&]R87H@:&%SLV\@9&\@(@HB;V1S>GEF<F]W86YI82!W
M:6%D;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDY-0IM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(E!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@
M4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A>B!H87.S;R!D;R`B"B)P;V1P
M:7-A;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)0;W1R>F5B;F4@
M<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T;GD@4R]-
M24U%(&]R87H@:&%SLV\@9&\@(@HB;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B
M"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G
M92XB"FUS9W-T<B`B(@HB4&]T<GIE8FYE('.Q(&ML=6-Z('!U8FQI8WIN>2!3
M+TU)344L(&ML=6-Z('!R>7=A=&YY(%,O34E-12!O<F%Z(&AA<[-O(&1O("(*
M(G!O9'!I<V%N:6$@=VEA9&]M;[9C:2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")0;W1R>F5B
M;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4TU)344@9&\@>F%S>GEF<F]W86YI
M82!W:6%D;VUOMF-I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R
M("):86UK;FEJ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T
M<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"B,L(&9U>GIY"FUS9VED(")!32!286EN(@IM<V=S='(@(D]S
M=')Z9;]E;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3(*(RP@9G5Z>GD*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B
M26UP;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3,*(RP@9G5Z>GD*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("));7!O<G0B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*
M;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D\@='EM(&5D>71O
M<GIE(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B
M;W5T+BXN(@IM<V=S='(@(D\@<')O9W)A;6EE+BXN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T
M=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(D%B<VUI9&1L92(*;7-G
M<W1R(")3=&%N;W=I<VMO(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P"B,L
M(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"B,L(&9U
M>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*
M;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@
M4U%,+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R(")(87.S;R!D;R!K;VYT82(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O
M=6YT(&9R;WIE;BXB"FUS9W-T<B`B2V]N=&\@>F%B;&]K;W=A;F4N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q-PIM<V=I9"`B06-C;W5N=&EN
M9R(*;7-G<W1R(")+;VYT82(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S,@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,38*;7-G:60@(D%D9"(*;7-G<W1R(")$;V1A:B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"B,L(&9U
M>GIY"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B1&]D86H@;F]W
ML2!G<G5PZB(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#0@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B1&]D86H@;F]W92!U<')A=VYI96YI92(*
M"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R
M93HB"FUS9W-T<B`B1&]D86H@='5T86HZ(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,#@@861M:6XO9W)O=7!S+G!H<#HR,#D*;7-G:60@(D%D9"!.97<@1W)O
M=7`B"FUS9W-T<B`B1&]D86H@;F]WL2!G<G5PZB(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-S,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-`IM<V=I
M9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D1O9&%J(&YO=V4@=7!R
M87=N:65N:64B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3W!C:F4@)7,B"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(D]P8VIE("5S(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G
M<W1R(")$;V1A:B!N;W=E9V\@=;]Y=&MO=VYI:V$Z(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B061D(&-O;'5M
M;B(*;7-G<W1R(")$;V1A:B!K;VQU;6[J(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM
M<V=S='(@(D1O9&%J(&YO=WEC:"!C>K-O;FOS=R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")$
M;V1A:B!P87+J(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(B"FUS9W-T<B`B1&]D86H@;65N=2`E<R!D;R!P87-K82!-;WII
M;&QI(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM
M<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B1&]D86H@9&\@
M:W-IL;]K:2!A9')E<V]W96HZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R(")$;V1A:B!D;R!M;VIE:B!K<VFQ>FMI(&%D<F5S;W=E:B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")$
M;V1A:B!UOWET:V]W;FEK82(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R(")$;V1A;F\@7"(E<UPB(&1O
M('-Y<W1E;74N($UOOV5S>B!S:>H@>F%L;V=O=V'F+B(*"B,Z('-I9VYU<"YP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B1&]D86YO
M(%PB)7-<(B!D;R!S>7-T96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")$;V1A=V%N:64@=;]Y
M=&MO=VYI:_-W(&IE<W0@=WFS86-Z;VYE+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#0S(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS9VED
M(")!9&1R97-S(@IM<V=S='(@(D%D<F5S(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DMS
M:;&_:V$@861R97-O=V$B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D]P8VIE("5S(@H*
M(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-T<F%C:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDR"FUS
M9VED(")!9',B"FUS9W-T<B`B4F5K;&%M>2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N
M(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@
M(D%L8F%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9VEE<FEA(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@
M(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")7<WIY
M<W1K;R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q."!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R(")7<WIY<V-Y('5W:65R>GET96QN:65N:2!UOWET:V]W
M;FEC>2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H
M<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5W-Z>7-T:VEE(&=R
M=7!Y(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&QI8B](;W)D
M92]097)M<R]522YP:'`Z-S<*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G
M<W1R(")7<WIY<W1K:64@=7!R87=N:65N:6$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"B,L(&9U>GIY"FUS
M9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<R"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,B"FUS9W-T<B`B4&]Z=_-L(&YA('=I96QE(&%D<F5S\W<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1&%T851R964O<W%L+G!H<#HT,#@*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(DIUOR!I<W1N:65J92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(D%L=&5R;F%T>7=N>2!L;V=I;B!)35-0(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS
M9W-T<B`B06QT97)N871Y=VYY(&AA<[-O($E-4U`B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#DQ"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M
M92(*;7-G<W1R(")!;'1E<FYA='EW;F$@;F%Z=V$@=;]Y=&MO=VYI:V$@24U3
M4"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!
M;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA='EW;GD@
M861R97,@96UA:6PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@HC+"!F
M=7IZ>0IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")4=_-J
M(&%D<F5S(&4M;6%I;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T
M97AT.B(*;7-G<W1R(")!;'1E<FYA='EW;GD@=&5K<W0Z(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE
M<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@
M:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("):;W-T8;-A
M('!O9&%N82!N:65P<F%W:62S;W=A('=A<G1OMN8N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B4')O<WKJ('!O9&'F
M(&YA>G?J('6_>71K;W=N:6MA(&D@:&%SLV\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM
M<V=S='(@(D%N9&]R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY
M(@IM<V=S='(@(D%N;VYI;6]W92!0<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B3V1P;W=I
M962\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT>61A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O
M2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P
M;&EK86-J82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G:60@
M(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!<&QI:V%C:F$@9V]T
M;W=A(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@
M(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*
M;7-G<W1R("):871W:65R9+PB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#,P"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S<@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R(")+=VEE8VEE\2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(E=I96QK;[;F(&%R8VAI=W5M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R(").87IW82!A<F-H:7=U;2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B
M0WIY(&YA('!E=VYO(&-H8V5S>B!U<W5NL>8@=.H@<F5G=;/J/R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D-Z>2!N
M82!P97=N;R!C:&-E<WH@=7-U;K'F('3J(')E9W6SZC\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E
M;G1I;F$B"FUS9W-T<B`B07)G96YT>6YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G
M<W1R(")!<FUE;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G
M:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,3<*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G
M<W1R(")0;W!R;[8@;R!P;W1W:65R9'IE;FEE('!R>F5D('=Y:V]N86YI96T@
M;W!E<F%C:FD@8WEK;&EC>FYY8V@_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,3(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<U"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HS.`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z.3@*;7-G:60@(D%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071R>6)U='DB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@Q(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T
M(@IM<V=S='(@(E-I97)P:67Q(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@
M(D%U<W1R86QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075S=')I82(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7V-Y<G5S.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O
M(')O>G-Z97)Z96YI82!I;6%P+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7V-Y<G5S.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z
M96YI82!I;6%P+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G
M:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W
M:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($YI92!Z;F%L97II;VYO('=Y
M;6%G86YE9V\@<F]Z<WIE<GIE;FEA($944"X@4VMO;7!I;'5J(%!(4"!Z("(*
M(G!A<F%M971R96T@+2UE;F%B;&4@+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM
M87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.:64@>FYA
M;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!)34%0+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E
M<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]K<F(U.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI
M82!K<F(U+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C4X"FUS9VED
M(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]L9&%P.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N
M96=O(')O>G-Z97)Z96YI82!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R("):87!I<WIA;FEE('-Z:VEC=2!N:65U
M9&%N92X@4V5R=V5R('IW<O-C:;,@;V1P;W=I962\.B`E<R(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!
M=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=7-U;K'F('6_>71K;W=N:6MA("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE('5D8;-O('-IZB!U86MT=6%L;FGF
M('6_>71K;W=N:6MA("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z
M-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($YI92!Z;F%L97II;VYO
M('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA($U#04PN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M<VUB875T:#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N
M:6$@<VUB875T:"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@
M(E5W:65R>GET96QN:65N:64@;FEE('!O=VEO9+-O('-IZB(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(E5W:65R>GET96QN:65N
M:64@;FEE('!O=VEO9+-O('-IZBX@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R
M861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!O
M9')Z=6-O;F4@<')Z97H@<V5R=V5R(%)!1$E54RXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z-S8X"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!D;R!S97)W97)A
M($944"!N:64@<&]W:6]DLV\@<VGJ+B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.#,*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@
M(D1O<W3J<&YE('!O;&$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!
M>F5R8F5J9+]A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I
M9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(E=Y;?-W:VD@0D]&2"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*
M;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B5+-O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R(")+;VQO<B!TLV$B"@HC.B!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+B(*;7-G<W1R("):LV4@:&%SLV\@2V5R8F5R;W-A+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA
M;64N(@IM<V=S='(@(EJS82!N87IW82!UOWET:V]W;FEK82!+97)B97)O<V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"86AA;6%S(@IM<V=S='(@(E=Y<W!Y($)A:&%M82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%J;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R
M(")"8;-T>6-K:2`H25-/+3@X-3DM,3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*
M;7-G<W1R(")"86YG;&%D97-Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<S"B,L(&9U>GIY"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")/9')Z
M=6-O;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)I8;-O<G6V(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS
M9W-T<B`B0F5L:7IE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9'DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B0FAU=&%N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D1A=&$@=7)O
M9'IE;FEA(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC
M871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG
M<R(*;7-G<W1R(")5<W1A=VEE;FEA(&)L;VMU(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(E1Y<"!B;&]K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.`HC+"!F=7IZ>0IM<V=I9"`B0F]L9"(*;7-G<W1R(")4<F6V
MYB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:7=I82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3$*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R("):86NS861K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*
M;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B
M2&]R9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@
M(D)OMFYI82!I($AE<F-E9V]W:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D]B82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W
M86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M(RP@9G5Z>GD*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B5WES<'D@
M3W=C>F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>GEL:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M;&=A<FEA(@IM<V=S='(@(D)ULV=A<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0HC+"!F=7IZ>0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R(")7>6)I97)Z(&QI<W3J(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,PIM<V=I9"`B0TU3
M(@IM<V=S='(@(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")7LV&V8VEW;[9C:2!K;VWS<FMI+BXN("A?8RDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34P"B,L(&9U>GIY
M"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R
M("):8;.Q8WIN:6L@;FEE('IO<W1ALR!Z;F%L97II;VYY+B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$T.`IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L
M96YD87)Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-`IM
M<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T
M<B`B2V%M8F]DOV$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<G5N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DYI92!U9&&S;R!S:>H@
M>G)E<V5T;W=AYB!H87.S82!A=71O;6%T>6-Z;FEE+"!S:V]N=&%K='5J('-I
MZB!Z("(*(F%D;6EN:7-T<F%T;W)E;2XB"@HC.B!L:6(O2&]R9&4O075T:"]C
M>7)U<RYP:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!)34%0.B`E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86YA
M9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,30@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$W"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,3<*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")!
M;G5L=6HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM
M<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%N=6QU:B!R
M87!O<G0@;R!P<F]B;&5M:64B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C4V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DYI92!M;[]N82!S:V%S;W=AYB!P;&EK=2!<(B5S7"(B"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!Z;F%L9;SF(&MA=&%L
M;V=U('1Y;6-Z87-O=V5G;RXB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z
M.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G
M('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(U
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N82!S:V%S;W=AYB!K871A;&]G
M=2!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$Q,B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HU.#0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*
M;7-G<W1R(").:64@;6^_;F$@<VMA<V]W8>8@:V%T86QO9W4@7"(E<UPB(@H*
M(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3$R"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B
M5WES<'D@6FEE;&]N96=O(%!R>GELL61K82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G
M:60@(D-A<'1I;VXB"FUS9W-T<B`B3W!C:F4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R(")+871E9V]R:64@:2!O>FYA8WIE;FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@
M(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(E=Y<W!Y(%-A;&]M;VYA(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E
M;&P@4&AO;F4B"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L
M;"!0<F]P97)T:65S(@IM<V=S='(@(E>S8;9C:7=OMF-I(&MO;?-R:VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM
M<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#
M96QL('!R;W!E<G1I97,B"FUS9W-T<B`B5[-AMF-I=V^V8VD@:V]M\W)K:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R
M"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5&5L
M+B!K;VTN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E
M;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D-E;'1Y8VMI("A)4T\M.#@U
M.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")#96YT97(B"FUS9W-T<B`B
M4W1W\W)Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S
M='(@(E)E<'5B;&EK82"F<F]D:V]W96H@069R>6MI(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I(@IM<V=S='(@(J9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM
M,BDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B
M0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")3>F-Z96?SLWD@8V5R='EF
M:6MA='4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I
M9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B5[-AMF-I8VEE;"!C97)T
M>69I:V%T=2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"B,L
M(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")3
M>F-Z96?SLWD@8V5R='EF:6MA='4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B
M0WIA9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@(D-H86YG92(*;7-G
M<W1R("):;6EE\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(EIM:67Q(&EM:>HL(&YA>G=I<VMO(&D@861R97,L(&MT
M\W)Y(&EN;FD@=VED>K$@=R!4=V]I8V@@;&ES=&%C:"!E;6%I;"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W
M"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(DMA;&5N9&%R>B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B4W!R87=DO"!L
M:6YK+BXN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P
M+FEN8SHQ,PIM<V=I9"`B0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T
M<B`B6F%Z;F%C>B!P;WIY8VKJ(&1L82!K=/-R96H@8VAC97-Z('=Y:V]N8>8@
M;W!E<F%C:NHN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EN82(*;7-G<W1R(")#:&EN>2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H
M:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S
M=V]R9"(*;7-G<W1R(")0;V1A:B!H87.S;R(*"B,Z(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G
M<W1R(")0;V1A:B!N87IWZB!UOWET:V]W;FEK82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.3`*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SHB"FUS9W-T<B`B5WEB:65R>B!S<&]S\V(@=WFV=VEE=&QA;FEA(&1A
M=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF
M;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S
M($ES;&%N9"(*;7-G<W1R(")7>7-P82!";[]E9V\@3F%R;V1Z96YI82(*"B,Z
M(&QI8B]61E,N<&AP.C8Q-2!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"XB"FUS9W-T<B`B6F&SL6-Z;FEK(&YI92!Z;W-T8;,@>FYA;&5Z
M:6]N>2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2V%L96YD87)Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(EID
M86QN92!S97)W97)Y(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C$V"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(DMA
M;&5N9&%R>B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T
M"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B2V%L
M96YD87)Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B
M2V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]B
M;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@
M(DML:6MN:6H@8GD@:V]N='EN=6]W8>8B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%14
M4"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O
M=R(*;7-G<W1R("):86UK;FEJ(&]K;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T-`HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(EIA;6MN
M:6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DMR\W1K
M:64@<W1R97-Z8WIE;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G<W1R
M(")+<F%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T
M<B`B5WES<'D@2V]K;W-O=V4@*$ME96QI;F=A*2(*"B,Z('1E;7!L871E<R]P
M;W)T86PO<VED96)A<BYI;F,Z-`IM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*
M;7-G<W1R(")38VAO=V%J('!A<V5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B
M0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B6G=I\2!F;VQD97(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED
M(")#;VQO<B(*;7-G<W1R(")+;VQO<B(*"B,Z(&QI8B](;W)D92]";&]C:R]#
M;VQL96-T:6]N+G!H<#HR.3D@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,P,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#<R('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3$*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3(*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C@*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-CD*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#8*;7-G:60@
M(D-O;&]R(%!I8VME<B(*;7-G<W1R(")7>6)I97)Z(&MO;&]R(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X-#4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB
M"FUS9W-T<B`B5WEB\W(@:V]L;W)U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*(RP@9G5Z>GD*;7-G:60@(D-O;',Z
M(@IM<V=S='(@(EIW:?$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-PIM
M<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")4>71ULWD@:V]L=6UN(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X-@HC+"!F=7IZ>0IM<V=I
M9"`B0V]M:6-S(@IM<V=S='(@(E1W\W)Z(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(DMO;65N9&$B"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS
M9W-T<B`B4&]WLV]K82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P
M,@IM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUE;G1A<GHB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)Y(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA
M:6QS+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H
M<#HY-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]M<&]S92!-97-S86=E("@E<RDB"FUS9W-T
M<B`B4W1W\W)Z('=I861O;6^VYB`H)7,I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B2V]M<'5T97)Y
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!F=7IZ
M>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(E=A<G5N:VDB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R
M(")787)U;FMI(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@
M(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*
M;7-G<W1R(")3:V]N9FEG=7)U:B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,S<*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS
M9W-T<B`B4&]T=VEE<F2\(&AA<[-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B
M2V]N9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE(@IM<V=S='(@(D1E;6]K<F%T>6-Z;F$@4F5P=6)L:6MA($MO;F=O
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9"XB"FUS9W-T<B`B4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@
M<VGJ+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")0;[.Q8WIE;FEE(&YI92!P;W=I
M;V2S;R!S:>HZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<W.0IM
M<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R(")/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L:6-Z
M;F5G;R!S97)W97)A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<X
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R
M(")/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L:6-Z;F5G;R!S97)W97)A
M+B!0;W?S9#H@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C(*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!&5%`N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B
M0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y('IO<W1ALWD@<&]M>;9L;FEE
M(&1O9&%N92!D;R!4=V]J96H@:W-IL;]K:2!A9')E<V]W96HN(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@
M='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S
M7"(B"FUS9W-T<B`B6F%W87)T;[;F(%PB)7-<(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")+
M;VYY;G5U:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")7>7-P>2!#
M;V]K82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@HC+"!F=7IZ>0IM
M<V=I9"`B0V]O:VEE(@IM<V=S='(@(E1W\W)Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(E-K;W!I=6HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*
M;7-G<W1R(")3:V]P:75J('=Y8O-R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.CDU-@IM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@>F%S
M>GEF<F]W8>8@*%!'4"D@=VEA9&]M;[9C:2XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,#,S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S
M<V%G92XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4$=0*2!W
M:6%D;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`B3FEE('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H4R]-24U%*2!W:6%D
M;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#8W"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B
M3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4R]-24U%*2!W:6%D;VUOMF-I+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N
M86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3$P
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB`E<RXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S
M='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!<(B5S
M7"(@<&]P<GIE>B!&5%`Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3`U"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!O9'-Z
M>69R;W=AYB!D86YY8V@@4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D86YY8V@@
M4R]-24U%+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N
M:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")(
M;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T
M(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-
M86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,X"FUS9VED(")#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RXB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!U<W1A;&GF(&%D<F5S=2!E
M+6UA:6P@;V1B:6]R8WDN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(X,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R
M>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A
M<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(").:64@;6^_
M;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@7"(E<UPB+B(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D
M=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S
M7"(N(@IM<V=S='(@(DYI92!M;[]N82!U='=O<GIYYB!K871A;&]G=2!<(B5S
M7"(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,#@*;7-G:60@(D-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@=7IY<VMAYB!Z('-E<G=E<F$@:VQU
M8WIA('!B=6QI8WIN96=O+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(DYI92!U9&&S;R!S:>H@;W1W;W)Z>>8@7"(E<UPB(&1O('IA<&ES=2XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").:64@;6^_;F$@;W1W
M;W)Z>>8@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF
M(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&MA=&%L;V=U(%PB)7-<(B(*
M"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(").:64@;6^_
M;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#,*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R
M(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@
M)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!E
MLVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!E
MLVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO
M;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W
M86YE+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('-K
M87-O=V%N:64@:V%T86QO9W4@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92!N
M:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PHC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF
M:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W
M('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G
M<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A
M<VL@)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE
M<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C$R,`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!P<GIE<WIU:VEW86YI
M82!Z('-E<G=E<F5M($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYI92!U9&&S
M;R!S:>H@<VMA<V]W8>8@<&QI:W4@7"(E<UPB+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF
M(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3@*;7-G:60@(D-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@>FYA;&6\YB!P
M87-K82!-;WII;&QI+B!5<&5W;FEJ('-IZBP@OV4@:F5S="!O;B!O='=A<G1Y
M+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E
M<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)5OWET:V]W;FEK(%PB)7-<(B!P<F%W
M:62S;W=O('ID969I;FEO=V&S('!R87=A(&1O<W3J<'4@9&\@9F]L9&5R82!<
M(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$*(RP@9G5Z>GD*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS
M9W-T<B`B2W)A:B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S`*
M(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BK'+S9+-A(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B4W1W\W)Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(E-T=_-R>B!L:6YK(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I
M9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")3='?S<GH@;F]WL2(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@HC+"!F=7IZ>0IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(E5T=_-R>B!N;W=Y
M(&9O;&1E<B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871O<B!0
M97)M:7-S:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,C(Y"FUS9VED(")#<F5D:70@8V%R9"!N
M=6UB97(B"FUS9W-T<B`B3G5M97(@:V%R='D@:W)E9'ET;W=E:B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")#<F]A=&EA(@IM<V=S='(@(D-H;W)W86-J82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS
M9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ
M>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")/8F5C;GD@8WIA
M<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H
M<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D]B96-N>2!C>F%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G
M<W1R(")/8F5C;GD@8WIA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")/8F5C
M;GD@8WIA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B
M3V)E8VYY(&MA=&%L;V<Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!S
M='EL92(*;7-G<W1R(")/8F5C;GD@8WIA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A
M<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")3<&5R<V]N
M86QI>G5J('IA9&%N:6$@=7)U8VAA;6EA;F4@<')Z>2!L;V=O=V%N:74@9&\@
M)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B5WET;FEJ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0HC+"!F
M=7IZ>0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@=WEB
M<F%NL2!T;[]S86UOMN8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP<B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H
M2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U
M8FQI8R(*;7-G<W1R(")297!U8FQI:V$@0WIE8V@B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(S('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D-O9'II
M96YN:64B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*(RP@9G5Z>GD*;7-G
M:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,SDX(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I
M9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")/=')Z>6UA;F4B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C@P-@HC+"!F=7IZ>0IM<V=I9"`B1&%T92!S96QE
M8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T
M<B`B0V]D>FEE;FYI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB
M"FUS9W-T<B`B7U5S=?$@:V]L=6UNZB(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")'<G5D>FEE
M\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*
M;7-G<W1R(")'<G5D>FEE\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D1E8W)E87-E($EN
M9&5N="(*;7-G<W1R(")287!O<G1U:B!J86MO(&YI97-Z:V]D;&EW>2(*"B,Z
M(&QI8B]P<F5F<RYP:'`Z,3$Q(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W
M"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S='(@(D1O;7FV;&YY(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*
M;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B1&]M>;9L;GD@:V]L;W(B
M"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT
M($ED96YT:71Y(@IM<V=S='(@(D1O;7FV;&YA('1OOW-A;6^VYB(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$Q.2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$Y-@IM<V=I9"`B1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R(")$;VUY
MMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,3DW"FUS9VED(")$969A=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV
M;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S
M"B,L(&9U>GIY"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")09;-N>2!O
M<&ES.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S(@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,Z(&QI8B](
M;W)D92]097)M<RYP:'`Z,CDU(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$U
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S,R('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW
M,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED
M(")$96QE=&4B"FUS9W-T<B`B57-U\2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3@Y(&%D;6EN+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")$96QE=&4@1W)O=7`B
M"FUS9W-T<B`B57-U\2!'<G5PZB(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z-C,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-PIM<V=I9"`B1&5L971E
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B57-U\2!U<')A=VYI96YI82(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")5<W7Q(&D@=WEC>GFVYB!W
M:6%D;VUOMF-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B
M57-U\2!K;VWS<FOJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G
M<W1R(")5<W7Q(&MO;'5M;NHB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R(")4=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4P(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(E-K87-U:B!U<')A=VYI96YI82!D;&$@7"(E
M<UPB(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-K87-O=V'F('5P<F%W
M;FEE;FEA(&1L82!<(B5S7"(@:2!W<WIY<W1K:64@<&]D+75P<F%W;FEE;FEA
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B57-U\2!W:65R
M<WHB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U
M"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4VMA
M<W5J('=Y8G)A;K$@=&^_<V%M;[;F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED(")$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E5S=?$@86MT=6%L;K$@:V]L
M=6UNZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,@IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*
M;7-G<W1R(")5<W7Q(&%K='5A;&YY('=I97)S>B(*"B,Z(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES('!E<FUI<W-I;VX@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-K87-O=V'F('1O
M('5P<F%W;FEE;FEE(&D@=W-Z>7-T:VEE('!O9"UU<')A=VYI96YI83\B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B
M1&5L:79E<GD@=&EM92(*;7-G<W1R(")5<W7Q(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*
M;7-G<W1R(")$86YI82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q,"!S
M97)V:6-E<R]P<F]B;&5M+G!H<#HQ,30@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(T"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")/<&ES
M>B!P<F]B;&5M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDS."!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U
M>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")09;-N>2!O<&ES.B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")3>F-Z96?SLWD@>F]S=&&S>2!Z
M86QO9V]W86YE(&1L82!A9&UI;FES=')A=&]R82XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DX"B,L(&9U>GIY"FUS9VED(")$979E;&]P;65N
M="(*;7-G<W1R(")$>FEALR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W
M"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N
M(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U.`IM<V=I9"`B1&ES<&QA>2`R
M-"UH;W5R('1I;65S/R(*;7-G<W1R(")7>;9W:65T;"!C>F%S('<@9F]R;6%C
M:64@,C0M9V]D>FEN;GEM/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E5S=&%W:65N:6$@
M=WEG;+%D=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.`HC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G
M<W1R(")5<W1A=VEE;FEA('=Y9VRQ9'4B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@U"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I
M(@IM<V=S='(@(E5S=&%W:65N:6$@=WEG;+%D=2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#$V"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*
M;7-G<W1R(")5<W1A=VEE;FEA('=Y9VRQ9'4B"@HC.B!L:6(O2&]R9&4O34E-
M12]-1$XN<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N(@IM<V=S='(@(E)O>FUI97-Z8WIE;FEE(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II
M8F]U=&DB"FUS9W-T<B`B1+]I8G5T:2(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,34*;7-G:60@(D1O
M(&YO="!D96QE=&4B"FUS9W-T<B`B3FEE(&MA<W5J(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(")"<F%K(&)E>G!OMG)E9&YI
M96=O(&1O<W3J<'4@9&\@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3D*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI:V$@*%=S</-L;F]T
M82!$;VUI;FEK:2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B1&]M:6YI:V%N82`H4F5P=6)L:6MA($1O;6EN:6MA\7-K82DB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R("*F8VFQ9VYI:B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HX-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B
M"FUS9W-T<B`BIF-IL6=N:6H@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38U"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$P.`IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G
M<W1R(").87)K;W1Y:VDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,#(*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@
M(D524B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5K=V%D
M;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E
M9&ET+FEN8SHR,@IM<V=I9"`B161I="(*;7-G<W1R(")%9'EC:F$B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B
M161Y='5J(&-Z87)NL2!L:7-TZB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@X
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(E5S=?$@1W)U<.HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C8R
M(&QI8B](;W)D92]097)M<R]522YP:'`Z.#8*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;B(*;7-G<W1R("):;6EE\2!U<')A=VYI96YI92(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B6FUI9?$@=7!R87=N:65N:6$B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(EIM:67Q('5P<F%W;FEE;FEA(&1L
M82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D
M:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(EIM:67Q('5S=&%W:65N:6$@9&QA
M.B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P-"!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(X,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(EIM:67Q('5P<F%W
M;FEE;FEA(&1L82`E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B6FUI9?$@=7!R87=N:65N:6$@9&QA("5S(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")%9'5C871I
M;VXB"FUS9W-T<B`B3W!C:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9VEP
M="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B4V%L=V%D;W(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#(*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<P(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*
M;7-G<W1R(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3(*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,`IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")!9')E<R!E;6%I;"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.38T"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`B061R97-Y(&5M86EL(&UU<WJQ(&1O('-I96)I92!P87-O
M=V'F+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DP"B,L(&9U>GIY"FUS
M9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")(87.S;R(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR.#`*;7-G
M:60@(D5M;W1I8V]N<R(*;7-G<W1R(")%;6]T:6MO;GDB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S
M<V%G92XB"FUS9W-T<B`B4'5S=&$@=VEA9&]M;[;F+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$R.`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G
M<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")%;7!T>2!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B3W!R\[]N:6H@9F]L9&5R(&MO<WIA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S-0IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,`IM<V=I9"`B16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B5[.Q8WIY
MYB!M96YU(&MO;G1E:W-T;W=E('!O9"!P<F%W>6T@<')Z>6-I<VMI96T@;7ES
M>GD_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3<@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(X,3`*(RP@9G5Z>GD*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@
M(E)O>G=I\2!P87-E:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3,*;7-G:60@(B(*(D5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG
M+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")'
M=VEN96$@4O-W;FEK;W=A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<GET
M<F5A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0W(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(W('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP
M:'`Z-SD*;7-G:60@(D5R<F]R(@IM<V=S='(@(D*SL60B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B
M17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")"<F%K(&9O;&1E
M<G4@>B!N;W=Y;6D@=VEA9&]M;[9C:6%M:2(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B0K.Q
M9"!P<GIY('IA<&ES:64@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T
M<B`B17-T;VYI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]P:6$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@
M(D5T:&YI8R(*;7-G<W1R(")%<W1O;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Q"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(D-O(&MAOV1E(#$U(&UI;G5T(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM
M<V=S='(@(D-O(&MAOV1E(#(@;6EN=71Y(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")%
M=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D-O(&MAOV1E(#,P('-E:W5N9"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S`@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X,@IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D-O
M(&MAOV1E(#4@;6EN=70B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")#;R!K8;]D92!Z86QO
M9V]W86YI92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S(*;7-G:60@
M(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#;R!K8;]D92!P\[,@9V]D>FEN
M>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,CD@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D-O
M(&MAOV2Q(&UI;G5TZB(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C(X"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B4')Z>6NS861O
M=V4@=V%R=&^V8VDZ(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C@@861M:6XO<&AP<VAE;&PN<&AP.C@Q"FUS9VED
M(")%>&5C=71E(@IM<V=S='(@(E=Y:V]N86HB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HS.30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")2;WIW
M:?$B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED
M(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")2;WIW:?$@<&%S96LB"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*(RP@9G5Z>GD*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R(")7>6MO;F%J(@H*(SH@;&EB+TAO<F1E
M+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0P,0IM<V=I9"`B17AP:7)A=&EO;B!$871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<V
M"B,L(&9U>GIY"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%:W-P;W)T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,0HC+"!F=7IZ>0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B1&]M>;9L
M;GD@:V]L;W(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,L(&9U
M>GIY"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(E=G<GEW
M86YI92!P;&EK\W<@;FEE(&IE<W0@;V)SLW5G:7=A;F4N(@H*(SH@;&EB+TAO
M<F1E+U!R969S+W-Q;"YP:'`Z,C$V"B,L(&9U>GIY"FUS9VED(")&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M('IM:6%N>2!U<W1A=VEE\2XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HQ,#`*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"B,L(&9U
M>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@
M3$1!4"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C`S"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")"
ML[%D('!O9&-Z87,@:V]P:6]W86YI82!Z(%PB)7-<(BXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z-C`X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(&MO<&EO=V%N
M:6$@9&\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W
M"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!,1$%0("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV-#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@<')Z96YO<WIE;FEA(&1O(%PB)7-<
M(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.`HC+"!F=7IZ>0IM<V=I9"`B1F%I<B(*;7-G<W1R(")/9"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A
M;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9'D@
M*$UA;'=I;GDI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")7>7-P
M>2!/=V-Z92(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(D*SL60@:W)Y='EC>FYY.B`B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(D9A:W,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B3'5T>2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(D9E
M96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B1F5W(%-H;W=E
M<G,B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D9E=R!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Y-#4*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(D9I9+]I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0V"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B365N962_
M97(@<&QI:_-W(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*
M;7-G<W1R(").87IW82!P;&EK=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.3DT"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")7>6+S<B!P;&EK
M=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#@X"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R(")79W)Y=V%N:64@<&QI:W4B"@HC.B!L:6(O2&]R9&4O
M0G)O=W-E<BYP:'`Z.#8S"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"XB"FUS9W-T<B`B5V=R>7=A;FEE('!L:6OS=R!N:64@:F5S="!O8G.S
M=6=I=V%N92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')Y(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*
M;7-G<W1R(")&:6YL86YD:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Q
M"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(DEM:>HB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V
M"B,L(&9U>GIY"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(DEM:>HB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Y"FUS
M9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`IM<V=I9"`B1FQI<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S
M='(@(B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$P-R!L:6(O5D93+W-Q;"YP
M:'`Z,38P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B5;]Y8VEE(&9O;&1E<G4@;FEE(&IE
M<W0@86MT>6YW92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED(")&;VYT($-O;&]R(@IM<V=S
M='(@(D1O;7FV;&YY(&MO;&]R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(DIE9'IE;FEE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V
M"B,L(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<R(*;7-G<W1R(")7>6UA9V%N82!J97-T(&]B<[-U9V$@:49R
M86UE<RAPLWEW86JQ8WEC:"!R86UE:RD@<')Z97H@<')Z96=LL61A<FOJ(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*(RP@9G5Z>GD*;7-G:60@(D9O
M<F5C87-T("A4048I(@IM<V=S='(@(E5S=&%W:65N:6$@=WEG;+%D=2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,0IM<V=I9"`B(@HB1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDX"FUS9VED(")&;W)G
M;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B6F%P;VUN:6&S9;8@:&%SLV$_
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0HC+"!F=7IZ>0IM
M<V=I9"`B1F]R;7,B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B
M57=A9VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*
M(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B57=A9VDB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"B,L(&9U>GIY"FUS9VED
M(")&;W)U;7,B"FUS9W-T<B`B57=A9VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3`Y"B,L(&9U>GIY"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M(")0<GIE:V&_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G(B"FUS9W-T<B`B3V0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`B3F%Z=V$@=;]Y
M=&MO=VYI:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-J82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE
M=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(D=U:F%N82!&<F%N8W5S:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R(")0;VQI;F5Z:F$@1G)A;F-U<VMA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B1G)A;F-U<VMI
M92!497)Y=&]R:6$@4&^S=61N:6]W92!I($%N=&%R:W1Y8WIN92(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M
M(@IM<V=S='(@(D]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0X"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.30*(RP@9G5Z>GD*;7-G:60@(D9R
M;VT@=&AE("(*;7-G<W1R(")/9"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL($1E<V-R:7!T:6]N
M(@IM<V=S='(@(E!ELVYY(&]P:7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#(@;&EB+T)L;V-K+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,SD*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")4=V]J92!I
M;6GJ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*
M;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E
M("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P
M9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O8V]N9FEG+FAT;6PZ,3`*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N
M>2(*;7-G<W1R(").:65M8WDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B
M1VEV96X@3F%M92(*;7-G<W1R(")-96YE9+]E<B!P;&EK\W<B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B262\
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I
M9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")7>7-Z=6MI=V%R:V$@1V]O9VQE
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`IM
M<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS
M9W-T<B`B1W)E8VIA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*(RP@
M9G5Z>GD*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("*F<F]D
M:V]W;V5U<F]P96IS:VD@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD
M(@IM<V=S='(@(D=R96YL86YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@
M(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W,`HC+"!F=7IZ>0IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
M86-J82(*"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3@*;7-G:60@(D=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C(P,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(W
M-PHC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@<&5R;6ES<VEO;G,B"FUS9W-T<B`B
M1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ-S8@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR-3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*
M;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P>2!D>7-K=7-Y:FYE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=V%D96QU<&$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'
M=V%T96UA;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@
M(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z,3(W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`U"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*(RP@9G5Z>GD*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(X(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C`V"B,L(&9U>GIY"FUS9VED(")'=65S="!P97)M:7-S:6]N
M<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,3<*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W=I;F5A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=6EN96$M0FES<V%U(@IM<V=S='(@(D=W:6YE82!":7-S874B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U>6%N82(*;7-G<W1R(")'=6IA;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U
M-PHC+"!F=7IZ>0IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E5W:65R>GET96QN:65N:64@;FEE('!O=VEO9+-O('-I
MZB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,#(*(RP@9G5Z>GD*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(D%L9V]R>71M('!O9'!I<W4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3$Y(&QI8B](;W)D
M92]&;W)M+G!H<#HR.3,Q"B,L(&9U>GIY"FUS9VED(")(96%D97(B"FUS9W-T
M<B`B3F%GL_-W:VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<R(*;7-G<W1R(")7>7-P>2!(96%R9"!I($UC1&]N86QD82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"B,L
M(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E5W86=I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*(RP@9G5Z>GD*;7-G:60@(DAE
M8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("*F<F]D:V]W;V5U<F]P96IS
M:VD@*$E33RTX.#4Y+3(I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(E=Y<V]K:2(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ-SD@
M;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L
M<"(*;7-G<W1R(")0;VUO8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<S"B,L(&9U>GIY
M"FUS9VED(")(96QP97(B"FUS9W-T<B`B4&]M;V,B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T
M<B`B4&]M;V,B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-R!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG
M:"(*;7-G<W1R(")7>7-O:VDB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z
M,S(Q"FUS9VED(")(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-`IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B7U-T87)T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A
M=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B5V%T>6MA;B`H4W1O;&EC82!!
M<&]S=&]L<VMA*2(*"B,Z(&QI8B](;W)D92YP:'`Z,30S-0IM<V=I9"`B2&]M
M92(*;7-G<W1R(")0;V-ZL71E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R97,@9&]M
M;W=Y(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*
M;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L+B!D;VTN(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+
M;VYG(@IM<V=S='(@(DAO;F=+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z-#(P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@
M7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(W
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(E5D
M8;-O('-IZB!U<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@561ALV\@
M<VGJ('5S=6ZQYB`E<R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$Q-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S(%PB)7-<(B(*;7-G<W1R
M(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@
M:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@
M97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-#@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*
M;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C`U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB('H@
M<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S
M='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$Q-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z
M('-Y<W1E;74N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C@R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S
M=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B561ALV\@<VGJ('5S
M=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS
M9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR.`IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#@@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#<*;7-G:60@(DAU
M;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG
M87)Y(@IM<V=S='(@(E?J9W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N
M<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@<VGJ
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(E!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZCH@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")5=VEE
M<GIY=&5L;FEE;FEE(&YI92!P;W=I;V2S;R!S:>HN("5S(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S,3<*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B
M"FUS9W-T<B`B061R97,B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H
M<#HW-PHC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")";&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N>2XB
M"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0HC+"!F=7IZ>0IM
M<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C
M:RXB"FUS9W-T<B`B0FQO:R!<(DUE=&%R7"(@;FEE(&IE<W0@9&]S=.IP;GDN
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G
M:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y
M"B,L(&9U>GIY"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T
M<B`B27-L86YD:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS
M9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E1Y;&MO(&EK;VYY(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V.0IM<V=I9"`B26-O;G,@=VET:"!T97AT
M(@IM<V=S='(@(DEK;VYY('H@=&5K<W1E;2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B
M3F%Z=V$@=&^_<V%M;[9C:3HB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z-3@Y"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M-PIM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T
M:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X
M"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(X"B,L(&9U>GIY"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")0
M;V1G;+%D('!O8WIT>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S<*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%52
M3"(*;7-G<W1R(")'<F%F:6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED
M("));6%G92!54DPZ(@IM<V=S='(@(D=R869I:V$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$W-C(*(RP@9G5Z>GD*;7-G:60@(DEM86=E('5P
M;&]A9"(*;7-G<W1R(")79W)Y=V%N:64@<&QI:W4B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D=R869I:V$B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHQ,`HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C4W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B
M26UP;W)T;W=A;F4@<&]L93H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L
M9#H@)7,B"FUS9W-T<B`B26UP;W)T;W=A;F4@<&]L93H@)7,B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C<S"FUS9VED("));7!O<G1E9"!F:65L
M9',Z(@IM<V=S='(@(DEM<&]R=&]W86YE('!O;&$Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"B,L(&9U
M>GIY"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")7<')O=V%D
MO"!K;'5C>B!T=71A:B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP
M.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI
M:V$@:2!H87.S;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q
M"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")287!O<G1U
M:B!J86MO(&YI97-Z:V]D;&EW>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B
M26YD:64B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-#$@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE
M>FIA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-#8*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM
M<V=S='(@(E1W;VIE(&EN9F]R;6%C:F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S$X"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N
M;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("));F9O<FUA8VIE(&\@;W-O
M8FES='EM(&ML=6-Z=2!P=6)L:6-Z;GEM(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"B,L(&9U>GIY"FUS
M9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")7<')O=V%DO"!K
M;'5C>B!T=71A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM
M<V=S='(@(E=K;&5J(&]B<F%Z96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M5&%B;&4B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(EIM:67Q(&QI;FLN
M+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E
M9F]R92(*;7-G<W1R(")7<')O=V%DO"!K;'5C>B!T=71A:B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")5<W7Q(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")5<W7Q(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`B57-U\2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,34P"B,L(&9U>GIY"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(E1W\VH@861R97,@92UM86EL.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S$*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L
M;"!A9G1E<B(*;7-G<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E=P<F]W
M862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T
M<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M97-S
M86=E<R(*;7-G<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(E=P
M<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R(")7<')O=V%DO"!K;'5C
M>B!T=71A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@869T
M97(B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R(")7<')O=V%D
MO"!K;'5C>B!T=71A:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*
M;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B26YS
M97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("):;6EE\2!L:6YK+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(EIM:67Q
M(&QI;FLN+BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0S"B,L(&9U>GIY"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").:64@;6^_
M;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`W-0HC+"!F=7IZ>0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")/
M9'=R\^8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S,PHC+"!F=7IZ>0IM
M<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(D]D=W+SYB(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-S`@;&EB+TAO<F1E+T-O;7!R97-S
M+WII<"YP:'`Z,C`Q"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q
M,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")!
M9')E<R!D;VUO=WDB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")$
M;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&)A=&-H
M($E$+B(*;7-G<W1R(").:65P;W!R87=N>2!)1"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#@X(&QI8B](;W)D92]&;W)M+G!H<#HR,34Y(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C,S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,CDX"FUS
M9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")7>7.S86YE
M(&YI97!R87=I9+-O=V4@9&%N92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+B(*;7-G<W1R(").:65P<F%W:62S;W=Y(&%D<F5S(&1O8V5L;W=Y
M+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C@Q(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T
M<B`B3FEE<')A=VEDLV]W>2!F;W)M870@<&QI:W4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38T"FUS9VED("));G9A;&ED(&QI8V5N<V4@
M:V5Y+B(*;7-G<W1R(").:65P<F%W:62S;W=Y(&ML=6-Z(&QI8V5N8VII+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3@*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYI
M97IN86YY(&%D<F5S870B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!M<V=?='EP92XB
M"FUS9W-T<B`B3FEE<&]P<F%W;F$@;F%Z=V$B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N
M:65N:6$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C0S"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI
M96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B1&]M
M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38R"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D
M92XB"FUS9W-T<B`B061R97,@9&]M;W=Y(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M<')O=&]C;VPN(@IM<V=S='(@(DYI97!O<')A=VYY(&]B:F5C=$ED(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM
M<V=S='(@(DYI97!O<')A=VYY('=P:7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$P-#,@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C(P"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(").:65P;W!R87=N
M>2!O8FIE8W1)9"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S
M+B(*;7-G<W1R(")!9')E<R!D;VUO=WDB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!U
M;FEC;V1E(&1A=&$N(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,C4*(RP@9G5Z>GD*;7-G:60@(DEN=F5N
M=&]R>2(*;7-G<W1R(").:65P;W!R87=N>2!W<&ES(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER86XB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(DER87$B"FUS9W-T<B`B27)A:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R
M("))<FQA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G
M:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"B,L(&9U>GIY"FUS9VED("))<V]L
M871E9"!4+5-T;W)M<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L
M(@IM<V=S='(@(DEZ<F%E;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B5WED87=C82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0HC+"!F=7IZ
M>0IM<V=I9"`B271A;&EC(@IM<V=S='(@(E>S;V-H>2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A
M;'DB"FUS9W-T<B`B5[-O8VAY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@
M(DIA;6%J:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S<T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM
M<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")3='EC>F7Q(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A
M;B(*;7-G<W1R(")*87!O;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@HC+"!F=7IZ>0IM<V=I9"`B
M2F5R<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS
M9W-T<B`B2F]R9&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B3&EP:65C(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B0WIE
M<G=I96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U
M"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I
M9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T
M:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG
M:'0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA
M>F%C:'-T86XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C0V"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DME;GEA(@IM<V=S='(@(DME;FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DME>2!#<F5A
M=&EO;B(*;7-G<W1R(")4=V]R>F5N:64@:VQU8WIA(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#`S"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B3V1C:7-K(&ML=6-Z82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0P,0IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$LW5G;[;F(&ML
M=6-Z82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B
M2V5Y(%1Y<&4B"FUS9W-T<B`B5'EP(&ML=6-Z82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B
M"FUS9W-T<B`B5VEA9&]M;[;F(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-S(Y"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(DML=6-Z(&IUOR!I<W1N:65J92!N82!P
M=6)L:6-Z;GEM('-E<G=E<GIE(&ML=6-Z>2XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B1'II96-I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M2V]R96'Q<VMA(%)E<'5B;&EK82!,=61O=V\M1&5M;VMR871Y8WIN82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM
M<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK82!+
M;W)E:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E
M86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T
M<B`B2W5W96IT(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=I
M<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R(")7>6=LL60@*%]Y*2(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-SD*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DKJ
M>GEK(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8R(*;7-G<W1R("),86]S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(DYA>G=I<VMO(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X(&QI8B]";&]C:R]M;V]N+G!H<#HY
M,`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(DYA>G=I
M<VMO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G
M:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(@IM<V=S='(@(D]S=&%T;FEE(&QO9V]W86YI93H@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z-C@X"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B3W-T871N:64@;&]G
M;W=A;FEE.B`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8X,PIM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B3W-T871N:64@;&]G
M;W=A;FEE.B!N:6=D>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(J-O='=A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"B,L(&9U>GIY"FUS9VED
M("),87<B"FUS9W-T<B`B3FES:VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("),969T(@IM<V=S='(@(E!R>F5S
M=?$@=R!L97=O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3@*(RP@9G5Z
M>GD*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A
M<G1OMF-I.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$T"B,L(&9U>GIY
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")0<GIY:[-A9&]W92!W87)T
M;[9C:3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6)E<FEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y
M86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0HC+"!F=7IZ>0IM
M<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*
M;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"B,L(&9U>GIY"FUS
M9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`HC+"!F=7IZ
M>0IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(EIA;&]G=6HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0HC+"!F
M=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B6F%L;V=U
M:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P
M"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G
M<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T
M<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,R"B,L(&9U>GIY"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*
M;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U
M"B,L(&9U>GIY"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6)E<FEA(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,34*(RP@9G5Z>GD*;7-G:60@(DQI
M;FLB"FUS9W-T<B`B6F%D86YI82!P<GIY(&QO9V]W86YI=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM
M<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#<V"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X
M,PHC+"!F=7IZ>0IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B6F%D86YI82!P<GIY
M(&QO9V]W86YI=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@HC+"!F
M=7IZ>0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(E1W\W)Z(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B3&ES="!$871A
M8F%S97,B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I
M8W,B"FUS9W-T<B`B5WFV=VEE=&P@=&5M871Y('!O;6]C>2(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(DQI<W0@5&%B;&5S
M(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y-`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U!
M<F-H:79E(@IM<V=S='(@(E5K<GEJ(&YI97-U8G-K<GEB;W=A;F4B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@
M(DQI<W0M2&5L<"(*;7-G<W1R(")7>;9W:65T;"!T96UA='D@<&]M;V-Y(@H*
M(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"B,L(&9U>GIY"FUS
M9VED("),:7-T+4ED(@IM<V=S='(@(E=YMG=I971L('1E;6%T>2!P;VUO8WDB
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*(RP@9G5Z>GD*
M;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B5WFV=VEE=&P@=&5M871Y('!O
M;6]C>2(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,PHC+"!F
M=7IZ>0IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(E=YMG=I971L('1E;6%T
M>2!P;VUO8WDB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3$*
M(RP@9G5Z>GD*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(E5K<GEJ
M(&YI97-U8G-K<GEB;W=A;F4B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.3`*(RP@9G5Z>GD*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS
M9W-T<B`B56MR>6H@;FEE<W5B<VMR>6)O=V%N92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&ES=&]W86YI92!UOWET:V]W;FEK\W<@
M:F5S="!W>;.Q8WIO;F4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W
M"B,L(&9U>GIY"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(E!O9'!I<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='=A(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*;7-G:60@(DQO861I;F<N
M+BXB"FUS9W-T<B`BHV%D;W=A;FEE+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Y.0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@
M(D-Z87,@;&]K86QN>3H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S
M"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B57-T87=I96YI82!L
M;VMA;&YE(&D@8WIA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HV-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,0HC+"!F
M=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3W!C:F4B"@HC.B!L;V=I
M;BYP:'`Z,38R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-C0@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@V"FUS
M9VED("),;V<@:6XB"FUS9W-T<B`B6F%L;V=U:B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B
M5WEL;V=U:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(EIA9&%N:6$@<')Z>2!L;V=O=V%N:74B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3,Q"FUS9VED("),;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B),;V=O=V%N:64@;FEE('!O
M=VEO9+-O('-IZBP@<&]N:65W8;\@<&]D8;-EMB!N:65P<F%W:62S;W=E(&AA
M<[-O(&QU8B!N87IWZB`B"B)UOWET:V]W;FEK82XB"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3(W"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(DQO
M9V]W86YI92!N:64@<&]W:6]DLV\@<VGJ+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S8W"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B
M5WEL;V=U:B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F=7IZ
M>0IM<V=I9"`B3&]V92(*;7-G<W1R("(B"B(C+2,M(RTC+2,@('!L7U!,+G!O
M("A);F=O(&@S+3$N,"XQ*2`@(RTC+2,M(RTC7&XB"B)0<GIE<W7Q7&XB"B(C
M+2,M(RTC+2,@('!L7U!,+G!O("A);7`@:#,M-"XP+C,I("`C+2,M(RTC+2-<
M;B(*(E!R>F5N:66V7&XB"B(C+2,M(RTC+2,@('!L7U!,+G!O("A4=7)B82!H
M,RTR+C`N,RD@(",M(RTC+2,M(UQN(@HB4')Z96YI9;8B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM
M<V=S='(@(DYI<VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T
M=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*(RP@9G5Z>GD*;7-G:60@(DQO
M=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B1W)U9'II9?$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5K<V5M8G5R9R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S,@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*
M;7-G<W1R(")-86MA=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYI82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*
M;7-G<W1R(")0;V-Z=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B4&]C>G1A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0W-PIM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#`*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA
M>7-I82(*;7-G<W1R(")-86QE>FIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G
M<W1R(")-86QE9&EW>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS
M9W-T<B`B(@HB6F%R>K%D>F%J(&QI<W2Q(&MA=&5G;W)I:2P@:W3S<GEM:2!B
MZF1Z:65S>B!O>FYA8WIALR!P;WIY8VIE+"!I(&MO;&]R86UI('H@(@HB;FEM
M:2!Z=VFQ>F%N>6UI+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#,Y"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-PHC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-`IM<V=I9"`B36%P
M475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-S8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)Z96,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q
M"FUS9VED(")-87)G:6XB"FUS9W-T<B`B36%R9VEN97,B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM
M<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")7>7-P>2!-87)S:&%L
M;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R='EN:6MA(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,3$*;7-G:60@(DUA=&-H
M:6YG(&9I96QD<R(*;7-G<W1R(")087-U:K%C92!P;VQA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-
M875R:71A;FEA(@IM<V=S='(@(DUA=7)E=&%N:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I
M=&EU<R(*;7-G<W1R(")-875R:71I=7,B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET
M+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`HC+"!F=7IZ>0IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED
M(")-87DB"FUS9W-T<B`B36%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R
M(")-86IO='1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"B,L(&9U
M>GIY"FUS9VED(")-961I8VEN92(*;7-G<W1R(")/9')Z=6-O;F4B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$Y"B,L(&9U>GIY"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(D=R=61Z:67Q(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")4
M<GEB(&UE;G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B
M4&^SL6-Z(&MO;?-R:VDB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S`*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
M5VEA9&]M;[;F(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*
M;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF
M:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*
M;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G
M:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE=&%R(%=E871H
M97(B"FUS9W-T<B`B3V)E8VYY(&-Z87,B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")";&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N>2XB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB0FQO:R!<(DUE=&%R7"(@
M;FEE(&IE<W0@9&]S=.IP;GDN(%-Z8WIE9_.S>2!Z9&%R>F5N:6$@>F]S=&&S
M>2!Z86QO9V]W86YE(&1L82`B"B)A9&UI;FES=')A=&]R82XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34R"FUS9VED(")-971A<D1"(&ES
M(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<T"B,L(&9U>GIY"FUS9VED(")-971H;V0B"FUS9W-T<B`B3&5S;W1H
M;R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O
M4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")5OWEC:64@
M9F]L9&5R=2!N:64@:F5S="!A:W1Y;G=E+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C<U"B,L(&9U
M>GIY"FUS9VED(")-971R:6,B"FUS9W-T<B`B365K<WEK(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M97AI8V\B"FUS9W-T<B`B365K<WEK(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS
M9VED(")-:61D;&4B"FUS9W-T<B`B4W1A;F]W:7-K;R(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM
M<V=S='(@(E1Y<"!-:6UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*
M;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(Q-PHC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(D*SL60B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G
M:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$T"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*(RP@9G5Z>GD*;7-G:60@(DUI<W-I
M;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B5VEA9&]M;[;F(&1O(@H*(SH@;&EB
M+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES
M<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*(RP@9G5Z
M>GD*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B3FEE('ID
M969I;FEO=V%N;R!T96MS='4@=R!N;V-I92!W86MA8WEJ;F5J+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@
M(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW
M-`HC+"!F=7IZ>0IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B3F]W82!P
M;V-Z=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`HC+"!F=7IZ>0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B3W-T871N
M:6$@;6]D>69I:V%C:F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I
M960@1&%T92(*;7-G<W1R(")/<W1A=&YI82!M;V1Y9FEK86-J82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,@IM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("):;6EE\2!L:6YK(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B
M"FUS9W-T<B`B36^S9&%W:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(E)E<'5B;&EK82!-;[-D87=I:2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N
M86-O(@IM<V=S='(@(DUO;F%K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T
M<B`B36]N9V]L:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,PHC+"!F
M=7IZ>0IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B4F]Z=VGQ('!A
M<V5K(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R(")#;R!M:65S:;%C(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R
M<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S
M(@IM<V=S='(@(D9A>GD@:W-IZK]Y8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS
M9W-T<B`B36%R;VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`HC+"!F
M=7IZ>0IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")+<F%J(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@
M(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HT,C@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")0<GIE
M<W7Q('<@9/.S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#,R
M"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B4')Z97-U\2!W(&QE=V\B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S8*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`B4')Z97-U\2!W('!R87=O(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-#(T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@
M(E!R>F5S=?$@=R!G\W+J(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Y-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E!R>F5N
M:66V('<@9/.S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Y-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV
M"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E!R>F5S=?$@=R!G\W+J(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Q.#4*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T
M,PHC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@
M(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,S$@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S.`IM
M<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")+;VYT;R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R
M(")-\VH@<&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$R
M-`HC+"!F=7IZ>0IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")0
M;W)T=6=A;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(D)I<FUA(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC
M.C<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S@*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#`P"FUS9VED(").86UE(@IM<V=S='(@(DYA>G=I<VMO(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U
M(@IM<V=S='(@(DYA=7)U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A
M;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B2&]L86YD:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B06YT>6QE($AO
M;&5N9&5R<VMI92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Q
M"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#0*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W
M"B,L(&9U>GIY"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M(@IM<V=S='(@(D)R86L@;W-O8FES=&5G;R!C97)T>69I:V%T=2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@P"B,L(&9U>GIY"FUS9VED(").
M971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E=P<F]W862\(&ML
M=6-Z('1U=&%J(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S.0IM
M<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")3:67F(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C<*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B3F5V97(B"FUS9W-T
M<B`B3FEG9'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]W
M82!+86QE9&]N:6$B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHR-PIM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=V$@
M:V%T96=O<FEA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C
M:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Y"B,L(&9U>GIY
M"FUS9VED(").97<@36]O;B(*;7-G<W1R(").;W=Y(&MO;G1A:W0B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@
M57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:
M96%L86YD(@IM<V=S='(@(DYO=V$@6F5L86YD:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN
M9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8Q"FUS9VED(").97=S(@IM<V=S='(@(E=I861O
M;6^V8VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDU"B,L(&9U
M>GIY"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7!Y(&1Y<VMU<WEJ
M;F4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHR,2!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHT-@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$S-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHS,@IM<V=I
M9"`B3F5X="(*;7-G<W1R(").87-TZG!N92(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R
M(").87-TZG!N82!S=')O;F$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C,W,"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W-`IM<V=I9"`B3F5X="!O
M<'1I;VYS(@IM<V=S='(@(DYA<W3J<&YE(&]P8VIE(@H*(SH@;&EB+TAO<F1E
M+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S
M='(@(DYA<W3J<&YE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEK
M87)A9W5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V.`HC+"!F=7IZ>0IM<V=I9"`B3FEG:'0B"FUS
M9W-T<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@U"B,L(&9U
M>GIY"FUS9VED(").;R(*;7-G<W1R(").:64B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS9VED(").;R!A=F%I;&%B;&4@8V]N
M9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").
M;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C(S,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HR-3(*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D
M('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN
M<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")"<F%K(&EN
M9F]R;6%C:FD@;R!S97)W97)Z92!344P@>B!UOWET:V]W;FEK86UI(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS
M9W-T<B`B0F5Z('IM:6%N+B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,30P"B,L(&9U>GIY"FUS9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@
M=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"XB"FUS9W-T<B`B561ALV\@
M<VGJ(&1O9&'F(%PB)7-<(B!D;R!U<')A=VYI9?$N(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(").;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(")5
M9&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('5P<F%W;FEE\2XB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$V-R!L:6(O2&]R9&4N<&AP.C0W-R!L:6(O2&]R9&4O571I
M;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B0G)A
M:R!K;VYF:6=U<F%C:FD@9&QA("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M-#$*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(")"<F%K(&EN9F]R
M;6%C:FD@;R!S97)W97)Z92!,1$%0('H@=7-T87=I96YI86UI+B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G
M<W1R(")"<F%K(&EN9F]R;6%C:FD@;R!S97)W97)Z92!344P@>B!K871E9V]R
M:6%M:2XB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,#0*(RP@9G5Z>GD*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(D)R86L@:6YF;W)M86-J:2!O
M('-E<G=E<GIE(%-13"!Z(&MA=&5G;W)I86UI+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"B,L(&9U>GIY"FUS9VED(").;R!C
M<F5D:70@;&5F="XB"FUS9W-T<B`B3FEE('=Y9V5N97)O=V%N;R"_861N96=O
M('-K<GEP='4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-`HC+"!F=7IZ>0IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HX.#$*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B3FEE('=G
M<F%N;R!P;&EK=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,34@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(S"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N
M(@IM<V=S='(@(D%P;&EK86-J82!G;W1O=V$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B3FEE>FYA;GD@861R97-A="(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G
M:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(E=I861O;6^VYB(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z
M>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").:64@=WEB
M<F%N;R!UOWET:V]W;FEK82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED(").;R!N=6UB97(@<W!E8VEF
M:65D+B(*;7-G<W1R(").:64@=WEB<F%N;R!UOWET:V]W;FEK82XB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").:64@>FYA;&5Z:6]N;R!K;VYT
M86MT\W<B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N
M:6$@2%144"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L
M;FEE;FEA($E-05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-S(*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEE('!O9&%N;R!H87.S82!D;&$@=7=I
M97)Z>71E;&YI96YI82!+97)B97)O<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HY-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$
M05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@
M9&QA('5W:65R>GET96QN:65N:6$@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@
M;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($Q/1TE.+B(*
M"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA
M(%!!4U-71"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE
M;FEA(%--0BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#8*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M<G5L97,B"FUS9W-T<B`B57=A9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").
M;R!S:61E<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,C4*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(E!R;W-Z
MZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O(@H*(SH@;&EB+TAO
M<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3`S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HY,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDS
M,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(E5W86=I(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@(DYO
M;F4B"FUS9W-T<B`BKV%D;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"B,L(&9U
M>GIY"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("*F<F]D
M:V]W;V5U<F]P96IS:VD@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK
M($ES;&%N9"(*;7-G<W1R(").;W)F;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B
M3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")0;VUO8R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F]R=V%Y(@IM<V=S='(@(DYO<G=E9VEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G
M<W1R(")5=V%G:2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y
M"B,L(&9U>GIY"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(E5W86=I(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S$*(RP@9G5Z>GD*;7-G:60@(DYO="!A
M(&1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.#,*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HY-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S
M='(@(DYI92!Z86EM<&QE;65N=&]W86YO+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS
M9W-T<B`B3FEE=7-T87=I;VYE(@H*(SH@;&EB+U9&4RYP:'`Z,3<U(&QI8B]6
M1E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,3`@;&EB+U9&4RYP:'`Z,C(V"B,Z
M(&QI8B]61E,N<&AP.C(T,B!L:6(O5D93+G!H<#HR-3<@;&EB+U9&4RYP:'`Z
M,C<T(&QI8B]61E,N<&AP.C,P-PHC.B!L:6(O5D93+G!H<#HS-C<@;&EB+U9&
M4RYP:'`Z-#0V(&QI8B]61E,N<&AP.C4Q-2!L:6(O5D93+G!H<#HU,S(*(SH@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-S,@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*
M(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0*;7-G:60@(DYO
M="!S=7!P;W)T960N(@IM<V=S='(@(DYI96]B<[-U9VEW86YE(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$V-`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B57=A9VDB
M"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$P"FUS9VED(").
M;W1I8V4B"FUS9W-T<B`B57=A9V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@T(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3&ES=&]P860B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B
M3G5M8F5R(@IM<V=S='(@(DQI<W1O<&%D(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,C<*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S
M(@IM<V=S='(@(DQI8WIB82!W:65R<WIY(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(DQI8WIB82!K;VQU;6XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B3&EC>F)A('=I97)S
M>GDB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"B,L
M(&9U>GIY"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")3='=O<GIYLV6V
M(&QI<W3J(&1Y<W1R>6)U8WEJ;K$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX,3$*(RP@
M9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R(")496UA="(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$Q"B,L(&9U>GIY"FUS9VED(")/8FIE
M8W0@0W)E871O<B(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-R!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(Q-0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(&-R96%T;W(@<&5R;6ES
M<VEO;G,B"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,R!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B
M97(B"FUS9W-T<B`B4&&\9'II97)N:6LB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#$*;7-G:60@(D]F9FEC92(*
M;7-G<W1R(")":75R;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"B,L(&9U>GIY
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R(")496X@<V5R=V5R(&YI92!O8G.S=6=U:F4@=61O<W3J
M<&YI86YI82!F;VQD97+S=RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4R(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.3<R"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M(@IM<V=S='(@(E1W\VH@:F5D96X@861R97,@92UM86EL(&IE<W0@9&]Z=V]L
M;VYY+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]T=_-R
M>B!W(&YO=WEM(&]K;FEE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-`HC+"!F=7IZ>0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R(")0;V)R8>8@<&]C>G3J('<@;W-O8FYY;2!O:VYI
M93\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A
M=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-J92(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HR.2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R(")/<&-J92`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G:60@(D]R9&5R960@3&ES
M="(*;7-G<W1R(")7>6)I97)Z(&QI<W3J(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/
M<F=A;FEZ86-J82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38X
M"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(DIE9&YO<W1K
M82!O<F=A;FEZ86-Y:FYA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FEZ871O<B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")$;VUYMFQN
M92!U<')A=VYI96YI82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L
M('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M26YN92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("))
M;FYE(&EN9F]R;6%C:F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("));FYE('5P
M<F%W;FEE;FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM<V=I
M9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(E5W:65R>GET96QN:65N:64@4$%-(&YI92!J97-T(&1O<W3J<&YE+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-3,*;7-G:60@(E!'4"!$
M:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")#>69R;W=Y('!O9'!I<R!01U`B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,CDY"FUS9VED(")01U`@
M16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B5VEA9&]M;[;F('IA<WIY9G)O=V%N
M82!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4Q"FUS9VED
M(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")+;'5C>B!P=6)L:6-Z;GD@4$=0
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,S,PIM<V=I9"`B4$=0
M(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")7:6%D;VUOMN8@>F%S
M>GEF<F]W86YA+W!O9'!I<V%N82!K;'5C>F5M(%!'4"(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2V]D(%!(
M4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL
M(@IM<V=S='(@(E!O=[-O:V$@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(E!-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")032!3:&]W
M97)S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")032!3;F]W(@IM
M<V=S='(@(E!O:V&_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("));7!O<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"B,L(&9U>GIY
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]A
M<&DN<&AP.C$R.`IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")0;W>S;VMA
M(%!?2%`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0V"B,L(&9U>GIY"FUS9VED(")0861D:6YG(@IM<V=S='(@
M(E)O>G=I:F%N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A:VES
M=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P
M=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82U.;W=A($=W:6YE82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=V%J(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*(RP@9G5Z>GD*;7-G
M:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2W)A:B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#,*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Q
M.2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<S"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,V,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B2&%SLV\B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W;W)D
M(&EN8V]R<F5C="(*;7-G<W1R(")(87.S;R!N:65P<F%W:62S;W=E(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@
M(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(D)R86L@:6YF;W)M86-J:2!O('-E<G=E<GIE(%-13"!Z('6_
M>71K;W=N:6MA;6DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U-`IM<V=I
M9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2&%SLV\@
M>B!P;W1W:65R9'IE;FEE;2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DAA<[-O.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(DAA<[-O.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S4*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(DAA<[-O(&UU<VD@<&%S;W=AYBXB"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B5VML96HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W
M"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")7:VQE:B!Z
M92!S8VAO=VMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4&%T:"(*;7-G<W1R(")7:VQE
M:B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHT"FUS9VED(")0
M96YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(EM2
M87!O<G0@;R!P<F]B;&5M:65=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#<*(RP@9G5Z>GD*;7-G:60@(E!E<F-E;G0B
M"FUS9W-T<B`B1')U:W5J(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?8F]T=&]M+FEN8SHV"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,B"FUS9W-T<B`B5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C
M:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDX"FUS9VED(")097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@
M(E=Y:V]N86H@8WEK;&EC>FYE(&]P97)A8VIE('!O9&-Z87,@;&]G;W=A;FEA
M/R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,2!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C0*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8W"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E5P<F%W;FEE;FEE(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM
M<V=S='(@(D)R86L@9&]S=.IP=2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C(R-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%C:F$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$T-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T.`HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$U,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R(@IM<V=S
M='(@(E5P<F%W;FEE;FEA(&1L82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF
M;W)M86-J92!O<V]B:7-T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I
M;GDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM
M<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0
M:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V
M"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#@*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`B3F$@<&5W;F\@=7-U;K'F('1E;B!W
M>6)R86YY(&5L96UE;G0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S
M='(@(DYA('!E=VYO('5S=6ZQYB!W>6)R86YY(&5L96UE;G0Z(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(U-S`*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E!R;W-ZZB!P;V1A
MYB!N;W>Q(&YA>G?J.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")0<F]S>NH@
M<&]D8>8@;F%Z=^H@9&QA(&YO=V5G;R!F;VQD97)U.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)
M4"!A9&1R97-S+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@<&]P<F%W;GD@861R
M97,@25`N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-3D*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-#4P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@<&]P<F%W;GD@8WIA<RXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E!R
M;W-ZZB!O<&ES8>8@<')O8FQE;2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$X('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC
M.C$R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I
M9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R
M(")-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z
M('5S=6ZQYBXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQS:V$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E!O
M;&ET:6-S(@IM<V=S='(@(EIW:?$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#,T"B,L(&9U>GIY"FUS9VED(")0;VQL<R(*;7-G<W1R("):=VGQ
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QI82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*
M;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]L9&%P+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VQD87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z
M<WIE<GIE;FEA($Q$05`N(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN
M<&AP.C,S"B,L(&9U>GIY"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M:6UP.B!7>6UA9V%N92!R;WIS>F5R>F5N:64@24U!4"!N:64@>FYA;&5Z:6]N
M92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G
M:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E!R97-S=7)E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$X.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B
M4&]D9VRQ9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(E=YMG=I971L('IA
ML[%C>FYI:R!W(&]S;V)N>6T@;VMN:64B"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,V,"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V-`HC+"!F=7IZ
M>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0<F5Z96YT86-J
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B4')I=F%T92!+97DB"FUS
M9W-T<B`B2VQU8WH@<')Y=V%T;GDB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z
M,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96TB"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B3W!I<R!P<F]B;&5M=2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,3,*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3$R(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3@Y"B,L(&9U>GIY"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")7>6QO
M9W5J(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(DML=6-Z('!U8FQI8WIN>2(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L
M9V]R:71H;2(*;7-G<W1R(")!;&=O<GET;2!K;'5C>F$@<'5B;&EC>FYE9V\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R;6%C:F4@;R!K;'5C>G4@<'5B
M;&EC>FYY;2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(S,`IM<V=I
M9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B4&%R82!K;'5C>GD@;W-O8FES='EC:"!N:64@
M>F]S=&&S82!W>6=E;F5R;W=A;F$@<&]M>;9L;FEE+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U
M97)T;R!2:6-O(@IM<V=S='(@(E!O<G1O<GEK;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R
M(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8R"FUS
M9VED(")1=65R>2(*;7-G<W1R("):87!Y=&%N:64B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@
M4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")+;'5C>B!P=6)L:6-Z;GD@
M4E-!("@E9"!B:73S=RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-0HC
M+"!F=7IZ>0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E-K87-U
M:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0S"B,L(&9U>GIY"FUS9VED(")286EN(@IM<V=S
M='(@(D]S=')Z9;]E;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@(E)A:6X@16%R;'DB"FUS
M9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0U"B,L(&9U>GIY"FUS9VED(")286EN($QA=&4B"FUS9W-T
M<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R
M("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T
M<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"B,L(&9U
M>GIY"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")5=V%G:2(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I;R(*
M;7-G<W1R(")/<&-J92(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDS('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@P"B,L(&9U>GIY"FUS9VED(")296%D(@IM<V=S='(@(E!R>F6S861U:B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(").;W=E('=I861O;6^V
M8VDB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`HC+"!F
M=7IZ>0IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
M5WIN\W<@<W=O:K$@<V5S:NHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@S"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS
M9W-T<B`B3V2V=VEEOR!D>6YA;6EC>FYE(&5L96UE;G1Y(&UE;G4Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,PIM<V=I9"`B4F5F<F5S:"!0;W)T
M86P@5FEE=SHB"FUS9W-T<B`B3V2V=VEEOR!W:61O:R!S97)W:7-U.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C0X"FUS9VED(")296QA
M=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,R-@HC+"!F=7IZ>0IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")$
M86YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(EID86QN92!S97)W97)Y(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,2!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$U"FUS9VED(")296UO=F4B"FUS
M9W-T<B`B57-U\2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ
M,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E5S=?$@8FQO:R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*;7-G:60@
M(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B57-U\2!K;VQU;6[J(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B57-U\2!P87+J
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S8*;7-G:60@(E)E
M;6]V92!P86ER(@IM<V=S='(@(E5S=?$@<&%RZB(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,#4*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#$*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B57-U\2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.0IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$V"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")5<W7Q('6_>71K;W=N
M:6MA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("):
M9&%L;F4@=;]Y=&MO=VYI:V$Z("5S(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR
M<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E
M9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-`HC+"!F=7IZ>0IM<V=I9"`B4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("*O
M861A;GD@;V)J96MT(&YI97IN86QE>FEO;GDN(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-S0@;&EB+TAO<F1E+G!H<#HT.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(D)R86L@=WEM86=A;F5J(&]P8VII("=U
M:60G(&1L82!K;VYF:6=U<F%C:FD@=7-T87=I9?$N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<T-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,3`@;&EB+U9&4R]S
M<6PN<&AP.C4Y-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(D)R86L@=WEM86=A;F5J(&]P8VII("=U:60G(&1L82!K;VYF
M:6=U<F%C:FD@=7-T87=I9?$N(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<X
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0G)A
M:R!W>6UA9V%N96H@;W!C:FD@)W5I9"<@9&QA(&MO;F9I9W5R86-J:2!U<W1A
M=VEE\2XB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(X"FUS
M9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,Y(&QI8B](;W)D92]&;W)M
M+U)E;F1E<F5R+G!H<#HS,34*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0T"FUS
M9VED(")297-E="(*;7-G<W1R(")+87-U:B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M(")7>6-Z>;;F(&AA<[-O(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B5WEC
M>GFVYB!4=V]J92!H87.S;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C4@861M:6XO<&AP<VAE;&PN<&AP.C<Q"FUS
M9VED(")297-U;'1S(@IM<V=S='(@(E=Y;FEK:2(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#(@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4&]W<O-T(&1O
M(&]P8VII(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W
M86YE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I
M8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")2;WIB=61O=V%N>2!E
M9'ET;W(@=&5K<W1U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"B,L
M(&9U>GIY"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E-T86YO=VES:V\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT(@IM<V=S='(@(E=Y<V]K:2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,3(P"B,L(&9U>GIY"FUS9VED(")2:6=H
M="!H96%D97(B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,38*(RP@9G5Z>GD*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R(")0<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C@*(RP@9G5Z>GD*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")496PN(&MO;2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")3=&%N;W=I<VMO(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UU;FEA(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P.`IM<V=I9"`B4F]T871E(#$X
M,"(*;7-G<W1R(")/8G+SYB!O(#$X,"!S=&]P;FDB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"FUS9VED(")2;W1A=&4@3&5F
M="(*;7-G<W1R(")/8G+SYB!W(&QE=V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C$Q"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS
M9W-T<B`B3V)R\^8@=R!P<F%W;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*(RP@9G5Z>GD*;7-G:60@(E)O
M=R!0<F]P97)T:65S(@IM<V=S='(@(E>S8;9C:7=OMF-I(')ZZF1U(%!R;W!E
M<G1I97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")7
MLV&V8VEW;[9C:2!R>NID=2!0<F]P97)T:65S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@
M(E-T86YO=VES:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4F]S:F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N
M9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R
M,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E=I
M861O;6^VYB!Z87-Z>69R;W=A;F$@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!305-,
M(&YI92!J97-T(&1O<W3J<&YE+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-3D*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T
M<B`B5WFV=VEE=&QA;FEE('=I861O;6^V8VDB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")0;W=L;VMA(%-1
M3"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S`*;7-G:60@(E-3
M2"(*;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,3,R"FUS9VED(")37U%,(%-H96QL(@IM<V=S
M='(@(E!O=[-O:V$@4U]13"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM<V=S='(@
M(EIA<&ES>B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("*F=VGJ
M=&$@2&5L96YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS
M9W-T<B`B4V%I;G0@2VET=',@:2!.979I<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C
M:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R
M<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT+5!I97)R92!I($UI<75E
M;&]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!I($=R96YA9'EN>2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@
M(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO
M82(*;7-G<W1R(")386UO82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T
M<B`B4V%N($UA<FEN;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*
M(RP@9G5Z>GD*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")7
M;VIE=_-DO'1W;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")!
M<F%B:6$@4V%U9'EJ<VMA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(EIA<&ES>B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@
M(E-A=F4@)7,B"FUS9W-T<B`B6F%P:7-Z("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R("):87!I<WH@7"(E<UPB(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(EIA<&ES>B!O<&-J92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S`*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@
M<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N82!O
M='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"B,L(&9U>GIY"FUS
M9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B57=A9VDB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E-C:65N
M8V4B"FUS9W-T<B`B3F%D87=C82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B4WIU:V%J(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(W.`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($5N
M9VEN97,B"FUS9W-T<B`B3W!C:F4@=WES>G5K:7=A;FEA(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Y-S(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R
M(")7>6)I97)Z('!L:6MI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*
M;7-G<W1R(")7>6)I97)Z(&9O<FUA="!D871Y.B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3DX"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M82!N97<@;W=N97(B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A('-E<G9E<B(*;7-G<W1R(")3='?S<GH@;F]WL2(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,34V"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M82!U<V5R('1O(&%D9"(*;7-G<W1R(")3='?S<GH@;F]WL2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-C8R"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B5WEB:65R>B!F;W)M870@9&%T
M>3HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$Q
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E-T
M=_-R>B!N;W>Q(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U
M>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B
M"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB
M5WEB:65R>B!Z;F%K:2!Z('!O;FF_<WIY8V@@</-L(&9O<FUU;&%R>F$N($UO
MOV5S>B!J92!S:V]P:6]W8>8@:2!W:VQE:>8@>B`B"B)P;VQA('1E:W-T;W=E
M9V\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E=Y8FEE<GH@>FYA
M:R!P;V1Z:6&S=2!D871Y.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")7
M>6)I97)Z(&9O<FUA="!D871Y.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.#D*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")7>6)I97)Z('1OOW-A;6^V
MYB!D;R!Z;6EA;GDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*
M;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E=Y
M8FEE<GH@>FYA:R!P;V1Z:6&S=2!D871Y.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*
M;7-G<W1R(")7>6)I97)Z(&9O<FUA="!C>F%S=3HB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C8T"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RXB"FUS9W-T<B`B5WEB:65R>B!D=V$@<&%S=6JQ8V4@<&]L82XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E=Y8FEE<GH@<V-H96UA="!K
M;VQO<O-W+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#`*;7-G:60@
M(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B5WEB
M:65R>B!T=_-J('!R969E<F]W86YY(&KJ>GEK.B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(E=YMFQI:B!R87!O<G0@;R!P<F]B;&5M:64B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38Q"FUS9VED(")3
M96YD(%--4R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@
M(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@HC+"!F=7IZ
M>0IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@R(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(E=R>F5S:67Q(@H*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q
M"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(DYU;65R('-E<GEJ;GDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30X"B,L(&9U>GIY
M"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")";&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N>2XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@HC+"!F=7IZ
M>0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")7:6%D;VUO
MMN8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q,PIM<V=I9"`B4V5T(@IM
M<V=S='(@(E5S=&%W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS
M9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+B(*;7-G<W1R(")5<W1A=R!Z9&%L;F4@<V5R=V5R>2P@9&\@:W3S
M<GEC:"!C:&-E<WH@;6EEYB!D;W-TZG`@>B!S97)W:7-U+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R
M(")5<W1A=R!P<F5F97)O=V%N>2!JZGIY:RP@<W1R96;J(&-Z87-O=[$@:2!O
M<&-J92!D871Y+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I
M9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H
M96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P
M=&EO;G,N(@IM<V=S='(@(B(*(E5S=&%W('5SLW5GZB!P;V-ZL71K;W>Q+"!S
M8VAE;6%T(&MO;&]R\W<L(&]DMG=I9;]A;FEE('-T<F]N>2!I(&EN;F4@;W!C
M:F4@(@HB=WFV=VEE=&QA;FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-`IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B2V]N9FEG=7)A8VIA(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,SD*(RP@9G5Z>GD*
M;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T
M<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K
M("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-`IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R
M(")3>F5S>F5L92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3$*
M(RP@9G5Z>GD*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(DAI<WIP86YI82(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3
M:&]R="!3=6UM87)Y(@IM<V=S='(@(DMR\W1K:2!O<&ES(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0S.`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,CDR('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S
M='(@(E!O:V&_(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U.`IM<V=I
M9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@R"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(E!O:V%Z>7=AYB!C>F%S(&]S=&%T;FEE9V\@>F%L;V=O=V%N:6$@<&\@
M;&]G;W=A;FEU/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8V"FUS9VED
M(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#$R"B,L(&9U>GIY"FUS9VED(")3:&]W
M('!I8VME<B(*;7-G<W1R("));7!O<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$X"B,L(&9U>GIY"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_(@IM<V=S='(@(E=YMG=I971L8>8@:6MO;NH@9FEL=&5R
M\W<@;F$@<&%S:W4@>F%D8?$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/R(*;7-G<W1R(")0;VMAOR!M96YU("5S('!O(&QE=V5J/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0HC+"!F=7IZ>0IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(E1E;"X@:V]M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&5L+B!K;VTN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C0*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(E=G<GEW86YI92!P;&EK=2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U>GIY
M"FUS9VED(")3:&]W97)S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"B,L(&9U>GIY"FUS9VED
M(")3:&]W97)S($5A<FQY(@IM<V=S='(@(DMR\W1K:64@<W1R97-Z8WIE;FEE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*
M(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("));7!O<G0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM
M<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,SDY"B,L(&9U>GIY"FUS9VED
M(")3:')I;FLB"FUS9W-T<B`B0F%H<F%J;B(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C8Y,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW
M-30*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#$R(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C@W-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HY,#D@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.30V"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDW-"!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HQ,#`T"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,
M96]N92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8U"B,L(&9U
M>GIY"FUS9VED(")3:6=N('5P(@IM<V=S='(@(E)E:F5S=')A8VIA("5S(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,@IM<V=I9"`B4VEG;B!U
M<"!I9B!N;W0@<F5G:7-T97)E9"(*;7-G<W1R("):87)E:F5S=')U:B!S:>HL
M(&IEMFQI(&IE<WIC>F4@=&5G;R!N:64@>G)O8FFS9;8B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S
M='(@(E!O9'!I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$Q
M"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R>71M
M('!O9'!I<W4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P
M=7(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C0W(&QI8B](;W)D92]&;W)M+G!H<#HR.3(Y(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3(R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE
M(@IM<V=S='(@(E=I96QK;[;F(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V-O;F9I<FU?8F]T=&]M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(E!O;6GQ(&]P97)A8VIE(&-Y:VQI8WIN92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9A:VEA(@IM<V=S='(@(E.S;W=A8VIA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B4[-O=V5N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R(*;7-G
M<W1R(")0;VMAOR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R
M("));7!O<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4W"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B2W+S=&MI92!S=')E<WIC>F5N:64B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4VYO
M=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO
M;B!)<VQA;F1S(@IM<V=S='(@(E=Y<W!Y(%-A;&]M;VYA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V]M86QI82(*;7-G<W1R(")3;VUA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR.3(U"B,L(&9U>GIY"FUS9VED(")3;W)T
M(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@=WEB<F%NL2!T;[]S
M86UOMN8B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-#<*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A
M9&1R97-S(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H
M($%F<FEC82(*;7-G<W1R(")0;[-U9&YI;W=A($%F<GEK82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RDB"FUS9W-T<B`B4&^S=61N:6]W;V5U<F]P96IS:VD@*$E33RTX
M.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@
M4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")'96]R9VEA(%!OLW5D;FEO=V$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8R"B,L(&9U>GIY"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(E!O;6]C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(DAI
M<WIP86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,`HC+"!F=7IZ>0IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R
M(")(:7-Z<&%N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")(:7-Z<&%N:6$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB
M"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM
M<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B161Y8VIA
M('IN86OS=R!S<&5C:F%L;GEC:"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB
M"FUS9W-T<B`B4&]D>FEE;"!K;VWS<FOJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(E!O9'II96P@:V]L=6UNZB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R(")0;V1Z:65L('=I97)S>B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM
M<V=S='(@(DEM<&]R="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R
M:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-2!L
M:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R
M="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DU(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#`X"B,L(&9U>GIY"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@
M(E-T87)T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G
M:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E=O:F5W\V2\='=O(&QU
M8B!S=&%N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C@Q-`HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M
M870B"FUS9W-T<B`B1F]R;6%T(&-Z87-U(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@
M(D%D<F5S(&1O;6]W>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S,*(RP@9G5Z>GD*;7-G:60@
M(E-T<FEN9R!L:7-T(@IM<V=S='(@(E5S=&%W:65N:6$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3@W-`IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE
M(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS
M9W-T<B`B5&5M870B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3(*;7-G:60@(E-U8FUI="(*;7-G
M<W1R(")7>;9L:6HB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@HC+"!F=7IZ
M>0IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(E!ELVYY(&]P:7,Z(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$P-2!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T
M<B`B4&]W;V1Z96YI92(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ(&1O9&'F(%PB)7-<(B!D;R!S
M>7-T96UU+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E5D8;-O('-IZB!U<W5N
ML>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@Q
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")59&&S
M;R!S:>H@=7-U;K'F(%PB)7-<(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ('5S=6ZQ
MYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@
M(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C4U"B,L(&9U>GIY"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C
M:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@
M<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B561ALV\@
M<VGJ('5A:W1U86QN:>8@7"(E<UPB(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M(")59&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('-Y<W1E;74N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4W5D86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED
M(")3=6UM87)Y(@IM<V=S='(@(DMR\W1K:64@<W1R97-Z8WIE;FEE.B(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4W5N
M(%)I<V4B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E-U;B!3970B"FUS
M9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`HC+"!F=7IZ
M>0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B5W-C:/-D
M+WIA8VCS9"!SLV_Q8V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`S"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B3F%Z
M=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`W"B,L(&9U>GIY"FUS9VED(")3=6YS970B"FUS9W-T<B`B3F%Z=V$@
M=;]Y=&MO=VYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`V"B,L(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R(").87IW82!U
MOWET:V]W;FEK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S
M='(@(E!ELVYY(&]P:7,Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0T,PHC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("));7!O<G0B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U
M<FYA;64B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W
M87II;&%N9"(*;7-G<W1R(")3=6%Z:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G
M<W1R(")3>G=E8VIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-Z
M=V%J8V%R:6$B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PHC
M+"!F=7IZ>0IM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*
M;7-G<W1R(")/<'+SOVYI:B!F;VQD97(@:V]S>F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I
M86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3>7)I82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"B,L(&9U>GIY"FUS9VED
M(")4+5-T;W)M(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I
M;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R
M(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")+<O-T:VEE('-T<F5S>F-Z96YI92(*"B,Z(&QI8B](;W)D92]$871A+W1S
M=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")4
M>71ULR(*"B,Z(&QI8B](;W)D92]522]486)L92YP:'`Z,3,V"B,L(&9U>GIY
M"FUS9VED(")486)L92(*;7-G<W1R(")7L[%C>F]N92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*(RP@9G5Z
M>GD*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B5&5L+B!K;VTN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G
M<W1R(")496PN(&MO;2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM
M<V=S='(@(E1A:G=A;B(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T
M<B`B5&%J=V%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4862_
M>6MI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B5&%N>F%N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDU"B,L(&9U>GIY"FUS9VED(")487)G970Z
M(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-S,*;7-G:60@(E1A<VMS(@IM<V=S='(@(EIA9&%N:6$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE
M($YU;6)E<B(*;7-G<W1R(").=6UE<B!T96QE9F]N=2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`HC+"!F=7IZ
M>0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0HC+"!F=7IZ>0IM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R(")0;V1P:7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E1E
M;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HR,3<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B5S(&YI97IN86QE>FEO;GDN(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:F$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(Q,0HC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R(")4
M>6QK;R!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*;7-G
M:60@(E1E>'0@3VYL>2(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*(RP@
M9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B5'EL:V\@=&5K<W0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q
M"B,L(&9U>GIY"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1Y;&MO('1E:W-T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1H86EL86YD(@IM<V=S='(@(E1A:FQA;F1I82(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HY,C,*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B1'IIZFMU:F5M>2!Z82!K;W)Z>7-T86YI92!Z
M('-E<G=I<W4N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<S-PHC+"!F=7IZ>0IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+TE-4U`O0F]O
M:RYP:'`Z,3(Y-`HC+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B4&]D<&ES(&YI92!M;[]E
M(&)YYB!Z87-TL7!I;VYA+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C(Y"B,L(&9U>GIY"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B5'=O
M<GIO;F$@=VEA9&]M;[;F('IO<W1ALV$@>F%M:VYIZG1A+B!7>6-H;V1Z96YI
M92XB"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$U."!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C$V.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X,`HC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C$Y,B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,R!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S
M,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(W,@IM<V=I9"`B(@HB5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I
M;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y('IO<W1ALWD@<&]M>;9L;FEE(&1O
M9&%N92!D;R!4=V]J96H@:W-IL;]K:2!A9')E<V]W96HN(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3$T.0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB4&]T<GIE
M8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!S<')A=V1Z96YI82!P
M;V1P:7-A;F5J('=I861O;6^V8VDN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G
M<W1R(")482!O<&5R86-J82!N:64@:F5S="!O8G.S=6=I=V%N82XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"B,L(&9U>GIY"FUS
M9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M(@IM<V=S='(@(E1A(&]P97)A8VIA(&YI92!J97-T(&]B<[-U9VEW86YA+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")4
M:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C
M;VYN96-T:6]N+B(*;7-G<W1R(")/8G.S=6=A(&]S;V)I<W1E9V\@:VQU8WIA
M(%!'4"!W>6UA9V$@8F5Z<&EE8WIN96=O('!OL[%C>F5N:6$@=W=W+B(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3<U(&QI8B](;W)D92YP:'`Z-#@X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!A("5S('-E='1I;F<N(@IM<V=S='(@(EIM:67Q('5S=&%W:65N:6$@=')A
M:W1O=V%N:6$@<&QI:_-W(&D@:V%T86QO9_-W+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,38X(&QI8B](;W)D92YP:'`Z-#<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+B(*;7-G<W1R("):;6EE\2!U<W1A=VEE;FEA('1R86MT;W=A;FEA
M('!L:6OS=R!I(&MA=&%L;V?S=RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$U
M,@IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E
M;&8N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-C`*;7-G
M:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")4;[]S86UOMN8@7"(E<UPB('IO<W1ALV$@=7-U;FGJ=&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM
M<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,30V"FUS9VED("(B"B)4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB
M(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W.`IM<V=I
M9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M
M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C
M<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P
M;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=V5R(%PB)7-<(B!Z;W-T8;,@
M=7-U;FGJ='DN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@<V%V960N(@IM<V=S='(@(E-E<G=E<B!<(B5S7"(@>F]S=&&S('IA<&ES
M86YY+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E
M;B!R96UO=F5D+B(*;7-G<W1R(")+;VYT;R!<(B5S7"(@>F]S=&&S;R!Z87!I
M<V%N92XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR.3`*(RP@
M9G5Z>GD*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R(")/:W)EMFQO;GD@<&QI:R!N:64@:7-T;FEE:F4N(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C$P.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B3VMR9;9L;VYY('!L:6L@;FEE(&ES=&YI96IE+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*
M;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]$871A+G!H<#HS,#<*;7-G:60@(E1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(T,"!L:6(O2&]R
M9&4O1&%T82]T<W8N<&AP.C$W,@HC+"!F=7IZ>0IM<V=I9"`B5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")0;V1P:7,@
M;FEE(&UOOV4@8GGF('IA<W2Q<&EO;F$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,#D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")";&]K('=E871H97(N8V]M(&YI92!J97-T(&1O<W3J
M<&YY+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DYI92!M
M82"_861N>6-H(&1O<W3J<&YY8V@@;W!C:FDN(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C,T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S
M='(@(DYI92!M82"_861N>6-H(&%L=&5R;F%T>7=N>6-H(&-ZZK9C:2P@:W3S
M<F4@;6]GLWEB>2!Z;W-T8>8@<&]K87IA;F4N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO
M=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S
M='(@(E=Y<W2Q<&FS('!R;V)L96T@<')Z>2!D;V1A=V%N:74@7"(E<UPB(&1O
M('-Y<W1E;74Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B
M(@HB5WES=+%P:;,@<')O8FQE;2!P<GIY('5S=7=A;FEU(&1A;GEC:"!D;&$@
M=;]Y=&MO=VYI:V$@7"(E<UPB('<@<WES=&5M:64Z("(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(")7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@7"(E<UPB('H@
M<WES=&5M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(E=Y<W2Q<&FS('!R;V)L96T@<')Z>2!U86MT=6%L;FEA
M;FEU(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#@X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DU"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O9&-Z87,@=WFV=VEE
M=&QA;FEA('1E:B!C>NJV8VD@=VEA9&]M;[9C:2(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")7>7-T
ML7!ILR!BL[%D('!O8WIA<R!I;7!O<G1O=V%N:6$@9&%N>6-H(&E#86QE;F1A
M<BXB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB
M"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V-Z87,@:6UP;W)T;W=A;FEA(&1A
M;GEC:"!I0V%L96YD87(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M.0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]D
M8WIA<R!A:W1U86QI>F%C:FD@=&5G;R!W<&ES=3H@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"B,L(&9U>GIY"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&%K='5A;&EZ
M86-J:2!T96=O('=P:7-U.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O9&-Z
M87,@86MT=6%L:7IA8VII('1E9V\@=W!I<W4Z("5S(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@
M;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B5WES=+%P
M:;,@8K.Q9"!P;V1C>F%S(&%K='5A;&EZ86-J:2!T96=O('=P:7-U.B`E<R(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*(RP@9G5Z
M>GD*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(E1E;B!S97)W97(@;FEE(&]B<[-U
M9W5J92!U9&]S=.IP;FEA;FEA(&9O;&1E<O-W+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")0;&EK
M(&YI92!W>6=LL61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%)!4BXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T
M<B`B4&QI:R!N:64@=WEG;+%D82!N82!P;W!R87=N92!A<F-H:7=U;2!:25`N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q-#0*(RP@9G5Z>GD*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R
M+B(*;7-G<W1R(")F;VQD97(@)7,@;FEE(&IE<W0@<')A=VEDLV]W>2XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510
M('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@
M=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI
M="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.#8*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S,#4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#`@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$U-3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Y-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#8*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P-SD@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3`*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R,C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T-3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-38@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,S8*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,W,C,@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,W,S$*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@
M(E1O('!O;&4@:F5S="!W>6UA9V%N92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q
M-PIM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O
M8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(E1O('!O;&4@;75S:2!B
M>>8@<&]P<F%W;K$@;&EC>F*Q+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.#,U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G
M(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU
M-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HU.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN(@IM<V=S='(@(E=I861O;6^VYB!Z;W-T8;-A(&YA<&ES
M86YA('<@:6YN96H@;FF_('1W;VIA('-T<F]N:64@:V]D;W=E:B`H)7,I+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(V"B,L(&9U>GIY"FUS9VED
M(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B
M375S:7-Z('=P<F]W861Z:>8@<')Z>6YA:FUN:65J(&IE9&YE9V\@861R97-A
M=&$N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED
M(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RXB"FUS9W-T<B`B5&5N('-E<G=E<B!N:64@<&]T<F%F:2!R;WIP86MO
M=WEW8>8@87)C:&EW\W<@>FEP(&D@9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$T-PHC+"!F=7IZ>0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@
M8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")3:W)Y<'0@9&5A:W1Y
M=V]W86YY('!O<')A=VYI92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$R-`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+B(*;7-G<W1R(")-=7-I<WH@=W!R;W=A9'IIYB!L:6-Z8NHN(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=R(*;7-G<W1R(")4;R!O:VYO(&UU<VD@>F]S=&'F('=Y=V^S
M86YE('!R>F5Z(&]K;F\@:V]M<&]Z>71O<F$@=VEA9&]M;[9C:2XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(").861A=V-A(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(R,@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R-PIM<V=I9"`B5&EM92(*
M;7-G<W1R(")#>F%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P
M.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O
M<FUA="!C>F%S=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,X"B,L(&9U
M>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@=WEB
M<F%NL2!T;[]S86UOMN8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,"!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R.0IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
M5'ET=;,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4
M;R(*;7-G<W1R(")$;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HV,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(D%B>2!W>6)R
M8>8@=VEE;&]K<F]T;F4@<&]L82!P<GIY=')Z>6UA:B!P<GIY8VES:R!#=')L
M("A00RD@;'5B($-O;6UA;F0@*$UA8RD@(@HB<&]D8WIA<R!K;&EK86YI82XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDY"FUS9VED(")4
M;V1A>2(*;7-G<W1R(")$>FFV(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#$*;7-G:60@(E1O;6]R<F]W(@IM<V=S
M='(@(DIU=')O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S<*(RP@9G5Z>GD*;7-G:60@(E1O<"(*;7-G<W1R(")$;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T
M<B`B4')E>F5N=&%C:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O
M(@IM<V=S='(@(E1R>6YI9&%D(&D@5&]B86=O(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W.3$*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B4')A
M=V1A(&QU8B!F8;-S>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U;FES:6$B"FUS9W-T<B`B5'5N97IJ82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*
M;7-G<W1R(")4=7)C:F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM
M<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R96-K:2`H
M25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B
M5'5R:VUE;FES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A
M;'4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U
M<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4W"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR-#D*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")5
M4DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B
M56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS
M9W-T<B`B56MR86EN82(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,U"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!3
M44PN(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D*SL60@
M<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HS,#@@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")"L[%D('!O9&-Z
M87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HV-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!T;R`E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S('IM:6%N>2!D;R`E
M<RXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C,W,0IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B0K.Q9"!P
M;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-S4V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$U
M."!L:6(O5D93+V9I;&4N<&AP.C$V,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ
M.#@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3DS(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C(P,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93
M(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W
M-R!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C0X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V(&QI8B](;W)D92]#;VUP<F5S<R]G
M>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB
M"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(')O>G!A:V]W>7=A;FEA(&1A;GEC:"XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI
M82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S
M='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-30@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,S$Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,R-@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z,S$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,"!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C(V,"!L:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T,R!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HS,S8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE
M;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,S,Y(&QI8B]61E,O<W%L+G!H<#HS-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!3
M44PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$W,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E
M;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,38W(&QI8B]61E,O;75S<6PN<&AP.C$X,`HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<P(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,W.`HC.B!L:6(O5D93+W-Q;"YP:'`Z,C$P"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*
M"B,Z(&QI8B]61E,O<W%L+G!H<#HS,C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB
M"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S(P"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G
M<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`S"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS
M(@IM<V=S='(@(E-Z8WIE9_.S>2!C97)T>69I:V%T=2(*"B,Z(&QI8B].970O
M24U34"YP:'`Z-#4Q(&QI8B].970O24U34"]!=71H+G!H<#HQ,3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@
M<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Y
M(&QI8B]61E,O9FEL92YP:'`Z,3,T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U
M.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C,*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")"L[%D('!O9&-Z
M87,@>FUI86YY('5S=&%W:67Q+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@
M<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`U
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$R,B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ,C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@
M<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C<@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C
M>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(D*SL60@<&]D8WIA
M<R!Z;6EA;GD@=7-T87=I9?$N(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z
M('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4Y,@HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@4U%,+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`V-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D*SL60@
M<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C(U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z,C@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4S,R!L:6(O5D93+VUU<W%L+G!H<#HR
M,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z
M96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HR-S<*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O
M<W%L+G!H<#HR-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@4U%,+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N="(*;7-G<W1R(").:64@;6^_;F$@<')Z972S=6UA8WIYYB!T96=O
M(&1O:W5M96YT=2!7;W)D+6$B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3(R(&QI
M8B]61E,O9G1P+G!H<#HQ,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,P
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(D*SL60@<&]D
M8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`HC+"!F=7IZ>0IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(D]D='?S<GHB"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T
M<B`B0V]F;FEJ('IM:6%N>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(E5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(E=Z;O-W('-W;VJQ('-E<VKJ(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,R!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C0*(RP@9G5Z>GD*;7-G:60@(E5N9FEL960B
M"FUS9W-T<B`B<&QI:R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E
M9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(EIJ961N;V-Z;VYE($5M:7)A='D@
M07)A8G-K:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E=I
M96QK82!"<GET86YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T
M<B`B55-!(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV,2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HU."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3@*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$Y"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DYI
M97IN86YE(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V
M:61E9"XB"FUS9W-T<B`B3FEE>FYA;GD@861R97-A="(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")0<F]S>NH@
M<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PHC+"!F
M=7IZ>0IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B57-U\2(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,CDV"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(D)E>B!N87IW>2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@HC+"!F=7IZ
M>0IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B1&]M>;9L;GD@:V]L;W(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@
M(DYI96]B<[-U9VEW86YE(')O>G-Z97)Z96YI92(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$X,PHC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(E5A:W1U86QN:6HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&4@)7,B"FUS9W-T<B`B1&]D86H@=;]Y=&MO=VYI:V$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,L(&9U>GIY"FUS9VED
M(")5<&1A=&4@=7-E<B(*;7-G<W1R(")$;V1A:B!UOWET:V]W;FEK82(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(Q
M-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B1&]D86H@
M=;]Y=&MO=VYI:V$B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,0HC
M+"!F=7IZ>0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B3FEE('=Y9V5N97)O=V%N;R"_861N96=O('-K<GEP='4N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3@R"FUS9VED(")5<&QO860B"FUS9W-T<B`B6F&S861U
M:B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#D*;7-G:60@(E5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G:60@(E5P<&5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B1W)U9'II9?$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(E5R=6=W86HB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(E5S=?$@;V)E8VYE(&ML
M=6-Z92(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*
M;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U)E9VES=')Y+G!H<#HV,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(P,PHC+"!F=7IZ>0IM<V=I9"`B57-E<B!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VIA('6_>71K;W=N:6OS
M=R!(;W)D92(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED
M(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B3W!C:F4@=;]Y=&MO=VYI:V$B"@HC
M.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G
M<W1R(")296IE<W1R86-J82!UOWET:V]W;FEK82(*"B,Z('-I9VYU<"YP:'`Z
M,C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(D]B<[-U9V$@9FEL
M='+S=R!J97-T('=YL[%C>F]N82!N82!T>6T@<WES=&5M:64N(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3<R(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C0V"B,L(&9U>GIY"FUS9VED(")5<V5R('!E<FUI<W-I;VYS(@IM<V=S='(@
M(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.3@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.3@@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHV."!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B3F%Z=V$@
M=;]Y=&MO=VYI:V$B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(E6_>71K;W=N:6L@;R!N87IW:64@7"(E<UPB
M(&IUOR!I<W1N:65J92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").87IW82!UOWET:V]W
M;FEK83HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED
M(")5<V5R;F%M93H@(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA.B`B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B
M57-E<G,B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@
M<WES=&5M.B(*;7-G<W1R(")5OWET:V]W;FEC>2!W('-Y<W1E;6EE.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI<W1A;B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,3`Q(&QI8B]61E,O9FEL92YP:'`Z,3@X"B,L(&9U
M>GIY"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R(")/:W)EMFQO;GD@<&QI:R!N:64@:7-T;FEE:F4N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T
M<B`B5V%K86-J92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C8*;7-G:60@
M(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED
M:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-38@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@
M;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C0U(&QI8B](;W)D92]&;W)M+G!H<#HR,C8W(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S$U"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3(W
M"B,L(&9U>GIY"FUS9VED(")686QU97,B"FUS9W-T<B`B57=A9VDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X
M-PIM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(E9A<FEA
M8FQE(@IM<V=S='(@(E=YL[%C>F]N92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R(")796YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S
M:6]N(@IM<V=S='(@(E=E<G-J82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,#4*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G
M<W1R(")?57!R87=N:65N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T
M:6-A;"!A;&EG;B(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G
M:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5'EL:V\@=&5K<W0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"B,L
M(&9U>GIY"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5'EL:V\@=&5K<W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`HC
M+"!F=7IZ>0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(E=Y<V]K:2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*
M;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E=I971N86TB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.34Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5VED;VL@
M)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E!O:V&_('-T<F]NZB!75U<B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B4&]K8;\@:F%K;R`E
M<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@
M(D)R>71Y:G-K:64@5WES<'D@1'II97=I8WIE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B5WES<'D@1'II97=I8WIE(%-T86[S
M=R!::F5D;F]C>F]N>6-H(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*
M;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(U,0IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES(&D@
M1G5T=6YA(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(Y"FUS9VED(")787)N:6YG(@IM<V=S='(@(D]S=')Z9;]E
M;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU.`HC+"!F=7IZ>0IM<V=I9"`B5V4B"FUS9W-T<B`B5U=7(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O
M<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,34*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")796%T
M:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=75R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-S8*(RP@9G5Z>GD*;7-G:60@(E=E8B!3:71E(@IM<V=S
M='(@(E523"!S=')O;GDB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B0V\@='ED>FEE\2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM
M<V=S='(@(E=I=&%M>2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E=I=&%M>2!W("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L
M("5S(@IM<V=S='(@(E=I=&%M>2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B
M6F%C:&]D;FD@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("):
M86-H;V1N:2`H25-/+3@X-3DM,34I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(E-A:&%R82!:86-H;V1N:6$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(DIA:[$@87!L:6MA8VKJ(&UA("5S('=YMG=I971L8>8@<&\@>F%L;V=O=V%N
M:74@<VGJ/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS
M9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-`IM<V=I9"`B
M5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7
M:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET
M;W(N(@IM<V=S='(@(DIA:VEE('=T>6-Z:VD@86MT>7=O=V'F('<@4F]Z8G5D
M;W=A;GEM(&5D>71O<GIE('1E:W-T=2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"B,L(&9U>GIY"FUS9VED
M(")7:61T:"(*;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3(T"B,L(&9U>GIY"FUS9VED(")7:61T:"!I;B!#4U,@=6YI
M=',B"FUS9W-T<B`B3&ET=V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU
M(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*
M;7-G<W1R("(B"B)3>F5R;VMOMN8@;&5W96=O(&UE;G4@)7,@*'IM:6%N82!Z
M86-Z;FEE(&]B;W=IL7IY=V'F('!R>GD@;F%S=.IP;GEM("(*(FQO9V]W86YI
M=2DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`HC
M+"!F=7IZ>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("),:71W82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"B,L
M(&9U>GIY"FUS9VED(")7:61T:#HB"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8X"FUS9VED(")7:6MI(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#@@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*(RP@9G5Z
M>GD*;7-G:60@(E=I;F0B"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM
M<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO
M=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*(RP@
M9G5Z>GD*;7-G:60@(E=I;F0Z(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,`HC+"!F=7IZ>0IM<V=I
M9"`B5VEN9#H@(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X,@HC+"!F=7IZ>0IM<V=I9"`B
M5VES:&QI<W1S(@IM<V=S='(@(D)I8;-A(&QI<W1A(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7;W)K(@IM<V=S='(@
M(FQU8B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7
M;W)K($%D9')E<W,B"FUS9W-T<B`B061R97,@9&\@<')A8WDB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0
M:&]N92(*;7-G<W1R(")496PN(&1O('!R86-Y(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(S,0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U
M,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")24B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#8@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R(")24E)2
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#$*
M;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA
M:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(D-O(')O
M:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X-0IM<V=I9"`B665S(@IM
M<V=S='(@(E1A:R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE
M;G1?8F]T=&]M+FEN8SHV"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B
M5&%K+"!Z9V%D>F%M('-IZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%
M+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)
M5UE'+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$R.3<*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H
M879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-38@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-S8*(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B5'?S:B!A9')E
M<R!E+6UA:6PZ(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3(S"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S
M='(@(E=Y;&]G;W=ALV6V('-IZBXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@X"B,L(&9U>GIY
M"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G
M<W1R(")4=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M(")"<F%K(&MO;F9I9W5R86-J:2!W97=NZG1R>FYE:B!D;&$@=&5G;R!H;W-T
M82(*"B,Z(&QI8B](;W)D92YP:'`Z-#,Q"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B0G)A:R!K
M;VYF:6=U<F%C:FD@=V5W;NIT<GIN96H@9&QA('1E9V\@:&]S=&$B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(DUU<VES>B!O<&ES8>8@<')O
M8FQE;2!Z86YI;2!G;R!W>;9L97-Z+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*
M;7-G<W1R(")-=7-I<WH@=W!R;W=A9'IIYB!P<GIY;F%J;6YI96H@:F5D;F5G
M;R!A9')E<V%T82XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX
M,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+B(*;7-G<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO
M=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S=6ZQYBXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(DUU<VES>B!O:W)EMFQI
MYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF('6_
M>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G
M;R!C:&-E<WH@9&]D8>8N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@
M:W3S<F5G;R!C:&-E<WH@9&]D8>8N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S
M+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DUU<VES>B!O:W)E
MMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<R"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G
M;R!C:&-E<WH@=7-U;K'F+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.CDQ,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G
M:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")4=_-J(&%D<F5S(&4M
M;6%I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO
M=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B5'?S:B!A9')E<R!/9#HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T
M<B`B5'=O:F4@:6YF;W)M86-J92(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)4=_-J(&%D<F5S(&EN=&5R
M;F5T;W=Y('-IZB!Z;6EE;FFS(&]D('!O8WJQ=&MU('-E<VII("5S+B!7('IW
M:;%Z:W4@>B`B"B)B97IP:65C>F7Q<W1W96T@5'=O:F5G;R!K;VYT82!M=7-I
M<WH@>F%L;V=O=V'F('-IZB!P;VYO=VYI92XB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@
M(E1W;VIE(&EM:>HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI
M;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B
M"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM
M<V=S='(@(B(*(E1E;B!S>7-T96T@875T96YT>6MA8VII(&YI92!O8G.S=6=U
M:F4@9&]D87=A;FEA('6_>71K;W=N:6OS=RP@;'5B('1A(&]P8VIA("(*(GIO
M<W1ALV$@=WFSL6-Z;VYA+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"B)496X@<WES=&5M(&%U=&5N='EK86-J:2!N:64@
M;V)SLW5G=6IE(&QI<W1O=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@=&$@;W!C
M:F$@(@HB>F]S=&&S82!W>;.Q8WIO;F$N(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDQ.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)4
M=_-J(&%D<F5S(&EN=&5R;F5T;W=Y('-IZB!Z;6EE;FFS(&]D('!O8WJQ=&MU
M('-E<VII("5S+B!7('IW:;%Z:W4@>B`B"B)B97IP:65C>F7Q<W1W96T@5'=O
M:F5G;R!K;VYT82!M=7-I<WH@>F%L;V=O=V'F('-IZB!P;VYO=VYI92XB"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G
M<W1R("(B"B)4=V]J82!P<GIE9VRQ9&%R:V$@;FEE(&]B<[-U9W5J92!W>;9W
M:65T;&%N:6$@<&QI:_-W(&=R869I8WIN>6-H('1E9V\@='EP=2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I
M;G0N(@IM<V=S='(@(B(*(E1W;VIA('!R>F5G;+%D87)K82!N:64@;V)SLW5G
M=6IE('1E:B!O<&-J:2!D<G5K;W=A;FEA+B!.86IC:;9N:6H@0W1R;"]/<&-J
M82`B"B(K(%`@86)Y('=Y9')U:V]W8>8N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(T.0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS
M9W-T<B`B5'=O:F$@;V)E8VYA('-T<F5F82!C>F%S;W=A.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>3HB"FUS9W-T<B`B1&]M>;9L;F$@=&^_<V%M;[;F.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*
M;7-G<W1R(")4=V]J92!P9;-N92!I;6GJ(&D@;F%Z=VES:V\Z(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")4
M=V]I;2!N;W=Y;2!H87.S96T@=R`E<R!J97-T.B`E<R(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(E1W;VIE('5S=&%W:65N:6$@>F]S=&&S>2!U86MT=6%L;FEO
M;F4@;F$@8WIA<R!T<G=A;FEA('1E:B!S97-J:2XB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+B(*;7-G<W1R(")4=V]J92!U<W1A=VEE;FEA('IO<W1ALWD@
M=6%K='5A;&YI;VYE+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<U"B,L(&9U>GIY"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T(@IM<V=S='(@(E1W;VEM(&YO=WEM(&AA<[-E;2!W("5S(&IE<W0Z("5S
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E1W;VIE('ID86QN
M92!S97)W97)Y.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM
M<V=S='(@(DIU9V]SLV%W:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):
M86UB:6$B"FUS9W-T<B`B6F%M8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS
M9W-T<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D
M(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C4V
M"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM287!O<G0@;R!P
M<F]B;&5M:65=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z,3DS
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB
M"FUS9W-T<B`B)7,@9&\@)7,@>B`E<R(*"B,Z(&QI8B](;W)D92YP:'`Z,30T
M,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-T<F%C:F$B"@HC.B!L:6(O87!I
M+G!H<#HQ,S8*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*"B,Z(&QI8B]A
M<&DN<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@
M(D1A=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]5
M<W7Q('=I97)S>B(*"B,Z(&QI8B]A<&DN<&AP.C$Q-@IM<V=I9"`B7T=R;W5P
M<R(*;7-G<W1R(")?1W)U<'DB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U
M"FUS9VED(")?2&5L<"(*;7-G<W1R(")?4&]M;V,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*(RP@9G5Z
M>GD*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E1E;"X@
M:V]M+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@
M:6XB"FUS9W-T<B`B7UIA;&]G=6HB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z
M,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?5WEL;V=U:B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(EIM:67Q(&QI;FLN
M+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N
M<R(*;7-G<W1R(")?3W!C:F4B"@HC.B!L:6(O87!I+G!H<#HQ,C`*;7-G:60@
M(E]097)M:7-S:6]N<R(*;7-G<W1R(")?57!R87=N:65N:6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*
M;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")5<W7Q(&QI;FLN+BXB
M"@HC.B!L:6(O87!I+G!H<#HQ,#@*;7-G:60@(E]3971U<"(*;7-G<W1R(")?
M2V]N9FEG=7)A8VIA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")?5&%B;&4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!L:6(O87!I
M+G!H<#HQ,3(*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?5;]Y=&MO=VYI8WDB
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y,`IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(FMS:;&_:V$@861R97-O=V$B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C@X,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L96YD
M87)Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3@Y"FUS9VED
M(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(F9I;&4B
M"FUS9W-T<B`B<&QI:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I
M(&%T("5S("5S(@IM<V=S='(@(B5S(&1O("5S('H@)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(E-I97)P:67Q(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,S,0IM<V=I9"`B
M:&@B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS
M9VED(")I;FQI;F4B"FUS9W-T<B`B3F%GL_-W:VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B
M;&EN97-=(@IM<V=S='(@(DYA9[/S=VMI(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F
M<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-#(*;7-G
M:60@(FUM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,C@X('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#4*;7-G:60@(FYA
M;64B"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L:6(O2&]R9&4O4E!#+G!H<#HQ
M,C$*(RP@9G5Z>GD*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")5
M:V_Q8WIO;F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,3D*
M(RP@9G5Z>GD*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B
M5&$@;W!C:F$@;FEE(&IE<W0@:F5S>F-Z92!Z8;.Q8WIO;F$N(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HX-S0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B
M;F]T871N:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@X"B,L(&9U>GIY"FUS9VED(")P97)C96YT(@IM<V=S
M='(@(D1R=6MU:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F
M=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D]R9V%N:7IA=&]R(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.`IM<V=I9"`B<VAO=R!D:69F97)E
M;F-E<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM
M<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D>2(*;7-G
M<W1R(").;W1A=&YI:R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DX
M"B,L(&9U>GIY"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B0WIA<FYA(&QI
M<W1A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D
M('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B2&%SLV\B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F
M=7IZ>0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")P;&EK(@H*(SH@;&EB+TAO
M<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B
M8F5Z(&YA>G=Y(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC+"!F
M=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B5WEB\W(@:V]L;W)U
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,L(&9U>GIY"FUS9VED(")W.B(*;7-G
M<W1R(")&=V0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&\O:VU?2T@N<&\`````````````````````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8T,#<R-``Q,#4Q-30S,3`V
M,P`P,38S-S,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R!33TU%($1%4T-225!4259%(%1)5$Q%+@HC($-O<'ER:6=H="`H
M0RD@645!4B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U
M=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C
M:V%G92X*(R!,96%N9R!#:'5M<V]B96X@/'-O8F5N0&MH;65R;W,N:6YF;SXL
M(#(P,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($E-4%QN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#0M,3(M,#@@,3`Z
M,C@K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-BTQ-2`Q,3HU
M,RLP-S`P7&XB"B),87-T+51R86YS;&%T;W(Z($QE86YG($-H=6US;V)E;B`\
M<V]B96Y`:VAM97)O<RYI;F9O/EQN(@HB3&%N9W5A9V4M5&5A;3H@2VAM97(@
M/'-U<'!O<G1`:VAM97)O<RYI;F9O/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UU=&8M.%QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(.&>D.&?DN&>A.&?@^*`
MB^&>@.&>D^&?DN&>F^&>A.*`B^&>D>&?A2DB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$S.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B`HX9Z"X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%
MX9Z[X9Z%XH"+X9Z5X9^2X9Z;X9Z\X9Z<XH"+X9Z`X9ZVX9Z/X9^+("5S*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S@Q"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R
M("(@*.&>D.&?DN&>A.&?@^*`B^&>D^&?@>&?ARDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S@S"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R
M("(@*.&>D.&?DN&>A.&?@^*`B^&>G^&?DN&>HN&?@N&>@"DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'EE<W1E<F1A>2DB
M"FUS9W-T<B`B("CAGICAGY+AGI_AGK?AGIOAGICAGXGAGK?AGHDI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4S"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.3D*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(.&>F.&>
MM^&>D^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>D.&>C^*`B^&>H>&>ON&>
MF<*@X9^4(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*
M;7-G<W1R(")<(B5S7"(@X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3XH"+X9Z'X9ZV
MXH"+X9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+X9Z/X9^2X9Z:X9ZYX9Z8X9Z/X9^2
MX9Z:X9Z\X9Z<XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<P,PHC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$P-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A
M=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M)7,@86YD("5S(@IM<V=S='(@(B5D("5S(.&>D^&>M^&>A"`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8W(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I
M;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO
M=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-#(@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!-0B(*;7-G<W1R("(E<R#AGICAGX'AGH#AGK;AGI3AGX,B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N
M(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Q(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<W(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4W(&QI8B]";&]C:R]M971A<BYP:'`Z,S8S
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A
M;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM
M<V=S='(@(B5S(.&?EB`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@
M5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T
M;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@
M;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-3<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P
M,@IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(P-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$S-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0V"FUS9VED("(M+2!S96QE
M8W0@+2TB"FUS9W-T<B`B+2T@X9Z'X9^2X9Z:X9Z^X9Z?("TM(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C(U"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G
M<W1R("+AGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGID@X9^AX9^B(.&>
MF.&?B>&?A.&>A"(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR-`IM<V=I9"`B
M,C0@2&]U<B!&;W)M870B"FUS9W-T<B`BX9Z1X9^2X9Z:X9Z$X9^+X9Z1X9^2
MX9Z:X9ZVX9Z9(.&?HN&?I"#AGICAGXGAGX3AGH0B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`BX9^B
MX9^D(.&>F.&?B>&?A.&>A"(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\X9Z8X9Z[X9Z3(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S$*;7-G:60@(D$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C(*;7-G:60@(D$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#`W"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D$@;65S<V%G92!H87,@8F5E;B!S96YT('1O(%PB)7-<(B!T
M;R!V97)I9GD@=&AA="!T:&ES(&ES(')E86QL>2!Y;W5R("(*(F%D9')E<W,N
M(%1H92!N97<@96UA:6P@861D<F5S<R!I<R!A8W1I=F%T960@87,@<V]O;B!A
M<R!Y;W4@8V]N9FER;2!T:&ES("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,38*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!
M32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS
M9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P
M,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@
M961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("+AGJ+AGX;AGI;AGKCB@(LN
M+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED
M9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G
M:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BX9Z6X9^0X9Z/X9^,
MX9Z8X9ZVX9Z3XH"+X9ZBX9^&X9Z6X9ZXX9Z"X9Z.X9Z3X9ZX(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@
M(D%C8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED
M(")!9&0B"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z0X9^"X9Z8(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D
M9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O
M=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M
M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@
M)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O
M(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z0X9^"
MX9Z8XH"+XH"+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D
M960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T.0IM<V=I9"`B061D<F5S<R(*
M;7-G<W1R("+AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30X"FUS9VED(")!9&1R97-S($)O;VLB
M"FUS9W-T<B`BX9Z?X9^`X9Z<X9Z7X9^%XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H
M<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGH+AGY+AGIKA
MGI3AGXOB@(OAGH+AGY+AGIKAGH0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4W"FUS9VED(")!9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`BX9ZBX9ZVX9Z@X9^2X9Z"X9ZV
MX9Z3X9ZXX9Z?X9^2X9Z0X9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB
M86YI82(*;7-G<W1R("+AGJ+AGK;AGIOAGXOAGI3AGK;AGI/AGK@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(N&>HN&>MN&>F^&?B^&>
MH.&?DN&>G^&?@>&>FN&>N"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(N&>B.&?
MDN&>F.&?A.&?A^*`B^&>@.&?DN&>F^&?@N&>A.&>@.&?DN&>F^&>MN&>F2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(N&>C^&>F.&?DN&>FN&>N>&>
MF"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDR"FUS9VED(")!;&PB"FUS9W-T<B`BX9Z1X9ZVX9^&
MX9Z$XH"+X9ZBX9Z?X9^+(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B
M06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL
M($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z
M-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS
M9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<Y"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S
M.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-3$X"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@
M24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E
M<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`BX9Z4X9^2X9Z*X9Z\X9Z:XH"+X9ZBX9ZVX9Z?X9Z9
MX9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M
M;V$B"FUS9W-T<B`BX9Z?X9ZVX9Z8X9Z\X9ZBX9ZV(.&>HN&>MN&>F.&?@>&>
MFN&>M^&>@"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,`IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B06YD;W)R82(*;7-G<W1R("+AGJ+AGH3AGXOAGHKAGKSAGIKAGXGA
MGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`BX9ZBX9Z$
MX9^+X9Z@X9^2X9Z"X9^$X9ZAX9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`BX9ZBX9Z$X9^+X9Z@X9^2X9Z?X9^*X9ZXX9ZAX9ZV
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B
M06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("+AGI?AGK;AGH+B
M@(OAGH'AGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(N&>HN&>A.&?B^&>
MD>&>N.&>H.&?DN&>@N&>MB#AGI/AGK?AGH0@X9Z4X9ZVX9Z4X9^*X9Z[X9Z9
MX9Z*X9ZV(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU
M."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!
M<'!L:6-A=&EO;B(*;7-G<W1R("+AGH#AGICAGY+AGICAGISAGK?AGI+AGK@B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T
M:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L
M>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,@IM<V=I9"`B
M07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T
M<B`BX9Z8X9^!X9Z?X9ZV(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S$*
M;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("+AGJ+AGK;A
MGIKAGXGAGK;AGI3AGXL@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@
M<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(N&>HN&>MN&>H.&?DN&>G^&>A.&?B^&>D>&>N.&>
MDR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`BX9ZBX9ZV
MX9Z8X9^!X9Z3X9ZX(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S(*;7-G
M:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(N&>HN&>MN&>FN&>O.&>
ME.&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,T"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A
M8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`V"FUS9VED(")!<W-I9VYM96YT
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM
M<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS
M9VED(")!='1R:6)U=&5S(@IM<V=S='(@(N&>@N&>N^&>CN&>F^&>@.&?DN&>
M@>&>CN&?B"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BX9Z?X9ZXX9Z@X9ZV(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(N&>HN&>O.&>
MG^&?DN&>C^&?DN&>FN&>MN&>F^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R:6$B"FUS9W-T<B`BX9ZBX9Z\X9Z1X9^2X9Z:X9ZXX9Z?(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q-@IM<V=I9"`B075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,Q
M"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(S-`IM<V=I9"`B075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z-38*;7-G:60@(B(*(D%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#0*
M;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C<S"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS,#$*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M-38*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDR"FUS9VED(")!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0P-`IM<V=I9"`B075T:%]L9&%P.B!5
M<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC
M86PN<&AP.C8R"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C@V"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!
M=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@
M(N&>@.&>MN&>FN*`B^&>E>&?DN&>D>&?@.&>A.*`B^&>E>&?DN&>D>&>MN&>
MC^&?B^*`B^&>E^&>MN&>EN*`B^&>C^&?DN&>FN&>N>&>F.*`B^&>C^&?DN&>
MFN&>O.&>G.*`B^&>E.&>MN&>D^*`B^&>E.&>FN&>MN&>A^&?D.&>F2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I
M=7,N<&AP.C$X,@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B
MX9ZBX9ZVX9Z@X9^2X9Z?X9^*X9^"X9Z:X9Z4X9^"X9Z@X9^2X9Z?X9Z$X9^+
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G
M<W1R("+AGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3A
MGIDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(N&>EN&>CN&?
MC.*`B^&>E>&?DN&>D>&?@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>
MF2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#(*;7-G:60@
M(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-`IM<V=I9"`B0F%D(&ME<F)E<F]S
M('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA
M;6%S(@IM<V=S='(@(N&>E.&>MN&>H.&>MN&>F.&?B>&>MN&>GR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`BX9Z4X9ZVX9Z:X9^)X9^"
MX9Z3(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)A;'1I
M8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)A;F=L861E<V@B"FUS9W-T<B`BX9Z4X9Z$X9^+X9Z`X9^2X9Z;X9ZVX9Z*
MX9^!X9Z?X9^2X9Z@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS
M9W-T<B`BX9Z4X9ZVX9Z:X9Z4X9ZVX9Z*X9Z\X9Z?(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F5L87)U<R(*;7-G<W1R("+AGI3AGX'AGJ'AGK;AGIKAGKOAGI_A
MGY+AGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(N&>
ME.&?@N&>F^*`B^&>H.&?DN&>G^&?BN&>M^&>@"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R("+AGI3AGX'AGIOAGKCAGJ#AGY+AGI\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("+AGI3AGX'AGH[AGK;A
MGX;AGH0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(N&>
ME.&?BN&?@>&>FN&>F.&>O.&>BN&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H
M=71A;B(*;7-G<W1R("+AGI3AGXKAGKSAGH_AGK;AGI,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T
M:&1A>2(*;7-G<W1R("+AGI#AGY+AGH3AGX/AGH#AGX;AGH[AGK[AGH\B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO
M;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW,@IM
M<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T
M<B`BX9Z*X9ZWX9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G
M<W1R("+AGI3AGKSAGIOAGKCAGISAGK@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(Q"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`BX9Z`X9Z3
MX9^2X9Z;X9^"X9Z$XH"+X9Z%X9^&X9Z.X9ZVX9^&(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M0F]R9&5R(@IM<V=S='(@(N&>G^&?BN&>N^&>F"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T
M:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS
M9W-T<B`BX9Z?X9^*X9Z[X9Z8XH"+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S
M;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("+AGI3AGKSAGI_AGY+AGI/A
MGXKAGK@@X9Z3X9ZWX9Z$(.&>H.&>NN&>H.&?DN&>G^&?BN&?@>&>H.&?DN&>
M@N&?A.&>G.&>N.&>CN&>MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HQ
M,#$*;7-G:60@(D)O=&@B"FUS9W-T<B`BX9Z1X9ZVX9^&X9Z$XH"+X9Z6X9ZX
MX9Z:XH"+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B
MX9Z4X9Z[X9Z/X9Z?X9^2X9Z<X9ZVX9Z.X9ZV(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`BX9Z4X9ZVX9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGI3AGXKAGKSAGISA
MGXGAGX(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`BX9Z4
MX9^2X9Z:X9^!X9Z?X9^*X9ZXX9Z;(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("+AGJ+AGK;A
MGH[AGK;AGH7AGH#AGY+AGIKB@(OAGI_AGICAGKOAGI'AGY+AGIKB@(OAGJ7A
MGH[AGY+AGHSAGK8@X9ZBX9Z$X9^+X9Z"X9^2X9Z;X9^!X9Z?(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`BX9Z4X9^2
MX9Z:X9^*X9Z[X9Z9X9Z.X9^!XH"+X9Z*X9ZVX9Z:X9^*X9Z[X9Z9X9Z?X9ZV
MX9ZAX9ZVX9Z8(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T
M<B`BX9Z4X9^*X9Z[X9Z;X9Z@X9^2X9Z"X9ZVX9Z:X9ZX(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K
M:6YA($9A<V\B"FUS9W-T<B`BX9Z4X9^*X9Z\X9Z:X9Z"X9ZXX9Z.X9ZVX9Z@
MX9^2X9Z<X9ZVX9Z?X9Z\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*
M;7-G<W1R("+AGI3AGXKAGKSAGIKAGKOAGI/AGHSAGK@B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8P"FUS9VED(")#35,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I
M9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-@IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X,R!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U-0HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,38T"FUS9VED(")#86QE;F1A<B(*;7-G<W1R
M("+AGI3AGY+AGIKAGH_AGK?AGI'AGK?AGI,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0P"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("+AGH#AGICAGY+A
MGI;AGKOAGH?AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G
M<W1R("+AGH#AGK;AGICAGXGAGK;AGIKAGKSAGI,B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL
M92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R
M"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N
M9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(T,2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S,P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA
M9&$B"FUS9W-T<B`BX9Z`X9ZVX9Z.X9ZVX9Z*X9ZV(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BX9Z4X9^$X9^'X9Z4X9Z$X9^+
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ
M"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,C(*;7-G:60@
M(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`BX9Z`X9ZVX9Z4X9Z<X9^"X9Z:
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+AGH7AGX;AGH[AGH3A
MGH?AGK[AGH0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`BX9Z<X9Z/X9^2
MX9Z0X9Z[XH"+X9Z*X9ZYX9Z`XH"+X9Z'X9Z)X9^2X9Z'X9Z\X9Z3(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N
M9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA
M;B!)<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>@.&?@^&>F.&?B>&>
MMN&>DR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I
M9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A
M9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL
M<&AO;F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*
M;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*
M;7-G:60@(D-E;G1E<B(*;7-G<W1R("+AGH#AGH[AGY+AGH_AGK;AGILB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZV
MX9Z@X9^2X9Z<X9^2X9Z:X9ZWX9Z`XH"+X9Z`X9Z.X9^2X9Z*X9ZVX9Z;(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM
M<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(N&>AN&>MN&>BB(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("+AGI7AGY+A
MGIOAGK;AGI_AGXOB@(OAGI3AGY+AGH_AGKSAGIHB"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N
M;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@
M("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE
M8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;&4B"FUS9W-T<B`BX9Z(X9ZXX9Z;X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0VAI;F$B"FUS9W-T<B`BX9Z%X9ZWX9Z3(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S8*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B
M0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T
M:6]N.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C<Q"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED
M(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T
M('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(N&>
M@.&?A.&?A^*`B^&>@N&?DN&>FN&>N.&>G^&?DN&>C^&>F.&?B>&>MN&>GR(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F
M:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A
M<B(*;7-G<W1R("+AGH?AGICAGY+AGIKAGX<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F
M9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(N&>A^&>F.&?DN&>FN&?
MA^*`B^&>G^&?AN&>CN&>O>&>FB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U
M<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(N&>E.&>
MM^&>D>*`B^&>E.&>A.&?DN&>HN&>O>&>A2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D
M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S
M='(@(N&>@.&?A.&?A^*`B^&>@.&>O.&>@.&>O"`HX9Z#X9ZXX9Z;X9ZXX9Z$
M*2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C0*;7-G:60@
M(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0V]L;VUB:6$B"FUS9W-T<B`BX9Z`X9Z\X9ZAX9Z[X9^&X9Z4X9^*X9ZX(@H*
M(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(N&>EN&>CN&?C"(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S`*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`Q('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I
M8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#,Y"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED
M(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.34T"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#`*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA
M;F0B"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z4X9Z)X9^2X9Z'X9ZV
M(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H
M96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("+AGI_AGX'AGH7AGH#A
MGY+AGH_AGKCB@(OB@(OAGJ+AGI+AGK?AGI3AGY+AGI3AGK;AGIDB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'XH"+X9Z2X9Z8X9^2
MX9Z8X9Z/X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T
M<B`BX9Z`X9Z[X9^&X9Z8X9^)X9Z\X9Z:X9^)X9Z\X9Z?(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M
M<&%N>2(*;7-G<W1R("+AGH#AGY+AGIKAGKOAGICAGJ#AGXKAGKOAGI,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D-O;7!U=&5R<R(*
M;7-G<W1R("+AGH#AGKOAGX;AGI;AGY+AGIGAGKSAGI'AGY#AGIHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDP"FUS9VED(")#;VYD:71I
M;VXB"FUS9W-T<B`BX9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-C$*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T
M<B`BX9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C;VYF:7)M+G!H<#HS.`IM<V=I9"`B0V]N9FER
M;2!%;6%I;"!!9&1R97-S(@IM<V=S='(@(N&>HN&?A^&>HN&>MN&>A.*`B^&>
MHN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>
MFR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G
M:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HS.#4*;7-G:60@(D-O;F9I<FT@;F5W
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BX9ZBX9^'X9ZBX9ZVX9Z$XH"+X9ZB
MX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;
MXH"+X9Z0X9^2X9Z8X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`BX9Z`X9Z[X9Z$X9Z@X9^2X9Z"X9^$(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I
M9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BX9Z`X9ZV
MX9Z:XH"+X9Z/X9Z7X9^2X9Z'X9ZVX9Z4X9^+XH"+X9Z4X9ZVX9Z3XH"+X9Z4
MX9Z:X9ZVX9Z'X9^0X9Z9XH"+PJ#AGY0B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,3`P
M"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")#;VYT86-T<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N
M=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S
M<V5D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT
M:6YU92(*;7-G<W1R("+AGI3AGI/AGY+AGH\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;V]K($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z`X9Z\X9Z`
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")#;V]K:64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(N&>A>&>
MF.&?DN&>F^&>A"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)
M1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM
M<V=S='(@(N&>@.&>O.&>G^&?DN&>C^&>MN&>FN&>N.&>@.&>MB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*
M;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M
M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R96%D("5S+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S
M=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T
M:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B
M:6QI=&EE<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I
M9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T
M(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(W"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z1X9^!X9Z?(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B0V]U<G-E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R
M("+AGI3AGH3AGY+AGH#AGK[AGH\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A
M(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,C,*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("+AGH#A
MGY+AGIKAGKSAGJ+AGK;AGH\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM
M<V=S='(@(N&>@N&>N^&>F>&>E.&>MB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K
M+W1I;64N<&AP.C,U"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`BX9Z6
MX9^!X9Z;XH"+X9Z<X9^!X9Z;X9ZVXH"+X9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2
MX9Z4X9Z3X9^2X9Z3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U
M<G)E;G0@57-E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,`IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(D-U<G)E;G0@
M8V]N9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*
M;7-G<W1R("+AGIKAGH7AGI/AGK;AGI3AGY#AGI'AGY+AGICB@(OAGI3AGH7A
MGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI/B@(LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`BX9Z4
MX9^2X9Z/X9Z\X9Z:XH"+X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z*
MX9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z:X9Z/X9^+XH"+X9Z/X9ZV
MX9Z8XH"+X9Z4X9^&X9Z.X9Z$(.&>HN&>MN&>G^&?DN&>FN&?D.&>F>*`B^&>
MF^&>ON*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>F^*`B^&>D>&?A>*`BR`E<R#A
MGY0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("+AGH#AGK;AGH_AGXLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U
M"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-Y<')U<R(*;7-G<W1R("+AGI_AGXKAGKCAGI;AGIKAGXTB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`BX9Z?X9^*X9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A+3TDX
M+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(N*`B^*`B^&>G^&?BN&>N.&>
MFN&>N.&>F^&>N.&>@"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@P"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L
M:6,B"FUS9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.XH"+X9Z:X9Z*X9^2X9Z+
MXH"+X9Z&X9^!X9Z`(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@S"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(N&>FN&>MN&>F^&?B^*`
MB^&>D.&?DN&>A.&?@R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I
M9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`V"FUS9VED(")$
M871E(@IM<V=S='(@(N&>@.&>MN&>F^*`B^*`B^&>E.&>FN&>M^&>A>&?@>&?
MDN&>AN&>D2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#`*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q-`IM<V=I9"`B1&%Y
M(@IM<V=S='(@(N&>D.&?DN&>A.&?@R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T
M92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(N&>
MDN&?DN&>D^&>O"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`BX9Z4
MX9Z3X9^2X9Z0X9Z9(.&>A>&>O.&>F^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?
MBR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P
M<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(N&>F^&?AN&>
MD^&>MN&?AN&>BN&>ON&>F"(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*
M;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1&5F
M:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(N&>F^&>
MN^&>E.*`BR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR
M,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@
M;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R
M("+AGIOAGKOAGI3B@(OAGH?AGKWAGIKB@(OAGHCAGIHB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O
M=R(*;7-G<W1R("+AGIOAGKOAGI3B@(OAGH?AGKWAGIKAGHKAGX'AGH`B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED
M(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@
M=&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM
M<V=S='(@(N&>BN&>MN&>CN&>NN&>F.&?B>&>MN&>@"(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@
M4')O8FQE;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:
MX9Z6X9ZWX9Z6X9Z.X9^,X9Z3X9ZV(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S4*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@
M(N*`B^&>HN&>E^&>M^&>G.&>C.&?DN&>C2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(Y"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R,0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I
M9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B
M1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("+A
MGI#AGH\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.30*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HY-PIM<V=I9"`B1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$P"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&II8F]U=&DB"FUS9W-T<B`BX9Z@X9^2X9Z?X9^*X9ZXX9Z4X9Z\X9Z1
MX9ZX(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G
M:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("+AGHKAGKSAGICA
MGKCAGI/AGKCAGH#AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@
M4F5P=6)L:6,B"FUS9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2
MX9Z+XH"+X9Z*X9Z\X9Z8X9ZXX9Z3X9ZXX9Z`X9^"X9Z3(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHX.`IM<V=I9"`B1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGICAGK;A
MGI/B@(OAGH+AGH[AGI/AGKC"H#\@X9Z?X9Z\X9Z8XH"+X9Z%X9Z[X9^'X9Z(
MX9^2X9Z8X9^$X9^'PJ#AGY0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-3@*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(N&>D>&>
MMN&>B>&>F>&>@"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$U
M"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B1'EN86UI8R!-
M86EL(@IM<V=S='(@(N&>G^&?AN&>E.&>N^&>C^&?DN&>FN*`B^&>D.&>MN&>
MF.&>G.&>D^&?DN&>CR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(N&>HN&?BN&>N.&>F.&?
M@N&>FR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O
M<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`BX9ZBX9^!X9Z`
MX9^2X9Z<X9ZVX9Z,X9^0X9Z:(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R
M"FUS9VED(")%9&ET(@IM<V=S='(@(N&>@.&?@N*`B^&>G^&>F.&?DN&>FN&>
MO>&>FR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G
M:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW
M-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I
M="!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P
M=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#`*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("+AGH#AGK;A
MGIKB@(OAGJ+AGI3AGXOAGIKAGX8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP
M="(*;7-G<W1R("+AGJ+AGX'AGJ#AGY+AGI_AGXKAGKCAGI0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(N&>HN&?@N&>F^&>
MG^&>MN&>F^&?B^&>G.&?B>&>MN&>C.&?D.&>FB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B
M16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")%;6%I;"(*;7-G
M<W1R("+AGJ+AGXKAGKCAGICAGX+AGILB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BX9ZBX9ZVX9Z?X9Z9
MX9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;(@H*(SH@<V5R
M=FEC97,O8V]N9FER;2YP:'`Z,S`*;7-G:60@(D5M86EL(&%D9')E<W-E<R!H
M879E(&)E96X@;&]C:V5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"XB"FUS9W-T<B`BX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+
MX9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"
MXH"+X9Z*X9Z\X9Z%X9Z"X9^2X9Z3X9ZVPJ#AGY0B"@HC.B!S97)V:6-E<R]C
M;VYF:7)M+G!H<#HR,PIM<V=I9"`B16UA:6P@861D<F5S<V5S('1O(&-O;F9I
M<FT@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.3DW"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(Y-PIM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(N&>G^&>B>&?DN&>B>&>
MMN*`B^&>HN&>MN&>FN&>F.&?DN&>F.&>CN&?C2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP
M='D@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`T"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@
M=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R
M"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,`IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(N&>
MH.&?DN&>@N&>N.&>CN&?@>*`B^&>HN&?@>&>@.&?DN&>G.&>MN&>D>&?D.&>
MFB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`BX9ZBX9^!
MX9Z:X9ZXX9Z1X9^2X9Z:X9ZV(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HU,PHC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C0Q"FUS9VED(")%<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI\B"@HC
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A
M=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN
M9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N
M:6$B"FUS9W-T<B`BX9ZBX9^!X9Z?X9^2X9Z/X9Z\X9Z3X9ZX(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`BX9ZBX9^!X9Z/X9^2X9Z9
MX9Z\X9Z6X9ZX(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`BX9ZBX9ZZX9Z:X9^)
MX9Z[X9Z4(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`BR#AGZ'A
MGZ4@X9Z3X9ZVX9Z1X9ZX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;
MX9^+XH"+(.&?H^&?H"#AGISAGK?AGI/AGK;AGI'AGK@B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`P(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E
M<GD@-2!M:6YU=&5S(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?
MBR#AGZ4@X9Z3X9ZVX9Z1X9ZX(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B
M"FUS9W-T<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+X9Z`X9Z3X9^2
MX9Z;X9^'XH"+X9Z8X9^)X9^$X9Z$(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C$P,PIM<V=I9"`B179E<GD@:&]U<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZV
MX9Z;X9^+X9Z3X9ZVX9Z1X9ZX(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T
M<B`BX9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/X9ZW(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-C8*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("+AGI3AGI/AGY+AGIOAGK;AGIDB"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`BX9ZBX9^*X9ZWX9Z%X9Z?X9^2X9Z4X9Z\X9Z.X9Z$X9^+X9Z?X9^"
MX9Z;(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR-#4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HQ,#$*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#D*;7-G:60@
M(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU,#$@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*2(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGJ#AGY+AGISA
MGXGAGH#AGJ'AGH3AGXL@*.&>F.&?B>&>MN&>F^&?B^&>G.&>N.&>CN&>MBDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(N&>
M@.&?A.&?A^&>H.&?DN&>G.&>MN&>HN&?@>&>FN&>O"(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3@W"FUS9VED(")&87@B"FUS9W-T<B`BX9Z1X9Z\X9Z:X9Z?X9ZVX9Z:(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V-0IM<V=I9"`B1F%X97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(N&>@.&>N^&>F.&?
MDN&>E^&?B"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C4*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU
M,@IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(D9I9VQE="!#05!40TA!(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#`*;7-G
M:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@
M(D9I:FDB"FUS9W-T<B`BX9Z@X9^2X9Z<X9ZXX9Z@X9^2X9Z?X9^*X9ZX(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE
M(@IM<V=S='(@(N&>K^&>@.&>G^&>MN&>FB(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R
M,PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B
MX9Z(X9^2X9Z8X9^$X9^'XH"+X9ZOX9Z`X9Z?X9ZVX9Z:(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDX.`IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Y-`IM
M<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#@U"FUS9VED(")&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.CDX"FUS9VED(")&:6QT97)S(@IM<V=S='(@(N&>C^&>F.&?DN&>
MFN&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`BX9Z@
MX9^2X9Z<X9ZVX9^&X9Z$X9ZAX9Z$X9^+(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-34*;7-G:60@(D9I>"!R871I;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,P"FUS9VED(")&;&EP(@IM<V=S='(@(N&>C^&?DN&>FN&>H>&>
ME.&?BR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(N&>D>&>G^&>E^&>
MMN&>@B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HR-C`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("+AGI;A
MGH[AGXSB@(OAGI;AGKOAGICAGY+AGI;B@(OAGJ+AGH#AGY+AGI_AGIHB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(D9O;V0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,T-@IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<W"FUS9VED("(B"B)&
M;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T
M(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.30*;7-G:60@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")&;W)M<R(*;7-G<W1R("+AGI_A
MGX;AGH[AGKOAGX;B@(OB@(OAGI3AGX+AGI3AGI3AGI$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C8*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P-`IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0T"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-CD*;7-G:60@(D9O<G5M<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED
M(")&;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`BX9Z?X9^*X9Z[X9Z8(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(N&>E.&>MN&>FN&>MN&?
MAN&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("+AGJ#AGY+AGH+AGKSA
MGJ+AGXKAGKCAGIGAGXGAGK;AGH[AGK8@X9Z4X9ZVX9Z:X9ZVX9^&X9Z$(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
MX9Z4X9^)X9Z\X9Z;X9ZXX9Z3X9^!X9Z?X9^*X9ZXXH"+X9Z4X9ZVX9Z:X9ZV
MX9^&X9Z$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,B"FUS9W-T<B`BX9ZBX9ZVX9Z.X9Z%X9Z`X9^2X9Z:XH"+
MX9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(.&>E.&>MN&>FN&>MN&?AN&>
MA"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`BX9Z6X9ZX(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S4R"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3@*
M;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BX9Z(
MX9^2X9Z8X9^$X9^'XH"+X9Z6X9^!X9Z)(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZVX9Z4X9Z[X9Z$(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("+AGJ#AGY+AGH#AGK;A
MGX;AGI3AGXKAGK@B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L
M('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH
M=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`BX9Z@X9^2X9Z?X9Z`X9Z@
MX9^2X9Z?X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G
M<W1R("+AGJ+AGK;AGIOAGY+AGIOAGKKAGICAGXGAGH3AGXLB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")':&%N82(*;7-G<W1R("+AGJ#AGY+AGH#AGK;AGH[AGK8B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`BX9Z@X9^2
MX9Z"X9ZXX9Z4X9^2X9Z:X9ZVX9Z;X9^+X9Z/X9ZV(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B
M"FUS9W-T<B`BX9Z3X9ZVX9Z8X9Z!X9^2X9Z;X9Z]X9Z3(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B
M1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`BX9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+
MX9Z?X9Z`X9Z;(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G
M:60@(D=O(@IM<V=S='(@(N&>D>&?A2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-0IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(Y"FUS9VED(")';V]G
M;&4@36%P<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S8*;7-G:60@(D=R
M87ES8V%L92(*;7-G<W1R("+AGICAGK;AGH_AGY+AGIKAGHKAGY+AGHOAGK;A
MGI/B@(OAGI3AGY+AGIKAGI7AGX'AGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M1W)E96-E(@IM<V=S='(@(N&>@.&?DN&>FN&>M^&>@"(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS
M9W-T<B`BX9Z`X9^2X9Z:X9ZWX9Z`("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("+AGH+AGY+AGIKAGKCAGJ'A
MGH3AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(N&>
MH.&?DN&>@N&?DN&>FN&>N.&>CN&>MN&>BN&>MB(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("+AGH#AGY+AGIKAGKOAGI@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(N&>H.&?DN&>
M@N&>O.&>HN&>MN&>BN&>NN&>F^&>O.&>E.&?B>&?@2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%M(@IM<V=S='(@(N&>H.&?DN&>@N&>MN&?AN&>F"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`BX9Z@X9^2X9Z"
MX9ZVX9Z/X9^!X9Z8X9^)X9ZVX9ZAX9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-@IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U
M:6YE82(*;7-G<W1R("+AGJ#AGY+AGH+AGKCAGH[AGX$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZX
MX9Z.X9^!X9Z4X9^*X9ZXX9Z?X9^%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=7EA;F$B"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZXX9Z9X9^)X9ZVX9Z.X9ZV(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM
M<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34T"FUS9VED(")(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("+AGJ#AGX/AGI'AGK@B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M
M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDR,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3(U"FUS9VED(")(96%D97(B"FUS9W-T<B`BX9Z4X9Z+X9Z8
MX9Z`X9Z0X9ZVXH"+(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("+AGI3AGHOA
MGICAGH#AGI#AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B@(OA
MGJ#AGXKAGK[AGHH@X9Z3X9ZWX9Z$(.&>@.&?A.&?A^*`B^&>F.&?B>&>MN&>
M@.&>BN&>O.&>CN&>MN&>F^&?BR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")(96)R
M97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I
M9VAT(@IM<V=S='(@(N&>@.&>F.&?DN&>EN&>G^&?BR(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92](96QP+G!H<#HQ.#$@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TAE;'`N<&AP.C$X,@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ
M-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G
M<W1R("+AGH?AGX;AGI/AGKWAGIDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Y
M"FUS9VED(")(96QP97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE
M(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")(:6=H(@IM<V=S='(@(N&>@>&?DN&>
MEN&>G^&?BR(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP
M;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A
M=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`BX9Z@X9Z\X9Z;X9ZXX9Z?X9^*
MX9ZX("CAGIKAGHKAGY+AGHOB@(OAGH#AGY+AGIKAGKOAGH3B@(OAGISAGXGA
MGK;AGI'AGKCAGH#AGH3AGXLI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-34U"FUS9VED(")(;VUE(@IM<V=S='(@(N&>@N&?@>&>H.&>D>&?
MAN&>EN&?D.&>FB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(N&>HN&>
MMN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>E>&?DN&>D>&?AR(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB
M"FUS9W-T<B`BX9Z0X9Z/X9Z5X9^2X9Z1X9^'(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R("+AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OAGI7AGY+A
MGI'AGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(N&>H.&>N^&>A.&>C.&>O.&>FN&?B>&>MN&>G^&?BR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(N&>H.&>N^&>A.&>@.&>N^&>
MA"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R
M9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P
M;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C0V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4
M:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!0
M2%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$Q.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G
M:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N
M=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@
M*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*;7-G:60@(DAU
M;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-3,*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED(")(=6UO<FES=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(N&>
MH.&>N^&>A.&>@N&?DN&>FN&>N"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W,"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C,T"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,CDV"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W-R!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS
M9W-T<B`BX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+($E0(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(N&>HN&?BN&>
MN.&>G^&?DN&>F^&>A.&?BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`BX9Z/X9^"XH"+X9Z:X9Z\
MX9Z4X9Z/X9^&X9Z.X9ZVX9Z$(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N
M<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y
M;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E
M<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM
M86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%52
M3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-CD*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(N&>FN&>
MO.&>E.&>E^&>MN&>EB(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O
M<G1E9"!F:65L9',Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T
M('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B
M"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z`X9Z^X9Z3XH"+X9Z`X9ZVX9Z:XH"+X9Z%
MX9Z\X9Z;XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED("));F1I82(*;7-G<W1R("+AGJ7AGH[AGY+AGHSAGK8B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R
M("+AGJ7AGH[AGY+AGHSAGKSAGI/AGX'AGI_AGXKAGK@B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O
M(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S
M='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E
M<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T
M($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM
M<V=S='(@(N&>E.&>B>&?DN&>A>&>O.&>F^*`B^&>C^&>MN&>FN&>MN&>A"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*
M;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G
M:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*
M;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y
M;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*
M;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM
M<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN
M<V5R="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED
M("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN
M<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R
M('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B
M26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O
M36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<Y"FUS9VED
M("));G1E9V5R(@IM<V=S='(@(N&>A>&?AN&>D^&>O>&>D^*`B^&>@N&>C^&?
MBR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN
M=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,38V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,P-PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F
M;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W,`IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-`IM<V=I9"`B
M26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS
M9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-@IM<V=I9"`B26YV86QI9"!P87)T
M;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38X"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-2!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3@*;7-G:60@(DEN=F%L:60@<VAA
M<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R
M8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N
M:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,W,PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@
M(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("+AGJ+AGXKAGKCAGIKA
MGXGAGK;AGH#AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS
M9W-T<B`BX9ZBX9^`X9Z:X9ZAX9Z$X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("+AGJ+AGXKAGKCAGI_AGY+AGIKA
MGK;AGJ+AGX+AGILB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`
MB^&>A>&?@>&>B2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(N&>D>&?DN&>FN&?
M@>&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`BX9ZB
MX9^*X9ZXX9Z/X9ZVX9Z;X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA
M:6-A(@IM<V=S='(@(N&>A>&>MN&>F.&?B>&?@^&>@.&>MB(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU
M87)Y(@IM<V=S='(@(N&>F.&>@.&>FN&>MB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F%P86XB"FUS9W-T<B`BX9Z'X9Z4X9^)X9Z[X9Z3(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*
M4"DB"FUS9W-T<B`BXH"+X9Z'X9Z4X9^)X9Z[X9Z3("A)4T\M,C`R,BU*4"DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R
M<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM
M<V=S='(@(N&>H.&?DN&>G^&?BN&>@.&>BN&>MN&>D^&>N"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY
M(@IM<V=S='(@(N&>@.&>@.&?DN&>@.&>BN&>MB(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S
M='(@(N&>F.&>M^&>D.&>N^&>D^&>MB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB
M"FUS9W-T<B`BX9Z/X9Z8X9^2X9Z:X9ZYX9Z8XH"+X9Z?X9Z$XH"+X9Z!X9ZV
MX9Z$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B
M2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMA>F%K:'-T86XB"FUS9W-T<B`BX9Z`X9ZVX9Z@X9^2X9Z?X9ZVX9Z`X9^+
MX9Z?X9^2X9Z/X9Z$X9^+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("+AGH#A
MGX+AGI/AGIGAGXGAGK8B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@V"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-PIM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(N&>E.&?DN&>FN&>G.&?@N&>A.*`B^&>@.&>
MO.&>D^&>G^&?A"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z7X9^!
MX9Z1XH"+X9Z"X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%X9Z[X9Z%(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5
M<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0X"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`BX9Z"X9ZWX9Z:X9ZWX9Z4X9ZV
MX9Z1X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I
M8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B2V]R96%N("A%54,M2U(I
M(@IM<V=S='(@(N*`B^&>@.&>O.&>FN&?B>&?@2`H155#+4M2*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(N&>@N&>N^&>F>*`B^&>
MG.&?B>&?@N&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*
M;7-G<W1R("+AGH+AGX#AGIKAGJ#AGY+AGH+AGKCAGI_AGY+AGH_AGH3AGXLB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M-0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BX9Z7X9ZVX9Z?X9ZV(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8R(*;7-G<W1R("+AGI_AGK;AGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB
M@(OAGI3AGY+AGIKAGH?AGK;AGI+AGK?AGI3AGH_AGX'AGIGAGY+AGIGB@(OA
MGI3AGY+AGIKAGH?AGK;AGICAGK;AGI/AGK?AGH_B@(OAGJ'AGK;AGIPB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),
M87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T
M(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C,*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA
M<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`BX9ZAX9ZVX9Z/
MX9Z<X9ZXX9Z9X9^)X9ZV(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y
M"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS
M9W-T<B`BX9Z4X9^2X9Z;X9Z$X9^+XH"+(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`BX9Z;X9ZXX9Z4X9Z$X9^+(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED
M("),969T(@IM<V=S='(@(N&>AN&?DN&>G.&?@>&>A"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3(*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#@*;7-G:60@
M(DQE9G0@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("+AGJ'AGX'AGI_AGKSAGH_AGKPB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S
M='(@(N&>@.&>F.&?DN&>FN&>M^&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&EB97)I82(*;7-G<W1R("+AGIOAGKCAGI3AGX'AGIKAGKCAGIGAGXGAGK8B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B
M"FUS9W-T<B`BX9Z%X9ZVX9Z8X9^)X9ZVX9ZBX9^*X9ZWX9Z:X9ZXX9Z9X9^)
MX9ZVXH"+X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+(.&>F^&>N.&>E.&?BN&>N"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("+A
MGIOAGK?AGH7AGI'AGX'AGI/AGI_AGY+AGH_AGX+AGI,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@
M1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM
M<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@
M4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N
M;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@R,@IM<V=I9"`B3&EN:R(*;7-G<W1R("+AGH_A
MGX;AGHXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@S"FUS9VED("),
M:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE
M;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM
M<V=S='(@(N&>C^&?AN&>CB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI
M<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,#D*;7-G:60@(DQI<W0M
M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4P-`IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3$Q"FUS9VED("),
M:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3`W"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`X"FUS9VED("),
M:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU,#8*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`U"FUS
M9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E
M<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@IM
M<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQI=&AU86YI82(*;7-G<W1R("+AGIOAGKCAGI'AGKOAGIGAGJ+AGK;A
MGI/AGK@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N
M<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(N&>@.&?AN&>EN&>
MN^&>A.*`B^&>E>&?DN&>D>&>N^&>@"XN+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L
M92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-C(*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A
M<BYP:'`Z-S<*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(N&>D>&>N.&>C^&>
MMN&?AN&>A"(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.#(*;7-G:60@(DQO9R!I;B(*;7-G<W1R("+AGH7AGKSA
MGILB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@
M(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U
M="(*;7-G<W1R("+AGH7AGX'AGHDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(N&>A>&>O.&>FR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM
M<V=S='(@(N&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>A>&>O.&>FR(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S,*;7-G:60@
M(DQO;F<@=&5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3,*;7-G:60@(DQO=F4B"FUS9W-T<B`BX9Z?X9^!X9Z%X9Z`X9^2X9Z/
MX9ZXXH"+X9Z?X9^2X9Z:X9ZAX9ZVX9Z)X9^+(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G<W1R
M("+AGI'AGK;AGI0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE
M='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`BX9Z;X9Z[X9Z%X9Z@X9^2X9Z?X9^&X9Z4X9Z]X9Z:
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y
M.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-
M32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3<*;7-G:60@(DU/
M5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B
M"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z`X9ZVX9Z<(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS
M9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R
M(@IM<V=S='(@(N&>F.&?B>&>MN&>BN&>MN&>H.&?DN&>@.&>MN&>G^&?DN&>
M@.&>MN&>FB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M36%G:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.CDP"FUS9VED(")-86EL(@IM<V=S='(@(N&>G^&?AN&>E.&>N^&>C^&?DN&>
MFB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,S@*;7-G:60@(DUA
M:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM
M<V=S='(@(N&>F.&?B>&>MN&>H>&>MN&>G.&?@R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B36%L87ES:6$B"FUS9W-T<B`BX9Z8X9^)X9ZVX9ZAX9^!X9Z?X9^*
MX9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("+A
MGICAGXGAGK;AGIOAGXOAGHSAGKCAGIPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUA;&DB"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z;X9ZX(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QT82(*;7-G<W1R("+AGICAGXGAGK;AGIOAGXOAGH_AGK8B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,34T"FUS9VED(")-87`R-"!M87`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P.#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-CD*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S
M('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(N&>F.&>
MN.&>D^&>MB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+AGIKAGKGA
MGICB@(OAGI'AGX;AGI;AGY#AGIHB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`BX9Z`
MX9^$X9^'($UA<G-H86QL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI
M<75E(@IM<V=S='(@(N&>F.&?B>&>MN&>FN&>D>&>N.&>D^&>N.&>@B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN
M9R!F:65L9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R
M:71A;FEA(@IM<V=S='(@(N&>F.&?B>&>O.&>FN&>N.&>C^&>MN&>D^&>N"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(N&>F.&?
MB>&>O.&>FN&>N.&>D>&>N^&>GR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@
M8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A
M<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q.`IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R,0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM
M<V=I9"`B36%Y(@IM<V=S='(@(N&>I^&>G^&>E^&>MB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`BX9Z8X9^#X9ZBX9Z\X9Z/X9^!
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")-961I8VEN
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(N&>G^&>F.&>MN&>A^&>
MM^&>@"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE
M;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BX9Z?
MX9ZVX9Z:(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C0R"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-`IM<V=I9"`B
M(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.`IM<V=I9"`B365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M("+AGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+AGIKAGY+AGH\B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#
M+W!H<&=W+G!H<#HX.`HC.B!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z
M.#D@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T
M:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B365T<FEC
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S
M='(@(N&>F.&?B>&>M^&>A>&>G^&?BN&>M^&>@"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS
M9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(N&>@.&>CN&?DN&>C^&>
MMN&>FR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z7X9^!
MX9Z1($UI;64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,@IM<V=I9"`B
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S$T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C0S.`IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,S"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B
MX9Z&X9^2X9Z;X9Z[X9^'(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V
M"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(N&>E>&?DN&>G^&?@>&>
MA.&?E^*`BR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!M
M=7-T(&=E;F5R871E(&ET(&)E9F]R92!U<VEN9R!T:&ES(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@
M1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("+AGICAGXGAGKSAGH[AGK;A
MGH#AGKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@
M(N&>F.&?B>&>N^&>A.&>H.&?DN&>@N&?A.&>F^&>N"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.3(*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM
M<V=S='(@(N&>@>&?@B#AGI/AGK?AGH0@X9Z&X9^2X9Z3X9ZVX9^&(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I
M9"`B36]N=&AL>2(*;7-G<W1R("+AGIKAGK;AGIOAGXOB@(OAGH'AGX(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`BX9Z8X9^)
MX9Z[X9Z$X9Z?X9^!X9Z:X9^)X9ZV(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@
M97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]R;V-C;R(*;7-G<W1R("+AGICAGXGAGK;AGIKAGXGAGKOAGH`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B
M36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HU,#`*;7-G
M:60@(DUO=F4@1&]W;B(*;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OA
MGI'AGKCB@(OAGH7AGKOAGX?B@(OAGH#AGY+AGIKAGX3AGI@B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C4P-`IM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>
MD>&>N.*`B^&>D>&?A>*`B^&>AN&?DN&>G.&?@>&>A"(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-3`X"FUS9VED(")-
M;W9E(%)I9VAT(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>
MN.*`B^&>D>&?A>*`B^&>G^&?DN&>C^&>MN&?AB(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#DV"FUS9VED(")-;W9E
M(%5P(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`B^&>
MH>&>ON&>A.*`B^&>F^&>OB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+A
MGH7AGKOAGX?B@(OAGH#AGY+AGIKAGX3AGI@B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS
M9W-T<B`BX9ZAX9Z^X9Z$XH"+X9Z;X9Z^(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-;WIA;6)I<75E(@IM<V=S='(@(N&>F.&?B>&>O.&>H.&?DN&>G^&>MN&?
MAN&>E.&?BN&>M^&>@"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.3(*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`U-@IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3`*;7-G:60@(DUU;'1I<&QE('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#$V"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C8V"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+V5D:70N<&AP.C$S-0IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`BX9Z8X9ZXX9Z9X9^)X9ZVX9Z3X9^+X9Z8X9^)X9ZV(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/
M+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+AGHCAGY+AGICA
MGX3AGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B
MX9Z.X9ZVX9Z8X9ZXX9Z4X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M875R=2(*;7-G<W1R("+AGH[AGKSAGIKAGKLB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE<&%L(@IM<V=S='(@(N&>D^&?@>&>E.&?B>&>MN&>F^&?BR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`BXH"+X9Z@
MX9Z[X9Z;X9^2X9Z;X9Z$X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE
M<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(N&>HN&>A.&?B^&>D>&>N.&>F>&?
MC>*`B^&>H.&>O.&>F^&?DN&>F^&>A.&?BR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@
M(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C<*;7-G
M:60@(DYE='=O<FLB"FUS9W-T<B`BX9Z4X9Z.X9^2X9Z/X9ZVX9Z)(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(N&>@.&>N^&?AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A
M;&5D;VYI82(*;7-G<W1R("+AGI/AGKSAGISAGX+AGIOAGH#AGK;AGIOAGX'A
MGHKAGKSAGI/AGK@B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX-`HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#@*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E
M<R(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGI#AGY+AGICAGKCB@(OAGI'AGX4@
M)7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B
MX9Z3X9Z\X9Z<X9^"X9Z;X9Z@X9^*X9^2X9Z?X9^!X9ZAX9Z$X9^+(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S
M<W=O<F0B"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$
MX9ZVX9Z/X9^+XH"+X9Z0X9^2X9Z8X9ZX(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C(T.0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D
M<R!D;VXG="!M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H
M7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT
M,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<R(*;7-G<W1R("+AGI;AGY#AGH_A
MGXSAGICAGK;AGI,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(Q
M"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(N&>G.&?@>&>D>&>M^&>@.&>
MMN*`B^&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(N&>E.&>
MD^&?DN&>D>&>MN&>E.&?BR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM
M<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V-R!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,W,0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G
M<W1R("+AGI/AGKCAGH#AGK;AGIKAGXGAGK;AGJ#AGY+AGH+AGY#AGIHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(N&>D^&>N.&>H.&?
MDN&>G^&?@>&>FB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G
M<W1R("+AGI/AGKCAGJ#AGY+AGI_AGX'AGIKAGKCAGIGAGXGAGK8B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<R"FUS9VED(").:6=H="(*
M;7-G<W1R("+AGIGAGI3AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B
M"FUS9W-T<B`BX9Z3X9ZXX9Z<(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV-`IM<V=I9"`B3F\B"FUS9W-T<B`BX9Z1X9^!
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED
M(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE
M('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HW-@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S
M-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C(U.0IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HV-PIM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@
M(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38Y
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(P"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4U"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HV.3@*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP
M,PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(Q
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$S-0IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38R"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO
M(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E
M<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY.0IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM
M<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S
M:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G
M:60@(DYO(')U;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U
M8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3,Q"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`@9G)A;65W;W)K+U)00R]24$,O
M<&AP9W<N<&AP.C$W-0IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDW,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3@R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY.3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,3`*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I
M9"`B3F]N92(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE
M("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S
M='(@(N&>@.&?A.&?A^*`B^&>CN&?B>&>H.&?DN&>G.&?B>&>@"(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G
M:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B
MX9Z`X9^$X9^'XH"+X9Z8X9^)X9ZVX9Z:X9^`X9Z.X9ZVXH"+X9Z7X9ZVX9Z"
MXH"+X9Z!X9ZVX9Z$XH"+X9Z'X9Z^X9Z$(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").;W)W87DB"FUS9W-T<B`BX9Z3X9^0X9Z:X9Z<X9^"X9Z?(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!
M9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3@*;7-G:60@(DYO="!A(&1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM
M<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@
M<V5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(P."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V
M.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@U(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,#$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S,S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS-C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4Y,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-C8Y"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HX,B!F<F%M
M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3,Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VAO<F1E+G!H<#HQ-3$@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP
M.C$W,`HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3@Y(&9R86UE
M=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR,#<*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O:&]R9&4N<&AP.C(R-R!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z
M,S,P"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#@U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#<*;7-G:60@(DYO=&5S(@IM<V=S='(@(N&>A>&?AN&>CN&>MN&?AB(*
M"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E
M;6)E<B(*;7-G<W1R("+AGISAGK?AGH7AGY+AGH;AGK?AGH#AGK8B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS
M9W-T<B`BX9Z;X9^!X9Z!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30S,PIM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BX9Z%
MX9^&X9Z3X9Z]X9Z3XH"+X9Z/X9Z]X9ZBX9Z`X9^2X9Z?X9Z:(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#,Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-3,@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@
M(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-S4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4Q('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("+AGIGAGIOAGXOAGI;AGY+AGIKA
MGI@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<Q"FUS9VED(")/8FIE8W0B"FUS9W-T<B`BX9Z<X9Z/X9^2X9Z0X9Z[(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C
M="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(N&>C^&>N^&>F^&>MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY-PIM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,@IM<V=I9"`B3V9F:6-E(@IM
M<V=S='(@(N&>@.&>MN&>FN&>M^&>F>&>MN&>F^&?D.&>F2(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S
M=V]R9"(*;7-G<W1R("+AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3A
MGK;AGH_AGXOB@(OAGH7AGK;AGI_AGXLB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R
M<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM
M<V=S='(@(N&>HN&>O.&>F.&?@N&>DR(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,3`P"FUS9VED(")/;FQY(&]F9F5N<VEV92!F
M;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-SD*;7-G:60@(D]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HT,`IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`BX9Z4X9Z^X9Z`XH"+XH"+X9Z`X9^2X9Z3X9Z[X9Z$XH"+XH"+
MX9Z4X9Z$X9^2X9ZBX9Z]X9Z%XH"+X9Z0X9^2X9Z8X9ZX(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS
M9W-T<B`BX9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z4X9^2X9Z:X9Z/
MX9ZWX9Z4X9Z/X9^2X9Z/X9ZWX9Z`X9ZVX9Z:(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("+A
MGH?AGICAGY+AGIKAGK[AGI_B@(LB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M,S(@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E
M9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@
M(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`BX9Z5X9^2X9Z?X9^!X9Z$X9^7(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF
M;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C@P"FUS9VED(")004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U
M"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I
M9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@
M(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,@IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS
M9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("+AGH7AGI/AGY+AGIOA
MGX3AGX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@
M(N&>E.&?B>&>MN&>@N&>N.&>G^&?DN&>D.&>MN&>DR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(N&>E.&?B>&>MN&>H>&>O"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B
M"FUS9W-T<B`BX9Z4X9^)X9ZVX9Z.X9ZVX9Z8X9^)X9ZV(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(N&>E.&?B>&>
MMN&>EN&>O.&>B>&>O.&>G.&>H.&?DN&>@N&>N.&>CN&?@2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(N&>E.&?B>&>MN&>FN&?
MB>&>MN&>H.&?DN&>@N&>MN&>F2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C8*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV.2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,SD*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(N&>EN&>MN&>@.&?DN&>
MF>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?BR(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-3<*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-C$*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM
M<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(N&>EN&>MN&>@.&?DN&>F>*`B^&>
MG^&>F.&?DN&>A.&>MN&>C^&?B\*@X9^6(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-#(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM
M<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R
M("+AGI3AGK?AGI'AGI?AGY+AGH?AGK;AGI3AGXLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F
M<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@
M(N&>E>&?DN&>F^&>O.&>G"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4&5O<&QE(@IM<V=S
M='(@(N&>F.&>D^&>N^&>G^&?DN&>GR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S
M='(@(N&>E^&>MN&>@N&>FN&>F2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+AGI+AGY+AGISAGK[B@(OAGI3AGY+A
MGIKAGH_AGK?AGI3AGH_AGY+AGH_AGK?AGH#AGK;AGIKB@(OAGH_AGX;AGJ#A
MGX+AGI'AGK;AGX8@X9Z6X9^!X9Z;XH"+X9Z%X9Z\X9Z;(#\B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R("+AGI_AGK?AGI'AGY+AGI+AGK<B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I
M;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(N&>G^&>M^&>D>&?DN&>DN&>MR(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BX9Z6X9^0
MX9Z/X9^,X9Z8X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9ZVX9Z;X9^+XH"+X9Z!X9^2
MX9Z;X9Z]X9Z3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@
M(N&>E.&?B>&?@>&>FN&?B>&>O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(N&>H.&?DN&>G.&>N.&>F^&>N.&>
MEN&>N.&>DR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(N&>D>&>O.&>FN&>G^&?
MD.&>EN&?DN&>D2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.30*
M;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED
M(")0:71C86ER;B(*;7-G<W1R("+AGI;AGKCAGH_AGH'AGK;AGIGAGIKAGK?A
MGI,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(N&>E^&>N.&>@.&>G^&?@N&>
MFR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4&QA=&ET
M=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<P"FUS9VED(")0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U,0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0U-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G
M:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0;VQA;F0B"FUS9W-T<B`BX9Z4X9^)X9Z\X9ZAX9Z\X9Z)(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`S"FUS9VED(")0
M;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A
M;"(*;7-G<W1R("+AGI;AGY#AGIKAGI'AGKOAGIGAGJ#AGY+AGH+AGK;AGIOA
MGXLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W."!L:6(O0FQO8VLO;65T87(N<&AP.C(X,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDQ"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HQ,S,*;7-G
M:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*
M;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(N&>G^&>F.&?DN&>EN&>MN&>DB(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"FUS9VED(")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(Y"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(N&>F.&>ON&>F^*`
MB^&>A^&>MN*`B^*`B^*`B^&>F.&>N^&>DR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B
M4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4W(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8Q"FUS9VED(")0<F5V:6]U<R!O<'1I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,X-0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`BX9Z"X9Z8X9^2
MX9Z:X9^$X9Z$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DV"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R.#<*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4'5B;&EC($ME>2(*;7-G<W1R("+AGH#AGKSAGI/AGI_AGX3B@(OAGI_AGK;A
MGI+AGK;AGIKAGH[AGX@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S
M='(@(N&>EN&?D.&>FN&>C^&>O.&>FN&>N.&>@.&>O"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(N&>@.&>MN&>C^&>MB(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`BX9Z?
MX9^&X9Z.X9Z]X9Z:XH"+(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"FUS9VED(")1=6]T82(*;7-G<W1R("+AGH#AGKSAGH_AGK8B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<R"FUS9VED(")2861I;R!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@
M(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-PIM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@86YD
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O
M<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R
M("+AGJ+AGK;AGI,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED
M(")2969R97-H(@IM<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`
MB^&>G^&?DN&>FN&>G^&?BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2
M969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.30*;7-G:60@(E)E9G)E<V@@<F%T93HB"FUS
M9W-T<B`BX9ZBX9Z/X9^2X9Z:X9ZVXH"+X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2
MX9Z9XH"+X9Z?X9^2X9Z:X9Z?X9^+PJ#AGY8B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0R"FUS
M9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`BX9Z5X9^2X9Z1
MX9Z[X9Z`XH"+X9ZAX9Z^X9Z$XH"+X9Z<X9ZWX9Z)(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,S@*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`BX9Z`X9^&
MX9Z.X9Z/X9^+XH"+X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS
M9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C@@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B
M"FUS9W-T<B`BX9Z9X9Z`XH"+X9Z%X9^!X9Z)(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I
M9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@
M(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I
M9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V
M92!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C$S."!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3<S
M"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34P"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3<V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3,P
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-S`T(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#8Q"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HT
M,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M571I;"]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S,T"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-#,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$Y('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`BX9Z`X9^&
MX9Z.X9Z/X9^+XH"+X9ZAX9Z^X9Z$XH"+X9Z<X9ZWX9Z)(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W
M"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R
M>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO
M8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B
M4F5S=6QT<R(*;7-G<W1R("+AGIOAGI'AGY+AGI+B@(OAGI7AGILB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@
M(N&>C^&?DN&>FN&>H>&>E.&?B^*`B^&>D>&?A>*`B^&>A^&>F.&?DN&>FN&>
MON&>GR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I
M9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(N&>FN&>N.&>HN&>N^&>F>&>
MD^&>N.&>F>&?B>&>N^&>A"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B4FED
M9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(N*`
MB^&>G^&?DN&>C^&>MN&?AB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,30*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$P"FUS9VED(")2:6=H="!V86QU97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+AGH_AGKWAGI/AGK;A
MGI'AGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@
M(N&>FN&>O.&>F.&?B>&>MN&>D^&>N"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,C0*;7-G:60@(E)O=&%T92`Q.#`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R,0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BX9Z4X9Z$X9^2
MX9Z<X9ZWX9Z;XH"+X9Z1X9^%XH"+X9Z&X9^2X9Z<X9^!X9Z$(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-PIM<V=I9"`B
M4F]T871E(%)I9VAT(@IM<V=S='(@(N&>E.&>A.&?DN&>G.&>M^&>F^*`B^&>
MD>&?A>*`B^&>G^&?DN&>BN&>MN&?AB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P
M97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("+AGH?AGKWAGIKB
M@(OAGHKAGX'AGH#"H.&?EB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM
M<V=I9"`B4G5N(@IM<V=S='(@(N&>FN&>C^&?B^*`BR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("+AGI_AGJ#A
MGI;AGY#AGI/AGY+AGI+B@(OAGIKAGKOAGI_AGY+AGI_AGXKAGK@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`BX9Z:X9Z<X9^)X9ZV
MX9Z3X9^+X9Z*X9ZV(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#(*;7-G
M:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,`IM<V=I
M9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")344P@<W1A=&5M96YT
M(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-#<*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q
M"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M86EN="!(96QE;F$B"FUS9W-T<B`BX9Z?X9Z$X9^+XH"+X9Z@X9^!X9ZAX9^!
MX9Z.X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@
M3F5V:7,B"FUS9W-T<B`BX9Z?X9Z$X9^+X9Z#X9ZXX9Z/(.&>D^&>M^&>A"#A
MGI/AGX'AGISAGKCAGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(N&>G^&>A.&?B^&>F^&>O.&>G^&?BN&>N.&>F>&?B>&>
MMB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`BX9Z?X9Z$X9^+XH"+X9Z6X9^2X9Z9X9^"X9Z:(.&>
MD^&>M^&>A"#AGICAGKCAGH+AGKOAGIGAGJ+AGX'AGJ'AGKOAGH0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<R(*;7-G<W1R("+AGI_AGH3AGXOAGISAGK;AGX;AGH3AGI_AGH3AGXL@
MX9Z3X9ZWX9Z$(.*`B^&>H.&?DN&>@N&?DN&>FN&>N.&>CN&>MN&>C.&>N.&>
MDR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("+AGI_AGK;AGICAGKSA
MGJ+AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S
M='(@(N&>G^&>MN&>D^&?B^&>F.&?B>&>MN&>FN&>N.&>CN&>O"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM
M<V=S='(@(N&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>E.&?BN&>N.&>G^&>
MMN&>HN&>O.&>C.&>N"(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,34*;7-G:60@(E-A=F4B"FUS9W-T<B`BX9Z:X9Z`X9^2X9Z?X9ZVXH"+
MXH"+X9Z1X9Z[X9Z`XH"+XH"+(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N
M<R(*;7-G<W1R("+AGIKAGH#AGY+AGI_AGK;B@(OAGI'AGKOAGH#B@(L@X9Z'
MX9Z8X9^2X9Z:X9Z^X9Z?(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A
M(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4V-A='1E<F5D(%0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-`IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(N&>G^&?DN&>G.&?@N&>
MA.&>FN&>@"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S8*;7-G
M:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(N&>F.&?B>&>MN&>G^&?BN&>
MN.&>D^*`B^&>G^&?DN&>G.&?@N&>A.&>FN&>@"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y-C8*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@S"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(N&>A^&?DN&>FN&>
MON&>G^*`B^&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>D2(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@
M82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I
M9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<T"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(N&>A^&?
MDN&>FN&>ON&>G^*`B^&>D>&>MN&?AN&>A.&>HN&>G^&?BR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-30*;7-G:60@(E-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<Q"FUS9VED(")396QE8W0@86X@;V)J
M96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S4*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(N&>
MA^&?DN&>FN&>ON&>G^*`B^&>@N&?DN&>F.&>MN&>DR(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,`IM
M<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V5N96=A;"(*;7-G<W1R("+AGI_AGX'AGH[AGX'AGJ#AGY+AGH+AGK;A
MGIOAGXLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R.`IM<V=I9"`B4V5N
M<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("+AGH#A
MGHGAGY+AGHGAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@
M(N&>G^&?@N&>E.&?BN&>N"#AGI/AGK?AGH0@X9Z8X9^)X9Z[X9Z$X9Z/X9^!
MX9Z.X9^!X9Z@X9^2X9Z`X9^2X9Z:X9Z\(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS
M9W-T<B`BX9Z;X9^!X9Z!XH"+X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-`IM<V=I9"`B4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM
M<V=S='(@(N&>G^&>F.&?D.&>F2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,C(*;7-G:60@(E-E="(*;7-G<W1R("+AGH#AGX;AGH[AGH_AGXLB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O
M<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I
M<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`BX9Z*X9^&X9ZAX9Z^
MX9Z$(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*
M;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X,`IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE
M;&QE<R(*;7-G<W1R("+AGI_AGKCAGI_AGY+AGJ#AGX+AGILB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$R"FUS9VED(")3:&]P<&EN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM
M<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS
M9W-T<B`BX9Z4X9Z$X9^2X9Z@X9ZVX9Z)(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO
M9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W-S,*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-@IM
M<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO
M=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W,0IM<V=I9"`B4VAO=R!U<&QO
M860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-`IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HT-S$*;7-G:60@(E-H<FEN:R(*;7-G<W1R("+AGI3AGH3AGY+AGIKAGKWA
MGHDB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C<V,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C@R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$P,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,#<U"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$P-`HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,S<*;7-G:60@(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`BX9Z?X9^!X9Z:X9^)X9ZVX9ZAX9^!X9ZBX9Z\
MX9Z3(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-PIM
M<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@
M(N&>H.&>C^&?DN&>D.&>F^&?@>&>@>&>MB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I
M=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R
M92(*;7-G<W1R("+AGI_AGKGAGH3AGY+AGJ#AGI3AGKOAGIKAGK@B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY,#`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$V"FUS9VED(")3:7IE(@IM<V=S
M='(@(N&>D>&?AN&>H.&?AB(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S
M='(@(N&>G^&?DN&>F^&>O.&>G.&?B>&>MN&>@N&>N"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(N&>G^&?DN&>F^&>O.&>G.&?
MB>&>MN&>D^&>N"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4U"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS
M9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@
M4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDP"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(E-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O
M;&]M;VX@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGI_AGKSAGJ'A
MGKSAGICAGXGAGKSAGI,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(N&>G^&>O.&>F.&?B>&>MN&>F^&>N"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$Y"FUS9VED(")3
M;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`BX9ZBX9ZVX9Z@X9^2X9Z:X9ZW
MX9Z`XH"+XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM
M<V=S='(@(N&>H.&?DN&>G^&>@.&>H.&?DN&>G^&?BN&>N.*`B^&>@>&>MN&>
MA.*`B^&>C^&?DN&>E.&>O.&>A"#AGI/AGK?AGH0@X9Z`X9^$X9^'X9Z?X9ZV
MX9^&X9Z$X9Z<X9ZWX9Z%XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H
M<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@
M8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I
M;F<B"FUS9W-T<B`BX9Z"X9Z8X9^2X9Z;X9ZVX9Z/(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B
M4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B4W!A:6XB"FUS9W-T<B`BX9ZBX9^!X9Z?X9^)X9^2X9Z4X9ZVX9Z)
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-PIM<V=I9"`B4W!A
M;2(*;7-G<W1R("+AGI_AGK;AGIKB@(OAGJ7AGH_B@(OAGI3AGK;AGI/B@(OA
MGH#AGK;AGIHB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@
M(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G
M:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(E-P
M;W)T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK
M82(*;7-G<W1R("+AGI_AGY+AGIKAGKCAGIOAGH3AGY+AGH#AGK8B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S$@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX-@IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BX9Z!X9^2X9Z3X9ZV
MX9Z/XH"+X9Z"X9^&X9Z:X9Z\(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8W"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#`R"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0
M<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(N&>G^&?DN&>
MD.&>MN&>D^&>E^&>MN&>EB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#@*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E
M970@061D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM
M<V=S='(@(N&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>AN&>O.&>CR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M.#$*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G
M:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+A
MGI3AGY+AGIKAGI+AGK;AGI/B@(OAGI3AGI$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S8@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S$V"FUS9VED(")3=6)M:70B"FUS9W-T<B`BX9Z*X9ZVX9Z`X9^+XH"+
MX9Z?X9^2X9Z3X9Z^(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B
M4W5B<V-R:7!T(@IM<V=S='(@(N&>HN&>@.&?DN&>G^&>FN*`B^&>C^&>O.&>
MA>*`B^&>@.&?DN&>FN&?A.&>F"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+A
MGH?AGX3AGH+AGH?AGY#AGIDB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D
M871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L
M971E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-U9&%N(@IM<V=S='(@(N&>G^&?BN&>O.&>BN&>A.&?BR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G
M:60@(E-U;6UA<GDB"FUS9W-T<B`BX9Z?X9Z$X9^2X9Z!X9^!X9Z4(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U
M;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3`*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`Y"FUS
M9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q,PIM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E-U;G-E
M=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(N&>
MHN&>@.&?DN&>G^&>FN*`B^&>C^&>O.&>A>*`B^&>F^&>OB(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.30*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`BX9Z"X9ZVX9^&X9Z1X9^2X9Z:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4W5R:6YA;64B"FUS9W-T<B`BX9Z?X9^*X9Z\X9Z:X9ZXX9Z.X9ZVX9Z8X9ZX
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G
M:60@(E-U<FYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("+AGI_AGY+AGISAGK;A
MGIOAGXOAGI3AGK;AGH\@X9Z3X9ZWX9Z$(.&>H.&?DN&>G^&>A.&?B^&>F.&?
MB>&>MN&>F>&?@>&>DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("+AGI_AGY+AGISAGK;AGJ#AGY+AGI_AGXKAGKCAGJ'AGH3A
MGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`BX9Z?
MX9^*X9Z[X9Z9X9ZBX9^"X9Z*(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z
M97)L86YD(@IM<V=S='(@(N&>G^&?DN&>G.&?BN&>N.&>GR(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE
M=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*
M;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER
M:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.
MX9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+(.&>G^&?BN&>
MN.&>FN&>N"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M
M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*
M;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"FUS9VED
M(")486)L92(*;7-G<W1R("+AGH_AGK;AGIKAGK;AGH0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED
M(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(N&>F^&>@.&?DN&>@>&>CN&?
MB.*`B^&>G^&>F.&?DN&>E.&>C^&?DN&>C^&>M^*`B^&>C^&>MN&>FN&>MN&>
MA"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")4
M86)L92!P<F]P97)T:65S(@IM<V=S='(@(N&>F^&>@.&?DN&>@>&>CN&?B.*`
MB^&>G^&>F.&?DN&>E.&>C^&?DN&>C^&>M^*`B^&>FN&>E.&>G^&?B^*`B^*`
MB^&>C^&>MN&>FN&>MN&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1A:7=A;B(*;7-G<W1R("+AGH_AGX/AGISAGXGAGK;AGI/AGXLB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I
M=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(N&>C^&>MN&>BN&>H.&?
MDN&>G^&?BN&>N.&>@N&>N.&>G^&?DN&>C^&>A.&?BR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`W,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV
M"FUS9VED(")487-K<R(*;7-G<W1R("+AGI?AGK;AGIKAGH#AGK?AGH7AGY+A
MGH4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM
M<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("+AGIOAGX'AGH'B@(OA
MGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,P,@IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C8*;7-G:60@(E1E;7!E<F%T
M=7)E(@IM<V=S='(@(N&>G^&>N.&>C^&>N^&>CN&?DN&>H.&>E^&>MN&>EB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3<*;7-G:60@(E1E
M;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP
M;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,S@*;7-G:60@(E1E>'0B"FUS9W-T<B`BX9ZBX9Z/X9^2X9Z0X9Z4X9Z1(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY
M(@IM<V=S='(@(N&>C^&?@N&>HN&>C^&?DN&>D.&>E.&>D2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G
M:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-PIM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`BX9Z0X9^#
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C8S"FUS9VED(")4
M:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E
M<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E
M;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*
M;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X
M.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I
M9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@
M=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4
M:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB
M5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-O;F9I<FTN<&AP.C(X"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!E;6%I;"!A9&1R97-S("5S(&AA<R!B965N(&%D9&5D('1O('EO
M=7(@:61E;G1I=&EE<RX@66]U(&-A;B!C;&]S92!T:&ES("(*(G=I;F1O=R!N
M;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z
M,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$W-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<P(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R.0IM<V=I9"`B5&AE(&9I
M;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z,3(P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I
M9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED
M("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X.#4*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z.30*;7-G:60@(E1H92!N97<@9G)O;2!A9&1R
M97-S(&-A;B=T(&)E('9E<FEF:65D+"!T<GD@86=A:6X@;&%T97(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G
M:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#<*;7-G:60@
M(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,Q,PIM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED
M(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@
M(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S
M=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G
M:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4T(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34*;7-G:60@(E1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C;VYF:7)M+G!H<#HQ-R!S97)V:6-E<R]C;VYF
M:7)M+G!H<#HR,0IM<V=I9"`B5&AE<F4@87)E(&YO(&5M86EL(&%D9')E<W-E
M<R!T;R!C;VYF:7)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HS-#4*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N
M=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@
M<WES=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3$W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T(@IM<V=S='(@(N&>F.&>MN&>D^*`B^&>@.&?AN&>H.&>N^&>
MG^*`B^&>F.&>O>&>F2#AGH#AGY+AGI/AGKOAGH3B@(OAGH#AGK;AGIKB@(OA
MGI3AGH3AGY+AGJ#AGK;AGHGB@(OAGI7AGY+AGI/AGX+AGH#B@(OAGIKAGI3A
MGI_AGXOB@(OAGI_AGK;AGIKB@(OAGI/AGX'AGX<B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$S.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DP(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8P"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-38U(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DV-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$S"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`X-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R,CD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,P(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S@Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(T"FUS9VED
M(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C0*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.3@*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C<*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#(Y"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DT"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I
M9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT
M-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3@R"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U,`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#,S('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("+AGI;AGX'AGIOB@(OA
MGISAGX'AGIOAGK;B@(LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`R"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HR,@IM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
MX9Z1X9^2X9Z:X9Z$X9^+XH"+X9Z1X9^2X9Z:X9ZVX9Z9XH"+XH"+XH"+XH"+
MX9Z6X9^!X9Z;XH"+XH"+X9Z<X9^!X9Z;X9ZVXH"+(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`BX9Z%X9^&X9Z.X9Z$XH"+X9Z'X9Z^X9Z$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET
M;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("+A
MGI'AGX4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C4R"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`S"FUS9VED(")4;V1A>2(*;7-G<W1R("+A
MGI#AGY+AGH3AGX/B@(OAGI/AGX'AGX<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3
M;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*
M;7-G<W1R("+AGH_AGKSAGJ#AGY+AGH+AGX0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(N&>C^&>O.&>@.&?@>&>H>&>MN&>HN&?
MBN&>O"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#4*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O;F=A(@IM<V=S='(@(N&>C^&>N^&>A.&>H.&?DN&>@N&?A"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM
M<V=I9"`B5&]P(@IM<V=S='(@(N&>@.&?AN&>EN&>O.&>FR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8X"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R
M("+AGI'AGY+AGIKAGKCAGI/AGKCAGHKAGK;AGHH@X9Z3X9ZWX9Z$XH"+XH"+
M(.&>C^&>O.&>E.&>MN&>H.&?DN&>@N&?A"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W.3@*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5N:7-I82(*;7-G<W1R("+AGI'AGKOAGIGAGH[AGX'AGI_AGXKAGK@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`BX9Z1X9Z]X9Z:
MX9Z"X9ZX(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(E1U
M<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(N&>D>&>O>&>FN&>@N&>N"`H
M25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T
M86XB"FUS9W-T<B`BX9Z1X9Z]X9Z"X9Z8X9^!X9Z3X9ZXX9Z?X9^2X9Z/X9Z$
MX9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>D>&>O>&>@"#AGI/AGK?A
MGH3B@(L@X9Z`X9^#X9Z`X9Z\X9Z?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5'5V86QU(@IM<V=S='(@(N&>D>&>N^&>F>&>G.&?B>&>MN&>F^&>N^&>F2(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U
M<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C8S"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E52
M3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")5
M4DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(N&>
MHN&?BN&>O.&>H.&?DN&>@N&>A.&?B^&>BN&>MB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`BX9ZBX9^*X9Z[X9Z9X9Z`X9^2X9Z:
MX9^"X9Z3(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#(R"FUS
M9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS.34@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDX(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`V,PHC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S-2!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-#`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,3<*;7-G:60@(E5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C0@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(W-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S
M<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(R."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#0S(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3,@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS,30*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R
M86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C`V(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-C4R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#$@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#8*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,30P(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*
M;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U-@IM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@X-PIM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-C<Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(W,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-C(P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS-#D@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M
M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3@Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR.3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,@IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E
M9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`BX9Z"
MX9Z\X9Z?XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z`X9^2X9Z:X9^$
MX9Z8(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD
M;R!#:&%N9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS
M9VED(")5;F9I;&5D(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>E.&>MN&>D^*`
MB^&>FN&?@.&>E.&>A>&?AB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y
M"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`BX9Z9X9Z\X9Z3X9ZX
MX9Z`X9Z\X9Z*("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D
M($%R86(@16UI<F%T97,B"FUS9W-T<B`BX9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+
MXH"+X9Z:X9Z]X9Z8(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN
M9V1O;2(*;7-G<W1R("+AGH7AGH#AGY+AGIKB@(OAGI?AGI;B@(OAGJ+AGH3A
MGXOAGH+AGY+AGIOAGX'AGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET
M960@4W1A=&5S(@IM<V=S='(@(N&>G^&>H.&>FN&>BN&?DN&>B^&>HN&>MN&>
MF.&?@>&>FN&>M^&>@"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3
M=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("+AGH#AGX3A
MGX?B@(OAGH;AGY+AGH3AGK;AGIGAGY?B@(OAGIKAGI3AGI_AGXOB@(OAGI_A
MGJ#AGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGICAGX'AGIKAGK?AGH`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX,PIM<V=I9"`B56YI=',B"FUS9W-T<B`BX9ZOX9Z`X9Z/X9ZV(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(N&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?BR(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U,@IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R
M<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(N&>
M@N&?DN&>F.&>MN&>D^*`B^&>B.&?DN&>F.&?A.&?AR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I
M9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S
M='(@(N&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>D>&>MN&>D^&?B^*`
MB^&>G^&>F.&?D.&>F2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*
M;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B
M"FUS9W-T<B`BX9Z5X9^2X9Z1X9Z[X9Z`XH"+X9ZAX9Z^X9Z$(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P
M<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@
M(N&>HN&?BN&>N^&>F>&>FN&?B>&>MN&>H.&?DN&>@N&>MN&>F2(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R
M(@IM<V=S='(@(N&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S8W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z"X9^2
MX9Z:X9Z4X9^+X9Z"X9^2X9Z:X9Z$XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2
MX9Z:X9Z^(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*
M;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-C0@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@
M(E5S97)N86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>HN&?DN&>
MD^&>@.*`B^&>E.&?DN&>FN&>OB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R("+AGHCAGY+AGICAGX3AGX?B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+A
MGIKAGK["H.&?EB(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*
M;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E
M;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A
M;B(*;7-G<W1R("+AGJ+AGXKAGKSAGJ#AGY+AGI_AGI3AGX'AGH+AGKCAGI_A
MGY+AGH_AGH3AGXLB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-S,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(W"FUS9VED(")686-A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-S`*;7-G:60@
M(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@
M(E9A;&ED:71Y(@IM<V=S='(@(N&>G^&>N^&>EN&>F^&>E^&>MN&>EB(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L
M=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(W-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L
M=65S(@IM<V=S='(@(N&>C^&>F.&?DN&>F^&?@R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y
M-`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`BX9Z<X9^)X9ZV
MX9Z3X9Z[X9Z9X9ZBX9ZVX9Z1X9Z[X9Z9(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S.`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`BX9ZB
MX9Z0X9^!X9Z:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(N&>G.&?@>&>CN&?@>&>H.&?DN&>G^&>N^&>F>&>HN&?@>&>H>&>
MMB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS
M9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H
M879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB
M"FUS9W-T<B`BX9Z`X9^&X9Z.X9^"(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(T,@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(N&>
M@.&>MN&>FN*`B^&>C^&?DN&>FN&>O>&>C^*`B^&>EN&>M^&>D^&>M^&>C^&?
MDN&>F>*`B^&>@.&?AN&>CN&?@B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y($AI
M9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,B"FUS9W-T<B`BX9Z8X9Z^X9Z;("5S(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@
M<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD
M<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6
M:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGISA
MGKCAGH?AGKCAGI,@X9Z?X9Z@X9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z8X9^!
MX9Z:X9ZWX9Z`(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@
M(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U-PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S
M='(@(N&>G.&?B>&>MN&>F^&>N.&>GR#AGI/AGK?AGH0@X9Z@X9^2X9Z<X9^*
MX9Z\XH"+X9Z1X9Z[X9Z9X9Z.X9ZV(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C0@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(N&>
MEN&?DN&>FN&>F.&>MN&>DR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-`IM<V=I9"`B5V5A=&AE<B!&
M;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#$Y"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS9VED
M(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(N&>G.&>M^&>E"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(N&>C^&?AN&>E.&>D^&?B^&>E.&>CN&?DN&>C^&>MN&>B2(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(E=E96ML>2(*;7-G<W1R("+AGIKAGK;AGIOAGXOB@(OAGI_AGI3AGY+A
MGHKAGK;AGJ#AGXTB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("+AGI_AGKSAGICB@(OAGI_AGY+A
MGISAGK;AGH+AGICAGI/AGXTB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+AGI_AGKSAGICB
M@(OAGI_AGY+AGISAGK;AGH+AGICAGI/AGXWB@(OAGICAGH#B@(OAGH#AGK;A
MGI/AGXL@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3$*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(N&>G^&>MN&>H.&>MN&>FN&?B>&>
MMN*`B^&>@>&>MN&>A.*`B^&>F^&>M^&>A2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A
M=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8R"FUS9VED(")7:&5R
M96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN
M<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("+AGI'AGI'AGKGAGH3B
M@(LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$X"FUS9VED(")7
M:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM
M<V=I9"`B5VED=&@Z(@IM<V=S='(@(N&>D>&>D>&>N>&>A"#AGY8B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(Y"FUS9VED(")7:6MI(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K
M;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V.`IM
M<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV.0IM<V=I9"`B5VES9&]M(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3(*;7-G:60@(E=I
M<VAL:7-T(@IM<V=S='(@(N&>E.&>B>&?DN&>A^&>N.*`B^&>E.&?DN&>FN&>
MMN&>D.&?DN&>D^&>MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HW,`IM
M<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G
M<W1R("+AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGH#AGI/AGY+A
MGIOAGX+AGH3B@(OAGI+AGY+AGISAGK[B@(OAGH#AGK;AGIHB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7
M;W)K(%!H;VYE(@IM<V=S='(@(N&>D>&>O.&>FN&>G^&?D.&>EN&?DN&>D>*`
MB^*`B^*`B^&>@.&>D^&?DN&>F^&?@N&>A.*`B^*`B^*`B^&>DN&?DN&>G.&>
MON&>@.&>MN&>FB(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y
M,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@
M<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(EE9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4T"FUS9VED(")965E9(@IM<V=S='(@(EE965DB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.0IM
M<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS
M9W-T<B`BX9Z4X9^2X9Z:X9Z%X9ZVX9^&X9Z&X9^2X9Z3X9ZVX9^&(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`BX9Z9X9^!X9Z8X9^"
MX9Z3(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV-`IM<V=I9"`B665S(@IM<V=S='(@(N&>E.&>MN&>D2_AGH7AGK;AGI\B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(U
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I
M9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M<&AP9W<N<&AP.C$Q-PIM<V=I9"`B66]U(&1I9"!N;W0@875T:&5N=&EC871E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8S
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#,*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB
M:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@:&%V92!R97%U97-T960@=&\@
M861D('1H92!E;6%I;"!A9&1R97-S(%PB)7-<(B!T;R!T:&4@;&ES="!O9B!Y
M;W5R("(*(G!E<G-O;F%L(&5M86EL(&%D9')E<W-E<RY<;B(*(EQN(@HB1V\@
M=&\@=&AE(&9O;&QO=VEN9R!L:6YK('1O(&-O;F9I<FT@=&AA="!T:&ES(&ES
M(')E86QL>2!Y;W5R(&%D9')E<W,Z7&XB"B(E<UQN(@HB7&XB"B))9B!Y;W4@
M9&]N)W0@:VYO=R!W:&%T('1H:7,@;65S<V%G92!M96%N<RP@>6]U(&-A;B!D
M96QE=&4@:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3DR
M"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-#<T"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V
M:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R
M;VTZ(&%D9')E<W,Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I
M9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>FN&>E.&>G^&?
MB^&>HN&?DN&>D^&>@"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K
M96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT
M<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M,3(V"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA
M;F=E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V
M,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS
M9W-T<B`BX9Z9X9Z\X9Z@X9^2X9Z"X9^$X9Z?X9^2X9Z;X9ZVX9Z<X9ZX(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I
M<F4B"FUS9W-T<B`BX9Z?X9^#(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(N&>H.&?DN&>G^&>MN&?AN&>E.&?BN&>N"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(N&>H.&?DN&>G^&?
MBN&>N.&>F.&>E.&>MN&>G.&?B>&?@2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HW,0IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I
M9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S
M+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@
M;V8@)7-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,34V,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34W
M"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM
M<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED
M(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO
M9R!I;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?3.&>A>&?@>&>
MB2`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED
M(")?3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C4*
M;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R
M.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G
M:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>
MG^&?DN&>@N&>MN&>F^&?B^*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>
MF^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>FB(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$R"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X-"!L:6(O0FQO8VLO;65T87(N<&AP
M.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(N&>F.&>M^&>D^*`
MB^&>HN&>MN&>A>*`B^&>E.&>A.&?DN&>@.&>ON&>C^*`B^&>K^&>@.&>G^&>
MMN&>FN*`B^&>F^&>D>&?DN&>DN&>E>&>FR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U
M="(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGK[AGH#B
M@(OAGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGI3AGHGAGY+AGH7AGKSAGILB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.34*;7-G
M:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G
M92!E<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGK;AGIKB
M@(OAGI3AGY+AGIKAGK[B@(OAGI3AGI/AGY+AGI'AGK;AGH_AGXOB@(OAGI;A
MGK;AGH#AGY+AGIGAGI3AGHGAGY+AGH?AGK8B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E
M<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGK;AGIKB@(OA
MGH#AGX;AGH[AGH_AGXOB@(OAGIKAGH7AGI/AGK;AGI_AGICAGY+AGI;AGY#A
MGI/AGY+AGI(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G
M<W1R("+AGI3AGK;AGH_AGXOB@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGI3AGY+A
MGIKAGI;AGY#AGI/AGY+AGI+B@(OAGI_AGX;AGH'AGK;AGI/AGXOB@(OAGI3A
MGX;AGI7AGKOAGH\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`BX9Z`
MX9^&X9Z@X9Z[X9Z?XH"+X9Z1X9^2X9Z:X9Z$X9^+X9Z1X9^2X9Z:X9ZVX9Z9
MXH"+X9Z1X9ZWX9Z3X9^2X9Z3X9Z3X9^0X9Z9(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8SHR.`IM<V=I9"`B961I="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT
M<GD@;F]T(&9O=6YD(@IM<V=S='(@(N&>FN&>@.*`B^&>F.&>M^&>D^*`B^&>
M@^&>ON&>B>*`B^&>DN&>MN&>C^&>N^*`B^&>E.&>B>&?DN&>A>&>O.&>FR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS
M9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@X,0IM<V=I9"`B9FEL92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$X-B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C,Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(F=U<W1I;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T.`IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U-PIM<V=I9"`B:&@B"FUS
M9W-T<B`B:&@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`BX9Z8X9ZW
MX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z(X9^2X9Z8X9^$X9^'XH"+
MX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I
M9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>
MG^*`B^&>E.&>B>&?DN&>A>&?@>&>B2_AGI3AGHGAGY+AGH7AGKSAGILB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B
M:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[
MX9Z?XH"+X9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZXXH"+X9Z!X9ZVX9Z$XH"+
MX9Z`X9^2X9Z:X9^%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-C@*;7-G:60@(FUM(@IM<V=S='(@
M(N&>F"[AGI@N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR
M.#8@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@
M(N&>B.&?DN&>F.&?A.&?AR(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ
M,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`BX9Z?X9ZWX9Z1X9^2X9Z2X9ZWXH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z*X9ZWX9Z?X9^!X9Z2(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM
M<V=I9"`B<&EX96QS(@IM<V=S='(@(N&>E^&>N.&>@.&>G^&?@N&>FR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[
MX9Z?XH"+X9Z6X9ZXXH"+X9Z%X9Z8X9^2X9Z$X9ZVX9Z9XH"+X9Z`X9^2X9Z3
MX9Z[X9Z$XH"+X9Z6X9ZWX9Z2X9ZXX9Z`X9ZVX9Z:(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G)I<VEN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("+AGICA
MGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGIKAGH#B@(OAGI_AGX'AGISAGK;B@(OA
MGI3AGK;AGI,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,@IM<V=I
M9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS
M,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@
M(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM
M<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`B^&>E.&?DN&>FN&>EN&?D.&>D^&?
MDN&>DB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(X"FUS9VED
M(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(N&>E.&>FN&>MN&>A^&?D.&>F>*`B^&>E.&>CN&?DN&>BN&?A.&?
MA^&>HN&>MN&>G^&>D^&?DN&>DR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S$*;7-G:60@(G1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O:&]R9&4N<&AP.C(W.0IM<V=I9"`B=6YK;F]W;B!E<G)O<B(*;7-G
M<W1R("+AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXOB@(OAGH#AGX;A
MGJ#AGKOAGI\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W
M"FUS9VED(")U;FYA;65D(@IM<V=S='(@(N&>@N&?DN&>F.&>MN&>D^*`B^&>
MB.&?DN&>F.&?A.&?AR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@(G<Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P;R]H95])3"YP;P``````````````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C`R,#8T`#$P-3$U-#,Q,#8S`#`Q
M-C,U-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C($AE8G)E=R!T<F%N<VQA=&EO;G,@9F]R($AO<F1E('!A8VMA9V4N"B,@
M0V]P>7)I9VAT("A#*2`R,#`V($UA='0@4V5L<VMY(#QS96QS:WE`8V]L=6UB
M:6$N961U/@HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($%U=&]M871I
M8V%L;'D@9V5N97)A=&5D+"`R,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C(M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#(M,#<@,#0Z,#@M,#4P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP,BTP-R`P-#HP."TP-3`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($UA='0@4V5L<VMY(#QS96QS:WE`8V]L=6UB:6$N961U/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]551&+3A<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S@V"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,X,0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,X,PIM<V=I9"`B("AT;VUO<G)O
M=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M.0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,U,PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY
M"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C$P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,#,*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU,R!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F
M34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C(V-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E
M>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S
M="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0Q(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,SD@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#0U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($U"(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y
M,"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<T-PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0S-"!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S$@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-S<@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*
M(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U
M:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE
M<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"
M97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P
M<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`R"FUS9VED
M("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C`U"B,L('!H<"UF;W)M870*
M;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<U,"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(Y-`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,S8*;7-G:60@(BTM('-E;&5C="`M+2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C4*;7-G:60@(C$R
M($AO=7(@1F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HR-`IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$S,0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB02!M97-S86=E(&AA
M<R!B965N('-E;G0@=&\@7"(E<UPB('1O('9E<FEF>2!T:&%T('1H:7,@:7,@
M<F5A;&QY('EO=7(@(@HB861D<F5S<RX@5&AE(&YE=R!E;6%I;"!A9&1R97-S
M(&ES(&%C=&EV871E9"!A<R!S;V]N(&%S('EO=2!C;VYF:7)M('1H:7,@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@
M(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!
M8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O
M<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0IM<V=I
M9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G
M:60@(D%D9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R,B!A
M9&UI;B]G<F]U<',N<&AP.C(R,PIM<V=I9"`B061D($-H:6QD($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H
M:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HW,@IM<V=I9"`B061D($-O;G1E;G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E
M.B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q-B!A9&UI;B]G
M<F]U<',N<&AP.C(Q-PIM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES
M<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HR.0IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-3@*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I
M9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@
M=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,P"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED
M(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#0Y"FUS9VED(")!9&1R97-S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#@*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R("+7H=>DUZ@@UYO7JM>5UY'7E=>J(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*
M;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(D%D<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("+7D->DUY+7
MH->9UZ'7JM>?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,0IM<V=I9"`B06QB86YI82(*;7-G<W1R
M("+7D-><UY'7H->9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T"FUS9VED(")!;&=E<FEA(@IM
M<V=S='(@(M>0UYS7DM>HUYG7E"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N
M=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS
M9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I
M9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HS,B!A9&UI;B]G<F]U<',N<&AP.C(R,`IM<V=I9"`B
M06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP
M:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W
M"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<Y"FUS9VED(")!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4S-PIM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-3$X"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA
M=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!
M;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL
M(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#$*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-PIM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38P"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!;F1O<G)A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0*;7-G:60@(D%N9V]L82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N
M>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(M>9UY'7J=>JXH"3UY#7
MH->8UY#7J->GUYC7F=>GUY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y"FUS9VED(")!;G1I9W5A
M(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HS,R!A9&UI;B]T96UP;&%T97,N<&AP.C<S"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ-`IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G
M:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI
M;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S.2!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#$*;7-G:60@(D%P<')O>&EM
M871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED(")!<F-H:79E($YA
M;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8*;7-G:60@(D%R9V5N=&EN82(*;7-G
M<W1R("+7D->HUY+7H->8UYG7H->4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,@IM<V=I9"`B07)M
M96YI82(*;7-G<W1R("+7D->HUY[7H->9UY0B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")!<G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,`IM<V=I9"`B07)U8F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S0*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I
M8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#8*;7-G:60@(D%S<VEG;FUE;G0@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<S"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.`IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#8*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3(*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*;7-G:60@
M(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`BUY#7E=>A
MUYC7J-><UYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@(D%U<W1R:6$B"FUS9W-T
M<B`BUY#7E=>AUYC7J->9UY0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,S$V"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S$*;7-G:60@(D%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,C,T"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O9G1P+G!H<#HU-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C$P-`IM<V=I9"`B075T:%]I;6%P.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S,*;7-G:60@(D%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P
M,0IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-@IM<V=I9"`B075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z.3(*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DX"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#`T"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-C(*;7-G:60@(D%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#8*
M;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-
M05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3@R"FUS
M9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V
M,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW
M-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@
M(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,@IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@T"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`BUY#7F=>9
MXH"3UY'7E->>UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X"FUS9VED(")"86AR86EN(@IM<V=S
M='(@(M>1UY?7J->9UYG7GR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S
M"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,T"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(M>1UZ#7DM><UY/7
MJ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S,*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3D*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#D*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("+7D=><UY+7F=>4(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@(M>1UYS7F=>6(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,`IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,0IM<V=I
M9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S(*;7-G
M:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`BUY'7E=><
MUYG7D=>9UY0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS
M9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,@IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,3`Q"FUS9VED(")";W1H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#@*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(M>1
MUY77IM>5UY77H->4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(R"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0T"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`BUY'7J->6UYG7G"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$W"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R
M:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`BUY'7J->5UZ#7F=>9(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-PIM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R
M("+7D=>5UZC7E=>@UY/7F2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-C<*;7-G:60@(D--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G
M:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34V"FUS9VED(")#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@W(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#4Q"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M-C0*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#`*;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C@*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(M>GUY[7D=>5
MUY/7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,`IM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B
MUZ?7GM>HUY77GR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C$*;7-G:60@(D-A;B=T(&%D;6EN
M:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,S,"!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR-#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3$*;7-G:60@(D-A;F%D82(*;7-G<W1R("+7I]>@UY/7
ME"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,"!A9&UI;B]U<V5R+G!H<#HQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$R('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(M>IUZ#7
ME"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4R"FUS9VED
M(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*;7-G:60@
M(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY
M,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@
M<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C8Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C(R"FUS9VED
M("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G
M92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(M>GUZ37E"#7E=>HUY/7E"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R
M:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM
M<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,U"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#96QT
M:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-`IM<V=I9"`B0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(M>4UZ?7E->9UYS7F=>9UY0@UY37GM>H
MUYO7EN*`D]>0UZ37J->9UZ?7H->9UZHB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@
M(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0
M;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$*;7-G:60@(D-H860B
M"FUS9W-T<B`BUZ;7DR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H
M86YG92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B
M(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU.0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`BUZ;7
MF=><UYDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Q"FUS9VED(")#:&EN82(*;7-G<W1R("+7H=>9
MUY\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A"
M:6<U*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW
M"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S$*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@
M(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R
M960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8*;7-G:60@(D-H<FES
M=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.CDW.2!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(M>IUY[7F=>=(->1
MUY37F=>HUYTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C8*;7-G:60@(D-L96%R(%%U
M97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@
M9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV
M,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G
M:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S
M='(@(M>IUY[7F=>=(->>UZ+7E=>@UZ#7F=>=(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,@IM<V=I
M9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR-`IM<V=I9"`B0V]L;&%P<V4@
M4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R
M9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R"FUS9VED(")#;VQO;6)I82(*
M;7-G<W1R("+7I]>5UYS7E=>>UY'7F=>4(@H*(SH@;&EB+T)L;V-K+V-O;&]R
M+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O
M;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S,W('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#,Y"FUS9VED(")#;VQO=7(@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34T"FUS9VED(")#;VQU;6X@=&ET;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#`*
M;7-G:60@(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C,*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C$X"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S`*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B
M0V]M<&%N>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S8*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDP"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C$*;7-G:60@(D-O;F1I
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*
M;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/
M=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4R"FUS9VED(")#;VYF:7)M
M(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z-#`W"FUS9VED(")#;VYF:7)M(&YE=R!E;6%I;"!A9&1R
M97-S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(M>GUY77H->2UY4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S"FUS9VED(")#;VYG;RP@5&AE
M($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A
M:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX-30*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#DV"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F
M:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C<U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,R!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU.`IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B
M0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I
M9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("+7
MI]>5UZ'7F->4(->HUYG7I]>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-PIM<V=I9"`B0V]T92!D
M)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$W,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@
M8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,R!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,X,0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S
M<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX
M-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q
M.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@
M9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I
M9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I
M<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4Y(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,PIM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HQ
M,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O
M<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I
M9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM
M<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(W"FUS
M9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B
M0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M-@IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E
M('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,C,*;7-G
M:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T"FUS9VED
M(")#=6)A(@IM<V=S='(@(M>GUY77D=>4(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R<F5N="!397-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO
M8VLO=&EM92YP:'`Z,S4*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R<F5N="!5<V5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P"FUS9VED(")#
M=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED
M(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<*;7-G:60@
M(D-Y<')U<R(*;7-G<W1R("+7I]>DUZC7F=>AUYG7GR(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@X"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X"FUS9VED(")#>F5C:"!297!U
M8FQI8R(*;7-G<W1R("+7IM>;UYG7E"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-30@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(D1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#,*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9&%T871R964N<&AP.C8S"FUS9VED(")$871A5')E92!"<F]W<V5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*
M;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,#8*;7-G:60@(D1A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A
M=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P,`IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$T"FUS9VED(")$87DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N
M=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L
M:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM
M<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M261E;G1I='DO261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT
M:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PIM
M<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S@*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S`@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,2!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*;7-G
M:60@(D1E;&5T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#
M96QL(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DW(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$
M96QE=&4@3&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*
M;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE
M=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@
M(D1E;&5T92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#<*
M;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E(')O=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T
M960@:61E;G1I='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DU"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S$*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`BUY/7H->9UY0B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR-PIM<V=I9"`B1&5S8W)I8F4@
M=&AE(%!R;V)L96TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.30R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DW"FUS9VED(")$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,U"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(R.0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`V"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C$*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I
M<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C
M=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDT"FUS9VED(")$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.3<*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,`IM<V=I
M9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`*;7-G:60@(D1J:6)O=71I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,@IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,PIM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(M>4UZC7I->5UY'7G->9UZ?7E"#7E->3UY77GM>9UZ#7F=>GUZ#7F=>J(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX.`IM<V=I9"`B1&]N)W0@
M:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3<*;7-G:60@(D1O=VYL
M;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED
M(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R
M:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3$U"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B1'EN86UI
M8R!-86EL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%
M36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC
M:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4*;7-G
M:60@(D5C=6%D;W(B"FUS9W-T<B`BUY#7I]>5UY77D]>5UZ@B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!"
M;&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y-B!A9&UI
M;B]G<F]U<',N<&AP.C(R-`IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M-@IM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,`IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<*;7-G
M:60@(D5G>7!T(@IM<V=S='(@(M>>UZ;7J->9UYTB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<*
M;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(M>0UYSB@)/7H=><UY77E=>3
MUY77J"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM
M<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<W"FUS9VED(")%;6%I;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8Y"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,3`*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B16UA:6P@861D<F5S
M<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z-#4P"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M=&\@8V]N9FER;2!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y.3<*;7-G:60@(D5M86EL('=I=&@@8V]N9FER
M;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S`Q"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%
M;7!T>2!R97-U;'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-34T"FUS9VED
M(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3(Q"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#0*;7-G:60@(D5N9"!Y
M96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG
M+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#DT"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY.0IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.0IM<V=I9"`B17)I=')E82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4S"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-#$*;7-G:60@(D5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L
M971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-@IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R("+7D->JUYG7E=>DUYG7E"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R
M;W!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@
M,34@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#`*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I
M9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z,3`P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@
M-2!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#(@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ
M,#,*;7-G:60@(D5V97)Y(&AO=7(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C0X(&%D;6EN+W!H<'-H96QL+G!H<#HW.2!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(U"FUS9VED(")%>&5C=71E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,0IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP
M:'`Z,C0U"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z,3`Q"FUS9VED(")&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Y"FUS9VED(")&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4R(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#DS"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@T"FUS9VED(")&86QK;&%N9"!)<VQA;F1S
M("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-@IM<V=I9"`B1F%R
M;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-C4*;7-G:60@(D9A>&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(U"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3(*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0P"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S"FUS9VED(")&
M:6II(@IM<V=S='(@(M>DUYG7DM>9(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0S,`IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDX.`IM
M<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30Y-`IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`V"FUS
M9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")&:6QT97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(*;7-G:60@(D9I;FQA;F0B"FUS9W-T
M<B`BUZ37F=>@UYS7H->3(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM
M<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1
M=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-34*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,P
M"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`BUZ+7J->DUYPB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,C8P"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B
M1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S0V"FUS9VED(")&;W)E8V%S="`H5$%&*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S<*
M;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB
M;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C
M:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY
M-`IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#4*;7-G:60@(D9O<FUS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR-@IM<V=I9"`B
M1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,3`T"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(D9O<G1U;F5S
M(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W
M-@IM<V=I9"`B1F]R=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,3@*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G
M:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@W"FUS9VED(")&<F%N8V4B"FUS9W-T<B`BUZ;7J->D
MUZHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$*
M;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(R"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-3(*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.`IM<V=I
M9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C0R"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C$*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@X"FUS9VED(")'86)O;B(*;7-G<W1R("+7DM>1UY77GR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDV"FUS9VED(")'86UB:6$B"FUS9W-T<B`BUY+7GM>1UYG7E"(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ-@IM<V=I9"`B
M1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,`IM<V=I9"`B
M1V5O<F=I82(*;7-G<W1R("+7DM>5UZC7DM>9UY0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(M>2UZC7GM>@UYG7E"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3,*;7-G:60@(D=H86YA(@IM<V=S='(@(M>2UZ#7E"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30*
M;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T
M<B`BUYS7FB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B
M1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3,S"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G
M;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S8*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,`IM<V=I9"`B1W)E96-E(@IM<V=S='(@(M>9UY77
ME=>?(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(D=R965K
M("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU"FUS9VED(")'
M<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.0IM<V=I9"`B1W)E;F%D
M82(*;7-G<W1R("+7DM>HUZ#7D]>4(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-S@*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I
M9"`B1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@*;7-G:60@(D=U861E
M;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,*;7-G:60@(D=U86TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#(*;7-G:60@(D=U871E;6%L82(*;7-G<W1R
M("+7DM>5UY#7F->>UYS7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3,*;7-G:60@(D=U97-T
M8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW"FUS9VED(")'=6EN96$B"FUS
M9W-T<B`BUY+7F=>@UY#7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4*;7-G:60@(D=U>6%N
M82(*;7-G<W1R("+7DM>9UY#7H->4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@
M:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HQ-30*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`*;7-G:60@(DAA:71I(@IM<V=S='(@
M(M>4UY#7F=>8UYDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#4*;7-G:60@(B(*(DAA=F4@82!B=71T
M;VX@:6X@=&AE('1O;VQB87(@=&AA="!P;W!S('5P(&$@=VEN9&]W('=I=&@@
M<W!E8VEA;"!C:&%R86-T97)S/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,C,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W"FUS
M9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`BUZ'7E=>DUZKB@)/7
MJ->BUY[7F=>=(->BUY;7E"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR
M"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ.#$@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE
M;'`N<&AP.C$X,@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP
M;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R("+7
MHM>6UZC7E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-SD*;7-G:60@(DAE;'!E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@
M(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`*;7-G
M:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUE;G4O
M;65N=2YI;F,Z-PIM<V=I9"`B2&]?;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,PIM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS
M9W-T<B`BUY77F->9UZ?7GR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,34U-0IM<V=I9"`B2&]M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*
M;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@
M4&AO;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X"FUS9VED(")(;VYD=7)A
M<R(*;7-G<W1R("+7E->5UZ#7D]>5UZC7H2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-@IM<V=I
M9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*
M;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E
M<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`R"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!8
M34P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM
M<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS
M*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#(*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(M><UY?7E=>J
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,PIM<V=I9"`B
M2'5M:61I='DZ("(*;7-G<W1R("(ZUYS7E]>9UZHB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#8*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3$*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`BUY37E=>@UY+7
MJ->9UY0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,T
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,CDV(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C0Q(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU
M"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,`IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("+7D->9UZ'7G->@
MUY,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@
M=VET:"!T97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DU"B,L('!H<"UF
M;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO
M=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G
M92!0<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Y
M"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-30*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-R!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S
M-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-@IM<V=I9"`B26YD:6$B"FUS9W-T<B`BUY37E=>3UY4B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3(*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("+7
MD->9UZ#7D]>5UZ#7EM>9UY0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(DEN9F]R;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,C(*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T.0IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM
M<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M
M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E
M<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R
M;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H
M92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T
M+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y
M($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<Y"FUS9VED("));G1E
M9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,S<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@
M(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED
M("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,38V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,P-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("))
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@
M(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN
M=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W,`IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME
M>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V-`IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR
M-@IM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-@IM<V=I9"`B
M26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38X"FUS9VED("));G9A;&ED('!R;V1U8W0@
M8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3`W-2!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3@*;7-G:60@
M(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B
M26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED
M("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,W,PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV.#`*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(M>0UYG7J->?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X"FUS9VED("))<F%Q(@IM
M<V=S='(@(M>BUYG7J->G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S"FUS9VED("))<F5L86YD
M(@IM<V=S='(@(M>0UYG7J-><UZ#7DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I
M9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T
M"FUS9VED("))<W)A96PB"FUS9W-T<B`BUYG7J=>!UZC7D-><(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C$*;7-G:60@(DET86QY(@IM<V=S='(@(M>0UYG7F-><UYG7E"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R("+7DM>>UYG7F=>G
MUY0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4*;7-G
M:60@(DIA<&%N(@IM<V=S='(@(M>9UZ37GR(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DS"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED
M(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T"FUS9VED(")*;W)D
M86XB"FUS9W-T<B`BUYG7J->3UY\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I
M9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,`IM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*;7-G:60@
M(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V"FUS9VED
M(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-C,*;7-G:60@(DME97`@;W)I9VEN86P_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-@IM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`BUZ?7H->9UY0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@V"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-PIM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@
M3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5
M<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0X"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M.0IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R"FUS
M9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,*;7-G:60@(DMO<F5A+"!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-`IM<V=I9"`B2W5W86ET(@IM<V=S='(@(M>;UY77E=>9UYG7JB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<U"FUS9VED("),86YG=6%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA
M;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B3&%S="!5
M<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED("),
M87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8*;7-G
M:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#D*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*;7-G:60@(DQA>6]U
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.`IM<V=I9"`B3&5B86YO;B(*;7-G
M<W1R("+7G->1UZ#7E=>?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"FUS9VED("),969T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3(*;7-G:60@(DQE9G0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,#@*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,@IM<V=I9"`B3&EB97)I82(*;7-G<W1R("+7G->9UY'7
MJ->9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H
M:7)I>6$B"FUS9W-T<B`BUYS7E=>1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P"FUS9VED("),
M:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H
M="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS
M9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B
M3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED
M("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#(R"FUS9VED("),:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I
M9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X.#,*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E
M>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*
M;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS9VED("),:7-T($1A
M=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED("),:7-T(%1A8FQE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P
M.0IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`T"FUS9VED("),:7-T+4AE;'`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU,3$*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU,#<*;7-G:60@(DQI<W0M3W=N97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU,#@*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-@IM<V=I9"`B3&ES="U3=6)S
M8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU,#4*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G
M:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4R"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-`IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@
M(DQO861I;F<N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N
M9"!4:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C<W(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HR,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP
M.C$X."!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.#(*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-0IM<V=I9"`B
M3&]G(&EN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DT
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS9VED("),
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,PIM
M<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-0IM<V=I9"`B3'5X96UB;W5R
M9R(*;7-G<W1R("+7G->5UYO7H=>>UY'7E=>HUY(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.3<*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@
M(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-PIM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34S"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(M>>UY/7DM>AUZ?7J"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B36%G:6,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDP"FUS9VED(")-86EL(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU-#4*;7-G:60@
M(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI
M;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L87=I
M(@IM<V=S='(@(M>>UYS7E=>5UYDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<*;7-G:60@(DUA
M;&%Y<VEA(@IM<V=S='(@(M>>UYS7F=>9UY;7F=>4(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T
M"FUS9VED(")-86QD:79E<R(*;7-G<W1R("+7E->0UYG7F=>=(->4UY[7G->3
MUYG7E=>5UYG7F=>=(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T"FUS9VED(")-86QI(@IM<V=S
M='(@(M>>UYS7F2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,@IM<V=I9"`B36%L=&$B"FUS9W-T
M<B`BUY[7G->8UY0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G
M:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34X"FUS9VED(")-
M87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-S,*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G
M:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3(*;7-G:60@(DUA<G-H86QL($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y"FUS9VED(")-87)T:6YI<75E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS
M9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P
M"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(M>>UY#7E=>HUYG7F->@UYG7
ME"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,PIM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(M>>
MUY#7E=>HUYG7IM>9UY77H2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q.`IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX
M-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,*;7-G:60@(DUA>6]T
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS
M9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D
M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(V,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8P,@IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C0R"FUS9VED
M(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$R-`IM<V=I9"`B(@HB365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U.`IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<@9G)A;65W;W)K+U)00R]24$,O>&UL
M<G!C+G!H<#HX,0HC.B!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#@@
M9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C@Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B365T<FEC(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-@IM<V=I9"`B365X:6-O(@IM<V=S='(@
M(M>>UYO7H=>9UZ?7E2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U"FUS9VED(")-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM<V=I9"`B
M36ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C(*;7-G:60@(DUI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q-`IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,S@*;7-G
M:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S,PIM<V=I9"`B36ER<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@;75S
M="!G96YE<F%T92!I="!B969O<F4@=7-I;F<@=&AI<R!A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@
M<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@
M36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*;7-G:60@(DUO9&EF:65D($1A
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,`IM<V=I
M9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Y"FUS9VED(")-;VYA8V\B"FUS9W-T<B`BUY[7E=>@UZ?7E2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`BUY[7E=>@UY+7E=><
MUYG7E"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3(*;7-G:60@
M(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38Q"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD
M<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#@*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B
MUY[7J->5UZ?7E2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@
M(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R
M"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M.`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,C<*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R.`IM<V=I9"`B36]V92!U<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@*;7-G:60@(DUO>F%M8FEQ=64B"FUS
M9W-T<B`BUY[7E=>6UY[7D=>9UZ<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3DR"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-C`*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C4P"FUS9VED(")-=6QT
M:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0R,PIM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HV-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HS-0IM<V=I9"`B37D@4&]R=&%L($QA
M>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34*;7-G:60@(DUY86YM87(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B3F%M
M92(*;7-G<W1R("+7J=>=(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y"FUS9VED(").86UI8FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.`IM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<W"FUS9VED(").97!A;"(*;7-G<W1R("+7H->D
MUYPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(M>4UY77G->@UY,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,PIM<V=I9"`B3F5T:&5R;&%N9',@
M06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T
M"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I
M9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A
M<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I
M;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-PIM<V=I9"`B3F5T
M=V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C4@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDW"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C@T"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HX.`HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z,3$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-@IM<V=I9"`B3F5W(%5S
M97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P"FUS
M9VED(").97<@6F5A;&%N9"(*;7-G<W1R("+7H->9UY7B@)/7EM>9UYS7H->3
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").
M97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C(T.0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O
M<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D
M;VXG="!M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L
M86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,P-0IM<V=I9"`B3F5W<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(Q"FUS9VED(").97=S9W)O=7!S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C0Q('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U"FUS
M9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT
M/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0*;7-G:60@(DYI8V%R86=U82(*
M;7-G<W1R("+7H->9UZ?7J->2UY77D->4(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q"FUS9VED
M(").:6=E<B(*;7-G<W1R("+7H->9UY;7J"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,PIM<V=I
M9"`B3FEG97)I82(*;7-G<W1R("+7H->9UY+7J->9UY0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<R"FUS9VED(").:6=H="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-SD*;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV.`IM<V=I
M9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I
M9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I
M9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-C<*;7-G:60@(DYO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C
M:&%N9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-CD*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@S,PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-CDX"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<T-PIM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C
M<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HY,C0*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").
M;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$R,2!L:6(O0FQO8VLO;65T87(N<&AP.C$S-0HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*;7-G:60@(DYO(&QO8V%T:6]N(&ES
M('-E="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,@IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W
M"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(DYO(&]F9F5N<VEV92!F
M;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y3
M4TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C
M97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G
M:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@Q,PIM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R
M871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I
M9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-38S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$S,0IM<V=I9"`B3F\@=&5M<&]R87)Y
M(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM
M<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P(&9R
M86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ-S4*;7-G:60@(DYO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY-S8*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DW"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#$T"FUS9VED(").;R!V86QU97,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-R!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDU"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#4*;7-G:60@(DYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H
M=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<R"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U.`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-@IM<V=I9"`B3F]R=V%Y(@IM<V=S
M='(@(M>@UY77J->5UY77DM>9UY0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0T,0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"FUS9VED(").;W0@:6UP;&5M
M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,R!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S0@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(U,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C8Y(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C,*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,X,"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#$S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HT-S,@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4U,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C(Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HV,S@*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<Q-B!F
M<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z.#(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O:&]R9&4N<&AP.C$S,2!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP
M:'`Z,34Q"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HQ-S`@9G)A
M;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$X.0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]H;W)D92YP:'`Z,C`W(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H
M<#HR,C<*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C,S,`HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`X,0HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(").;W1E<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G
M:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I
M9"`B3F]V96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S,*;7-G:60@(DYU;6)E<B!O9B!C:&%R
M86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#4S('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,CD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30U,2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W-0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`X"FUS
M9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3<*;7-G:60@(D]F9F5N<V4@
M9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#(*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,0IM<V=I9"`B3VUA;B(*;7-G<W1R("+7HM>5UY[7
MD->?(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HQ
M,#`*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW.0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-C0*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*
M(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C0P"FUS
M9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q
M"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(M>0UZ37J=>HUY77F=>5UZHB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S(@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A
M;FES871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I
M9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$S-`IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
MUY#7E]>H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B
M3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C@P"FUS
M9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I
M9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R
M>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS
M9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV-@IM<V=I9"`B4$A0($-O9&4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C$X"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G
M:60@(E!-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")0
M32!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#<*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(M>DUZ?7F=>A
MUZK7GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.30*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3(*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED(")086YA
M;6$B"FUS9W-T<B`BUZ37H->>UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4*;7-G:60@(E!A
M<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-0IM<V=I
M9"`B4&%R86=U87DB"FUS9W-T<B`BUZ37J->2UY77D->9UYDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#(V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-CD@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")087-S=V]R9"(*;7-G<W1R
M("+7H=>9UZ'7GM>0(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U-PIM<V=I9"`B4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V,0IM<V=I
M9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R
M9#HB"FUS9W-T<B`BUZ'7F=>AUY[7D#HB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+7H=>9
MUZ'7GM>0.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`T,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q-R!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A
M<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED
M(")096]P;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<
M(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-38V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C4Y(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3<*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`X(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,0IM<V=I
M9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O
M<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,*;7-G:60@(E!E<G4B
M"FUS9W-T<B`BUZ37J->5(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P
M"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-@IM<V=I9"`B
M4&AI;&EP<&EN97,B"FUS9W-T<B`BUZ37F=><UYG7I->9UZ#7F=>9UYTB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3`Q"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G
M:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E
M(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,`IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,#4*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-34*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S='(@(M>DUY77G->9UY\B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3`*;7-G:60@
M(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,*;7-G:60@(E!O<G1U
M9V%L(@IM<V=S='(@(M>DUY77J->8UY77DM><(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,0IM<V=I9"`B4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O;&1A<"YP:'`Z,3,S"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")0<F5S<W5R92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0IM<V=I9"`B4')E<W-U
M<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(R.0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C`T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,U,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-@IM<V=I9"`B
M4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L
M96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS
M9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#4*;7-G:60@(E!R;VIE8W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@W"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI
M8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U
M"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ"FUS9VED(")0=65R=&\@4FEC;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-@IM<V=I9"`B46%T87(B"FUS9W-T<B`BUZ?7F->H(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C8Q"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-S(*
M;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM
M<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!T;R!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS
M9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED
M(")296%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G
M:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G
M:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY-`IM<V=I9"`B4F5F<F5S:"!R871E
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0R"FUS9VED(")296QA=&EO;G-H
M:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS
M9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,S@*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED
M(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,R!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(R"FUS9VED(")296UO=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4V,0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")2
M96UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S."!F<F%M97=O<FLO
M4E!#+U)00R]P:'!G=RYP:'`Z,3<S"FUS9VED(")297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34P"FUS9VED(")2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<V(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3,P"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#,Y(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-S`T"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-3,@9G)A;65W;W)K+U9&4R]61E,O
M:&]R9&4N<&AP.C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S,T"FUS9VED(")297%U:7)E9"!&:65L
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS-#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S$Y('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW.`IM<V=I9"`B
M4F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R
M(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C@*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C8@861M:6XO<&AP<VAE;&PN<&AP.C8Y(&%D
M;6EN+W-Q;'-H96QL+G!H<#HV-`IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM
M<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DW"FUS9VED(")2975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM
M<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,PIM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*;7-G:60@(E)I
M9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,30*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$P"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX
M"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(M>HUY77GM>@UYG7E"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*;7-G:60@
M(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,0IM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R-PIM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*
M;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3@*;7-G:60@(E)U;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY"FUS9VED(")2=7-S:6%N($9E9&5R
M871I;VXB"FUS9W-T<B`BUZC7E=>AUYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`*;7-G
M:60@(E)W86YD82(*;7-G<W1R("+7J->5UY#7H->3UY0B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HX,@IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3(W"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ.0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*
M;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-`IM<V=I9"`B
M4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%
M4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,
M(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#<*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S$*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,SD*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-`IM<V=I9"`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B
M4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-@IM<V=I9"`B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V
M:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D:2!!
M<F%B:6$B"FUS9W-T<B`BUZ+7J->1(->4UZ'7HM>5UY/7F=>J(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q-0IM<V=I9"`B4V%V92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO
M=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E-C:65N8V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E
M87)C:"(*;7-G<W1R("+7E]>9UZ37E=>I(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,S-@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDV-@IM<V=I9"`B4V5L
M96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#<*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G
M:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@
M;W=N97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A
M('5S97(@=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!A;&PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-`IM<V=I
M9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S4*;7-G
M:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B4V5L96-T
M(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W
M"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDR"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Q"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#0T"FUS9VED(")396YD(%--4R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S"FUS9VED(")396YE9V%L(@IM<V=S
M='(@(M>AUZ#7DM><(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C@*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*
M;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R
M:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34T"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,C8*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED
M(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,R,@IM<V=I9"`B4V5T(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO
M;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U
M(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA
M="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES
M<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-0IM<V=I9"`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@P"FUS9VED(")3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(M>0
MUYG7F>*`D]>AUYG7F=>IUYPB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3$Y"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B4VAO<G0@4W5M;6%R
M>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS
M9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-S,*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@
M;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P-@IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R.0IM<V=I9"`B4VAO=R!T86)L92!O<&5R
M871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM
M<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W,0IM<V=I9"`B
M4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*
M;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@
M3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW
M,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$*;7-G:60@(E-I97)R82!,96]N
M92(*;7-G<W1R("+7I]>9UYG7J->4(-><UYG7D->5UY\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8W"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!
M;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-@IM<V=I9"`B4VEN
M9V%P;W)E(@IM<V=S='(@(M>AUYG7H->2UZ37E=>H(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(T,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C4T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C,*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-@IM<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM
M<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$P"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X
M"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-@IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`R"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-`IM<V=I9"`B4V]M86QI82(*;7-G<W1R("+7H=>5UY[7G->9
MUY0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E-O;F=S
M("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDQ.0IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(M>3
MUZC7E=>=XH"3UY#7I->HUYG7I]>4(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.38*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#$*;7-G:60@(E-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G
M:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P
M86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@
M(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$Y"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4U"FUS9VED(")3<&%C:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#`*;7-G:60@(E-P86EN(@IM<V=S='(@(M>AUZ37
MJ->3(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-PIM<V=I9"`B
M4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*
M;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B
M4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G
M:60@(E-P;W)T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$*;7-G:60@(E-R
M:2!,86YK82(*;7-G<W1R("+7H=>HUYD@UYS7H->GUY0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S$@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M-@IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8W"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`R"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,`IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#@*;7-G:60@(E-T
M;W)A9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X.#$*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@
M(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S8@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S$V"FUS9VED(")3=6)M:70B"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3
M=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU-R!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E
M9"!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(M>AUY77D]>?(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q,`IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#D*;7-G:60@(E-U;G)I<V4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$S"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,Y-`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$U"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("+7H=>5
MUZC7F=>@UYTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y
M"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3D*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("+7H=>5UY77
MEM>9UYS7H->3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-0IM<V=I9"`B4W=E9&5N(@IM<V=S
M='(@(M>IUY77E=>3UYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R("+7J=>5UY77F=>E(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN
M8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X"FUS9VED(")3>7)I86X@07)A8B!2
M97!U8FQI8R(*;7-G<W1R("+7H=>5UZC7F=>4(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FTB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C(*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED
M(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM
M<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*
M;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B
M;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-`IM<V=I9"`B5&%I
M=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-0IM<V=I9"`B5&%N>F%N:6$L(%5N:71E
M9"!297!U8FQI8R!O9B(*;7-G<W1R("+7F->@UY;7H->9UY0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")4
M87)G970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#8V(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E1A<VMS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")496UP(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M-@IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q-PIM<V=I9"`B5&5M<&5R871U<F4Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-C@*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B5&5X
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS
M9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G
M:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW
M"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(T"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("+7JM>0UYG7G->@UY,B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R.0IM<V=I9"`B5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z-C,*;7-G:60@(E1H92!(
M:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC
M93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I
M9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B
M"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B
M;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@
M8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E
M=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@
M(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D
M871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE(&5M86EL(&%D9')E<W,@)7,@:&%S(&)E96X@861D
M960@=&\@>6]U<B!I9&5N=&ET:65S+B!9;W4@8V%N(&-L;W-E('1H:7,@(@HB
M=VEN9&]W(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<W(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3,Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S`@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0R"FUS9VED
M(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@
M(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED
M(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@
M9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W
M:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S
M('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG
M:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I
M=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@
M($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI
M:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N
M($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E
M;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A
M;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N
M7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X-0IM<V=I9"`B5&AE(&YA;64@=&\@
M=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,#`*;7-G:60@(E1H92!N97<@
M9G)O;2!A9&1R97-S(&-A;B=T(&)E('9E<FEF:65D+"!T<GD@86=A:6X@;&%T
M97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(X,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I
M9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DW
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,PIM<V=I9"`B5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34*;7-G:60@
M(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C0T-"!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0T.`IM
M<V=I9"`B5&AE<F4@87)E(&YO(&5M86EL(&%D9')E<W-E<R!T;R!C;VYF:7)M
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HS-#4*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H
M879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@
M;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D
M;6EN+W5S97(N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,34X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HY,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HY,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3,X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@
M<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@
M;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED
M(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F
M;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,X"FUS9VED
M(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL
M("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#8Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$U-C4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(Q"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,S`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,C0*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R
M-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3DS"FUS9VED
M(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,CD*;7-G:60@(B(*
M(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38U"FUS9VED
M(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W
M('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V
M:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#(*
M;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM
M<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4P"FUS9VED(")4:6-K
M971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,S,@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*
M;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C(R"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P"FUS9VED(")4:6UO
M<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS
M9VED(")4:71L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-38*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#,*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,
M(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S"FUS9VED(")4;V=O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8*;7-G:60@(E1O:V5L874B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P-0IM
M<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.0IM<V=I
M9"`B5&]N9V$B"FUS9W-T<B`BUZ?7D=>5UZ;7JN*`D]>0UYG7F>*`D]>8UY77
MH->2UY0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#$*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@
M9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV.`IM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S(*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B
MUYC7J->9UZ#7F=>3UY,@UY77F->5UY'7DM>5(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<Y.`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X"FUS9VED
M(")4=6YI<VEA(@IM<V=S='(@(M>8UY77H->9UZ'7F=>4(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(M>8UY77J->GUYG7F=>4(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E1U<FMI<V@@*$E3
M3RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<*;7-G:60@(E1U
M<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P"FUS9VED(")4
M=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,PIM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS
M9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(M>0UZK7J"(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED
M(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R("+7D->JUZ@Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-PIM<V=I9"`B56=A;F1A(@IM<V=S='(@(M>0UY77DM>@UY/7
ME"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`BUY#7
ME=>GUZC7F=>9UZ#7E"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0T-0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$X(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C<R,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P-C,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@W,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#@*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-3@@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C8S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR,C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(S,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C,Y"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@W
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-@IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR.3@*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&1E
M8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<W(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS-C0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q."!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S8T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-S@@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,@IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-S`@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,W-`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0T,R!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,V
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$X,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S$T(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0R,0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@Q,@IM<V=I
M9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I
M;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP
M.C0S-R!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(Q."!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$X-2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DP"FUS9VED(")5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HY."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-C(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S$P(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C@Q(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@V"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$T,"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,#,*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A
M:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY
M,S0*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA
M8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C<P,@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$Q,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS,C,*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8T,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR,3,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0U,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,T.2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S$U"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS,S$*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O
M(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$X.0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$T(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,#D*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N
M9&\@0VAA;F=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,C$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM
M<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y.0IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R
M("+7E->0UY[7F=>HUY77F=>5UZH@UY37GM>0UY77E]>3UY77JB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S.`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`BUY37GM>>
MUYS7F]>4(->4UY[7D->5UY?7D]>J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,`IM<V=I9"`B
M56YI=&5D(%-T871E<R(*;7-G<W1R("+7D->HUZ;7E=>JXH"3UY37D=>HUYG7
MJB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,SD*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,PIM<V=I
M9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HU."!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,CD*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS
M9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G
M:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,@IM
M<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z,S$Y"FUS9VED(")5;FYA;65D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*
M(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO
M4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP
M="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM
M<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@
M(E5P9&%T92!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,30S(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,2!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M.0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T
M<B`BUY37HM><UY#7E"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*
M;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E
M<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P
M<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,0IM
M<V=I9"`B57)U9W5A>2(*;7-G<W1R("+7D->5UZC7E=>2UY77E=>9(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D
M(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HW-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N
M;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C(P,@IM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I
M9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U
M;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S0@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-"!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E
M<FYA;64B"FUS9W-T<B`BUZ?7E=>3(->6UYG7E->5UYD@UY[7J=>JUY[7J2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#(*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3<S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(X.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R-PIM
M<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC
M;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.3<*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C4R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-S0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(Q"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.30*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y"FUS9VED
M(")686YU871U(@IM<V=S='(@(M>5UZ#7E=>0UYC7E2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S@*;7-G:60@(E9A<FEA8FQE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#4*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R
M("+7E=>@UY;7E=>0UYS7E"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BUY+7F=>HUZ'7E"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#(*;7-G:60@(E9E<G-I;VX@0V]N=')O
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#@*;7-G:60@(E9I970@3F%M(@IM<V=S='(@
M(M>5UYG7F=>8XH"3UZ#7G2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,C`P
M"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDW-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#(V"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R
M:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-PIM<V=I9"`B5FER9VEN
M($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C$*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-PIM<V=I9"`B5FES:6)I;&ET
M>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")7
M05).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(
M5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A
M;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(Q(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS
M9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S0*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q.0IM<V=I9"`B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8P"FUS
M9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@
M(E=E;&-O;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHU-R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HW-"!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C(P,0IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HR,#(*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.`IM<V=I9"`B5V5S=&5R;B!386AA<F$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C8*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@
M(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@
M=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3@*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED
M=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4S-@IM<V=I9"`B5VEK:2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD
M(@IM<V=S='(@(M>HUY77ER(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C@*;7-G:60@(E=I;F0Z(@IM<V=S='(@(M>HUY77ESHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,V"FUS9VED(")7:6YD.B`B"FUS9W-T
M<B`BUZC7E=>7.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-CD*;7-G
M:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C$R"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-S`*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS
M9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ
M.3,@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@
M17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@
M(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")962(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3@*;7-G:60@(EE965DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3,*;7-G:60@
M(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3(*;7-G:60@(EEE;65N(@IM<V=S='(@(M>JUYG7
MGM>?(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV.`IM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R
M964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30R-0IM
M<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,C4*;7-G:60@
M(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W!H
M<&=W+G!H<#HQ,3<*;7-G:60@(EEO=2!D:60@;F]T(&%U=&AE;G1I8V%T92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@S"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM
M<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&AA=F4@<F5Q=65S=&5D('1O(&%D
M9"!T:&4@96UA:6P@861D<F5S<R!<(B5S7"(@=&\@=&AE(&QI<W0@;V8@>6]U
M<B`B"B)P97)S;VYA;"!E;6%I;"!A9&1R97-S97,N7&XB"B)<;B(*(D=O('1O
M('1H92!F;VQL;W=I;F<@;&EN:R!T;R!C;VYF:7)M('1H870@=&AI<R!I<R!R
M96%L;'D@>6]U<B!A9&1R97-S.EQN(@HB)7-<;B(*(EQN(@HB268@>6]U(&1O
M;B=T(&MN;W<@=VAA="!T:&ES(&UE<W-A9V4@;65A;G,L('EO=2!C86X@9&5L
M971E(&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E
M;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@
M)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y,@IM
M<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS
M9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O
M('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C0W-`IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O
M8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R
M92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Q.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z.3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8Q('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#4*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E
M(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S0*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ
M(&%D9')E<W,Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,`IM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K
M96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT
M<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M,3(T"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA
M;F=E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V
M,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-30*;7-G:60@(EEU9V]S;&%V:6$B"FUS
M9W-T<B`BUYG7E=>2UY77H=><UY'7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U-@IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(M>6UY[7D=>9UYG7
ME"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3<*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(M>6
MUYG7GM>1UY'7E=>5UY0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-S$*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T
M"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-C$*
M;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS
M9VED(")?1&5L971E(%)O=R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B
MUZ+7EM>HUY0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS
M9W-T<B`BUY37JM>@UZK7I]>5UZHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@
M3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("+7D->DUZG7
MJ->5UYG7E=>J(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T
M=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,`IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(M>AUZ37J"#7F]>J
MUY77D=>5UZHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3(*;7-G:60@(F-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@T(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*
M;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-0IM<V=I9"`B8VQI8VL@
M:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C
M<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A
M(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N
M;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`R"FUS9VED(")F
M:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@V(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<R(&QI8B]";&]C:R]M971A<BYP:'`Z,SDX
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS9VED(")H.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S8Q"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O
M;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,@IM<V=I9"`B;6TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#$@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@(M>IUYTB
M"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP
M;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`T"FUS
M9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@
M(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HQ,#(*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S@Y"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<W1E861Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I
M9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S4@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,0IM
M<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,C<Y"FUS9VED(")U;FMN;W=N
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R
M="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#`*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V1A7T1+
M+G!O````````````````````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#$Q,#$R-#$`,3`U,34T,S$P-C,`,#$V,S(W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@1&%N:7-H('1R86YS;&%T
M:6]N<R!F;W(@2&]R9&4@<&%C:V%G90HC($1A;G-K92!O=F5R<^9T=&5L<V5R
M(&9O<B!P86MK92!(;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@36%R=&EN
M($QI<W0M4&5T97)S96XN"B,@0V]P>7)I9VAT("A#*2`R,#`U+3(P,#8@0G)I
M86X@5')U96QS96XN"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R
M('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@36%R
M=&EN($QI<W0M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K/BP@
M,C`P,2X*(R!"<FEA;B!4<G5E;'-E;B`\:&]R9&4K:3$X;D!B<FEA;G1R=65L
M<V5N+F1K/BP@,C`P-2TR,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$N,2UC=G-<;B(*(E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E
M871I;VXM1&%T93H@,C`P-BTP,RTQ,2`Q,CHS.2LP,3`P7&XB"B)03RU2979I
M<VEO;BU$871E.B`R,#`V+3`S+3$Q(#$V.C4R*S`Q,#!<;B(*(DQA<W0M5')A
M;G-L871O<CH@0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E
M;'-E;BYD:SY<;B(*(DQA;F=U86=E+51E86TZ($1A;FES:"`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M
M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN("$](#$I.UQN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R
M("(@*"5S(&1A9V4@<VED96XI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ,S@S(&QI8B](;W)D92YP:'`Z,3,X,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A!8V-E<W-K97D@)7,I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A
M>7,I(@IM<V=S='(@(B`H;VT@)7,@9&%G92DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<S(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"FUS9VED
M("(@*'1O9&%Y*2(*;7-G<W1R("(@*&D@9&%G*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H:2!M;W)G96XI(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H:2!GY7(I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B(&UE9"`B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q.2!L:6(O5D93+W-M8BYP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E
M8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!E<B!I:VME(&5T(&MA=&%L;V<N(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,B!L:6(O2&]R9&4O0TQ)+G!H
M<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A
M;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&5R(&EN=&5T(&=Y;&1I9W0@
M=F%L9RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C<Q,`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P
M.3@@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*(SH@;&EB+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S
M='(@(EPB)7-<(B!E<B!I:VME(&MO;F9I9W5R97)E="!I($AO<F1E<R!F;W)T
M96=N96QS92XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$@;&EB
M+TAO<F1E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!T
M<N8M;W!B>6=G97(@:6MK92!F=6YD970N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@8FQE=B!T:6QF
M^&IE="!I(&=R=7!P92US>7-T96UE="XB"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")<(B5S
M7"(@8FQE=B!T:6QF^&IE="!T:6QL861E;'-E<RUS>7-T96UE="XB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D
M.B`E<RXB"FUS9W-T<B`B7"(E<UPB(&)L978@:6MK92!D86YN970Z("5S+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*
M;7-G<W1R("(E+C)F34(@8G)U9W0@=60@868@)2XR9DU"('1I;&QA9'0@*"4N
M,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E
M<R!O9R`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(V.`HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3DT"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT
M:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(E9"!D86=E('1I
M;"!D:70@:V]D96]R9"!U9&SX8F5R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O
M<F5C87-T(@IM<V=S='(@(B5D+61A9W,@=61S:6=T(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@
M3F]T:6-E(@IM<V=S='(@(B5S("T@3F]T:71S(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B
M"FUS9W-T<B`B)7,@9FEN9V5R869T<GEK(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0R(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@T-`HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M.#0R(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R
M("(E<R!6961L:6=E:&]L9&5L<V4@+2!"96MRYF9T96QS92(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R!O
M<'/F=&YI;F<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8T(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@;W!S:W)I=FYI;F<B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(&)R
M=6=S8F5T:6YG96QS97(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8X,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0Y-`HC.B!L:6(O5D93+V9T<"YP:'`Z-C@R(&QI8B]61E,O9G1P+G!H
M<#HW-3`@;&EB+U9&4R]S;6(N<&AP.C0S,@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-#DT"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R("(E<R!E:W-I<W1E<F5R(&%L;&5R961E+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&%T("5S("5S(@IM<V=S='(@(B5S('9E9"`E<R`E<R(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R
M871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N(@IM<V=S='(@(B(*(B5S(&5R('!A<F%T('1I;"!A="!U9&;X<F4@9&4@
M=F5D;&EG96AO;&1E;'-E<VAA;F1L:6YG97(L('-O;2!E<B!M87)K97)E="`B
M"B)N961E;F9O<BX@(%/F="!H86L@=60@9F]R(&1E(&AA;F1L:6YG97(L('-O
M;2!D=2#X;G-K97(@=61F^')T(&YU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-#`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:W+F=F5T
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU='1E<B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S(@;&EB+TAO
M<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&EK:V4@9G5N9&5T+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@=&EL("5S
M(&%F("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C8@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7-S(&%D<F5S<V5K87)T;W1E:R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD
M87(B"FUS9W-T<B`B)7-S(&MA;&5N9&5R(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,3`@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S<R!N;W1E
M<V)L;VLB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-"!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(B5S<R!O<&=A=F5R(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HY-@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$R-R!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@HB)7,Z($1E;FYE(&)E<VME9"!E<B!M=6QI9W9I<R!I:VME(&9R82!D
M96X@<&5R<V]N+"!S;VT@9&5N(&CF=F1E<B!A="!VYG)E("(*(F9R82X@(%;F
M<B!V87)S;VT@;65D(&%T(&;X;&=E(&AE;G9I<VYI;F=E<B!E;&QE<B!F;W)S
M>6YE(&%F<V5N9&5R96X@;65D("(*(G!E<G-O;FQI9V4@:6YF;W)M871I;VYE
M<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B
M"FUS9W-T<B`B+"!D:7-E="`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y
M-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!B;.9S96YD92`E<R`E<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G
M:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('-K<FEF
M=&5N9&4@9G)A("5S('1I;"`E<R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HW-#@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR.30*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3(X(&QI8B](;W)D92]&;W)M+G!H<#HR,#8Y"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3(X(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HW-#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.30@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@*;7-G:60@(BTM('-E;&5C="`M
M+2(*;7-G<W1R("(M+2!VYFQG("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUT:6UE<G,@
M9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(
M;W5R($9O<FUA="(*;7-G<W1R("(R-"UT:6UE<G,@9F]R;6%T(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S
M='(@(C(T('1I;65R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV
M.2!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B
M"FUS9W-T<B`B/$9O<F5GY65N9&4@9&%G(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B16X@9&%T86)A<V4M8F%C:V5N
M9"!E<B!K<N9V970@9F]R(&1E;FYE(&)L;VLN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-S$@;&EB+TAO<F1E+G!H<#HQ-S$*;7-G:60@(D$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D1E<B!E<B!O<'-T
MY65T(&5N(&=R879E<F5N9&4@9F5J;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDS-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,S4*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI9R!01U`M;OAG;&4@
M97(@:W+F=F5T(&9O<B!A="!K<GEP=&5R92!E;B!B97-K960N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V."!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")%
M;B!O9F9E;G1L:6<@4$=0+6[X9VQE(&5R(&MRYG9E="!F;W(@870@=F5R:69I
M8V5R92!E;B!S:6=N97)E="!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3`Y.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB16X@;V9F96YT;&EG(%!'4"UN^&=L
M92P@<')I=F%T(%!'4"UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970@9F]R
M(&%T("(*(F1E:W)Y<'1E<F4@96X@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$P,38@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!01U`M;OAG
M;&4L('!R:79A="!01U`M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T+"!F
M;W(@870@(@HB<VEG;F5R92!E;B!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E;G1L
M:6<@4R]-24U%+6[X9VQE+"!P<FEV870@4R]-24U%+6[X9VQE(&]G(&5T(&SX
M<V5N(&5R(&MRYG9E="P@9F]R(&%T("(*(F1E:W)Y<'1E<F4@96X@8F5S:V5D
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB16X@;V9F96YT;&EG(%,O34E-12UN^&=L92P@<&5R<V]N;&EG(%,O
M34E-12UN^&=L92!O9R!L^'-E;B!E<B!K<N9V970@9F]R(&%T("(*(G-I9VYE
M<F4@96X@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED
M(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI9R!3+TU)344M;OAG;&4@
M97(@:W+F=F5T(&9O<B!A="!K<GEP=&5R92!E;B!B97-K960N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(D9O<FUI9&1A9R!3:WEE="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H
M="!286EN(@IM<V=S='(@(D9O<FUI9&1A9R!,970@4F5G;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!2
M86EN(@IM<V=S='(@(D9O<FUI9&1A9R!296=N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B
M"FUS9W-T<B`B1F]R;6ED9&%G($)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R(")&;W)M:61D86<@4VYE8GEG97(B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,#`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*
M;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T
M:&ES(&5D:71O<B(*;7-G<W1R(")/;2!D96YN92!S:W)I8F5N="(*"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G
M<W1R(")/;2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-B;W1T
M;VTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B06)S;6ED9&QE(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,"!L:6(O5D93+VUU<W%L
M+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B061G86YG(&[F9W1E="!V960@9&%N;F5L<V4@
M868@5D93+6MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(D%D9V%N9R!NYF=T
M970@=F5D(&1A;FYE;'-E(&%F(%9&4RUF:6PN(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B2V]N=&\M:6YF;W)M871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B2V]N=&]E
M;G,@:V]D96]R9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(DMO
M;G1O(&EN9&5F<F]S<V5T+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B2V]N=&5R:6YG+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,30X"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHQ-"!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM
M<V=I9"`B061D(@IM<V=S='(@(E1I;&;X:B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@
M1W)O=7`B"FUS9W-T<B`B5&EL9OAJ('5N9&5R9W)U<'!E(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B5&EL9OAJ('5N9&5R;W)D;F5D92!T:6QL861E;'-E
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(
M97)E.B(*;7-G<W1R(")4:6QF^&H@:&5R.B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R
M;W5P(@IM<V=S='(@(E1I;&;X:B!N>2!G<G5P<&4B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B5&EL9OAJ(&YY(')E='1I9VAE9"(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(E1I;&;X
M:B!U;F1E<F=R=7!P92!T:6P@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R!<(B5S7"(B"FUS9W-T<B`B5&EL9OAJ(&5N('5N9&5R<F5T=&EG:&5D('1I
M;"!<(B5S7"(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@
M;F5W('5S97(Z(@IM<V=S='(@(D]P<F5T=&4@96X@;GD@8G)U9V5R.B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B
M061D(&-O;'5M;B(*;7-G<W1R(")4:6QF^&H@:V]L;VYN92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@
M;65M8F5R<R(*;7-G<W1R(")4:6QF^&H@;GEE(&UE9&QE;6UE<B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM
M<V=S='(@(D]P<F5T('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(E1I;&;X:B`E<RUM96YU96X@<V]M
M(&5N($UO>FEL;&$@4VED96)A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R
M(")4:6QF^&H@=&EL(&%D<F5S<V5K87)T;W1E:SHB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@
M8F]O:R(*;7-G<W1R(")4:6QF^&H@=&EL(&UI="!A9')E<W-E:V%R=&]T96LB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T
M<B`B3W!R970@8G)U9V5R(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL
M(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T
M:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB2&%R('1I;&;X:F5T(%PB)7-<(B!T
M:6P@<WES=&5M970L(&UE;B!K=6YN92!I:VME('1I;&;X:F4@96MS=')A("(*
M(F]P<VMR:79N:6YG<VEN9F]R;6%T:6]N.B`E<RXB"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(E1I;&;X:F5T
M(%PB)7-<(B!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G92!I;F0@;G4N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3W!R971T96QS92!A
M9B!B<G5G97)E(&5R('-LY65T(&9R82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0Q(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D
M<F5S<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED
M(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S96MA<G1O=&5K(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1RZ7(@
M+2!I;F1S=&EL('1I;&QA9&5L<V5R(&9O<B!A;F1R92!B<G5G97)E(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T
M<F%T:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I
M9"`B061S(@IM<V=S='(@(E)E:VQA;65R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H
M86YI<W1A;B(*;7-G<W1R(")!9F=H86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M06QB86YI82(*;7-G<W1R(")!;&)A;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG
M97)I82(*;7-G<W1R(")!;&=E<FEE="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(DMA;&1E
M;F%V;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(D]P<W1I;&QI;F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W
M"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(DIU<W1E<FEN9SHB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")!
M;&QE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#<*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS
M9W-T<B`B06QL92#F9W1E9&4@8G)U9V5R92(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B
M"FUS9W-T<B`B06QL92!G<G5P<&5R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N
M<&AP.C<U"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E
M+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(D%L;&4@=&EL;&%D96QS97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@
M9F]U<B!S:61E<R(*;7-G<W1R(")!;&QE(&9I<F4@<VED97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B
M5&EL;&%D(&UU;'1I<&QE(&%D<F5S<V5R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\B"FUS9W-T<B`B5&EL;&%D(&%N9VEV96QS92!A9B!O<F1N970@
M;&ES=&5T>7!E/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S
M<6PN<&AP.C4P-"!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*;7-G
M:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D5K<VES=&5R97(@86QL97)E
M9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E
M<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=&EV($E-4U`M;&]G
M:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E
M<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EV($E-4U`M
M:V]D96]R9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T:78@
M24U34"UB<G5G97)N879N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(D1I;B!E+6UA:6PM861R97-S92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R
M;F%T:79E('-K86)E;&]N97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*;7-G:60@(D%L=&5R;F%T
M92!T97AT.B(*;7-G<W1R(")!;'1E<FYA=&EV('1E:W-T.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK86YS:R!386UO
M82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")$96X@
M=N9R9&DL(&1E<B!B;&5V(&%N9VEV970L('9A<B!I:VME(&=Y;&1I9RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U
M;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")$97(@97(@;W!S
M=.5E="!E;B!U:V5N9'0@9F5J;"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B
M"FUS9W-T<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B
M06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S
M(%!R;WAY(@IM<V=S='(@(D%N;VYY;6ES97)E;F1E('!R;WAY(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G
M<W1R(")"97-V87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B4WED<&]L96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U
M9&$B"FUS9W-T<B`B06YT:6=U82!A;F0@0F%R8G5D82(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HS-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@;&EB+TAO<F1E+T)L;V-K+U5)
M+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV
M"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<'!L:6MA=&EO;B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@
M3&ES="(*;7-G<W1R(")!<'!L:6MA=&EO;G-L:7-T92(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y
M+B(*;7-G<W1R(")!<'!L:6MA=&EO;B!E<B!P87)A="XB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@
M4VAA<F5S(@IM<V=S='(@(E#E9OAR('5N9&5R9&5L:6YG97(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V
M92(*;7-G<W1R(")';V1K96YD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0R(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M-#(*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B0VER:V%S=/AR
M<F5L<V4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@
M(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!
M<F%B:7-K("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C8*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE
M(@IM<V=S='(@(D%R:VEV+69I;'-T^')R96QS92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C4X"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED(")!<F-H:79E($YA
M;64B"FUS9W-T<B`B07)K:79N879N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/R(*;7-G<W1R(")%<B!D=2!S:6MK97(@<.4L(&%T(&1U
M('9I;"!S;&5T=&4@;W!S:W)I=FYI;F=S86YM;V1N:6YG96X@9F]R("5S(#\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D5R(&1U
M('-I:VME<BP@870@9'4@^&YS:V5R(&%T('-L971T92!<(B5S7"(@;V<@96YH
M=F5R('5N9&5R9W)U<'!E/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM
M<V=S='(@(D%R9V5N=&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G
M<W1R(")!<FUE;FEE;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS
M9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;G-K("A!
M4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B2W5N<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM
M<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)
M<VQA;F0B"FUS9W-T<B`B07-C96YS:6]N^&5N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B05-#24D@
M07)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G
M:6]N(@IM<V=S='(@(D%S:6%T:7-K+W-T:6QL96AA=G-R96=I;VXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B
M"FUS9W-T<B`B4W#X<F<@969T97(@8F5K<N9F=&5L<V4@9OAR('5D9OAR96QS
M92!A9B!V961L:6=E:&]L9&5L<V5S:&%N9&QI;F=E<C\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,#DU(&QI8B](;W)D92]&;W)M+G!H<#HS,#DU
M"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B5&EL9&5L(&MO
M;&]N;F5R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(D9O
M<G/X9R!PY2!A="!S;&5T=&4@96X@:6MK92UE:W-I<W1E<F5N9&4@9W)U<'!E
M+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(D9O<G/X9R!PY2!A="!S;&5T=&4@96X@:6MK92UE:W-I<W1E<F5N9&4@
M=&EL;&%D96QS92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(D9O<G/X9R!PY2!A="#F;F1R92!E;B!I:VME+65K<VES=&5R
M96YD92!T:6QL861E;'-E+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+B(*;7-G<W1R(")&;W)S^&<@<.4@870@YFYD<F4@96X@:6MK92UE:W-I
M<W1E<F5N9&4@9&5L:6YG+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<Q(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<Q"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T
M=')I8G5T=&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS
M9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B075S=')A;&EE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M075S=')I82(*;7-G<W1R("+8<W1R:6<B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,38X(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z
M,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@2W+F=F5T($E-
M05`M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ,S4@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!"
M86-K96YD(&AA<B!I:VME(&1E(&[X9'9E;F1I9V4@979N97(N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R(&QI8B](;W)D92]!=71H
M+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@
M2W+F=F5T($E-05`M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O9G1P
M+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L
M92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@2W+F=F5T
M($944"UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+B!/=F5R<^9T(%!(4"!M960@
M+2UE;F%B;&4M9G1P+2(*(F9L86=E="XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEM87`N<&AP.C8T(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS
M9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!+<N9V970@24U!4"UU9'9I9&1E
M;'-E(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z-3$@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VMR8C4Z($MRYG9E="!+4D(U+75D=FED9&5L<V4@:6MK
M92!F=6YD970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M,#(@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD
M87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@5&EL9OAJ96QS92!B
M<G5G97)E(&5R(&EK:V4@=6YD97)S=/AT=&5T(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E
M;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!3;&5T;FEN9R!A9B!B<G5G
M97)E(&5R(&EK:V4@=6YD97)S=/AT=&5T('9E9"!!8W1I=F4@1&ER96-T;W)Y
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,R!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A
M<#H@2W+F=F5T($Q$05`M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.2!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($MU;FYE(&EK:V4@=&EL
M9OAJ92!B<G5G97(@)7,N(%-E<G9E<F5N('-A9V1E.B`B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,X-2!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!+86X@
M:6MK92!S;&5T=&4@8G)U9V5R("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT.3D@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EK:V4@;W!D871E
M<F4@8G)U9V5R("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,#4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H
M7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@3W!D871E
M<FEN9R!A9B!B<G5G97)E(&5R(&EK:V4@=6YD97)S=/AT=&5T('9E9"!!8W1I
M=F4@1&ER96-T;W)Y+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-#8@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VUC86PZ($MRYG9E="!-0T%,+75D=FED9&5L<V4@:6MK92!F
M=6YD970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7W-M8F%U=&@Z($MRYG9E="!334)!551(+75D=FED9&5L<V4@:6MK
M92!F=6YD970N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z
M,3`V(&QI8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BQF=T
M;FEN9R!V960@24U!4"US97)V97(@9F5J;&5D92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+&9W1N:6YG(&9E:FQE9&4B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW
M-@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+&9W1N
M:6YG(&9E:FQE9&4N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I
M=7,N<&AP.C$W-B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`BQF=T;FEN9R!A9G9I<W0@868@4D%$2553+7-E<G9E<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,B!L:6(O5D93+V9T<"YP
M:'`Z.#@R"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`BQF=T;FEN9R!O=F5R9F]R($944"US97)V97(@9F5J
M;&5D92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P(&QI8B]6
M1E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--
M0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+&9W1N:6YG(&]V97)F;W(@4TU"
M+7-E<G9E<B!F96IL961E+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D9E;'1E
M<B!T:6P@<N5D:6=H960Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM
M<V=S='(@(D%S97)B86ED:F%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"UU;F1S:WEL
M9&YI;F=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B0F%C
M:V=R;W5N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0F%G
M9W)U;F1S9F%R=F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@Q(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R
M8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(D3E<FQI9W0@:V5R8F5R;W,M:V]D
M96]R9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S(&QI
M8B](;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@
M=7-E<FYA;64N(@IM<V=S='(@(D3E<FQI9W0@:V5R8F5R;W,M8G)U9V5R;F%V
M;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U
M.2TQ,RDB"FUS9W-T<B`B0F%L=&EK=6T@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,S(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")"87-I<R!G<F%F:6MK871A;&]G(%PB)7-<(B!I:VME(&9U;F1E="XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3D*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(D)A<VES;&EN:64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B2'9I9&5R=7-L86YD(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M
M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*
M;7-G<W1R(")":'5T86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3$Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")&^&1S96QS9&%G
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V
M-R!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")";&]K(%PB)7-<(B!A9B!A<'!L:6MA
M=&EO;B!<(B5S7"(@:6MK92!F=6YD970N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R
M(")";&]K+65G96YS:V%B97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B0FQO:W1Y<&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*
M;7-G:60@(D)O;&0B"FUS9W-T<B`B1F5D(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI
M=FEA(@IM<V=S='(@(D)O;&EV:65N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(D)O9VWF<FME
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")286YD(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B
M0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4F%M;65T>6MK96QS93HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(E)A;F1E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI96X@
M;V<@2&5R>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*
M;7-G:60@(D)O=&@B"FUS9W-T<B`B0F5G9V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M='-W86YA(@IM<V=S='(@(D)O='-V86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"FUS9VED(")";W1T;VTB
M"FUS9W-T<B`B0G5N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*
M;7-G<W1R(")";W5V973X96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G
M<W1R(")"<F%S:6QI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71I<VLM26YD:65N($]C
M96%N;VURY61E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*
M;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L
M9V%R:6$B"FUS9W-T<B`B0G5L9V%R:65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R(")0=6YK=&QI<W1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA
M($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-2!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-2
M0R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@9&ES=')I8G5T:6]N<W-T961E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")#96QL92UE9V5N<VMA8F5R+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"XB"FUS9W-T<B`B26YI=&EA;&ES97)I;F<@868@;6ED;&5R=&ED:6=T
M(&QA9V5R(&EK:V4@9N9R9&EG9VIO<G0N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-2!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDQ-@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ-B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#0P(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*
M;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R
M(")6:6YD<W1I;&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S
M='(@(DMA;6)O9&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R
M(")#86UE<F]U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")+86X@:6MK
M92!N=6QS=&EL;&4@:V]D96]R9"!A=71O;6%T:7-K.R!K;VYT86MT(&1I;B!A
M9&UI;FES=')A=&]R+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,U,"!L:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(DMA;B!I
M:VME('-K<FEV92!T:6P@9FEL(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S
M:6]N(&AA;F1L97)S+B(*;7-G<W1R(")+86X@:6MK92!HY6YD=&5R92!E:W-T
M97)N92!S97-S:6]N<VCE;F1T86<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C,Q.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")+86X@
M:6MK92!F;W)B:6YD92!T:6P@24U!4"!S97)V97(N("5S(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V(&QI8B]&:6QE+T-35BYP:'`Z-#0V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DMA;B!I:VME(.5B;F4@9FEL(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9&$B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-2!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*
M;7-G:60@(D-A;F-E;"(*;7-G<W1R(")!;FYU;&QE<B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B069B<GED(')E<&]R=&5R:6YG(&%F('!R;V)L
M96TB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,R!L:6(O5D93
M+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE
M=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME('-L971T92!F:6P@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!F:6YD92!E
M="!M:61L97)T:61I9W0@:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.CDQ(&QI8B]61E,O25-/5W)I=&5R+G!H
M<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+B(*;7-G<W1R(")+86X@:6MK92!F;W)T<^9T=&4@=61E
M;B`G=&%R9V5T1FEL92<M<&%R86UE=')E;BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Q.2!L:6(O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B2V%N(&EK:V4@9FIE<FYE(&MA=&%L;V<@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC.B!L:6(O2&]R9&4O
M1&%T851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(DMA;B!I:VME(&9J97)N92P@)60@8OAR
M;B!E:W-I<W1E<F5R+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8P."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*
M;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB
M<W1O<F5D+B(*;7-G<W1R("(B"B)+86X@:6MK92!O;69O<F1E;&4[(&%N=&%L
M;&5T(&%F('!U;FMT97(@86YG:79E="!T:6P@;VUF;W)D96QI;F<@<W9A<F5R
M(&EK:V4@(@HB=&EL(&1E="!O<&)E=F%R961E(&%N=&%L+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T
M<B`B2V%N(&EK:V4@9&ER:6=E<F4@8F5S:V5D('1I;"!A;F=I=FYE(&YU;6UE
M<BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E
M<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")":6QL961T96MS
M="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.C$P-"!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R(")59&)Y9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T
M<B`B2V%T96=O<FEE<B!O9R!-YG)K97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y
M;6%N($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N^&5R;F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE
M(@IM<V=S='(@(DUO8FEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(D-E;&QE+65G96YS:V%B97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D
M:6YG.B(*;7-G<W1R(")#96QL969O<G)I;F<Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L
M;"!P<F]P97)T:65S(@IM<V=S='(@(D-E;&QE+65G96YS:V%B97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I
M9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")#96QL92UM96QL96UR=6TZ(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL=&5L
M969O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT
M:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT:7-K("A)4T\M.#@U.2TQ
M-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B0V5N='+I<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(D1E;B!C96YT<F%L869R:6MA;G-K92!297!U8FQI:R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*2(*;7-G<W1R(")#96YT<F%L+65U<F]PYFES:R`H25-/+3@X-3DM
M,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,"!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")#97)T:69I:V%T+61E=&%L:F5R(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R
M(@IM<V=S='(@(D-E<G1I9FEK870M96IE<B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DW(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")#
M97)T:69I:V%T+7!O;&ET:6MK97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D
M(@IM<V=S='(@(E1C:&%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(L9N9')E(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G
M<W1R("+&;F1R92!D:70@:V]D96]R9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(DAE<B!K86X@9'4@YFYD<F4@
M9&5T(&YA=FX@;V<@9&5N(&%D<F5S<V4L('-O;2!A;F1R92!S97(L(&[E<B!D
M92!LYG-E<B!O9R`B"B)S=F%R97(@<.4@9&EN92!E+6UA:6PN(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(DMO9&5O<F1SYFYD<FEN9R!E<B!I:VME('5N
M9&5R<W3X='1E="!A9B!D96X@;G5VYG)E;F1E(&]P<^9T;FEN9RX@($MO;G1A
M:W0@(@HB9&EN(&%D;6EN:7-T<F%T;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*
M;7-G<W1R(")496=N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*
M;7-G<W1R(")(86L@;&EN:R!A9BXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(DMI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(E-I;7!L:69I8V5R
M970@:VEN97-I<VL@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T
M<B`B5')A9&ET:6]N96QT(&MI;F5S:7-K("A":6<U*2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB
M"FUS9W-T<B`B5N9L9R!A<'!L:6MA=&EO;CHB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C<P(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")6YFQG
M(&5T(&MO9&5O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#
M:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")6YFQG(&5T(&)R=6=E<FYA=FXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@
M:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E;F;&<@:'9O<F1A;B!D
M871O97(@<VMA;"!V:7-E<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B5N9L
M9R!L:7-T92US=&EL("AF;W(@;W)D;F5D92!L:7-T97(I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(DIU;&7X96XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T(&9R86UE=V]R:R].971?4TU3+U--
M4RYP:'`Z,CDT(&QI8B]61E,N<&AP.CDQ-`HC.B!L:6(O3F5T+U--4RYP:'`Z
M,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S<V5D969I;FET:6]N(&%F("5S
M(&EK:V4@9G5N9&5T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")+;&%R="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G
M:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B1FIE<FX@35-/9F9I
M8V4M;W!MYG)K;FEN9V5R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM
M<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B3G5L<W1I;"!F;W)E<W#X<F=S
M96PB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B
M4F5N<R!B<G5G97(@=60Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(DYU;'-T
M:6P@8G)U9V5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")6:7-K(&)R=6=E
M<F1A=&$@=60B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")396X@;W!K
M;&%R:6YG(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML
M:6L@9F]R(&%T(&9O<G1SYG1T92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%14
M4"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R
M"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B3'5K('9I;F1U92(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T
M<B`B4VMY97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(E-K>65R('1I
M9&QI9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(E-K>65T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")#;V-O<R`H
M2V5E;&EN9RD@V&5R;F4B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(D9O;&0@
M<VED97!A;F5L('-A;6UE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D
M97)S(@IM<V=S='(@(E-A;6UE;F9O;&1E9&4@<F%N9&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEE;B(*"B,Z(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R(")&87)V92(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,#,*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,#,@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,S.`HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S,Y('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@
M(D-O;&]R(%!I8VME<B(*;7-G<W1R(")&87)V97;F;&=E<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,C@*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B1F%R=F5V86QG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(DMO;',Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DT-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-@IM
M<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")+;VQO;FYE=&ET;&5R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S
M(@IM<V=S='(@(E1E9VYE<V5R:65R(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(DMO;6UA;F1O(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S
M='(@(DMO;6UA;F1O;&EN:64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(DMO;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38W(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(")#;VUM;VX@
M3F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R
M97)N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*
M;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")#;VUP
M=71E<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS
M9VED(")#;VYD:71I;VXB"FUS9W-T<B`B1F]R:&]L9"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D)E
M=&EN9V5L<V5R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@
M(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B2V]N9FEG=7)A
M=&EO;G-F;W)S:V5L;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@
M4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(DMO;F9I9W5R871I
M;VX@=&EL('-Y;FMR;VYI<V5R:6YG(&UE9"!01$%E<BP@4VUA<G1P:&]N97,@
M;V<@3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")+
M;VYF:6=U<F%T:6]N96X@97(@9F]RYFQD970N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@
M)7,B"FUS9W-T<B`B2V]N9FEG=7+I<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B
M"FUS9W-T<B`B0F5K<N9F="!K;V1E;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG
M;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+;VYG;RP@1&5N
M(&1E;6]K<F%T:7-K92!R97!U8FQI:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B1F]R8FEN
M9&5L<V4@;6ES;'EK:V5D97,N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,P."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DW"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B1F]R8FEN9&5L
M<V4@;6ES;'EK:V5D97,Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<Y,"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B1F]R8FEN9&5L<V4@=&EL(&]F9F5N=&QI9R!N^&=L97-E<G9E
M<B!NYF=T970N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-SDR(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")&;W)B:6YD96QS92!T
M:6P@;V9F96YT;&EG(&[X9VQE<V5R=F5R(&[F9W1E="X@Q7)S86<Z("5S("@E
M<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W-B!L:6(O5D93
M+V9T<"YP:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R(")&;W)B:6YD96QS92!T:6P@1E10+7-E<G9E<B!M
M:7-L>6MK961E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M-"!L:6(O2&]R9&4O2V]L86(N<&AP.CDR-`HC.B!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B2V]N=&%K=&5R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O
M;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT97(@8FQE=B!T:6QF^&IE="!T:6P@
M9&ET(&%D<F5S<V5K87)T;W1E:V5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL
M93H@(@IM<V=S='(@(DEN9&AO;&1S='EP92!A9B!K;VUP<FEM97)E="!F:6PZ
M("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C4V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C<U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R("));F1H;VQD(&%F(%PB)7-<(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM
M<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B1F]R='/F="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VL@27-L86YD<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@
M(E-MY6MA9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(@;&EB+U9&4R]S
M;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B2V]P:65R:6YG(&UI<VQY:VME9&5S.B`E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@
M(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(DMO<&GI<B!M87)K97)I;F<B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-2!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B1V5B>7(@240B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")%;&9E;F)E
M;G-K>7-T96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-S<@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DMU;FYE(&EK:V4@
M4$=0+6MR>7!TZ7)E(&)E<VME9#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`U-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U
M"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@
M(DMU;FYE(&EK:V4@4$=0+7-I9V[I<F4@8F5S:V5D.B`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,R!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK:V4@4R]-24U%+6MR>7!T97)E
M(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0V-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK
M:V4@4R]-24U%+7-I9V[I<F4@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME
M('1I;&;X:F4@:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M,C$*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.CDV(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#@R
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B2W5N;F4@:6MK92!K;V)L92!T:6P@3$1!4"US97)V97(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DMU
M;FYE(&EK:V4@:V]N=')O;&QE<B!B86QA;F-E+B`E<R(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&9O<F)I;F1E('1I
M;"!,1$%0+7-E<G9E<BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R
M=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@
M9F]R8FEN9&4@=&EL('-E<G9E<B!<(B5S7"(@=F5D(&)R=6<@868@1E10.B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S(R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O<')E='1E(&1I
M<W1R:6)U=&EO;G-L:7-T92X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3(X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B
M2W5N;F4@:6MK92!D96MR>7!T97)E(%!'4"UD871A.B`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,R!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N(@IM<V=S='(@(DMU;FYE(&EK:V4@9&5K<GEP=&5R92!3+TU)344M
M9&%T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(T-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!S;&5T=&4@:V]N=&%K="X@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,U-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@<VQE='1E(&1I
M<W1R:6)U=&EO;G-L:7-T92X@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!S;&5T=&4@/&5M/G-C<FEP=#PO96T^(%PB)7-<(B!T:6P@;W!G<F%D
M97)I;F<@868@;W!SYG1N:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.CDU,R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,X,0HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,2!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(")+
M=6YN92!I:VME(&)E<W1E;6UE(&UO9'1A9V5R96YS(&4M;6%I;"UA9')E<W-E
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C@S"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@:&5L92!A9')E<W-E:V%R=&]T
M96LN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT.3,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E(&AE;&4@9&ES=')I
M8G5T:6]N<VQI<W1E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#0V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DMU;FYE
M(&EK:V4@:&5N=&4@9G5L9'-TYFYD:6<@9F]R=&5G;F5L<V4@;W9E<B!D:7-T
M<FEB=71I;VYS;&ES=&5R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HV.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO
M860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E
M('-T<F%T96=I(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T
M<B`B2W5N;F4@:6MK92!M:V1I<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT92!O9F9E
M;G1L:6<@;OAG;&4@9G)A(&[X9VQE<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,SD*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2W5N;F4@:6MK
M92#E8FYE(%PB)7-<(B!F;W(@<VMR:79N:6YG+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0U(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@Y6)N92`E<RXB"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,"!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(")+=6YN
M92!I:VME(.5B;F4@;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS92`E<R(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HW,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+
M=6YN92!I:VME(.5B;F4@:V%T86QO9R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-CDY"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T
M(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!N
MY2!,1$%0+7-E<G9E<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C0P(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DMU;FYE(&EK
M:V4@;.9S92`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX
M-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*(DMU;FYE(&EK:V4@;G5L<W1I;&QE(&MO9&5O<F1E="!F
M;W(@9&5N(&%N;6]D961E(&)R=6=E<BX@($YO9VQE(&5L;&5R(&%L;&4@(@HB
M9&5T86QJ97(@97(@=6MO<G)E:W1E+B!0<OAV(&EG96X@96QL97(@:V]N=&%K
M="!D:6X@861M:6YI<W1R871O<BP@:'9I<R!D=2`B"B)H87(@8F5H;W8@9F]R
M('ED97)L:6=E<F4@:&KF;'`N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,S.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S4*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS
M9W-T<B`B2W5N;F4@:6MK92!H96YT92!!0TPB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@
M(DMU;FYE(&EK:V4@:&5N=&4@861R97-S96MA<G1O=&5K970N("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@9&ES=')I8G5T
M:6]N<VQI<W1E+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#,W"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B2W5N;F4@
M:6MK92!H96YT92!D:7-T<FEB=71I;VYS;&ES=&5R+B`E<R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@<V5R=F5R<R!E=FYE
M<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W5N;F4@:6MK
M92!G96YD86YN92!K;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HY-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD
M:7(@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(')M9&ER(%PB)7-<(BXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")+=6YN92!I:VME(&=E;6UE("5S+6MO;F9I9W5R871I;VXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!G96UM92!E;B!B86-K=7`M:V]N
M9FEG=7)A=&EO;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&=E;6UE(&5N(&)A
M8VMU<"UK;VYF:6=U<F%T:6]N.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@9V5M;64@<V-R:7!T('1I;"!O<&=R861E<FEN9R!A9B!O<'/F
M=&YI;F<@=&EL.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!G96UM92!B86-K=7`M:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@
M=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@
M=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DMU;FYE(&EK:V4@
M9V5M;64@:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RX@1'4@:V%N(&5N=&5N(&%N
M=F5N9&4@96X@868@(@HB;75L:6=H961E<FYE(&9O<B!A="!G96UM92!K;V1E
M;B!T:6QB86=E('#E("5S(&5L;&5R(&UA;G5E;'0@:V]P:65R92!K;V1E;B`B
M"B)N961E;F9O<B!T:6P@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-#,@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED
M(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M2W5N;F4@:6MK92!S^&=E($Q$05`M<V5R=F5R96XN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C@V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(#QE;3YU;FQI
M;FL\+V5M/B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR,3D*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!D871E
M<F4@:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,Y-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK
M:V4@;W!D871E<F4@9&ES=')I8G5T:6]N<VQI<W1E+B`E<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G
M<W1R(")+=6YN92!I:VME('-K<FEV92!K;VYF:6=U<F%T:6]N(&9O<B!<(B5S
M7"(Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!F:6YD
M92!-;WII;&QA(%-I9&5B87(N($9O<G9I<R!D:6<@;VT@870@<VED96)A<F5N
M(&5R(.5B96XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,34T(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB
M)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*(DMU;FYE(&EK:V4@9VEV92!B<G5G97(@7"(E
M<UPB(&;X;&=E;F1E(')E='1I9VAE9&5R('1I;"!M87!P96X@7"(E<UPB.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")/
M<'1A;'0@=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B
M0V]U;G1R>2(*;7-G<W1R("),86YD(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)S97(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")/<')E="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")/<')E="!E;B!H96YV
M:7-N:6YG(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")/<')E="!E
M;B!N>2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDR"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@
M9F]L9&5R<R(*;7-G<W1R(")/<')E="!U;F1E<FUA<'!E(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M4VMA8F5R<R!R971T:6=H961E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3(*;7-G:60@(D-R961I
M="!C87)D(&YU;6)E<B(*;7-G<W1R(")+<F5D:71K;W)T+6YU;6UE<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(D-U8F$B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B
M3G5VYG)E;F1E(#0@9F%S97(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*
M;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B26YD97;F<F5N9&4@
M<V5S<VEO;B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D%K='5E
M;"!T:60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@
M(DYU=N9R96YD92!54DP@97(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*
M;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B3G5VYG)E;F1E(&)R=6=E
M<F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT
M(%=E871H97(B"FUS9W-T<B`B06MT=65L="!V96IR(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I
M;VXZ("(*;7-G<W1R(").=7;F<F5N9&4@=F5J<CH@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R(")!:W1U96P@<W1I;"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")4:6QP
M87,@;W!G879E<BP@9&5R(&)L:79E<B!U9&;X<G0L(&[E<B!D=2!L;V=G97(@
M:6YD(&D@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B2VQI<"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*
M;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B2VQI<"!V86QG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8W(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP97)N(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM
M<V=S='(@(DMY<FEL;&ES:R`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G
M<W1R(")+>7)I;&QI<VL@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX
M+54I(@IM<V=S='(@(DMY<FEL;&ES:R]5:W)A:6YS:R`H2T])."U5*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B5&IE:VMI970B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S(W,@IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*2(*;7-G<W1R("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M.2!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*
M;7-G<W1R(")$86=L:6<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G
M:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@<W1I9FEN
M9&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(W,`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S
M='(@(D1A=&%B87-E+6]P<VQA9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Y.`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Y."!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$
M871O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*
M;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B36]D=&%G96QS97-D871O
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<X.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C<X.0IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B
M1&%T;W9A;&<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*
M;7-G<W1R(")$86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(E-L970@:V]L;VYN92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5C96UB97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5C:6UA
M;'1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")-:6YD<VL@
M:6YD<GEK;FEN9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,3@W"FUS9VED(")$969A=6QT(@IM<V=S='(@(E-T86YD87)D(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G
M:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A<F1F87)V92(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38@;&EB+TAO<F1E
M+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G
M<W1R(")3=&%N9&%R9"UI9&5N=&ET970B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4W1A;F1A
M<F0M<VMA;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B
M1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6YI=&EO;F5R(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C,R-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(E-L970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@
M(E-L970@8V5L;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E-L
M970@9W)U<'!E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y
M"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(E-L970@;&]G8F]G(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C<W(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@
M4&5R;6ES<VEO;B(*;7-G<W1R(")3;&5T('1I;&QA9&5L<V5R(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S(@IM<V=S='(@(D9J97)N(&]G('5D<VQE="!B97-K961E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(E-L970@8V5L
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E-L970@
M:V]L;VYN92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E-L
M970@96MS:7-T97)E;F1E+"!A;'1E<FYA=&EV92!S:V%B96QO;B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4T(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A
M9V5S(@IM<V=S='(@(E-L970@8F5S:V5D97(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R(")3;&5T('1I;&QA9&5L<V5R(&9O<B!<(B5S7"(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-"!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\B"FUS9W-T<B`B4VQE="!T:6QL861E;'-E<B!F;W(@7"(E<UPB(&]G
M(&%L;&4@=6YD97)O<F1N961E('1I;&QA9&5L<V5R/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!R;W<B"FUS9W-T<B`B4VQE="!RYFMK92(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")3;&5T('9A;&=T92!I9&5N=&ET
M970B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E
M;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")3;&5T('5N9&5R;6%P<&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S
M='(@(E-L970@9&5N(&%K='5E;&QE(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4VQE="!D96X@86MT
M=65L;&4@<N9K:V4B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B3W!G<F%D97)I;F=S<V-R:7!T(%PB)7-<
M(B!S;&5T=&5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED
M(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(DQE=F5R:6YG<W1I9'-P=6YK="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$86YM87)K(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R
M:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D)E<VMR:78@<')O8FQE;65T(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X(&QI8B](;W)D92]&;W)M
M+G!H<#HY,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B0F5S
M:W)I=F5L<V4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-B!L
M:6(O2&]R9&4N<&AP.C(P-@IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&IE<B`H;V=SY2!I($AO<F1E
M)W,@;&]G9FEL*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q
M,"!L:6(O2&]R9&4N<&AP.C(Q,`IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B1&5T86QJ
M97(@97(@<VMR979E="!T:6P@;&]G8F]G96X@868@:&5N<WEN('1I;"!A9&UI
M;FES=')A=&]R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B561V:6ML:6YG(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G
M<W1R(")$=6=P=6YK="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS
M9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(D1U9W!U
M;FMT(&9O<B!S:61S=&4@=&EM93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B1'5G
M<'5N:W0Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S
M='(@(E)E=&YI;F<@=F5N<W1R92!T:6P@:/AJ<F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")2971N:6YG(&CX:G)E('1I;"!V
M96YS=')E(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I
M<F5C=&]R>2(*;7-G<W1R(")+871A;&]G(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G
M<W1R(")6:7,@=&ED(&UE9"`R-"!T:6UE<C\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
M26YD<W1I;&QI;F=E<B!F;W(@=FES;FEN9R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E
M8V%S="(*;7-G<W1R(")6:7,@=61D>6)E;F1E('9E:G)U9'-I9W0B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T
M("A4048I(@IM<V=S='(@(E9I<R!V96IR=61S:6=T("A4048I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y.2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C<Y.0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5FES;FEN9W-F
M;W)M870B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ(&QI
M8B](;W)D92]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B3W9E<F1R86=E;'-E<VYO=&ET<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")&
M;W)T<GED('-L971N:6YG(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<"(*;7-G<W1R(")$=2!MY2!I:VME(&MA;&1E(&UA:6YT96YA;F-E+G!H
M<"!D:7)E:W1E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B26YD96AO;&1E<B!D96X@9OAR<W1E
M('+F:VME(&9E;'1N879N93\@2'9I<R!J82P@;6%R:^ER(&1E;FYE(&)O:W,Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$96X@9&]M:6YI
M:V%N<VME(%)E<'5B;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`B1&5N(&1O;6EN:6MA;G-K92!297!U8FQI:R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA
M=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B2&%R(&1U(&EK:V4@
M;F]G96X@:V]N=&\_($UE;&0@9&EG('1I;"XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-3,@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C@U,PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B2&5N="(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U,R!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G:60@
M(D1O=VYL;V%D("5S(@IM<V=S='(@(DAE;G0@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")(96YT(&=E;F5R
M97)E="!K;VYF:6=U<F%T:6]N(&YE9"!S;VT@4$A0+7-C<FEP="XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(")2=6QL96=A
M<F1I;BUL:7-T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I
M9"`B1')U9W,B"FUS9W-T<B`B365D:6MA;65N=&5R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR(&QI8B].
M970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--
M4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@
M=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"B)%36%I;"UT:6PM4TU3(&=A=&5W
M87DM9')I=F5R+"!F;W(@;W!E<F%T^')E<BP@<V]M('5D8GED97(@9&5N;F4@
M<V5R=FEC92XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM
M<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%
M<75A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HS,C4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,34*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(E)E9&EG97(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P(&QI8B](;W)D
M92]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B
MQFYD<F4@8FQO:R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(L9N9')E
M(&=R=7!P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`IM
M<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(L9N9')E('1I;&QA9&5L
M<V4B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(L9N9')E('1I;&QA9&5L<V5R(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+&;F1R
M92!T:6QL861E;'-E<B!F;W(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+&;F1R
M92!V86QG(&9O<CHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B
MQFYD<F4@=&EL;&%D96QS97(@9F]R(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BQFYD<F4@=&EL;&%D96QS97(@
M9F]R("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%
M9'5C871I;VXB"FUS9W-T<B`B561D86YN96QS92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16=Y<'0B"FUS9W-T<B`BQF=Y<'1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L
M(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED
M(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB
M"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-CD@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(F5-86EL(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHV."!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$P"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(F4M;6%I;"UA
M9')E<W-E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(D4M;6%I;"UA9')E<W-E<B!S:V%L('!A<W-E
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(D4M;6%I;"!M960@8F5K<N9F=&5L<V4B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,2!L:6(O3F5T+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T
M97=A>2(*;7-G<W1R(")%;6%I;"UT;RU335,@1V%T97=A>2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3D*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(E-M:6QE>7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM
M<V=S='(@(E1O;2!B97-K960N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$U,"!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,C0S"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT.#0@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8V,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z-S`U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R("));G1E="!R97-U;'1A="XB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S(&QI8B](;W)D92]3
M44PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS
M(@IM<V=S='(@(E1O;70@=61T<GEK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B06MT:7;I<B!I
M;F1SYG1T96QS92!A9B!B:6QL961E<B!F<F$@1F]T;V=A;&QE<FEE<B!I('1E
M:W-T/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@(D5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EV
MZ7(@:/AJ<F4M:VQI:R!C;VYT97AT+6UE;G4_(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4X."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDS
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@X(&QI8B](;W)D92]&;W)M+G!H
M<#HR-SDS"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")3;'5T+>5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I
M9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B1F]R<W3X<B!E9&ET97)I;F=S
M=N9R:W3X:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@
M(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R
M9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G
M<W1R("(B"B));F1T87-T(&5T('-I:VME<FAE9'-S</AR9W-MY6PL('-O;2!D
M=2!V:6P@8FQI=F4@<W!U<F=T+"!NY7(@9'4@:&%R(&)R=6<@9F]R("(*(F%T
M(.9N9')E(&1I="!K;V1E;W)D+"!F>"`G:'9A9"!E<B!D:70@:^9L961Y<G,@
M;F%V;C\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0IM<V=I9"`B16YT97(@=&AE(&EM86=E(%52
M3"!H97)E(@IM<V=S='(@(DEN9'1A<W0@55),('1I;"!B:6QL960@:&5R(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED
M(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B26YD=&%S="!B
M;V=S=&%V97(@;F5D96YF;W(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L
M($=U:6YE82(*;7-G<W1R("+&:W9A=&]R:6%L($=U:6YE82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B17)I=')E82(*;7-G<W1R("+&<FET<F5A(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP
M.CDT"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0X"FUS9VED(")%<G)O<B(*;7-G<W1R(")&96IL(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,@;&EB+TAO<F1E
M+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(D9E:FP@=F5D(&1A;FYE;'-E
M(&%F(&)L;VLZ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A
M;F-H;W(Z("5S(@IM<V=S='(@(D9E:FP@=6YD97(@<VQE=&YI;F<@868@<WEN
M8RUHYF=T93H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO
M9SH@)7,B"FUS9W-T<B`B1F5J;"!U;F1E<B!S;&5T;FEN9R!A9B!S>6YC(&QO
M9SH@)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V
M."!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(D9E:FP@
M=6YD97(@:&5N=&YI;F<@868@:6YD:&]L9#H@)7,B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D9E:FP@=6YD97(@
M;W!D871E<FEN9R!A9B!K;V1E;W)D.B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+B(*;7-G<W1R(")&96IL(&9O<F)U;F1E="!M960@92UP
M;W-T(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS
M9W-T<B`B1F5J;"!U;F1E<B!S:W)I=FYI;F<@868@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1L86YD(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")%=&AI;W!I82(*;7-G<W1R("+&=&EO<&EE;B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FES
M:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U
M<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V
M97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B2'9E<B!K=F%R=&5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S
M(@IM<V=S='(@(DAV97)T(#(N(&UI;G5T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%
M=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DAV97(@:&%L=F4@;6EN=70B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")(=F5R
M(#4N(&UI;G5T(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HV,"!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED
M(")%=F5R>2!,;V=I;B(*;7-G<W1R(")!;'1I9"!V960@;&]G:6XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B2'9E<B!H86QV92!T:6UE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED
M(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2'9E<B!M:6YU="(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E
M<SHB"FUS9W-T<B`B16MS96UP96QVYG)D:65R.B(*"B,Z(&%D;6EN+V-M9'-H
M96QL+G!H<#HU,2!A9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO<W%L<VAE
M;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")59&;X<B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0W-0HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM
M<V=S='(@(E5D=FED(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B1F]L9"!S:61E
M<&%N96P@=60B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,38X(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP
M96-T960@)RDG(@IM<V=S='(@(D9O<G9E;G1E9&4@)RDG(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-2!L:6(O2&]R9&4O4U%,+TME
M>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B1F]R=F5N=&5D92!R96YT(&]R
M9"!E;&QE<B!C:71E<F5T('/X9V5T97)M(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D9O<N9L9&5L<V5S
M9&%T;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N
M="(*;7-G<W1R(")%:W-P;VYE;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*
M;7-G<W1R(")&1RUF87)V92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B1E10+6QA
M9W)I;F<@868@;W!SYG1N:6YG(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-Q;"YP:'`Z,C(P(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP.C(R,`IM<V=I
M9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@YFYD<F4@:6YD<W1I;&QI;F=E<FYE+B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.CDX"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@9N4@
M9F]R8FEN9&5L<V4@=&EL($Q$05`@<V5R=F5R96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.CDX(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@9F]R8FEN9&4@=&EL(%--0BUS97)V97(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<@;&EB+U9&4R]F='`N
M<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F
M<F]M(%PB)7-<(BXB"FUS9W-T<B`B1F5J;"!U;F1E<B!K;W!I97)I;F<@9G)A
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,B!L
M:6(O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!K;W!I
M97)E('1I;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX-R!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")+
M=6YN92!I:VME(&5T86)L97)E(&YY(%-!4TPM9F]R8FEN9&5L<V4N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU,#$*(SH@;&EB+U9&4R]F='`N<&AP.C<U-2!L:6(O5D93
M+W-M8BYP:'`Z-3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M
M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!F;'ET=&4@=&EL
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V-2!L
M:6(O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT93H@
M)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")3;75K="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD
M<_AE<FYE("A-86QV:6YA<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N
M9',B"FUS9W-T<B`B1N9R^&5R;F4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C,X(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R
M;W(Z(@IM<V=S='(@(D3X9&5L:6<@9F5J;#HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X
M97,B"FUS9W-T<B`B1F%K<VEM:6QE<B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME
M(@IM<V=S='(@(D;X;&5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(D;X;&5S.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM
M<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B1N4@8GEG97(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")&Y2!S;F5B>6=E<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")&96QT;6%T<FEC92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,S,C4*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(D9I
M9VQE="!#05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R.0IM<V=I9"`B1FEG;&5T(&9O;G0B
M"FUS9W-T<B`B1FEG;&5T('-K<FEF='-T>7!O9W)A9FDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6PB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D%N
M=&%L(&9I;&5R.B`E<R!F:6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,`HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.2!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")!;G1A;"!F:6QE<CH@)7,@9FEL97(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B1FEL:.5N9'1E<FEN9R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<P(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA
M;64B"FUS9W-T<B`B1FEL;F%V;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y-S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S<*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(D9I;'9A;&<B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#@V(&QI8B](;W)D92]&;W)M+G!H<#HQ-#@V"FUS9VED
M(")&:6QE('5P;&]A9"(*;7-G<W1R(")&:6QL86=R:6YG(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`R(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,#(*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R(")&:6QL86=R:6YG(&EK:V4@=6YD97)S=/AT=&5T+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R(")&:6QT<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B
M1FEN;&%N9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I
M<G-T($AA;&8B"FUS9W-T<B`B1OAR<W1E(&AA;'9D96PB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(D;X<G-T92!K=F%R=&%L(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PHC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@
M<F%T:6\B"FUS9W-T<B`B1FEK<^ER('-T^')R96QS97-F;W)H;VQD(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&
M;&EP(@IM<V=S='(@(D9L:7`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M(")&;'ED96YD92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B5.5G92(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR,S<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W(&QI8B]61E,O
M<W%L+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T(@IM<V=S='(@(DUA<'!E("5S(&5K<VES=&5R97(@:6MK
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B5'EP;V=R869I9F%R=F4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS
M9W-T<B`B36%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")&;W(@=V5B<')O9W)A
M;6UE<BP@<V]M(&EK:V4@=6YD97)S=/AT=&5R(&)I;&QE9&5R(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM
M<V=S='(@(E9E:G)U9'-I9W0@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@
M=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A
M;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT
M(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB561S:6=T<V1A9V4@*&)E
M;>9R:R!A="!D96X@<F5T=7)N97)E('9E:G)U9'-I9W0@=F5D<OAR97(@8N5D
M92!D86<@;V<@;F%T.R!E="`B"B)S=&]R="!A;G1A;"!H97(@:V%N(')E<W5L
M=&5R92!I(&5N(&UE9V5T(&)R960@8FQO:RDB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_
M(@IM<V=S='(@(D=L96UT(&1I="!K;V1E;W)D/R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU
M;&%R97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O
M<G1U;F4B"FUS9W-T<B`B3W)D<W!R;V<B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")%<&EG<F%M
M='EP92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R
M='5N97,B"FUS9W-T<B`B17!I9W)A;6UE<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")%<&EG<F%M
M;65R(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED
M(")&;W)U;7,B"FUS9W-T<B`B1F]R82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E9I9&5R97-E
M;F1E;'-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B1G)E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B
M1G)A;65S(@IM<V=S='(@(E)A;6UE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M(@IM<V=S='(@(D9R86YK<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N:W)I9RP@365T<F]P
M;VQI=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@
M(D9R86YS:R!'=7EA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R(")&<F%N<VL@4&]L>6YE<VEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&
M<F%N<VME('-Y9&QI9V4@5&5R<FET;W)I97(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D9R
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1G)A
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@
M(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1G5L9"!B97-K<FEV96QS92(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B1G5L9&WE;F4B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D9U;&1T
M(&YA=FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*
M;7-G<W1R(")'86QL97)I(&AV;W)F<F$@8FEL;&5D92!S:V%L('1A9V5S(&9R
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L;&5R
M:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G
M:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N97+I
M<B`E<RUK;VYF:6=U<F%T:6]N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@
M(D=E;F5R97)E="!K;V1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDP(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S
M='(@(D=E;W)G:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@
M(E1Y<VML86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A
M<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE
M(@IM<V=S='(@(D9O<FYA=FXB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*
M;7-G<W1R(")'<G5N9&SF9V=E;F1E(&EN9'-T:6QL:6YG97(B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B561F
M^'(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E
M;"(*;7-G<W1R(")']F1E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3,Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")'
M;V]G;&4@36%P<R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G
M:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE+7/X9VYI;F<B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@
M(D=R87ES8V%L92(*;7-G<W1R(")'<N5T;VYE<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B1W+F:V5N;&%N9"(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`B1W+F<VL@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDU(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA
M;F0B"FUS9W-T<B`B1W+X;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B
M"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS
M9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P<&4M861M
M:6YI<W1R871I;VXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*(SH@;&EB+TAO
M<F1E+T=R;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y
M"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R
M(")'<G5P<&5N879N92!MY2!I:VME(';F<F4@=&]M;64B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(D=R;W5P7VQD87`Z($MA;B!I:VME('1I;&;X
M:F4@9W)U<'!E("5S+B!397)V97)E;B!M96QD97(Z("(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$R-"!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@
M2V%N(&EK:V4@<VQE='1E(&=R=7!P92`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,W.0HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R(")'<F]U<%]L9&%P.B!+86X@:6MK92!O<&1A=&5R92!G<G5P<&4@)7,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,Q-`HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B
M"FUS9W-T<B`B1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM
M<V=S='(@(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(D=U871A;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C(V(&QI8B](;W)D92]097)M<R]522YP:'`Z,C(V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(D?F<W1E=&EL;&%D96QS97(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B
M1^9S=&5B;V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN
M96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@
M(D=U:6YE82U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS
M9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P
M(&QI8B](;W)D92]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B
M2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,
M07)E82!NYF=T97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N('-I9'-T92!C
M96QL92!I('+F:VME+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB
M"FUS9W-T<B`B2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@870@<VQE='1E
M(&1E;B!S:61S=&4@:V]L;VYN92!I('1A8F5L+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O
M=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V
M:7,@870@<VQE='1E(&1E;B!S:61S=&4@<N9K:V4@:2!T86)E;"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-R!L:6(O2&]R9&4O075T
M:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")(5%10+>9G=&YI;F<@:6MK92!F=6YD970N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&'O=&DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R
M(")(87-H+6%L9V]R:71M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(D1I<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3$T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,3D@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Y,30*;7-G:60@(DAE861E<B(*;7-G<W1R(")4;W!T
M96MS="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-C$*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`B3W9E<G-K<FEF=&5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M(@IM<V=S='(@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS
M9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(DMR869T:6<@=&]R9&5N(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/
M+3@X-3DM."U)*2(*;7-G<W1R(")(96)R86ES:R`H25-/+3@X-3DM."U)*2(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R(")(^&ID92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC
M.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ
M.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B2&KF;'`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS
M9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")(:N9L<"!T:6P@<F5D
M:6=E<FEN9W-VYG)K=/AJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(DAJYFQP97(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G
M:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FYG)E(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`B2&5R(&5R('-T87)T96X@868@9FEL96XZ(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@
M(DAI9V@B"FUS9W-T<B`B2/AJ(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS
M9VED(")(;U]M92(*;7-G<W1R(")(:F5M(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")(96QL
M:6=S^"`H5F%T:6MA;G-T871E;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$U-#@@;&EB+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM
M<V=S='(@(DAJ96TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G
M:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")0<FEV870M861R97-S92(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B2&]M92!$:7)E8W1O
M<GDB"FUS9W-T<B`B2&IE;6UE:V%T86QO9R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T
M<B`B4')I=F%T+71E;&5F;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A
M<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@56=Y;&1I9R`E<R!834P@9&%T82!PY71R
M=69F970@:2!B97-K960@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C(Y.2!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN9V5N(&)E<VME
M9"!S=F%R97(@=&EL(&]B:F5K="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#0U(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!)
M;G1E="!O8FIE:W0@868@='EP92`E<R!F=6YD970@:2!B97-K960@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3$@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(%-L971T961E("5S(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,C(S(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS
M9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@26YT96=R871I;VYS;6%S:VEN96X@:W+F=F5R(%!(4"UU9'9I
M9&1E;'-E("=D;VUX;6PG(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HU,3(@;&EB+TAO<F1E+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I
M:VME(&1A;FYE(&YY="!834PM='+F(&9O<B!O8FIE:W0@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#@@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z($MA;B!I:VME('-L971T92`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT.#,@;&EB+TAO<F1E+TMO;&%B+G!H<#HT
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6MK92!I;F1H96YT92!-24U%+4E$
M(&9O<B!D96QE;B!A9B!T>7!E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3DW(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I
M:VME('-Y;FMR;VYI<V5R92`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,S,W(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($MA;B!I:VME('-Y;FMR;VYI<V5R92!D96QI;F=E<CH@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,"!L:6(O2&]R9&4O2V]L86(N<&AP
M.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W
M;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%5K96YD="!D
M96QI;F<@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@
M(E9A;F1R970@<W1R96<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B5F%N9')E="!F;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R
M(")686YD<F5T.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B2'9O<F1A;B!B87(@9'4@
M9&EG(&%D(&UE9"!A="!H879N92!H97(_("A);F1R87!P;W)TZ7(A*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(DAV;W(@;6%N9V4@:V]L;VYN97(@^&YS:V5R(&1U
M(&%T('-A;6UE;FSF9V=E/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T
M:&5R93\B"FUS9W-T<B`B2'9O<B!M86YG92!F96QT97(@*&MO;&]N;F5R*2!E
M<B!D97(_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2'9O<B!M86YG92!RYFMK97(@^&YS
M:V5R(&1U(&%T('-A;6UE;FSF9V=E/R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*;7-G:60@
M(DAU;6ED:71Y(@IM<V=S='(@(D9U9W1I9VAE9"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T
M<B`B1G5G=&EG:&5D.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*
M;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")5;F=A<FXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN
M<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(D]P<F5T=&5L<V4@868@24U!4"UM87!P92!F96IL961E.B`E
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,CDU(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B4VQE=&YI;F<@868@24U!4"UM87!P92!F
M96IL961E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR-#(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B1&5F:6YE<FEN
M9R!A9B!K=F]T92!F;W(@24U!4"UM87!P92!F96IL961E.B`E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`M861R97-S92(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<@;&EB+TAO
M<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B25`M861R97-S92!I:VME('1I;&?F;F=E
M;&EG92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y
M(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))
M4"UA9')E<W-E(&EK:V4@:6YD96YF;W(@0TE$4BUB;&]K+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@
M;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS
M9W-T<B`B26YD<^9T('+F:VME(&;X<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC
M96QA;F0B"FUS9W-T<B`B27-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")+=6X@:6MO;F5R
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N97(@9F]R("5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(DEK;VYE<B!M960@=&5K<W0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM
M<V=S='(@(DED96YT:71E='-N879N.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C8P,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z-C`P"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RXB"FUS9W-T<B`B2'9I<R!D96X@:6MK92!V:7-T(&MO<G)E:W0L("5S(&9O
M<B!A="#E8FYE(&1E;B!I(&5T(&YY="!V:6YD=64N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+B(*;7-G<W1R("(B"B)(=FES(&1U(&EK:V4@<V5R(&YO9V5N(&EK
M;VYE<B!V960@8G)U9R!A9B!);G1E<FYE="!%>'!L;W)E<B!S:V%L(&1U(&WE
M<VME("(*(FAA:VME(&1E;FYE(&)O:W,@868@9F]R(&%T('-LY2!03D<M=')A
M;G-P87)E;G,@9G)A+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@
M8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A
M;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@
M(B(*(DAV:7,@9'4@<V5R(&1E;FYE(&)E<VME9"!I('-T961E="!F;W(@970@
M8FEL;&5D92P@<^4@=FEL(&1U(&EK:V4@:W5N;F4@<V4@(@HB9&5T(&D@9&EN
M(&YE="ULYG-E<B!E9G1E<B!O<&SF9VYI;F<N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"FUS9VED
M("));6%G92!0<F5V:65W.B(*;7-G<W1R(")":6QL960M9F]R:.5N9'-V:7-N
M:6YG.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")":6QL960M
M55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$X"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(D)I
M;&QE9"U54DPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDB"FUS9W-T<B`B0FEL;&5D92!F<F$@9V%L;&5R:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM
M<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")":6QL961E(&9R
M82!G86QL97)I.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*
M;7-G<W1R(")":6QL960M;W!LYF=N:6YG(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")":6QL961E<B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-`HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&5R:6YG+"!T
M<FEN("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@
M(DEM<&]R=&5R961E(&9E;'1E<CH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@
M(DEM<&]R=&5R961E(&9E;'1E<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@
M4F]W($%F=&5R(@IM<V=S='(@(DEN9'/F="!RYFMK92!E9G1E<B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-"!L:6(O2&]R
M9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B1F5J;&%G=&EG(&AA;F1L:6YG<VMO
M9&4@86YG:79E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+B(*;7-G<W1R(")5:V]R<F5K="!B<G5G97)N879N(&]G+V5L;&5R
M(&MO9&5O<F0N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*
M;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB56MO
M<G)E:W0@8G)U9V5R;F%V;B!E;&QE<B!A;'1E<FYA=&EV(&%D<F5S<V4N(%!R
M^'8@:6=E;B!E;&QE<B!K;VYT86MT(&1I;B`B"B)A9&UI;FES=')A=&]R+"!H
M=FES(&1U(&AA<B!B<G5G(&9O<B!Y9&5R;&EG97)E(&AJYFQP+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@
M(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")&;W+X9R!I;F1R>6MN:6YG(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:65N(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR-30*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B26YD:79I9'5E
M;&QE(&)R=6=E<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS
M9W-T<B`B26YD;VYE<VEE;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N
M(@IM<V=S='(@(DEN9F]R;6%T:6]N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V
M86EL86)L92XB"FUS9W-T<B`B26YF;W)M871I;VX@:6MK92!LYFYG97)E('1I
M;&?F;F=E;&EG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E
M<B(*;7-G<W1R("));F1SYG0@:V]L;VYN92!E9G1E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PIM
M<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(DEN9'/F="!B:6QL961E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM
M<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(DEN9'/F="!T86)E;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("));F1SYG0@=V5B+6AE;G9I
M<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*
M;7-G<W1R("));F1SYG0@:V]L;VYN92!F^'(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(DEN9'/F="!E;B!N>2!K;VQO;FYE(&5F=&5R(&1E;B!A:W1U96QL92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9'/F="!E;B!N>2!K;VQO;FYE(&;X
M<B!D96X@86MT=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9'/F="!E;B!N
M>2!RYFMK92!E9G1E<B!D96X@86MT=65L;&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("));F1SYG0@96X@;GD@<N9K:V4@9OAR(&1E;B!A:W1U96QL92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B26YD<^9T(&5N('!A<F%G<F%F(&5F=&5R(&1E="!A
M:W1U96QL92!P=6YK="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN9'/F="!E
M;B!P87)A9W)A9B!F^'(@9&5T(&%K='5E;&QE('!U;FMT(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`B26YD<^9T(&%L=&5R;F%T:78@<VMA8F5L;VXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@
M96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE
M=R!P87-S=V]R9#HB"FUS9W-T<B`B26YD=&%S="!E;B!E+6UA:6PM861R97-S
M92P@:'9O<G1I;"!D=2!K86X@;6]D=&%G92!D970@;GEE(&MO9&5O<F0Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B26YD<^9T
M(&-E;&QE(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E
M(@IM<V=S='(@(DEN9'/F="!C96QL92!F^'(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E
M<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DEN9'/F="!K;VQO;FYE(&5F=&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
M26YD<^9T(&MO;&]N;F4@9OAR(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-3`@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DEN9'/F="!B97-K961E<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R
M("));F1SYG0@<&%R86=R868@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(DEN9'/F="!P87)A9W)A9B!E
M9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B
M26YD<^9T('+F:VME(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B
M969O<F4B"FUS9W-T<B`B26YD<^9T('+F:VME(&;X<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B26YD
M=&%S="!D970@:W+F=F5D92!S=F%R('1I;"!S:6MK97)H961S<W#X<F=S;>5L
M970Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));F1S
MYG0OYFYD<F4@8FEL;&5D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*
M;7-G<W1R("));F1SYG0OYFYD<F4@:&5N=FES;FEN9R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(E5T:6QS='+F:VME;&EG(&MR961I="!T:6P@870@<V5N9&4@
M=&EL(&1I<W1R:6)U=&EO;G-L:7-T96XN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`B571I;'-T<N9K:V5L:6=E(&MR961I="XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(DAE;'1A;"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")(96QT86QS;&ES
M=&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM
M<V=S='(@(E5G>6QD:6<@541(+B`H57-E<B!$871A($AE861E<BDN(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(@;&EB+TAO<F1E
M+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z
M:7`N<&AP.C$Y-"!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G
M:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B56=Y;&1I9V4@6DE0+61A
M=&$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A
M;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")59WEL9&EG="!A<'!L:6MA=&EO
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(E5G>6QD:6=T
M('-K<FEP="U)1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q-3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R.3D*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(E5G
M>6QD:6=E(&1A=&$@869S96YD="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I
M;VX@861D<F5S<RXB"FUS9W-T<B`B56=Y;&1I9R!D97-T:6YA=&EO;BXB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,2!L:6(O2&]R
M9&4O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+T-O;7!R97-S
M+V1B>"YP:'`Z,3,Y(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM
M<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")59WEL9&EG="!F
M:6QF;W)M870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U
M"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")59WEL9&EG
M(&QI8V5N<V[X9VQE+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(E5G>6QD:6<@<&QA8V5R:6YG(&%N9VEV970N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED
M(&US9U]T>7!E+B(*;7-G<W1R(")59WEL9&EG(&US9U]T>7!E+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B56=Y;&1I9R!E
M;&QE<B!M86YG;&5N(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+B(*;7-G<W1R(")59WEL9&EG92!E;&QE<B!M86YG;&5N
M9&4@<&%R86UE=')E+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR
M-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M56=Y;&1I9V4@9F]RYFQD<F4M=&EL;&%D96QS97(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R
M(&ED+B(*;7-G<W1R(")59WEL9&EG('!A<G1N97(M:60N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D
M=6-T(&-O9&4N(@IM<V=S='(@(E5G>6QD:6<@<')O9'5K="UK;V1E+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B56=Y;&1I9R!P<F]T;VMO
M;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E
M<UPB(@IM<V=S='(@(E5G>6QD:6<@;6]D=&%G97(Z(%PB)7-<(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-C,*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#@P(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O
M8FIE8W0B"FUS9W-T<B`B56=Y;&1I9W0@9&5L:6YG<V]B:F5K="(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B
M26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B56=Y;&1I9R!O<')I
M;F1E;'-E<V%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB
M"FUS9W-T<B`B56=Y;&1I9R!U;FEC;V1E+61A=&$N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@
M(DEN9&)O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DEN=F5R=.ER
M(&UA<FME<FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A;BP@1&5N(&ES;&%M:7-K(')E<'5B
M;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA;F0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")-86XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM
M<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B4W1E9'9I<R!T;W)D
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G
M<W1R(")59'-T961E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DET86QI96YS
M:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DET86QI96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A
M<GDB"FUS9W-T<B`B2F%N=6%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB
M"FUS9W-T<B`B2F%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!A;G-K
M("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB
M"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM
M<V=S='(@(DIO<F1E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DIU<W3I<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")#96YT<NER(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*
M;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("),:6=E(&UA<F=E;F5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")696YS=')E:G5S
M=&5R970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")(
M^&IR96IU<W1E<F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*
M;7-G<W1R(")+87-A:VAS=&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(V-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R
M(")"979A<B!O<FEG:6YA;#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R(")+96YY82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#4@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M2V5R8F5R;W,@<V5R=F5R(&%F=FES=&4@9V]D:V5N9&5L<V4@868@:61E;G1I
M=&5T+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R
M;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F4M/&5M/DYE=V)I97,\+V5M/B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G
M<W1R(").^&=L92US:V%B96QS92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q-"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30*;7-G
M:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(").^&=L92UF:6YG97)A9G1R
M>6LB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM
M<V=S='(@(D[X9VQE;.9N9V1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I
M9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B3OAG;&5T>7!E(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(").^&=L96%N
M=F5N9&5L<V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M-#`@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(D[X9VQE(&5K<VES=&5R97(@86QL97)E9&4@<.4@9&5N(&]F9F5N=&QI9V4@
M;OAG;&5S97)V97(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS
M9VED(")+:61S(@IM<V=S='(@(D+X<FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(E-Y9&MO<F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DYO<F1K;W)E82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B:V]R
M96%N<VL@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS
M9W-T<B`B2W5W86ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*
M;7-G<W1R(")+:7)G:7-I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")59&9O<FUN:6YG(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B4W!R;V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S
M='(@(E-I9'-T92!H86QV9&5L(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C@X"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")3:61S
M=&4@:V]D96]R9'/F;F1R:6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V
M(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM
M<V=S='(@(E-I9'-T92!K=F%R=&%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3@*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B4VED<W0@;W!D
M871E<F5T.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-R!L:6(O
M2&]R9&4O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(@IM<V=S='(@(E-I9'-T92!L;V=I;CH@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,3D@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S
M(@IM<V=S='(@(E-I9'-T92!I;F1L;V=N:6YG.B`E<R!F<F$@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30@;&EB+TAO<F1E+T%U=&@N<&AP
M.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B4VED<W1E
M(&QO9VEN.B!!;&1R:6<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS
M9W-T<B`B3&5T;&%N9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM
M<V=I9"`B3&%W(@IM<V=S='(@(DQO=B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM
M<V=S='(@(DQA>6]U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(B"FUS9W-T<B`B5&]M('9E9"!I;F=E;B!R86UM97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*;7-G:60@
M(DQE9G0B"FUS9W-T<B`B5F5N<W1R92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,#$@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE
M9G0@:&5A9&5R(@IM<V=S='(@(E9E;G-T<F4@=&]P=&5K<W0B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DW(&QI8B](;W)D92]&;W)M+G!H<#HS
M,#DW"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")696YS=')E(';F<F1I
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M3&5V96PB"FUS9W-T<B`B3FEV96%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("),:6)E<FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB>65N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T
M96EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B4W3X=G)E9VXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I
M9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),970@<F5G;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!2
M86EN($5A<FQY(@IM<V=S='(@(DQE="!R96=N('1I9&QI9W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG
M:'0@4F%I;B!,871E(@IM<V=S='(@(DQE="!R96=N('-E;G0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG
M:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B3&5T(&)Y9V4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B3&5T(&)Y9V4@;65D('1O<F1E
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q
M"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DQE="!S;F4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3&5T('-N92!B>6=E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R
M(")6:71T:6=H960B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@
M(DAE;G9I<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*
M;7-G<W1R(")&;W)B:6YD('!U;FMT97(@=&EL.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S4*;7-G
M:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B1F]R8FEN9"!E+6UA:6PM861R
M97-S96X@;65D(&EN9'-K<FEV;FEN9W-S:61E;B!V960@9G)E;79I<VYI;F<B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP
M:'`Z,3@R"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B2&5N=FES;FEN9V5R(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B
M"FUS9W-T<B`B3&EN=7@M:VEK<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C0V(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H
M<#HT-@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G
M:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),
M:7-T92`M(&)R=6=E<B!K86X@<V4@;6%P<&5N(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&ES
M="!D871A8F%S97(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM
M<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")/<&QI<W1N:6YG(&%F
M(&AJYFQP965M;F5R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&ES="!T86)E;&QE<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(DQI<W1E+4%R8VAI=F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4X.2!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T+4AE;'`B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES
M="U)9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/
M=VYE<B(*;7-G<W1R("),:7-T+4]W;F5R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3,@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES="U0;W-T(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB
M92(*;7-G<W1R("),:7-T+5-U8G-C<FEB92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DP(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T
M+55N<W5B<V-R:6)E(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*
M;7-G<W1R("),:7-T;FEN9R!A9B!S97-S:6]N<R!F96IL961E.B`E<R(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B3&ES=&YI;F<@868@
M8G)U9V5R92!F96IL961E.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`B5FES;FEN9R!A9B!B<G5G97)E(&5R('-LY65T(&9R82XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`B3&ET=&5R871U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M=&AU86YI82(*;7-G<W1R("),:71A=65N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R
M(")(96YT97(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86P@=&ED.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N
M9"!4:6UE(@IM<V=S='(@(E)E9VEO;F%L9&%T82!O9R!T:60B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W,@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<R(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HR,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-3<*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E-T960B"@HC
M.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR
M,#`@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U"FUS9VED("),;V<@:6XB"FUS9W-T<B`B3&]G(&EN9"(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I
M;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("),;V<@868@=&ED;&EG97)E('-Y
M;FMR;VYI<V5R:6YG<W-E<W-I;VYE<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3&]G('5D
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*
M;7-G<W1R("),;V<@:6YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B3&]G:6XM;W!G879E<B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-2!L:6(O2&]R9&4O075T
M:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*
M;7-G<W1R("(B"B),;V<@:6YD(&9E:FQE9&4@9F]R9&D@9&ET(&)R=6=E<FYA
M=FX@96QL97(@:V]D96]R9"!B;&5V(&%N9VEV970@9F]R:V5R="XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3$@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("),;V=I;F0@;6ES
M;'EK:V5D97,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S
M='(@(DQA;F<@=&5K<W0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*
M;7-G:60@(DQO=F4B"FUS9W-T<B`B2^9R;&EG:&5D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G
M<W1R("),878B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S
M(@IM<V=S='(@(E-MY2!G<N9S:V4@=&5G;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO
M=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B4VWE(&QA=&EN<VME('1E9VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(E-MY2!R;VUE<G1A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B
M"FUS9W-T<B`B3'5X96UB;W)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0S.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS
M9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS
M9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS-B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1BUB:6QA9R!I;F1H;VQD="!I
M;F=E;B!D871A+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B
M"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T
M<B`B36%C86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%K961O;FEE
M;BP@1&5N('1I9&QI9V5R92!J=6=O<VQA=FES:V4@<F5P=6)L:6LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-K87(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM
M<V=S='(@(DUA9VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*
M;7-G:60@(DUA:6PB"FUS9W-T<B`B12UM86EL(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")%
M+6UA:6PM861M:6YI<W1R871O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?
M:RXN+B(*;7-G<W1R(")$86X@:&5N=FES;FEN9RXN+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA>7-I82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=F5R;F4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T
M<B`B(@HB2.5N9'3I<B!L:7-T96X@868@:V%T96=O<FEE<BP@<V]M(&1U('-K
M86P@;6%R:V5R92!E;6YE<B!M960L(&]G(&9A<G9E<FYE+"`B"B)D97(@<VMA
M;"!K;GET=&5S('1I;"!D:7-S92!K871E9V]R:65R+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS9VED(")-87`R-"!M
M87`B"FUS9W-T<B`B36%P,C0M:V]R="(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T
M<B`B36%P475E<W0M:V]R="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")+;W)T
M;.9G;FEN9R!G96UT+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R=',B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-
M87)G:6XB"FUS9W-T<B`B36%R9V5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N
M<&AP.C0X"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM
M<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUA
M<FOI<B!M960@4V5T+U5S970M9FQA9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C0Y(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*
M;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I(@IM<V=S='(@(DUA<FOI<B!M960@86YD<F4@9FQA9R`H9G@@
M5FEG=&EG+T)E<W9A<F5T*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL
M($ES;&%N9',B"FUS9W-T<B`B36%R<VAA;&SX97)N92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`B3W9E<F5N<W!A<W-E;F1E(&9E;'1E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET
M:75S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA>"!T
M:6QL861T(&MR961I="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+B(*;7-G<W1R(")-86MS:6UU;2!B97-K960M9&5L92!O=F5R<VMR961E
M="XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I9"`B36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DUA:W,N('1E;7`N('-I9'-T
M(#(T('1I;65R.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I
M9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B36%K<RX@=&5M
M<"X@<VED<W1E(#8@=&EM97(Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED
M(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DUA
M:W-I;75M(&%N=&%L(&%F('!O<G1A;&)L;VMK92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-PHC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B36%K<VEM=6ULYFYG9&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-86HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D
M:6-I;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B365D;&5M;65R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R
M(")-96YU+71I;'-T86YD.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM
M<V=S='(@(D9O<NEN(&-E;&QE<B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G
M92(*;7-G<W1R(")"97-K960B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*(D)E<VME9"!S=6-C97-F=6QD="!V97)I9FEC97)E
M="!M960@=6YD97)S:W)I=F5R96YS(&-E<G1I9FEK870@:W5N;F4@:6MK92`B
M"B)V97)I9FEC97)E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T
M<B`B0F5S:V5D('5D;/AB970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")"97-K961T>7!E(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(DUE=&%R(%=E871H97(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")-971A<F)L;VL@:6MK92!T:6QGYFYG96QI9RXB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB365T87)B;&]K(&EK:V4@=&EL9^9N
M9V5L:6<N($1E=&%L:F5R(&5R(&)L979E="!N;W1E<F5T('1I;"!B<G5G(&9O
M<B`B"B)A9&UI;FES=')A=&]R96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+B(*;7-G<W1R(")-971A<D1"(&5R(&EK:V4@9F]R8G5N9&5T+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DUE=&]D92(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-R!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C@Q"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX
M,2!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE
M=&]D92!<(B5S7"(@97(@:6MK92!D969I;F5R970B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]R97-T+G!H<#HX,B!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L
M;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B365T;V1E(&EK:V4@9&5F:6YE9"X@
M365T;V1E(&MA;&1T.B`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#(@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W"FUS9VED(")-971R:6,B
M"FUS9W-T<B`B3>5L965N:&5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O
M(@IM<V=S='(@(DUE>&EC;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O;F5S:65N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"FUS9VED(")-:61D;&4B"FUS9W-T<B`B36ED="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@
M(DU)344M='EP92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS9VED
M(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36EN+B!T96UP
M+B!S:61S=&4@,C0@=&EM97(Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")-
M:6XN('1E;7`N('-I9'-T92`V('1I;65R.B`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0S.2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT
M,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960B"FUS9W-T<B`B36EN:6UU;2!K;V1E;W)D<V%L9&5R(&5R(&5N9&YU
M(&EK:V4@=61S=.5E="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(E-P96IL92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U
M<R(*;7-G<W1R(")&;W)S:V5L;&EG="(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,"!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0P(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G
M:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T
M<B`B36%N9VQE<B!014%2+7!A:VME($A45%!?4F5Q=65S="XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB
M2V]N9FEG=7)A=&EO;B!M86YG;&5R+B!$=2!B;&EV97(@;OAD="!T:6P@870@
M9V5N97)E<F4@9&5N(&YU+"!H=FES(&1U(/AN<VME<B`B"B)A="!B<G5G92!D
M96YN92!A<'!L:6MA=&EO;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`B36%N9VQE<B!B97-K960M:60N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*(SH@;&EB+TYE
M="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B36%N9VQE
M<B!K<N9V970@4$5!4BUP86MK92!-86EL+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S
M:6]N($E$+B(*;7-G<W1R(")-86YG;&5R('-E<W-I;VXM240N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B
M36\B"FUS9W-T<B`B36%N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I;"!%+7!O<W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B2N9V;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<S(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(L9N9')I;F=S9&%T;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R("+&;F1R92!54DPB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M36]L9&]V82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-
M;VYA8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-
M;VYG;VQI96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@T(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3@T"FUS9VED(")-;VYT:"!A;F0@>65A<B(*
M;7-G<W1R(")-Y6YE9"!O9R#E<B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3<@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-Y6YE9&QI9R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B3>5N969A<V5R(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C(X,`HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L:6(O
M1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*
M;7-G<W1R(")&;&5R92!F96QT97(@9G5N9&5T(&D@;&EN:64@)60@96YD(&1E
M="!F;W)V96YT961E("5D+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B
M"FUS9W-T<B`B36%R;VMK;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B
M365S="!S:WEF<FET(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B365S
M="!S:WEE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,U"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R
M(")-97-T('-K>65T(&]G(&)LYG-E;F1E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN>2(*
M;7-G<W1R(")-97-T('-O;"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C0X(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C4P.0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(D9L>70@;F5D(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B1FQY="!T:6P@=F5N<W1R92(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C4Q-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")-;V0@
M:/AJ<F4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C8T-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#4*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`B1FQY="!O<"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C8*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(D9L>70@;F5D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(V"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")&;'ET(&]P(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;V-A;6)I<75E(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM
M<V=S='(@(DUU;'1I+6YI=F5A=2!R=6QL96=A<F1I;G-L:7-T97(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.0HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B
M375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P(%5+(&MO<G0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B
M375L=&EP;&4@=F%L9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B36EN(&MO;G1O(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DUI;F4@:V]N=&\M:6YF;W)M871I;VYE<B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#0*;7-G:60@(DUY(%!O
M<G1A;"(*;7-G<W1R(")-:6X@4&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C0R"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@
M(DUI;B!0;W)T86PM=61F;W)M;FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY
M86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@
M06=R964B"FUS9W-T<B`B3D5*+"!J96<@97(@24M+12!E;FEG(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1N968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`R"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M3F%M92(*;7-G<W1R(").879N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I
M82(*;7-G<W1R(").86UI8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B
M"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G
M<W1R(").97!A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM
M<V=S='(@(DYE9&5R;&%N9&5N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L
M86YD<R!!;G1I;&QE<R(*;7-G<W1R(")(;VQL86YD<VME($%N=&EL;&5R(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@
M55),(@IM<V=S='(@(DYE='-C87!E($)A<V4@55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!5
M4DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R(").971S8V%P92!296YE=V%L(%523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G
M<W1R(").971S8V%P92!2979O8V%T:6]N(%523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS
M9W-T<B`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#@@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0B"FUS9W-T<B`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I
M8V%T92!T>7!E(@IM<V=S='(@(DYE='-C87!E(&-E<G1I9FEC=&4@='EP92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`B3F5T=N9R:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C4*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(")!;&1R:6<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYY($MA;&5D;VYI
M96XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU,`HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYY(&MA=&5G;W)I
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H
M<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*
M;7-G<W1R(").>6WE;F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G
M<W1R(").>70@8G)U9V5R;F%V;B`H=F%L9V9R:70I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F5W(%IE86QA;F0B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S
M=V]R9"(*;7-G<W1R(").>70@:V]D96]R9"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HR,C<@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+B(*;7-G<W1R(").>70@:V]D96]R9"!V:6P@=61L^&)E(&1E;B`E
M>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@
M(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DYY92!K;V1E
M;W)D(&5R(&EK:V4@96YS+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB
M"FUS9W-T<B`B3GET('9I;F1U92`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,`HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@
M(DYY:&5D97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS
M9VED(").97=S9W)O=7!S(@IM<V=S='(@(DYY:&5D<V=R=7!P97(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-2!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$R.0HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M,2!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-0IM<V=I9"`B3F5X="(*
M;7-G<W1R(").YG-T92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(").YG-T92`T(&9A<V5R(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S`*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HS-C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@
M;W!T:6]N<R(*;7-G<W1R(").YG-T92!T:6QV86QG(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HQ,#,@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ
M,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(D[F<W1E/B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@
M(DYA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I
M9"`B3F\B"FUS9W-T<B`B3F5J(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("));F=E
M;B!T:6QGYFYG96QI9V4@:V]N9FEG=7)A=&EO;F1A=&$@870@=FES92!F;W)S
M:V5L;&4@9F]R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z,3`V(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@
M(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M(@IM<V=S='(@(DEN9V5N('1I;&?F;F=E;&EG('-T<F%T96=I('1I;"!A="!L
M879E($E33RUB:6QL961E<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*
M;7-G<W1R("));F=E;B!S:W)I<'0M<VMA8F5L;VXN(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-SD*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z,C0U(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(V
M-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`B1&5R(&5K<VES=&5R97(@:6MK92!N;V=E;B!B;&]K('#E(&1E;B!F
M;W)E<W!U<F=T92!P;W-I=&EO;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;6-A;"YP:'`Z-3`@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DEN9V5N(&MA;&5N9&5R(&%N9VEV970@=&EL($U#
M04PMYF=T;FEN9RXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I
M9"`B3F\@8VAA;F=E+B(*;7-G<W1R("));F=E;B#F;F1R:6YG+B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(")$97(@:V%N(&EK:V4@=&EL
M9OAJ97,@8OAR;B!T:6P@9&5N;F4@=&EL;&%D96QS92XB"@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S@*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3<@;&EB+TAO
M<F1E+G!H<#HQ-S@@;&EB+TAO<F1E+G!H<#HU,3<*(SH@;&EB+TAO<F1E+U5T
M:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(DEN
M9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E="!F;W(@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34@;&EB+U9&4R]F
M='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I
M9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E="!F;W(@1E10(%9&4RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W,B!L:6(O5D93+W-Q;"YP
M:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A
M=&EO;BUI;F9O<FUA=&EO;B!A;F=I=F5T(&9O<B!344P@5D93+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C4@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("));F=E
M;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R(%-13"U&
M:6QE(%9&4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,30*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")+<F5D
M:70@=61T^&UT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R("));G1E="!B97-T96UM96QS97-S=&5D(&%N9VEV970N(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(P(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,C`*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B
M26YG96X@9FEL('-E;F1T(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q
M"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B1F%N9'0@:6YG96X@
M:6MO;F5R+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$V"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DEN
M=&5T('-T960@:6YD<W1I;&QE="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B26YT970@<W1E9"!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P
M<&QI960N(@IM<V=S='(@(DEN9V5N(&)E<VME9"!A;F=I=F5T+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO
M(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("));G1E="!N879N(&%N9VEV970N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S<*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM
M<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B26YT970@;G5M
M;65R(&%N9VEV970N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B26YG96X@86YS
M=/AD96QI9V4@97!I9W)A;6UE<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z.3$@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("));G1E="!K;V1E;W)D(&%N9VEV970@=&EL(&)R=6<@9F]R
M($A45%`MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C$P."!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("));G1E="!K;V1E;W)D(&%N9VEV970@=&EL(&)R=6<@9F]R($E-
M05`MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C<R(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DEN=&5T(&MO9&5O<F0@86YG:79E="!T:6P@8G)U9R!F;W(@2V5R
M8F5R;W,MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN
M+G!H<#HX-"!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O075T:"]L
M;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW-2!L:6(O
M2&]R9&4O075T:"]S87-L+G!H<#HW-PIM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));G1E
M="!K;V1E;W)D(&%N9VEV970@9F]R($QO9VEN9"WF9W1N:6YG+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4@;&EB+TAO<F1E+T%U
M=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN=&5T(&MO
M9&5O<F0@86YG:79E='0@=&EL(%!!4U-71"WF9W1N:6YG+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-"!L:6(O2&]R9&4O075T:"]S;6(N
M<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));G1E="!K;V1E;W)D(&%N9VEV970@
M9F]R(%--0BWF9W1N:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(E-T:2!T:6P@3W!E
M;E-33"UB:6)L:6]T96ME="!M86YG;&5R+B`@3W!E;E-33"UB:6)L:6]T96ME
M="!E<B!N^&1V96YD:6=T(&9O<B`B"B)A="!HY6YD=&5R92!02T-3,3(M9&%T
M82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS
M9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(DEN9V5N('9E;G1E
M;F1E(&]P<VMR:79N:6YG97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C<V-B!L:6(O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS
M9W-T<B`B2W9O=&4@:6MK92!I;F1S=&EL;&5T+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO
M(')U;&5S(@IM<V=S='(@(DEN9V5N('-T<F5G97(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT.#(@;&EB+T9I;&4O0U-6+G!H<#HT.#(*;7-G
M:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DEN9V5N('-K
M:6QL971E9VX@86YG:79E="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G
M<W1R("));F=E;B!S:61E<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3@W(&QI8B]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R("));F=E;B!SY61A;B!F:6PB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(D1E<B!M86YG;&5R
M(&5T(&UI9&QE<G1I9&EG="!K871A;&]G('1I;"!M96QL96UL86=E<BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("));G1E="!B<G5G97)N879N(&]G
M+V5L;&5R(&MO9&5O<F0@<V5N9'0N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ-#`@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM
M<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B26YG
M96X@9WEL9&EG92!834PM9&%T82!R971U<FYE<F5T(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-"!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.34*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("));F=E;B!V
MYG)D:65R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B
M3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D]R:6=I;F%L
M(&MO;F9I9W5R871I;VX@;6%N9VQE<B!V97)S:6]N<VYU;6UE<BX@4F5G96YE
M<NER(&MO;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1&EN
M(&MO;F9I9W5R871I;VX@;6%N9VQE<B!V97)S:6]N<VYU;6UE<BX@4F5G96YE
M<NER(&MO;F9I9W5R871I;VXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(W(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-PHC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G
M:60@(DYO;F4B"FUS9W-T<B`B26YG96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP
M;&EC:70I(@IM<V=S='(@(DEN9V5N("AB<G5G(&EM<&QI8VET*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y
M+3$P*2(*;7-G<W1R(").;W)D:7-K("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(").;W)D;&EG
M92!H86QV:W5G;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I
M86YA($ES;&%N9',B"FUS9W-T<B`B3F]R9&QI9V4@36%R:6%N8?AE<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)G92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M26MK92!S96YE<F4@96YD(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B26MK92!F^'(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,34@;&EB+U9&4R]F:6QE+G!H<#HT,34*
M;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")):VME(&YO9V5T(&MA
M=&%L;V<B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N
M<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE3
M3U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`B26MK92!I;7!L96UE;G1E<F5T+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS
M9W-T<B`B26MK92!I;F1S=&EL;&5T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C$Y,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U,@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,2!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S$V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M,S,@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-#(V(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#4*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C4W-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-3DQ"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HR,S8@;&EB+U9&4RYP:'`Z,3DS"B,Z(&QI8B]61E,N<&AP
M.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z,C4R(&QI8B]61E,N
M<&AP.C(V.0HC.B!L:6(O5D93+G!H<#HR.#4@;&EB+U9&4RYP:'`Z,S`Q(&QI
M8B]61E,N<&AP.C,Q-B!L:6(O5D93+G!H<#HS,S,*(SH@;&EB+U9&4RYP:'`Z
M,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU,#4@;&EB+U9&4RYP
M:'`Z-3<T"B,Z(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93+G!H<#HV-CD@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-C`@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G:60@(DYO="!S
M=7!P;W)T960N(@IM<V=S='(@(DEK:V4@=6YD97)S=/AT=&5T+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#@*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,#@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3@@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T97(B"@HC.B!S
M97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("));G1E="!A="!B<F]W<V4L
M('9E;F0@=&EL8F%G92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(E1A;"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4*
M;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(D%N=&%L('1E
M9VXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,30R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B
M3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B06YT86P@:V]L;VYN97(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V-PHC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R
M(&]F(')O=W,B"FUS9W-T<B`B06YT86P@<N9K:V5R(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N
M;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B5&%L(&EK:V4@86YG:79E="!F;W(@;W!D871E<FEN9R!I
M(&1I<W1R:6)U=&EO;G-L:7-T92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED
M(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@
M(D]B:F5K=&1A;FYE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,#0@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S
M='(@(D]K=&%L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS
M9VED(")/8W1O8F5R(@IM<V=S='(@(D]K=&]B97(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(D%N<W3X9&5N9&4@9FEL=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(DMO;G1O<B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N
M97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")'86UM
M96QT(&]G(&YY="!K;V1E;W)D('-K86P@=N9R92!F;W)S:V5L;&EG92XB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P
M87-S=V]R9"(*;7-G<W1R(")'86UM96QT(&MO9&5O<F0B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I
M<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B1V%M;65L="!K;V1E;W)D(&5R(&EK
M:V4@:V]R<F5K="XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@
M(D]M86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HW,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@
M(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM
M<V=S='(@(D1E;'1E(&UA<'!E<B!U;F1E<G-T^'1T97,@:W5N(&%F($E-05`M
M<V5R=F5R92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@
M(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DMU;B!A;G-T^&1E
M;&EG92!E<&EG<F%M;65R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#4Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Q"FUS9VED
M(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DMU
M;B#I;B!E+7!O<W0M861R97-S92!T:6QL861T+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB
M16X@9&5L:6YG<R!E:F5R<VMA8B!O9R!E:F5R=&EL;&%D96QS97(@;>4@:W5N
M(.9N9')E(&%F(&5N("(*(G-Y<W1E;6%D;6EN:7-T<F%T;W(@96QL97(@96IE
M<F5N('-E;'8B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`BQ6)E;B!I(&5T(&YY="!V:6YD=64B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-2!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B
M3W!E;E-33"UF96IL.B!$871A(&MU;FYE(&EK:V4@=61D<F%G97,@9G)A('-I
M9VYE<F5T(%,O34E-12UD96PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(L5B96X@9&5N;F4@:&5N
M=FES;FEN9R!I(&5T(&YY="!V:6YD=64B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E
M<F%T:79S>7-T96TB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(DEN9'-T:6QL:6YG97(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B26YD<W1I;&QI;F=E<B!F;W(@)7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI
M<W0B"FUS9W-T<B`B3W)D;F5T(&QI<W1E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C@@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FES871I
M;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.2!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T
M:6]N86P@56YI="(*;7-G<W1R(")/<F=A;FES871O<FES:R!E;FAE9"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II
M;F<B"FUS9W-T<B`B3W)G86YI<V5R:6YG(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E
M(@IM<V=S='(@(D]P<FEN9&5L:6<@87!P;&EK871I;VYS<VMA8F5L;VXB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(D]P<FEN9&5L
M:6=E('-K86)E;&]N97(@:2`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%N
M9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H
M97(@26YF;W)M871I;VXB"FUS9W-T<B`B06YD96X@:6YF;W)M871I;VXB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!0
M97)M:7-S:6]N<R(*;7-G<W1R(")%:F5R<F5T=&EG:&5D97(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD@;&EB+TAO<F1E+T%U=&@O<&%M
M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(E!!32WF9W1N:6YG(&5R(&EK:V4@=&EL9^9N9V5L
M:6=E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-2!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I
M9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.DUA:6PM;6]T
M;W(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L
M(%-I9VYA='5R92(*;7-G<W1R(")01U`@9&EG:71A;"!S:6=N871U<B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(E!'4"UK<GEP=&5R970@9&%T82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-S0@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B3V9F96YT
M;&EG(%!'4"UN^&=L92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S-38@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`M<VEG;F5R
M970O:W)Y<'1E<F5T(&1A=&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*
M;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"UK;V1E(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0
M+7-K86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")%9G1M+B!L970@
M<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Y"FUS9VED(")032!286EN(@IM<V=S='(@(D5F=&TN(')E9VXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B
M4$T@4VAO=V5R<R(*;7-G<W1R(")%9G1M+B!B>6=E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W
M(@IM<V=S='(@(D5F=&TN('-N92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B169T;2X@<VYE8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(D5F
M=&TN('-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")%9G0N('1O<F1E
M;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8+75D=FED9&5L
M<V4@;6%N9VQE<B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3
M:&5L;"(*;7-G<W1R(")02%`M<VMA;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B
M"FUS9W-T<B`B1F]R<FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N
M(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA
M=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DR(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086SF<W1I;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")0
M87!U82!.>2!'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y
M(@IM<V=S='(@(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T
M<B`B1&5L=FES="!S:WEE="(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,3@*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")+;V1E;W)D
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")0
M87-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B2V]D96]R
M9"#F;F1R970N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,S(S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B
M4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(DMO9&5O<F0@9F]R:V5R="(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(@;&EB+TAO
M<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DMO9&5O
M<F0@:W+F=F5T('9E9"!2041)55,MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#4S(&QI8B](;W)D92]&;W)M+G!H<#HR,#4S"FUS
M9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")+;V1E
M;W)D(&UE9"!B96MRYF9T96QS92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DMO9&5O<F0Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`B2V]D96]R9#H@(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@
M(DMO9&5O<F1E;F4@<VMA;"!VYG)E(&5N<RXB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B26YD<^9T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM
M<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B26YD<^9T(&9R
M82!U9&ML:7!S:&]L9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")3=&DB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN
M9R!3:6=N=7!S.B(*;7-G<W1R(")696YT96YD92!O<'-K<FEV;FEN9V5R.B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM
M<V=S='(@(D9O;&LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0<F]C96YT
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R(")59&;X<B!V961L:6=E:&]L9&5L<V4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E5D9OAR('9E9&QI9V5H;VQD96QS
M92!V960@;&]G(&EN9#\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$U-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R
M;6ES<VEO;B(*;7-G<W1R(")4:6QL861E;'-E<B(*"B,Z(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO
M;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(E1I;&QA9&5L<V4@7"(E
M<UPB(&EK:V4@<VQE='1E="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C4Y,"!L:6(O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M:7-S:6]N
M($1E;FEE9"(*;7-G<W1R(")4:6QL861E;'-E(&[F9W1E="(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,38T"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,38Q
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N
M<R(*;7-G<W1R(")4:6QL861E;'-E<B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(*
M;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E1I
M;&QA9&5L<V5S+6%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R
M(")0<F]F:6QE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#,@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B
M4&5R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T
M<R(*;7-G<W1R(")+YFQE9'ER(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP
M<&EN97,B"FUS9W-T<B`B1FEL:7!P:6YE<FYE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B
M5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G
M:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS
M(@IM<V=S='(@(E!R:6MK97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B0F%N86QI=&5T97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T
M<B`B2VQI:R!I(&5N(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM
M<V=S='(@(D)E:W+F9G0@870@9'4@^&YS:V5R(&%T('-L971T92!D971T92!E
M;&5M96YT.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")"96MR
MYF9T(&%T(&1U(/AN<VME<B!A="!A9FSF;FME(&1E='1E(&5L96UE;G0N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4V,B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4V,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BXB"FUS9W-T<B`B26YD=&%S="!E;B!MY6YE9"!O9R!E="#E<G-T86PN
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T
M96=O<GDZ(@IM<V=S='(@(DEN9'1A<W0@970@;F%V;B!T:6P@9&5N(&YY92!K
M871E9V]R:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("));F1T87-T(&5N(&=Y;&1I9R!)
M4"UA9')E<W-E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#`*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N(@IM<V=S='(@(DEN9'1A<W0@96X@9WEL9&EG(&1A=&\L('1J96L@
M86YT86QL970@868@9&%G92!I(&WE;F5D96XN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0T-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0T-PIM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B26YD=&%S
M="!E;B!G>6QD:6<@=&ED<V%N9VEV96QS92XB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E-K<FEV('9E;FQI9W-T
M+"!H=F%D('!R;V)L96UE="!GY7(@=60@<.4@;V<@:'9A9"!D97(@<VME<BXB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(DEN9'1A<W0@=F5N;&EG
M<W0@8G)U9V5R;F%V;B!O9R!K;V1E;W)D(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B),YG,@9OAL9V5N9&4@=&5K
M<W0N($1U(%-+04P@=N9R92!E;FEG(&D@8F5T:6YG96QS97)N92!F;W(@870@
M8G)U9V4@<WES=&5M970N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S`*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B26YD=&%S="!D970@;GEE(&MA=&5G
M;W)I;F%V;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B
M4&]L96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O
M;&ET:6-S(@IM<V=S='(@(E!O;&ET:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")-96YI;F=S;>5L
M:6YG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@
M(E!O<G1U9V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E(@IM<V=S='(@(E!L86-E<FEN9R!A9B!B:6QL961E="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS
M9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!L86-E
M<FEN9R!A9B!D96YN92!T86)E;"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDQ"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4Q(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G
M:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*2(*;7-G<W1R(")396YD('1I;"!D96YN92!M87!P92`H:6MK92!G96YN96UT
M=G5N9V5T(&%F($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B
M3F5D8OAR(&=E;FYE;2!S96YE<W0@)7,@=&EM97(Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\
M8G(@+SYC:&%N8V4B"FUS9W-T<B`B3F5D8OAR/&)R("\^8VAA;F-E(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX(&QI8B](;W)D92]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P
M.B!+<N9V970@3$1!4"UU9'9I9&1E;"!I:VME(&9U;F1E="XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,@;&EB+TAO<F1E+U!R
M969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R
M969S7W-E<W-I;VXZ($MRYG9E="!S97-S:6]N+75D=FED9&5L<V4@:6MK92!F
M=6YD970N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R
M97-S=7)E(@IM<V=S='(@(E1R>6LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(V-@IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B
M5')Y:R!V960@;W9E<F9L861E;CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")4<GEK
M.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C`S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(P"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D=L:6UT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(Q"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B0F5T<F%G="!B:6QL961E="!I(&5T(&YY="!V:6YD=64B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,`HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B
M4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")&;W)R:6=E('1I;'9A;&<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS
M9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")59'-K<FEV(&1O:W5M96YT
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS
M9W-T<B`B4')I=F%T(&[X9VQE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V.2!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0
M<F]B;&5M(@IM<V=S='(@(E!R;V)L96TB"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M4')O8FQE;6)E<VMR:79E;'-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K=&5R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-S8@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q.#@@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S8*;7-G:60@(E!R;VUP
M="!T97AT(@IM<V=S='(@(E-T:6MO<F1S=&5K<W0B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D]F9F5N=&QI9V4@
M;OAG;&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC
M($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B3V9F96YT;&EG+6[X9VQE+6%L9V]R
M:71M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@
M2V5Y($EN9F\B"FUS9W-T<B`B3V9F96YT;&EG(&[X9VQE(&EN9F]R;6%T:6]N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M3V9F96YT;&EG+W!R:79A="UN^&=L97/F="UG96YE<F5R:6YG(&UI<VQY:VME
M9&5S+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T
M<B`B4'5E<G1O(%)I8V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU-2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E5D<F5N<R!B97-K
M961E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T
M87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM
M<V=S='(@(D9O<F5S</AR9W-E;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HX,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B2W9O=&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-"!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC
M($ME>2`H)60@8FET*2(*;7-G<W1R(")/9F9E;G1L:6<@4E-!+6[X9VQE("@E
M9"!B:70I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(D5N:V5L='9I<R!V86QG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B4F5G
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(E)E9VX@=&ED;&EG="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED
M(")286EN($QA=&4B"FUS9W-T<B`B4F5G;B!S96YT(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@4VAO
M=V5R(@IM<V=S='(@(E)E9VYB>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN(&%N9"!3;F]W(@IM
M<V=S='(@(E)E9VX@;V<@<VYE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R
M(")3;'5D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A
M;F1O;2!&;W)T=6YE(@IM<V=S='(@(E1I;&;F;&1I9W0@97!I9W)A;2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B1F]R:&]L9"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T(&QI8B](;W)D92]097)M
M<RYP:'`Z,S(T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDQ('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DSF<R(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0W(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T
M<B`B3.9S(&)E<VME9&5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@
M(E9I<FME;&EG('-L971T92`E<S\@1&5N;F4@;W!E<F%T:6]N(&MA;B!I:VME
M(&)L:79E(&]M9VIO<G0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(B(*(E9I<FME;&EG('-L971T92!D871A(&9O
M<B!B<G5G97(@)7,_($1E;FYE(&]P97)A=&EO;B!K86X@:6MK92!B;&EV92!O
M;6=J;W)T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(D]M9_AR(&1I;B!S:61S=&4@:&%N9&QI;F<B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I
M9"`B4F5F<F5S:"(*;7-G<W1R(")/<&1A=&5R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z(@IM<V=S='(@(D]P9G)I<VL@9'EN86UI<VME(&UE;G4M96QE;65N
M=&5R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E
M9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D=E;F]P9G)I<VL@<&]R=&%L
M=FES;FEN9SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,U(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R,3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*;7-G
M:60@(E)E9V5X(@IM<V=S='(@(E)E9W5LYG)T('5D=')Y:R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M,S$*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(E)E;&%T
M:6]N<VSF<V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D
M(@IM<V=S='(@(D=E;F]P9G)I<VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R(").;W1E<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM
M<V=S='(@(D9J97)N92!S97)V97)E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B1FIE<FX@55),("AH='1P.B\O
M=W=W+F5K<V5M<&5L+F1K+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$S('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C(*;7-G:60@(E)E;6]V92(*;7-G<W1R(")3;&5T(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO
M8VLB"FUS9W-T<B`B4VQE="!B;&]K(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S
M='(@(D9J97)N(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*
M;7-G<W1R(")3;&5T(&9O<FUA=&5R:6YG(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E-L
M970@<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(D9J97)N(&QA9W)E="!S:W)I<'0@9G)A('-E
M<G9E<G,@;6ED;&5R=&ED:6=E(&MA=&%L;V<N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")2
M96UO=F4@=&AE(@IM<V=S='(@(D9J97)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D9J97)N
M(&1E='1E('!U;FMT(&9R82!D;VMU;65N=&5T(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS
M9W-T<B`B4VQE="!B<G5G97(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(E-L970@8G)U9V5R.B`E<R(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z,3,X(&QI8B](;W)D92]24$,O>&UL<G!C+G!H
M<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(D%N;6]D;FEN9R!K=6YN92!I
M:VME(&)E<W9A<F5S+B!2971U<FYE<F5T(&9E:FQK;V1E.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D%N;6]D970@
M=&IE;F5S=&4@:W5N;F4@:6MK92!F:6YD97,N(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,C<*(SH@;&EB+TAO<F1E+G!H<#HQ.#4@;&EB+TAO<F1E+G!H<#HU,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W+F=F5D92`G)7,G
M(&5R(&EK:V4@86YG:79E="!I("5S+6MO;F9I9W5R871I;VXN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HV-S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<S,2!L:6(O5D93+V9T<"YP:'`Z.#8Q(&QI8B]61E,O<W%L+G!H<#HV-S@*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")+<N9V970@7"(E<UPB(&5R(&EK:V4@86YG
M:79E="!I(%9&4R!K;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<W-B!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMRYG9E9&4@7"(E<UPB(&5R(&EK
M:V4@86YG:79E="!I(&MO;F9I9W5R871I;VYE;BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N
M9&5R97(N<&AP.C,S-@IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B
M2W+F=F5T(&9E;'0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S.2!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S.2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"B,Z(&QI8B](;W)D92]&;W)M
M+U)E;F1E<F5R+G!H<#HS,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS
M9VED(")297-E="(*;7-G<W1R(").=6QS=&EL(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S
M='(@(DYU;'-T:6P@:V]D96]R9"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(DYU;'-T:6P@9&ET(&MO9&5O<F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B1V5N<VMA
M8B!S:61S=&4@9F]R97-P^')G<V5L(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(Y(&%D;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C<*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT871E<B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M5&EL8F%G92!T:6P@:6YD<W1I;&QI;F=E<FYE(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(D=E;G1A<W0@;GET(&MO9&5O<F0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM
M<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N9&%N(&MO
M;F9I9W5R871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS
M9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B26YD<W1I
M;&QI;F=E<B!F;W(@4FEC:"!497AT+7)E9&EG97)I;F<B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B1^5D
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#@*;7-G:60@(E)I9VAT(@IM<V=S='(@(DCX:G)E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$P,PIM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(DCX:G)E('1O<'1E
M:W-T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@
M(DCX:G)E(';F<F1I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R(")2YFMK92UE9V5N<VMA8F5R+BXN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G
M<W1R(")296=E;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G
M<W1R(")2=6WF;FEE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")2;W3I<B`Q
M.#`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*
M;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(E)O=.ER('9E;G-T<F4B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@
M(E)O=&%T92!2:6=H="(*;7-G<W1R(")2;W3I<B!H^&IR92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G
M:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E+F:VME+65G96YS:V%B97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")2YFMK92UE
M9V5N<VMA8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E+F:VME<CHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")3=')E9V5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(*;7-G<W1R(")3=')E9V5R('9I;"!O<'1RYF1E(&UE;&QE;2!RYFMK
M97(@;V<@:V]L;VYN97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R(")3=')E9V5R('9I;"!K
M=6X@;W!T<N9D92!M96QL96T@:V]L;VYN97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")3=')E
M9V5R('9I;"!K=6X@;W!T<N9D92!M96QL96T@<N9K:V5R(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(E5D9OAR(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T
M<B`B4G5S;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S
M='(@(E)W86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C@U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B2W)Y<'1O
M9W)A9FES:R!3+TU)344M<VEG;F%T=7(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,R,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@
M(E,O34E-12US:6=N97)E="!B97-K960B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C@Q(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS
M9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(E-!4TPMYF=T;FEN9R!E<B!I:VME('1I;&?F;F=E;&EG+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S
M86=I;F<B"FUS9W-T<B`B4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q
M"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,+69O<G1O;&ME<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S0@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,R-S0*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU
M<',B"FUS9W-T<B`B4U%,+75D=')Y:R!F;W(@;W!S;&%G(&%F(';F<F1I97(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B
M"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-5
M0T-%4U,B"FUS9W-T<B`B4U5#0T53(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS
M9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-13"UF;W)T;VQK97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED
M(")382(*;7-G<W1R("),^'(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT
M($AE;&5N82(*;7-G<W1R(")3:W0N($AE;&5N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")3:W0N($MI='1S
M(&]G($YE=FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS
M9W-T<B`B4VMT+B!,=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")3:W0N(%!I97)R92!O9R!-
M:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4VMT+B!6:6YC96YT(&]G($=R
M96YA9&EN97)N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R
M(")386UM92!R86UM92`H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")3
M86UO82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V]A(%1O;64@
M;V<@4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L:71U9&)Y9&5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U9&EA<F%B
M:65N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED
M(")3879E(@IM<V=S='(@(D=E;2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S
M7"(B"FUS9W-T<B`B1V5M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS
M9W-T<B`B1V5M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")'96UM92!);F1S=&EL
M;&EN9V5R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B
M(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"B)'96T@9V5N97)E<F5T(&MO;F9I9W5R871I;VX@<V]M(%!(
M4"US:W)I<'0@:2!D:6X@<V5R=F5R<R!M:61L97)T:61I9V4@(@HB:V%T86QO
M9RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")'
M96UT("5S+6MO;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B1V5M=&4@<VMR:7!T
M(&9O<B!O<&=R861E<FEN9R!A9B!O<'/F=&YI;F<@=&EL.B!<(B5S7"(N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G
M:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")3<')E9'0@=&]R9&5N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E
M(@IM<V=S='(@(E9I9&5N<VMA8B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B4_AG(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B4_AG96UA<VMI;F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDU-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDU-0IM<V=I9"`B4V5L96-T($9I
M;&5S(@IM<V=S='(@(E;F;&<@9FEL97(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS
M9W-T<B`B5N9L9R!E;B!D871O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R
M(")6YFQG(&5N(&=R=7!P92!A="!T:6QF^&IE(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM
M<V=S='(@(E;F;&<@96X@;GD@96IE<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@
M(E;F;&<@96X@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E;F
M;&<@96X@8G)U9V5R(&%T('1I;&;X:F4B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`B5N9L9R!A;&QE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T,PIM<V=I9"`B4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E;F;&<@86QL92!D871O+6MO;7!O
M;F5N=&5R+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-S,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")6YFQG(&5T
M(&]B:F5K="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B5N9L9R!I;F=E;B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E;F;&<@9&4@=&5G;B!D=2!H87(@
M8G)U9R!F;W(@9G)A(&MA<W-E<FYE(&YE9&5N9F]R+B!$92!K86X@<^4@:VQI
M<'!E<R!O9R`B"B)K;W!I97)E<R!F<F$@=&5X=&9E;'1E="XB"@HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CHB"FUS9W-T<B`B5N9L9R!D871O+6%D<VMI;&QE<F5N.B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")6YFQG(&1A=&]F;W)M870Z(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I
M9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM
M<V=S='(@(E;F;&<@9&5N(&ED96YT:71E="P@<V]M(&1U('9I;"#F;F1R93HB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T
M('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5N9L9R!T:61S+6%D<VMI
M;&QE<F5N.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED
M(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")6YFQG('1I9'-F
M;W)M870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I
M9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E;F;&<@
M=&\@9F5L=&5R+"!D97(@<W9A<F5R('1I;"!H:6YA;F1E;BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(E;F;&<@9&EN(&9A<G9E<V%M;65N<^9T;FEN
M9RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E;F;&<@9&ET
M(&9O<F5T<G5K;F4@<W!R;V<Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B4V5N9"!P<F]B;&5M8F5S:W)I=F5L<V4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS
M9W-T<B`B4V5N9"!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB
M"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S
M"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")&^&QE<CH@(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`B4V5P=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I
M9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I96X@;V<@
M36]N=&5N96=R;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")3
M97)I86P@3G5M8F5R(@IM<V=S='(@(E-E<FEE;G5M;65R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@
M=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4V5R=F5R+61A=&$@
M9F]R:V5R="!E;&QE<B!I:VME('1I;&?F;F=E;&EG+B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")3
M97-S:6]N<V%D;6EN:7-T<F%T;W(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B4V5S<VEO;BU)1"!U9&SX8F5T+B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S<VEO;F5R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(DWF;F=D92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("(B"B));F1S=&EL;&EN9V5R(&1E<B!T:6QL
M861E<B!D:6<@870@;G5L<W1I;&QE(&1I="!K;V1E;W)D+"!H=FES(&1U(&YO
M9V5N<VEN9&4@(@HB<VMU;&QE(&=L96UM92!D970N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM
M<V=S='(@(DEN9'-T:6P@9FIE<FYE('-E<G9E<F4L('-O;2!D=2#X;G-K97(@
M870@=&EL9^4@9G)A(&1I;B!P;W)T86PN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L
M('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(DEN9'-T:6P@
M9&EN(&9O<F5T<G5K;F4@<W!R;V<M+"!T:61S>F]N92T@;V<@9&%T;W9A;&<N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM
M<V=S='(@(B(*(DEN9'-T:6P@9&EN92!O<'-T87)T<V%P<&QI:V%T:6]N97(L
M(&9A<G9E<V%M;65N<^9T;FEN9RP@<VED96]P9G)I<VMN:6X@;V<@(@HB86YD
M<F4@=FES;FEN9W-T:6QV86QG+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(DEN9'-T:6QL:6YG(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4VMR:7!T
M<R!T:6P@;W!G<F%D97)I;F<@868@;W!SYG1N:6YG('1I;&?F;F=E;&EG92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M(@IM<V=S='(@(D9L97)E('-T961E<B!M=6QI9R!M960@<&%R86UE=&5R96XZ
M("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")3
M97EC:&5L;&5R;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX
M"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")3:&]P<&EN9R(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(DMO<G0@;W!S=6UM97)I;F<B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B4VMA;"!H=7)T:6<M
M=&%S=&5R(&1E9FEN97)E<R!F;W(@9&4@9FQE<W1E(&AE;G9I<VYI;F=E<C\@
M*/<I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HS,C,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B
M5FES(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB
M4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@
M=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"B)6:7,@9F]R<VME;&QE;F4@;65L;&5M(&1E;B!G96UT92!O9R!D96X@
M;GEL:6=T(&=E;F5R97)E9&4@:V]N9FEG=7)A=&EO;BXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(E9I<R!T:61S<'5N:W0@9F]R
M('-E;F5S=&4@=&EL9V%N9R!V960@<.5L;V=N:6YG/R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*
M;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B
M5FES(&UU;&EG:&5D(&9O<B!A="!B96AO;&1E(&]P<FEN9&5L:6<B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDU(&QI8B](;W)D92]&;W)M+G!H
M<#HR-SDU"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")6:7,@<VYU<'!E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5FES(%1A8F5L
M;W!E<F%T:6]N97(M:VYA<'!E;B!I(&UE;G5E;C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE
M("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E9I<R`E<RUM96YU96X@
M=&EL('9E;G-T<F4_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#
M96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E9I<R!D:6%L;V=V:6YD
M=64@;65D(&5G96YS:V%B97(@9F]R('1A8F5L8V5L;&5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS
M9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M(")6:7,@9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!T86)E;&QE
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(E9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS
M:V%B97(@9F]R('1A8F5L<N9K:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")6:7,@9&EA;&]G
M=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!B:6QL961E="(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$W
M-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(E9I<R!A9G-E;F1T92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS
M9VED(")3:&]W97)S(@IM<V=S='(@(D)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B0GEG97(@=&ED;&EG="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S($QA=&4B
M"FUS9W-T<B`B0GEG97(@<V5N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I
M;FET>2(*;7-G<W1R(")">6=E<B!I(&[F<FAE9&5N(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-#@P"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B4VMR
M=6UP(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C@S-@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,C(@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C$P-#<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z,3`X-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q-#D*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3$R,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$Q.#,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,C(S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3(U,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")3:W)U
M;7`@96QL97(@9FQY="!N86)O8FQO:VME(&%F('9E:F5N(&;X<G-T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A
M($QE;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U
M<"(*;7-G<W1R(")3:W)I=B!I;F0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<Q,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q
M,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(E5N9&5R<VMR:69T(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET
M:&TB"FUS9W-T<B`B4VEG;F%T=7)A;&=O<FET;64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!O<F4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`U(&QI8B](;W)D92]&;W)M+G!H<#HX
M.38@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y,3(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#0@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S(*;7-G:60@(E-I>F4B"FUS9W-T<B`B4W3X<G)E;'-E(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@
M(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B4W!R:6YG('9E9&QI9V5H;VQD
M96QS92!O=F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G
M<W1R(")3;&]V86MI970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(E-L;W9E;FEE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(@IM<V=S='(@(E-N92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3;F5B>6=E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")3;F5B>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@
M16%R;'DB"FUS9W-T<B`B4VYE8GEG97(@=&ED;&EG="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3;F]W(%-H
M;W=E<G,@3&%T92(*;7-G<W1R(")3;F5B>6=E<B!S96YT(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M(")3;F5D>6)D93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*;7-G
M:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(E-N9>9K
M=FEV86QE;G0@:2!V86YD.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R(")386QO;6]N^&5R;F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G
M<W1R(")386YG92!O9R!P;V5S:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,#@*;7-G:60@(E-O<G0@
M;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-O<G1E<FEN9W-V86QG(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$X.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-#<@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V
M-@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R
M8V4@861D<F5S<R(*;7-G<W1R(")!9G-E;F1E<F%D<F5S<V4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3>61A9G)I:V$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(E-Y9&5U<F]PYFES:R`H25-/
M+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3>60@1V5O
M<F=I82!O9R!$92!S>61L:6=E(%-A;F1W:6-H^&5R(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")3>61L:6=E(&AA;'9K=6=L92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S
M"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@
M(DQU9G0@;65L;&5M(&YA8F]C96QL97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("),=69T(&UE
M;&QE;2!I;F1H;VQD(&]G(')A;6UE(&D@8V5L;&4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX,34@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q-0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(DUE;&QE;7)U;7-T86YG970B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B365L;&5M<G5M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B
M4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("),=69T(&]G(&9O<G)I;F<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B4W!A;FEE;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS
M9W-T<B`B4VMI9'1P;W-T(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("));F1T
M87-T;FEN9R!F;W(@<W!E8VEA;&MA<F%K=&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L
M:70@8V5L;"(*;7-G<W1R(")$96P@8V5L;&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI
M="!C;VQU;6XB"FUS9W-T<B`B1&5L(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3
M<&QI="!R;W<B"FUS9W-T<B`B1&5L('+F:VME(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C8*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD
M87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R
M(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDQ"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-3@V(&QI8B](;W)D92]&;W)M+G!H<#HR
M-SDQ"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D)E9WEN9&5L<V5SY7(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O
M=FEN8V4B"FUS9W-T<B`B1&5L<W1A="!E;&QE<B!P<F]V:6YS(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U
M<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-SDW(&QI8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&]R86=E
M(&9O<FUA="(*;7-G<W1R("),86=R:6YG<V9O<FUA="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")6
M96HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(D=E;FYE;7-T<F5G
M;FEN9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@
M(DQI<W1E(&%F('-T<F5N9V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#<S(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")&:F5R;B!D;VWF;F4@
M9G)A(&%D<F5S<V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T
M<B`B4W1I;"!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(E/X;B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B56YD97)K
M871A;&]G(%PB)7-<(B!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@
M(D5M;F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$X"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`IM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(D=O9&ME;F0B"@HC.B!S:6=N=7`N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@
M:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*
M;7-G<W1R("(B"B)!;FUO9&YI;F<@;VT@870@=&EL9OAJ92!<(B5S7"(@=&EL
M('-Y<W1E;2!A9G-E;F1T+B`@1'4@:V%N(&EK:V4@;&]G9V4@<.4@9OAR("(*
M(F1I;B!A;FUO9&YI;F<@97(@8FQE=F5T(&%N97)K96YD="XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3
M=6)S8W)I<'0B"FUS9W-T<B`B3&%V('-K<FEF="(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E
M<W,B"FUS9W-T<B`B561F^')T(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@8FQE=B!T:6QF^&IE="!T
M:6P@<WES=&5M970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1&%T82!F;W(@
M8G)U9V5R(%PB)7-<(B!B;&5V('-L971T970@9G)A('-Y<W1E;65T+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<
M(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!S;&5T=&5T+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S
M7"(@<VQE='1E="!F<F$@<WES=&5M970N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B2V]N
M9FEG=7)A=&EO;B!T:6QB86=E9OAR="X@1V5N:6YD;.9S(&9O<B!A="!S92#F
M;F1R:6YG97)N92XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4F5S97)V96MO
M;F9I9W5R871I;VX@9V5M="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B4F5S
M97)V96MO;F9I9W5R871I;VYF:6P@)7,@9V5M="XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!O<&1A=&5R970N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(EPB)7-<(B!S:W)E=F5T+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM
M87)Y(@IM<V=S='(@(DEN9&AO;&0B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-O;&]P9V%N9R(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G
M<W1R(")3;VQN961G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-O;')I9W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3
M=6YR:7-E(@IM<V=S='(@(E-O;&]P9V%N9R(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N
M<FES92]3=6YS970B"FUS9W-T<B`B4V]L;W!G86YG+W-O;&YE9&=A;F<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR
M:7-E.B`B"FUS9W-T<B`B4V]L;W!G86YG.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]L
M;F5D9V%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*
M;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(E-O;&YE9&=A;F<Z("(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(DCF=F5T('-K<FEF="(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`B2&KF;'`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B
M4W5R;F%M92(*;7-G<W1R(")%9G1E<FYA=FXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@
M;V<@2F%N($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B
M"FUS9W-T<B`B4W=A>FEL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D
M96XB"FUS9W-T<B`B4W9E<FEG92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R(")38VAW96EZ(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B
M4WEN8R!L;V<@<VQE='1E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B4WEN=&%K<V9E:FP@:2!S^&=E;&5D(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3>7)I
M96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")4;W)D96XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B5&]R9&5N(&]G('9I;F0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3
M=&]R;7,B"FUS9W-T<B`B5&]R9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM
M<V=S='(@(E1O<F1E;B!T:61L:6=T(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$V-B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM<V=I
M9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6+69I;"(*"B,Z(&QI8B](;W)D92]5
M22]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")486)E;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96PM
M96=E;G-K86)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3<*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)E;&WF;F=D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96PM
M96=E;G-K86)E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486EW86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(E1A:7=A;BP@1&5N(&MI;F5S:7-K92!P<F]V:6YS(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9&II:VES
M=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(E1A;GIA;FEA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*
M;7-G<W1R(")-Y6PZ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S(@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S(*(SH@8V]N9FEG+VAO;VMS+G!H
M<"YD:7-T.C$P-#D@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I
M9"`B5&%S:W,B"FUS9W-T<B`B3W!G879E<B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<T(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F
M;VYN=6UM97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B
M5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<"X@<VED<W1E('1I
M;64Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R(")496UP97)A='5R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G
M<W1R(")496UP97)A='5R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R
M("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U
M<CQB<B`O/B@E<TCX:B5S+R5S3&%V)7,I("9D96<[)7,B"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-2!L:6(O2&]R9&4O5&5M<&QA
M=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")3:V%B96QO;B!<(B5S7"(@:6MK92!F
M=6YD970N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E-K86)E;&]N+6%D;6EN
M:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(W"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C$Q(&QI8B](;W)D92]&;W)M+G!H<#HS,S(W"FUS9VED(")497AT
M(@IM<V=S='(@(E1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E)E;B!T96MS="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*
M;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B5&5K<W0M:G5S=&5R:6YG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM
M<V=I9"`B5&5X='1O<"(*;7-G<W1R(")496MS="UT;W`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*
M;7-G<W1R(")4;W(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I
M9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA:2`H5$E3+38R,"DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EL86YD
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$@;&EB+U9&4R]F
M='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B1E10+75D=FED9&5L<V5N(&5R(&EK:V4@=&EL
M9^9N9V5L:6<N(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z
M-34@;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R
M>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(DAI<W1O<FEK+7-Y<W1E
M;65T(&5R('-LY65T(&9R82XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS."!L:6(O2&]R9&4O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B+6EN
M=&5G<F%T:6]N<VUO=&]R96X@=6YD97)S=/AT=&5R(&EK:V4@7"(E<UPB(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y."!L:6(O
M3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B24U34"UL;V=G96X@
M:W5N;F4@:6MK92!K;&%R9_AR97,N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@
M;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E.CHM
M:VQA<W-E;B!B;&5V(&EK:V4@:6YD;.9S="(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")4:6QV86QG<W9I;F1U
M970@97(@8FQE=F5T(&QU:VME="X@069S;'5T=&5R+B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S`S"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI
M8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q
M"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP
M:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]0
M97)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B
M"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D%D;6EN:7-T<F%T;W)E;B!B
M;&EV97(@;OAD="!T:6P@870@:V]N9FEG=7)E<F4@96X@<&5R;6%N96YT(%1I
M;&QA9&5L<V5S+2(*(F)A8VME;F0L(&AV:7,@9'4@=FEL(&%N=F5N9&4@5&EL
M;&%D96QS97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB
M"FUS9W-T<B`B2W5N('5N9&5R<VED96XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DMO
M;G1A:W0M240M;G5M;65R970@8FQE=B!I:VME(&%N9VEV970L(&5F=&5R;&%D
M="!T;VUT(&5L;&5R(&)L978@:6MK92!F=6YD970@(@HB:2!D871A8F%S96XN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H
M92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1E;B!B;&5V('1I;&;X:F5T('1I
M;"!D:70@861R97-S96MA<G1O=&5K970N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$W,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("(B"B)$96X@;/AS9VIO<G1E(%!'4"US:6=N871U<BUB;&]K(&5R
M(&MRYG9E="!F;W(@870@:W5N;F4@=F5R:69I8V5R92!D96X@(@HB<VEG;F5R
M961E(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(D1I<W1R:6)U
M=&EO;G-L:7-T92U)1"!E<B!E;G1E;B!I:VME(&%N9VEV970L('1O;70@96QL
M97(@:6MK92!F=6YD970@:2`B"B)D871A8F%S96XN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(")$:7-T
M<FEB=71I;VYS;&ES=&5N(&EK:V4@86YG:79E="XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0N<&AP.C$Q-B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B2W)Y<'1E<FEN9W-F86-I;&ET
M971E<FYE(&MRYG9E<B!E;B!S:6MK97(@=V5B+69O<F)I;F1E;'-E+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3(X"B,Z(&QI8B](;W)D92YP:'`Z,3@V(&QI8B](;W)D
M92YP:'`Z-3(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B1FEL96X@)7,@
M8OAR(&EN9&5H;VQD92!E;B`E<RUI;F1S=&EL;&EN9RXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4Q.`HC.B!L:6(O2&]R9&4N<&AP.C$W.2!L:6(O2&]R9&4N<&AP.C4Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")&:6QE;B`E<R!B^'(@
M:6YD96AO;&1E(&YO9VQE("5S+6EN9'-T:6QL:6YG97(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V(&QI8B]61E,O9FEL92YP:'`Z,C(V
M"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+B(*;7-G<W1R(")&:6QE;B!K86X@:6MK92!K;W!I97)E<R!O=F5N<.4@<VEG
M<V5L=BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`@;&EB+TAO
M<F1E+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(D9I;&5N(&EN9&5H;VQD="!I;F=E;B!D871A+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(D;X;&=E;F1E(&5R(&AO=F5D
M97)N92!F<F$@9&5N;F4@;65S<V%G92]R9F,X,C(M8F5S:V5D+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@
M(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS
M9W-T<B`B(@HB1G5L9'-KYG)M<W1I;'-T86YD('9I9&5S(&%T('9O;&1E('!R
M;V)L96UE<B!I($EN=&5R;F5T($5X<&QO<F5R(&=R=6YD970@(@HB8G)O=W-E
M<BUF96IL+"!S;VT@=FD@:6MK92!H87(@:W5N;F5T(&]M9^4N($1U('9I;"!M
M=6QI9W9I<R!O<&QE=F4@(@HB9F]R=F%N<VME9&4@=FES;FEN9V5R+"!M86YG
M96P@<.4@961I=&5R:6YG<V9U;FMT:6]N97(@;V<O96QL97(@=&EL9N9L9&EG
M92`B"B)B<F]W<V5R+6YE9&)R=60N($AV:7,@9&ET('-Y<W1E;2!E<B!7:6YD
M;W=S)FYB<W`[.7@@=FEL(&1U(&UE9"!H^&H@(@HB<V%N9'-Y;FQI9VAE9"!O
M<&QE=F4@)T=E;F5R96P@8F5S:WET=&5L<V5S9F5J;"<@;V<@=FEL(&)L:79E
M(&[X9'0@=&EL(&%T("(*(F=E;G-T87)T92!M87-K:6YE;BY<7&Y<7&Y$=2!E
M<B!N=2!A9'9A<F5T+B`@5')Y:R!/2R!H=FES(&1U('-T861I9R#X;G-K97(@
M870@(@HB<'+X=F5T(&9U;&1S:^9R;7-R961I9V5R:6YG+B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N
M=&ET971E;B!<(B5S7"(@97(@<VQE='1E="XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")+=6X@=F5N<W1R92!S:61E
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-R!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R(")0;&%C97)I;F=E;B!A9B!';G50
M1RUP<F]G<F%M;65T('-K86P@9VEV97,@=&EL($-R>7!T7W!G<#HZ+6ML87-S
M96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,B!L:6(O
M2&]R9&4O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N(@IM<V=S='(@(B(*(D)E<VME9&5N+"!S;VT@97(@<V5N9'0@9&5N
M("5S('1I;"`E<R!M960@96UN970@7"(E<UPB(&5R(&)L979E="!V:7-T+EQN
M(@HB1&5T=&4@97(@:6YG96X@9V%R86YT:2!F;W(L(&%T(&)E<VME9&5N(')E
M;G0@9F%K=&ES:R!E<B!B;&5V970@;.9S="!E;&QE<B`B"B)F;W)S=.5E="XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3F%V;F5T+"!D97(@
M<VMA;"!B<G5G92P@;N5R(&1E<B!H96YV:7-E<R!T:6P@<VMR:79E<VED96XB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0@;&EB+T9I;&4O
M0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@
M8F4@;G5M97)I8RXB"FUS9W-T<B`B06YT86QL970@868@9F5L=&5R('-K86P@
M=N9R92!E="!T86PN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HQ,C,R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B;W!E;G-S;"UM;V1U
M;&5T(&5R(&MRYG9E="!A9B!(;W)D95]#<GEP=%]S;6EM93HZ+6ML87-S96XN
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.34@;&EB+TAO<F1E
M+U!R969S+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R
M969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE
M(@IM<V=S='(@(B(*(E!RYF9E<F5N8V5N(%PB)7-<(B!K=6YN92!I:VME(&=E
M;6UE<R!F;W)D:2!D96YS(&1A=&$@;W9E<G-K<FED97(@9&5N("(*(FUA:W-I
M;6%L="!T:6QL861T92!S=/AR<F5L<V4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=V5B8W!P+G!H<#HS-R!L:6(O2&]R9&4O34E-12]6:65W
M97(O9&5B+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I
M<'0N<&AP.C,U(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]W96)C<'`N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB4')O
M9W)A;6UE="P@9&5R(&)R=6=E<R!T:6P@870@8F5T<F%G=&4@9&5N;F4@9&%T
M871Y<&4@*"5S*2P@8FQE=F5T(&EK:V4@(@HB9G5N9&5T('#E('-Y<W1E;65T
M+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X-R!L:6(O1FEL
M92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")#:71A=&EO;G-T
M96=N970@<VMA;"!VYG)E(&5T(&5N:V5L="!T96=N+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@
M(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(DMU;B!H
M^&IR92!O9R!V96YS=')E('-I9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B2W5N('-I9&5N('1I;"!H^&IR92(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.2!L:6(O1FEL92]#
M4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")!9'-K:6QL96QS97-T96=N970@
M<VMA;"!VYG)E(&5T(&5N:V5L="!T96=N+B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V
M97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E<G9E<F5N
M(%PB)7-<(B!E<B!S;&5T=&5T+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")397)V97)E;B!<(B5S7"(@
M97(@9V5M="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R
M96UO=F5D+B(*;7-G<W1R(")/<'-K<FEV;FEN9W-A;FUO9&YI;F=E;B!F;W(@
M)7,@97(@<VQE='1E="XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C0W,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E
M8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$96X@
M86YG:79N92!RYFMK92`H)60I(&5K<VES=&5R97(@:6MK92XB"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I
M960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$96X@86YG:79N92!R
MYFMK92!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HQ-SD@;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")$96X@;6ED;&5R=&ED:6=E(&9I;"!<(B5S7"(@9FEN
M9&5S(&EK:V4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,@IM<V=I9"`B5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*
M;7-G<W1R(")$96X@=&5K<W0L('-O;2!D=2!I;F1T87-T961E+"!P87-S97(@
M:6MK92!T:6P@=&5K<W1E;B!PY2!S:^9R;65N+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(DMU;B!T;W`@
M;V<@8G5N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S
M='(@(DMU;B!T;W`B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<@
M;&EB+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@
M(D1E;B!A9G-E;F1T92!I;F9O<FUA=&EO;B!E<B!T86)T('-I9&5N('-I9'-T
M92!T<FEN+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@HC.B!L:6(O2&]R9&4O
M1&%T82]T<W8N<&AP.C$W,B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V,@IM
M<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*
M;7-G<W1R(")$96X@;W9E<F;X<G1E(&9I;"!K=6YN92!I:VME(&=E;6UE<RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(G=E871H97(N8V]M
M+6)L;VMK96X@97(@:6MK92!T:6QGYFYG96QI9RXB"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")496UA+6MA=&%L
M;V=E="!<(B5S7"(@:6MK92!F=6YD970N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-S@@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*
M;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T
M<B`B26YG96X@=&EL=F%L9R!T:6P@<N5D:6=H960N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S4P(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HS-3`*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$97(@9F]R969I
M;F1E<R!I;F=E;B!D96QE+"!S;VT@:V%N('9I<V5S(&EN9&QE:G)E="XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"B)$97(@97(@9F]R(&UA;F=E('1E9VX@:2!D
M971T92!F96QT+B!$=2!H87(@:6YD=&%S=&5T("5S('1E9VX[(&1U('-K86P@
M(@HB:6YD=&%S=&4@;6EN9')E(&5N9"`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S
M(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E
M<R(*;7-G<W1R(")$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@=&EL9OAJ
M96QS96X@868@)R5S)R!T:6P@<WES=&5M970Z("5S(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B(@HB1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N
M9&5R(&9J97)N96QS92!A9B!D871A(&9O<B!B<G5G97(@7"(E<UPB(&9R82`B
M"B)S>7-T96UE=#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D1E<B!O<'-T;V0@970@
M<')O8FQE;2!U;F1E<B!S;&5T;FEN9R!A9B!<(B5S7"(@9G)A('-Y<W1E;65T
M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM
M<V=S='(@(D1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!O<&1A=&5R:6YG
M(&%F(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HY,C<@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(D1E<B!O<'-T
M;V0@970@<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@26YG96X@)7,@
M8FQE=B!O=F5R9OAR="XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HY,S(@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)$97(@
M;W!S=&]D(&5T('!R;V)L96T@=6YD97(@9FEL;W9E<F;X<G-L96XZ("5S('9A
M<B!S=/AR<F4@96YD(&1E;B!M86MS:6UA;'0@(@HB=&EL;&%D=&4@<W3X<G)E
M;'-E("@E9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3,T(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"XB"FUS9W-T<B`B(@HB1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9I
M;&]V97)F^')S;&5N.B`E<R!B;&5V(&MU;B!D96QV:7-T(&]V97)F^')T+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P
M87)T(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!V:7-N:6YG
M(&%F(&1E;FYE(&)E<VME9&1E;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-#@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!I
M;7!O<G1E<FEN9V5N(&%F(&MO;G1A:W1I;F9O<FUA=&EO;BXB"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$@;&EB+TAO<F1E+T1A=&$O:6UC
M+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J
M;"!U;F1E<B!I;7!O<G1E<FEN9V5N(&%F(&E#86QE;F1A<B!D871A+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B
M"B)$97(@;W!S=&]D(&5N(&9E:FP@:2!K;VYF:6=U<F%T:6]N<V9O<FUU;&%R
M96XN($YU;&EG=FES(&AA<B!D=2!U9&5L861T(&5T("(*(FMRYG9E="!F96QT
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,X"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)$97(@;W!S=&]D(&5T('!R;V)L
M96T@=6YD97(@=61F^')E;'-E(&%F(&1E;B!A;F=I=FYE("(*(F%D<F5S<V5K
M87)T;W1E:W-F=6YK=&EO;BX@4'+X=B!I9V5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E
M:FP@=6YD97(@;W!D871E<FEN9R!A9B!K;VYT86MT+61E=&%L:F5R;F4N(%!R
M^'8@:6=E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(R,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U
M"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(D1E<B!O<'-T
M;V0@96X@9F5J;"!U;F1E<B!O<&1A=&5R:6YG(&%F(&1I<W1R:6)U=&EO;G-L
M:7-T96XN(%!R^'8@:6=E;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B1&5N;F4@24U!4"US97)V
M97(@=6YD97)S=/AT=&5R(&EK:V4@9&5L:6YG(&%F(&UA<'!E<BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")$
M971T92!T>61E<B!I:VME('#E(&%T(';F<F4@970@9WEL9&EG="!R87(M87)K
M:78N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU
M,B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS
M9W-T<B`B1&5N;F4@='ED97(@:6MK92!PY2!A="!VYG)E(&5N(&=Y;&1I9R!Z
M:7`M9FEL+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C<@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E
M;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")$971T92!T
M>61E<B!I:VME('#E(&%T(';F<F4@970@9WEL9&EG="!K;W)T;G5M;65R+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@HB1&5N;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D
M97(@:6=E;FYE;2!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC
M;VTI(&%D9V%N9W-P=6YK=&5T('9E9"!B<G5G(&%F($A45%`@05!)(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH
M='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*(D1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E
M;'-E(&%F(&)E<VME9&5R(&EG96YN96T@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@(@HB861G86YG<W!U;FMT970@=F5D(&)R=6<@868@2%144"!!4$DB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&5N
M;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D97(@:6=E
M;FYE;2!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!A9&=A
M;F=S<'5N:W1E="!V960@8G)U9R!A9B!(5%10($%022(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"B,Z(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!3
M3510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N
M;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@
M86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN(@IM<V=S='(@(B(*(D1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E
M;F1E;'-E(&%F(&)E<VME9&5R('9I82!33510(&EG96YN96T@5F]D869O;F4@
M(@HB271A;&EE;B!A9&=A;F=S<'5N:W1E="P@9&]G(&MU;B!T:6P@5F]D869O
M;F4M;G5M<F4N($1E;B!K<N9V97(@96X@92TB"B)M86EL:V]N=&\@:&]S(%9O
M9&%F;VYE($ET86QI96X@*&AT='`Z+R]W=W<N,3DP+FET*2XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0P."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.3<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#$S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$P-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.#8*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$S.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$U
M-3<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,SD@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#4*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Q-#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(T
M-3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V,S<@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(X,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3D*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,R.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#4@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,X,3,*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(@IM<V=S='(@(D1E='1E(&9E;'0@97(@:W+F=F5T+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B1&5T=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E(&AE;'1A
M;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#$V"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")$971T92!F
M96QT(&WE(&MU;B!I;F1E:&]L9&4@;G5M<F4@;V<@:V]L;VXN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RXB"FUS9W-T<B`B1&5T=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E
M(&]K=&%L92!VYG)D:65R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(B(*(D1E='1E(&9E;'0@<VMA;"!VYG)E(&5N
M(&MO;6UA+2!E;&QE<B!M96QL96UR=6US861S:VEL9'0@;&ES=&4@868@:&5L
M=&%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y(&QI8B](;W)D
M92]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BXB"FUS9W-T<B`B1&5T=&4@9F5L="!S:V%L(';F<F4@970@
M9WEL9&EG="!N=6UM97(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q.`IM<V=I9"`B(@HB5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R(")$
M971T92!F96QT('-K86P@:6YD96AO;&1E(&5N(&9A<G9E:V]D92!I(%)'0B!H
M97@M9F]R;6%T+"!F>"`G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z-38Q(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
M1&5N;F4@9F]R;75L87(@97(@86QL97)E9&4@<')O8V5S<V5R970N(@H*(SH@
M=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B1&5T=&4@97(@)7,N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-CD@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I
M;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*
M(D1E='1E(&5R(&5T($MO;&%B($=R;W5P=V%R92UO8FIE:W0N($9O<B!A="!S
M92!D971T92!O8FIE:W0@:&%R(&1U(&)R=6<@9F]R("(*(F5N(&4M;6%I;"UK
M;&EE;G0L('-O;2!F;W)S=.5R($MO;&%B($=R;W5P=V%R92UF;W)M871E="X@
M0F5S^&<@)7,@9F]R(&5N("(*(FQI<W1E(&%F(&ML:65N=&5R+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.2!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R(")$96YN92!B97-K960@
M97(@<VMR979E="!M960@970@86YD970@=&5G;G/F="`H)7,I(&5N9"!D:70@
M96=E="XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E1A;&QE="!S:V%L(';F
M<F4@;6EN+B`Q+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G
M>FEP+G!H<#HT-2!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R(")$96YN92!S97)V97(@:V%N(&EK:V4@9&5K;VUP
M<FEM97)E('II<"T@;V<@9WII<"UF:6QE<BXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.2!L:6(O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+B(*;7-G<W1R(")$971T92!S>7-T96T@97(@9&5A:W1I=F5R970N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BXB"FUS9W-T<B`B1&5N;F4@=N9R9&D@<VMA;"!VYG)E(&5T
M('1A;"XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U
M"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W(@IM<V=S='(@(D1E='1E('9I;F1U92!S:V%L(&MA;&1E
M<R!F<F$@970@5&EL=F%L9W-V:6YD=64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R
M(")4;W)D96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS
M9VED(")4:6-K971S(@IM<V=S='(@(E-A9V5R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R-0HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS
M9W-T<B`B5&ED(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM
M<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R(")4:61S;W!G^')E;'-E(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*
M;7-G<W1R(")4:61S9F]R;6%T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4S,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S,0IM<V=I9"`B5&EM92!S
M96QE8W1I;VXB"FUS9W-T<B`B5&ED<W9A;&<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R
M86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET96PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED
M(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(E1I=&QE("AT;V]L=&EP*3HB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED
M(")4;R(*;7-G<W1R(")4:6PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4T"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(D9O<B!A
M="!VYFQG92!M=6QT:7!L92!I;F1G86YG92!S:V%L($-T<FPM("A00RD@96QL
M97(@0V]M;6%N9"`H36%C*2UT87-T96X@(@HB:&]L9&5S(&YE9&4@;65D96YS
M(&1E<B!K;&EK:V5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DD@1&%G(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G
M9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E-K:69T($A434PM:VEL9&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R
M;W<B"FUS9W-T<B`B22!M;W)G96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M;VQA8BYP:'`Z,3`T(&QI8B](;W)D92]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G
M:60@(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M
M:6YU=&5S+B(*;7-G<W1R(")&;W(@;6%N9V4@=6=Y;&1I9V4@;&]G:6YD+69O
M<G/X9R!I(&SX8F5T(&%F(&1E('-I9'-T92!M:6YU='1E<BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*;7-G
M:60@(E1O<"(*;7-G<W1R(")4;W`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I
M(@IM<V=S='(@(E1O<"!F<F%M92`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")/=F5R
M<^9T=&5L<V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@
M5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D(&]G(%1O8F%G;R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`@;&EB+TAO<F1E+T9O<FTN<&AP.C$W
M.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B4V%N9"!E;&QE<B!F
M86QS:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(E1I<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YE<VEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1Y<FMI970B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB
M"FUS9W-T<B`B5'ER:VES:R`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*
M;7-G<W1R(")4=7)K<R!O9R!#86EC;W,@V&5R;F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C8T(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B
M5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(E-K<FEV(&1I="!V86QG.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5
M+E8N(&EN9&5X.B`B"FUS9W-T<B`B52Y6+BUI;F1E:W,Z("(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B
M55),(&9O<B!S:W)I<'0@=&EL(&UO9'1A9V5L<V4@868@<W1A='5S(')A<'!O
M<G1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:6YE(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$Y(&QI8B]61E,O9FEL92YP:'`Z-#$Y
M"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMU;FYE(&EK:V4@=&EL9^4@5D93+6MA=&%L;V<N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(DMA;B!I:VME
M('1I;&;X:F4@96MS=')A(&)R=6=E<B!I;F9O<FUA=&EO;B!U;F1E<B!O<'-K
M<FEV;FEN9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y,R!L
M:6(O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")+86X@:6MK92#F;F1R92!T:6QL861E;'-E<B!F;W(@5D93+69I
M;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,SDR
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HS.3(@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(DMA;B!I:VME(.9N9')E('1I;&QA9&5L
M<V5R(&9O<B!61E,M9FEL("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S@V(&QI8B]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B2V%N
M(&EK:V4@<VMI9G1E('1I;"`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(S-R!L:6(O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*
M;7-G<W1R(")+86X@:6MK92!T:F5K:V4@9FEL<W3X<G)E;'-E;B!A9B!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z.#4P(&QI8B]61E,O9FEL92YP:'`Z-CDU"B,Z(&QI
M8B]61E,O<W%L+G!H<#HQ,#(X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@=&IE:VME(&9I;'-T
M^')R96QS96X@868@7"(E<R\E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HT,SD@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@
M(DMU;FYE(&EK:V4@9N4@9F]R8FEN9&5L<V4@=&EL(%-13"!S97)V97)E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,"!L:6(O5D93+V9T
M<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB
M"FUS9W-T<B`B2V%N(&EK:V4@9N4@9F]R8FEN9&5L<V4@;65D(%-33"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S(@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W(&QI8B]6
M1E,O9FEL92YP:'`Z,C,R"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,W(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C(P-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]P:65R92!61E,M
M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P(&QI8B]6
M1E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK
M:V4@9&%N;F4@5D93+6MA=&%L;V<@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,V,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0@
M;&EB+U9&4R]F:6QE+G!H<#HS-C$*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C4X
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!D86YN92!6
M1E,M:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3(T(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@;&%V92!61E,M9FEL
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP(&QI8B]61E,O
M<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@;W!R
M971T92!61E,M;6%P<&4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(W,B!L:6(O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK
M:V4@;&%V92!T;VT@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP
M.C<Y"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V"FUS9VED(")5
M;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")+86X@:6MK92!D
M96MO;7!R:6UE<F4@9&%T82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R.`HC.B!L:6(O
M5D93+V9T<"YP:'`Z,S`S(&QI8B]61E,O<VUB+G!H<#HR,C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@
M7"(E<UPB.R!K871A;&]G970@97(@:6MK92!T;VUT+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(DMA;B!I:VME('-L971T92!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S."!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDU
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HS,S@@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q(&QI8B]61E,O
M<W%L+G!H<#HS.34*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DMA;B!I:VME('-L971T92`E
M<SL@:V%T86QO9V5T(&5R(&EK:V4@=&]M="(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,V,`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-38@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DMA;B!I:VME('-L
M971T92!61E,M:V%T86QO9V5T(')E:W5R<VEV="XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,U,B!L:6(O5D93+V9I;&4N<&AP.C,T-`HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U
M(&QI8B]61E,O;75S<6PN<&AP.C,T,PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&4RUK871A;&]G+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#,R"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C`@;&EB+U9&4R]S
M<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")+86X@:6MK92!S;&5T
M=&4@5D93+6MA=&%L;V<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,C$R(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DMA;B!I:VME('-L971T92!61E,M9FEL(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$V-PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3@P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR.3$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDY(&QI8B]61E,O9FEL92YP:'`Z,S$P"B,Z(&QI8B]61E,O;75S<6PN
M<&AP.C$V-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3@W"B,Z(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDQ(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@<VQE
M='1E(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#@@;&EB+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6MK92!S;&5T=&4@5D93+6UA<'!E(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0P.2!L:6(O5D93+W-Q;"YP:'`Z-#`Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&4R!R96MU
M<G-I=G0Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T
M(&QI8B]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VME(&)E<W1E
M;6UE(&%K='5E;'0@:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8P-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P
M-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<R(*;7-G<W1R(")+86X@:6MK92!U9&1R86=E(&-E<G1I9FEK870M9&5T86QJ
M97(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE
M=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC.B!L:6(O3F5T+TE-
M4U`N<&AP.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R(")+86X@:6MK92!I;F1LYG-E(&1E9FEN:71I;VYE;B!A
M9B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#,@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-S0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$W.0HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,R!L:6(O5D93+V9I
M;&4N<&AP.C(P."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S0*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@9FQY='1E(%9&4RUF:6PN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY."!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI8B]61E,O9G1P
M+G!H<#HY."!L:6(O5D93+W-M8BYP:'`Z.3,@;&EB+U9&4R]S;6(N<&AP.C$P
M-@HC.B!L:6(O5D93+W-M8BYP:'`Z-C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N
M(&EK:V4@Y6)N92!61E,M9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR.#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q
M(&QI8B]61E,O9FEL92YP:'`Z,C@T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")+86X@:6MK
M92#E8FYE(%9&4RUF:6P@=&EL('-K<FEV;FEN9RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HX,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<V(&QI
M8B]61E,O9FEL92YP:'`Z.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S<*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92#E8FYE(%9&4RUF:6PN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-2!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")+86X@:6MK92#E8FYE
M(&MO;7!R:6UE<F5T(&%R:VEV+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX-38@;&EB+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(")+86X@:6MK
M92!LYG-E(%9&4RUF:6P@*&9I;&5S:7IE*"D@9F5J;&5D92DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@X-R!L:6(O5D93+G!H<#HX.#<*;7-G:60@
M(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(DMA;B!I:VME(&SF<V4@5D93+69I;"`H9V5T1FEL95-I
M>F4H*2!F96IL961E*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(SH@;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F
M:6QE.B`B"FUS9W-T<B`B2V%N(&EK:V4@;.9S92!F:6PZ("(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8W-B!L:6(O5D93+V9I;&4N<&AP.C8W
M-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+B(*;7-G<W1R(")+86X@:6MK92!LYG-E('9F<W)O;W0M:V%T86QO9V5T+B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P.2!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$Q,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(DMA;B!I:VME(&]M9/AB92`E<R!T:6P@)7,Z(&WE
M;&UA<'!E;B!F:6YD97,@86QL97)E9&4B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S`Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P,0IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")+86X@:6MK92!O;63X8F4@5D93+6MA=&%L;V<N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS,S(@;&EB+U9&4R]S<6PN<&AP.C,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(")+86X@:6MK92!O;63X8F4@5D93+6MA=&%L;V<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0X(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C<Q"B,Z(&QI8B]61E,O9G1P+G!H<#HS
M-#@@;&EB+U9&4R]S;6(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N
M(&EK:V4@;VUD^&)E(%9&4RUF:6P@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C(Y"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$W(&QI8B]61E,O;75S<6PN
M<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6MK92!O;63X8F4@5D93
M+69I;"`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C$S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS,C8@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S`Y(&QI8B]61E,O;75S<6PN<&AP.C(Q,PHC.B!L:6(O5D93+VUU<W%L
M+G!H<#HT-3(@;&EB+U9&4R]S<6PN<&AP.C,R-B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HR.3,*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!O
M;63X8F4@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(SH@;&EB+U9&4R])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R(")+86X@:6MK92!A9G9I:VQE("=M:VES;V9S)RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")+
M=6YN92!I:VME(&]V97)SYG1T92!D971T92!7;W)D(&1O:W5M96YT(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HQ-3<*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L:6(O5D93
M+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME('-K<FEV
M92!61E,M9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ.#8@;&EB+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DMA
M;B!I:VME('-K<FEV92!61E,M9FEL("AC;W!Y*"D@9F5J;&5D92DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$U,2!L:6(O5D93+V9I;&4N<&AP.C(X.`HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B
M2V%N(&EK:V4@<VMR:79E(%9&4RUF:6QD871A+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-C(@;&EB+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM
M<V=S='(@(DMA;B!I:VME('-K<FEV92!61E,M9FEL.R!K=F]T96X@=FEL(&)L
M:79E(&]V97)S:W)E9&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")5
M;F1E<FQI;FEE<F5T(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM
M<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D9O<G1R>60@YFYD<FEN9V5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B3VUG
M^'(@9&EN('-I9'-T92!H86YD;&EN9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@X"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")5=F5N=&5T(')E86MT:6]N(&9R82!S
M97)V97(@<.4@9F]R8FEN9&5L<V5N.B`B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#(@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(Q-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E5V96YT970@
M<F5A:W1I;VX@9G)A('-E<G9E<B!PY3H@(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@;&EB+TAO<F1E+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B26MK92!A;F)R86=T(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A5
M5$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B
M"FUS9W-T<B`B1F]R96YE9&4@07)A8FES:V4@16UI<F%T97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")3=&]R8G)I='1A
M;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G
M<W1R(")54T$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")54T%S('5N9&5R;W)D
M;F5D92#X97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B56YI=',B"FUS9W-T<B`B
M16YH961E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-3@@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,"!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HU.`HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN
M;W=N(@IM<V=S='(@(E5K96YD="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")5:V5N9'0@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3D*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N
M="!-97-S86=E($E$*2XB"FUS9W-T<B`B56ME;F1T(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B56ME;F1T('-T960@86YG:79E="XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5K96YD="!B<G5G97)N879N
M(&5L;&5R(&MO9&5O<F0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N="(*;7-G<W1R(")(YF=T(&%K='5E;'0@96QE;65N="!A
M9BXB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,B!L
M:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G
M<W1R(")):VME(&YA=FYG:79E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB57!R:79I;&EG97)E9&4@<VMR:7!T
M97(@:V%N(&EK:V4@=&EL9^4@:VQI<'!E+VMO<&DO:6YD<^9T('!R;V=R86UM
MYG-S:6=T(&%F("(*(G-I:VME<FAE9'/E<G-A9V5R+B`@2VQI:R!/2R!F;W(@
M870@<V4@96X@=&5K;FES:R!N;W1E(&AO<R!M;WII;&QA+F]R9RP@<V]M("(*
M(G9I<V5R(&1I9RP@:'9O<F1A;B!D=2!K86X@=&EL;&%D92!E="!S:W)I<'0@
M870@=&EL9^4@=61K;&EP<VAO;&1E<F5N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T
M(&-O;&]R(@IM<V=S='(@(D9A<G9E(&EK:V4@:6YD<W1I;&QE="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3,S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C@W"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E
M;G-I;VXB"FUS9W-T<B`B561V:61D96QS92!I:VME('5N9&5R<W3X='1E="(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,3DW"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B3W!D873I<B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D]P9&%TZ7(@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5
M<&1A=&4@=7-E<B(*;7-G<W1R(")/<&1A=.ER(&)R=6=E<B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@;W!D871E<F5T+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E
M('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")/<&=R861E<FEN9W,M9F]R97-K
M<FEF="!S;&5T=&5T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5
M<&QO860B"FUS9W-T<B`B57!L;V%D(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(D]P<^9T;FEN9W-F:6QE
M<B!T:6P@86QL92!A<'!L:6MA=&EO;F5R(&QA9W0@;W`@<.4@<V5R=F5R+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M4W1O<F4@;&%T:6YS:V4@8F]G<W1A=F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")3=&]R92!R;VUE<G1A;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-#4*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@
M(D%N=F5N9"!N=7;F<F5N9&4Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")"
M<G5G(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@
M(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N(@IM<V=S='(@(D)R=6<@:'9I<R!N879N+VMO9&5O<F0@97(@9F]R
M<VME;&QI9R!F;W(@24U34"US97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")"<G5G
M97(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W
M-"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T
M<B`B0G)U9V5R("5S(&EK:V4@8F5M>6YD:6=E="!T:6P@)7,N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D)R=6=E<BUA9&UI;FES=')A=&EO;B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,C0U(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B0G)U9V5R:6YD<W1I
M;&QI;F=E<B(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T
M<F%T:6]N(@IM<V=S='(@(D)R=6=E<BUR96=I<W1R97)I;F<B"@HC.B!S:6=N
M=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")"<G5G97(M<F5G:7-T
M<F5R:6YG(&5R(&)L979E="!S;.5E="!F<F$@<.4@9&5T=&4@=V5B<W1E9"XB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#DT"FUS9VED(")5<V5R(&%C
M8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(D)R=6=E<FMO;G1O(&EK:V4@9G5N
M9&5T(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-3`@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDX(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E
M<FYA;64B"FUS9W-T<B`B0G)U9V5R;F%V;B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HQ,C0@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R(")"<G5G97)N879N(%PB)7-<(B!F:6YD
M97,@86QL97)E9&4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B0G)U9V5R;F%V;CHB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(D)R=6=E<FYA=FXZ("(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ
M(@IM<V=S='(@(D)R=6=E<F4@:2!S>7-T96UE=#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57-B96MI<W1A;B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,"!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-C(*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@;&EB+U9&
M4R]F:6QE+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(E9&4RUK871A;&]G(&5K<VES=&5R97(@:6MK92XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A
M=&EO;B(*;7-G<W1R(")&97)I92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(D=Y;&1I9V4@9G5N
M9&5T('-T961E<B!I;FML=61E<F5R.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C,Y(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")'>6QD:6=H960B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.3<*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@
M:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5N9R9&D@97(@;6EN=71T
M97(@9G)A(&YU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HX-38@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@
M)7,N(@IM<V=S='(@(E;F<F1I(&5R(&UE<F4@96YD(&1E;B!M86MS:6UA;&4@
M;.9N9V1E(&%F("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,3`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-`HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDQ,`HC.B!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E;F<F1I97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,#D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*
M;7-G<W1R(")6YG)D:65R+"!D97(@:V%N(';F;&=E<R!I8FQA;F1T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I
M86)L92(*;7-G<W1R(")3:VEF=&5N9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q."!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@
M(D5F=&5R<'+X=FYI;F<@9F5J;&5D92`M(&1E<B!E<B!B;&5V970@<&EL;&5T
M('9E9"!D96YN92!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,#$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEO;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*
M;7-G<W1R(")697)S:6]N<VMO;G1R;VPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;"!A;&EG;B(*;7-G<W1R("),;V1R970@;W!S=&EL;&EN9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E
M<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B3&]D<F5T(&9O<G)I;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED
M(")697)T:6-A;#HB"FUS9W-T<B`B3&]D<F5T.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")697)Y($AI9V@B
M"FUS9W-T<B`B365G970@:/AJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T
M($YA;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE
M=&YA;65S:7-K("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.3<Q(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")6:7,@
M)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E-E('#E(&5K<W1E<FX@=V5B
M<VED92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,P"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES('-O;2`E<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS
M9W-T<B`B2F]M9G)U^&5R+"!"<FET:7-K92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B2F]M9G)U^&5R+"!!
M;65R:6MA;G-K92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED
M(")6:7-I8FEL:71Y(@IM<V=S='(@(E-Y;FQI9VAE9"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R(")3>6YL:6=H960Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY
M('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE($ET86QI96X@=FEA(%--5%`B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,V"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")7
M05).(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N(@IM<V=S='(@(D%$5D%24T5,(2$A($9*15).(%-#4DE05"!-
M04Y514Q4($9202`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$S,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS
M9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.('9I82!(5%10(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")7
M86QL:7,@;V<@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.CDU"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%D=F%R<V5L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM
M<V=I9"`B5V4B"FUS9W-T<B`B3VYS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@
M(E9E:G)U9'-I9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B
M5F5J<FEN9F]R;6%T:6]N('-T:6QL970@=&EL<N5D:6=H960@868B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S
M='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8G-I=&4B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X(&QI8B](;W)D92]-86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")59V5N=&QI
M9R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")7
M96QC;VUE(@IM<V=S='(@(E9E;&MO;6UE;B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-3<@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E9E
M;&MO;6UE;B!T:6P@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5F5L:V]M;65N+"`E<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ*2(*;7-G<W1R(")697-T;&EG("A)4T\M.#@U.2TQ*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M
M.#@U.2TQ-2DB"FUS9W-T<B`B5F5S=&QI9R`H25-/+3@X-3DM,34I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E9E<W1S86AA
M<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_(@IM<V=S='(@(DAV:6QK96X@87!P;&EK871I;VX@<VMA
M;"`E<R!V:7-E(&5F=&5R(&QO9VEN9#\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\B"FUS9W-T<B`B2'9A9"!E<B!S97!A<F%T;W)T96=N970_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@
M:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B2'9A9"!E<B!C:71A
M=&EO;G-T96=N970_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-C4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G
M<W1R(")7:&5R96ES($%U<W1R86QI96XM:V]R="(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(DAV:6QK
M92!F87-E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@
M(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BXB"FUS9W-T<B`B2'9I;&ME('!L=6=I;G,@<VMA;"!A:W1I=F5R97,@
M9F]R(%)I8V@@5&5X="UVYG)K=/AJ970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B
M"FUS9W-T<B`B0G)E9&1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$P-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM<V=I9"`B5VED=&@@:6X@
M0U-3('5N:71S(@IM<V=S='(@(D)R961D92!I($-34RUE;FAE9&5R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F
M96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B0G)E9&1E(&%F("5S+6UE
M;G5E;B!T:6P@=F5N<W1R92`H8FQI=F5R(&%K=&EV97)E="!V960@;N9S=&4@
M;&]G:6YD*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@
M(D)R961D92!A9B!T86)E;&QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S
M='(@(D)R961D92UE;FAE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B0G)E
M9&1E.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@
M(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C<*;7-G:60@(E=I;F0B"FUS9W-T<B`B5FEN9"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A
M<FQY(@IM<V=S='(@(D)LYG-T('1I9&QI9W0B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@
M(E9I;F1H87-T:6=H960@:2!K;F]B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9I;F0Z(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S
M='(@(E9I;F0Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I
M9"`B5VES9&]M(@IM<V=S='(@(E9I<V1O;2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(MAN<VME
M;&ES=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O
M<FLB"FUS9W-T<B`B07)B96ID92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$V-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@*&%R
M8F5J9&4I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N("AA<F)E:F1E
M*2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ
M.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(D9O<FME<G0@86YT86P@9F5L=&5R(&D@
M;&EN:64@)60N($9O<G9E;G1E9&4@)60L(&9A;F1T("5D+B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S,B!L:6(O1FEL92]#4U8N<&AP.C,S
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D9O<FME<G0@86YT
M86P@9F5L=&5R+B!&;W)V96YT961E("5D+"!F86YD="`E9"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C$@;&EB+U9&4R]F:6QE+G!H<#HQ
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B1F]R:V5R="!F;W)S:WED
M;FEN9R`E9"!U;F1E<B!I;F1LYG-N:6YG(&%F(&5N(%9&4RUF:6PN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS
M9W-T<B`B6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DS(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R
M(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N
M=&EF:65R(@IM<V=S='(@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!U9'9I9&1E;'-E<B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+%Q2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T
M<B`BQ<7%Q2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3$Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2UK;W)T
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M-B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB
M"FUS9W-T<B`BQ7)L:6<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM
M<V=S='(@(EEE;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.38V"FUS9VED(")997,B"FUS9W-T<B`B2F$B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S
M+"!)($%G<F5E(@IM<V=S='(@(DIA+"!J96<@97(@96YI9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO
M=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S
M=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)$=2!B969I;F1E
M<B!D:6<@:2!414M35"!-3T154RX@($)R=6<@6SP^72UK;F%P<&5N('1I;"!A
M="!S:VEF=&4@=&EL8F%G92!T:6P@(@HB5UE325=91RXB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")$=2!H87(@:6MK92!T:6QL861E
M;'-E('1I;"!A="!O<')E='1E(&UE<F4@96YD("5D(&)L;VMK92XB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C0@;&EB+TAO<F1E+G!H<#HQ
M-#(T"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R
M(")$=2!E<B!I:VME(.9G=&5T+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,S`X(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`X"FUS
M9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+B(*;7-G<W1R(")$=2!K86X@:6MK92!H879E("=<7"<M
M=&5G;F5T(&D@9&ET(&9U;&1E(&YA=FXN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N(@IM<V=S='(@(D1U(&EN9'1A<W1E9&4@:6MK92!E;B!G>6QD:6<@
M92UP;W-T+6%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,CDP(&QI8B](;W)D92]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O
M<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E
M<RXB"FUS9W-T<B`B(@HB1F]R(&%T(&EM<&]R=&5R92!S:V%L(&1U('1I;&]R
M9&YE(&9E;'1E<B!F<F$@9&5N(&9I;"!D=2!I;7!O<G1E<F5R('1I;"!D92`B
M"B)T:6QS=F%R96YD92!F96QT97(@:2`E<RXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.#<@;&EB+TAO<F1E+T%U=&@N<&AP.CDX-PIM<V=I9"`B
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")$=2!E<B!B;&5V
M970@;&]G9V5T('5D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)$=2!S:V%L(&EN9'1A
M<W1E(&5T(&9U;F=E<F5N9&4@;6]B:6QN=6UM97([(&MU;B!C:69R92!M960@
M970@=F%L9V9R:2`G*R<@9F]R("(*(F1E;B!I;G1E<FYA=&EO;F%L(')E=&YI
M;F=S:V]D92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")$=2!S:V%L(&EN9'1A<W1E(&5N
M(&=Y;&1I9R!VYG)D:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,S<@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RXB"FUS9W-T<B`B(@HB1'4@<VMA;"!K;VYF:6=U<F5R92!E;B!$
M871A5')E92UB86-K96YD(&9O<B!A="!K=6YN92!A;G9E;F1E($]P<VMR:79N
M:6YG97(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S$@;&EB
M+TAO<F1E+G!H<#HT-S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+B(*;7-G<W1R(")$=2!S:V%L(&MO;F9I9W5R97)E(&5N9"!6
M1E,M8F%C:V5N9"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F
M;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@
M(B(*(D1U(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@<')O8FQE;6)E<VMR
M:79E;'-E+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(D1U('-K86P@:6YD=&%S=&4@9&5N(%523"!H=F]R=&EL(&1E
M;FYE(&CF9W1E('-K86P@:&5N=FES92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N(@IM<V=S='(@(D1U('-K86P@=N9L9V4@9&5N('-E
M<G9E<BP@<V]M('-K86P@<VQE='1E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N(@IM<V=S='(@(D1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@
M<V]M(&1U('9I;"!F:F5R;F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*
M;7-G<W1R(")$=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D=2!V
M:6P@9FIE<FYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")$=2!S:V%L(&%N9VEV
M92!B<G5G97)N879N970L('-O;2!D=2!V:6P@=&EL9OAJ92XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B1'4@<VMA;"!A;F=I=F4@8G)U
M9V5R;F%V;F5T+"!S;VT@9'4@=FEL(&]P9&%T97)E+B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S."!L:6(O2&]R9&4O0V]M
M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA
M="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B1'4@<VMA;"!A;F=I=F4@
M9&5N(&AA;F1L:6YG+"!S;VT@<VMA;"!U9&;X<F5S+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,Z(&QI8B](
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U('-K
M86P@86YG:79E(&5T(&YY="!K871E9V]R:6YA=FXN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*(SH@;&EB
M+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G
M<W1R(")$=2!B;&EV97(@;OAD="!T:6P@870@86YG:79E(&5T(&ET86QI96YS
M:V4@=&5L969O;FYU;6UE<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDW-2!L:6(O2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+B(*;7-G<W1R(")$:6X@)7,@<V5S<VEO;B!E<B!U9&SX8F5T+B!,
M;V<@=F5N;&EG<W0@:6YD(&EG96XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G
M<W1R(")$:6X@92UP;W-T+6%D<F5S<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(D1I;B!&<F]M.B!A9')E<W-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$:6YE(&EN9F]R;6%T:6]N97(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D1I;B!);G1E
M<FYE="UA9')E<W-E(&5R('-K:69T970@<VED96X@8F5G>6YD96QS96X@868@
M9&EN("5S+7-E<W-I;VXN($9O<B!A="`B"B)B97-K>71T92!D:6X@<VEK:V5R
M:&5D(&)L:79E<B!D=2!N^&1T('1I;"!A="!L;V=G92!I;F0@:6=E;BXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(D1I="!N879N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(D1I;B#F9W1N:6YG<RUB86-K
M96YD('5N9&5R<W3X='1E<B!I:VME('1I;&;X:F5L<V5N(&%F(&)R=6=E<F4N
M($AV:7,@9'4@(@HB^&YS:V5R(&%T(&)R=6=E($AO<F1E('1I;"!A="!A9&UI
M;FES=')E<F4@8G)U9V5R:V]N=&DL(&)L:79E<B!D=2!N^&1T('1I;"!A="`B
M"B)B<G5G92!E;B!A;F1E;B#F9W1N:6YG<RUB86-K96YD+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)$:6X@875T;W)I
M<V%T:6]N<RUB86-K96YD('5N9&5R<W3X='1E<B!I:VME(&]P;&ES=&YI;F=E
M;B!A9B!B<G5G97)E(&5L;&5R(&5R("(*(F1E;B!F=6YK=&EO;B!A9B!E;B!E
M;&QE<B!A;F1E;B!G<G5N9"!B;&5V970@<VSE970@9G)A+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX,R!L:6(O2&]R9&4O075T:"YP:'`Z.3@S
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB1&EN(&)R;W=S97(@<WEN
M97,@870@=N9R92!S:VEF=&5T('-I9&5N(&)E9WEN9&5L<V5N(&%F(&1I;B`E
M<RUS97-S:6]N+B!&;W(@(@HB870@8F5S:WET=&4@9&EN('-I:VME<FAE9"P@
M<VMA;"!D=2!L;V=G92!I;F0@:6=E;BXB"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HU-PIM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+B(*;7-G<W1R(")$:6X@8G)O=W-E<B!U;F1E<G-T^'1T
M97(@:6MK92!D96YN92!F=6YK=&EO;F%L:71E="XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(D1I
M;B!B<F]W<V5R('5N9&5R<W3X='1E<B!I:VME(&1E;FYE('!R:6YT+6UU;&EG
M:&5D+B!4<GEK($-T<FPO0V]M;6%N9"`K(%`@(@HB9F]R(&%T('!R:6YT92XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U
M<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")$:6X@86MT=65L;&4@=&ED<WIO
M;F4Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(D1I
M;B!F;W)V86QG=&4@:61E;G1I=&5T(&5R(.9N9')E="XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ(@IM<V=S='(@(D1I;B!S=&%N9&%R9"UI9&5N=&ET970Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(D1I="!F=6QD92!N879N.B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY.2!L:6(O2&]R9&4O075T:"YP:'`Z.3DY"FUS9VED(")9
M;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")$:70@;&]G:6YD(&5R
M('5D;/AB970N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(*;7-G<W1R(")$:70@;GEE(&MO9&5O<F0@9F]R("5S(&5R.B`E
M<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN(@IM<V=S='(@(D1I;F4@=&EL=F%L9R!E<B!B;&5V970@;W!D871E<F5T
M(&9O<B!V87)I9VAE9&5N(&%F(&1E;FYE('-E<W-I;VXN(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"XB"FUS9W-T<B`B1&EN92!T:6QV86QG(&5R(&]P9&%T97)E="XB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")$:70@:V]D96]R9"!E<B!B
M;&5V970@;G5L<W1I;&QE="(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B
M"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB1&ET(&MO9&5O<F0@97(@8FQE=F5T
M(&YU;'-T:6QL93L@:V]N=')O;&SI<B!D:6X@:6YD8F%K:V4@;V<@;&]G(&EN
M9"!M960@9&ET("(*(FYY92!K;V1E;W)D+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,R!L:6(O2&]R9&4O075T:"YP:'`Z-S,S"FUS9VED(")9
M;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")$:70@:V]D96]R
M9"!E<B!U9&SX8F5T+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B1&EN
M92!F:F5R;F4@<V5R=F5R93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S;&%V:65N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA
M[W)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M
M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("):
M:6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B
M6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI
M9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM3:VIU;"!C:71E<F5T('1E:W-T
M72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE
M;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;&5M8F5S:W)I=F5L<V5=(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@
M(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6U9I<R!C:71E<F5T('1E
M:W-T("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");5FES(&-I
M=&5R970@=&5K<W0@+2`E<R!L:6YI97)=(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HR,#0@;&EB+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YI92`E<R!U
M9"!A9B`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-30@
M;&EB+TAO<F1E+G!H<#HQ-34T"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES
M=')A=&EO;B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G
M<W1R(")#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E
M92(*;7-G<W1R(")$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B4VQE="!RYFMK92(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM
M<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-2!L:6(O2&]R9&4O365N=2YP:'`Z
M,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")(:N9L<"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B0FEL;&5D+65G96YS
M:V%B97(N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3DT(&QI8B](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS
M9W-T<B`B3&]G(&EN9"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ.3`@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B3&]G('5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI
M;FLN+BXB"FUS9W-T<B`BQFYD<FEN9R!H96YV:7-N:6YG+BXN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-"!L:6(O2&]R9&4O365N
M=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("));F1S=&EL;&EN
M9V5R(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B5&EL;&%D96QS97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R(")3;&5T(&AE;G9I<VYI;F<N+BXB"@HC.B!L:6(O
M87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")/<'/F=&YI;F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E1A8F5L+65G96YS:V%B97(N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G
M:60@(E]5<V5R<R(*;7-G<W1R(")"<G5G97)E(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C4@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C4*;7-G
M:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")A9')E<W-E:V%R=&]T96LB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-"!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN
M;W=N(@IM<V=S='(@(F%D<F5S<V5N="!U:V5N9'0B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-R!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ-PIM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L96YD97(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(G9I;F1S=&EL;&4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U."!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@
M;W5T<'5T(&9I;&4B"FUS9W-T<B`B:V%N(&EK:V4@9&%N;F4@=61D871A+69I
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B:V%N(&EK:V4@Y6)N92!I;F1D871A(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`B:VQI:R!H97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G
M:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")F96IL('9E
M9"!A;G9E;F1E;'-E(&%F(&MO;6UA;F1O+6QI;FEE(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(FMO;F9I9W5R871I;VYS9F5J;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34T(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G
M<W1R(")M86YG;&5R(&MR:71I<VL@<WES=&5M9FEL(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R
M(")F96IL(&D@9&%T869O<FUA="(*"B,Z('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B<F5D:6=E<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM
M<V=S='(@(FEN9&=A;F<@:6MK92!F=6YD970B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*;7-G
M<W1R(")F86QD96YD92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@Y."!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE
M(@IM<V=S='(@(F9I;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`B9G)A("5S("@E<RD@;65D("5S("5S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G
M<W1R(")S=&]R;69U;&0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C4P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G
M<W1R(")H:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,X(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S
M="!N86UE('5N:VYO=VXB"FUS9W-T<B`B=6ME;F1T(&UA<VMI;FYA=FXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM
M961I871E(@IM<V=S='(@(OAJ96)L:6MK96QI9W0B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M:6YL:6YE(@IM<V=S='(@(FEN9&QE:G)E="(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38R(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEN
M9&1A=&$O=61D871A+69E:FPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T-B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#8*
M;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(FEN=&5R
M;B!S;V9T=V%R92UF96IL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")L:6YI97)=
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4S"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S
M"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")M:VES;V9S(&9E:FQK;V1E("5D
M('5N9&5R(&1A;FYE;'-E(&%F($E33RXB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-S`*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#4@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HR.#4*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$W,"!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED
M(")N86UE(@IM<V=S='(@(FYA=FXB"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP
M:'`Z,3(T(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(FEK:V4@:6UP;&5M96YT97)E="(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(R,"!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B
M"FUS9W-T<B`B96YD;G4@:6MK92!I;7!L96UE;G1E<F5T(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#D@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B;F]T97-B;&]K(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM
M<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P<F]C96YT(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M(")T:6QL861E;'-E(&[F9W1E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G
M<W1R(")P<FEK:V5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S`@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED
M(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B9F5J;"!I('!R
M;W1O:V]L(&9R82!F:F5R;B!S:61E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")S
M=&EG96YD92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,30R(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R
M=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")T:F5N97-T92!U=&EL9^9N9V5L
M:6<B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO
M=R!D:69F97)E;F-E<R(*;7-G<W1R(")V:7,@9F]R<VME;&QE(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS
M,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%144"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I
M9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G-T86)I
M;'0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,"!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E
M<G)O<B(*;7-G<W1R(")S>7-T96UF96IL(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,S,@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*;7-G:60@
M(G1A<VL@;&ES="(*;7-G<W1R(")O<&=A=F5L:7-T92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V(&QI8B](;W)D92]-24U%+TUE
M<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T
M<B`B;6ED;&5R=&ED:6<@9F5J;'1I;'-T86YD(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")I;F1T87-T(&MO
M9&5O<F1E="!T;R!G86YG92!F;W(@870@8F5K<N9F=&4B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B=6YI9FEE9"(*;7-G<W1R(")S86UM96YS;65L=&5T(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-R!L:6(O2&]R9&4O34E-12]087)T
M+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")U;F%V;F=I=F5N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S
M97(@<V5L96-T(@IM<V=S='(@(F)R=6=E<G9A;&<B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A
M<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C0R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*
M;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H
M97(N8V]M(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V-S7T-:+G!O````````````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`W,C$Q-S$`
M,3`U,34T,S$P-C,`,#$V,S<W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@0WIE8V@@=')A;G-L871I;VYS(&9O<B!(;W)D
M92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!(;W)D92!P86-K86=E+@HC(%!A=F5L($-H>71I;"`\<&%V96Q`8VAY
M=&EL+G1K/BP@,C`P,2TR,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C!<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`T+3`W+3(R(#$Q.C0Y+3`W,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@36EL;W,@5VEM;65R(#QW:6UM97)`>F-U+F-Z/EQN(@HB3&%N9W5A9V4M
M5&5A;3H@0WIE8V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3,[('!L=7)A;#TH
M;B4Q,#T],2`F)B!N)3$P,"$],3$@/R`P(#H@;B4Q,#X],B`F)B!N)2(*(C$P
M/#TT("8F("AN)3$P,#PQ,"!\?"!N)3$P,#X],C`I(#\@,2`Z(#(I.UQN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*'#X960@)7,@9&YY
M*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A0^.US
M='5P;W;](&ML[>@@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S
M='(@(B`H=B`E<R!D;F5C:"DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&1N97,I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O
M=RDB"FUS9W-T<B`B("AZ[71R82DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AVZ&5R
M82DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(@<GEC:&QO
M<W0@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYE;NT@861R97/A^&5M(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)7,@;F5L>F4@
M>G9O;&ET+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B
M)R5S)R!N96[M(&YA:V]N9FEG=7)O=N%N('8@<F5G:7-T<F5C:"!(;W)D92!S
M>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(G)7,G('#X96ML861AZ"!N96)Y;"!N86QE
M>F5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN(@IM<V=S='(@(B5S)R!B>6P@</AI9.%N(&1O('-Y<W3I;74@<VMU
M<&EN+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G(&)Y;"!P^&EDX6X@
M9&\@<WES=.EM=2!P^.US='5P;W;]8V@@<'+A=BXB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@
M)7,N(@IM<V=S='(@(B<E<R<@;F5B>6P@=GET=F_X96XZ("5S+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!A
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M9&5N
M;NT@</AE9'!O=NSO(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S
M("T@;WINX6UE;NTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*
M;7-G<W1R("(E<R!O=&ES:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@
M2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(E<R!O<&5R86-E(/ID<KYB>2`M('!O='9R>F5N
M[2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*
M;7-G<W1R("(E<R!N87-T879E;NTB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@
M57`B"FUS9W-T<B`B)7,@<F5G:7-T<F%C92(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O
M9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@<&]D;>UN:WD@<&]UONUVX6[M(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&II
MOB!E>&ES='5J92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R
M("(E<R!N82`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")/
M>FYAZ&ET('+A;67H96L@<')O(':Y96-H;GD@;W!E<F%C92P@:W1E<ND@8VAC
M971E('1E[R!P<F]VZ7-T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS
M9W-T<B`B)7,@:F4@<&^^861O=N%N;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T
M<B`B)7,@;6EN=70B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B)7,@;F5B>6QO(&YA;&5Z96YO+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@8;X@)7,@>B`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S(&%D<F5SX?@B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S(&MA;&5N9.'X(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S('KA<&ES;NUK(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E<R!S97IN86T@^FMO
M;/DB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I
M;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,3`*(RP@9G5Z>GD*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!N
MX7)A>F]V_2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&[A<F%Z;W;]("5S("5S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@<')O;>QN;N$@
M;V0@)7,@9&\@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(';]8NQR
M("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R
M($9O<FUA="(*;7-G<W1R("(Q,B!H;V1I;F]V_2!F;W)MX70B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S
M='(@(C(T(&AO9&EN;W;](&9O<FWA="(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!H;V1I;B(*
M"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G
M:60@(CQ0<F5V:6]U<R(*;7-G<W1R(")0^&5D8VAO>NT@<W1RX6YK82(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(E!R
M;R!T96YT;R!B;&]K(&IE('9YOF%D;W;A;B!D871A8N%Z;W;]('ID<F]J+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")6>7-K>71L82!S92!Z
MX79AOF[A(&-H>6)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")0<F\@>F&Y:69R;W;A;NT@
M>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N(@IM<V=S='(@(E!R;R!V97)I9FEK86-I('!O9&5P<V%NZ2!Z
M<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM
M<V=S='(@(B(*(E!R;R!D9;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]U
MONUT('9E^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K;.WH(&$@(@HB
M:&5S;&\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q
M-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(E!R;R!P;V1E<'/A;NT@>G!RX79Y(&IE(&YU
M=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+"!P<FEVX71N[2!01U`@:VSM
MZ"!A("(*(FAE<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB4')O(&1EN6EF
M<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!3+TU)344@
M:VSMZ"P@<')I=N%T;NT@4R]-24U%("(*(FML[>@@82!H97-L;RXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(E!R;R!P;V1E<'/A;NT@>G!RX79Y(&IE(&YU=&YO('!O
M=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N[2!3+TU)344@(@HB
M:VSMZ"!A(&AE<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E!R;R!Z8;EI9G)O
M=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4R]-24U%(&ML
M[>@N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(EIA=&&^96YO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*
M(RP@9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B3V1P;VQE
M9&[M(&QE:&O](&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")286YN[2!D
MZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B4F%N;NT@</AE:.'R:WDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM
M<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E)A;F[M('-N[&AO=ND@
M</AE:.'R:WDB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*
M;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G
M<W1R("));F9O<FUA8V4@;R!T;VUT;R!E9&ET;W)U(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(DEN
M9F]R;6%C92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")497AT(&1O
M;/D@9&\@;V)RX7IK=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")497AT
M(&1O<')O<W3X960@;V)RX7IK=2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5GET=F_X96[M(%9&4R!A9')A<^'X92!N
M96)Y;&\@<&]V;VQE;F\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92XB"FUS9W-T<B`B5GET=F_X96[M(%9&4R!S;W5B;W)U(&YE8GEL;R!P;W9O
M;&5N;RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM
M<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")68;EE(&EN9F]R
M;6%C92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R(")5OFEV871E;'-KZ2!H97-L;R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(E6^:79A=&5L:_T@
M^NAE="!B>6P@>F%B;&]K;W;A;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(E6^:79A=&5L
M:^D@^NAT>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@
M(E9L;[XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N
M<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(E#X:61A
M="!P;V1S:W5P:6YU(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!
M9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")0^&ED870@<&]D+7!RX79A
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(
M97)E.B(*;7-G<W1R(")0^&ED870Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B
M"FUS9W-T<B`B4/AI9&%T(&YO=F]U('-K=7!I;G4B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")0
M^&ED870@;F]VX2!P<N%V82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D
M9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")0^&ED870@<&]D
M<VMU<&EN=2!D;R`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(E#X:61A="!P;V0M
M<'+A=F$@9&\@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!
M9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B4/AI9&%T(&YO=NEH;R!UOFEV871E
M;&4Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")0^&ED870@<VQO=7!E
M8R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G
M:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")0^&ED870@;F]VZ2#H;&5N
M>2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D
M9"!P86ER(@IM<V=S='(@(E#X:61A="!PX7(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")0^&ED870@)7,@
M;65N=2!J86MO(&)OZ&[M('-L;W5P96,@36]Z:6QL>2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O
M(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B4/AI9&%T(&1O(&%D<F5SX?AE.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM
M<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")0^&ED870@
M9&\@;>EH;R!A9')E<^'X92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED
M(")!9&0@=7-E<B(*;7-G<W1R(")0^&ED870@=;YI=F%T96QE(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S
M='(@(B(*(B<E<R<@8GEL;R!P^&EDX6YO(&1O('-Y<W3I;74L(&%L92!N96QZ
M92!P^&ED870@;N%S;&5D=6KM8^T@:6YF;W)M86-E.B`E<RXB"@HC.B!S:6=N
M=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G
M<W1R("(G)7,G(&)Y;&\@</AI9.%N;R!D;R!S>7-TZ6UU+B!-^;YE=&4@<V4@
M;GEN[2!P^&EH;.%S:70@9&\@<WES=.EM=2XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")0^&EDX7;A;NT@=;YI=F%T96SY(&IE('IA8FQO
M:V]VX6YO+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!
M9&1R97-S(@IM<V=S='(@(D%D<F5S82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E
M<^'X(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S(@IM<V=S='(@(B(*(E9Y:V]NX79A="!A9&UI;FES=')A8VD@
M+2!N87-T879E;NT@</CM<W1U<&]V_6-H('!RX78@<')O(&]S=&%T;NT@=;YI
M=F%T96QE(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%C92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#$*;7-G:60@(D%D<R(*;7-G<W1R("));GIE<N%T>2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9VCA;FES=.%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&+A;FEE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;+[M<G-K;R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*
M;7-G:60@(D%L:6%S(@IM<V=S='(@(E#X97ID[79K82]!;&EA<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*
M;7-G:60@(D%L:6=N(@IM<V=S='(@(EIA<F]V;F%T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM
M96YT.B(*;7-G<W1R("):87)O=F[A;NTZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B5KEE(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS
M9W-T<B`B5KEI8VAN:2!O=NSX96[M('6^:79A=&5LZ2(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B5KEE8VAN>2!S:W5P:6YY(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B5KEE8VAN82!UOFEV871E;'-KX2!P<N%V82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L
M;"!F;W5R('-I9&5S(@IM<V=S='(@(E:Y96-H;GD@Z'1Y^&D@<W1R86YY(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@
M;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E!O=F]L:70@=NUC92!A9')E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(E!O=F]L
M:70@;F%S=&%V96[M('1Y<'4@<V5T^.UD[&[]('-E>FYA;3\B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(DIIOB!E>&ES='5J92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO
M9VEN(@IM<V=S='(@(D%L=&5R;F%T:79N[2!)35-0('#X:6ALX;EE;NT@9&\@
M<WES=.EM=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(D%L=&5R;F%T:79N
M[2!)35-0(&AE<VQO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM
M<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N
M871I=F[M($E-4U`@=;YI=F%T96QS:^D@:FWI;F\B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`B06QT97)N871I=F[M(&4M;6%I;&]VX2!A9')E<V$B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E
M('1E;7!L871E<R(*;7-G<W1R(")!;'1E<FYA=&EV;NT@=GIO<GDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!;'1E<FYA
M=&EV;NT@=&5X=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO
M82(*;7-G<W1R(")!;65R:6-KX2!386UO82(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB
M"FUS9W-T<B`B0GEL82!Z863A;F$@;F5P;W9O;&5NX2!H;V1N;W1A+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G
M:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(FYA
M<W1A;&$@8VAY8F$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R(")!;F1O<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T
M<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T
M<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;GEM;NT@
M<')O>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I
M9"`B06YS=V5R(@IM<V=S='(@(D]D<&]V[.\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I:V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@
M82!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED
M(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI:V%C92(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G
M<W1R(")397IN86T@87!L:6MA8^TB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B
M07!L:6MA8V4@:F4@</AI<')A=F5N82(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`B4&]UONUT('!R;R!D[&1IZ&[I('-D[6QE;NTB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*
M;7-G<W1R(")38VAVX6QI="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R
M(")0^&EB;&F^;N$@=F5L:6MO<W0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B1'5B
M96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC
M("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)S:WD@*%=I;F1O=W,M,3(U
M-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C
M:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B5F5L:6MO<W0@87)C:&EV;W9A;NEH
M;R!S;W5B;W)U(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G
M:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")*;>EN;R!A<F-H:79U(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")5<NAI
M=.P@8VAC971E('9Y;6%Z870@ON%D;W-T(&\@</AI:&SAN65N[2!D;R`E<S\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R
M(")5<NAI=.P@<VD@</AE:F5T92!V>6UA>F%T("<E<R<@82!P;V1S:W5P:6YY
M/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E
M;G1I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R
M;>EN:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M
M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)MZ6YS:_T@*$%235-#24DM
M."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*
M;7-G<W1R(")5;>QN[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S
M='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM
M<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I;VX@27-L
M86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I
M:2!!<G0B"FUS9W-T<B`B07-C:6D@=6WL;NTB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB
M"FUS9W-T<B`B07-I92]R96=I;VX@5&EC:.EH;R!O8V7A;G4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS
M9W-T<B`B4&^^X61A="!O('!O='9R>F5N[2!P^&5D('!R;W9E9&5N[6T@;W!E
M<F%C[2#Z9'*^8GD_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(E-L;W5P8V4@
M<R#Z:V]L>2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")0
M;VMU<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[2!S:W5P:6YY+B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!O:W5S
M(&\@=GEM87KA;NT@;F5E>&ES='5J[6/M8V@@=;YI=F%T96QS:_UC:"!P<N%V
M+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M4&]K=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M8V@@=;YI=F%T96QS:_UC:"!P
M<N%V+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R
M(")0;VMU<R!O(/IP<F%V=2!N965X:7-T=6KM8^UH;R!S9.UL96[I:&\@;V)J
M96MT=2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T>2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS
M9W-T<B`B4W)P96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B075S='+A;&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*
M;7-G<W1R(")286MO=7-K;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!.
M96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!I;6%P+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B
M075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A
M<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!:9')O:B!N96WA('!O
MOF%D;W9A;ND@<V-H;W!N;W-T:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@
M3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:6UA<"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B(@HB075T:%]F='`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V
M86[A('#X[7!O;F$@<')O(&9T<"X@2V]M<&EL=6IT92!02%`@<R`M+2(*(F5N
M86)L92UF='`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T
M"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.96)Y;&$@;F%L97IE;F$@
M<&^^861O=F%NX2!P^.UP;VYA('!R;R!)34%0+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR
M8C4Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&MR
M8C4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G
M:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M
M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!.96)Y;&$@;F%L
M97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!,1$%0(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($YE
M;'IE('#X:61A="!UOFEV871E;&4@)7,N($ALX;EE;NT@<V5R=F5R=3H@(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.96QZ92!V>6UA>F%T('6^:79A=&5L
M92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L>F4@86MT=6%L:7IO
M=F%T('6^:79A=&5L92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@
M(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VUC86PZ($YE8GEL82!N86QE>F5N82!P;[YA9&]V
M86[A('#X[7!O;F$@<')O($U#04PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A
M=71H.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!S
M;6)A=71H+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM
M<V=S='(@(D]V[/AE;NT@<V5L:&%L;R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B3W;L
M^&5N[2!S96QH86QO+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D]V[/AE;NT@8GEL;R!Z86WM=&YU
M=&\@4D%$2553('-E<G9E<F5M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B4V5L:&%L;R!O=NSX96[M($944"!S979E<F5M
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B4V5L:&%L;R!O=NSX96[M($944"!S979E<F5M+B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L
M92!F:65L9',Z(@IM<V=S='(@(D1O<W1U<&[A('!O;&4Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%J9+[A;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(D)/1D@@=OUM;'5V>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U
M;F0B"FUS9W-T<B`B4&]Z863M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*
M;7-G<W1R(")"87)V82!P;WIA9.TB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM
M<V=S='(@(JEP871NZ2!H97-L;R!P<F\@:V5R8F5R;W,N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S
M('5S97)N86UE+B(*;7-G<W1R("*I<&%T;ND@=;YI=F%T96QS:^D@:FWI;F\@
M<')O(&ME<F)E<F]S+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS
M9W-T<B`B0F%H86UY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G
M<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I8VOI("A)
M4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM
M<V=S='(@(D)A;F=L863IN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S
M(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").96)Y;"!N
M86QE>F5N(&%D<F5SX?@@)R5S)R!S(&=R869I:V%M:2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@
M(D)A<V5L:6YE(@IM<V=S='(@(EKA:VQA9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)E;&%R=7,B"FUS9W-T<B`B0NQL;W)U<VMO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QI>F4B"FUS9W-T<B`B0F5L:7HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B0F5R;75D>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A
M;B(*;7-G<W1R(")":/ITX6XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(").
M87)O>F5N:6YY(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5L
M>F4@;F%LZ7IT(.CA<W0@7"(E<UPB(&%P;&EK86-E(%PB)7-<(BXB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E
M='1I;F=S(@IM<V=S='(@(DYA<W1A=F5N[2!B;&]K=2(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G
M<W1R(")4>7`@8FQO:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B5'7H;NPB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;.UV:64B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R
M:W,B"FUS9W-T<B`B6N%L;[YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G
M<W1R(")/:W)A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@
M(JGM^&MA(&]K<F%J93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@
M(D]K<F%J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$B"FUS9W-T<B`B0F]S;F$@82!(97)C96=O=FEN82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")/8F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D1O;&[M(.CA<W0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(D)O=79E
M="!)<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B
M0G)A>NUL:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71S:^$@=&5R:71O<FEA('8@
M26YD:6-KZ6T@;V-EX6[L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QH87)S:V\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED
M(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E-E>FYA;2!S(&]D<N&^:V%M:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K
M:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@
M(D)U<G5N9&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS
M9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@9&ES=')I
M8G7H;NT@8F]D>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")6;&%S=&YO<W1I(&)?=?)K>2XN+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*(RP@9G5Z>GD*;7-G:60@(D-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DYE8GEL('5V961E
M;B!D:7-T<FEB=>AN[2!S97IN86TN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(DMA;&5N9.'X(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R(")"97IV['3X
M[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB
M;V2^82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA
M;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB2&5S;&\@;F5L
M>F4@;F%S=&%V:70@875T;VUA=&EC:WDL('!R;W/M;2!K;VYT86MT=6IT92!6
M8;EE:&\@<WES=.EM;W;I:&\@(@HB861M:6YI<W1RX71O<F$N(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S
M='(@(DYE;'IE('9Y;6%Z870@<V]U8F]R(%PB)7-<(BXB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F5L>F4@<V4@</AI
M<&]J:70@:R!)34%0('-E<G9E<G4Z("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96QZ92!V>6UA>F%T
M('-O=6)O<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM
M<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U
M<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(E-T;W)N;R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B4W1O<FYO(&ALX;EE;NT@<')O8FSI;74B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96QZ92!V>6UA>F%T('-O
M=6)O<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5L>F4@;F%J[70@9&_H87-N_2!A9')E
M<^'X+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B3F5L>F4@<&]K<F'H;W9A="!B97H@
M<&%R86UE=')U("=T87)G971&:6QE)RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@
M861R97/A^"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").96QZ92!V>6UA>F%T+"!P<F]T
M;[YE(&5X:7-T=6KM('!O9'-K=7!I;GD@)60N(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B
M(@HB3F5L>F4@<')O=NES="!Z;>QN=2!U<W!O^.%DX6[M+"!P;^AE="!P;W-K
M>71N=73]8V@@<&]L;[YE:R!P<F\@;F]VZ2`B"B)U<W!O^.%DX6[M(&YE;V1P
M;W;M9.$@<&_H='4@=6QOOF5N_6-H('!O;&^^96LN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G
M<W1R(").96QZ92!Z87-L870@>G!RX79U(&YA('IA9&%NZ2#H[7-L;RX@(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")#87!E(%9E
M<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")4:71U;&MY(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T
M"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S
M='(@(DMA=&5G;W)I92!A('IN8>AK>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R(")+86IM86YS:^D@;W-T<F]V>2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G
M:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QN[2!T96QE9F]N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(DUOOFYO<W1I(&)U
M\FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B3V1S='5P(&UE
M>FD@8G7R:V%M:3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS
M9W-T<B`B5FQA<W1N;W-T:2!B=?)K>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z
M(@IM<V=S='(@(DUE>F5R>2!M97II(&)U\FMA;6DZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@
M(DUO8FEL;NT@=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT<VO]
M("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B
M4W3X960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`B4W3X961O869R:6-KX2!R97!U8FQI:V$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A
M;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B4W3X961O979R;W!S:_T@*$E33RTX
M.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B4&]D<F]B
M;F]S=&D@8V5R=&EF:6OA='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8Q,0HC+"!F=7IZ>0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N
M97(B"FUS9W-T<B`B4&]D<F]B;F]S=&D@8V5R=&EF:6OA='4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF
M:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]D;>UN:WD@8V5R=&EF:6OA='4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`BR&%D(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(EIM[&YI
M="(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ
M>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B5OUC:&]Z
M[2!N87-T879E;NT@5F&Y96AO(&AE<VQA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB3F%S=&%V96[M(&IMZ6YA
M(&$@96UA:6QO=ND@861R97-Y+B!4>71O('!O;&^^:WD@;&EDZ2!U=FED[2P@
M:V1YOB!S:2#H=&]U("(*(FYE8F\@;V1P;W;M9&%J[2!N82!68;EE('IP<N%V
M>2XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R("):;F%K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN
M+B(*;7-G<W1R(")::V]N=%]R;VQO=F%T(&]D:V%Z+BXN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EN82(*;7-G<W1R("+([6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M;7-G<W1R("+([6ZY=&EN82!Z:F5D;F]D=;EE;N$@*$=",C,Q,BDB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2DB"FUS9W-T<B`B5')A9&GH;NT@Z.UNN71I;F$@*$)I9S4I
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I
M9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B6G9O;'1E(&AE<VQO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B
M0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B6G9O;'1E('6^:79A=&5L<VOI
M(&IMZ6YO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B
M0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")6>6)R870@
M>F]B<F%Z96[M(&1A='5M=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B5GEB
M<F%T('1Y<"!S='EL=2!S97IN86UU("AP<F\@^&%Z96[I('-E>FYA;7DI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")6
MX6YOZ&[M(&]S=')O=B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z
M,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(DYE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD>2`E<RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B
M0VQE87(B"FUS9W-T<B`B5GGH:7-T:70B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC
M92!T86=S(@IM<V=S='(@(E9YZ&ES=&ET('IN8>AK>2!Z($U33V9F:6-E(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE
M87(@475E<GDB"FUS9W-T<B`B3V1S=')A;FET('6^:79A=&5L92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")/9'-T<F%N[&[M
M('6^:79A=&5L93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B3V1S=')A;FET
M('6^:79A=&5L92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B3V1S=')A;NQN
M[2#Z9&%J^2!O('6^:79A=&5L:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED(")#;&5A<FEN9R!,
M871E(@IM<V=S='(@(E!O>F1N[2!DZ;F[(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O
M;G1I;G5E(@IM<V=S='(@(DML:6MN['1E('!R;R!P;VMR8>AO=N%N[2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X
M-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T
M96QL('#X97,@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN
M9&]W(@IM<V=S='(@(EIA=OCM="!O:VYO(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("):871AOF5N;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U
M>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3V)L8>AN;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED
M(")#;&]U9'DB"FUS9W-T<B`B3V)L8>AN;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DMO:V]S;W;I(&]S
M=')O=GDB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS
M9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E-K;&%P;F]U="!B;^AN
M[2!L:;ET=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S
M='(@(E-K;&%P;F]U="!O:W)A:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO
M;6)I82(*;7-G<W1R(")+;VQU;6)I92(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO
M<B(*;7-G<W1R(")"87)V82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")6_6+L<B!B87)E
M=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O
M;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4&%L971A(&)A<F5V(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@
M(D-O;',Z(@IM<V=S='(@(E-L;W5P8V4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(").
MX7IV>2!S;&]U<&-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V
M-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(DMO;6EK<WDB"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B4/CM:V%Z
M(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H
M96QL(@IM<V=S='(@(E#X[6MA>F]VX2!K;VYZ;VQA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S
M='(@(E!O>F[A;6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(D]B96-NZ2!J
M;>EN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO
M;6]R;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D9I<FUA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B4&_H[71AZ&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B4&]D;>UN
M:WDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET
M:6]N<R(*;7-G<W1R(")0;V1M[6YK>2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(E)O>F3M;'D@=B!N87-T879E;NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I
M=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@
M(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(DIE('3X
M96)A(&%K='5A;&EZ;W9A="!N87-T879E;NTN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@
M)7,B"FUS9W-T<B`B3F%S=&%V:70@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM
M<V=S='(@(E!O='9R9&ET(&AE<VQO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N
M9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(DMO;F=O
M+"!$96UO:W)A=&EC:^$@<F5P=6)L:6MA(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(E-P;VIE;NT@<V5L:&%L;RXB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@(@IM<V=S='(@(E-P;VIE;NT@<V5L:&%L;SH@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(D)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[];2!K;.WH;W;];2!S
M97)V97)E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T
M<B`B0GEL;R!Z86WM=&YU=&\@<W!O:F5N[2!S('9E^&5J;OUM(&ML[>AO=OUM
M('-E<G9E<F5M+B!$^79O9"`Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B4V5L:&%L;R!S<&]J96[M(',@1E10('-E
M<G9E<F5M+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED
M(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M(")+;VYT86MT>2!B>6QY(/IS<.RY;NP@</AI9.%N>2!D;R!68;EE:&\@861R
M97/A^&4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R(")/8G-A:"!V("<E<R<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@
M(D-O;G1I;G5E(@IM<V=S='(@(E!O:W)AZ&]V870B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:V]V>2!O<W1R;W9Y(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS
M9W-T<B`B2V]LX>AE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")+
M;W#M<F]V870B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM
M<V=S='(@(E-P;VIE;NT@<V5L:&%L;SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I
M;VXB"FUS9W-T<B`B2V]P[7)O=F%T(';]8NQR(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")+
M;W-T87)I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM
M<V=S='(@(E!O8OAEONT@<VQO;F]V:6YY(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B6G!RX79U(&YE;'IE(+EI9G)O=F%T('!O
M;6]C[2!01U`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(EIP<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@4$=0+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B6G!RX79U
M(&YE;'IE(+EI9G)O=F%T('!O;6]C[2!3+TU)344N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("):<'+A=G4@;F5L>F4@<&]D
M97!S870@<&]M;V/M(%,O34E-12XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE;'IE('#X
M:61A="!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0IM
M<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(DYE;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE;'IE('-E('#X:7!O
M:FET(&L@3$1!4"!S97)V97)U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B3F5L
M>F4@>FMO;G1R;VQO=F%T(/KH970N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:R!3
M34(@<V5R=F5R=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O
M('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(").96QZ92!S
M92!P^&EP;VII="!K('-E<G9E<G4@)R5S)R!P;VUO8^T@1E10.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;'IE('9Y='9O^&ET(&1I<W1R
M:6)UZ&[M('-E>FYA;2X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M82XB"FUS9W-T<B`B3F5L>F4@9&6Y:69R;W9A="!01U`@9&%T82XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DYE;'IE(&1E
MN6EF<F]V870@4R]-24U%(&1A=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").96QZ
M92!S;6%Z870@:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R(").96QZ92!S;6%Z870@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@<VUA>F%T(&YA<W1A=F]V86/M
M('-K<FEP="!P<F\@86MT=6%L:7IA8VD@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").96QZ92!Z
M:FES=&ET(&4M;6%I;&]V;W4@861R97-U('#X[6IE;6-E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(").96QZ92!Z[7-K870@^G!L;OT@861R97/A^"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R(").96QZ92!Z[7-K870@^G!L;OT@9&ES=')I8G7H;NT@<V5Z;F%M
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI
M<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(").96QZ92!Z[7-K
M870@^G!L;OT@<V5Z;F%M(&1I<W1R:6)UZ&[M8V@@<V5Z;F%M^2XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N
M(@IM<V=S='(@(E-T<F%T96=I92`G)7,G(&IE(&YE9&]S='5P;N$N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<
M(B5S7"(N(@IM<V=S='(@(DYE;'IE('IA;&^^:70@)R5S)RXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S
M='(@(DYE;'IE('KM<VMA="!V9?AE:F[](&ML[>@@>B!K;.WH;W;I:&\@<V5R
M=F5R=2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DYE;'IE(&]T97;X[70@)R5S)R!K('KA<&ES=2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM
M<V=S='(@(DYE;'IE(&]T97;X[70@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B
M"FUS9W-T<B`B3F5L>F4@<')O=NES="!O<&5R86-E(/ID<KYB>2!P<F\@;6]D
M=6P@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(DYE;'IE(&]T97;X[70@861R97/A^"`G)7,G+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@:&QE9&%T('8@
M3$1!4"!S97)V97)U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP
M:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S
M+B(*;7-G<W1R(").96QZ92#H[7-T("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE
M('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL
M(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*
M(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3F5L>F4@<F5S971O=F%T(&AE
M<VQO('!R;R!D86[I:&\@=;YI=F%T96QE+B!6N65C:&YY(&YE8F\@;NQK=&5R
MZ2!Z("(*(G!O9')O8FYO<W3M(&YE8GEL>2!S<'+A=F[L('IA9.%N>2X@6FMU
M<W1E('1O('IN;W9U(&YE8F\@<&]K=60@<&]T^&5B=6IE=&4@(@HB<&]M;V,L
M(&MO;G1A:W1U:G1E('-P<N%V8V4@<WES=.EM=2XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(@IM<V=S='(@(DYE;'IE('KM<VMA="!!0TPB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R(").96QZ92!Z[7-K870@861R97/A^"X@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;'IE('KM<VMA="!D:7-T<FEB
M=>AN[2!S97IN86TN("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T
M<B`B3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;7DN("5S(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`B3F5L>F4@>NUS:V%T('-C:&]P;F]S=&D@<V5R=F5R=2(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F5L>F4@</AE<&YO=70@:V]N9FEG
M=7)A8VDN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R
M(").96QZ92!O9'-T<F%N="`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE;'IE('5L;[YI="!K;VYF
M:6=U<F%C:2!P<F\@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYE;'IE('5L
M;[YI="!ZX6QOOF[M(&MO;F9I9W5R86-I+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(").
M96QZ92!U;&^^:70@>N%L;[YN[2!K;VYF:6=U<F%C:2`E<RXB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@=6QOOFET(&YA<W1A=F]V86/M('-C
M<FEP="!P<F\@86MT=6%L:7IA8VD@9&\Z("<E<R<N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`B3F5L>F4@=6QOOFET('KA;&]H=2!K;VYF:6=U<F'H;NUH;R!S;W5B
M;W)U("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@
M;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S
M='(@(B(*(DYE;'IE('IA<'-A="X@3?F^971E('!O=;[M="!S:W)I<'0@<')O
M(&%K='5A;&EZ86-I(&YE8F\@<G7H;NP@>FMO<.UR;W9A="`B"B)N[;YE('5V
M961E;OT@:_-D(&1O("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3F5L>F4@:&QE9&%T('8@3$1!4"!S97)V97)U+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYE;'IE
M(&]D<&]J:70@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE;'IE(&%K='5A
M;&EZ;W9A="!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(DYE;'IE(&%K='5A;&EZ;W9A="!D:7-T<FEB=>AN[2!S97IN86TN("5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@7"(E<UPB.B`E<R(*;7-G<W1R(").96QZ92!U;&^^:70@:V]N9FEG=7)A
M8VD@<')O("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V
M-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@HB3F5L
M>F4@;F%LZ7IT(&)OZ&[M(&QIN71U('!R;R!-;WII;&QU+B!0<F]S[6T@</AE
M<W;L9.AT92!S92P@OF4@:F4@;W1E=OAE;N$N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F
M;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B5;YI=F%T96QI("<E<R<@;F5L>F4@<&]S:WET;F]U="!NX7-L961U
M:NUC[2!P<N%V82!P<F\@<VQOOFMU("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S
M='(@(D]D<&_H[71A;OT@=&5X="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(EIE;>PB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R
M<V5S(@IM<V=S='(@(E9Y=>AO=F%C[2!P^&5D;>QT>2(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(E9Y='9O^&ET(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED
M(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(E9Y='9O^&ET(&]D:V%Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B
M0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")6>71V;_AI="!N;W9O=2(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED
M(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B5GET=F_X:70@<&]D<VQO
MOFMY(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G
M:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5';Y<F-E('!RX78B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D
M:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BR.US;&\@:W)E9&ET;NT@:V%R='DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")#:&]R=F%T
M<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(D%K='7A;&[M(&;A>F4B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S
M<VEO;G,B"FUS9W-T<B`B5';Y<F-E('!RX78B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@
M5&EM92(*;7-G<W1R(")!:W1UX6QN[2#H87,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U
M<G)E;G0@55),(&ES(@IM<V=S='(@(D%K='7A;&[M(%523"!J92(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5
M<V5R<R(*;7-G<W1R(")!:W1UX6QN[2!FX7IE(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D%K
M='7A;&[M('!OZ&%S[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B06MT
M=>%L;NT@<&]D;>UN:WDZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T
M<B`B3GEN[&JY[2!S='EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(DYA<W1A=F5N[2#Z:V]L^2!P
M<F]VX63L;OUC:"!P^&D@</AI:&SAN65N[2!D;R`E<RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G
M:60@(D-U="(*;7-G<W1R(")6>7-T^&EH;F]U="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE
M8W1I;VXB"FUS9W-T<B`B5GES=/AI:&YO=70@=OUB['(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B2WEP<B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R
M(")!>F)U:V$@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B07IB
M=6MA("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R
M(")!>F)U:V$O56MR86II;F$@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("+(97-KX2!R97!U8FQI:V$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B
M1&%I;'DB"FUS9W-T<B`B1&5N;NPB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@
M<')O:&SMOF7H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM
M<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R(")$871U;2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(E#X:6IA=&\@9&YE(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I
M;VXB"FUS9W-T<B`B5OUB['(@9&%T=6UU(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S(R"FUS9VED(")$87DB"FUS9W-T<B`B1&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R(")3;6%?>F%T('-L;W5P96,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`B4')O<VEN96,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$
M96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`BR.US;&$@9&5S[71K;W;I('-O=7-T
M879Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(EIM96ZY:70@
M;V1S87IE;NTB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X
M-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R("))
M;7!L:6-I=&[M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B26UP
M;&EC:71N[2!B87)V82(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B26UP
M;&EC:71N[2!I9&5N=&ET82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("));7!L
M:6-I=&[M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$
M969I;FET:6]N<R(*;7-G<W1R(")$969I;FEC92(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G
M<W1R(")3;6%Z870B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#
M96QL(@IM<V=S='(@(E-M87IA="!B=?)K=2(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O
M=7`B"FUS9W-T<B`B4VUA>F%T('-K=7!I;G4B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B
M"FUS9W-T<B`B4VUA>F%T(/CA9&5K(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4VUA>F%T('!R
MX79A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B
M4VUA>F%T(&$@=GGH:7-T:70@>G!RX79Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E
M(&-E;&PB"FUS9W-T<B`B4VUA>F%T(&)U\FMU(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L
M971E(&-O;'5M;B(*;7-G<W1R(")3;6%Z870@<VQO=7!E8R(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(E-M87IA="!E>&ES='5J[6/M(&%L
M=&5R;F%T:79N[2!V>F]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E-M87IA="!P<N%V82!P
M<F\@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T
M<B`B4VUA>F%T('!RX79A(&$@<&]D<'+A=F$@<')O("<E<R<_(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3;6%Z870@^.%D96LB"@HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4VUA>F%T('9Y8G)A
M;F]U*.DI(&ED96YT:71U*'DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E-M87IA="!S;W7H87-N_2!S;&]U
M<&5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(E-M87IA="!S;W7H87-N_2#XX61E:R(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M2V]N9FEG=7)AZ&[M('-C<FEP="!P<F\@86MT=6%L:7IA8VD@)R5S)R!B>6P@
M<VUA>N%N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`BR&%S(&1O<G7H96[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N
M;6%R:R(*;7-G<W1R(")$X6YS:V\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS
M9W-T<B`B4&]P<V%T('!R;V)LZ6TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&]P:7,B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")0;V1R
M;V)N;W-T:2`H=&%KZ2!V(&QO9R!S;W5B;W)U($AO<F1E*3HB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!D;R!L;V<@<V]U8F]R=2!P
M<F\@861M:6YI<W1RX71O<F$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B5OUV;VHB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM
M<V=S='(@(E)O<V[](&)O9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT
M"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E)O
M<V[](&)O9"!Z82!P;W-L961N[2!H;V1I;G4Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(E)O<V[](&)O9#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0B"FUS9W-T<B`B4VWL<B!Z(&QE=F$@9&]P<F%V82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C
M=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(E-M['(@>B!P<F%V82!D;VQE
M=F$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T
M;W)Y(@IM<V=S='(@(D%D<F5SX?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@
M(EIO8G)A>FET(#(T+6AO9&EN;W;](.AA<S\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")-
M;[YN;W-T:2!Z;V)R87IE;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R
M96-A<W0B"FUS9W-T<B`B6F]B<F%Z:70@</AE9'!O=NSO("A4048I(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("):;V)R87II="!P^&5D<&]V[.\@*%1!1BDB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$:7-P;&%Y
M(&9O<FUA="(*;7-G<W1R(")&;W)MX70@>F]B<F%Z96[M(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N(@IM<V=S='(@(D1I<W!O>FGH;NT@=7!O>F]R;NQN[2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)O=71I
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F5S;6%Z870B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DYE</AI<W1U<&]V870@
M</CM;6\@9&\@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*
M;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@HB3V)S
M86AU:F4@<')V;NT@^.%D96L@;N%Z978@<VQO=7!C^3\@4&]K=60@86YO+"!Z
M8;EK<G1N['1E('1E;G1O('+A;67H96LZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI:V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:^%N<VOA(')E
M<'5B;&EK82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G
M:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS
M9VED(")$;W=N;&]A9"(*;7-G<W1R(")3=&&^96[M(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E-T8;YE;NT@)7,B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")3=&%H
M;F]U="!G96YE<F]V86YO=2!K;VYF:6=U<F%C:2!J86MO(%!(4"!S:W)I<'0N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O
M<"!D;W=N(&QI<W0B"FUS9W-T<B`B4F]L971O=OT@<V5Z;F%M(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$
M<F]G>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B12U-86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5C=6%D;W(B"FUS9W-T<B`B16MVX61O<B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET(@IM<V=S='(@(E5P<F%V:70B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*
M;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B57!R879I="!B;&]K(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G
M:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B57!R879I="!S:W5P:6YU(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM
M<V=S='(@(E5P<F%V:70@<'+A=F$B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E5P
M<F%V:70@<'+A=F$B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(E5P<F%V:70@<'+A=F$@<')O("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS
M9W-T<B`B57!R879I="!M;[YN;W-T:2!P<F\Z(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")5<')A
M=FET('!RX79A('!R;R`E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B57!R879I="!P<N%V82!P<F\@)7,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M(")6_75K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G
M>7!T(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@
M=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A
M;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(E!R
M=F5K+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R(")%;6%I;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")%;6%I;&]VX2!A9')E<V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`B16UA:6QO=ND@861R97-Y('-E(&UU<^T@<VAO9&]V870N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B16UA:6P@<R!P;W1V<GIE
M;NUM(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*
M;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")):V]N:WD@<R!E;6]C96UI(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")0<N%Z9&[A('IP
M<N%V82XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E!RX7ID
M;OT@=OUS;&5D96LN(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E!R
MX7ID;OT@=&5R;>UN('!R;R!V>6AL963A=N%N[2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(E!O
M=F]L:70@=FMLX63A;NT@;V)R87IK^2!Z(&9O=&\@9V%L97)I[2!D;R!T97AT
M=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")!:W1I=F]V
M870@<')A=ND@:VQI:VYU=.T@<')O(&MO;G1E>'1O=ND@;65N=3\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(DMO;F5C(')O
M:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("):=NQTN6ET(&5D
M:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*
M(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@
M87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R
M("(B"B):861E:G1E(&)E>G!EZ&YO<W1N[2!O=.%Z:W4L(&YA(&MT97)O=2!B
M=61E=&4@;75S970@;V1P;W;L9.QT('!O:W5D('-I("(*(F)U9&5T92!C:'3M
M="!R97-E=&]V870@<W;I(&AE<VQO+"!N87#X+B`G2F%KZ2!J92!J;>EN;R!6
M8;EE:&\@<'-A/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4B"FUS9W-T<B`B6F1E('9L;[YI="!54DP@;V)RX7IK=2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*
M;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")2
M;W9N[6MO=N$@1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*
M;7-G<W1R(")%<FET<F5A(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B0VAY
M8F$B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D97/M;.%N[2!O
M9'!O=NQD:3H@)7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A
M;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P
M^&D@;V1E<^ULX6[M(&]D<&]V[&1I.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(").87-T
M86QA(&-H>6)A('#X:2!O9&5S[6SA;NT@;V1P;W;L9&DZ("5S+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S
M='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D97/M;.%N[2!O9'!O=NQD:3H@)7,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S
M='(@(DYA<W1A;&$@8VAY8F$@<R!P;[ET;W9N[2!Z<'+A=F]U+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")#:'EB82!P^&D@>N%P
M:7-U("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R
M(")%<W1O;G-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S
M='(@(D5T:6]P:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G
M:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI8VOI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B179R
M;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E
M<GD@,34@;6EN=71E<R(*;7-G<W1R(")+8;YD_6-H(#$U(&UI;G5T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B179E<GD@,B!M:6YU
M=&5S(@IM<V=S='(@(DMAOF3I(#(@;6EN=71Y(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DMAOF3]8V@@,S`@<V5K=6YD
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B
M2V&^9/UC:"`U(&UI;G5T(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
M2V&^9.D@</AI:&SAN65N[2!D;R!S>7-TZ6UU(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@
M(DMAOF1O=2!P^6P@:&]D:6YU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M
M:6YU=&4B"FUS9W-T<B`B2V&^9&]U(&UI;G5T=2(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS
M9W-T<B`B5GIO<F]V_2!P^.UK;&%D(&AO9&YO=#HB"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B4')O=NES="(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I
M9"`B17AP86YD(@IM<V=S='(@(E)O>G9I;F]U="(*"B,Z('1E;7!L871E<R]P
M;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM
M<V=S='(@(E)O>F)A;&ET(&)OZ&[M(&QIN71U(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM
M<V=S='(@(D_H96OA=N%N82`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(D_H96OA=N%N;R!S86UO<W1A
M=&[I('-L;W9O(&YE8F\@:&QE9&%N_2!T97)M[6X@=B!U=F]Z;W9KX6-H(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T=6T@<')O(&MO;F5C('!L871N
M;W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V
M"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G
M:60@(D9'($-O;&]R(@IM<V=S='(@(D)A<G9A('!O</AE9.TB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E
M='5P(@IM<V=S='(@(E#X96YO<R!K;VYF:6=U<F%C92!P;VUO8^T@1E10(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B4V5L:&%L
M;R!Z[7-KX6[M(&UOOFYO<W3M+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E<G9E<G4N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(").96QZ92!S92!P
M^&EP;VII="!K(%--0B!S97)V97)U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")396QH86QO(&MO<.UR;W;A;NT@
M>B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R(")396QH86QO(&MO<.UR;W;A;NT@9&\@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B4V5L
M:&%L;R!Z86QOOF5N[2!N;W;I:&\@4T%33"!S<&]J96[M+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB"FUS9W-T<B`B4V5L:&%L;R!P^&5S=6YU=.T@9&\@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S
M(@IM<V=S='(@(E-E;&AA;&\@</AE<W5N=73M(&1O(%PB)7-<(BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B
M1F%I<B(*;7-G<W1R(")$;V)RZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9'-KZ2!O
M<W1R;W9Y("A-86QV:6YY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B1F%R:6IS:^D@;W-T<F]V>2(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R
M("):X79AOF[A(&-H>6)A.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED
M(")&87AE<R(*;7-G<W1R(")&87@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B
MVFYO<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(D/M=&ET('-E(&IA:V\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS
M9W-T<B`B0^UT:70@<V4@:F%K;SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T
M<B`B1')O8F[I('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B1')O8F[I('-N[&AO=ND@</AE:.'R:WDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T
M<B`B36%T:6-E('!O;&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I
M:FDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z
M>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B<V]U8F]R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL92(*;7-G<W1R(")0;^AE="!S;W5B;W+Y.B`E<R!S;W5B
M;W(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")0;^AE
M="!S;W5B;W+Y.B`E<R!S;W5B;W+Y(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(E-P<N%V
M8V4@<V]U8F]R^2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS
M9VED(")&:6QE($YA;64B"FUS9W-T<B`B3N%Z978@<V]U8F]R=2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T
M:6]N(@IM<V=S='(@(E;]8NQR('-O=6)O<G4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")0
M^&5NZ7-T('-O=6)O<B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(E#X96YO<R!S;W5B;W+Y(&YE;NT@<&]D<&]R;W;A;BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B1FEL=')Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R(")&:6YS:V\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED
M(")&:7)S="!(86QF(@IM<V=S='(@(E!R=F[M('!O;&]V:6YA(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I
M9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")0<G9N[2#H='9R=&EN82(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G
M:60@(D9I>"!R871I;R(*;7-G<W1R(")0979NZ2!M[/CM=&MO(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B
M1FQI<"(*;7-G<W1R(")0^&5H;V1I="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(E!L;W9O=6/M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")-;&AA(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B4VQOOFMA("5S(&YE97AI<W1U
M:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D)A<G9A('#M<VUA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S
M='(@(DKM9&QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")0<F\@<')O:&SMOF7H
M92!N97!O9'!O<G5J[6/M(&]B<N%Z:WDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4/AE9'!O
M=NSO("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y
M"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*
M(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI(@IM<V=S='(@(B(*(E#X961P;W;L[R!P;^AA<^T@<')O(&1N>2`H<&]Z
M;N%M:V$Z('#X961P;W;L[R!J92!P<F\@9&YY(&D@;F]C:3L@=&]T;R!M^;YE
M("(*(G9Y='9O^&ET('!O;>QR;NP@;V)SX6AL_2!S97IN86TN(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R
M('!A<W-W;W)D/R(*;7-G<W1R("):87!O;6[L;&D@:G-T92!68;EE(&AE<VQO
M/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O
M<FUS(@IM<V=S='(@(D9O<FUU;.'X92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("*I=.QS=.TB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*
M;7-G<W1R(")4>7`@N73L<W3M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("*I=.QS=.TB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T
M<B`BJ73L<W3M(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S
M"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1O-R82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E#X
M97!O<VSA;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")0X2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@
M(D9R86UE<R(*;7-G<W1R(")2X6UY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E(@IM<V=S='(@(D9R86YC:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S
M='(@(D9R86YC:64L(&UE=')O<&]L:71N[2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;F-O=7-KX2!'=6%IX6YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
M1G)A;F-O=7-KX2!0;VQY;NES:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N8V]U<VOA
M(&IIOF[M('1E<FET;W)I82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B3V0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D]D(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&]D<F]B;OT@<&]P:7,B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I
M9"`B1G5L;"!-;V]N(@IM<V=S='(@(MIP;&[L:R(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B0V5LZ2!J;>EN;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R
M(")'86QE<FEE('!R;R!V_6+L<B!O8G+A>FOY(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEE.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=A;6)I82(*;7-G<W1R(")'86UB:64B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S
M($-O;F9I9W5R871I;VXB"FUS9W-T<B`B5GET=F_X:70@)7,@:V]N9FEG=7)A
M8VDB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM
M<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B5GEG96YE<F]V86[](&OS
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1W)U>NUN
M<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(").[&UE
M8VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L
M=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*
M;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B2_AE<W1N[2!J;>EN;R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R
M(")*9&D@;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@
M(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B1V]O
M9VQE($UA<',B"FUS9W-T<B`B5GEH;&5DX7;A;NT@<&]M;V/M($=O;V=L=2(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!3
M96%R8V@B"FUS9W-T<B`B5GEH;&5DX7;A;NT@<&]M;V/M($=O;V=L=2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G
M:60@(D=R87ES8V%L92(*;7-G<W1R(")3='5P;NP@N65D:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`BV&5C:V\B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM
M<V=S='(@(MAE8VOI("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=R965N;&%N9"(*;7-G<W1R(")'<O-N<VMO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F%C92!P<F\@<VMU<&EN>2(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B375S[2!B_70@>F%DX6YO(&IMZ6YO('-K=7!I;GDB"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B
M075T:%]L9&%P.B!.96QZ92!P^&ED870@=;YI=F%T96QE("5S+B!(;.&Y96[M
M('-E<G9E<G4Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L>F4@86MT=6%L:7IO
M=F%T('6^:79A=&5L92`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YE
M;'IE(&%K='5A;&EZ;W9A="!UOFEV871E;&4@)7,B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O
M=7!S(@IM<V=S='(@(E-K=7!I;GDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D
M96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R
M;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(E!RX79A(&AO<W3Y(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DMN
M:6AA(&AO<W3Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@
M(D=U:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*
M;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@>F)A8NQL92!O
M9&WM=.$@<VUA>F%T('!O<VQE9&[M(&)U\FMU(&YA(/CA9&MU+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@>F)A
M8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(&)U\FMU('9E('-L;W5P8VD@
M=&%B=6QK>2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@
M(DA434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N[2#XX61E
M:R!V('1A8G5L8V4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")/=NSX;W;A;NT@<&]M;V/M($A45%`@;F5B>6QO(&YA;&5Z96YO
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M86QG;W)I=&UU<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")(87IE(@IM<V=S='(@(DUL:&%V;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B2&QA=FGH:V$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(
M96%D97)S(@IM<V=S='(@(DAL879IZ&MA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B
M2&5A<F0@27-L86YD(&$@36-$;VYA;&0@27-L86YD<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED
M(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(D)O=?AK82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB
M"FUS9W-T<B`B2&5B<F5JN71I;F$@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS
M9VED(")(96EG:'0B"FUS9W-T<B`B5OVY:V$B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](
M96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M
M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B
M3N%P;W;L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(").
MX7!O=NQD82!P<F\@961I=&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(E!O;6]C;NUK(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S
M='(@(DAE;6ES9NER82(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E
M(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(EID92!J
M92!Z8>CA=&5K('-O=6)O<G4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B5GES;VOA
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A
M9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R
M(")?2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")3=F%TZ2!-['-T;R`H5F%T:6OA
M;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@
M(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G
M<W1R(")!9')E<V$@9&]M^2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B061R
M97/A^"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L969O;B!D;VWY
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD
M=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@
M(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM
M<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.97!L871NZ2`E<R!834P@
M9&%T82!V92!Z<'+A=NP@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(*[A9&[A('IP<N%V82!S92!N97-H;V1U:F4@<R!O8FIE:W1E
M;2`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!.96)Y;"!N86QE>F5N(+[A9&[](&]B:F5K="!T>7!U("5S('9E('IP<N%V
M["`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#:<W#LN6[I
M(&]D<W1R86[L;NT@)7,@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E9W)AZ&[M(&[A<W1R;VH@<&]T
M^&5B=6IE(%!(4"!P^.UP;VYU("=D;VUX;6PG(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;'IE('9Y='9O^&ET(&YO
M=OT@<W1R;VT@6$U,('!R;R!O8FIE:W0@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@3F5L>F4@;V1S=')A;FET("5S(%PB)7-<(CH@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z($YE;'IE('KM<VMA="!-24U%($E$('!R;R#HX7-T('1Y<'4@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.96QZ92!S
M>6YC:')O;FEZ;W9A="`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@3F5L>F4@<WEN8VAR;VYI>F]V870@<V3M;&5N
MZ2!O8FIE:W1Y.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5Z;N%M_2!S
M9.UL96[](&]B:F5K="!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B
M"FUS9W-T<B`B5F]D;W)O=F[I('!R87;M=&MO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A
M;"!P861D:6YG(@IM<V=S='(@(DAO<FEZ;VYTX6QN[2!O9'-T=7`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED
M(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N=.%L;NTZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R(")*86L@:G-T92!S92!S96T@9&]S=&%L:3\@*%IAN6QE=&4@
M<')O<^UM('IP<N%V=2$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2V]L:6L@<VQO
M=7!C^2!C:&-E=&4@<W!O:FET/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R
M92!T:&5R93\B"FUS9W-T<B`B2V]L:6L@:F4@=&%M('!O;.T@*'-L;W5P8_DI
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(DMO;&EK(/CA9&OY(&-H8V5T92!S<&]J:70_
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B5FQH
M:V]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G
M:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B5FQH:V]S=#HB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(
M=6UO<F[I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@
M(DUA[V%R<VMO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B4V5L:&%L;R!V>71V;_AE;NT@24U!4&]VZ2!S8VARX6YK
M>3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R(")396QH86QO('-M87KA;NT@24U!4&]VZ2!S8VARX6YK>3H@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R(")396QH86QO(&YA<W1A=F5N[2!K=O-T>2!P<F\@24U!4&]V;W4@
M<V-H<N%N:W4Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q
M-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!A9')E<V$B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!
M9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0(&%D<F5S82!N96[M
M(&1O<W1U<&[A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP
M:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN(@IM<V=S='(@(DE0(&%D<F5S82!N96[M('8@<&]V;VQE;NEM
M($-)1%(@<F]Z<V%H=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA
M=&EO;BXB"FUS9W-T<B`B4&]R=;EE;NT@:6YT96=R:71Y($E0+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(E9?;&^^=&4@
M^.%D96L@</AE9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G
M<W1R("))<VQA;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS
M9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E!O=7IE(&EK;VYY(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC
M;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N>2!P<F\@)7,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS
M9W-T<B`B26MO;GD@<R!T97AT96TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(D[A>F5V
M(&ED96YT:71Y.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES
M<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD
M;W<N(@IM<V=S='(@(E!O:W5D('IO8G)A>F5N[2!N96[M('8@<&_XX61K=2P@
M)7,@;W1E=OCM="!V(&YO=NEM(&]K;NPN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+B(*;7-G<W1R("(B"B)0;VMU9"!P;W6^[7;A=&4@26YT97)N970@17AP;&]R
M97(@82!N979I9.UT92"^X61NZ2!I:V]N>2P@>OAE:FWL('!O=/AE8G5J971E
M("(*(F]Z;F'H:70@=&5N=&\@<N%M9>AE:R!P<F\@=GEP;G5T[2!03D<@=')A
M;G-P87)E;F-E+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R
M("(B"B)0;VMU9"!V:63M=&4@='5T;R!Z<'+A=G4@;>US=&\@;V)RX7IK=2P@
M;V)RX7IE:R!K=&5R_2!C:&-E=&4@</AE;NES="!N96QZ92`B"B)68;GM;2!P
M<F]H;.V^9>AE;2!Z;V)R87II="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E
M(%!R979I97<Z(@IM<V=S='(@(D[A:&QE9"!O8G+A>FMU.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G
M:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@;V)RX7IK=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@;V)RX7IK=3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")/
M8G+A>F5K('H@9V%L97)I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y.B(*;7-G<W1R(")/8G+A>F5K('H@9V%L97)I93HB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO
M860B"FUS9W-T<B`B4/AE;F]S(&]B<N%Z:W4B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D]B<N%Z:WDB"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU
M-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G0L(&MR;VL@
M)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B26UP
M;W)T;W9A;ND@<&]L93H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R
M=&]V86[A('!O;&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E
M<B(*;7-G<W1R(")6;&^^:70@^.%D:W4@>F$B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0GEL('IA9.%N(&YE<W!RX79N
M_2!A:^AN[2!K\V0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE<W!RX79N["!Z861A;ND@=;YI
M=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*(DYE<W!RX79NZ2!UOFEV871E;'-KZ2!J;>EN;R!N
M96)O(&%L=&5R;F%T:79N[2!A9')E<V$N(%IK=7-T92!J9;ET["!J961N;W4@
M(@HB;F5B;R!K;VYT86MT=6IT92!68;EE:&\@<WES=.EM;W;I:&\@861M:6YI
M<W1RX71O<F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(EIV
M['2Y:70@;V1S87IE;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM
M<V=S='(@(DEN9&EE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN
M9&EV:61U86P@57-E<G,B"FUS9W-T<B`B2F5D;F]T;&EV[2!UOFEV871E;.DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O
M;NES:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R;6%C92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*;7-G:60@(DEN9F]R;6%T:6]N
M(@IM<V=S='(@(DEN9F]R;6%C92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO
M;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(J[A9&[I('H@;6^^;F]S=.T@;F5J
M<V]U(&1O<W1U<&[I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@
M069T97(B"FUS9W-T<B`B5FQOOFET('-?;&]U<&5C('IA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P
M"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B5FQOOFET(&]B<N%Z96LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P
M"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B5FQOOFET('1A8G5L:W4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U
M"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B5FQOOFET('=E8F]V
M_2!O9&MA>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E
M(@IM<V=S='(@(E9L;[YI="!?<VQO=7!E8R!P^&5D("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B5FQOOFET(&YO=OT@<VQO=7!E8R!Z82!S;W7H87-N_2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YI="!N;W;]('-L;W5P96,@</AE9"!S
M;W7H87-N_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFET(&YO=OT@^.%D96L@
M>F$@<V]UZ&%S;OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")6;&^^:70@;F]V_2#X
MX61E:R!P^&5D('-O=>AA<V[](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P
M87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")6;&^^
M:70@;V1S=&%V96,@>F$@<V]UZ&%S;OT@=7IE;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM
M<V=S='(@(E9L;[YI="!O9'-T879E8R!P^&5D('-O=>AA<V[]('5Z96PB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R(")6;&^^:70@86QT97)N871I=F[M('9Z
M;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E
M<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@
M=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B5FQOOG1E(&5M86EL;W9O=2!A
M9')E<W4L(&YA(&MT97)O=2!O8F1RONUT92!N;W;I(&AE<VQO.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*
M;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(E9L;[YI="!B=?)K
M=2!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R
M(")6;&^^:70@8G7R:W4@</AE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`B5FQOOFET('-L;W5P96,@>F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")6;&^^:70@<VQO
M=7!E8R!P^&5D(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R(")6;&^^
M:70@>G!RX79Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F
M=&5R(@IM<V=S='(@(E9L;[YI="!O9'-T879E8R!Z82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B5FQOOFET(&]D
M<W1A=F5C('#X960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM
M<V=S='(@(E9L;[YI="#XX61E:R!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R
M;W<@8F5F;W)E(@IM<V=S='(@(E9L;[YI="#XX61E:R!P^&5D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U
M:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R
M(")6;&^^=&4@<&^^861O=F%N;W4@;V1P;W;L[R!N82!B97IP9>AN;W-T;NT@
M;W3A>FMU.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B
M5FQOOFET+W5P<F%V:70@;V)RX7IE:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@
M3&EN:R(*;7-G<W1R(")6;&^^:70O=7!R879I="!O9&MA>B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R(").961O<W1A=&7H;OT@:W)E9&ET(&L@;V1E
M<VSA;NT@>G!RX79Y(&YA(&1I<W1R:6)UZ&[M('-E>FYA;2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I
M9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B3F5D;W-T871EZ&[]
M(&MR961I="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS
M9VED("));G1E9V5R(@IM<V=S='(@(D-E;.D@Z.US;&\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS
M9W-T<B`B4V5Z;F%M(&-E;/UC:"#H[7-E;"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B3F5S<'+A=F[I
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M(%I)4"!D871A(@IM<V=S='(@(DYE<&QA=&[A(&1A=&$@=6YI8V]D92XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P
M<&QI8V%T:6]N+B(*;7-G<W1R(").97!L871NX2!A<&QI:V%C92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DYE<&QA=&[I(&ED
M96YT:69I:V'H;NT@Z.US;&\@*$E$*2!DX79K>2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T
M960N(@IM<V=S='(@(D)Y;&$@>F%DX6YA(&YE<&QA=&[A(&1A=&$B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*
M;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B
M3F5P;&%T;N$@861R97-A('#X[6IE;6-E+B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B3F5P;&%T;OT@9F]R;>%T('-O=6)O<G4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(").97!L871NX2!A<&QI:V%C
M92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M(").97!L871NX2!A<&QI:V%C92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G
M7W1Y<&4N(@IM<V=S='(@(DYE<&QA=&[](&US9U]T>7!E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B3F5P;&%T
M;ND@;F5B;R!C:'EB[&KM8^T@87!I7VED+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(DYE<&QA=&[I(&YE
M8F\@8VAY8NQJ[6/M('!A<F%M971R>2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(DYE<&QA=&[A('9L87-T;FEC:^$@<'+A=F$N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(").97!L871NX2!V;&%S=&YI
M8VOA('!RX79A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G
M<W1R(").97!L871N_2!P<F]T;VMO;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@
M<')O=&]C;VPN(@IM<V=S='(@(DYE<&QA=&[]('!R;W1O:V]L+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(DYE<&QA=&[]('#X[6IE;6-E.B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3F5P
M;&%T;OT@<V3M;&5N_2!O8FIE:W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U
M<F-E(&%D9')E<W,N(@IM<V=S='(@(DYE<&QA=&[A(&%D<F5S82!O9&5S[6QA
M=&5L92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G
M<W1R(").97!L871NX2!D871A('5N:6-O9&4N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN
M=F5N=.'X(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G
M<W1R(")6>7-T^&EH;F]U="!V_6+L<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("+-<N%N+"!)<VSA
M;7-KX2!R97!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS
M9W-T<B`B27+A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("))<G-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U
M"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")/<W1R;W8@;76^92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED
M("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")/:F5D:6[L;.D@8F]U^&MY
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G
M:60@(DES<W5E<B(*;7-G<W1R(")0;W-K>71O=F%T96PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI
M8R(*;7-G<W1R(")+=7)Z[79A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L
M>2(*;7-G<W1R("))=.%L:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I
M8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DQE
M9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!O
M;G-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A
M;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]NN71I;F$@*$E33RTR
M,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS
M9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@
M8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN
M9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B5')I:V]T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9.%N<VMO
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*
M;7-G:60@(DIU;'DB"FUS9W-T<B`BR&5R=F5N96,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G
M<W1R("+(97)V96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(EIA
M<F]V;F%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@
M(EIA<F]V;F%T(&YA('-T^&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L
M;"(*;7-G<W1R("):87)O=FYA="!V>7!L;NQN[6TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B
M2G5S=&EF>2!,969T(@IM<V=S='(@(EIA<F]V;F%T(&1O;&5V82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V
M"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(EIA<F]V;F%T(&1O<')A
M=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B
M2V%Z86-H<W3A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(E5C
M:&]V870@;W)I9VENX6P_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R(")+9?)A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!S97)V97(@>F%M[71N=6P@;W;L
M^&5N[2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME
M<FYE;"!.97=B:65S(@IM<V=S='(@(DYO=N'H8VD@:V5R;F5L=2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(E9Y='9O^&5N[2!K;.WH92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R
M:6YT(@IM<V=S='(@(E9Y='9O^&5N[2!O=&ES:W4@:VSMZ&4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B1.EL:V$@:VSMZ&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E1Y
M<"!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DX"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B5;YI=.T@:VSMZ&4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B2VSMZ"!J:;X@97AI<W1U:F4@;F$@=F7X96INZ6T@:VSMZ&]VZ6T@
M<V5R=F5R=2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(DMI9',B"FUS9W-T<B`B1.QT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER
M:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(DM,1%(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI
M8R!O9B(*;7-G<W1R(")+;W)E82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R96IS:WD@
M*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R
M(")+=79A:G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS
M9W-T<B`B2WER9VEZ<W3A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?4F]Z;&^^96[M(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B
M"FUS9W-T<B`B2F%Z>6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,L($QI9&]V
M["!$96UO:W)A=&EC:V$@4F5P=6)L:6MA(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(D1R=6CA('!O;&]V
M:6YA(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")6_6-H;WKM(&YA
M<W1A=F5N[2!H97-L82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R
M(")0;W-L961N[2#H='9R=&EN82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E!O<VQE9&[M(&%K
M='5A;&EZ86-E.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")0
M;W-L961N[2!P^&EH;.&Y96[M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R!F<F]M("5S(@IM<V=S='(@(E!O<VQE9&[M('#X:6ALX;EE;NTZ("5S('H@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA
M<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E!O<VQE9&[M('#X:6ALX;EE;NTZ
M($YI:V1Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B
M3&ET=F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA
M=R(*;7-G<W1R(")0<N%V;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@
M(E)O>FQOOF5N[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B
M"FUS9W-T<B`B3F5C:&%T('!RX7ID;ND@8F5Z(&]K<F%J92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS
M9VED("),969T(@IM<V=S='(@(D1O;&5V82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(DQE
M=N$@:&QA=FGH:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")(;V1N;W1Y(&YA;&5V;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY
M"FUS9VED("),979E;"(*;7-G<W1R("),X7-K82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I<FEE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FEE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@
M(DQI8VAT96ZY=&5J;G-K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@
M(DQE:&OI(&UR:&]L96[M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B3&5H
M:_T@9.FYNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(D)R>FO]
M(&QE:&O](&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(E!O
M>F3L:FD@;&5H:_T@9.FYNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G
M<W1R("),96AKZ2!D9;F[;W;I('-RX;YK>2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I
M=&@@5&AU;F1E<B(*;7-G<W1R("),96AK_2!DZ;F[(',@:/AM[&[M;2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED
M("),:6=H="!3;F]W(@IM<V=S='(@(DQE:&OI('-N[+YE;NTB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3&5H:^D@<V[L:&]VZ2!P^&5HX?)K
M>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I
M8VLB"FUS9W-T<B`B3&EM97)I8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(D]D:V%Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W
M"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3V1K87IY('5K87IU
M:NT@;F$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I
M9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"B)0;W6^[70@;V1K87IY(&YA
M(&5M86EL;W;I(&%D<F5S>2!P^&D@>F]B<F%Z;W;A;NT@<W1RX6YK>2!P<F\@
M<'-A;NT@>G!RX78B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R(")/9&MA
M>GDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X
M($-O;VMI92(*;7-G<W1R("),:6YU>&]VZ2!C;V]K:64B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M
M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(E-E>FYA;2`M('6^
M:79A=&5L(&WYOF4@=FED['0@<VQOOFMU(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B4V5Z;F%M
M(&1A=&%BX7KM(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G
M:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B4V5Z;F%M('3I;6%T(&[A
M<&]V[&1Y(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES
M="!486)L97,B"FUS9W-T<B`B4V5Z;F%M('1A8G5L96LB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H
M:79E(@IM<V=S='(@(E-E>FYA;2U!<F-H:78B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(E-E>FYA;2U.X7!O=NQD82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(E-E>FYA
M;2U)9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR
M"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(E-E>FYA;2U6;&%S=&[M:R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED
M("),:7-T+5!O<W0B"FUS9W-T<B`B4V5Z;F%M+4]D97-LX6[M(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(E-E>FYA;2U0^&EH;.&Y96[M(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M
M56YS=6)S8W)I8F4B"FUS9W-T<B`B4V5Z;F%M+4]D:&SAN65N[2(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(E;]<&ES
M('6^:79A=&5L^2!N96[M(&1O<W1U<&[]+B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S(@IM<V=S='(@(E;]<&ES('6^:79A=&5L^2!N96[M
M(&1O<W1U<&[]+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B5OUP:7,@=;YI=F%T96SY(&YE;NT@9&]S='5P;OTN(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@
M(DQI=&5R871U<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*
M;7-G<W1R("),;W1YN7-K;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B
M3F%H<N%VX6[M+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DWM<W1N[2#H87,Z
M("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE
M(&%N9"!4:6UE(@IM<V=S='(@(DQO8V%L92!A(.AA<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B
M3>US=&\B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B4/AI:&SA<VET
M('-E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED
M("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O
M=70B"FUS9W-T<B`B3V1H;.&Y96[M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R(")0^&EH;.%S
M:70@<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),
M;V=I;B!487-K<R(*;7-G<W1R("+::V]L>2!P<F]VX63L;ND@</AI('#X:6AL
MX;EE;NTB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(E-E;&AA
M;&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU+B!0<F%V9.QP;V1O8F[L(%9AN64@
M=;YI=F%T96QS:^D@:FWI;F\@82]N96)O("(*(FAE<VQO(&YE8GEL;R!S<'+A
M=F[L('IA9.%N;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*
M;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B4/AI:&SAN65N[2!S96QH
M86QO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*;7-G:60@
M(DQO;F<@=&5X="(*;7-G<W1R(")$;&]U:/T@=&5X="(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("),X7-K82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS
M9VED("),;W<B"FUS9W-T<B`B3NUZ:^$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E
M<B!G<F5E:R!L971T97)S(@IM<V=S='(@(DUA;.$@^&5C:^$@<.US;65N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M36%LX2!T:7-K86/M('#M<VUE;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(DUA;.D@^.UM<VOI(.CM<VQI8V4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5C96UB
M=7)S:V\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S
M='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I
M9"`B34]41"(*;7-G<W1R("):<'+A=F$@9&YE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B4/AI<&]J96[]
M('-O=6)O<B!-4RU.5$5&(&YE;V)S86AU:F4@ON%D;N$@9&%T82XB"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86MA;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DUA:V5D;VYI92P@8OUV86SA(%)E<'5B;&EK
M82!*=6=O<VSA=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R
M(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEE(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(E!O
MN71A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R(")!9&UI;FES='+A=&]R('!ON71Y(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(E9Y='9O^&ET(&]D
M7VMA>BXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@
M(DUA;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T
M<B`B36%L86IS:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM
M<V=S='(@(DUA;&1I=GDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS
M9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T
M<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@
M(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(E!R;R!U;6^^;NQN
M[2!O=FSA9.%N[2!K871E9V]R:>T@:F4@>F%P;W3X96+M(&]Z;F'H:70@<&]L
M;[YK>2!B87)V86UI+"!K=&5RZ2`B"B)J<V]U('#X:?AA>F5N>2!K('3L;71O
M(&MA=&5G;W)I[6TN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87!A
M($UA<#(T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!A($UA
M<%%U97-T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS
M9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R(")"^&5Z96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B
M3VMR86HB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(D]Z;F'H:70@>FYAZ&MO=2!0<F]H;.ED;G5T;R].97!R;VALZ61N=71O
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*
M;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I(@IM<V=S='(@(D]Z;F'H:70@:FEN_6UI('IN8>AK86UI("AJ
M86MO($3Y;&6^:73I+T]D<&]V['IE;NDI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<KEA;'-KZ2!/<W1R;W9Y
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA
M<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM
M<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-H;V1U:NUC[2!S92!P
M;VQE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@
M(DUA=7)E=.%N:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*
M;7-G<W1R(")-875R:6-I=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R
M961I="XB"FUS9W-T<B`B36%X:6UA;&[M('!O=F]L96[](&MR961I="(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@
M(D)Y;&$@</AE:W)OZ&5N82!M87AI;6%L;NT@9.EL:V$@>G!RX79Y+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B3F5J=GFYN>T@=&5P;&]T82!Z82!P;W-L
M961N[6-H(#(T(&AO9&EN.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B3F5J
M=GFYN>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ("(*"B,Z(&QI
M8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@
M0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM
M<V=S='(@(DUA>&EMX6QN[2!DZ6QK82(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B2W;L
M=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-
M87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-
M961I8VEN92(*;7-G<W1R(")-961I8^UN82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B
MR&QE;F]VZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@
M(DUE;G4@;6]D93HB"FUS9W-T<B`B3?-D>2!P<F\@;65N=3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R(")3<&]J:70@8G7R:WDB"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("):<'+A=F$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(EIP
M<N%V82!B>6QA(&]V[/AE;F$@=B!P;_CA9&MU+"!A;&4@;F5L>F4@;W;L^&ET
M('!O9'!I<V]V_2!C97)T:69I:^%T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R("):<'+A=F$@<')O<&%D;&$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1Y<"!Z<'+A=GDB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H
M97(B"FUS9W-T<B`B4&_H87/M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)";&]K(&\@<&_H87/M(&YE;NT@9&]S='5P
M;OTN(%!O9')O8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@<')O('-Y<W3I;6]V
MZ6AO("(*(F%D;6EN:7-T<N%T;W)A(&1O(&QO9W4N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-971O9&$B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]2
M4$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-971O
M9&$@)R5S)R!N96[M(&1E9FEN;W;A;F$B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T
M(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N
M<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FEC:_TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI:V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O
M9B(*;7-G<W1R(")-:6MR;V[I<VEE+"!&961E<F%C92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B
M36ED9&QE(@IM<V=S='(@(E5P<F]S=/AE9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B5'EP($UI;64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM
M<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DYE:FYI
MOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`R-"!H;V1I;CH@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(DYE:FYIOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC
M:"`V(&AO9&EN.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@
M97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,T"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B6G)C
M861L;W;L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-
M:7-C96QL86YE;W5S(@IM<V=S='(@(E+Y>F[I(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!R;V=R
M86UO=OT@8F%L[6L@2%144%]297%U97-T(&-H>6+M('8@4$5!4BXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M(@HB0VAY8NQJ[6/M(&MO;F9I9W5R86-E+B!0;VMU9"!S:2!P^&5J971E('!O
M=;[M=F%T('1U=&\@87!L:6MA8VDL(&UU<^UT92`B"B)V>6=E;F5R;W9A="!K
M;VYF:6=U<F'H;NT@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S
M86=E($E$+B(*;7-G<W1R(")#:'EB[&KM8^T@240@>G!RX79Y("AI9&5N=&EF
M:6MAZ&[M(.CM<VQO*2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")0;[YA9&]V86[]('!R;V=R
M86UO=OT@8F%L[6L@36%I;"!C:'EB[2!V(%!%05(N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-
M:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D-H>6+L:NUC[2!)1"!P<F\@
M<F5L86-I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(E!O(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R
M(")-;V)I;&[M('!ON71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DWM<F[]
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF
M:65D($1A=&4B"FUS9W-T<B`B1&%T=6T@<&]S;&5D;NT@>FWL;GDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B6FWL\FET(%523"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-
M;V1U;'5S(@IM<V=S='(@(DUO9'5L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQDX79I92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%K;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L<VMO(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@
M86YD('EE87(B"FUS9W-T<B`B3>QS[6,@82!R;VLB"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY
M(@IM<V=S='(@(DWL<^WH;NPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S
M97)R870B"FUS9W-T<B`B36]N<V5R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S
M(@IM<V=S='(@(D;A>F4@3>QS[6-E(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE
M("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;VMO(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO
M<W1L>2!#;&5A<B(*;7-G<W1R(")0^&5VX;YN["!J87-N;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T
M;'D@0VQO=61Y(@IM<V=S='(@(E#X97;AOF[L(&]B;&'H;F\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(E#X97;AOF[L('-L=6YEZ&YO(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`B4&]S=6YO=70@9&]L^2(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM
M<V=S='(@(E!O<W5N;W5T(&1O;&5V82(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R
M(")0;W-U;F]U="!D;W!R879A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E!O<W5N
M;W5T(&YA:&]R=2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")0;W-U;F]U
M="!D;VSY(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E!O<W5N;W5T(&YA:&]R
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-
M;W-A;6)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G
M:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R(")6[6-E
M+?IR;W;R;W;I(')O;&5T;W;I('-E>FYA;7DB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@
M54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")6[6-E
M;N%S;V)NX2!S96QE:V-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-^6H@^NAE="(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B37D@
M06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")68;EE(&EN9F]R;6%C92(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O
M<G1A;"(*;7-G<W1R(")-^6H@<&]R=.%L(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R
M(")-;VIE(')O>FQOOF5N[2!P;W)TX6QU(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@
M3D]4($%G<F5E(@IM<V=S='(@(DY%+"!.15-/54A,05/-32(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(DIM
MZ6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA
M;6EB:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA
M=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97#A
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B
M3FEZ;WIE;>TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT
M:6QL97,B"FUS9W-T<B`B3FEZ;WIE;7-KZ2!!;G1I;'DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0F%S92!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R
M(").971S8V%P92!#02!P;VQI8WD@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@
M55),(@IM<V=S='(@(DYE='-C87!E(%)E;F5W86P@55),(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E
M(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(%)E=F]C871I;VX@
M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(")*;>EN
M;R!.971S8V%P92!34TP@<V5R=F5R=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT(@IM<V=S='(@(E!O>F[A;6MA(&L@8V5R=&EF:6OA='4@3F5T
M<V-A<'4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4
M>7`@8V5R=&EF:6OA='4@3F5T<V-A<'4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(E/MNR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*
M;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI:V1Y(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=N$@2V%L961O;FEE(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").;W;A(&MA=&5G;W)I
M92(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S
M86=E('1O("5S(@IM<V=S='(@(E9Y='9O^&ET('IP<N%V=2`H)7,I(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R
M(")-['/M8R!V('!R=F[M(.AT=G)T:6[L(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I
M;VYA;"DB"FUS9W-T<B`B3F]VZ2!UOFEV871E;'-KZ2!J;>EN;R`H;F5P;W9I
M;F[I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T
M<B`B3F]V_2!:Z6QA;F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(")(
M97-L;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T
M8V@N(@IM<V=S='(@(DAE<VQA('-E(&UU<^T@<VAO9&]V870N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B
M3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").;W;I(&]K;F\@*%]P<N%Z
M9&[I*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y
M"FUS9VED(").97=S(@IM<V=S='(@(DYO=FEN:WDB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@
M(DYE=W-G<F]U<',B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")$86RY[2(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*
M;7-G<W1R(")$86RY[2!FX7IE(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*
M;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")$86RY[2!M;[YN;W-T:2(*
M"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"B,L(&9U>GIY"FUS
M9VED(").97AT/B(*;7-G<W1R(")$86RY[2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=U82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEGZ7)I92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@
M(DYO8R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M,PIM<V=I9"`B3F\B"FUS9W-T<B`B3F4B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(JYA9&[A(&MO;F9I9W5R8>AN[2!D871A(&YE:G-O=2!D;W-T=7!NX2!P<F\@
M>F]B<F%Z96[M(')O>F3M;/DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(DYE;NT@9&]S
M='5P;N$@ON%D;N$@<W1R871E9VEE('!R;R!T=F]R8G4@25-/(&]B<F%Z^2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")"97H@
M9.%V:V]VZ6AO('9Z;W)U+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*
M;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N(@IM<V=S='(@(DYA('!OOF%D;W9A;ND@<&]Z:6-I(&YE97AI<W1U:F4@
MON%D;OT@8FQO:R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z
M-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL;R!P;W-K>71N=71O(+[A
M9&[I(&IMZ6YO('!R;R!K86QE;F3A^"!P^&D@;W;L^&]VX6[M('!O;6]C[2!-
M0T%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C
M:&%N9V4N(@IM<V=S='(@(D)E>B!Z;>QN>2XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E
M(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5L>F4@</AI
M9&%T(+[A9&[A('!O9"UP<N%V82!K('3L;71O('!RX7;Y;2XB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").96)Y;'D@=79E9&5N>2"^
MX61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S
M='(@(DYE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA
M8V4@<')O($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").96)Y;'D@=79E9&5N>2"^
MX61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R!344P@5D93+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM
M1FEL92!61E,N(@IM<V=S='(@(DYE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I
M9W5R8>AN[2!I;F9O<FUA8V4@<')O(%-13"U&:6QE(%9&4RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G
M:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(").96WA=&4@ON%D;OT@:W)E
M9&ET+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS
M9W-T<B`B3F5B>6P@<&]S:WET;G5T(+[A9&[](&/M;"XB"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L
M;V%D960B"FUS9W-T<B`BKN%D;OT@<V]U8F]R(&YE8GEL('#X96YE<V5N(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F
M;W5N9"XB"FUS9W-T<B`B3F5B>6QY(&YA;&5Z96YY(+[A9&[I(&EK;VYY+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS
M9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DYE8GEL;R!V>6)R
MX6YO(+[A9&[I(&WM<W1O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D
M+B(*;7-G<W1R(").96)Y;&\@=GEB<N%N;R"^X61NZ2!M[7-T;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM
M<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F5B>6QY('!O
M<VMY=&YU='D@ON%D;ND@>G!RX79Y+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P
M96-I9FEE9"XB"FUS9W-T<B`B3F5B>6QO('5V961E;F\@ON%D;ND@:FWI;F\N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYE
M8GEL;R!U=F5D96YO(+[A9&[I(.CM<VQO+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(D)E>B!N97-L=;EN_6-H(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H
M='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A4
M5%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL;R!P;W-K>71N=71O
M(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!(5%10+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5B
M>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M($E-05`N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L
M^&5N[2!P;VUO8^T@2V5R8F5R;W,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX
M-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@
M</AI:&SAN65N[2!S92!D;R!S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL
M;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!005-35T0N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(").96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P
M;VUO8^T@4TU"+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F5B
M>6QA('!O<VMY=&YU=&$@8V5S=&$@:R!B:6[A<F[M;74@<V]U8F]R=2!/<&5N
M4U-,+B!":6[A<F[M('-O=6)O<B!/<&5N4U-,("(*(FIE('IA<&]T^&5B[2!P
M<F\@<'+A8VD@<R!02T-3(#$R(&1A='DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S
M+B(*;7-G<W1R("*NX61NZ2!N979Y^.UZ96[I(+[A9&]S=&D@;R!P^&EH;.&Y
M96[M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3F5N
M[2!N87-T879E;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")"
M97H@<')A=FED96PB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#D*(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM
M<V=S='(@(DYE8GEL;R!U=F5D96YO(+[A9&[I(.CM<VQO+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G
M:60@(DYO('-I9&5S(@IM<V=S='(@(D)E>B!O:W)A:ODB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<W5C
M:"!F:6QE(@IM<V=S='(@(D)E>B!O:W)A:ODB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(J[A9&[]('H@9&_H
M87-N_6-H(&%D<F5SX?CY(&YE;NT@9&]S='5P;OT@<')O(&-A8VAE+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS
M9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T
M<B`B3F5B>6QO(&]D97-LX6YO(+[A9&[I('6^:79A=&5L<VOI(&IMZ6YO(&$O
M;F5B;R!H97-L;RXB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B3F5B>6QA(&YA=G+A8V5N82"^X61NX2!P;&%T;N$@6$U,(&1A=&$N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G
M:60@(DYO('9A;'5E<R(*;7-G<W1R("*NX61NZ2!H;V1N;W1Y(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E8@;W)I9VENX6QN[2!K;VYF:6=U<F%C:2!N
M96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@:V]N9FEG=7)A8VDN(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B5F4@5F&Y[2!K;VYF:6=U<F%C:2!N96)Y
M;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@:V]N9FEG=7)A8VDN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N
M92(*;7-G<W1R("*NX61N_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB
M"FUS9W-T<B`BKN%D;OT@*'!O=;YI:G1E(&EM<&QI8VET;NTI(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM
M,3`I(@IM<V=S='(@(E-E=F5R<VO]("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&MS
M:^D@;W-T<F]V>2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B4V5V97)N[2!P;VQO:V]U;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(")3979E<F[M($UA
M<FGA;G-KZ2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB
M"FUS9W-T<B`B3F]R<VMO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").96[M('!O
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B3F5N[2!P^&5D(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O
M<GDB"FUS9W-T<B`B3F5N[2!A9')E<^'X96TB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(").96[M
M(&EM<&QE;65N=&]VX6YO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F5N
M[2!N87-T879E;F\B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F5N[2!P;V1P
M;W)O=N%N;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(E!O>F[A;6MA(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V
M"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B
M3FEC(&L@<')O:&SI9&YU=.TL(&+LOG1E('IP['0N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R
M(@IM<V=S='(@(DQI<W1O<&%D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(LCM<VQO(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H
M87)A8W1E<G,B"FUS9W-T<B`B4&_H970@>FYA:_DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`B4&_H970@<VQO=7!C^2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").
M=6UB97(@;V8@<F]W<R(*;7-G<W1R(")0;^AE="#XX61K^2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED
M(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").96)Y;&$@>F%DX6YA(.CM<VQA('!R
M;R!A:W1U86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA;74N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/
M2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE:W0B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J
M96-T($-R96%T;W(B"FUS9W-T<B`B5';Y<F-E(&]B:F5K=/DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R
M(")/<VUIZ&MO=OTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("+8[6IE;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT
M97(B"FUS9W-T<B`B1FEL=')O=F%T(&YE<VQUN6[I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(DMA
M;F-E;.'X(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS
M9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(DAE<VQO
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY
M"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@
M(DYE<W!RX79NZ2!H97-L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R(")/;>%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E-D[6QE;ND@<VQOOFMY(&IS;W4@
M<&]S:WET;W;A;GD@<&]U>F4@24U!4"!S97)V97)Y+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B4&]U>F4@;F5S;'6Y;NDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*
M;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T
M<B`B2F4@<&]V;VQE;F$@<&]U>F4@:F5D;F$@92UM86EL;W;A(&%D<F5S82XB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E(@IM<V=S='(@(B(*(E!O=7IE('9L87-T;NUK(&YE8F\@<WES=.EM;W;]
M(&%D;6EN:7-T<N%T;W(@;?F^92!M[&YI="!P<N%V82!P<F\@<V3M;&5N_2`B
M"B)O8FIE:W0N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@
M(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]T97;X[70@=B!N;W;I
M;2!O:V[L+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D
M871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R(")#:'EB82!/
M<&5N4U-,.B!.96QZ92!Z[7-K870@9&%T82!Z('!O9&5P<V%NZ2#HX7-T:2!3
M+TU)344N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(D]T97;X[70@=&5N=&\@;V1K87H@=B!N;W;I
M;2!O:V[L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/
M<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P97)AZ&[M('-Y<W3I;2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO
M;G,B"FUS9W-T<B`B36^^;F]S=&DB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B36^^;F]S=&D@<')O("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E-E^&%Z96[]('-E>FYA
M;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS
M9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI>F%C92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A
M;FES871I;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N:7IAZ&[M(&IE9&YO=&MA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G
M86YI>FEN9R(*;7-G<W1R(")/<F=A;FEZ;W;A;NTB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4B"FUS9W-T<B`B3W)I9VENX6QN[2!V>F]R('!R;R"^X61O<W0B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(D]R:6=I;N%L
M;NT@=GIO<B!V("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*
M;7-G<W1R(")/<W1A=&[M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B3W-T871N[2!I
M;F9O<FUA8V4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS
M9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")5OFEV871E;'-KX2!P
M<N%V82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I
M9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D]V[/AE;NT@<&]M;V/M(%!!32!N96[M(&1O<W1U<&[I+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I
M9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L
M(%-I9VYA='5R92(*;7-G<W1R(")01U`@9&EG:73A;&[M('!O9'!I<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'
M4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@N6EF<F]V86[A(&1A=&$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED
M(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")69?AE:F[](%!'4"!K;.WH(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")$871A('!O9&5P
M<V%NX2^Y:69R;W9A;N$@<&]M;V/M(%!'4"(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(&OS9"(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S
M='(@(E!(4"!K;VYZ;VQA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M3V1P;VQE9&[M(&QE:&O](&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R
M(")/9'!O;&5D;NT@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")/
M9'!O;&5D;NT@<V[LOF5N[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B3V1P;VQE9&[M('-N[&AO=ND@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0HC+"!F=7IZ>0IM<V=I9"`B
M4$T@4W5N(@IM<V=S='(@(D]D<&]L961N[2!S;NR^96[M(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M
M4W1O<FUS(@IM<V=S='(@(D]D<&]L961N[2!B;W7X:WDB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@
M;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@
M(E!?2%`@4VAE;&PB"FUS9W-T<B`B4%](4"!K;VYZ;VQA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I
M9"`B4&%D9&EN9R(*;7-G<W1R(")/9'-T=7!Y(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")086MI<W1A;B(*;7-G<W1R(")0X6MI<W3A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G
M<W1R(")086QE<W1I;G-KZ2!T97)I=&]R:75M+"!O:W5P;W9A;NDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B4&%P
M=6$@3F]VX2!'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A
M>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(DWM<W1Y('IA=&&^96YO(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B
M2&5S;&\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G
M:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G
M:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(").97-P<N%V;ND@:&5S
M;&\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS
M9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")0<F\@;W;L^&5N[2!P;VUO8^T@4D%$54E3(&IE(&YU
M=&YO('IA9&%T(&AE<VQO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(DAE<VQO(',@<&]T=G)Z96[M;2(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DAE<VQO
M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")0
M87-S=V]R9#H@(@IM<V=S='(@(DAE<VQO.B`B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@
M;75S="!M871C:"XB"FUS9W-T<B`B2&5S;&$@<V4@;75S[2!S:&]D;W9A="XB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B
M"FUS9W-T<B`B5FQOOFET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B
M"FUS9W-T<B`B5FQOOFET('IE('-C:'+A;FMY(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R(")#97-T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW
M"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(J[A9&]S=&D@;R!P
M^&EH;.&Y96[M.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I
M9"`B4&5O<&QE(@IM<V=S='(@(DQI9.DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G
M<W1R(")0<F]C96YT(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R(*;7-G<W1R(")0<F]VZ7-T(&]P97)A8V4@^F1ROF)Y(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")0<F]VZ7-T
M(&]P97)A8V4@^F1ROF)Y('#X:2!P^&EH;.&Y96[M(&1O('-Y<W3I;74_(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E
M<FUI<W-I;VXB"FUS9W-T<B`B4'+A=F$B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S
M:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B4'+A=F\@)R5S)R!N
M96)Y;&\@<VUA>N%N;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`B4'+A=F$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM
M<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!RX79A(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV
M,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B061M:6YI<W1R8>AN[2!P<N%V82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS
M9W-T<B`B3W-O8F[M(&EN9F]R;6%C92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&5R=2(*;7-G<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4U"FUS9VED(")0971S(@IM<V=S='(@(D1O;>%C[2!Z=NWX871A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<.UN
M>2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B
M1F]T;V=R869I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM
M<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:7AE
M;/DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I
M='5D97,B"FUS9W-T<B`B1G+A>F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B4')O<^UM(&ML:6MN['1E(&YA
M(&[L:F%K;W4@8G7R:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T
M<B`B4')O<^UM('!O='9R[W1E+""^92!S:2!P^&5J971E(&]D<W1R86YI="!T
M96YT;R!P<G9E:SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M4')O<^UM('!O='9R[W1E+""^92!S:2!P^&5J971E(&]D<W1R86YI="!T96YT
M;R!P<G9E:RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R
M(")0<F]S[6T@>F%D96IT92!M['/M8R!A(')O:RXB"@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B
M4')O<^UM('IA9&5J=&4@;N%Z978@;F]VZ2!K871E9V]R:64Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B4')O<^UM('IA9&5J=&4@
M<W!RX79N;W4@25`@861R97-U+BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R
M(")0<F]S[6T@>F%D96IT92!S<'+A=F[](&1A='5M(&$@>FMO;G1R;VQU:G1E
M('!OZ&5T(&1N[2!V(&WL<^UC:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R(")0<F]S[6T@>F%D96IT92!S<'+A=F[](.AA<RXB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E!R;W/M
M;2!U=F7O=&4@<VAR;G5T[2!68;EE:&\@<')O8FSI;74N(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9"(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!68;EE('6^:79A
M=&5L<VOI(&IMZ6YO(&$@:&5S;&\B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E!R;W/M;2!P^&7H
M=.QT92!S:2!NX7-L961U:NUC[2!T97AT+B!-55/-5$4@<V]U:&QA<VET(',@
M<&]D;>UN:V%M:2!P;W6^[7;A;NT@(@HB<WES=.EM=2XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")0
M<F]S[6T@>F%D96IT92!N;W;](&[A>F5V(&MA=&5G;W)I93HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQS:V\B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@
M(E!O;&ET:6MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM
M<V=I9"`B4&]L;',B"FUS9W-T<B`B2&QA<V]VX6[M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QS:V\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B56WM<W3L;NT@=&]H;W1O(&]B<N%Z:W4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")5;>US=.QN[2!T86)U;&MY(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G
M:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*2(*;7-G<W1R("):87-L870@9&\@=.ET;R!S;&^^:WD@*&YE;NT@<&]S:WET
M;G5T;R!)34%096TI(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E
M8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4W+A
MOFMY('IA('!O<VQE9&[M*&-H*2`E<R!H;V1I;BAU*3H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A
M<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!,1$%0+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I
M9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!.96)Y;&$@;F%L
M97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('-E:V-E+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")"87)O
M;65T<FEC:_T@=&QA:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS
M9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R(")"87)O;65T
M<FEC:_T@=&QA:R!N82#Z<F]V;FD@;6_X93H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R
M(")"87)O;65T<FEC:_T@=&QA:SHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE
M=R(*;7-G<W1R(").X6AL960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(").X6AL960@;V)R
MX7IK=2!V(&YO=NEM(&]K;NPB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@IM
M<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0^&5D8VAO>NT@;6^^
M;F]S=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")4:7-K;F]U
M="!D;VMU;65N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B4')I=N%T;NT@:VSM
MZ"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G
M:60@(E!R;V)L96TB"FUS9W-T<B`B4')O8FSI;2(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G
M<W1R(")0;W!I<R!P<F]B;.EM=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:W1Y(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E!R;VUP="!T97AT(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(E9E^&5J;OT@:VSMZ"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y
M($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;75S('!R;R!V9?AE:F[](&ML
M[>@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`HC
M+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(E9E^&5J
M;OT@:VSMZ"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T
M,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5F7X96IN_2]P<FEVX71N[2!K;.WH
M;W;]('#A<B!N96)Y;"#Z<W#LN6[L('9Y='9O^&5N+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!O<G1O<FEK;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")6
M>6AL963A;NTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@9G5Z
M>GD*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMA=&%R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!('9E^&5J
M;OT@:VSMZ"`H)60@8FET^2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4W#X8;YE
M;ND@=&QAZ.UT:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")$Z;F[(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A
M:6X@16%R;'DB"FUS9W-T<B`B0G)Z:_T@9.FYNR(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B
M"FUS9W-T<B`B4&]Z9&[M(&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T
M<B`B1&6YNV]VZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S
M='(@(D3IN;L@<V4@<V[L:&5M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R
M(")$Z;F[(&&^('-N[6@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM
M<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B3N%H;V1N["!V>6)R86[I
M(+ET['-T[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM
M<V=I9"`B4F%T:6\B"FUS9W-T<B`B4&]M['(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("+(
M=&5C[2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(E#X9>AT96[I('IP
M<N%V>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")/<')A=F1U('-M
M87IA="`E<S\@5&%T;R!O<&5R86-E(&IE(&YE=G)A=&[A+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)/<')A
M=F1U('-M87IA="!UOFEV871E;'-KX2!D871A('!R;R!UOFEV871E;&4@)7,_
M(%1A=&\@;W!E<F%C92!J92!N979R871NX2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")/<&%K;W9A="!P;W-L961N[2!A:V-I
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D]B;F]V:70@9'EN86UI8VOI('!R
M=FMY(&UE;G4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I
M9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B3V)N;W9A('IO8G)A
M>F5N[2!P;W)TX6QU.B`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")296=E
M>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E
M;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(E!R;VAL[;YEZ"!V>G1A:/DB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B
M"FUS9W-T<B`BR'1E8^TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R(")(;V1N;W1Y(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T
M<B`B5GIDX6QE;ND@<V5R=F5R>2XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")6>F3A;&5NX2!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(D]D<W1R86YI="(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E($)L;V-K(@IM<V=S='(@(D]D<W1R86YI="!B;&]K(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M
M;W9E(&-O;'5M;B(*;7-G<W1R(")/9'-T<F%N:70@<VQO=7!E8R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@
M(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D]D<W1R86YI="!F;W)MX71O
M=N%N[2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED
M(")296UO=F4@<&%I<B(*;7-G<W1R(")/9'-T<F%N:70@<.%R(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(D]D<W1R871I="!U;&^^96[]('-K<FEP="!Z(&1OZ&%S;NEH;R!A9')E
M<^'X92!N82!S97)V97)U+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*
M;7-G<W1R(")/9'-T<F%N:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B3V1S=')A;FET('1U
M=&\@Z.%S="!D;VMU;65N='4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")/9'-T
M<F%N:70@=;YI=F%T96QE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E
M<R(*;7-G<W1R(")/9'-T<F%N:70@=;YI=F%T96QE.B`E<R(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G
M<W1R(").96QZ92!O9'!O=NQD['0@;F$@<&^^861A=F5K+B!#:'EB;W;I(&AL
MX;EE;NTZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*
M(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B
M92!F;W5N9"XB"FUS9W-T<B`B4/AE;F5S96[]('-O=6)O<B!N96QZ92!U;&^^
M:70N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(E!OOF%D;W9A;ND@)R5S)R!N96)Y;&\@
M=79E9&5N;R!V(&MO;F9I9W5R86-I('!R;R`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&^^
M861O=F%NZ2`G)7,G(&YE8GEL;R!U=F5D96YO('8@:V]N9FEG=7)A8VD@<')O
M(%9&4RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!OOF%D;W9A;ND@
M)R5S)R!N96)Y;&\@=79E9&5N;R!V(&MO;F9I9W5R86-I+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER
M960@1FEE;&0B"FUS9W-T<B`B4&^^861O=F%NZ2!P;VQE(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(E;]8VAO>NT@
M;F%S=&%V96[M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*
M;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E;]8VAO>NT@;F%S=&%V
M96[M(&AE<VQA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B5OUC:&]Z[2!N
M87-T879E;NT@5F&Y96AO(&AE<VQA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S
M='(@(E!O<VQE9&[M(.AT=G)T:6YA(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B5OUS;&5D:WDB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(D[A
M=G)A="!D;R!M;[YN;W-T[2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*
M;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2!H97-L82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B4/AE<&YO
M=70@:V]N9FEG=7)A8VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R
M"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B36^^
M;F]S=&D@4FEC:"!497AT(&5D:71O<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B2.%D86YK>2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B1&]P<F%V82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G
M<W1R(")(;&%V:>AK82!N87!R879O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(DAO9&YO
M='D@;F%P<F%V;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(E9L87-T;F]S=&D@^.%?9&MU(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G
M<W1R("+:;&]H82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS
M9W-T<B`B4G5M=6YS:V\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D]T
M;^AI="!O(#$X,+`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")/=&_H
M:70@9&]L979A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(D]T;^AI
M="!D;W!R879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T
M<B`B5FQA<W1N;W-T:2#XX61K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T
M:65S(@IM<V=S='(@(E9L87-T;F]S=&D@^.%D:W4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB
M"FUS9W-T<B`BV.%D:WDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B
M4')A=FED;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(E!R879I9&QA('-E
M('5P;&%T;NT@;65Z:2!VN65M:2#XX61K>2!A('-L;W5P8VDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*
M;7-G<W1R(")0<F%V:61L82!S92!U<&QA=&[M('!O=7IE(&UE>FD@<VQO=7!C
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY(@IM<V=S='(@(E!R879I9&QA('-E('5P;&%T;NT@<&]U>F4@;65Z
M:2#XX61K>2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U
M;B(*;7-G<W1R(")0<F]VZ7-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S
M<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<VOA(&9E9&5R86-E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD82(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%
M(+EI9G)O=F%N_2!P;V1P:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(E,O34E-12"Y:69R;W9A;N$@>G!RX79A(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/=NSX96[M('!O
M;6]C[2!305-,(&YE;NT@9&]S='5P;NDN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")3
M35,@>G!RX79Y(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")3
M44P@4VAE;&PB"FUS9W-T<B`B4U%,(&MO;GIO;&$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(MI34,Q#2"(*"B,Z
M(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")3
M7U%,(&MO;GIO;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")3;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")3=F%TX2!(96QE
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I
M<R(*;7-G<W1R(")3=F%T_2!+:71T<R!A($YE=FES(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB
M"FUS9W-T<B`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM
M<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E-T96IN_2!RX6T@
M*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@
M(E-A;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G
M<W1R(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O
M;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&%N9"!0<FEN8VEP
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")6;&%S=&[M:R!S871E;&ET
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R
M(")3875D<VOA($%RX6)I92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R(")5;&^^:70B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")5;&^^:70@)7,B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E5L;[YI="`E<R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*
M;7-G<W1R(")5;&^^96[M(&UOOFYO<W3M(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)5;&^^:70@=GET=F_X96[]
M(&MO;F9I9W5R8>AN[2!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!A9')E<^'X
M92!N82!S97)V97)U+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DMO;F9I9W5R86-E("5S('5L;[YE;F$N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(DMO;F9I9W5R8>AN[2!S:W)I<'0@<')O(&%K='5A;&EZ86-I(&)Y
M;"!U;&^^96X@9&\Z("<E<R<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E-C871T97)E9"!4
M+5-T;W)M<R(*;7-G<W1R(")/:F5D:6[L;.D@8F]U^&MY(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(E;L
M9&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM
M<V=S='(@(E9Y:&QE9&%T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B5GEH;&5DX79A
M8^T@;N%S=')O:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5GEB<F%T('-O=6)O<GDB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T
M"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9Y8G)A="!D871U;2(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE
M8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5GEB<F%T('-K=7!I;G4L(&MT
M97+A(&)U9&4@</AI9.%N82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6>6)R
M870@;F]VZ6AO('9L87-T;NUK82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E9Y
M8G)A="!S97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U
M-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B5GEB<F%T
M('6^:79A=&5L92P@:W1E<OT@8G5D92!P^&EDX6XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@86QL(@IM<V=S='(@(E9Y8G)A="!S;W5B;W)Y(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E9Y8G)A="!VN65C:&YY(.CA<W1I
M(&1A='5M=2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9Y
M8G)A="!O8FIE:W0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*;7-G
M<W1R(")6>6)R870@;F]VZ6AO('9L87-T;NUK82(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM
M<V=S='(@(B(*(E9Y8F5R=&4@<&]T^&5B;ND@>FYA:WD@>B!N[;YE('5V961E
M;OUC:"!B;WCY+B!0;W3I(&IE(&WYOF5T92!K;W#M<F]V870@82`B"B)V;&^^
M:70@>B!T97AT;W;I(&]B;&%S=&DN(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM
M<V=S='(@(E9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R!D871U;3HB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5GEB97)T92!F;W)MX70@9&%T=6UU
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*
M;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.B(*;7-G<W1R(")6>6)E<G1E(&ED96YT:71U+"!K=&5R;W4@<VD@</AE:F5T
M92!Z;>QN:70Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E9Y8F5R
M=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R#H87,Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(E9Y8F5R=&4@9F]R;>%T(.AA<W4Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N(@IM<V=S='(@(E9Y8F5R=&4@9';L(&]D<&]V[61A:NUC[2!P
M;VQE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B5GEB97)T92!B87)E
M=F[](&UO=&EV+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M5GEB97)T92!6X6UI('!R969E<F]V86[](&IA>GEK.B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@
M4F5P;W)T(@IM<V=S='(@(E!O<VQA="!Z<'+A=G4@;R!P<F]B;.EM=2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS
M9VED(")396YD(%--4R(*;7-G<W1R(")0;W-L870@4TU3(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(E-E;G-O<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(EKA^.TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R
M8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-R8G-K;R!A(,AE<F[A($AO
M<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM
M<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")3Z7)I;W;I(.CM<VQO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM
M<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI
M;B(*;7-G<W1R(")!9&UI;FES=')AZ&[M('!RX79A(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")3
M97-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DE$('-E:V-E('IA;FEK;&\N
M(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N
M<R(*;7-G<W1R(")?4'+A=F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B3F%S=&%V:70B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="XB"FUS9W-T<B`B3F%S=&%V:70@;6^^;F]S=&D@<')O('!O=F]L
M96[M(')E<V5T=2!H97-L82P@<&]K=60@:&\@>F%P;VUE;F5T92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"XB"FUS9W-T<B`B3F%S=&%V:70@=GIDX6QE;ND@<V5R=F5R>2!T86LL
M(+YE(&)U9&]U('#X[7-T=7!NZ2!Z('!O<G3A;'4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(DYA
M<W1A=F5N[2!6X6UI('!R969E<F]V86[I:&\@:F%Z>6MA+"#H87-O=NEH;R!P
MX7-M82!A('1Y<'4@9&%T=6UU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(DYA<W1A=F5N[2!P;^CA=&7H
M;NT@87!L:6MA8V4L(&)A<F5V;NEH;R!M;W1I=G4L(&]B;F]V;W;A;NT@<W1R
MX6YE:R!A(&1A;+GM8V@@(@HB;6^^;F]S=.T@>F]B<F%Z96[M+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@
M(DYA<W1A=F5N[2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M(@IM<V=S='(@(DYA<W1A=F]V86/M(&MO;F9I9W5R8>AN[2!S:W)I<'1Y('!R
M;R!A:W1U86QI>F%C:2!J<V]U(&1O<W1U<&[I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B3NQK=&5R
MX2!M[7-T82!L>F4@;F%S=&%V:70@<R!T[6UT;R!P87)A;65T<F5M.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H
M96QL97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED
M(")3:&]P<&EN9R(*;7-G<W1R(").86MU<&]VX6[M(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB
M"FUS9W-T<B`B2W+A=&OI('-H<FYU=.TB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B3>QL>2!B>2!B_70@</CM<W1U
M<&]VZ2!K;.WH92!D969I;F]VX6YY('!R;R!V['2Y:6YU(&]D:V%Z^3\B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B
M4VAO=R(*;7-G<W1R("):;V)R87II="(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B6F]B<F%Z:70@<F]Z9.UL>2!M97II('-O
M=>AA<VYO=2!A('#X961C:&]Z[2!K;VYF:6=U<F%C[2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(EIO8G)A>FET(.AA<R!P;W-L
M961N[6AO('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P
M(&]R:6=I;F%L(@IM<V=S='(@(EIO8G)A>FET(&UOOFYO<W0@=61ROF5N[2!O
M<FEG:6[A;'4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS
M9VED(")3:&]W('!I8VME<B(*;7-G<W1R("):;V)R87II="!S8NQR8>@B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(EIO8G)A>FET(&UE;G4@
M;W!E<F'H;NT@;&FY='4@<')O('1A8G5L:WD_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("):;V)R87II="`E<R!M96YU
M(&YA;&5V;S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:70@9&EA;&]G('!R
M;R!V;&%S=&YO<W1I(&)U;NQK('8@=&%B=6QKX6-H(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED
M(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):
M;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!T86)U;&5K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS
M9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S=.T@^.%D96L@=&%B=6QE
M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S=.T@;V)R
MX7IK^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(EIO8G)A>FET('#X96YO<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3
M:&]W97)S(@IM<V=S='(@(E#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B0G)Z:^D@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(E!O>F1N[2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6
M:6-I;FET>2(*;7-G<W1R(")0^&5HX?)K>2!V(&]K;VSM(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB
M"FUS9W-T<B`B6FUE;KEI="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O
M=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B
M6FUE;KEI="!N96)O('!O<W5N;W5T(&1O('-O=7-E9&[M:&\@8FQO:W4H^2DL
M('H@8V5S='D@<')V;NUM=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R
M82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(E)E9VES=')O=F%T('-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")0;V1P
M:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM
M<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;75S
M('!R;R!P;V1P:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B
M"FUS9W-T<B`B4VEN9V%P=7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(E9E;&EK;W-T(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@
M(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B5GEN96-H870@^F1ROF)U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F5N
M<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B
M4VQO=FEN<VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B4V[LOF5N[2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R(")3;NQH;W;A('#X96CA\FMA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")3;NQH;W;I('#X96CA\FMY(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N
M;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")286YN[2!S;NQH;W;I('#X96CA
M\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(E!O>F1N[2!S
M;NQH;W;I('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*
M;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")3;NQH;W;A('!O:W+]=FMA
M.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q
M=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")6;V1N[2!E:W9I=F%L96YT
M('!R;R!S;NUH.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES
M;&%N9',B"FUS9W-T<B`BJ6%L86UO=6YO=GD@;W-T<F]V>2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]MX6QS:V\B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B
M"FUS9W-T<B`B4.US;NP@82!BX7-N["(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S
M='(@(E-M['(@=/CM9.QN[2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R
M97-S(@IM<V=S='(@(EID<F]J;W;A(&%D<F5S82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")*:;YN[2!!9G)I:V$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DII:&]E=G)O<'-K_2`H25-/+3@X
M-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(E-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I
M9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")*:;YN[2!P;VQO:V]U
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G
M<W1R(")0<F]S=&]R(&UE>FD@<V]U<V5D;NUM:2!B=?)K86UI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@
M(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS
M9W-T<B`B4')O<W1O<B!M97II(&]B<V%H96T@82!H<F%N:6-E;6D@=B!B=?)C
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A
M8V5R(@IM<V=S='(@(DUE>F5R;NUK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM
M<V=S='(@(DUE>F5R>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B3V1S='5P>2!A(&UE>F5R>2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")3<&%I;B(*;7-G<W1R("*I<&%N[&QS:V\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#
M:&%R86-T97(@26YP=70B"FUS9W-T<B`B5G-T=7`@<')O('IV;.&Y=&[M('IN
M86MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")2;WID[&QI
M="!B=?)K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")2
M;WID[&QI="!S;&]U<&5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S
M='(@(E)O>F3L;&ET(/CA9&5K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<F0B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*
M;7-G<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T
M87)T('EE87(B"FUS9W-T<B`B4F]K('IAZ.%T:W4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O
M=FEN8V4B"FUS9W-T<B`B4W3A="#H:2!P<F]V:6YC:64B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM
M<V=S='(@(E-T878B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U
M"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")&;W)MX70@=6QOOF5N
M[2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"FUS
M9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")5;&EC92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T
M<FEK971H<F]U9V@B"FUS9W-T<B`B4/AEN6MR=&YU=/TB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G
M<W1R(")397IN86T@^&5T['IC92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(D]D<W1R86YI="!D;VWI;F]VZ2!J;>EN;R!Z(&%D<F5S>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T>6P@6T-34UTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R
M"FUS9VED(")3=2(*;7-G<W1R(").92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E!O9&%D<F5SX?@@)R5S
M)R!N96)Y;"!N86QE>F5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B4/AE
M9&WL="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*
M;7-G<W1R(")0;V1A="(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL
M('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B
M(@HB0GEL82!P;V3A;F$@ON%D;W-T(&\@</AI9.%N[2`G)7,G(&1O('-Y<W3I
M;74N($)U9&5T92!S92!M;V-I('#X:6ALX7-I="!AOB!P;R`B"B)K;&%D;NEM
M('9Y^.UZ96[M(%9AN>T@ON%D;W-T:2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS
M9W-T<B`B1&]L;NT@:6YD97@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BVG-P
M[+EN["(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(@IM<V=S='(@(B<E<R<@8GEL*&$I(/IS<.RY;NP@</AI9.%N*&$I
M(&1O('-Y<W3I;74N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(D1A
M=&$@<')O('6^:79A=&5L92`E<R!B>6QA(/IS<.RY;NP@;V1S=')A;NQN82!Z
M92!S>7-TZ6UU+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("+:<W#LN6[L
M(&]D<W1R86[L;F$@)R5S)RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@^G-P[+EN
M["!O9'-T<F%N[&XH82D@>F4@<WES=.EM=2XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N
M9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R(")+
M;VYF:6=U<F%C92!B>6QA(/IS<.RY;NP@>FWL;NQN82X@3V)N;W9T92!S='+A
M;FMU+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+:<W#LN6[I('5L;[YE;NT@
M>N%L;[YN[2!K;VYF:6=U<F%C92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B
MVG-P[+ENZ2!U;&^^96[M('KA;&]H>2!K;VYF:6=U<F'H;NUH;R!S;W5B;W)U
M("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S
M='(@(MIS<.RY;N$@86MT=6%L:7IA8V4@<')O("<E<R<B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B)7,@8GEL;R#Z<W#LN6[L('IA<'/A;F\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")3=61A;B(*;7-G<W1R(")3=63A;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U
M;6UA<GDB"FUS9W-T<B`B4VAR;G5T[2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B4W;M=.%N[2(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G
M<W1R("):X7!A9"!3;'5N8V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4VQU;F7H
M;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED
M(")3=6YR:7-E(@IM<V=S='(@(E;]8VAO9"!3;'5N8V4B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G
M:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E;]8VAO9"]ZX7!A9"!3;'5N
M8V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`B5OUC:&]D(%-L=6YC93H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM
M<V=S='(@(EKA<&%D(%-L=6YC92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(EKA<&%D(%-L
M=6YC93H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B2&]R;NT@:6YD
M97@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"FUS9VED(")3
M=7!P;W)T(@IM<V=S='(@(E!O9'!O<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM<V=S
M='(@(E#X[6IM96[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W
M87II;'-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R
M("*I=NED<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(JEV_6-A<G-K;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(DYE<VUA>F%T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM
M<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<R(*;7-G<W1R(")3>6YT87AO=N$@8VAY8F$@=B!H;&5D86[I;2!T
M97AT=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B
M;&EC(@IM<V=S='(@(E/]<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B0F]U
M^&MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4
M+5-T;W)M<R(*;7-G<W1R(")";W7X:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R
M;7,@16%R;'DB"FUS9W-T<B`B0G)Z:^D@</AE:.'R:WDB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G
M<W1R(")44U8@<V]U8F]R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H
M<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A8G5L:V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@=&%B
M=6QK>2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)U
M;&MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")6
M;&%S=&YO<W1I('1A8G5L:WDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!P<F]V:6YC:64@R.UN>2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%DOFEK
M:7-TX6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GKA;FEE+"!3<&]J96[A(')E<'5B
M;&EK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B0^UL.B(*"B,Z(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`BVFMO;'DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE
M($YU;6)E<B(*;7-G<W1R(")496QE9F]N;NT@Z.US;&\B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B
M"FUS9W-T<B`B5&5P;&]T82!Z82!P;W-L961N[2!H;V1I;G4Z("(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G
M<W1R(")497!L;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")497!L;W1A.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E
M;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E9Z;W(@)R5S)R!N
M96)Y;"!N86QE>F5N+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS
M9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")6>F]R('!R
M;R!A9&UI;FES=')A8VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B
M"FUS9W-T<B`B5&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*
M;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")0;W5Z92!T97AT(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM
M<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("):87)O=F[A;NT@=&5X='4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS
M9VED(")497AT=&]P(@IM<V=S='(@(E9R8V@@=&5X='4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*
M;7-G<W1R("+(="(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED
M(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%J<VMY("A425,M-C(P*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86IS
M:V\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H
M86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1.QK=6IE
M;64@>F$@<&]UONUVX6[M('-Y<W3I;74N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(E#X[7!O;F$@<')O($944"!N96[M(&1O
M<W1U<&[A+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B26YT
M96=R8>AN[2!A;&=O<FET;7D@=B!(;W)D92]+;VQA8B!N97!O9'!O<G5J[2!<
M(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ
M,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B(*;7-G<W1R(")0^&5N97-E;OT@<V]U8F]R(&YE;'IE
M('5L;[YI="XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G
M:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'DB"FUS9W-T<B`B3F7Z<W#LN6[I(&YAZ'1E;NT@=/CM9'D@36%I
M;G1E;F%N8V4Z.B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%
M>&ET:6YG+B(*;7-G<W1R(")">6QO('5Z87;X96YO(&]K;F\@<R!M;[YN;W-T
M;6DN(%5K;V[H96YO+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS
M9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D%D;6EN:7-T<NUT
M;W(@<&]T^&5B=6IE(&YA:V]N9FEG=7)O=F%T('1R=F%LX2!P<N%V82!V('-Y
M<W3I;74L('!O:W5D('-I("(*(G#X96IE=&4@<&]UONUT('!RX79A+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(E!O=7IE
M('-P;V1N[2!S=')A;F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B).96)Y
M;&\@=79E9&5N;R!)1"!P<F\@:V]N=&%K="P@;F5B>6QO(&YA;&5Z96YO('8@
M9&%T86+A>FD@;F5B;R!B>6QO(/IP;&[L("(*(G9Y;F5C:.%N;RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@
M(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W0@8GEL(/IS<.RY;NP@</AI
M9.%N(&1O(%9AN65H;R!A9')E<^'X92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R(")+(&]V[/AE;NT@<&]D97!S86[I('IP
M<N%V>2!J92!T^&5B82!O9&3L;&5N_2!B;&]K(',@4$=0('!O9'!I<V5M+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B
M"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(DYE8GEL;R!U=F5D96YO
M($E$(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2P@;F5B>6QO(&YA;&5Z96YO('8@
M9&%T86+A>FD@;F5B;R`B"B)B>6QO(/IP;&[L('9Y;F5C:.%N;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R(").96)Y;"!U=F5D96X@9&ES=')I8G7H;NT@<V5Z;F%M+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@
M96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN
M96-T:6]N+B(*;7-G<W1R("(B"B*I:69R;W9A8^T@;6^^;F]S=&D@;'IE('9Y
M=;[M="!P;W5Z92!P^&D@8F5Z<&7H;NEM('-P;VIE;NT@<R!W96)E;2`H:'1T
M<',I+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@;F%S=&%V96[M("5S
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM
M<V=S='(@(E-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T(&[L:W1E<N$@>B!N
M87-T879E;NT@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BXB"FUS9W-T<B`B4V]U8F]R(&YE;'IE(&MO<.UR;W9A="!SX6T@9&\@
M<V5B92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@
M(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")3;W5B;W(@
M;F5O8G-A:'5J92"^X61NX2!D871A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N(@IM<V=S='(@(D[A<VQE9'5J[2!H;&%V:>AK>2!P<F\@;65S<V%G92]R
M9F,X,C(@>G!RX79U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@
M:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L
M;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@
M86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB
M9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD
M+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@
M=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L
M;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)*92!Z;N%MZ2P@OF4@;?-D
M('#X97,@8V5L;W4@;V)R87IO=FMU('8@26YT97)N970@17AP;&]R97)U('#Y
M<V]B[2!P<F]B;.EM>2P@(@HB<')O=&^^92!S92!V(&[L;2!V>7-K>71U:F4@
M8VAY8F$L(&MT97+I('-E(&YE;'IE('9Y:&YO=70N($IA:V\@;N%S;&5D96L@
M;?F^92`B"B)B_70@;N%H;V1NZ2!Z:')O=6-E;NT@=&]H;W1O('!R;V=R86UU
M+"!C:'EB[&KM8^T@9G5N:V-E(&5D:71O<G4@;F5B;R`B"B)N97-P<N%V;ND@
M>F]B<F%Z;W;A;NTN(%!O:W5D(&IE(%;AN2!S>7-T96WI;2!7:6YO9'=S(#EX
M+"!J92!V96QM:2`B"B)P<F%V9.QP;V1O8F[I+""^92!S92!O8FIE=NT@8VAY
M8F]VZ2!H;.&Y96[M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&$@(@HB
M8G5D971E(&UU<V5T(')E<W1A<G1O=F%T('!OZ.UT8>@N7%QN7%QN0GEL:2!J
M<W1E('9A<F]VX6YI+B!0<F]S[6T@<W1I<VMN['1E("(*(D]+('!O:W5D('-I
M('#X96IE=&4@<&]K<F'H;W9A="!V(&WS9'4@</AE<R!C96QO=2!O8G)A>F]V
M:W4N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B261E;G1I=&$@7"(E<UPB(&)Y;&$@<VUA>N%N82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V
M"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")0;W5Z
M92!N82!L97;I('-T<F%N["(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N(@IM<V=S='(@(E5M[7-T[&[M(&)I;N%R;NUH;R!S;W5B;W)U($=N=5!'
M(&UU<^T@8OUT('IA9.%N;R!D;R!T^.UD>2!#<GEP=%]P9W`Z.BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB6G!RX79A('IA<VQA;N$@=B`E
M<R!K("5S(',@</AE9&WL=&5M(%PB)7-<(B!B>6QA('IO8G)A>F5N82Y<;B(*
M(E1O=&\@;F5Z87)UZ'5J92P@OF4@>G!RX79A(&)Y;&$@</AEZ'1E;F$@;F5B
M;R"^92!J[2!A9')E<^%T*&MA*2!R;WIU;>QL*&$I+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R(").X7IE
M=BP@:W1E<OT@8G5D92!P;W6^:70@</AI(&]D:V%Z;W;A;NT@;F$@<W1RX6YC
M92!T=F]R8GD@>G!RX78B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B5&]T;R!P;VQE(&UU<^T@8OUT('!L
M871NZ2#H[7-L;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@
M(E3X[61A($AO<F1E7T-R>7!T7W-M:6UE.CH@=GF^861U:F4@;6]D=6P@;W!E
M;G-S;"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3F5L>F4@
M=6QOOFET(&YA<W1A=F5N[2!<(B5S7"(L('!R;W1OOF4@:F5H;R!V96QI:V]S
M="!P^&5SX6AL82!P;W9O;&5N_2!L:6UI="XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@
M(DYE8GEL82!N86QE>F5N82!A<&QI:V%C92!P<F\@Z'1E;NT@=&]H;W1O('1Y
M<'4@9&%T("@E<RDN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R
M:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(E!O=7IE(&YA('!R
M87;I(&$@;&5VZ2!S=')A;NPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F$@<')A=ND@<W1R86[L(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@
M<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(E-E<G9E<B!<(B5S7"(@8GEL('9Y;6%ZX6XN(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(E-E<G9E<B!<(B5S7"(@8GEL('5L;[YE;BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")">6QA
M(&]D<W1R86[L;F$@ON%D;W-T(&\@</AI:&SAN65N[2!P<F\@)7,N(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B4&^^
M861O=F%N_2#XX61E:R!N965X:7-T=6IE+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1O
MZ&%S;OT@<V]U8F]R(%PB)7-<(B!N965X:7-T=6IE+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E
M<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F%H;_AE(&$@9&]L92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G
M:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E!O=7IE(&YA:&_X92(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M(@IM<V=S='(@(EIT<F%T:6QA('-E('#X96YE<V5NX2!D871A('H@</AE9&-H
M;WKM:&\@:W)O:W4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP
M.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@
M(E#X96YE<V5N_2!S;W5B;W(@;F5L>F4@=6QOOFET+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A
M=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B0FQO
M:R!W96%T:&5R+F-O;2!N96[M(&1O<W1U<&[]+B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").96)Y
M;"!N86QE>F5N(&%D<F5SX?@@<R!TZ6UA='D@)R5S)RXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("*NX61NZ2!Z(&UOOFYO<W3M
M(&YE:G-O=2!D;W-T=7!NZ2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(").96)Y;'D@;F%L
M97IE;GD@ON%D;ND@Z.%S=&DL(&MT97+I(&)Y(&)Y;&\@;6^^;F\@>F]B<F%Z
M:70@=B#XX61K=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*
M;7-G<W1R("(B"B)0^.UL:;D@;6YO:&\@>FYA:_D@=B!P;VQI+B!:861A;&D@
M:G-T92`E<R!Z;F%K^3L@;75S[71E('IA9&%T(&WI;NP@;F6^("5S("(*(GIN
M86OY+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(").87-T
M86QA(&-H>6)A('#X:2!P^&EDX7;A;NT@)R5S)R!D;R!S>7-TZ6UU.B`E<R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(").87-T86QA
M(&-H>6)A('#X:2!O9'-T<F'R;W;A;NT@=;YI=F%T96QS:_UC:"!D870@)R5S
M)R!Z92!S>7-TZ6UU.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M
M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DYA<W1A
M;&$@8VAY8F$@</AI(&]D<W1R8?)O=N%N[2`G)7,G('IE('-Y<W3I;74Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&%K='5A;&EZ86-I("<E<R<Z
M("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B
M3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U.B`E<R!N96)Y;"!P
M^&5N97-E;BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS
M9W-T<B`B(@HB3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U+B`E
M<R!N96WYOF4@8OUT(';L=+GM(&YEOB!M87AI;>%L;NT@(@HB<&]V;VQE;N$@
M=F5L:6MO<W0@*"5D(&)Y=/DI+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R(").87-T86QA(&-H
M>6)A('#X:2!P^&5N;W-U('-O=6)O<G4Z(&)Y;&$@</AE;F5S96YA(&IE;B#H
MX7-T('-O=6)O<G4@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B1&^Y;&\@:R!C
M:'EB["!P^&D@>F]B<F%Z;W;A;NT@=.ET;R#HX7-T:2!Z<'+A=GDB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&EM<&]R=&]VX6[M(&MO;G1A
M:W1U+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N(@IM<V=S='(@(E#X:2!I;7!O<G1O=N%N[2!I0V%L96YD87(@9&%T
M(&1ON6QO(&L@8VAY8NPN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX
M,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER
M960@9FEE;&0N(@IM<V=S='(@(B(*(D-H>6)A('8@:V]N9FEG=7)AZ&[M;2!F
M;W)M=6SA^&DN(%KX96IM["!J<W1E('9Y;F5C:&%L:2!P;[YA9&]V86[I('!O
M;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B).87-T86QA(&-H
M>6)A('#X:2!P<F]VX63L;NT@>F%D86[I(&]P97)A8V4@=B!A9')E<^'X:2X@
M4')O<^UM('IK=7-T92!T;R`B"B)P;WID[&II+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL
M<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P^&D@86MT=6%L:7IA8VD@:V]N=&%K='4N(%!R;W/M;2!Z:W5S=&4@
M=&\@<&]Z9.QJ:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@HB3F%S=&%L82!C:'EB82!P^&D@86MT=6%L
M:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+B!0<F]S[6T@>FMU<W1E('1O
M("(*(G!O>F3L:FDN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")496YT;R!)34%0
M('-E<G9E<B!N97!O9'!O<G5J92!S9.UL96[M('-L;[YE:RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*
M;7-G<W1R(")4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[](')A<B!A<F-H:78N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`B5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!Z:7`@
M<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+B(*;7-G<W1R(")4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[I(.CM<VQO
M(&MA<G1Y+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T
M<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@HB5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M
M;.%N[2!Z<'+A=B!P;VUO8^T@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN(@HB8V]M*2!B<N%N>2!P^&D@<&]UOFET[2!(5%10($%022(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"B,L(&9U>GIY
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&5N=&\@
M;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO8^T@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+B(*(F-O;2D@8G+A;GD@</AI('!O=;YI
M=.T@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*(E1E;G1O(&]V;&%D8>@@=6UOOO)U:F4@<&]S
M[6SA;NT@>G!RX78@<&]M;V/M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I
M;"XB"B)C;VTI(&)RX6YY('#X:2!P;W6^:73M($A45%`@05!)(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(E1E;G1O(&]V;&%D8>@@=6UO
MOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M(%--5%`@9&\@5F]D869O;F4@
M271A;'D@8G+A;GD@(@HB<&]U>F4@<')O(.CM<VQA('!O<VMY=&YU=.D@5F]D
M869O;F5M+B!-=7/M=&4@;>UT(&5M86EL;W;](/KH970@=2!6;V1A9F]N92`B
M"B))=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G
M:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(E1O=&\@<&]L
M92!J92!N=71NZ2!V>7!L;FET+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RXB"FUS9W-T<B`B5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O
M=7IE(&-E;.$@Z.US;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B5&]T;R!P;VQE(&WYOF4@;V)S
M86AO=F%T('!O=7IE(&-E;.$@Z.US;&$@82!D=F]J=&7H:W4N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B5&]T;R!P
M;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&]S;6GH:V]VZ2#H[7-L82XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R(")4;W1O('!O;&4@;75S[2!B_70@<V5Z;F%M
M(&-E;/UC:"#H[7-E;"!O9&3L;&5N_6-H(.CA<FMO=2!N96)O(&UE>F5R;W4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B5&]T;R!P
M;VQE(&UU<^T@8OUT('!L871NZ2#H[7-L;RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N
M=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@
M97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(E1O=&\@<&]L92!M
M=7/M('!B<V%H;W9A="!B87)E=F[](&OS9"!V(+EE<W1NX6-K;W;I;2!21T(@
M9F]R;>%T=2P@;F%P^"X@(@HB)R,Q,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")496YT;R!F;W)M=6SA^"!J:;X@
M8GEL('IP<F%C;W;A;BXB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")4
M;W1O(&IE("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)4;W1O
M(&IE(&]B:F5K="!+;VQA8B!'<F]U<'=A<G4N($L@>FALZ61N=73M('1O:&]T
M;R!O8FIE:W1U(&IE('IA<&]T^&5B[2!M[70@(@HB<&^Y=&]V;NUH;R!K;&EE
M;G1A+"!K=&5R_2!R;WIU;>T@9F]R;>%T=2!+;VQA8B!'<F]U<'=A<G4N(%!R
M;R!S97IN86T@(@HB=&%K;W;]8V@@:VQI96YT^2!P<F]S[6T@;F%VN71I=G1E
M("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+B(*;7-G<W1R(")4871O('IP<N%V82!B>6QA(&YA<'/A;F$@=B!J:6[I('IN
M86MO=ND@<V%D["`H)7,I(&YEOB!68;GM+B`B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(E1O=&\@Z.US;&\@;75S[2!B_70@
M;F5J;>EN["!J961N82XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")397)V97(@;F5M
M^;YE(')O>F)A;&ET('II<"!A(&=Z:7`@<V]U8F]R>2XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")496YT
M;R!S>7-TZ6T@:F4@=B!S;W7H87-N;W-T:2!D96%K=&EV;W9A;OTN(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B5&%T;R!H;V1N;W1A
M(&UU<^T@8OUT(.CM<VQO+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B5&]T;R!O:VYO(&UU
MOF4@8OUT('9O;.%N;R!P;W5Z92!Z(&]K;F$@;6^^;F]S=.TB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU
M;F1E<B(*;7-G<W1R(")(^&WL;NTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(DSM<W1K>2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(LAA<R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A
M8VMI;F<B"FUS9W-T<B`B4VQE9&]VX6[M(.AA<W4B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O<FWA
M="#H87-U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I
M9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B5OUB['(@Z&%S=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE
M<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS
M9W-T<B`B5&ET=6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@
M(E1I='5L("AT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(DMO;74B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L
M:6-K:6YG+B(*;7-G<W1R("(B"B)0;VMU9"!S:2!P^&5J971E('9Y8G)A="!V
M[6-E('!O;&^^96LL('IMX>AK;NQT92!K;.%V97-U($-O;G1R;VP@*%!#*2!N
M96)O("(*(D-O;6UA;F0@*$UA8RD@82!K;&EK;NQT92!N82!P;VQOOFMU+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O
M9&%Y(@IM<V=S='(@(D1N97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B
M"FUS9W-T<B`B4/AE<&YO=70@;F$@2%1-3"!Z9')O:B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S
M='(@(EKM=')A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T
M<B`B5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")6<F-H(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")(;W)N[2!RX6T@*%]T;W`I
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA
M=&EO;G,B"FUS9W-T<B`B4/AE:VQA9'DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D(&$@5&]B
M86=O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B
M5')U92!O<B!F86QS92(*;7-G<W1R(")3<'+A=F[L(&YE8F\@N7!A=&[L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`BVG0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=6YI<VEA(@IM<V=S='(@(E1U;FES:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4=7)K97DB"FUS9W-T<B`B5'5R96-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R
M(")4=7)E8VMY("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-TX6XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T
M<B`B5'5R:W,@82!#86EC;W,@;W-T<F]V>2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T
M<B`B3F%P:;ET92!68;EI('9O;&)U.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R(")5
M+E8N(&EN9&5X.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")5
M4DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@<')O('IP
M<N%V=2!O('-T879U('IA<VQA;NEH;R!S:W)I<'1U(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*
M;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM
M<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B
M"FUS9W-T<B`B56MR86II;F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B5D93(&%D<F5SX?@@:F4@;F5P^.US='5P;OTN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B
M;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG
M('5P+B(*;7-G<W1R(")0^&D@<F5G:7-T<F%C:2!N96QZ92!P^&ED870@97AT
M<F$@=;YI=F%T96QS:^D@^F1A:F4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DYE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B3F5L>F4@>FWL;FET('!RX79A('!R;R!61E,@<V]U8F]R("5S
M+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S
M='(@(DYE;'IE('IM[&YI="!N82`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(DYE
M;'IE('#X97-U;F]U="!61E,@<V]U8F]R(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX
M,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(").96QZ92!P^&5J
M;65N;W9A="!61E,@<V]U8F]R("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET(&L@4U%,
M('-E<G9E<G4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(").
M96QZ92!S92!P^&EP;VII="!P;VUO8^T@4U-,+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!K;W#M<F]V870@5D93('-O
M=6)O<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R(").96QZ92!V>71V;_AI="!61E,@861R97/A
M^"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").96QZ92!V>71V;_AI="!6
M1E,@861R97/A^"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R
M(").96QZ92!V>71V;_AI="!61E,@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M(").96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DYE;'IE('9Y='9O
M^&ET('!RX7ID;OT@5D93('-O=6)O<BXB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N(@IM<V=S='(@(DYE;'IE(')O>F)A;&ET(&1A=&$N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*
M;7-G<W1R(").96QZ92!V>6UA>F%T(%PB)7-<(BP@<')O=&^^92!A9')E<^'X
M(&YE;NT@<'+A>F1N_2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B3F5L
M>F4@=GEM87IA="`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@)7,L('!R;W1OOF4@861R97/A^"!N
M96[M('!RX7ID;OTN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN(@IM<V=S='(@(DYE;'IE(')E:W5R>FEV["!O9'-T<F%N:70@5D93(&%D
M<F5SX?@N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F5L>F4@=GEM87IA="!61E,@861R97/A^"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").96QZ92!V>6UA>F%T(%9&4R!A
M9')E<^'X.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!61E,@<V]U8F]R
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!V>6UA>F%T(%9&4R!S;W5B
M;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@5D93('-O=6)O
M<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+B(*;7-G<W1R(").96QZ92!R96MU<GII=F[L(&]D<W1R
M86YI="!61E,Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#`S"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+B(*;7-G<W1R(").96QZ92!U<NAI="!A:W1UX6QN[2!A9')E<^'X+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED
M(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S
M='(@(DYE;'IE('IJ:7-T:70@<&]D<F]B;F]S=&D@;R!C97)T:69I:^%T=2XB
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R
M:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`B1&5F:6YI8V4@)7,@;F5N[2!D;W-T=7!NX2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYE;'IE('#X97-U
M;F]U="!61E,@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('#X97-U;F]U="!61E,@
M<V]U8F]R(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B5D93
M('-O=6)O<B!N96QZ92!O=&5V^.UT('!R;R!ZX7!I<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3F5L
M>F4@;W1E=OCM="!61E,@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3F5L>F4@;W1E=OCM="!A<F-H
M:79O=F%N_2!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S
M-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5L>F4@>F%P<V%T(&1A=&$@
M9&\@5D93('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R
M(").96QZ92!Z87!S870@9&%T82!D;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C
M;W!Y*"DI+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(')E860@9FEL93H@(@IM<V=S='(@(DYE;'IE('#X96IM96YO=F%T(%9&4R!S
M;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM
M<V=S='(@(DYE;'IE(.CM<W0@>B!V9G-R;V]T(&%D<F5SX?AE+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B3F5L>F4@</AE:FUE;F]V
M870@)7,@;F$@)7,Z(&/M;&]VX2!S;&^^:V$@:FF^(&5X:7-T=6IE(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@861R
M97/A^"!N96QZ92!P^&5J;65N;W9A="XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")61E,@861R97/A
M^"!N96QZ92!P^&5J;65N;W9A=#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B
M;W(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q
M,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(DYE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(@)7,O)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B3F5L>F4@</AE
M:FUE;F]V870@5D93('-O=6)O<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T
M;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(").96QZ92!P<F]VZ7-T("=M:VES
M;V9S)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N="(*;7-G<W1R(")496YT;R!D;VMU;65N="!7;W)D(&YE;'IE('#X
M96QOOFET(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3F5L>F4@>F%P<V%T(&1O(%9&4R!S;W5B;W)U(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DYE;'IE
M('IA<'-A="!D871A(&1O(%9&4R!S;W5B;W)U("AS96QH86QO(&-O<'DH*2DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N(@IM<V=S='(@(DYE;'IE('IA<'-A="!D871A(&1O(%9&
M4R!S;W5B;W)U(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(").96QZ92!Z87!S870@9&%T82!D
M;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C;W!Y*"DI+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R
M;&EN92(*;7-G<W1R(")0;V1T<FAN=73I(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(E-T;W)N
M;R!Z;>QN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B4W1O<FYO=F%T('!O<VQE;NT@86MC:2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(DYE
M;^AE:^%V86[A(&]D<&]V[.\@<V5R=F5R=2!N82!S<&]J96[M.B`B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(").96_H
M96OA=F%NX2!O9'!O=NSO('-E<G9E<G4Z("(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D
M(@IM<V=S='(@(DYE=GEP;&[L;F\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@
M*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER
M871E<R(*;7-G<W1R(")3<&]J96[I($%R86)S:^D@16UI<N%T>2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B5F5L:^$@
M0G)I=.%N:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M(@IM<V=S='(@(E-P;VIE;ND@4W3A='D@06UE<FEC:^DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',B"FUS9W-T<B`B4W!O:F5NZ2!3=.%T>2!-96ZY:6YO=OUC:"!O<W1R;W;Y
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(DIE9&YO=&MY
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*
M;7-G<W1R(").97INX6WI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(DYE>F[A;>D@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B3F5Z;N%MZ2!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(DYE8GEL;R!V>6)RX6YO(+[A9&[I
M(&WM<W1O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B3F5Z;N%MZ2!UOFEV871E;'-KZ2!J;>EN;R!N96)O
M(&AE<VQO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`B3V1P;VII="!S;W7H87-N_2!P<G9E:R(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA
M;65D(@IM<V=S='(@(D)E>F4@:FWI;F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(DYE<')I=FEL96=O=F%NZ2!S
M:W)I<'1Y(&YE;6]H;W4@=GEUONUV870@9G5N:V-A(%9Y:FUO=70O2V]P[7)O
M=F%T+U9L;[X@>B`B"B)B97IP9>AN;W-T;NUC:"!D^79O9/DN($ML:6MN['1E
M(&YA($]+(&%B>7-T92!V:63L;&D@=&5C:&YI8VMO=2!Z<'+A=G4@>B`B"B)M
M;WII;&QA+F]R9RP@:W1E<N$@=GES=NQT;'5J92P@:F%K(&YA<W1A=FET('-K
M<FEP="!P<F\@</CM<W1U<"!K92!S8VARX6YC92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5
M;G-E="!C;VQO<B(*;7-G<W1R(").96YA<W1A=F5NX2!B87)V82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I
M;VXB"FUS9W-T<B`B3F5P;V1P;W)O=F%NX2!P^.UP;VYA(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")!:W1U86QI
M>F]V870B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")!:W1U
M86QI>F]V870@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")!:W1U86QI>F]V
M870@=;YI=F%T96QE(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB
M+B(*;7-G<W1R(")!:W1U86QI>F]VX6YY("<E<R<N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N(@IM<V=S='(@(E-K<FEP="!P<F\@86MT=6%L:7IA8VD@8GEL('9Y;6%Z
MX6XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B4/AE;F]S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N(@IM<V=S='(@(E:Y96-H;GD@<V]U8F]R>2!P<F\@
M;F%S=&%V96[M(&%P;&EK86/M(&)Y;'D@</AE;F5S96YY(&YA('-E<G9E<BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(E9E;&OA('1I<VMA8^T@<.US;65N82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B5F5L:^D@^.UM<VOI(.CM<VQI8V4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U
M87DB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B
M"FUS9W-T<B`B4&]UONUT(&%K='7A;&[M.B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@
M4U-,(@IM<V=S='(@(E!O=;[M="!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")0;W6^[70@<&]K=60@
M:FWI;F\O:&5S;&\@:G-O=2!J:6[I(&YEOB!P<F\@24U34"!S97)V97(N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B57-E<B(*;7-G<W1R(")5OFEV871E;.DB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS
M9W-T<B`B5;YI=F%T96P@)7,@;F5N[2!O<'+A=F[L;B!K('!O=;[M=N%N[2`E
M<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-E('6^:79A=&5L^2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`B5;YI=F%T96QS:^D@;6^^;F]S=&DB"@HC.B!S
M:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R
M(")296=I<W1R86-E('6^:79A=&5L^2(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(DYA('1O;71O('-E<G9E<G4@;F5N[2!M;[YN
MX2!R96=I<W1R86-E('6^:79A=&5L^2XB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O
M=6YD(@IM<V=S='(@(B5S(&YE8GEL;R!N86QE>F5N;RXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5OFEV871E;'-K
MZ2!J;>EN;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ
M,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<
M(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B5;YI=F%T96QS:^D@:FWI;F\@
M)R5S)R!J:;X@97AI<W1U:F4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B5;YI=F%T96QS
M:^D@:FWI;F\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM
M<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5OFEV871E;'-KZ2!J;>EN;SH@
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B
M57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B4V5Z;F%M('6^:79A=&5L
M^3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@
M(E5Z8F5K:7-TX6XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")61E,@861R97/A
M^"!N965X:7-T=6IE+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D1O=F]L96[A(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(DYA;&5Z96[A('!L871NX2!M
M[7-T82!Z86AR;G5J[3H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E!L871N;W-T
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*
M;7-G<W1R(")(;V1N;W1A('8@;6EN=73A8V@N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(DAO9&YO='DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O
M;2(*;7-G<W1R(")6>6)R86[I(&AO9&YO='D@>B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S
M='(@(E!R;VWL;F[I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA
M(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@
M=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS
M9W-T<B`B4V5L:&%L82!V97)I9FEK86-E("T@=&%T;R!Z<'+A=F$@;6]H;&$@
M8OUT('IF86RY;W;A;F$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R>F4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N
M($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;B!#;VYT<F]L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B5F5R=&EKX6QN[2!Z87)O=F[A
M;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(E9E<G1I:^%L
M;NT@;V1S='5P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:^%L
M;NTZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")696QM:2!V>7-O:^$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE
M<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;7-K>2`H5DE30TE)*2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(EIO8G)A>FET("5S(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G92(*;7-G<W1R("):;V)R87II="!E>'1E<F[M('=E8G-T
M<N%N:W4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("):
M;V)R87II="!J86MO("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B4&%N;F5N<VOI($]S=')O=GDL
M($)R:71S:^DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD
M<RP@52Y3+B(*;7-G<W1R(")086YN96YS:^D@3W-T<F]V>2P@52Y3+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM
M<V=S='(@(E9I9&ET96QN;W-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E9I9&ET
M96QN;W-T.B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!P^&5S(%--5%`B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(E503UI/4DY)5"(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+B(*;7-G<W1R(")54$]:3U).S$[-(2$A($]$4U120=)412!32U))4%0@4E7(
M3LP@6B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@
M(G-M<S)E;6%I;"!Z82!P;W6^:73M($A45%`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@86YD($9U
M='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX
M,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")5<&]Z;W)N[&[M(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B
M5V4B"FUS9W-T<B`B4W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B4/AE9'!O
M=NSO('!OZ&%S[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")$
M871A(&\@<&_H87/M('!O<VMY='5J92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE
M<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B
M(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8B!S97)V97(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED
M(")7965K;'DB"FUS9W-T<B`B5/UD;NPB"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")6[71E:G1E
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O
M;64@=&\@)7,B"FUS9W-T<B`B5NUT96IT92!V("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@
M(E;M=&5J=&4L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G
M:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(EKA<&%D;NT@*$E3
M3RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@
M(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("):X7!A9&[M("A)4T\M
M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B
M"FUS9W-T<B`B6N%P861N[2!386AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(DMT
M97)O=2!A<&QI:V%C:2!MX2`E<R!Z;V)R87II="!P;R!P^&EH;.&Y96[M(&1O
M('-Y<W3I;74_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*
M;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S
M='(@(DIA:_T@:F4@;V1D[&QO=F%C[2!Z;F%K/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_(@IM<V=S='(@(DIA:_T@:F4@>FYA:R!P<F\@8VET86-I/R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q
M"B,L(&9U>GIY"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T
M<B`B075S='+A;&EE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED
M(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2W1E<ND@9N%Z92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B5F]L
M8F$@<F]ZN>WX96[M('!R;R!2:6-H(%1E>'0@961I=&]R+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G
M:60@(E=I9'1H(@IM<V=S='(@(JGM^&MA(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S
M='(@(JGM^&MA('8@0U-3(&IE9&YO=&OA8V@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R("*I[?AK82`E<R!M96YU('9L979O("AZ;>QN82!S
M92!O8FIE=NT@</AI(&1A;+GM;2!P^&EH;.&Y96[M*3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED
M=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(JGM^&MA('1A8G5L:WDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I
M9"`B5VED=&@@=6YI="(*;7-G<W1R(")*961N;W1K82"Y[?AK>2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED
M(")7:61T:#HB"FUS9W-T<B`BJ>WX:V$Z(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R
M(")6[71R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B4F%N;NT@=NUT<B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B4GEC:&QO<W0@=NQT<G4@=B!U>FQE8V@B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T
M<B`B5NUT<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R
M"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5NUT<CH@(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B36]U9')O
M<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"B,L(&9U>GIY
M"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")397IN86T@</CA;NTB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B
M4'+A8V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<V$@9&\@
M>F%M['-T;N%N[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O
M;B!D;R!Z86WL<W1NX6[M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S
M970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")6>71V
M;_AE;NT@5D93('-O=6)O<G4@;F5B>6QO('!O=F]L96YO+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@
M(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8
M-3`Y=C,@>N%K;&%D;NT@;VUE>F5N[2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y
M(%5S86=E(@IM<V=S='(@(E@U,#EV,R!R;WJY[?AE;ND@<&]UOFET[2!K;.WH
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@
M(E@U,#EV,R!A;'1E<FYA=&EV;NT@:FWI;F\@;W-O8GDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S(&ED96YT:69I
M:^%T;W(@:VSMZ&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P
M.78S(')O>KGM^&5N[2(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")962(*;7-G<W1R(")24B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*;7-G<W1R(")24E)2(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*
M;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B36%P82!986AO;R$B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B4F_H;NPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")996UE;B(*;7-G<W1R(")*96UE;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R(")!
M;F\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(D%N;RP@<V]U:&QA
M<^UM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\
M/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@
M(B(*(DIS=&4@=B!415A43U;)32!-TT15+B!0;W6^:6IT92!;/#Y=('1L8>CM
M=&MA(&L@>G#L=&[I;74@</AE<&YU=.T@9&\@5UE325=91RXB"@HC.B!S97)V
M:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L
M;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G
M<W1R(").96)Y;&D@:G-T92!S<'+A=F[L(&]V[/AE;FDN(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@
M;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE
M+B(*;7-G<W1R("):;F%K("=<7"<@;F5M^;YE(&+]="!S;W7HX7-T[2!68;EE
M:&\@:FWI;F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(D)Y;&$@
M>F%DX6YA(&YE<&QA=&[A(&4M;6%I;&]VX2!A9')E<V$N(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@
M9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM
M<V=S='(@(B(*(DYE;6%P;W9A;&D@:G-T92"^X61NX2!P;VQE('H@:6UP;W)T
M;W9A;NEH;R!S;W5B;W)U(&L@;V1P;W;M9&%J[6/M;2!P;VSM;2!V("4B"B)S
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")">6QI(&IS=&4@;V1H
M;.&Y96YI('IE('-Y<W3I;74N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M(@IM<V=S='(@(B(*(E9L;[YT92#H[7-L;R!M;V)I;&[M:&\@=&5L969O;G4L
M('!O=;YI:G1E(&IE;B#H[7-L:6,@;F5B;R!P^.UP861N["`G*R<@<')O("(*
M(FUE>FENX7)O9&[M(.AI<VQA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N(@IM<V=S='(@(DUU<^UT92!Z861A="!P;&%T;F]U(&AO9&YO='4N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+B(*;7-G<W1R("(B"B)-=7/M=&4@:V]N9FEG=7)O=F%T(&1A=&%B
MX7II(&1A="P@<&]K=60@<VD@</AE:F5T92!P;W6^[79A="!296=I<W1R86-E
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B375S
M[71E(&MO;F9I9W5R;W9A="!61E,@8F%C:V5N9"XB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N(@IM<V=S='(@(DUU<^UT92!N96ID^.UV92!P;W!S870@<')O
M8FSI;2!A('!O=.D@:&\@;V1E<VQA="XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B
M375S[71E('IA9&%T(%523"!N82!K=&5RZ2!B=61E('1E;G1O(&]D:V%Z('5K
M87IO=F%T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB
M"FUS9W-T<B`B375S[71E('9Y8G)A="!S97)V97(L(&MT97+](&)U9&4@<VUA
M>N%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B375S
M[71E('9Y8G)A="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!S;6%Z
MX6YO+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B375S[71E
M('IA9&%T('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E(&]D<W1R86[L
M;F\N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DYE=79E9&QI(&IS=&4@=;YI=F%T
M96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@</AI9.%N;RXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92XB"FUS9W-T<B`B3F5U=F5D;&D@:G-T92!UOFEV871E
M;'-KZ2!J;>EN;R!P<F\@86MT=6%L:7IA8VDN(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DUU<^UT
M92!Z861A="!A:V-I+"!K=&5RX2!B=61E('!R;W9E9&5N82XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I
M9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R
M(")-=7/M=&4@>F%D870@:FWI;F\@;F]VZ2!K871E9V]R:64N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*
M;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")68;EE("5S
M(')E;&%C92!B>6QA('5K;V[H96YA+B!/<.QT('-E('#X:6AL8;ET92P@<')O
M<^UM+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS
M9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B5F&Y92!E;6%I;&]V
MX2!A9')E<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED
M(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E9AN64@3V0M:V]H;SH@
M861R97-A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")68;EE(&EN9F]R;6%C92(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E8@
M<F5L86-I("5S('-E('IM[&YI;&$@5F&Y92!I;G1E<FYE=&]VX2!A9')E<V$N
M(%H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y('-E("(*(FUU<^UT92!O<.QT('#X
M:6ALX7-I="XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E9AN64@:FWI;F\B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T
M<B`B(@HB5N&Y(&]V[/AO=F%C[2!S>7-TZ6T@;F5P;V1P;W)U:F4@</AI9.%V
MX6[M('6^:79A=&5L^2!A;F5B;R!T871O(&UOOFYO<W0@;F5N[2`B"B)P^.US
M='5P;N$@>B!J:6[]8V@@9/EV;V3Y+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+B(*;7-G<W1R("(B"B)6X;D@;W;L^&]V86/M('-Y<W3I;2!N
M97!O9'!O<G5J92!V_7!I<R!UOFEV871E;/D@86YE8F\@=&%T;R!M;[YN;W-T
M(&YE;NT@(@HB</CM<W1U<&[A('H@:FEN_6-H(&3Y=F]D^2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B):9.$@<V4L(+YE('8@<'+Y8NQH=2!R96QA8V4@)7,@<V4@>FWL
M;FEL(%;AN2!P<F]H;.V^9>@N(%H@8F5Z<&7H;F]S=&[M8V@@(@HB9/EV;V3Y
M('-E(&UU<^UT92!O<.QT('#X:6ALX7-I="XB"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")6X;D@<')O:&SMOF7H(&YE<&]D
M<&]R=6IE('1U=&\@;6^^;F]S="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(E;A
MN2!P<F]H;.V^9>@@;F5U;6^^\G5J92!T:7-K('3M;71O('IP^7-O8F5M+B!0
M<F]V961E;NUM('-T:7-K;G5T[2!#=')L+R(*(D]P=&EO;B`K(%`@<W!U<W3M
M=&4@=&ES:RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED
M(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")68;EE('-O=>AA
M<V[I(.AA<V]VZ2!PX7-M;SHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E
M;B!C:&%N9V5D+B(*;7-G<W1R(")68;EE(&EM<&QI8VET;NT@:61E;G1I=&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E9AN64@:6UP;&EC:71N[2!I9&5N
M=&ET82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*;7-G:60@(EEO
M=7(@9G5L;"!N86UE.B(*;7-G<W1R(")68;EE(/IP;&[I(&IMZ6YO.B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(E9AN64@;F%S=&%V
M96[M(&)Y;&\@86MT=6%L:7IO=N%N;RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E9AN64@;F]VZ2!H97-L
M;R!P<F\@)7,@:F4Z("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B
M5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI>F]VX6YO('!R;R!T<G;A;NT@
M=.ET;R!R96QA8V4N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB
M"FUS9W-T<B`B5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI>F]VX6YO+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E9AN64@:&5S;&\@
M8GEL;R!R97-E=&]VX6YO+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B
M"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB5F&Y92!H97-L;R!B>6QO(')E<V5T
M;W;A;F\L('IK;VYT<F]L=6IT92!S:2!Z<'+A=GD@96QE:W1R;VYI8VOI('!O
MN71Y(&$@(@HB</AI:&QAN71E('-E(',@5F&Y[6T@;F]V_6T@:&5S;&5M+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B5F&Y92!H
M97-L;R!B>6QO(')E<V5T;W;A;F\N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G
M<W1R(")68;EE('9Z9.%L96[I('-E<G9E<GDZ(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<VSA=FEE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I
M<F4B"FUS9W-T<B`B6F%I<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I
M82(*;7-G<W1R("):86UB:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB
M86)W92(*;7-G<W1R(")::6UB86)V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R
M"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6U5K<OUT(&-I
M=&]V86[]('1E>'1=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G
M:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6TALX;EE;NT@<')O8FSI
M;75=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6UIO8G)A
M>FET(&-I=&]V86[]('1E>'0@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T
M<B`B6UIO8G)A>FET(&-I=&]V86[]('1E>'0@+2`E<R#XX61K^5TB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6_CA9&5K("5S('H@)7-=
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")?061M:6YI<W1R86-E(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]3;6%Z870@^.%D96LB"@HC
M.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7U-K
M=7!I;GDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U
M"FUS9VED(")?2&5L<"(*;7-G<W1R(")?3N%P;W;L9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G
M:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]6;&%S=&YO<W1I
M(&]B<N%Z:W4N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]0^&EH;.&Y96[M(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B
M7TQO9R!O=70B"FUS9W-T<B`B7T]D:&SAN65N[2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B
M7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]-;V1I9FEK;W9A="!O9&MA>BXN
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G
M:60@(E]/<'1I;VYS(@IM<V=S='(@(E]-;[YN;W-T:2(*"B,Z(&QI8B]A<&DN
M<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]0<N%V82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]/9'-T
M<F%N:70@;V1K87HN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3
M971U<"(*;7-G<W1R(")?3F%S=&%V96[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B
M;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?5FQA<W1N;W-T:2!T86)U;&MY
M+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T
M<B`B7U6^:79A=&5LZ2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(Q"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97/A^"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"B,L(&9U>GIY
M"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")A9')E<^'X(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(FMA;&5N9.'X(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B8V%L;2(*;7-G<W1R(")B97IV['3X[2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B:VQI:VYO=70@>F1E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G
M:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM
M<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")2;WID[6QY('8@
M;F%S=&%V96[M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS
M9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B;F5N86QE>F5N;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED
M(")F86QL:6YG(@IM<V=S='(@(G-RX;YK>2(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R(")S;W5B
M;W(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@
M(GH@)7,@*"5S*2!R>6-H;&]S=.T@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(BP@;N%R87IO=OT@)7,@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R(")H
M.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")O
M:V%MOFET["(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B=B#X863L
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G
M:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@
M<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R
M("+XX61K^5TB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F
M<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(F-H
M>6)O=OT@:_-D(&UK:7-O9G,@)60@</AI('9Y=';A^&5N[2!)4T\N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I
M9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM
M<V=S='(@(FIMZ6YO(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM
M<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYE;NT@:6UP;&5M96YT
M;W;A;F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B;F5N[2!D
M;W-U9"!I;7!L96UE;G1O=N%N;R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(GKA<&ES;NUK(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P<F]C96YT(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E!RX79A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM
M<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L^2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")S
M=&]U<&%J[6/M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS
M9W-T<B`B0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B>F]B<F%Z:70@<F]Z9.UL>2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA
M:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('IA('!O=;YI=.T@2%14
M4"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M=GET<G9A;.DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM
M<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T
M96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")S97IN86T@^FMO
M;/DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A
M9V%I;B(*;7-G<W1R(")+8;YDZ2!P^&EH;.&Y96[M(&1O('-Y<W3I;74B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M(@IM<V=S='(@(G!R;R!P;W1V<GIE;NT@;F%P:;ET92!H97-L;R!D
M=F%K<N%T(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B<VIE9&YO
M8V5N_2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G
M:60@(G5N;F%M960B"FUS9W-T<B`B8F5Z(&[A>G9U(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED
M(")U<V5R('-E;&5C="(*;7-G<W1R(")V>6)R870@=;YI=F%T96QE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED
M(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(G<Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E
M871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M;R]P=%]"4BYP;P``````````````````````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P-S,S-S,U`#$P-3$U-#,Q,#8S`#`Q-C0Q-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C('1R86YS;&%T
M:6]N(&]F(&AO<F1E+G!O('1O($)R87II;&EA;B!0;W)T=6=U97-E"B,@0V]P
M>7)I9VAT("A#*2!914%2($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@
M9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R
M9&4@<&%C:V%G92X*(PHC($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB
M<CXL(#(P,#8N"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D95QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,34@
M,38Z-3`M,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!&86)I;R!';VUE<R`\
M9FQG;VUS0'5O;"YC;VTN8G(^7&XB"B),86YG=6%G92U496%M.B!"<F%Z:6QI
M86X@4&]R='5G=65S92`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*(E@M1V5N97)A=&]R.B!+0F%B96P@,2XS+C%<;B(*(E!L
M=7)A;"U&;W)M<SH@(&YP;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.UQN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&1I87,@871R
MX7,I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<T"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%1E
M8VQA(&1E($%T86QH;R`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S@Q"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS
M9W-T<B`B("AE;2`E<R!D:6%S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S<*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H:&]J92DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R
M<F]W*2(*;7-G<W1R("(@*&%M86YHXRDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<U"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AO
M;G1E;2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@82`B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R
M(")<(B5S7"(@3N-O(.D@=6T@9&ER973S<FEO+B(*"B,Z(&9R86UE=V]R:R]#
M3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R!NXV\@Z2!U;6$@
M97-C;VQH82!VX6QI9&$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HW,3`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@
M(B<E<R<@;N-O(&5S=.$@8V]N9FEG=7)A9&\@;F\@4F5G:7-T<F\@9&\@2&]R
M9&4N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB
M"FUS9W-T<B`B<F5N9&5R:7IA9&]R(&1E(.%R=F]R92!<(B5S7"(@;N-O(&5N
M8V]N=')A9&\N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+B(*;7-G<W1R(")<(B5S7"(@9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M
M82!D92!G<G5P;W,N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE
M('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&9O:2!A9&EC
M:6]N861O(&%O('-I<W1E;6$@9&4@<&5R;6ES<_5E<RXB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB
M"FUS9W-T<B`B7"(G)7-<(B!NXV\@9F]I(&-R:6%D;SH@)7,N(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N
M,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@
M(B4N,F9-0B!U<V%D;W,@9&4E+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&4@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A
M>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(E9"!D
M:6%S(&%TZ2!S=6$@<V5N:&$@97AP:7)A<BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A
M>2!F;W)E8V%S="(*;7-G<W1R("(E9"!P<F5V:7/C;R!D;R!D:6$B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!!=FES;R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(DEM<')E<W/C;R!$:6=I
M=&%L(&1E("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#0P(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M(@IM<V=S='(@(B5S($]P97)AY_5E<R!D92!-86YU=&5NY^-O("T@0V]N9FER
M;6'GXV\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T
M=7`B"FUS9W-T<B`B0V]N9FEG=7)AY^-O(&1E("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(D-A9&%S=')O(&1E("5S(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!497)M;W,@9&\@
M06-O<F1O(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S
M='(@(B5S(&KA(&5X:7-T92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V
M-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*
M;7-G<W1R("(E<R!A("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB
M)7,@97-TX2!P<F]N=&\@<&%R82!E>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@
M;6%N=71E;N?C;R!M87)C861A<R!A8F%I>&\N("(*(DUA<G%U92!A(&-A:7AA
M('!A<F$@<75A;'%U97(@;W!E<F'GXV\@<75E('9O8^H@<75E:7)A(&5X96-U
M=&%R(&1E<W1A('9E>BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S
M='(@(B5S(.D@;V)R:6=A=/-R:6\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(B5S(&UI;G5T;W,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B)7,@;N-O(&5N8V]N=')A9&\N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!A("5S(&1E("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B0V%TX6QO9V\@9&4@16YD
M97)EYV]S(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M(")!9V5N9&$@9&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`B06YO=&'G]65S(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*
M;7-G<W1R("),:7-T82!D92!487)E9F%S(&1E("5S(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z
M("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z
M,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I
M;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB
M"FUS9W-T<B`B(@HB)7,Z($5S=&$@;65N<V%G96T@<&]D92!NXV\@<V5R(&1E
M('%U96T@96QA(&1I>B!S97(N(%1O;64@8W5I9&%D;R!C;VT@(@HB<75A;'%U
M97(@;&EN:R!P<F5S96YT92!N96QA(&]U(&5M(&9O<FYE8V5R(&%O(')E;65T
M96YT92!Q=6%L<75E<B!I;F9O<FUAY^-O("(*(G!E<W-O86PN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@
M8G)I<V$@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG
M("5S("5S(@IM<V=S='(@(BP@8G)I<V$@)7,@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V87)IX79E;"!D92`E<R!P87)A
M("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3,R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#8*
M;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!S96QE8VEO;F4@+2TB
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R
M;6%T(@IM<V=S='(@(D9O<FUA=&\@,3(@2&]R87,B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O
M<FUA=&\@,C0@2&]R87,B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&]R87,B"@HC.B!F<F%M
M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS
M9W-T<B`B/%#A9VEN82!!;G1E<FEO<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@
M9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(E5M(&-O;F5C=&]R(&1E(&)A;F-O
M(&1E(&1A9&]S(.D@;V)R:6=A=/-R:6\@<&%R82!E<W1E(&)L;V-O+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")5;2!E<G)O(&9A=&%L(&]C
M;W)R974B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(E5M82!C:&%V92!P^F)L:6-A(%!'4"#I
M(&]B<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)5;6$@8VAA=F4@</IB;&EC82!0
M1U`@Z2!O8G)I9V%T\W)I82!P87)A('9E<FEF:6-A<B!U;6$@;65N<V%G96T@
M87-S:6YA9&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E5M82!C:&%V92!P<FEV861A(%!'
M4"!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@9&5S8W)I<'1O
M9W)A9F%R('5M82`B"B)M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB56UA(&-H879E
M('!R:79A9&$@4$=0(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R
M82!A<W-I;F%R('5M82!M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(E5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@
M4R]-24U%(&4@=6UA('-E;FAA('/C;R`B"B)O8G)I9V%T\W)I87,@<&%R82!D
M97-C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B
M(@HB56UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D
M82!3+TU)344@92!U;6$@<V5N:&$@<^-O("(*(F]B<FEG873S<FEA<R!P87)A
M(&%S<VEN87(@=6UA(&UE;G-A9V5M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E5M
M82!C:&%V92!P^F)L:6-A(%,O34E-12#I(&]B<FEG873S<FEA('!A<F$@8W)I
M<'1O9W)A9F%R('5M82!M96YS86=E;2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T
M<B`B3G5V96YS(&UA='5T:6YA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S
M='(@(D-H=79A($9R86-A(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R(")#:'5V82!M871U=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@
M(D-H=79A<R!M871U=&EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(DYE=F%S8V%S($UA='5T:6YA<R(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM
M<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H
M:7,@961I=&]R(@IM<V=S='(@(E-O8G)E(&5S=&4@961I=&]R(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S
M='(@(E-O8G)E+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D%B<V)O
M='1O;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")!8G-M:61D;&4B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D%C
M97-S;R!N96=A9&\@86\@8W)I87(@9&ER973S<FEO(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")!8V5S<V\@;F5G861O
M(&%O(&-R:6%R(&%R<75I=F\@5D93+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E-U
M87,@26YF;W)M8>?U97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*
M;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B4V5N:&$@9&$@0V]N
M=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")#;VYT
M82!D97-A=&EV861A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B0V]N=&%S(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B061I8VEO;F%R(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G
M:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")!9&EC:6]N87(@1W)U<&\@
M4W5B;W)D:6YA9&\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D
M9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(D%D:6-I;VYA<B!097)M:7-S
M]65S(%-U8F]R9&EN861A<R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B061I8VEO;F4@07%U:3HB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q
M.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")!9&EC:6]N87(@3F]V
M;R!'<G5P;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE
M=R!097)M:7-S:6]N(@IM<V=S='(@(D%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C
M;R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E
M<UPB(@IM<V=S='(@(D%D:6-I;VYA<B!U;2!G<G5P;R!S=6)O<F1I;F%D;R!A
M("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O
M(%PB)7-<(B(*;7-G<W1R(")!9&EC:6]N87(@=6UA('!E<FUI<W/C;R!S=6)O
M<F1I;F%D82!A("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B
M061D(&$@;F5W('5S97(Z(@IM<V=S='(@(D%D:6-I;VYA<B!U;2!N;W9O('5S
M=>%R:6\Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")!9&EC:6]N87(@
M8V]L=6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS
M-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(D%D:6-I;VYA<B!N
M;W9O<R!M96UB<F]S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY
M-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B061I8VEO;F%R('!A<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S
M='(@(D%D:6-I;VYA<B!O($UE;G4@)7,@8V]M;R!U;6$@0F%R<F$@3&%T97)A
M;"!D;R!-;WII;&QA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R(")!9&EC:6]N87(@86\@8V%TX6QO9V\@9&4@96YD97)EYV]S.B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I
M9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!9&EC:6]N87(@
M86\@;65U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")!9&EC:6]N87(@=7-U
MX7)I;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N
M(@IM<V=S='(@(B(*(B<E<R<@861I8VEO;F%D;R!A;R!S:7-T96UA+"!M87,@
M;N-O('!U9&4@:6YC;'5I<B!I;F9O<FUAY_5E<R!A9&EC:6]N86ES(&1O("(*
M(F-A9&%S=')O.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N(@IM<V=S='(@(B5S(&%D:6-I;VYA9&\@86\@<VES=&5M
M82X@5F]CZB!P;V1E('-E(&-O;F5C=&%R(&%G;W)A+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(D%D:>?C;R!D92!U<W7A<FEO<R!E<W3A
M(&1E<V%B:6QI=&%D82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-0IM
M<V=I9"`B061D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R(")#873A;&]G;R!D92!%;F1E<F7G;W,B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M
M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M
M:6YI<W1R87(@+2!C;VYF:6=U<F$@<&5R;6ES<_5E<R!P87)A(&]U=')O<R!U
M<W7A<FEO<R(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!9&UI;FES=')AY^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(D%N^FYC:6]S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069E9V%N:7-TXV\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8N)N:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%R9^ER:6$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W
M"FUS9VED(")!;&EA<R(*;7-G<W1R(")!<&5L:61O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B
M06QI9VXB"FUS9W-T<B`B06QI;FAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS
M9W-T<B`B06QI;FAA;65N=&\Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B5&]D;W,B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R
M(")4;V1O<R!5<W7A<FEO<R!!=71E;G1I8V%D;W,B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O
M=7!S(@IM<V=S='(@(E1O9&]S($=R=7!O<R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1O
M9&%S(%!E<FUI<W/U97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*
M;7-G<W1R(")4;V1O<R!Q=6%T<F\@;&%D;W,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,B"FUS9W-T<B`B4&5R;6ET:7(@;?IL=&EP;&]S(&5N9&5R9>=O<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(E!E<FUI=&ER(&-O
M;F9I9W5R87(@;R!T:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!
M;')E861Y(&5X:7-T<R(*;7-G<W1R(")*X2!E>&ES=&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I
M;B(*;7-G<W1R("),;V=I;B!)35-0($%L=&5R;F%T:79O(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S
M<W=O<F0B"FUS9W-T<B`B4V5N:&$@24U34"!!;'1E<FYA=&EV82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%5S97)N86UE(@IM<V=S='(@(E5S=>%R:6\@24U34"!!;'1E<FYA=&EV;R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!D92!E+6UA
M:6P@86QT97)N871I=F\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM
M<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")-;V1E;&]S(&%L
M=&5R;F%T:79O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z
M(@IM<V=S='(@(E1E>'1O(&%L=&5R;F%T:79O.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(E-A;6]A($%M97)I8V%N82(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B56T@=F%L;W(@:6QE9V%L(&9O
M:2!E<W!E8VEF:6-A9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB
M"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&1E<V-O;FAE8VED;RXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO
M=7,@4')O>'DB"FUS9W-T<B`B4')O>'D@86[T;FEM;R(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M4F5S<&]S=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S
M='(@(D%N=.%R=&ED82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD
M($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!E($)A<F)A9&]S(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G
M<W1R(")!<&QI8V'GXV\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*
M;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@07!L
M:6-AY_5E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@
M(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!(&%P;&EC8>?C;R!E
M<W3A('!R;VYT82XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P;&EC
M87(@86]S($-O;7!A<G1I;&AA;65N=&]S(%-U8F]R9&EN861O<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R
M;W9E(@IM<V=S='(@(D%P<F]V87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS
M9W-T<B`B5&%M86YH;R!!<')O>&EM861O(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@
M(D%B<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G:60@(D%R
M86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<N%B:6-O("A7:6YD;W=S
M+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@
M(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(E1A;6%N:&\@9&\@07)Q=6EV
M;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H
M:79E($YA;64B"FUS9W-T<B`B3F]M92!D;R!!<G%U:79O(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")6;V/J('1E;2!C
M97)T97IA('%U92!Q=65R(')E;6]V97(@82!S;VQI8VET8>?C;R!D92!C861A
M<W1R;R!D92`E<S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM
M<V=S='(@(E9O8^H@=&5M(&-E<G1E>F$@<75E(&1E<V5J82!E>&-L=6ER("<E
M<R<@92!S975S('-U8F=R=7!O<S\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E
M;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M07)M96YI82(*;7-G<W1R(")!<FWJ;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S4*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@
M(D%R;>IN:6\@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")!<G1E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S
M='(@(DEL:&$@07-C96YSXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<G1E($%S8VEI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A
M8VEF:6,@4F5G:6]N(@IM<V=S='(@(L%S:6$O4F5G:>-O(&1O(%!A8^UF:6-O
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_(@IM<V=S='(@(E-O;&EC:71A<B!C;VYF:7)M8>?C;R!A;G1E<R!D
M92!E>&5C=71A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;S\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`R"FUS9VED(")!<W-I9VYM96YT
M(&-O;'5M;G,B"FUS9W-T<B`B0V]L=6YA<R!D92!D97-I9VYAY^-O(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E1E;G1O=2!E>&-L=6ER
M('5M(&=R=7!O(&EN97AI<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1O=2!E>&-L=6ER('5M82!P
M97)M:7-SXV\@;N-O(&5X:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1O=2!E9&ET87(@=6UA('!E<FUI
M<W/C;R!NXV\@97AI<W1E;G1E+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+B(*;7-G<W1R(")496YT;W4@961I=&%R('5M(&-O;7!A<G1I;&AA
M;65N=&\@;N-O(&5X:7-T96YT92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T;W,B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM
M<V=I9"`B075G=7-T(@IM<V=S='(@(D%G;W-T;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<N%L:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(L%U<W1R:6$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7V-Y<G-Q;#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@
M:6UA<"!N96-E<W/A<FEA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y
M<G5S.B!/(&-O;F5C=&]R(&[C;R!P;W-S=6D@87,@8V%P86-I9&%D97,@;F5C
M97-SX7)I87,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($[C;R!F;VD@96YC
M;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P
M.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!0
M2%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B
M(@HB075T:%]F='`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($94
M4"!N96-E<W/A<FEA+B!#;VUP:6QE(&\@4$A0(&-O;2!A("(*(F]PY^-O("TM
M96YA8FQE+69T<"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.XV\@9F]I(&5N8V]N
M=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?:W)B-3H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:W)B-2!N
M96-E<W/A<FEA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A
M<#H@26YC;'5SXV\@9&4@=7-UX7)I;W,@;N-O(.D@<W5P;W)T861A('!A<F$@
M06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M075T:%]L9&%P.B!%>&-L=7/C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A
M9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@
M3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B
M(@HB075T:%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!O('5S=>%R:6\@
M)7,N($ES=&\@9F]I(&\@<75E(&\@<V5R=FED;W(@(@HB<F5P;W)T;W4Z("(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@26UP;W-S[79E;"!R96UO=F5R(&\@
M=7-UX7)I;R`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@26UP;W-S[79E
M;"!A='5A;&EZ87(@;R!U<W7A<FEO("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@HB075T:%]L9&%P.B!!='5A;&EZ8>?C;R!D92!U<W7A<FEO
M<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VUC86PZ($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O
M($U#04P@;F5C97-SX7)I82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z
M($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O('-M8F%U=&@@;F5C97-S
MX7)I82XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ,#8*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B075T96YT:6-AY^-O(&YO('-E<G9I9&]R($E-05`@9F%L:&]U
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@
M(D9A;&AA(&YA(&%U=&5N=&EC8>?C;R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B1F%L
M:&$@;F$@875T96YT:6-AY^-O.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C
M=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!R
M96IE:71A9&$@<&5L;R!S97)V:61O<B!2041)55,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!(&%U=&5N=&EC8>?C;R!N
M;R!S97)V:61O<B!&5%`@9F%L:&]U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B02!A=71E;G1I8V'GXV\@;F\@<V5R
M=FED;W(@4TU"(&9A;&AO=2XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#86UP
M;W,@9&ES<&]N[79E:7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA
M;B(*;7-G<W1R(")!>F5R8F%I:N-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B1&5S8W5L<&%S
M(&1O($)/1D@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D9U
M;F1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")#;W(@9&4@
M1G5N9&\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS
M9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(E-E;FAA(&ME
M<F)E<F]S(&EN8V]R<F5T82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S
M='(@(E5S=>%R:6\@:V5R8F5R;W,@:6YC;W)R971O+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%I;B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<V"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*
M;7-G<W1R(")"X6QT:6-O("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(").XV\@9F]I(&5N8V]N=')A9&\@;R!D:7)E=/-R:6\@8F%S92!D92!I
M;6%G96YS("<E<R<N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("),
M:6YH82!D92!087)T:61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*
M;7-G<W1R(")"96QO<OIS<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU
M;2(*;7-G<W1R(")"Z6QG:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM
M<V=S='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G
M<W1R(")"97)M=61A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G
M<W1R(")"=73C;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D%N:79E<G/A
M<FEO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P
M;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3N-O(&9O:2!E
M;F-O;G1R861O(&\@8FQO8V\@7"(E<UPB(&1A(&%P;&EC8>?C;R!<(B5S7"(N
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R(")#;VYF:6=U<F'G]65S(&1O($)L;V-O
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")"
M;&]C:R!4>7!E(@IM<V=S='(@(E1I<&\@9&4@0FQO8V\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B
M"FUS9W-T<B`B3F5G<FET;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B0F]L[79I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")&879O<FET;W,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B0F]R9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D
M97(@=&AI8VMN97-S.B(*;7-G<W1R("),87)G=7)A(&1A(&)O<F1A.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0F]R9&%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")"\W-N
M:6$@92!(97)Z96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")!;6)O<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-U86YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")"
M;W1T;VTB"FUS9W-T<B`B4F]D87#I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R("));&AA($)O=79E="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%S:6PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@
M(E1E<G)I=/-R:6\@9&\@3V-E86YO(,UN9&EC;R!);F=LZG,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QGX7)I
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B3&ES=&$@8V]M($UA
M<F-A9&]R97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS
M9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD
M:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G
M<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B
M4&]N=&]S(&1E($1I<W1R:6)U:>?C;R!#4DPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?
M96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A($/I
M7VQU;&$N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q
M"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R
M(")!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D
M82XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@S(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B06=E
M;F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I
M9"`B0V%L;2(*;7-G<W1R(")#86QM;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#
M86UB;V1I82(*;7-G<W1R(")#86UB;V1J82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-A;65R;V]N(@IM<V=S='(@(D-A;6%R]65S(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O
M<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(D[C;R#I('!O<W/M=F5L(&=E<F%R('5M82!N;W9A('-E
M;FAA(&%U=&]M871I8V%M96YT92P@96YT<F4@96T@8V]N=&%T;R!C;VT@;R`B
M"B)A9&UI;FES=')A9&]R+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O
M(&9I;&4@7"(E<UPB(@IM<V=S='(@(D[C;R!C;VYS:6=O(&=R879A<B!O(&%R
M<75I=F\@7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED
M(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N
M(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(&%D;6EN:7-T<F%R(&=E<F5N8VEA
M9&]R97,@97AT97)N;W,@9&4@<V5S<^-O+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(&-O
M;F5C=&%R(&%O('-E<G9I9&]R($E-05`Z("5S(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(D[C;R!C;VYS:6=O(&%B<FER
M(&\@87)Q=6EV;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A
M(@IM<V=S='(@(D-A;F%DX2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI
M;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(D-A;F-E;&%R(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R(")#86YC96QA<B!296QA=/-R:6\@9&4@4')O8FQE;6$B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@
MZ2!P;W-S[79E;"!E>&-L=6ER(&\@87)Q=6EV;R!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@
M(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3N-O(.D@<&]S<^UV96P@96YC;VYT<F%R('5M(&1I<F5T\W)I;R!T96UP;W+A
M<FEO+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@8V]N=&EN
M=6%R('-E;2!O('!A<N)M971R;R`G=&%R9V5T1FEL92<N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").XV\@
MZ2!P;W-S[79E;"!E>&-L=6ER(&\@9&ER973S<FEO(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S
M='(@(D[C;R#I('!O<W/M=F5L(&5X8VQU:7(L("5D('!O<W-U:2!S=6)O<F1I
M;F%D;W,N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB3N-O(.D@<&]S<^UV96P@<F5O
M<F1E;F%R+"!N^FUE<F\@9&4@<F5G:7-T<F]S(&9O<FYE8VED;W,@<&%R82!R
M96]R9&5N87(@;N-O("(*(F-O<G)E<W!O;F1E(&%O(&[Z;65R;R!A<FUA>F5N
M861O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@<F]T96%R
M(&UE;G-A9V5M('!A<F$@;R!N^FUE<F\@97-P96-I9FEC861O+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B0V%B;R!697)D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B5.UT=6QO(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED
M(")#87)R:65R(@IM<V=S='(@(D]P97)A9&]R82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM
M<V=S='(@(D-A=&5G;W)I87,@92!.;VUE<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")#87EM86X@27-L86YD<R(*;7-G<W1R("));&AA<R!#87EM86XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(E1E;&5F;VYE($-E;'5L87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U
M"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S
M(&1A($/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(DUA
M<F=E;2!D82!CZ6QU;&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S
M(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!#Z6QU;&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L
M;"!S<&%C:6YG.B(*;7-G<W1R(")%<W!AYV%M96YT;R!D82!CZ6QU;&$Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H
M;VYE(@IM<V=S='(@(E1E;&5F;VYE(&-E;'5L87(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-PIM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS
M9W-T<B`B0^EL=&EC;R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N
M=&5R(@IM<V=S='(@(D-E;G1R;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R
M86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@9&$@P69R
M:6-A($-E;G1R86PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B175R
M;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I
M;',B"FUS9W-T<B`B1&5T86QH97,@9&\@0V5R=&EF:6-A9&\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF
M:6-A=&4@3W=N97(B"FUS9W-T<B`B4')O<')I973A<FEO(&1O($-E<G1I9FEC
M861O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*
M;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E!O;.UT:6-A
M<R!D;R!#97)T:69I8V%D;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*
M;7-G<W1R(")48VAA9&4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#
M:&%N9V4B"FUS9W-T<B`B06QT97)A<B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`B06QT97)E(%-U82!396YH82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(D%L=&5R87(@;R!N;VUE(&4@
M;R!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!VZF5M('%U86YD;R!E;&%S(&SJ
M96T@92!R97-P;VYD96T@(@HB<W5A<R!M96YS86=E;G,N(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(D%L=&5R8>?C;R!D92!S96YH82!NXV\@Z2!S=7!O
M<G1A9&$@;F$@8V]N9FEG=7)AY^-O(&%T=6%L+B`@16YT<F4@96T@8V]N=&%T
M;R`B"B)C;VT@;R!A9&UI;FES=')A9&]R+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B
M"FUS9W-T<B`B0VAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB
M"FUS9W-T<B`B5F5R:69I8V%R($QI;E]K+BXN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M:&EN82(*;7-G<W1R(")#:&EN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<Y"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T
M<B`B0VAI;NIS(%-I;7!L:69I8V%D;R`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A"
M:6<U*2(*;7-G<W1R(")#:&ENZG,@5')A9&EC:6]N86P@*$)I9S4I(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI
M8V%T:6]N.B(*;7-G<W1R(")%<V-O;&AA(&$@07!L:6-AY^-O.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(D5S8V]L:&$@=6UA('-E;FAA(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO
M;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B17-C;VQH82!U;2!U<W7A<FEO(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")%<V-O;&AA(&-O;6\@97AI
M8FER(&1A=&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")%<V-O;&AA(&\@
M=&EP;R!D92!E<W1I;&\@9&4@;&ES=&%S("AP87)A(&QI<W1A<R!O<F1E;F%D
M87,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G
M<W1R("));&AA<R!#:')I<W1M87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R(").XV\@9F]I(&5N8V]N=')A9&$@82!D969I;FGGXV\@9&4@
M8VQA<W-E(&1E("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R("),:6UP87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS
M9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DQI;7!A<B!T86=S
M($U33V9F:6-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B
M0VQE87(@475E<GDB"FUS9W-T<B`B17AC;'5I<B!U<W7A<FEO(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(D5X8VQU:7(@=7-U
MX7)I;SH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B17AC;'5I<B!U<W7A<FEO
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@
M(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")%>&-L=6ER(&1A9&]S(&1O('5S
M=>%R:6\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")#Z74@86)E<G1O
M(&$@5&%R9&4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B
M0VQI<75E('!A<F$@0V]N=&EN=6%R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL
M('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@=FEA($A45%`B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")&96-H87(@
M2F%N96QA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L
M;W5D<R(*;7-G<W1R(").=79E;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S
M='(@(DYU8FQA9&\@<&5L82!-86YHXR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B
M3G5B;&%D;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)
M<VQA;F1S(@IM<V=S='(@(DEL:&%S(&1E($-O8V]S(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A
M<B(*;7-G<W1R(")#;VYT<F%I<B!"87)R82!,871E<F%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I
M9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B0V]N=')A:7(@8F]R9&%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B0V]L]&UB
M:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B0V]R(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#$@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC
M:V5R(@IM<V=S='(@(E!A;&AE=&$@9&4@0V]R97,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#,U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM
M<V=S='(@(E-E;&7GXV\@9&4@0V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@
M(D-O;',Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU,`IM<V=I
M9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")4[71U;&]S(&1A<R!#;VQU;F%S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(E%U861R:6YH;W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M86YD;R(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G
M<W1R("),:6YH82!D92!#;VUA;F1O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;65N
M=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*
M;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(DYO;64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F]S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M
M<&%N>2(*;7-G<W1R(")%;7!R97-A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B0V]M<'5T861O<F5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B
M0V]N9&ET:6]N(@IM<V=S='(@(D-O;F1IY^-O(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B0V]N9&GG
M]65S(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I
M9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1&EF97)E;N=A<R!D92!#
M;VYF:6=U<F'GXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA
M<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!D
M92!S:6YC<F]N:7IAY^-O(&-O;2!01$%S+"!3;6%R='!H;VYE<R!E($]U=&QO
M;VLN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B0V]N9FEG=7)A
MY^-O(&YE8V5S<VET82!D92!A='5A;&EZ8>?C;RXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R
M92`E<R(*;7-G<W1R(")#;VYF:6=U<F%R("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R
M9"(*;7-G<W1R(")#;VYF:7)M92!A(%-E;FAA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]N9V\B"FUS9W-T<B`B0V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(D-O;F=O+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9"XB"FUS9W-T<B`B1F%L:&$@;F$@8V]N97CC;RXB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D9A;&AA(&YA(&-O;F5XXV\Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R(")#;VYE>.-O(')E8W5S861A('!E;&\@<V5R=FED;W(@9&4@
M8VAA=F5S('#Z8FQI8V%S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*2(*;7-G<W1R(")#;VYE>.-O(')E8W5S861A('!E;&\@<V5R=FED;W(@9&4@
M8VAA=F5S('#Z8FQI8V%S+B!-;W1I=F\Z("5S("@E<RDB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B02!C;VYE>.-O(&%O('-E<G9I
M9&]R($944"!F86QH;W4N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(D-O;G1A=&]S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#
M;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B(@HB3W,@8V]N=&%T;W,@9F]R86T@861I8VEO
M;F%D;W,@8V]M('-U8V5S<V\@86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O
M<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P
M"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS
M9W-T<B`B5&EP92!D92!C;VYT9?ID;R!D;R!A<G%U:79O(&-O;7!R:6UI9&\Z
M("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")#;VYT9?ID
M;R!D92`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU
M92(*;7-G<W1R(")#;VYT:6YU87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K
M($ES;&%N9',B"FUS9W-T<B`B26QH87,@0V]O:R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(D-O;VMI92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!I87(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F%L:&$@;F$@8_-P:6$Z("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B0V]P:6%R('-E;&7G
MXV\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM
M<V=I9"`B0V]S="!)1"(*;7-G<W1R("))1"!D92!#=7-T;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B0V]S=&$@
M9&\@36%R9FEM(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM
M<V=S='(@(DEM<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@;65N<V%G96T@8V]M
M(%!'4#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U
M-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R
M("));7!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4$=0.B`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@;65N<V%G96T@8V]M(%,O
M34E-12XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V
M-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!3
M+TU)344N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%D:6-I
M;VYA<B!C;VYT871O+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@
M8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@;R!S86QD;RX@)7,B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B26UP;W-S[79E
M;"!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B`G)7,G
M('5T:6QI>F%N9&\@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!L:7-T82!D92!D:7-T<FEB
M=6GGXV\N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G
M<W1R("));7!O<W/M=F5L(&1E<V-R:7!T;V=R869A<B!O<R!D861O<R!01U`Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!D97-C<FEP=&]G<F%F87(@;R!D861O(%,O34E-
M12XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@97AC;'5I
M<B!O(&-O;G1A=&\N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER(&$@;&ES=&$@9&4@9&ES=')I8G5I
MY^-O+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5X
M8VQU:7(@;R!S8W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O
M("<E<R<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&\@
M96YD97)EYV\@9&4@92UM86EL(&1O(&1E<W1I;F%TX7)I;RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&\@
M8V%TX6QO9V\@9&4@96YD97)EYV]S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A(&1E
M(&1I<W1R:6)U:>?C;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T
M<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&$@
M;&ES=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RXB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!C87)R96=A<B!A(&5S=')A=.EG:6$@)R5S)RXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-R:6%R(&\@9&ER973S<FEO
M("<E<R<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y
M"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@
M8VAA=F4@</IB;&EC82!A('!A<G1I<B!D;R!S97)V:61O<B!D92!C:&%V97,N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@)R5S)R!P87)A(&=R879AY^-O+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`E<RXB"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@
M;?-D=6QO("=-86EN=&5N86YC95]487-K)R`E<R(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%B
M<FER(&\@9&ER973S<FEO("<E<R<N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY
M"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L('!E<W%U:7-A<B!N;R!S97)V:61O<B!,
M1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(&QE<B`E<RXB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H
M92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L
M;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B
M"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@
M9V5R87(@=6UA(&YO=F$@<V5N:&$@<&%R82!O('5S=>%R:6\@<V]L:6-I=&%D
M;RX@06QG=6YS(&]U("(*(G1O9&]S(&]S(&1E=&%L:&5S(&[C;R!E<W3C;R!C
M;W)R971O<RX@5&5N=&4@;F]V86UE;G1E(&]U(&5N=')E(&5M(&-O;G1A=&\@
M(@HB8V]M(&\@861M:6YI<W1R861O<B!S92!V;V/J(&YE8V5S<VET82!D92!M
M86ES(&%J=61A+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!O8G1E<B!A($%#3"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!C873A;&]G;R!D92!E
M;F1E<F7G;W,N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O
M+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@87,@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX@)7,B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*
M;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-A<&%C:61A9&5S
M(&1O('-E<G9I9&]R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM
M<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(')E=F5R=&5R(&$@8V]N9FEG=7)AY^-O+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(')E;6]V97(@;R!D:7)E=/-R:6\@)R5S)RXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L('-A;'9A<B!A(&-O;F9I9W5R8>?C;R`E<RXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*
M;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!S86QV87(@=6T@8F%C:W5P(&1A
M(&-O;F9I9W5R8>?C;RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L('-A
M;'9A<B!U;2!B86-K=7`@9&$@8V]N9FEG=7)AY^-O.B`E<R(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@<V%L=F%R(&\@<V-R:7!T
M(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!E;3H@)R5S)RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B(*;7-G<W1R(").XV\@8V]N<V5G=6D@<V%L=F%R(&\@8F%C:W5P
M(&1O(&%R<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3N-O(&-O;G-E9W5I('-A;'9A<B!O
M(&%R<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B!6;V/J('!O9&4@;W4@=71I
M;&EZ87(@=6UA("(*(F1A<R!O<.?U97,@<&%R82!S86QV87(@;R!C\V1I9V\@
M9&4@=F]L=&$@96T@)7,@;W4@8V]P:6%R(&UA;G5A;&UE;G1E(&\@(@HB8_-D
M:6=O(&%B86EX;R!P87)A("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@
M;F\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&QI;FL@)R5S)RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@871U86QI>F%R
M(&\@8V]N=&%T;RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U
M:>?C;RX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!G<F%V
M87(@82!C;VYF:6=U<F'GXV\@9&4@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*
M;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(&5N8V]N=')A<B!A($)A<G)A
M($QA=&5R86P@9&\@36]Z:6QL82X@0V5R=&EF:7%U92US92!Q=64@96QA("(*
M(F5S=.$@86)E<G1A+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG
M="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S
M[79E;"!D87(@86\@=7-UX7)I;R`E<R!O<R!S96=U:6YT97,@9&ER96ET;W,@
M<&%R82!A('!A<W1A("<E<R<Z("4B"B)S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E1E
M>'1O(&-O;G1A9&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")08>US(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G
M<W1R(")#=7)S;W,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R
M(")#<FEA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R
M(")#<FEA<B!U;2!L:6YK(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R
M(")#<FEA<B!U;6$@;F]V82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B0W)I87(@<W5B('!A<W1A<R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E!E<FUI<W/U97,@9&\@8W)I861O<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,3D*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*
M;7-G<W1R(").^FUE<F\@9&\@8V%R=.-O(&1E(&-RZ61I=&\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")#<F_A8VEA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")#=6)A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(C0@1F%S97,@071U86ES(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS
M9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(E-E<W/U97,@071U86ES
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP
M.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B2&]R82!!='5A;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B02!54DP@
M871U86P@Z2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R
M<F5N="!5<V5R<R(*;7-G<W1R(")5<W7A<FEO<R!N;R!M;VUE;G1O(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R
M(@IM<V=S='(@(D-L:6UA($%T=6%L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G
M<W1R(")#;VYD:>?C;R!A='5A;#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*
M;7-G<W1R(")%<W1I;&\@871U86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B0W5S=&]M:7IA('1A
M<F5F87,@82!S97)E;2!E>&5C=71A9&%S(&%O(&-O;F5C=&%R(&$@)7,N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B0V]R=&%R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R(")#;W)T87(@<V5L9>?C;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#:&EP<F4B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS
M9W-T<B`B0VER[6QI8V\@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T
M<B`B0VER[6QI8V\@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M(@IM<V=S='(@(D-I<NUL:6-O+U5C<F%N:6%N;R`H2T])."U5*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC
M82!48VAE8V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4P('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*
M;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*
M;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T
M<B`B(@HB1%-.("AV96IA(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N
M+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")$:6%R:6%M96YT92(*"B,Z(&%D;6EN+V1A=&%T<F5E
M+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(").879E
M9V%D;W(@9&4@1&%T851R964B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C<W"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B4&5S<75I
M<V$@;F\@0F%N8V\@9&4@1&%D;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,#(*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(D1A=&$@9&4@4F5C96)I;65N=&\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDV"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R(")396QEY^-O(&1E(&1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3$*;7-G:60@(D1A>2(*;7-G<W1R(")$:6$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E
M7VQE=&4@0V]L=6UN(@IM<V=S='(@(D5?>&-L=6ER($-O;'5N82(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$
M96-E;6)E<B(*;7-G<W1R(")$97IE;6)R;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E
M8VEM86P@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(&1E8VEM86ES(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(E)E8W5A<B!)9&5N=&'GXV\B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E
M9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")0861RXV\B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM
M<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")#;W(@4&%D<N-O(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F
M875L="!)9&5N=&ET>2(*;7-G<W1R("))9&5N=&ED861E(%!A9'+C;R(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L
M;"(*;7-G<W1R(")3:&5L;"!0861RXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:>?U
M97,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q
M"FUS9VED(")$96QE=&4B"FUS9W-T<B`B17AC;'5I<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I
M9"`B1&5L971E($-E;&PB"FUS9W-T<B`B17AC;'5I<B!CZ6QU;&$B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I
M9"`B1&5L971E($=R;W5P(@IM<V=S='(@(D5X8VQU:7(@1W)U<&\B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,
M;V<B"FUS9W-T<B`B17AC;'5I<B!,;V<B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")%>&-L=6ER
M(%!E<FUI<W/C;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(D5X8VQU:7(@92!P=7)G87(@;65N<V%G96YS(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B17AC;'5I<B!CZ6QU;&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(D5X8VQU:7(@8V]L=6YA
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E
M>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B17AC;'5I<B!M
M;V1E;&\@<W5B<W1I='5T;R!E>&ES=&5N=&4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")%>&-L=6ER('!E
M<FUI<W/U97,@<&%R82`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM
M<V=S='(@(D5X8VQU:7(@<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%L<75E
M<B!O=71R82!S=6(M<&5R;6ES<^-O/R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R
M;W<B"FUS9W-T<B`B17AC;'5I<B!L:6YH82(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R(")%>&-L=6ER(&ED96YT:61A9&4@<V5L96-I
M;VYA9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6XB"FUS9W-T<B`B17AC;'5I<B!A(&-O;'5N82!A='5A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM
M<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")%>&-L=6ER
M(&$@;&EN:&$@871U86PB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@
M<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B4V-R:7!T(&1E(&%T=6%L:7IAY^-O
M(&1E(&-O;F9I9W5R8>?C;R`G)7,G(&5X8VQU[61O+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B2&]R82!D92!E;G1R
M96=A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$:6YA
M;6%R8V$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B1&5S8W)E=F$@
M;R!P<F]B;&5M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDT,B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P
M"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&AE<R`H
M=&%M8NEM(&YO(')E9VES=')O(&1E(&%T:79I9&%D97,@9&\@2&]R9&4I.B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R(")/<R!D971A;&AE<R!F;W)A;2!G<F%V861O<R!E;2!L;V<@<&%R
M82!O(&%D;6EN:7-T<F%D;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B1&5S96YV;VQV
M:6UE;G1O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E
M=R!0;VEN="(*;7-G<W1R(")0;VYT;R!D92!/<G9A;&AO(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B4&]N=&\@9&4@3W)V86QH;R!P87)A(&$@^FQT:6UA
M(&AO<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*
M;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E!O;G1O(&1E($]R=F%L:&\Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(D1I
M<F7GXV\@9&$@97-Q=65R9&$@<&%R82!D:7)E:71A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B1&ER9>?C;R!D82!D:7)E:71A
M('!A<F$@97-Q=65R9&$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5T\W)I;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\B"FUS9W-T<B`B17AI8FER(&5M(&9O<FUA=&\@,C0@:&]R87,_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/
M<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!%>&EB:>?C;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R(")%>&EB:7(@<')E=FESXV\@9&5T86QH
M861A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA
M>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")%>&EB:7(@<')E=FESXV\@*%1!
M1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`V"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")%>&EB:7(@9F]R;6%T;R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R(").;W1I9FEC8>?C;R!D92!$:7-P
M;W-IY^-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B
M1&II8G5T:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R
M"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(D[C;R!E>&-L=6ER(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").XV\@
M86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S
M='(@(B(*(D$@<')I;65I<F$@;&EN:&$@8V]N=.EM(&]S(&YO;65S(&1O<R!C
M86UP;W,_(%-E('-I;2P@8VQI<75E(&YE<W1A(&-A:7AA.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:6-A;F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P
M^F)L:6-A($1O;6EN:6-A;F$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(D[C;R!T96T@=6UA(&-O;G1A/R!#861A<W1R92US92XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G:60@
M(D1O=VYL;V%D(@IM<V=S='(@(D)A:7AA<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R(")"86EX87(@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")"86EX87(@82!C
M;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@<V-R:7!T(%!(4"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R("),:7-T82!D92!S96QEY^-O(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<F]G87,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R(")#;W)R96EO(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--
M4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@
M=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"B)#;VYE8W1O<B!D;R!G871E=V%Y
M($5-86EL+7!A<F$M4TU3+"!P87)A(&]P97)A9&]R87,@<75E(&1I<W!O;FEB
M:6QI>F%M(&5S=&4@(@HB<V5R=FGG;RXB"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS
M9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U
M861O<B(*;7-G<W1R(")%<75A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(D5D:71A<B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS
M9W-T<B`B161I=&%R($)L;V-O(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@
M861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T
M<B`B161I=&%R($=R=7!O(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(D5D:71A<B!097)M:7-SXV\B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(D5D:71A<B!097)M:7-S]65S(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%9&ET87(@
M4&5R;6ES<_5E<R!P87)A("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B161I=&%R
M(&]PY_5E<R!D93HB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B161I=&%R('!E<FUI<W/U97,@<&%R82`E<R(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B161I
M=&%R('!E<FUI<W/U97,@<&%R82`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(D5D=6-AY^-O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I=&\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A;'9A
M9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE
M;G1O+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")%;6%I;"(*;7-G<W1R(")%+6UA:6PB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B
M"FUS9W-T<B`B16YD97)EYV\@9&4@12U-86EL(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DV-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N(@IM<V=S='(@(D\@96YD97)EYV\@9&4@92UM86EL(&1E=F4@8V]R
M<F5S<&]N9&5R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.3,*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DUE;G-A
M9V5M(&-O;2!C;VYF:7)M8>?C;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T
M97=A>2(*;7-G<W1R(")'871E=V%Y(&1E($5-86EL+7!A<F$M4TU3(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y-PIM<V=I
M9"`B16UO=&EC;VYS(@IM<V=S='(@(D5M;W1I8V]N<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B
M16UP='D@;65S<V%G92XB"FUS9W-T<B`B365N<V%G96T@96T@8G)A;F-O+B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4F5S=6QT861O(&5M
M(&)R86YC;RXB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5&5R;6]S
M(&1E('!E<W%U:7-A(&5M(&)R86YC;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R
M;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(DAA8FEL:71A
M<B!I;G-E<N?C;R!D92!I;6%G96YS(&$@<&%R=&ER(&1A($=A;&5R:6$@9&4@
M26UA9V5N<R!N;R!T97AT;S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R(")(86)I;&ET87(@;65N=2!D92!C;VYT97AT;R!C;VT@;R!B;W3C
M;R!D:7)E:71O/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,`IM<V=I9"`B16YD('EE87(B
M"FUS9W-T<B`B1FEN86P@9&\@86YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B
M"FUS9W-T<B`B075M96YT87(@161I=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(D9O<FYEYV$@=6UA('!E<F=U;G1A
M(&1E('-E9W5R86[G82!A('%U86P@=F]CZB!S97+A('!E<F=U;G1A9&\@<V4@
M=F]CZB`B"B)N96-E<W-I=&%R(&=E<F%R('5M82!N;W9A('-E;FAA+"!E>"X@
M)W%U86P@;R!N;VUE(&1O('-E=2!C86-H;W)R;S\G.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM
M<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(D9O<FYE
MYV$@82!54DP@9&$@:6UA9V5M(&%Q=6DB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DP"FUS9VED(")%;G1E<B!T:&4@;&5T
M=&5R<R!B96QO=SHB"FUS9W-T<B`B1&EG:71E(&%S(&QE=')A<R!A8F%I>&\Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T
M<B`B1W5I;ND@17%U871O<FEA;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R
M96$B"FUS9W-T<B`B17)I='+I:6$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8*;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F\B"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B17)R;R!A
M;R!C<FEA<B!B;&]C;SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B17)R;R!A;R!E>&-L=6ER(.)N8V]R
M82!D92!S:6YC<F]N:7IAY^-O.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")%<G)O(&%O(&5X8VQU:7(@;&]G
M(&1E('-I;F-R;VYI>F'GXV\Z("5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")%<G)O(&%O(&]B=&5R(&-O
M;G1E^F1O.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,B"FUS9W-T<B`B17)R;R!A;R!A='5A;&EZ87(@82!S96YH83H@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`B17)R;R!N82!M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*
M;7-G<W1R(")%<G)O(&=R879A;F1O("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B17-T;VYI82(*;7-G<W1R(")%<W3T;FEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B171H:6]P:6$B"FUS9W-T<B`B171I\W!I82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(LET;FEC;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R
M;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`Q
M-2!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I
M9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,B!M:6YU=&]S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D-A
M9&$@,S`@<V5G=6YD;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R(")#861A(#4@;6EN=71O<R(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO
M9VEN(@IM<V=S='(@(D-A9&$@0V]N97CC;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#
M861A(&UE:6$@:&]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E
M(@IM<V=S='(@(D-A9&$@;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")6
M86QO<F5S(&1E(&5X96UP;&\Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q
M(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W
M"FUS9VED(")%>&5C=71E(@IM<V=S='(@(D5X96-U=&%R(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R(")%>'!A;F1I<B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S
M='(@(D5X<&%N9&ER($)A<G)A($QA=&5R86PB"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS
M9W-T<B`B17-P97)A9&\@)RDG(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")%<W!E<F%D;R!U;6$@<&%L879R
M82!O=2!T97)M;R!D92!P97-Q=6ES82!E;G1R92!A<W!A<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO
M;B!$871E(@IM<V=S='(@(D1A=&$@9&4@17AP:7)AY^-O(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT
M(@IM<V=S='(@(D5X<&]E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS
M9W-T<B`B0V]R(&1O('!R:6UE:7)O('!L86YO(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G
M<W1R(")#;VYF:6=U<F'GXV\@9&4@96YV:6\@9&4@87)Q=6EV;W,@1E10(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B1F%L:&$@
M;V)T96YD;R!P<F5F97+J;F-I87,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(")&86QH82!A;R!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B1F%L:&$@
M86\@8V]N96-T87(@86\@<V5R=FED;W(@4TU"+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")&86QH82!A;R!C;W!I
M87(@9&4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S(R"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB
M)7-<(BXB"FUS9W-T<B`B1F%L:&$@86\@8V]P:6%R('!A<F$@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A
M:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B
M1F%L:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M
M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B1F%L:&$@86\@;6]V97(@<&%R82!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G
M<W1R(")&86QH82!A;R!O8G1E<CH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")*
M=7-T;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA
M;'9I;F%S*2(*;7-G<W1R("));&AA<R!&86QK;&%N9"`H36%L=FEN87,I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("));&AA
M<R!&87)O92(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@
M(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%<G)O($9A=&%L.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A
M>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&87AE<R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R(")&979E<F5I<F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")396YS8>?C;R!4Z7)M
M:6-A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E-E;G-AY^-O('3I<FUI8V$Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")086YC861A<R!D92!#:'5V82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(DYE=F4@1G)A8V$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30X"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B36%T<FEZ(&1O(&-A;7!O(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S,@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS
M9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,V"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R(")&;VYT92!&
M:6=L970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I
M;&4B"FUS9W-T<B`B87)Q=6EV;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`B0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")#;VYT86=E
M;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B
M1V5R96YC:6%D;W(@9&4@07)Q=6EV;W,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;64@9&\@
M07)Q=6EV;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.#0*;7-G
M:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&7GXV\@9&4@87)Q=6EV
M;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.3`*;7-G:60@(D9I
M;&4@=7!L;V%D(@IM<V=S='(@(D5N=FEO(&1E(&%R<75I=F\B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#4*;7-G:60@(D9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")%;G9I;R!D92!A<G%U:79O
M<R!NXV\@Z2!S=7!O<G1A9&\N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R;W,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FSB;F1I82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS
M9W-T<B`B4')I;65I<F$@365T861E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R(")0<FEM96ER;R!1=6%R=&\B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4U"FUS9VED(")&:7@@<F%T:6\B
M"FUS9W-T<B`B5&%X82!F:7AA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,`IM<V=I9"`B1FQI<"(*;7-G<W1R(")':7)A
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D1I<W!O<VGGXV\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I
M9"`B1F]G(@IM<V=S='(@(D[I=F]A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B
M"FUS9W-T<B`B4&%S=&$@)7,@;N-O(&5X:7-T92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`B0V]R(&1A($9O;G1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(D-O;6ED82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,B"FUS9W-T<B`B4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R
M=&%M(&EM86=E;G,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I
M9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')E=FESXV\@*%1!1BDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B
M(@HB1&EA<R!0<F5V:7-T;W,@*$YO=&4@<75E(&$@<')E=FESXV\@<F5T;W)N
M861A(&5X:6)E(&%M8F]S(&1I82!E(&YO:71E.R!U;2`B"B)N^FUE<F\@;75I
M=&\@86QT;R!A<75I('!O9&4@<F5S=6QT87(@96T@=6T@8FQO8V\@97AT96YS
M;RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B
M1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(D5S<75E8V5U(&$@<V5N
M:&$_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B
M1F]R;7,B"FUS9W-T<B`B1F]R;75LX7)I;W,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B4V]R=&4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP
M92(*;7-G<W1R(")4:7!O(&1E(%-O<G1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")3;W)T97,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B
M"FUS9W-T<B`B4V]R=&5S(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1O-R=6YS(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS
M9W-T<B`B4F5D:7)E8VEO;F%M96YT;W,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")3
M97@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B475A9')O<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%NYV$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@
M365T<F]P;VQI=&%N(@IM<V=S='(@(D9R86[G82!-971R;W!O;&ET86YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")'=6EA
M;F$@1G)A;F-E<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R(")0;VQI;NES:6$@1G)A;F-E<V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M(")497)R:73S<FEO<R!&<F%N8V5S97,@9&\@4W5L(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*
M;7-G<W1R(")$92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS
M9W-T<B`B1&\H82DB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGG
MXV\@0V]M<&QE=&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(DQU
M82!#:&5I82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B
M"FUS9W-T<B`B3F]M92!#;VUP;&5T;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A
M8F]N(@IM<V=S='(@(D=A8N-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QE<FEA(&1E(&]N9&4@
M;V)T97(@87,@:6UA9V5N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB
M"FUS9W-T<B`B1V%L97)I83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B
M"FUS9W-T<B`B1^)M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T
M:6]N(@IM<V=S='(@(D=E<F%R(&$@0V]N9FEG=7)AY^-O(&1E("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E
M;F5R871E9"!#;V1E(@IM<V=S='(@(D/S9&EG;R!'97)A9&\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E\W)G:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(D%L96UA;FAA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1V%N82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R(")0<FEM96ER;R!.;VUE(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L
M($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S($=L;V)A:7,B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B27(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G
M<W1R(")';V5D96PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$R.0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O
M9VQE($UA<&%S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I
M9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")097-Q=6ES87(@;F\@1V]O9VQE
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S
M-@IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D5S8V%L82!D92!#:6YZ87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RZ6-I82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B1W)E9V\@*$E33RTX.#4Y+3<I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R;V5LXFYD:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R86YA9&$B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!'<G5P;W,B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y(@IM<V=S='(@(DYO;65S(&1E(&=R=7!O<R!NXV\@9&5V96T@
M97-T87(@96T@8G)A;F-O(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`B"FUS9W-T<B`B(@HB1W)O=7!?;&1A<#H@26UP;W-S[79E;"!A
M9&EC:6]N87(@9W)U<&\@)7,N($ES=&\@Z2!O('%U92!O('-E<G9I9&]R(&1I
M<W-E.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM
M<V=S='(@(D=R;W5P7VQD87`Z($EM<&]S<^UV96P@97AC;'5I<B!G<G5P;R`E
M<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S
M(@IM<V=S='(@(D=R;W5P7VQD87`Z($EM<&]S<^UV96P@871U86QI>F%R(&=R
M=7!O("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P;W,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861A;'5P
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;&%M
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U
M97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX
M.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E
M<R!D92!#;VYV:61A9&\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B3&EV<F\@9&4@5FES:71A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6ENZ2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'
M=6ENZ2U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G
M<W1R(")'=6EA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C0*
M;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT
M92!A(&5X8VQU:7(@82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@<V4@
M;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&-O;'5N82!D
M82!T86)E;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R
M(")(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z
M;'1I;6$@;&EN:&$@9&$@=&%B96QA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T96YT:6-AY^-O($A45%`@;N-O(&5N8V]N
M=')A9&$N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(
M86ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO($AA<V@B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM
M<V=I9"`B2&%Z92(*;7-G<W1R(").96)L:6YA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3(S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C$*
M;7-G:60@(DAE861E<B(*;7-G<W1R(")#86)EYV%L:&\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D
M97)S(@IM<V=S='(@(D-A8F7G86QH;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DEL
M:&$@2&5A<F0@92!);&AA<R!-8T1O;F%L9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M
M(@IM<V=S='(@(E1E;7!E<W1A9&4@1F]R=&4B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S
M='(@(DAE8G)E=2`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H
M="(*;7-G<W1R(")!;'1U<F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B06IU9&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS
M9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")!:G5D82!D;R!E9&ET
M;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<U"FUS9VED(")(
M96QP97(B"FUS9W-T<B`B07-S:7-T96YT92(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V;I<FEO
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B07%U:2!E<W3A(&\@:6[M8VEO
M(&1O(&%R<75I=F\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S`*;7-G:60@(DAI9V@B"FUS9W-T<B`B06QT82(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B25]N[6-I
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I
M='D@4W1A=&4I(@IM<V=S='(@(E-A;G1A(%/I("A#:61A9&4M17-T861O(&1O
M(%9A=&EC86YO*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S
M.0IM<V=I9"`B2&]M92(*;7-G<W1R("));NUC:6\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!297-I9&5N8VEA;"(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS
M9W-T<B`B1&ER973S<FEO(%!E<W-O86PB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM
M<V=S='(@(D9O;F4@4F5S:61E;F-I86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(
M;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D
M871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z($1A9&\@6$U,("5S(&EN=N%L:61O(&5N8V]N=')A9&\@;F$@;65N
M<V%G96T@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($YE;FAU;6$@;65N<V%G96T@8V]R<F5S<&]N9&4@86\@;V)J971O("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;FAU
M;2!O8FIE=&\@9&\@=&EP;R`E<R!F;VD@96YC;VYT<F%D;R!N82!M96YS86=E
M;2`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!296UO=FED
M;R!C;VT@<W5C97-S;R`E<R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A
M=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I
M;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($$@96YG:6YE(&1E(&EN=&5G<F'G
MXV\@<F5Q=65R(&$@97AT96YSXV\@4$A0("=D;VUX;6PG(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@
M8W)I87(@=6UA(&YO=F$@X7)V;W)E(%A-3"!P87)A(&\@;V)J971O("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@<F5M
M;W9E<B`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!);7!O<W/M=F5L(&]B=&5R
M(&$@:61E;G1I9FEC8>?C;R!-24U%('!A<F$@82!P87)T92!D;R!T:7!O("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@26UP;W-S
M[79E;"!S:6YC<F]N:7IA<B`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,S,R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA<B!C
M;VUP87)T:6QH86UE;G1O<SH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($-O
M;7!A<G1I;&AA;65N=&\@9&5S8V]N:&5C:61O(%PB)7-<(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R("),:6YH82!(;W)I>F]N=&%L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DUA<F=E;2!H;W)I>F]N
M=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A;#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(D-O;6\@=F]CZB!C:&5G;W4@87%U:3\@*%!O
M<B!F879O<B!C;VUU;FEQ=64A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E%U86YT
M87,@8V]L=6YA<R!V;V/J(&=O<W1A<FEA(&1E(&UE<V-L87(_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")1=6%N=&]S(&-A
M;7!O<R`H8V]L=6YA<RD@97AI<W1E;3\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N
M=&%S(&QI;FAA<R!V;V/J(&=O<W1A<FEA(&1E(&UE<V-L87(_(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C(S-PIM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B56UI9&%D92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED
M:71Y.B`B"FUS9W-T<B`B56UI9&%D93H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")(=6YG
M<NUA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B1F%L:&$@86\@8W)I87(@8V%I>&$@<&]S=&%L($E-05`Z("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M1F%L:&$@86\@97AC;'5I<B!C86EX82!P;W-T86P@24U!4#H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M(")&86QH82!A;R!C<FEA<B!Q=6]T82!D82!C86EX82!P;W-T86P@24U!4#H@
M)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S(P"FUS9VED("))
M4"!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O($E0(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")%;F1E<F7G;R!)4"!NXV\@9&ES<&]N
M[79E;"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R(")%;F1E<F7G;R!)4"!NXV\@97-TX2!N;R!B;&]C;R!P
M97)M:71I9&\@0TE$4BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA
M=&EO;BXB"FUS9W-T<B`B5FEO;&'GXV\@9&\@8FQO<75E:6\@25`N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B25]N<VER
M82!,:6YH82!!;G1E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*
M;7-G<W1R("))<VSB;F1I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B4V]M96YT92#-8V]N97,B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(LUC;VYE<R!P87)A("5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(LUC;VYE<R!E('1E>'1O(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G
M<W1R(").;VUE(&1A(&ED96YT:61A9&4Z(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(DEF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B4V4@;N-O(&9O<B!E>&EB:61O
M(&-O<G)E=&%M96YT92P@)7,@<&%R82!A8G+M+6QO(&5M('5M82!N;W9A(&IA
M;F5L82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B
M"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(E-E('9O
M8^H@;N-O(';J(&YE;FAU;2#M8V]N92!A;R!U=&EL:7IA<B!O($EN=&5R;F5T
M($5X<&QO<F5R+"!V;V/J('!O9&4@(@HB8VAE8V%R(&5S=&$@8V%I>&$@<&%R
M82!D97-A8FEL:71A<B!A('1R86YS<&%RZFYC:6$@4$Y'+B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*
M(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)392!V;V/J(';J(&5S=&$@
M;65N<V%G96T@;6%S(&[C;R!A(&EM86=E;2P@82!I;6%G96T@<75E('9O8^H@
M<75E<B!E;G9I87(@;N-O("(*(G!O9&4@<V5R(&5X:6)I9&$@<&5L;R!S974@
M;F%V96=A9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB
M"FUS9W-T<B`B4'+I+79I<W5A;&EZ8>?C;R!D82!);6%G96TZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM
M<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"!D82!);6%G96TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B55),(&1A($EM86=E
M;3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G
M<W1R("));6%G96T@9&$@9V%L97)I82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("));6%G96T@9&$@9V%L97)I83HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED("));6%G
M92!U<&QO860B"FUS9W-T<B`B16YV:6\@9&4@26UA9V5M(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("));6%G
M96YS(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T
M87(L(%!A<W-O("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM
M<V=S='(@(D-A;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S
M='(@(D-A;7!O<R!I;7!O<G1A9&]S.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B26Y?<V5R:7(@3&EN:&$@07#S<R(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")#\V1I
M9V\@9&4@8>?C;R!F;W)N96-I9&\@97-TX2!I;F-O<G)E=&\N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G
M:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(E5S=>%R:6\@92]O=2!S96YH82!I;F-O<G)E=&]S+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*(E5S=>%R:6\@;W4@96YD97)EYV\@86QT
M97)N871I=F\@:6YC;W)R971O<RX@5&5N=&4@;F]V86UE;G1E(&]U(&5N=')E
M(&5M("(*(F-O;G1A=&\@8V]M(&\@861M:6YI<W1R861O<B!S92!V;V/J(&YE
M8V5S<VET82!D92!M86ES(&%J=61A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N
M="(*;7-G<W1R(")!=6UE;G1A<B!)9&5N=&'GXV\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(DEN9&EA(@IM<V=S='(@(LUN9&EA(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B57-UX7)I
M;W,@:6YD:79I9'5A:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I
M82(*;7-G<W1R("));F1O;NES:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN
M9F]R;6'GXV\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS
M9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUAY^-O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I
M;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B3N-O(&5X:7-T96T@
M;W#G]65S(&1I<W!O;NUV96ES+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?
M;VQU;6X@069T97(B"FUS9W-T<B`B26YS97)I<B!#7V]L=6YA($%P\W,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("));G-E<FER
M($EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("));G-E<FER
M(%1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("));G-E
M<FER($QI;FL@9&$@5V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M
M;B!"969O<F4B"FUS9W-T<B`B26YS97)I<B!?0V]L=6YA($%N=&5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("));G-E<FER('5M82!N;W9A(&-O;'5N82!A</-S
M(&$@871U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<FER('5M82!N
M;W9A(&-O;'5N82!A;G1E<R!D82!A='5A;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M26YS97)I<B!U;6$@;F]V82!L:6YH82!A</-S(&$@871U86PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("));G-E<FER('5M82!N;W9A(&QI;FAA(&%N=&5S(&1A(&%T
M=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E<FER('5M('!A<N%G<F%F
M;R!A</-S(&\@871U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E<FER
M('5M('!A<N%G<F%F;R!A;G1E<R!D;R!A='5A;"(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(DEN<V5R:7(@=6T@;6]D96QO(&%L=&5R;F%T:79O(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z(@IM<V=S='(@(D9O<FYEYV$@=6T@96YD97)EYV\@9&4@92UM
M86EL(&YO('%U86P@=F]CZB!P;V1E(')E8V5B97(@82!N;W9A('-E;FAA.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN<V5R
M:7(@8^EL=6QA(&%P\W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O
M<F4B"FUS9W-T<B`B26YS97)I<B!CZ6QU;&$@86YT97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED
M("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@8V]L=6YA
M(&%P\W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G
M<W1R("));G-E<FER(&-O;'5N82!A;G1E<R(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`B26YS97)I<B!M96YS86=E;G,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B26YS97)I<B!P87+A
M9W)A9F\@87#S<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B
M969O<F4B"FUS9W-T<B`B26YS97)I<B!P87+A9W)A9F\@86YT97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y
M"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@;&EN
M:&$@87#S<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S
M='(@(DEN<V5R:7(@;&EN:&$@86YT97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(D9O<FYEYV$@82!R
M97-P;W-T82!O8G)I9V%T\W)I82!P87)A(&$@<&5R9W5N=&$@9&4@<V5G=7)A
M;N=A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B26YS
M97)I<B]!;'1E<F%R($EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R("));G-E<FER+T%L=&5R87(@3&EN:R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(")#<NED:71O(&EN<W5F:6-I96YT92!P87)A(&5N
M=FEA<B!P87)A(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")#<NED:71O(&EN<W5F
M:6-I96YT92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<Y"FUS
M9VED("));G1E9V5R(@IM<V=S='(@(D[Z;65R;R!);G1E:7)O(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T
M(@IM<V=S='(@(DQI<W1A(&1E($EN=&5I<F]S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")#1%4@*$-A
M8F7G86QH;R!D92!$861O<R!D92!5<W7A<FEO*2!I;G;A;&ED;RXB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV
M86QI9"!:25`@9&%T82(*;7-G<W1R(")$861O<R!:25`@:6YVX6QI9&]S(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B07!L:6-AY^-O(&EN=N%L:61A+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B261E;G1I9FEC
M8>?C;R!D;R!B871C:"!I;G;A;&ED82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#DQ(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-C(*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S`S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM
M<V=S='(@(D1A9&]S(&5N=FEA9&]S('/C;R!I;G;A;&ED;W,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(D5N
M9&5R9>=O(&1E(&1E<W1I;F\@Z2!I;G;A;&ED;RXB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE
M(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1O(&%R<75I=F\@Z2!I;G;A;&ED
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D[Z;65R;R!D92!L:6-E
M;N=A(&EN=N%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(DQO8V%L:7IAY^-O(&9O<FYE8VED82#I(&EN=N%L:61A+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM
M<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B5&EP;R!D82!M96YS
M86=E;2#I(&EN=N%L:61O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`B07!I7VED(.D@:6YVX6QI9&\@;W4@97-T
MX2!F86QT86YD;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P
M87)A;65T97)S+B(*;7-G<W1R(")087+B;65T<F]S(&EN=N%L:61O<R!O=2!F
M86QT86YD;RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G
M:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!E<FUI
M<W/U97,@9&\@<&%I('/C;R!I;G;A;&ED87,N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED
M+B(*;7-G<W1R(")097)M:7-S]65S(&1O('!A:2!SXV\@:6YVX6QI9&%S+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN
M=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")#\V1I9V\@9&\@<')O9'5T
M;R#I(&EN=N%L:61O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB
M"FUS9W-T<B`B4')O=&]C;VQO(&EN=N%L:61O+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B1&5S=&EN873A<FEO
M(&EN=N%L:61O.B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,#<U(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3V)J971O(&-O;7!A<G1I
M;&AA9&\@:6YVX6QI9&\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D
M9')E<W,N(@IM<V=S='(@(D9O;G1E(&1O(&5N9&5R9>=O(&EN=N%L:61A+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D1A
M9&]S('5N:6-O9&4@:6YVX6QI9&]S+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G3A
M<FEO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-@IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("));G9E<G1E
M<B!S96QEY^-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(DERXRP@4F5P^F)L:6-A($ES;.)M:6-A
M(&1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER87%U
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA
M;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@
M(DES;&4@;V8@36%N(@IM<V=S='(@(DEL:&$@9&\@2&]M96TB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O
M;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&5S=&%D97,@27-O;&%D87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)A96PB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I
M9"`B27-S=65R(@IM<V=S='(@(D5M:7-S;W(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G
M<W1R("))=.%L:6-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G
M<W1R("))=.%L:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS
M9W-T<B`B2F%M86EC82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA;F5I<F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<.-O(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DIA<&%N97-E("A)
M4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;V[J<R`H25-/+3(P,C(M2E`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E
M>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A
M;B(*;7-G<W1R(")*;W)DXFYI82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(DIU;&AO
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*
M;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:&\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T
M:69Y(@IM<V=S='(@(DIU<W1I9FEC87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF
M>2!#96YT97(B"FUS9W-T<B`B06QI;FAA<B!A;R!#96YT<F\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM
M<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(DIU<W1I9FEC87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(D%L:6YH87(@X"!%<W%U
M97)D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(D%L
M:6YH87(@X"!$:7)E:71A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS
M=&%N(@IM<V=S='(@(D-A>F%Q=6ES=.-O(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA
M;#\B"FUS9W-T<B`B36%N=&5R(&\@;W)I9VEN86P_(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")+96YY82(*;7-G<W1R(")1=>IN:6$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-E<G9I9&]R(&ME
M<F)E<F]S(')E:F5I=&]U(&$@875T96YT:6-AY^-O+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T
M<B`B3F]V871O<R!D92!+97)N96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")#
M<FEAY^-O(&1E($-H879E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B26UP
M<F5S<^-O($1I9VET86P@9&$@0VAA=F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B
M5&%M86YH;R!D82!#:&%V92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5&EP;R!D82!#
M:&%V92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY
M"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B57-O(&1A($-H879E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D-H879E(&KA(&5X:7-T92!N;R!S97)V:61O<B!D92!C:&%V97,@</IB
M;&EC87,N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+
M:61S(@IM<V=S='(@(D-R:6%NYV%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I
M9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B0V]RZ6EA+"!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(D-O<NEI82P@4F5P^F)L:6-A(&1A(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#<*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")#
M;W)E86YO("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B
M"FUS9W-T<B`B2W5W86ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS
M=&%N(@IM<V=S='(@(E%U:7)G=6ES=.-O(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(DQA7WEO=70B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG
M=6%G92(*;7-G<W1R("))9&EO;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;R!2
M97#Z8FQI8V$@1&5M;V-RX71I8V$@4&]P=6QA<B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("+:;'1I;6$@
M365T861E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),
M87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")'97)A<B!.;W9A(%-E;FAA
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H
M<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(MIL=&EM;R!1=6%R
M=&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM<V=I9"`B3&%S="!5
M<&1A=&5D.B(*;7-G<W1R("+:;'1I;6$@071U86QI>F'GXV\Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(MIL=&EM;R!L;V=I;CH@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("+:;'1I;6\@
M;&]G:6XZ("5S(.`@<&%R=&ER(&1E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R
M("+:;'1I;6\@;&]G:6XZ($YU;F-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M871V:6$B"FUS9W-T<B`B3&5T]&YI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DQE:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B
M3&%Y;W5T(@IM<V=S='(@(DQA>6]U="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(B"FUS9W-T<B`B1&5I>&$@=F%Z:6\@<V4@<75I<V5R('-E
M;2!B;W)D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R
M("),[6)A;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B17-Q=65R9&$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`X"FUS9VED("),969T
M(&AE861E<B(*;7-G<W1R(")#86)EYV%L:&\@97-Q=65R9&\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`T"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R(")686QO<F5S(&1A(&5S<75E<F1A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T;R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B06UO
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I
M<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER
M:7EA(@IM<V=S='(@(DSM8FEA(,%R86)E($IA;6%H:7)I>6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS
M=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(D-H:79I<V-O1G)A
M8V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")#:'5V82!&<F%C82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED
M("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(D-H=79A($9R86-A($UA='5T
M:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")#:'5V82!&<F%C
M82!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@
M(DQE=F5S(%!A;F-A9&%S(&1E($-H=79A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R(@IM<V=S='(@(D-H=79A<R!&<F%C87,@8V]M(%1R;W;U97,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM
M<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(").979E($9R86-A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI
M9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(D)R979E($YE=F%S8V$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(E!OZFUA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3@*
M;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN
M:R!P;VEN=',@=&\Z(@IM<V=S='(@(DQI;FL@87!O;G1A('!A<F$Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W.0IM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("),:6=A<B!O(&5N9&5R9>=O(&1E(&4M;6%I;"#@('#A
M9VEN82!D92!C;VUP;W-IY^-O(&%O(&5X:6)I<B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI
M;FMS(@IM<V=S='(@(DQI;FMS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B0V]O:VEE(&1O($QI
M;G5X(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G
M<W1R("),:7-T87(@+2!U<W7A<FEO('!O9&4@=F5R(&$@<&%S=&$B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*
M;7-G<W1R("),:7-T87(@0F%N8V]S(&1E($1A9&]S(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS
M9W-T<B`B3&ES=&%R(%3S<&EC;W,@9&4@06IU9&$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("),:7-T
M87(@5&%B96QA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES="U!<F-H
M:79E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T+4AE;'`B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)
M9"(*;7-G<W1R("),:7-T+4ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES
M="U/=VYE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI
M<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M4W5B<V-R:6)E(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M
M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!L:7-T86=E;2!D
M92!S97-S]65S(&9A;&AO=3H@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z
M("5S(@IM<V=S='(@(D$@;&ES=&%G96T@9&4@=7-UX7)I;W,@9F%L:&]U.B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I
M9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&ES=&%G
M96T@9&4@=7-UX7)I;W,@97-TX2!D97-A8FEL:71A9&$N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@
M(DQI=&5R871U<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*
M;7-G<W1R("),:71UXFYI82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B
M0V%R<F5G86YD;RXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")(;W)A(&QO8V%L
M.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L
M92!A;F0@5&EM92(*;7-G<W1R("),;V-A;&EZ8>?C;R!E($AO<F$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM
M<V=S='(@(E)E9VGC;R(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")#
M;VYE8W1A<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM
M<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("),
M;V<@9&$@<V5S<^-O(&1E('-I;F-R;VYI>F'GXV\@86YT97)I;W(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T
M(@IM<V=S='(@(D1E<V-O;F5C=&%R(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R(")#;VYE8W1A<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM
M<V=S='(@(E1A<F5F87,@9&4@0V]N97CC;R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2XB"FUS9W-T<B`B3R!L;V=I;B!F86QH;W4@<&]R<75E('-E=2!U<W7A<FEO
M(&]U('-E;FAA(&5S=&%V82!I;F-O<G)E=&$N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(D9A;&AA(&1E($QO9VEN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-CD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")497AT;R!L;VYG;R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G
M<W1R(")!;6]R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G<W1R(")"86EX82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*
M;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B06QF86)E=&\@
M9W)E9V\@96T@;6EN^G-C=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R(")!;&9A8F5T;R!L871I;F\@96T@;6EN^G-C
M=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R(").^FUE<F]S(')O;6%N;W,@96T@;6EN^G-C=6QO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R9V\B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,SDY"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,S<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*
M;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B3R!A;F5X;R!-4RU43D5&(&[C;R!C;VYT
MZ6T@9&%D;W,N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S
M='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B
M36%C86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86-E9&]N:6$L
M($%N=&EG82!297#Z8FQI8V$@275G;W-LX79I82!D82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S8V%R(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R
M(")-X6=I8V\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G
M:60@(DUA:6PB"FUS9W-T<B`B0V]R<F5I;R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B061M
M:6YI<W1R861O<B!D;R!#;W)R96EO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI
M;E]K+BXN(@IM<V=S='(@(D-R:6%R(&QI;E]K+BXN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86SA<VEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD:79A<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F
M(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD
M(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB
M"FUS9W-T<B`B1V5R96YC:6$@82!L:7-T82!D92!C871E9V]R:6%S(&4@87,@
M8V]R97,@87-S;V-I861A<R!A(&5L87,N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-30*;7-G:60@(DUA<#(T(&UA<"(*
M;7-G<W1R(")-87!E86UE;G1O($UA<#(T(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-CD*;7-G:60@(DUA<%%U97-T(&UA
M<"(*;7-G<W1R(")-87!E86UE;G1O($UA<%%U97-T(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N
M(@IM<V=S='(@(DUA<&5A;65N=&]S(&=R879A9&]S+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R(")-87+G;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-
M87)G96TB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(DUA<F-A<B!C;VT@9FQA9W,@3&ED82].XV\@3&ED82(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*
M;7-G<W1R(")-87)C87(@8V]M(&]U=')O<R!F;&%G<R`H97@N($EM<&]R=&%N
M=&4O4F5S<&]N9&ED82DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL
M($ES;&%N9',B"FUS9W-T<B`B26QH87,@36%R<VAA;&PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6-A(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG
M(&9I96QD<R(*;7-G<W1R(")#86UP;W,@8V]R<F5S<&]N9&5N=&5S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=.)N
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-
M875R[6-I;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G
M<W1R(")#<NED:71O(&WA>&EM;R!P97)M:71I9&\N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B3OIM97)O(&WA
M>&EM;R!D92!P87)T97,@9&$@;65N<V%G96T@97AC961E=2XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA
M<R`R-"!H;W)A<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G
M:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T
M=7)A(&WA>&EM82!N87,@^FQT:6UA<R`V(&AO<F%S.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R(").^FUE<F\@3>%X:6UO(&1E($)L;V-O<R!D92!0;W)T86PB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C0S"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")486UA;FAO(&WA
M>&EM;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%I;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D
M:6-I;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V
M"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE;6)R;W,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@
M(DUO9&\@9&\@;65N=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G
M<W1R(")-97-C;&%R(&/I;'5L87,B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*
M;7-G<W1R(")-96YS86=E;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB365N<V%G96T@5F5R:69I
M8V%D82!C;VT@4W5C97-S;R!M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I;F%N
M=&4@;N-O('#T9&4@<V5R("(*(G9E<FEF:6-A9&\N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-
M97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE;G-A9V5M(&5X<&ER861A+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4
M:7!O(&1E(&UE;G-A9V5M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS
M9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(D-L:6UA($UE=&%R(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B0FQO8V\@365T87(@;N-O(&1I<W!O;NUV
M96PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D)L;V-O
M($UE=&%R(&[C;R!D:7-P;V[M=F5L+B!$971A;&AE<R!F;W)A;2!G<F%V861O
M<R!E;2!L;V<@<&%R82!O("(*(F%D;6EN:7-T<F%D;W(N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")/($UE=&%R1$(@;N-O(&5S=.$@8V]N
M96-T861O+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM
M<V=I9"`B365T:&]D(@IM<V=S='(@(DWI=&]D;R(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`B3>ET;V1O("<E<R<@;N-O(&5S=.$@9&5F
M:6YI9&\B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S(@IM<V=S='(@(DWI=&]D;R!NXV\@9&5F:6YI9&\N($WI=&]D
M;R!C:&%M861O.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS
M9W-T<B`B3>ET<FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM
M<V=S='(@(DWI>&EC;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI8W)O;NES:6$L($5S
M=&%D;W,@1F5D97)A9&]S(&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T
M<B`B365I;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N
M<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5&EP;R!-:6UE(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R82!M[6YI;6$@;F%S
M(/IL=&EM87,@,C0@:&]R87,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")4
M96UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@-B!H;W)A<SH@(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM
M=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B
M261A9&4@;>UN:6UA(&1A('-E;FAA(&%I;F1A(&[C;R!E>'!I<F]U(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,PIM<V=I
M9"`B36ER<F]R(@IM<V=S='(@(D5S<&5L:&\B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B1&EV
M97)S;W,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="XB"FUS9W-T<B`B4&%C;W1E(%!%05(@2%144%]297%U97-T(&9A
M;'1A;F1O+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@
M(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"B)#;VYF:6=U<F'GXV\@9F%L=&%N9&\N(%9O8^H@
M=&5M('%U92!G97)A<B!E;&$@86=O<F$@<V4@=F]CZB!Q=65R('5T:6QI>F%R
M("(*(F5S=&$@87!L:6-AY^-O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S
M86=E($E$+B(*;7-G<W1R("))1"!D82!M96YS86=E;2!F86QT86YD;RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"XB"FUS9W-T<B`B4&%C;W1E(&]B<FEG873S<FEO(%!%05(@36%I;"!F86QT
M86YD;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T
M<B`B240@9&$@<V5S<^-O(&9A;'1A;F1O+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@
M(E-E9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B
M36]B:6QE($UA:6PB"FUS9W-T<B`B0V]R<F5I;R!-\W9E;"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")-;V1E
M<F%T92(*;7-G<W1R(")-;V1E<F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T82!-
M;V1I9FEC861A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@
M(D%L=&5R87(@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B3?-D=6QO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R
M(")-;VQD;W9A+"!297#Z8FQI8V$@9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;F%C;R(*;7-G<W1R(")-]&YA8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUO;F=O;&EA(@IM<V=S='(@(DUO;F?S;&EA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4X.`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T
M<B`B3>IS(&4@86YO(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-96YS86QM
M96YT92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R
M(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")&
M87-E<R!D82!,=6$B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ
M.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N(@IM<V=S='(@(DUA:7,@8V%M<&]S(&5N8V]N=')A
M9&]S(&YA(&QI;FAA("5D('%U92!O(&[Z;65R;R!E<W!E<F%D;R`E9"XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R<F]C;W,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM
M<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(D=R86YD92!087)T92!,:6UP
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T
M"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(D=R86YD92!087)T92!.
M=6)L861O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")'<F%N9&4@4&%R
M=&4@16YS;VQA<F%D;R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B
M36]V97(@06)A:7AO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")-
M;W9E<B#@($5S<75E<F1A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T
M<B`B36]V97(@X"!$:7)E:71A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T
M<B`B36]V97(@06-I;6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B06)A
M:7AO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(D%C:6UA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUOYV%M8FEQ=64B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B3&ES=&%S(&1E('-E;&7G
MXV\@9&4@;?IL=&EP;&]S(&[M=F5I<R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#4V"FUS9VED(")-=6QT:6UA<"!52R!M
M87`B"FUS9W-T<B`B36%P87,@26YG;&5S97,@375L=&EM87`B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V"FUS9VED(")-=6QT:7!L92!S96QE
M8W1I;VXB"FUS9W-T<B`B4V5L9>?C;R!M^FQT:7!L82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T
M<B`B36EN:&$@0V]N=&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*
M;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B4W5A<R!)
M;F9O<FUAY_5E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#4*
M;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-974@4&]R=&%L(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T86P@3&%Y
M;W5T(@IM<V=S='(@(DUE=2!,87EO=70@9&4@4&]R=&%L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(D)I<FWB;FEA(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@
M(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").PT\L($5U($[#3R!#;VYC
M;W)D;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").
M86UE(@IM<V=S='(@(DYO;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB
M:6$B"FUS9W-T<B`B3F%M[6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U
M<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L
M(@IM<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L
M86YD<R(*;7-G<W1R(")(;VQA;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE
M=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(D%N=&EL:&%S($AO;&%N9&5S
M87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B55),($)A<V4@9&\@
M3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B55),(&1E(%)E=F]G8>?C;R!D92!#02!D;R!.971S8V%P92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S
M8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(E523"!D92!P;VSM=&EC87,@
M9&4@0T$@9&\@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS
M9W-T<B`B55),(&1E(%)E;F]V8>?C;R!D;R!.971S8V%P92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P
M92!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@4F5V;V=AY^-O(&1O
M($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R
M(").;VUE(&1O('-E<G9I9&]R(%-33"!D;R!.971S8V%P92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(D-O;65N=.%R:6\@9&\@
M8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@='EP92(*;7-G<W1R(")4:7!O(&1E(&-E<G1I9FEC861O(&1O($YE='-C
M87!E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B
M3F5T=V]R:R(*;7-G<W1R(")2961E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T
M<B`B3G5N8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B
M"FUS9W-T<B`B3F]V82!#86QE9/1N:6$B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G
M;W)Y(@IM<V=S='(@(DYO=F$@0V%T96=O<FEA(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R(").;W9A($UE
M;G-A9V5M('!A<F$@)7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G
M:60@(DYE=R!-;V]N(@IM<V=S='(@(DQU82!.;W9A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE
M("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]V;R!5<W7A<FEO("AO<&-I;VYA;"DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO
M=F$@6F5LXFYD:6$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").;W9A('-E;FAA(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM
M<V=S='(@(DYO=F$@<V5N:&$@97AP:7)A<N$@96T@)7@N(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R(")!<R!N;W9A<R!S96YH87,@;N-O('/C
M;R!I9W5A:7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R
M(").;W9A(&IA;F5L82`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYO=.UC
M:6%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B
M3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P;W,@9&4@3F]T[6-I87,B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R
M.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*
M;7-G<W1R(")0<O-X:6UA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS
M9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(E!R\WAI;6%S(#0@1F%S97,B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS
M(@IM<V=S='(@(E!R\WAI;6%S(&]PY_5E<R(*"B,Z(&9R86UE=V]R:R]522]5
M22]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")0<O-X:6UA
M/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI
M8V%RX6=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B
M3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B
M3FEGZ7)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*
M;7-G:60@(DYI9VAT(@IM<V=S='(@(DYO:71E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"FUS9VED(").;R(*;7-G<W1R(").
MXV\B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G
M:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(DYE;FAU;2!D861O(&1E(&-O;F9I
M9W5R8>?C;R!D:7-P;V[M=F5L('!A<F$@97AI8FER(&%S(&1I9F5R96[G87,N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ
M,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N(@IM<V=S='(@(DYE;FAU;6$@97-T<F%TZ6=I82!D:7-P;V[M
M=F5L('!A<F$@8W)I87(@:6UA9V5N<R!)4T\N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B3F5N:'5M(&UO9&5L;R!D92!B871C
M:"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B3F5N:'5M(&)L;V-O(&5X:7-T
M92!N82!P;W-IY^-O('-O;&EC:71A9&$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6T@
M;F]M92!D92!A9V5N9&$@9F]R;F5C:61O('!A<F$@82!A=71E;G1I8V'GXV\@
M34-!3"XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@
M8VAA;F=E+B(*;7-G<W1R(").96YH=6UA(&%L=&5R8>?C;RXB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M3F5N:'5M('-U8F]R9&EN861O('!O9&4@<V5R(&%D:6-I;VYA9&\@82!E<W1A
M('!E<FUI<W/C;RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P.`HC.B!F<F%M97=O<FLO
M571I;"]5=&EL+G!H<#HW-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G
M<W1R(").96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C
M:69I8V%D82!P87)A("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#4U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B3F5N:'5M82!I;F9O<FUA
MY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!&5%`@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R
M8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!344P@5D93+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M(@IM<V=S='(@(DYE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@
M97-P96-I9FEC861A('!A<F$@4U%,+49I;&4@5D93+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DYE;FAU;2!C<NED:71O(')E<W1A
M;G1E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS
M9W-T<B`B3F5N:'5M(&1E<W1I;F\@9F]R;F5C:61O+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP,PIM<V=I9"`B3F\@9FEL92!U<&QO
M861E9"(*;7-G<W1R(").96YH=6T@87)Q=6EV;R!E;G9I861O(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB
M"FUS9W-T<B`B3F5N:'5M(.UC;VYE(&5N8V]N=')A9&\N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S`*;7-G:60@(DYO(&QO
M8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B3F5N:'5M82!L;V-A;&EZ8>?C;R!C
M;VYF:6=U<F%D82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F5N
M:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@
M;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F5N:'5M82!M96YS86=E;2!F
M;W)N96-I9&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G
M<W1R(").96YH=6T@;F]M92!E<W!E8VEF:6-A9&\N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO
M(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYE;FAU;2!N^FUE<F\@97-P
M96-I9FEC861O+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I
M9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E-E;2!S;W)T97,@
M;V9E;G-I=F%S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY
M,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A
M<F$@82!A=71E;G1I8V'GXV\@2%144"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;6$@<V5N
M:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@24U!4"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DYE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I
M8V'GXV\@2V5R8F5R;W,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C
M;R!,;V=I;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z
M,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6UA('-E;FAA(&9O<FYE8VED
M82!P87)A(&$@875T96YT:6-AY^-O(%!!4U-71"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;6$@
M<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@4TU"+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B
M(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H
M92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F5N:'5M('!A=&@@<&%R82!O
M(&)I;N%R:6\@9&\@3W!E;E-33"!F;VD@9F]R;F5C:61O+B!/(&)I;N%R:6\@
M9&\@3W!E;E-33"#I("(*(FYE8V5S<^%R:6\@<&%R82!M86YI<'5L87(@;W,@
M9&%D;W,@4$M#4R`Q,BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@
M(DYE;FAU;2!C861A<W1R;R!P96YD96YT92XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(E%U
M;W1A(&[C;R!C;VYF:6=U<F%D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*
M;7-G<W1R(")396T@;&EN:&%S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G
M<W1R(").96YH=6T@<V5P87)A9&]R(&9O:2!E<W!E8VEF:6-A9&\N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B4V5M(&QA9&]S(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R(")!<G%U:79O(&EN97AI<W1E;G1E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(").96YH=6T@
M9&ER973S<FEO('1E;7!O<N%R:6\@9&ES<&]N[79E;"!P87)A(&\@8V%C:&4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*
M;7-G<W1R(").96YH=6T@=7-UX7)I;R!E+V]U('-E;FAA(&9O<FYE8VED;W,N
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYE;FAU;2!D
M861O(%A-3"!VX6QI9&\@<F5T;W)N861O(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@R"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3`*;7-G:60@(DYO('9A;'5E<R(*;7-G
M<W1R(")396T@=F%L;W)E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B).96YH=6T@=F5R<^-O(&5N8V]N=')A9&$@;F$@8V]N9FEG=7)AY^-O(&]R
M:6=I;F%L+B!'97)E(&YO=F%M96YT92!A("(*(F-O;F9I9W5R8>?C;RXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"B).96YH=6UA('9E<G/C;R!E;F-O;G1R
M861A(&YA('-U82!C;VYF:6=U<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@8V]N
M9FEG=7)AY^-O+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F5N:'5M82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO
M;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B3F5N:'5M82`H=7-O(&EM<&SM
M8VET;RDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B3F]R
M9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3O-R9&EC;R`H25-/+3@X-3DM
M,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G
M<W1R("));&AA($YO<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(DAE;6ES9NER:6\@3F]R=&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("));&AA
M<R!-87)I86YA(&1O($YO<G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W
M87DB"FUS9W-T<B`B3F]R=65G82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B3N-O
M($%P\W,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(").XV\@06YT97,B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,34*;7-G:60@(DYO="!A(&1I
M<F5C=&]R>2(*;7-G<W1R(").XV\@Z2!U;2!D:7)E=/-R:6\B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G
M<W1R(").XV\@26UP;&5M96YT861O+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T
M<B`B3N-O(&-O;F9I9W5R861O(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HR,S8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C`X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S0*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U,B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C8Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#4@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,P,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,V-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(V"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W
M-`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3DQ(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HV-CD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(D[C
M;R!S=7!O<G1A9&\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G
M<W1R(")!;F]T8>?U97,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP
M:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G
M<W1R(").861A('!A<F$@97AI8FER+"!V;VQT92XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B
M"FUS9W-T<B`B3F]V96UB<F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B3OIM97)O(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H
M87)A8W1E<G,B"FUS9W-T<B`B3OIM97)O(&1E(&-A<F%C=&5R97,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T.2!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I
M9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B3OIM97)O(&1E(&-O;'5N
M87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B3OIM97)O(&1E
M(&QI;FAA<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").^FUE
M<F\@;N-O(&5S<&5C:69I8V%D;R!P87)A(&%T=6%L:7IAY^-O(&YA(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,0IM<V=I
M9"`B3V)J96-T(@IM<V=S='(@(D]B:F5T;R(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R
M(")#<FEA9&]R(&1O($]B:F5T;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]C=&%L(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C
M=&]B97(B"FUS9W-T<B`B3W5T=6)R;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')O
M(&]F96YS:79O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM
M<V=I9"`B3V9F:6-E(@IM<V=S='(@(D5S8W)I=/-R:6\B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A
M<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B4V5N:&%S(&%N
M=&EG82!E(&YO=F$@9&5V96T@<V5R(&1I9F5R96YT97,N(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B
M"FUS9W-T<B`B4V5N:&$@86YT:6=A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N(@IM<V=S='(@(E-E;FAA(&%N=&EG82!NXV\@97-TX2!C;W)R971A+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;>,B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS
M9W-T<B`B4V]M96YT92!S97)V:61O<F5S($E-05`@<W5P;W)T86T@<&%S=&%S
M(&-O;7!A<G1I;&AA9&%S+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B4V]M
M96YT92!S;W)T97,@;V9E;G-I=F%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED
M(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E-O
M;65N=&4@=6T@96YD97)EYV\@9&4@92UM86EL('!E<FUI=&ED;RXB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*(E-O;65N=&4@;R!P<F]P<FEE=.%R:6\@;W4@;R!A9&UI;FES
M=')A9&]R(&1O('-I<W1E;6$@<&]D96T@86QT97)A<B!A<R`B"B)P97)M:7-S
M]65S(&1E('!R;W!R:65D861E(&]U('!R;W!R:65TX7)I;R!D92!U;2!C;VUP
M87)T:6QH86UE;G1O(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D%B<FER(&5M('5M82!N;W9A(&IA;F5L82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R(")%<G)O(&1O($]P96Y34TPZ($[C;R!P
M=61E(&5X=')A:7(@9&%D;W,@9&$@<&%R=&4@87-S:6YA9&$@4R]-24U%+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R(")!8G)E(&5S=&4@;&EN:R!E;2!U;6$@;F]V82!J86YE;&$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN
M9R!3>7-T96TB"FUS9W-T<B`B4VES=&5M82!/<&5R86-I;VYA;"(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B
M"FUS9W-T<B`B3W#G]65S(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]PY_5E<R!D92`E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@
M(D]R9&5R960@3&ES="(*;7-G<W1R("),:7-T82!/<F1E;F%D82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A
M;FES871I;VXB"FUS9W-T<B`B3W)G86YI>F'GXV\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N
M86P@56YI="(*;7-G<W1R(")5;FED861E($]R9V%N:7IA8VEO;F%L(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN
M9R(*;7-G<W1R(")/<F=A;FEZ86YD;R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*
M;7-G<W1R(")-;V1E;&\@;W)I9VEN86P@9&4@87!L:6-AY^-O(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")-;V1E;&\@;W)I9VEN
M86P@96T@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S
M='(@(D]U=')O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I
M9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B3W5T<F%S($EN9F]R;6'G
M]65S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B
M3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!0<F]P
M<FEE=.%R:6\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*
M;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")!=71E;G1I8V'GXV\@4$%-(&[C;R!E<W3A(&1I<W!O;NUV96PN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B0V]N96-T
M;W(@4$5!4CHZ36%I;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R
M(")!<W-I;F%T=7)A($1I9VET86P@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(D1A9&]S($-R:7!T;V=R869A9&]S(&-O;2!01U`B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@
M4'5B;&EC($ME>2(*;7-G<W1R(")#:&%V92!0^F)L:6-A(%!'4"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%D;W,@07-S:6YA9&]S
M+T-R:7!T;V=R869A9&]S(&-O;2!01U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(D/S9&EG;R!02%`B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G
M<W1R("),:6YH82!D92!#;VUA;F1O(%!(4"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN
M(@IM<V=S='(@(D-H=79A($9R86-A(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4F%I
M;B(*;7-G<W1R(")#:'5V82!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B
M"FUS9W-T<B`B0VAU=F%S(%9E<W!E<G1I;F%S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<B"FUS
M9W-T<B`B3F5V92!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R(").979A<V-A(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4W5N(@IM<V=S
M='(@(DYE=F4@5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R
M(")4<F]V;V%D87,@5F5S<&5R=&EN87,B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*
M;7-G<W1R(")%<W3A(&9A;'1A;F1O(&$@97AT96YSXV\@4$]325@B"@HC.B!L
M:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B3&EN
M:&$@9&4@0V]M86YD;R!07TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G
M<W1R(")-87)G96TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM
M<V=S='(@(E!A<75I<W3C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;F\L
M(%1E<G)I=/-R:6\@3V-U<&%D;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(E!A;F%MX2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P
M=6$@3F5W($=U:6YE82(*;7-G<W1R(")0X7!U82!.;W9A($=U:6[I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U86DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM
M<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")087)C:6%L;65N=&4@3G5B
M;&%D;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C(*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E-E;FAA(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4V5N:&$@86QT97)A9&$@
M8V]M('-U8V5S<V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B
M4V5N:&$@:6YC;W)R971A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I
M=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4V5N:&$@;V)R:6=A=/-R:6$@
M<&%R82!A(&%U=&5N=&EC8>?C;R!2041)55,N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`U-PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B4V5N:&$@8V]M(&-O;F9I<FUAY^-O(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`B4V5N:&$Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4V5N:&$Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#,X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G
M:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")396YH87,@9&5V
M96T@<V5R(&EG=6%I<RXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B0V]L87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F
M<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")#;VQA<B!D82#A<F5A(&1E('1R86YS
M9F5RZFYC:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(E!A=&@B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N
M=7!S.B(*;7-G<W1R(")#861A<W1R;W,@4&5N9&5N=&5S.B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E!E
M<W-O87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0;W)C96YT86=E;2(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y
M"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T
M<B`B17AE8W5T87(@3W!E<F'G]65S(&1E($UA;G5T96[GXV\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D5X96-U=&%R(&]P
M97)AY_5E<R!D92!M86YU=&5NY^-O(&%O(&-O;F5C=&%R/R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N
M(@IM<V=S='(@(E!E<FUI<W/C;R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@
M;F]T(&1E;&5T960N(@IM<V=S='(@(E!E<FUI<W/C;R!<(B5S7"(@;N-O(&5X
M8VQU[61A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")097)M:7-SXV\@3F5G
M861A(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(E!E<FUI<W/U97,B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!
M9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U97,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S
M='(@(DEN9F]R;6'G]65S(%!E<W-O86ES(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B06YI;6%I<R!D92!%<W1I;6'G
MXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@
M(D9I;&EP:6YA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VYE(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S
M(@IM<V=S='(@(D9O=&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I
M<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@
M(E!I>&5L<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B
M4&QA=&ET=61E<R(*;7-G<W1R(")#;&EC:.DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B4&]R(&9A=F]R(&-L
M:7%U92!E;2!A;&=U;6$@8^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(@IM<V=S='(@(E!O<B!F879O<B!C;VYF:7)M92!Q=64@=F]CZB!Q=65R(')E
M;6]V97(@97-T92!E;&5M96YT;SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB
M"FUS9W-T<B`B4&]R(&9A=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@<F5M
M;W9E<B!O(&QI;FL@9&5S=&4@96QE;65N=&\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4V-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@=6T@;>IS
M(&4@=6T@86YO+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!U
M;2!N;VUE('!A<F$@82!N;W9A(&-A=&5G;W)I83HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S`U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+B(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!U;2!E
M;F1E<F7G;R!)4"!VX6QI9&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8T-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B
M4&]R(&9A=F]R(&9O<FYEYV$@=6UA(&1A=&$@=N%L:61A+"!V97)I9FEQ=64@
M;R!N^FUE<F\@9&4@9&EA<R!N;R!MZG,N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92XB"FUS9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@=6UA(&AO<F$@=N%L:61A
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@
M(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS
M9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@=6T@<F5S=6UO(&1O('!R;V)L96UA
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4&]R(&9A=F]R(&9O
M<FYEYV$@<V5U('5S=>%R:6\@92!S96YH82(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO
M=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB4&]R(&9A=F]R(&QE:6$@
M;R!T97AT;R!A('-E9W5I<BX@5F]CZB!$159%(&-O;F-O<F1A<B!C;VT@;W,@
M=&5R;6]S(&1E('5S;R!D;R`B"B)S:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A
M<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E!O<B!F
M879O<B!D:6=I=&4@;R!N;VUE(&1A(&YO=F$@8V%T96=O<FEA.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;/1N:6$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(E!O;.UT:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B16YQ=65T92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@
M(E!O<VGGXV\@9&5S=&$@:6UA9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:>?C;R!D97-T82!T86)E;&$B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I
M9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M(@IM<V=S='(@(D5N=FEE('!A<F$@97-T82!P87-T82`H;N-O(.D@;V)R:6=A
M9&\@<&5L;R!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R
M96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!R
M96-I<&ET8>?C;R!P87)A(&$H<RD@^FQT:6UA*',I("5S(&AO<F$H<RDZ("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R
M96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4')E8VEP:71AY^-O
M/&)R("\^8VAA;F-E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N
M<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z($5X=&5N<^-O
M($Q$05`@;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ($5X=&5N<^-O(&1E('-E<W/C;R!O
M8G)I9V%T\W)I82!NXV\@96YC;VYT<F%D82XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B4')E<W/C;R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(*;7-G<W1R(")0<F5S<^-O(&5M(&[M=F5L(&1O(&UA
M<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R(")0<F5S<^-O.B`B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4')E=FEE=R(*;7-G<W1R(")0<NDM=FES=6%L:7IAY^-O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B4')E=F5R(&$@:6UA9V5M(&5M('5M82!N;W9A(&IA;F5L
M82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O
M<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!A;G1E<FEO<F5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I
M;G0@9&]C=6UE;G0B"FUS9W-T<B`B26UP<FEM:7(@9&]C=6UE;G1O(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV
M871E($ME>2(*;7-G<W1R(")#:&%V92!0<FEV861A(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G
M<W1R(")0<F]B;&5M82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM
M<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\@
M9&\@4')O8FQE;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q
M"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J971O<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$Y,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED
M(")0<F]M<'0@=&5X="(*;7-G<W1R(")497AT;R!B<F5V92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME
M>2(*;7-G<W1R(")#:&%V92!0^F)L:6-A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(D%L9V]R:71M;R!D82!#:&%V92!0^F)L:6-A(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U
M8FQI8R!+97D@26YF;R(*;7-G<W1R(")#:&%V92!0^F)L:6-A(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")087(@9&4@8VAA=F5S(%#Z8FQI8V$O4')I=F%D82!NXV\@9F]R
M86T@9V5R861O<R!C;VT@<W5C97-S;RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED
M(")0=65R=&\@4FEC;R(*;7-G<W1R(")0;W)T;R!2:6-O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T87(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(D-O;G-U;'1A
M<B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B
M"FUS9W-T<B`B46%T87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME
M>2`H)60@8FET*2(*;7-G<W1R(")#:&%V92!0^F)L:6-A(%)302`H)60@8FET
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R(")";W3U97,@9&4@<V5L9>?C;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED
M(")286EN(@IM<V=S='(@(D-H=79A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`B0VAU=F$@36%T=71I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(D-H
M=79A(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B4&%N
M8V%D87,@9&4@0VAU=F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")#
M:'5V82!E($YE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(D-H=79A
M('!A<F$@3F5V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED
M(")286YD;VT@1F]R='5N92(*;7-G<W1R(")3;W)T92!!;&5A=/-R:6$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(E)E;&'GXV\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),97(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B
M4F5A9"!M97-S86=E<R(*;7-G<W1R("),97(@;65N<V%G96YS(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(D5X8VQU:7(@<F5A;&UE;G1E("5S/R!%
M<W1A(&]P97)AY^-O(&[C;R!P;V1E('-E<B!D97-F96ET82XB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB4F5M
M;W9E<B!R96%L;65N=&4@;W,@9&%D;W,@9&\@=7-UX7)I;R`E<S\@17-T82!O
M<&5R8>?C;R!NXV\@<&]D92!S97(@(@HB9&5S9F5I=&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B4F5F87H@<W5A(/IL=&EM
M82!AY^-O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B071U
M86QI>F%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D%T=6%L
M:7IA<B!-96YU(&1E($5L96UE;G1O<R!$:6[B;6EC;W,Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE
M=SHB"FUS9W-T<B`B071U86QI>F%R($5X:6)IY^-O(&1O(%!O<G1A;#HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,S@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R
M(@IM<V=S='(@(DYA=F5G861O<B!D92!296QAY_5E<R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("),97(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")/
M8G-E<G9AY_5E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G
M:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E-E<G9I9&]R97,@4F5M;W1O
M<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(E523"!296UO=&$@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M
M;W9E(@IM<V=S='(@(E)E;6]V97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")296UO
M=F5R($)L;V-O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")296UO
M=F5R(&-O;'5N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@
M(E)E;6]V97(@9F]R;6%T8>?C;R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")296UO=F5R
M('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E
M;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+B(*;7-G<W1R(")296UO=F5R('-C<FEP="!G<F%V861O(&YO(&1I
M<F5T\W)I;R!T96UP;W+A<FEO(&1O('-E<G9I9&]R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I
M9"`B4F5M;W9E('1H92(*;7-G<W1R(")296UO=F5R(&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G
M:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T
M<B`B4F5M;W9E<B!E<W1E(&[S(&1O(&1O8W5M96YT;R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R
M(@IM<V=S='(@(E)E;6]V97(@=7-UX7)I;R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO
M=F4@=7-E<CH@)7,B"FUS9W-T<B`B4F5M;W9E<B!U<W7A<FEO.B`E<R(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U
M97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z
M("(*;7-G<W1R(")3;VQI8VET8>?C;R!NXV\@</1D92!S97(@<F5S<&]N9&ED
M82X@0_-D:6=O(&1E(&5R<F\@<F5T;W)N861O.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC
M92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D\@<V5R=FGG;R!R97%U
M:7-I=&%D;R!NXV\@<&]D92!S97(@96YC;VYT<F%D;RXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$W-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G
M)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I
M9W5R8>?C;R`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W
M."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P
M96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R!61E,N(@H*(SH@9G)A;65W;W)K
M+U5T:6PO571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@
M;F$@8V]N9FEG=7)AY^-O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B
M0V%M<&\@3V)R:6=A=/-R:6\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS-#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM
M<V=I9"`B4F5S970B"FUS9W-T<B`B3&EM<&%R(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S
M='(@(D=E<F%R($YO=F$@4V5N:&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R
M(")'97)A<B!.;W9A(%-E;FAA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(MIL=&EM;R!1
M=6%R=&\B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE
M;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")297-U;'1A9&]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED
M(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")2971O<FYA<B#@($]PY_5E
M<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B
M4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")$:6=I=&4@82!N;W9A('-E
M;FAA(&YO=F%M96YT92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB
M"FUS9W-T<B`B4F5U;FGC;R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B4F5V97)T97(@0V]N9FEG=7)AY^-O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT
M($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D;R!%9&ET;W(@4FEC
M:"!497AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2
M:61D;&5S(@IM<V=S='(@(D-H87)A9&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*
M;7-G<W1R(")$:7)E:71A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$Q,`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(D-A8F7G86QH;R!D
M:7)E:71O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-@IM<V=I
M9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E9A;&]R97,@9&$@9&ER96ET82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R
M;W!R:65D861E<R!D82!?3&EN:&$N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@
M(D9U;N?C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T
M<B`B4F]MZFYI82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C0*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B1VER87(@
M,3@P(&=R875S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B1VER87(@
M<&%R82!A($5S<75E<F1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-PIM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(D=I<F%R('!A<F$@82!$:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A($QI;FAA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM
M<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A
M(&QI;FAA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(DQI;FAA<SHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S
M"FUS9VED(")2=6QE<R(*;7-G<W1R("),:6YH87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(@IM<V=S='(@(DQI;FAA<R!A<&%R96-E<N-O(&5N=')E('1O9&%S(&%S(&QI
M;FAA<R!E(&-O;'5N87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("),:6YH87,@87!A<F5C
M97+C;R!S;VUE;G1E(&5N=')E(&-O;'5N87,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("),:6YH
M87,@87!A<F5C97+C;R!S;VUE;G1E(&5N=')E(&QI;FAA<R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R(")%>&5C=71A
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R(")&961E<F'GXV\@4G5S<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")2=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R92(*;7-G<W1R(")!<W-I;F%T=7)A($-R:7!T;V=RX69I
M8V$@4R]-24U%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R
M(")-96YS86=E;2!#<FEP=&]G<F%F861A(&-O;2!3+TU)344B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%U=&5N=&EC
M8>?C;R!305-,(&[C;R!E<W3A(&1I<W!O;NUV96PN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G
M<W1R(")#;W)R96EO(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM
M<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(DQI;FAA(&1E(&-O;6%N9&\@4U%,
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B4U%,
M('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")396YT96[G
M82!344P@<&%R82!P97-Q=6ES87,@9&4@=F%L;W)E<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(E-5
M0T534T\B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB
M"FUS9W-T<B`B3&EN:&$@9&4@8V]M86YD;R!37U%,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS
M9W-T<B`B4V%B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA
M(@IM<V=S='(@(E-A;G1A($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E/C;R!+:71T<R!E($YE
M=FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R
M(")386YT82!,=7II82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4^-O(%!E9')O(&4@36EQ=65L
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")3XV\@5FEC96YT92!E($=R86YA9&EN
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B365S;6\@
M<75A9')O("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*
M;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")3XV\@5&]MZ2!E(%!R
M[6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM
M<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E!R;W9E9&]R(&1E
M(%-A=.EL:71E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA
M(@IM<V=S='(@(D%RX6)I82!3875D:71A(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9A<B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4V%L=F%R("5S
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")386QV87(@)7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`B4V%L=F%R($]PY_5E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB4V%L=F%R(&-O;F9I9W5R8>?C
M;R!G97)A9&$@8V]M;R!U;2!S8W)I<'0@4$A0('!A<F$@;R!D:7)E=/-R:6\@
M=&5M<&]RX7)I;R!D;R`B"B)S974@<V5R=FED;W(N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0V]N9FEG=7)AY^-O("5S('-A
M;'9A+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(E-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF
M:6=U<F'GXV\@<V%L=F\@96TZ("<E<R<N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T
M;W)M<R(*;7-G<W1R(")496UP97-T861E<R!)<V]L861A<R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")#
M:>IN8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C
M:"(*;7-G<W1R(")097-Q=6ES87(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")%;F=I
M;F5S(&1E(%!E<W%U:7-A("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-C(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")396QE8VEO;F4@
M;W,@07)Q=6EV;W,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@S"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E
M;&5C:6]N92!U;6$@9&%T82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B
M4V5L96-I;VYE('5M(&=R=7!O('!A<F$@861I8VEO;F%R(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W
M;F5R(@IM<V=S='(@(E-E;&5C:6]N92!U;2!N;W9O(&UE;6)R;R(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@
M<V5R=F5R(@IM<V=S='(@(E-E;&5C:6]N92!U;2!S97)V:61O<B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U
M<V5R('1O(&%D9"(*;7-G<W1R(")396QE8VEO;F4@=6T@=7-UX7)I;R!P87)A
M(&%D:6-I;VYA<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S0*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B4V5L96-I
M;VYA<B!T;V1O<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3`*
M;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")3
M96QE8VEO;F4@=&]D;W,@;W,@8V]M<&]N96YT97,@9&4@9&%T82XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<Q"FUS9VED
M(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E-E;&5C:6]N92!U;2!O8FIE
M=&\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<U"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(").XV\@<V5L96-I;VYA
M<B!N96YH=6TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)396QE8VEO;F4@
M;W,@8V%R86-T97)E<R!Q=64@=F]CZB!P<F5C:7-A(&YA(&-A:7AA(&%B86EX
M;RX@5F]CZB!P;V1E(&5N=.-O("(*(F-O<&GA+6QO<R!E(&-O;.$M;&]S(&YA
M(.%R96$@9&4@=&5X=&\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@
M(E-E;&5C:6]N92!U;2!D96QI;6ET861O<B!D92!D871A.B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.B(*;7-G<W1R(")396QE8VEO;F4@;R!F;W)M871O(&1E(&1A=&$Z
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM
M<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M(@IM<V=S='(@(E-E;&5C:6]N92!A(&ED96YT:61A9&4@<75E('9O8^H@<75E
M<B!A;'1E<F%R.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS
M9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE
M8VEO;F4@=6T@9&5L:6UI=&%D;W(@9&4@:&]R83HB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA
M=#HB"FUS9W-T<B`B4V5L96-I;VYE(&\@9F]R;6%T;R!D92!H;W)A.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")396QE8VEO;F4@9&]I<R!C
M86UP;W,@8V]R<F5S<&]N9&5N=&5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS
M9W-T<B`B4V5L96-I;VYE('-E=2!E<W%U96UA(&1E(&-O<F5S+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4V5L96-I;VYE('-E=2!I9&EO
M;6$@<')E9F5R:61O.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D5N
M=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,`IM<V=I9"`B4V5N9"!335,B
M"FUS9W-T<B`B16YV:6%R(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS;W(Z("(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED
M(")397!T96UB97(B"FUS9W-T<B`B4V5T96UB<F\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(E-E<G9I82!E($UO;G1E;F5G<F\B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R
M:6%L($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@4^ER:64B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")$861O<R!D;R!S
M97)V:61O<B!E<G)A9&]S(&]U(&[C;R!D:7-P;V[M=F5I<RXB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T
M<B`B061M:6YI<W1R861O<B!D92!397-SXV\B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I
M;VX@240@97AP:7)E9"XB"FUS9W-T<B`B240@9&$@4V5S<^-O(&5X<&ER;W4N
M(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R
M(")397-S]65S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q.`IM
M<V=I9"`B4V5T(@IM<V=S='(@(D%J=7-T87(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB
M"FUS9W-T<B`B(@HB0V]N9FEG=7)A(&%S(&]PY_5E<R!P87)A('!E<FUI=&ER
M('9O8^H@9V5R87(@=6UA(&YO=F$@<V5N:&$@<V4@=F]CZB!E<W%U96/J+2(*
M(FQA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B)#;VYF:6=U<F$@;W,@<V5R
M=FED;W)E<R!R96UO=&]S('%U92!V;V/J('%U97(@86-E<W-A<B#@('!A<G1I
M<B!D;R!P;W)T86PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS
M9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(D-O;F9I9W5R82!S974@:61I;VUA
M('!R969E<FED;RP@9G5S;R!H;W+A<FEO(&4@;W#G]65S(&1E(&1A=&$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(B(*(D-O;F9I9W5R82!S=6$@87!L:6-AY^-O(&EN:6-I86PL(&5S<75E
M;6$@9&4@8V]R97,L(&%T=6%L:7IAY^-O(&1E('#A9VEN87,@92`B"B)O=71R
M87,@;W#G]65S(&1E(&5X:6)IY^-O+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(D-O;F9I9W5R8>?C;R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(E-C
M<FEP=',@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV
M96ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`B1&EV97)S87,@;&]C86QI9&%D97,@<&]S<^UV96ES
M(&-O;2!O('!A<N)M971R;SH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y
M8VAE;&QE<R(*;7-G<W1R(")396EC:&5L97,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")#;VUP
M<F%S(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G
M:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4F5S=6UO(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(E1E8VQA<R!D
M92!A=&%L:&\@9&5V97+C;R!S97(@9&5F:6YI9&%S('!A<F$@82!M86EO<FEA
M(&1O<R!L:6YK<S\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")%>&EB:7(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(D5X:6)I<B!A<R!D
M:69E<F5NYV%S(&5N=')E(&$@8V]N9FEG=7)AY^-O(&%T=6%L(&4@82!N;W9A
M(&=E<F%D82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(D5X:6)I<B!D871A(&4@:&]R82!D82#Z;'1I;6$@8V]N97CC;R!A;R!S
M92!C;VYE8W1A<C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Y
M"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@
M(D5X:6)I<B!A(&]PY^-O(&1E(&UA;G1E<B!O(&]R:6=I;F%L(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,@IM<V=I9"`B4VAO=R!P:6-K97(B
M"FUS9W-T<B`B17AI8FER('-E;&5T;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_(@IM<V=S='(@(D5X:6)I<B!B87)R82!D92!M96YU(&-O;2!O<&5R8>?U
M97,@9&4@=&%B96QA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\B"FUS9W-T<B`B17AI8FER(&\@365N=2`E<R#@(&5S<75E<F1A/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R(")%>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D
M97,@9&4@0^EL=6QA<R!D82!486)E;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D5X:6)I<B!D
M:>%L;V=O(&1E(%!R;W!R:65D861E<R!D82!486)E;&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G
M:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R(")%>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@3&EN:&%S
M(&1A(%1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B17AI8FER(&1IX6QO9V\@9&4@<')O
M<')I961A9&5S(&1E(&EM86=E;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W-C<*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(D5X:6)I<B!U
M<&QO860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")#:'5V87,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO
M=V5R<R!%87)L>2(*;7-G<W1R(")#:'5V87,@;6%T:6YA:7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO
M=V5R<R!,871E(@IM<V=S='(@(D-H=79A<R!697-P97)T:6YA<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3
M:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")#:'5V87,@;F%S(')E
M9&]N9&5Z87,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(E)E9'5Z:7(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK
M(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y
M(&9I<G-T(@IM<V=S='(@(E!R:6UE:7)A;65N=&4@<F5D=7IA(&]U('1I<F4@
M9&\@8V%M:6YH;R!O*',I(&)L;V-O*',I(&%D:F%C96YT92AS*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")397)R82!,
M96]A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-@IM
M<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")296=I<W1R87(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E
M(@IM<V=S='(@(D%S<VEN871U<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*
M;7-G<W1R(")!;&=O<FET;6\@9&$@07-S:6YA='5R82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")#:6YG87!U<F$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY,#`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$R"FUS9VED(")3:7IE(@IM<V=S
M='(@(E1A;6%N:&\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M("))9VYO<F%R($UA;G5T96[GXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M;&]V86MI82(*;7-G<W1R(")%<VQO=N%Q=6EA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B17-L;W9E;FEA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<B
M"FUS9W-T<B`B3F5V92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(").979A
M<V-A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3<*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(").979A<V-A<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B0VAU=F%S(&UA=&EN86ES
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*
M;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(DYE=F%S8V%S(%9E
M<W!E<G1I;F%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@
M(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")0<F]F=6YD:61A9&4@9&$@3F5V93H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*;7-G:60@(E-N;W<@97%U
M:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(D5Q=6EV86QE;G1E(&1E(&YE
M=F4@96T@X6=U83H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)
M<VQA;F1S(@IM<V=S='(@(DEL:&%S(%-A;&]MXV\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;>%L:6$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T
M<B`B0V%NY_5E<R`F(%!O96UA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,34*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@
M(D]R9&5N87(@<V5L9>?C;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R
M97-S(@IM<V=S='(@(D5N9&5R9>=O(&1E(&]R:6=E;2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("+!9G)I8V$@9&\@4W5L
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")3=6P@175R;W!E=2`H25-/
M+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@
M86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(E-U;"!D
M82!'96]R9VEA(&4@4W5L(&1A<R!);&AA<R!386YD=>UC:&4B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED
M(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9NER:6\@4W5L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T
M<B`B17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S
M='(@(D5S<&'G;R!E;G1R92!O(&-O;G1E^F1O(&4@8F]R9&$@9&$@8^EL=6QA
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$Y"FUS9VED(")3<&%C
M97(B"FUS9W-T<B`B17-P8>=A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM
M<V=S='(@(D5S<&'G86UE;G1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@
M<&%D9&EN9R(*;7-G<W1R(")%<W!AYV%M96YT;R!E(&UA<F=E;2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")%<W!A;FAA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R
M(")3<&%M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")%;G1R861A(&1E($-A
M<F%C=&5R97,@17-P96-I86ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*
M;7-G<W1R(")$:79I9&ER(&/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O
M;'5M;B(*;7-G<W1R(")$:79I9&ER(&-O;'5N82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P
M;&ET(')O=R(*;7-G<W1R(")$:79I9&ER(&QI;FAA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B17-P;W)T
M97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3
M<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T
M<B`B4&%D<N-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED
M(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-SDX"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%N;R!I;FEC:6%L(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(D5S=&%D;R!O=2!0<F]V[6YC
M:6$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(E-I='5AY^-O(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P-`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS
M9W-T<B`B1F]R;6%T;R!D;R!A<FUA>F5N86UE;G1O(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R
M97-S(@IM<V=S='(@(DYO;64@9&$@4G5A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G
M:"(*;7-G<W1R(")4<F'G861O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@
M8V%D96EA<R!D92!C87)A8W1E<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,B"FUS9W-T<B`B4F5T:7)A<B!A('!A<G1E(&1O(&1O;>UN:6\@9&\@96YD
M97)EYV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")%<W1I
M;&\@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")$;VTB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E-U8F1I<F5T\W)I
M;R`G)7,G(&[C;R!E;F-O;G1R861O+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`B07-S=6YT;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U
M8FUI="(*;7-G<W1R(")%;G9I87(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@
M>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B
M"B)%;G9I861A(&$@<V]L:6-I=&'GXV\@9&4@861I8VEO;F%R(%PB)7-<(B!A
M;R!S:7-T96UA+B!6;V/J(&[C;R!P;V1E(&-O;F5C=&%R+2(*(G-E(&%TZ2!Q
M=64@<W5A('-O;&EC:71AY^-O('-E:F$@87!R;W9A9&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(E-U8G-C<F5V97(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B4W5C97-S;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!A9&EC:6]N861O(&-O;2!S=6-E<W-O
M(&%O('-I<W1E;6$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B3W,@9&%D;W,@
M9&\@=7-UX7)I;R`G)7,G(&9O<F%M(')E;6]V:61O<R!D;R!S:7-T96UA(&-O
M;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(B<E<R<@97AC;'7M9&\@
M8V]M('-U8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(D5X8VQU[61O("<E<R<@9&\@<VES=&5M
M82!C;VT@<W5C97-S;RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R(")#;VYF:6=U<F'GXV\@
M<F5V97)T:61A(&-O;2!S=6-E<W-O+B!!='5A;&EZ92!P87)A('9E<B!A<R!A
M;'1E<F'G]65S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"86-K=7`@9&$@
M8V]N9FEG=7)AY^-O('-A;'9A(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R(")/(&)A8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C
M;R`E<R!F;VD@<V%L=F\@8V]M('-U8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A
M=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G(&%T=6%L:7IA9&\@8V]M('-U8V5S
M<V\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@9W)A=F%D;R!C;VT@<W5C97-S;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9.-O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")297-U;6\B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@
M(D%M86YH96-E<B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I
M9"`B4W5N(%-E="(*;7-G<W1R(")0]'(M9&\M4V]L(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-U;FYY(@IM
M<V=S='(@(D5N<V]L87)A9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D%M86YH96-E<B(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B06UA;FAE
M8V5R+U#T<BUD;RU3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B06UA;FAE8V5R.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3
M=6YS970B"FUS9W-T<B`B4/1R+61O+5-O;"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(E#T
M<BUD;RU3;VPZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(E-O8G)E
M<V-R979E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G
M:60@(E-U<'!O<G0B"FUS9W-T<B`B4W5P;W)T92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*
M;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86UE(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B
M"FUS9W-T<B`B4V]B<F5N;VUE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A
M;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!E($IA;B!-
M87EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R
M(")3=6%Z:6SB;F1I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*
M;7-G<W1R(")3=>EC:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA
M;F0B"FUS9W-T<B`B4W7MYV$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(").XV\@
M97AC;'5I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@
M(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B17)R;R!D92!S:6YT87AE(&YO<R!T97)M;W,@
M9&$@<&5S<75I<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A
M8B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@P7)A8F4@9&$@4^UR:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM
M<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")496UP97-T861E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O
M<FT@86YD(%=I;F1Y(@IM<V=S='(@(E1E;7!E<W1A9&5S(&4@5F5N=&%N:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM
M<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&5S=&%D97,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3
M=&]R;7,@16%R;'DB"FUS9W-T<B`B5&5M<&5S=&%D97,@36%T:6YA:7,B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@
M9FEL92(*;7-G<W1R(")!<G%U:79O(%135B(*"B,Z(&9R86UE=V]R:R]522]5
M22]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")486)E;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R
M:65D861E<R!D82!486)E;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B
M5&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R
M(")0<F]P<FEE9&%D97,@9&$@=&%B96QA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A:7=A;BP@4')O=NUN8VEA(&1A
M($-H:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R(")486II<75I<W3C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>N)N:6$L(%)E
M</IB;&EC82!D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B06QV;SHB"@HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(E1A<F5F87,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B
M5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@5&5L969O;F4B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@<&%R82!A(/IL=&EM
M82!H;W)A.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B
M5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U<F$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@
M(@IM<V=S='(@(E1E;7!E<F%T=7)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M
M<&5R871U<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S*2`F9&5G.R5S(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B36]D96QO("<E<R<@;N-O(&5N8V]N=')A9&\N(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@36]D96QO<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S-`IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G
M<W1R(")3;VUE;G1E(%1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*
M;7-G<W1R(")!;&EN:&%M96YT;R!D92!497AT;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B0F]R9&$@<W5P97)I;W(@9&\@5&5X=&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*
M;7-G<W1R(")1=6DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&%I;&%N9.IS("A425,M-C(P
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A
M:6SB;F1I82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS
M9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")!(&5X=&5N<^-O($944"!NXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z
M(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@
M2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(D\@:&ES=/-R
M:6-O(&1O('-I<W1E;6$@97-TX2!D97-A8FEL:71A9&\N(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")!(&5N9VEN92!D92!I;G1E9W)AY^-O
M($AO<F1E+TMO;&%B(&[C;R!S=7!O<G1A(%PB)7-<(B(*"B,Z(&9R86UE=V]R
M:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0
M(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(D\@;&]G
M($E-4U`@;N-O('!O9&4@<V5R(&EN:6-I86QI>F%D;RXB"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B02!C
M;&%S<V4@7")-86EN=&5N86YC95PB(&[C;R!F;VD@8V%R<F5G861A(&-O;2!S
M=6-E<W-O(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR
M.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(D$@:F%N96QA(&1E($]PY_5E<R!F;VD@9F5C:&%D82X@
M4V%I;F1O+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B
M"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D\@861M:6YI<W1R861O<B!P
M<F5C:7-A(&-O;F9I9W5R87(@=6T@8V]N96-T;W(@<&5R;6%N96YT92!D92!0
M97)M:7-S]65S('-E("(*(G9O8^H@<75E<B!U=&EL:7IA<B!097)M:7-S]65S
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@
M(E-O;65N=&4@;R!L861O(&1E(&)A:7AO(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T
M<B`B(@HB3R!N^FUE<F\@240@9&\@8V]N=&%T;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;RP@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2`B"B)E;F-O;G1R
M861O(&YO(&)A;F-O(&1E(&1A9&]S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B3R!C;VYT871O(&9O:2!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O
M('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB4&%R82!V97)I9FEC87(@
M82!M96YS86=E;2!A<W-I;F%D82#I(&YE8V5S<^%R:6\@=6T@8FQO8V\@<V5P
M87)A9&\@9&$@(@HB87-S:6YA='5R82!01U`N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S
M92XB"FUS9W-T<B`B(@HB3R!)1"!D82!L:7-T82!D92!D:7-T<FEB=6GGXV\@
M;N-O(&9O:2!E<W!E8VEF:6-A9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C
M;R`B"B)F;VD@96YC;VYT<F%D;R!N;R!B86YC;R!D92!D861O<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R(")!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S
M<&5C:69I8V%D82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q
M-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B07,@9G5NY_5E<R!D92!C
M<FEP=&]G<F%F:6$@<F5Q=65R96T@=6UA(&-O;F5XXV\@=V5B('-E9W5R82XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-R!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@
M(D\@87)Q=6EV;R`E<R!D979E<FEA(&-O;G1E<B!U;6$@8V]N9FEG=7)AY^-O
M(&1E("5S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<P(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N(@IM<V=S='(@(D\@87)Q=6EV;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U
M;6%S(&-O;F9I9W5R8>?U97,@9&4@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P
M:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")/(&%R<75I=F\@;N-O('!O9&4@
M<V5R(&-O<&EA9&\@<&%R82!E;&4@;65S;6\N(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@
M9&%T82XB"FUS9W-T<B`B3R!A<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM
M<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B4V5G=65M(&]S(&-A
M8F7G86QH;W,@9&5S=&$@;65N<V%G96TO;65N<V%G96T@<F9C.#(R+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G
M:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*
M(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB
M"FUS9W-T<B`B(@HBR2!S86)I9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A
M=7-A('!R;V)L96UA<R!C;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@96T@(@HB
M=FER='5D92!D92!B=6=S(&1O(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A
M;6]S(&%P=&]S(&$@8V]N=&]R;F%R+B!6;V/J("(*(G!O9&4@;V)S97)V87(@
M97)R;W,@9&4@97AI8FGGXV\L(&9A;'1A(&1E(&9U;N?U97,@9&\@961I=&]R
M(&4O;W4@=')A=F%M96YT;W,@(@HB86QE873S<FEO<R!D;R!N879E9V%D;W(N
M(%-E('-E=2!S:7-T96UA(.D@5VEN9&]W<R`Y>"#I(&UU:71O('!R;W;A=F5L
M('%U92`B"B)V;V/J(')E8V5B82!U;2!E<G)O(&1E("=&86QH82!'97)A;"!D
M92!0<F]T9>?C;R<@92!P<F5C:7-A<N$@<F5I;FEC:6%R+B!<7&XB"B)<7&X@
M5F]CZB!F;VD@879I<V%D;RX@4&]R(&9A=F]R('!R97-S:6]N92!/2R!S92!V
M;V/J(&%I;F1A('%U97(@=&5N=&%R('5S87(@(@HB;R!E9&ET;W(@9&4@=&5L
M82!C:&5I82XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B02!I9&5N=&ED861E(%PB)7-<(B!F;VD@97AC;'7M
M9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS
M9W-T<B`B4V]M96YT92!O(&QA9&\@97-Q=65R9&\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)!(&QO8V%L:7IAY^-O(&1O
M(&)I;N%R:6\@9&\@1VYU4$<@9&5V92!S97(@9F]R;F5C:61A(.`@8VQA<W-E
M(%PB0W)Y<'1?<&=P7"(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN
M<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S
M96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@
M9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@
M(B(*(D$@;65N<V%G96T@96YV:6%D82!E;2`E<R!P87)A("5S(&-O;2!O(&%S
M<W5N=&\@7"(E<UPB(&9O:2!E>&EB:61A+EQN(@HB27-T;R!NXV\@9V%R86YT
M92!Q=64@82!M96YS86=E;2!F;VD@;&ED82!O=2!E;G1E;F1I9&$N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(D\@;F]M92!U=&EL:7IA9&\@86\@=FEN8W5L87(@82!PX6=I;F$@9&4@
M8V]M<&]S:>?C;R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W
M-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC
M+B(*;7-G<W1R(")/(&[Z;65R;R!D92!C86UP;W,@9&5V92!S97(@;G5MZ7)I
M8V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R
M"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")/(&WS9'5L
M;R!O<&5N<W-L(.D@;V)R:6=A=/-R:6\@<&%R82!A(&-L87-S92!<(DAO<F1E
M7T-R>7!T7W-M:6UE7"(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H
M<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@
M7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@
M(B(*(D$@<')E9F5RZFYC:6$@7"(E<UPB(&[C;R!P;V1E('-E<B!S86QV82!P
M;W)Q=64@<V5U<R!D861O<R!E>&-E9&5R86T@;R`B"B)T86UA;FAO(&WA>&EM
M;R!P97)M:71I9&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D
M96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R
M:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O
M=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI
M9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(D\@<')O9W)A;6$@
M=71I;&EZ861O('!A<F$@=FES=6%L:7IA<B!E<W1E('1I<&\@9&4@9&%D;R`H
M)7,I(&[C;R!F;VD@(@HB96YC;VYT<F%D;R!N;R!S:7-T96UA+B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E
M(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G
M<W1R(")/(&-A<F%C=&5R92!P87)A(&-I=&'GXV\@9&4@<V5R(&%P96YA<R!U
M;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL
M>2(*;7-G<W1R(")3;VUE;G1E(&]S(&QA9&]S(&1I<F5I=&\@92!E<W%U97)D
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R(")3;VUE;G1E(&\@;&%D;R!D:7)E:71O(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D\@<V5P87)A9&]R
M(&1E=F4@<V5R('5M(/IN:6-O(&-A<F%C=&5R92XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")/('-E
M<G9I9&]R(%PB)7-<(B!F;VD@97AC;'7M9&\N(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E
M<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(D\@<V5R=FED
M;W(@7"(E<UPB(&9O:2!S86QV;RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")!('-O;&EC:71AY^-O(&1E
M(&-A9&%S=')O(&1E("5S(&9O:2!E>&-L=>UD82XB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")!(&QI;FAA(&5S<&5C:69I8V%D82`H)60I(&[C;R!E
M>&ES=&4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3R!A<G%U:79O('1E;7!O<N%R:6\@
M7"(E<UPB(&[C;R!E>&ES=&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,P.0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M
M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R(")/('1E>'1O
M('%U92!V;V/J(&1I9VET;W4@;N-O(&-O<G)E<W!O;F1E(&%O('1E>'1O(&YA
M('1E;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'DB"FUS9W-T<B`B4V]M96YT92!O<R!L861O<R!D92!C:6UA(&4@9&4@
M8F%I>&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R
M(")3;VUE;G1E(&\@;&%D;R!D92!C:6UA(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B3W,@9&%D;W,@
M96YV:6%D;W,@9F]R86T@<&5R9&ED;W,@9&5S9&4@;R!P87-S;R!A;G1E<FEO
M<BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B3R!A<G%U:79O
M(&5N=FEA9&\@;N-O('#T9&4@<V5R('-A;'9O+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B3R!B;&]C;R!<(G=E871H97(N8V]M7"(@;N-O
M(&5S=.$@9&ES<&]N[79E;"XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")/(&1I<F5T\W)I;R!D92!T96UA<R`G
M)7,G(&[C;R!F;VD@96YC;VYT<F%D;RXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+B(*;7-G<W1R(").XV\@97AI<W1E;2!O<.?U97,@9&ES<&]N
M[79E:7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M,S0Y"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3N-O(&5X:7-T96T@<&%R=&5S('%U
M92!P;W-S86T@<V5R(&5X:6)I9&%S(&EN8V]R<&]R861A<RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)%>&ES=&5M(&UU
M:71O<R!C87)A8W1E<F5S(&YE<W1E(&-A;7!O+B!6;V/J('!R965N8VAE=2!C
M;VT@)7,@8V%R86-T97)E<SL@(@HB=F]CZB!D979E('!R965N8VAE<B!C;VT@
M)7,@;W4@;65N;W,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H
M<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B2&]U
M=F4@=6T@<')O8FQE;6$@861I8VEO;F%N9&\@)R5S)R!A;R!S:7-T96UA.B`E
M<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DAO=79E('5M('!R
M;V)L96UA(&%O(&5X8VQU:7(@9&\@<VES=&5M82!O<R!D861O<R!D;R!U<W7A
M<FEO("<E<R<Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M
M82!A;R!E>&-L=6ER("<E<R<@9&\@<VES=&5M83H@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W5V92!U;2!P
M<F]B;&5M82!A;R!A='5A;&EZ87(@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@
M)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M82!C
M;VT@;R!E;G9I;R!D;R!A<G%U:79O.B!.96YH=6T@)7,@9F]I(&5N=FEA9&\N
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3$U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*
M(DAO=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@
M)7,@97)A(&UA:6]R('%U92!O('1A;6%N:&\@(@HB;>%X:6UO('!E<FUI=&ED
M;R`H)60@8GET97,I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDQ-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)(;W5V92!U;2!P<F]B
M;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U:79O+B!/("5S(&9O:2!E;G9I861O
M('!A<F-I86QM96YT92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")(;W5V92!U;2!E
M<G)O(&%O(&5X:6)I<B!E<W1A('!A<G1E(&1A(&UE;G-A9V5M(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R(")(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O
M(&-O;G1A=&\N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82XB"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!I;7!O<G1A
M<B!O<R!D861O<R!D;R!I0V%L96YD87(N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(DAO=79E('5M(&5R<F\@
M;F\@9F]R;75LX7)I;R!D92!C;VYF:6=U<F'GXV\N(%1A;'9E>B!V;V/J(&1E
M:7AO=2!U;2!C86UP;R`B"B)O8G)I9V%T\W)I;R!E;2!B<F%N8V\N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)(;W5V92!U;2!E<G)O(&%O(&5X
M96-U=&%R(&$@9G5NY^-O(&1E(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!E<W!E
M8VEF:6-A9&$N("(*(E!O<B!F879O<B!T96YT92!N;W9A;65N=&4@;6%I<R!T
M87)D92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(DAO=79E('5M(&5R<F\@86\@871U86QI>F%R(&]S
M(&1E=&%L:&5S(&1O(&-O;G1A=&\N(%!O<B!F879O<B!T96YT92!N;W9A;65N
M=&4@(@HB;6%I<R!T87)D92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB2&]U=F4@=6T@97)R;R!A;R!A
M='5A;&EZ87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(%!O<B!F879O<B!T
M96YT92`B"B)N;W9A;65N=&4@;6%I<R!T87)D92XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!
M4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM
M<V=S='(@(D5S=&4@<V5R=FED;W(@24U!4"!NXV\@<W5P;W)T82!P87-T87,@
M8V]M<&%R=&EL:&%D87,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B17-T92!NXV\@<&%R
M96-E('-E<B!U;2!A<G%U:79O(')A<B!VX6QI9&\N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B
M17-T92!NXV\@<&%R96-E('-E<B!U;2!A<G%U:79O('II<"!VX6QI9&\N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-`IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(D5S=&4@;N-O('!A<F5C92!S97(@=6T@;OIM97)O(&1E(&-A<G3C;R!V
MX6QI9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P
M.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R("(B"B)%<W1E(&-O;F5C=&]R('!E<FUI=&4@96YV:6%R
M(&UE;G-A9V5N<R!A=')A=NES(&1O($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2DL('5T:6QI>F%N9&\@82!!4$D@2%144"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17-T92!C;VYE8W1O<B!P
M97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!G871E=V%Y('-M
M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI+"!U=&EL:7IA;F1O
M(&\@05!)($A45%`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*(D5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I
M87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT
M='`Z+R\B"B)S;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(5%10
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(D5S=&4@8V]N
M96-T;W(@<&5R;6ET92!E;G9I87(@=6UA(&UE;G-A9V5M('9I82!33510(&%T
M<F%VZ7,@9&\@5F]D869O;F4@(@HB271A;&EA;F\L('-O;65N=&4@<&%R82!N
M^FUE<F]S(%9O9&%F;VYE+B#)(&]B<FEG873S<FEO('!O<W-U:7(@=6UA(&-O
M;G1A(&YO("(*(E9O9&%F;VYE($ET86QI86YO("AH='1P.B\O=W=W+C$Y,"YI
M="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$Y"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(V,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#(*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,34V,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0S"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`P.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#(*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$U,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(U"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$R-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,3(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S@R,`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB"FUS9W-T<B`B17-T92!C86UP;R#I(&]B<FEG873S<FEO+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B17-T92!C86UP
M;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!I;G1E:7)O<RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G
M<W1R(")%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!N^FUE<F]S(&4@
M=NUR9W5L82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+B(*;7-G<W1R(")%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!V86QO
M<F5S(&]C=&%I<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(W
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)%<W1E(&-A
M;7!O(&1E=F4@<V5R('5M82!L:7-T82!D92!N^FUE<F]S(&EN=&5I<F]S('-E
M<&%R861A('!O<B!V[7)G=6QA<R!O=2`B"B)E<W!AYV]S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3DS"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D5S=&4@8V%M<&\@9&5V92!S
M97(@=6T@;OIM97)O(';A;&ED;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#(U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@9&5V92!C
M;VYT97(@=6T@8_-D:6=O(&1E(&-O<B!E;2!F;W)M871O(%)'0B!(97AA+"!P
M;W(@97AE;7!L;R`B"B(G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N(@IM<V=S='(@(D5S=&4@9F]R;75LX7)I;R!JX2!F;VD@
M<')O8V5S<V%D;RXB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("))<W1O
M(.D@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@
M1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*
M(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(D5S=&4@Z2!U
M;2!O8FIE=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9I<W5A;&EZ87(@97-T
M92!O8FIE=&\@=F]CZB!P<F5C:7-A<N$@(@HB9&4@=6T@8VQI96YT92!D92!C
M;W)R96EO('%U92!E;G1E;F1A(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N
M(%!A<F$@=6UA("(*(FQI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@8V]M
M(&5S=&%S(&9U;N?U97,@<&]R(&9A=F]R('9I<VET92`E<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HB
M17-T82!M96YS86=E;2!F;VD@97-C<FET82!E;2!U;2!C;VYJ=6YT;R!D92!C
M87)A8W1E<F5S("@E<RD@<75E(&[C;R#I(&\@(@HB;65S;6\@<75E(&\@<V5U
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED
M(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B
M17-T92!N^FUE<F\@9&5V92!S97(@<&5L;R!M96YO<R!U;2XB"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R(&[C;R!P;V1E(&1E<V-O;7!R:6UI
M<B!A<G%U:79O<R!Z:7`@92!G>FEP+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D5S=&4@<VES=&5M82!E
M<W3A(&%T=6%L;65N=&4@9&5S871I=F%D;RXB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+B(*;7-G<W1R(")%<W1E('9A;&]R(&1E=F4@<V5R('5M(&[Z
M;65R;RXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U
M"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W(@IM<V=S='(@(D5S=&$@:F%N96QA(&1E=F4@<V5R(&-H
M86UA9&$@82!P87)T:7(@9&$@:F%N96QA(&1E($]PY_5E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N
M9&5R(@IM<V=S='(@(E)A:6\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(D)I;&AE=&5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B2&]R82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A
M8VMI;F<B"FUS9W-T<B`B06-O;7!A;FAA;65N=&\@9&4@2&]RX7)I;R(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS
M9W-T<B`B1F]R;6%T;R!D92!H;W)A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4S-0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L
M9>?C;R!D92!H;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S
M=&4B"FUS9W-T<B`B5&EM;W(@3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4[71U;&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L
M92`H=&]O;'1I<"DZ(@IM<V=S='(@(D%S<W5N=&\@*&1I8V$I.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(E!A<F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4R"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP
M;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)0
M87)A('-E;&5C:6]N87(@;?IL=&EP;&]S(.UT96YS+"!S96=U<F4@82!T96-L
M82!#;VYT<F]L("A00RD@;W4@0V]M;6%N9"`B"B(H36%C*2!A;R!C;&EC87(N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B
M5&]D87DB"FUS9W-T<B`B2&]J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C
M92(*;7-G<W1R(")4<F]C87(@<&%R82!C\V1I9V\@2%1-3"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(D%M86YHXR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM
M<V=S='(@(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B5&]P;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*
M;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B475A9')O(&1O(%1O
M<&\@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED
M(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B5')A9'7G]65S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN
M9&%D92!E(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5F5R9&%D96ER;R!O
M=2!F86QS;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(E1E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N[7-I82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)Q=6EA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y
M+3DI(@IM<V=S='(@(E1U<F-O("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)C;VUE;FES=.-O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S(@IM<V=S='(@(DEL:&%S(%1U<FMS(&4@0V%I8V]S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R(")0<F5E;F-H82!C;VT@<W5A(&5S8V]L:&$Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD
M97@Z("(*;7-G<W1R("+-;F1I8V4@52Y6+CH@(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")5
M4DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS
M9W-T<B`B55),(&1O('-E=2!R96QA=/-R:6\@9&4@<VET=6'GXV\@9&4@96YT
M<F5G82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E5C<N)N:6$B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A
M8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S[79E;"!A8V5S
M<V%R(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("));7!O<W/M
M=F5L(&%D:6-I;VYA<B!I;F9O<FUAY_5E<R!E>'1R87,@9&4@=7-UX7)I;R!A
M;R!R96=I<W1R87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV
M96P@86QT97)A<B!P97)M:7-SXV\@9&\@87)Q=6EV;R!61E,@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Y,B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M(@IM<V=S='(@(DEM<&]S<^UV96P@86QT97)A<B!P97)M:7-SXV\@9&\@87)Q
M=6EV;R!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T
M;R`E<RXB"FUS9W-T<B`B26UP;W-S[79E;"!A;'1E<F%R('!A<F$@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D;R!A
M<G%U:79O(&1E(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV.34@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#(X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S
M7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@=F5R:69I8V%R(&\@=&%M86YH;R!D
M;R!A<G%U:79O(&1E(%PB)7,O)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(*;7-G<W1R("));7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E
M<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W
M,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@
M(DEM<&]S<^UV96P@8V]N96-T87(@=71I;&EZ86YD;R!34TPN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,R(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<^UV96P@8V]P
M:6%R(&%R<75I=F\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@8W)I
M87(@9&ER973S<FEO(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("))
M;7!O<W/M=F5L(&-R:6%R(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S[79E;"!C<FEA<B!A<G%U:79O
M(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@
M5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM
M<V=S='(@(DEM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!61E,@=F%Z:6\N(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("));7!O<W/M
M=F5L(&1E<V-O;7!R:6UI<B!D861O<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(R."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DEM<&]S<^UV
M96P@97AC;'5I<B!<(B5S7"(L(&\@9&ER973S<FEO(&[C;R!E<W3A('9A>FEO
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(CH@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B!<(B5S
M7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S."!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y-0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B26UP
M;W-S[79E;"!E>&-L=6ER("5S+"!O(&1I<F5T\W)I;R!NXV\@97-TX2!V87II
M;R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M("));7!O<W/M=F5L(&5X8VQU:7(@<F5C=7)S:79A;65N=&4@;R!D:7)E=/-R
M:6\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DEM<&]S<^UV96P@97AC;'5I<B!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@
M97AC;'5I<B!D:7)E=/-R:6\@5D93.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E
M;"!E>&-L=6ER(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("))
M;7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26UP
M;W-S[79E;"!E>&-L=6ER(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S
M='(@(DEM<&]S<^UV96P@97AC;'5I<B!61E,@<F5C=7)S:79A;65N=&4Z("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R
M("));7!O<W/M=F5L(&1E=&5R;6EN87(@;R!D:7)E=/-R:6\@871U86PN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@
M(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T
M<B`B26UP;W-S[79E;"!E>'1R86ER(&1E=&%L:&5S(&1O(&-E<G1I9FEC861O
M(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM
M<V=S='(@(DEM<&]S<^UV96P@8V%R<F5G87(@82!D969I;FGGXV\@9&4@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R
M("));7!O<W/M=F5L(&UO=F5R(&\@87)Q=6EV;R!61E,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C$P-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8U,B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP
M;W-S[79E;"!A8G)I<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(@IM<V=S='(@(DEM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,@
M<&%R82!G<F%V8>?C;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HX,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S<*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S[79E;"!A8G)I<B!A<G%U
M:79O(%9&4RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(DEM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!C;VUP<FEM
M:61O+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM
M<V=S='(@(DEM<&]S<^UV96P@;&5R(&%R<75I=F\@5D93("AF:6QE<VEZ92@I
M(&9A;&AO=2DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@X-PIM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B26UP;W-S[79E;"!L97(@87)Q=6EV;R!61E,@*&=E
M=$9I;&53:7IE*"D@9F%L:&]U*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L
M92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("));7!O<W/M=F5L(&QE<B!O(&%R
M<75I=F\Z("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8W-@IM
M<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*
M;7-G<W1R("));7!O<W/M=F5L(&QE<B!A(')A:7H@9&\@9&ER973S<FEO(%9&
M4RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DEM<&]S
M<^UV96P@<F5N;VUE87(@)7,@<&%R82`E<SH@82!P87-T82!D92!D97-T:6YO
M(&KA(&5X:7-T92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B26UP;W-S[79E;"!R96YO;65A<B!O(&1I<F5T\W)I;R!61E,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B26UP;W-S[79E;"!R96YO;65A<B!D:7)E=/-R:6\@5D93
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(W,2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B26UP;W-S[79E
M;"!R96YO;65A<B!A<G%U:79O(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,R-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W/M=F5L(')E;F]M96%R(&%R
M<75I=F\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N(@IM<V=S='(@(DEM<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z
M-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT(@IM<V=S='(@(DEM<&]S<^UV96P@=')A9'5Z:7(@97-T92!D;V-U;65N
M=&\@5V]R9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DEM<&]S<^UV96P@9W)A=F%R(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DEM
M<&]S<^UV96P@9W)A=F%R(&%R<75I=F\@5D93("AC;W!Y*"D@9F%L:&]U*2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#@@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82XB"FUS9W-T<B`B26UP;W-S[79E;"!G<F%V87(@9&%D;W,@
M9&\@87)Q=6EV;R!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V
M,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL
M(&)E(&5X8V5E9&5D+B(*;7-G<W1R("));7!O<W/M=F5L(&=R879A<B!A<G%U
M:79O(%9&4RP@<75O=&$@97AC961E<N$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM
M<V=S='(@(E-U8FQI;FAA9&\B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B1&5S9F%Z97(@06QT
M97)AY_5E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(D1E<V9A>B!S=6$@^FQT:6UA(&'GXV\B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")2
M97-P;W-T82!I;F5S<&5R861A(&1O('-E<G9I9&]R(&1U<F%N=&4@82!C;VYE
M>.-O.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*
M;7-G<W1R(")297-P;W-T82!I;F5S<&5R861A(&1O('-E<G9I9&]R('!A<F$Z
M("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(E-E;2!C871E9V]R:6$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B56YI8V]D92`H
M551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")%;6ER861O
M<R#!<F%B97,@56YI9&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@
M2VEN9V1O;2(*;7-G<W1R(")296EN;R!5;FED;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B17-T861O<R!5;FED;W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B26QH87,@4&5R:6;I<FEC87,@365N
M;W)E<R!D;W,@17-T861O<R!5;FED;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B56YI9&%D97,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#,P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B1&5S8V]N:&5C:61O(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX
M"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM
M<V=S='(@(F%P:6US9VED(&1E<V-O;FAE8VED;R`H05!)($UE<W-A9V4@240I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R(")C;&EM<V=I9"!D97-C;VYH96-I9&\@*$-L:65N
M="!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R(").96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M57-UX7)I;R!O=2!S96YH82!D97-C;VYH96-I9&]S+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I
M9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B1&5S=FEN
M8W5L87(@;R!E;&5M96YT;R!A='5A;"(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-E
M;2!.;VUE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T
M(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*
M(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC
M86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W
M('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*
M;7-G<W1R("(B"B)38W)I<'1S(&[C;R!P<FEV:6QE9VEA9&]S(&[C;R!P;V1E
M;2!U=&EL:7IA<B!#;W)T87(O0V]P:6%R+T-O;&%R('!O<B!R87KU97,@(@HB
M9&4@<V5G=7)A;N=A+B!#;&EQ=64@96T@3TL@<&%R82!V97(@82!N;W1A('3I
M8VYI8V$@96T@;6]Z:6QL82YO<F<@82!Q=6%L("(*(F5N<VEN82!C;VUO('!E
M<FUI=&ER('-C<FEP=',@86-E<W-A<F5M(&$@X7)E82!D92!T<F%N<V9E<NIN
M8VEA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(D1E<VUA
M<F-A<B!C;W(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS
M=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(D5X=&5N<^-O($[C;R!3=7!O
M<G1A9&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(D%T=6%L:7IA<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S
M(@IM<V=S='(@(B5S(&%T=6%L:7IA9&\B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M(")!='5A;&EZ87(@=7-UX7)I;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB
M+B(*;7-G<W1R("(G)7,G(&%T=6%L:7IA9&\N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M(@IM<V=S='(@(E-C<FEP="!D92!A='5A;&EZ8>?C;R!R96UO=FED;RXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R
M(")%;G9I87(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED
M(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BXB"FUS9W-T<B`B(@HB5&]D;W,@87)Q=6EV;W,@9&4@(&-O;F9I
M9W5R8>?U97,@9&%S(&%P;&EC8>?U97,@9F]R86T@96YV:6%D;W,@86\@<V5R
M=FED;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R(")!;&9A8F5T;R!L871I;F\@96T@;6%I^G-C=6QO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S
M(')O;6%N;W,@96T@;6%I^G-C=6QO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M57)U9W5A>2(*;7-G<W1R(")5<G5G=6%I(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(E5T:6QI>F%R($%T=6%L
M.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(E5T:6QI>F%R(%-3
M3"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M(@IM<V=S='(@(E5T:6QI>F%R('-E(&\@;F]M92]S96YH82#I(&1I9F5R96YT
M92!N;R!S97)V:61O<B!)35-0+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B57-UX7)I;W,B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RXB"FUS9W-T<B`B57-UX7)I;R`E<R!NXV\@97-TX2!A=71O<FEZ
M861O('!A<F$@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5
M<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@
M57-UX7)I;W,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T
M-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!5<W7A
M<FEO<R(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T
M:6]N(@IM<V=S='(@(E)E9VES=')O(&1E(%5S=>%R:6]S(@H*(SH@<VEG;G5P
M+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B4F5G:7-T<F\@9&4@57-U
MX7)I;W,@97-TX2!D97-A8FEL:71A9&\@;F5S=&4@<VET92XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD(@IM<V=S='(@(D-O;G1A(&1E('5S=>%R:6\@;N-O(&5N8V]N=')A
M9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R(")5<W7A<FEO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(E5S=>%R:6\@)R5S)R!JX2!E>&ES
M=&4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED
M(")5<V5R;F%M93HB"FUS9W-T<B`B57-UX7)I;SHB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@
M(E5S=>%R:6\Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5S=>%R
M:6]S(&YO('-I<W1E;6$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI
M<W1A;B(*;7-G<W1R(")5>F)E<75I<W3C;R(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$W,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(D\@9&ER973S<FEO(%9&4R!NXV\@97AI<W1E+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@
M(D;I<FEA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@W,`IM<V=I
M9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("),
M;V-A;&EZ8>?U97,@=N%L:61A<R!E;F-O;G1R861A<R!I;F-L=65M.B`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B
M5F%L:61I='DB"FUS9W-T<B`B5F%L:61A9&4B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E9A;&]R(&5M(&UI
M;G5T;W,@82!P87)T:7(@9&4@86=O<F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N(@IM<V=S='(@(D\@=F%L;W(@97-TX2!A8VEM82!D;R!T
M86UA;FAO(&WA>&EM;R!D92`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-S`*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,R,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")686QO<F5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3DP"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS
M9W-T<B`B5F%L;W)E<R!P87)A('-E;&5C:6]N87(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G
M<W1R(")687)IX79E;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L
M82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM
M<V=S='(@(D9A;&AA(&YA('9E<FEF:6-AY^-O("T@97-T82!M96YS86=E;2!P
M;V1E('1E<B!S:61O(&%D=6QT97)A9&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B
M5F5R<^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I
M9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(D-O;G1R;VQE(&1E(%9E<G/C
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D%L:6YH
M86UE;G1O('9E<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G
M<W1R(")-87)G96T@=F5R=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T
M<B`B5F5R=&EC86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S$*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")-=6ET;R!!
M;'1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B
M5FEE=&[C(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E9I
M971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;6ET82`H5DE30TE)
M*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9E<B`E<R(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT
M97)N86P@=V5B('!A9V4B"FUS9W-T<B`B5FES=6%L:7IA<B!U;6$@<.%G:6YA
M('=E8B!E>'1E<FYA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(X"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS
M9W-T<B`B5FES=6%L:7IA<B!C;VUO("5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B26QH87,@5FER
M9V5N<RP@0G)I=.)N:6-A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DEL:&%S(%9I<F=E;G,L($4N52Y!
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL
M:71Y(@IM<V=S='(@(E9I<VEB:6QI9&%D92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R
M(")6:7-I8FEL:61A9&4Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L:6%N;R!V:6$@4TU4
M4"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B051%
M3L?#3R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+B(*;7-G<W1R(")!5$5.Q\-/(2$A(%)%34]602!/(%-#4DE0
M5"!-04Y504Q-14Y412!$12`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S
M='(@(E=)3B!V:6$@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI
M<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!E($9U='5N82(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(Q(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R(")!=&5NY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B475A
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")7
M96%T:&5R($9O<F5C87-T(@IM<V=S='(@(E!R979I<^-O(&1O(%1E;7!O(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D1A9&]S(&1O($-L:6UA
M(&9O<FYE8VED;R!P;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R
M(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED
M(")796(@4VET92(*;7-G<W1R(")3:71E(%=E8B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*
M;7-G<W1R(")396UA;F%L;65N=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")"96TM=FEN9&\B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M
M92!T;R`E<R(*;7-G<W1R(")"96TM=FEN9&\@86\@)7,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T
M<B`B0F5M+79I;F1O+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT
M"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")/8VED96YT
M86P@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")/8VED96YT
M86P@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N
M(%-A:&%R82(*;7-G<W1R(")386AA<F$@3V-I9&5N=&%L(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T
M(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*
M;7-G<W1R(")1=64@87!L:6-AY^-O("5S(&1E=F5R:6$@97AI8FER(&%P\W,@
M82!C;VYE>.-O/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T
M"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G
M<W1R(")1=6%L(&\@8V%R86-T97)E(&1E;&EM:71A9&]R/R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q
M=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E%U86P@;R!C87)A8W1E<F4@9&4@
M8VET8>?C;S\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`V,@IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S
M='(@(DUA<&%S($%U<W1R86QI86YO<R!7:&5R96ES(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B475A
M:7,@9F%S97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(E%U86ES('!L=6=I;G,@:&%B:6QI=&%R('!A<F$@
M;R!E9&ET;W(@4FEC:"!497AT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S
M='(@(DQA<F=U<F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$T
M"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B3&%R9W5R82!E
M;2!U;FED861E<R!#4U,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G
M<W1R("),87)G=7)A(&1O(&UE;G4@)7,@9&\@;&%D;R!E<W%U97)D;R`H=&5R
MX2!E9F5I=&\@;F$@<'+S>&EM82!C;VYE>.-O*3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@
M;V8@=&AE('1A8FQE(@IM<V=S='(@(DQA<F=U<F$@9&$@=&%B96QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`B56YI9&%D92!D92!,87)G=7)A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*
M;7-G:60@(E=I9'1H.B(*;7-G<W1R("),87)G=7)A.B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0B
M"FUS9W-T<B`B5F5N=&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")696YT
M;W,@<&5L82!M86YHXR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G
M:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5F5L;V-I9&%D92!D
M;R!V96YT;R!E;2!N\W,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM
M<V=I9"`B5VEN9#HB"FUS9W-T<B`B5F5N=&\Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9E
M;G1O.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I
M<V1O;2(*;7-G<W1R(")386)E9&]R:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("),:7-T82!D
M92!P961I9&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED
M(")7;W)K(@IM<V=S='(@(E1R86)A;&AO(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B
M"FUS9W-T<B`B16YD97)EYV\@0V]M97)C:6%L(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N
M92(*;7-G<W1R(")&;VYE($-O;65R8VEA;"(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR
M.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@
M(D[Z;65R;R!I;F-O<G)E=&\@9&4@8V%M<&]S(&YA(&QI;FAA("5D+B!%<W!E
M<F%D;W,@)60L(&5N8V]N=')A9&]S("5D+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S
M='(@(D[Z;65R;R!E<G)A9&\@9&4@8V%M<&]S+B!%<W!E<F%D;W,@)60L(&5N
M8V]N=')A9&]S("5D+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")/9F9S970@)60@:6YC
M;W)R971O(&%O(&QE<B!O(&%R<75I=F\@5D93+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")297-T<FGG
M]65S($+A<VEC87,@6#4P.78S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A
M9V4B"FUS9W-T<B`B571I;&EZ8>?C;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P
M.78S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T
M<B`B3F]M92!!;'1E<FYA=&EV;R!D92!!<W-U;G1O(%@U,#EV,R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))9&5N=&EF:6-A
M9&]R(&1A($-H879E(&1E($%S<W5N=&\@6#4P.78S(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(D5X=&5N<_5E<R!8-3`Y=C,B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-30*;7-G:60@(EE9
M65DB"FUS9W-T<B`B04%!02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3`Y"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@
M(DUA<&$@66%H;V\A(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(D%N=6%L;65N
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("),ZFUE
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C0*;7-G:60@(EEE<R(*;7-G<W1R(")3:6TB"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(E-I;2P@174@0V]N8V]R9&\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E
M(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H
M(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB5F]CZB!E<W3A(&5M($U/
M1$\@5$585$\N("!5=&EL:7IA(&\@8F]TXV\@6SP^72!P87)A('9O;'1A<B!P
M87)A(&\@;6]D;R`B"B)765-)5UE'+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!B;&]C:W,N(@IM<V=S='(@(E9O8^H@;N-O(&5S=.$@875T;W)I>F%D;R!A
M(&-R:6%R(&UA:7,@9&4@)60@8FQO8V]S+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"XB"FUS9W-T<B`B5F]CZB!NXV\@97-TX2!A=71E;G1I8V%D;RXB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I9"`B
M66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E
M<B!<7"!N;R!S974@;F]M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-SD*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B5F]CZB!NXV\@9F]R;F5C974@=6T@96YD97)EYV\@9&4@92UM86EL(';A
M;&ED;RXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F
M<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I
M96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB5F]CZB!NXV\@;6%P96]U(&YE
M;FAU;2!C86UP;R!D;R!A<G%U:79O(&EM<&]R=&%D;R!A;W,@8V%M<&]S(&-O
M<G)E<W!O;F1E;G1E<R`B"B)E;2`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB
M"FUS9W-T<B`B5F]CZB!F;VD@9&5S8V]N96-T861O+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)6;V/J(&1E=F4@<')E96YC:&5R
M('5M(&[Z;65R;R!D92!T96QE9F]N92!C96QU;&%R(';A;&ED;RP@<V]M96YT
M92!D[6=I=&]S("(*(F-O;2!U;2!O<&-I;VYA;"`G*R<@<&%R82!D:7-C86=E
M;2!D92!P<F5F:7AO(&EN=&5R;F%C:6]N86PN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B5F]CZB!D979E('!R965N8VAE<B!U;2!V
M86QO<B!VX6QI9&\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B
M86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R(")6;V/J(&1E=F4@8V]N
M9FEG=7)A<B!U;2!C;VYE8W1O<B!$871A5')E92!P87)A('5T:6QI>F%R($-A
M9&%S=')O<RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0V,@IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S
M='(@(E9O8^H@9&5V92!C;VYF:6=U<F%R('5M(&-O;F5C=&]R(%9&4RXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*(E9O8^H@9&5V92!D
M97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R
M:6\@9&4@<')O8FQE;6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(E9O8^H@9&5V
M92!F;W)N96-E<B!A(%523"!O;F1E(&\@;&EN:R!A<&]N=&$B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")6;V/J(&1E
M=F4@<V5L96-I;VYA<B!U;2!S97)V:61O<B!P87)A('-E<B!E>&-L=>UD;RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E9O8^H@9&5V
M92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@97AC;'5I<BXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(E9O8^H@9&5V92!E<W!E8VEF
M:6-A<B!U;2!U<W7A<FEO('!A<F$@<F5M;W9E<BXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS
M9W-T<B`B5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R82!A
M9&EC:6]N87(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(E9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@871U86QI
M>F%R+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+B(*;7-G<W1R(")6;V/J(&1E=F4@97-P96-I9FEC87(@=6UA(&'G
MXV\@<&%R82!E>&5C=71A<BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A
M(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")6;V/J(&1E=F4@<')E96YC
M:&5R('5M(&YO;64@<&%R82!A(&YO=F$@8V%T96=O<FEA+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS
M9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M
M8F5R(@IM<V=S='(@(E9O8^H@<')E8VES82!F;W)N96-E<B!U;2!N^FUE<F\@
M9&4@=&5L969O;F4@:71A;&EA;F\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(E-U
M82!S97-SXV\@)7,@97AP:7)O=2X@4&]R(&9A=F]R+"!C;VYE8W1E+7-E(&YO
M=F%M96YT92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E-E=2!%;F1E
M<F7G;R!D92!%+6UA:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U
M"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E-E=2!%;F1E
M<F7G;R!D92!296UE=&5N=&4@*$1E.BDZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS
M9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E-U87,@26YF;W)M8>?U
M97,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"B)3974@16YD97)EYV\@9&4@26YT97)N970@;75D
M;W4@9&5S9&4@;R!I;NUC:6\@9&4@<W5A('-E<W/C;R`E<RX@4&%R82`B"B)P
M<F]T96=E<B!S=6$@<V5G=7)A;N=A('9O8^H@9&5V92!C;VYE8W1A<BUS92!N
M;W9A;65N=&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")3974@3F]M92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)3974@
M8F%C:V5N9"!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E
M('5S=>%R:6]S+"!O=2!A(&9U;N?C;R!F;VD@(@HB9&5S86)I;&ET861A('!O
M<B!A;&=U;6$@;W5T<F$@<F%ZXV\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN(@IM<V=S='(@(B(*(E-E=2!B86-K96YD(&1E(&%U=&5N=&EC
M8>?C;R!NXV\@<W5P;W)T82!L:7-T86=E;2!D92!U<W7A<FEO<RP@;W4@82!F
M=6[GXV\@(@HB9F]I(&1E<V%B:6QI=&%D82!P;W(@86QG=6UA(&]U=')A(')A
M>N-O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*(E-E=2!N879E9V%D;W(@<&%R96-E('1E
M<B!A;'1E<F%D;R!D97-D92!O(&EN[6-I;R!D92!S=6$@<V5S<^-O("5S+B!0
M87)A("(*(G!R;W1E9V5R('-U82!S96=U<F%NYV$L('9O8^H@9&5V92!C;VYE
M8W1A<BUS92!N;W9A;65N=&4N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92XB"FUS9W-T<B`B4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E
M<W1A(&9U;N?C;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ
M<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(E-E=2!N879E9V%D;W(@;N-O('-U
M<&]R=&$@97-T82!O<.?C;R!D92!I;7!R97-SXV\N(%!R97-S:6]N92!#;VYT
M<F]L+T]P=&EO;B`B"B(K(%`@<&%R82!I;7!R:6UI<BXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z
M;VYE.B(*;7-G<W1R(")3974@9G5S;R!H;W+A<FEO(&%T=6%L.B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HQ,3$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")3=6$@:61E;G1I9&%D
M92!P861RXV\@9F]I(&%L=&5R861A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T
M<B`B4W5A(&ED96YT:61A9&4@<&%D<N-O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")3
M974@;F]M92!C;VUP;&5T;SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@
M(E-U82!C;VYE>.-O(&5X<&ER;W4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")3=6$@;F]V82!S96YH82!P
M87)A("5S(.DZ("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F
M;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B4W5A
M<R!O<.?U97,@9F]R86T@871U86QI>F%D87,@<&]R(&-A=7-A(&1A(&1U<F'G
MXV\@9&5S=&$@<V5S<^-O+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N(@IM<V=S='(@(E-U87,@;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E-U82!N;W9A('-E
M;FAA(&9O:2!G97)A9&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB
M<&%S<W=O<F0N(@IM<V=S='(@(B(*(E-U82!N;W9A('-E;FAA(&9O:2!G97)A
M9&$L('9E<FEF:7%U92!S974@92UM86EL(&4@8V]N96-T92US92!C;VT@<W5A
M(&YO=F$@(@HB<V5N:&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M(")3=6$@<V5N:&$@97AP:7)O=2XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S
M='(@(E-E=7,@<V5R=FED;W)E<R!R96UO=&]S.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B275G;W-LX79I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA
M:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(EKB;6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII
M;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");3V-U;'1A
M<B!497AT;R!#:71A9&]=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*
M;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U)E;&%T\W)I;R!D
M92!0<F]B;&5M85TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R
M(");17AI8FER(%1E>'1O($-I=&%D;R`M(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*
M;7-G<W1R(");17AI8FER(%1E>'1O($-I=&%D;R`M("5S(&QI;FAA<UTB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6VQI;FAA("5S(&1E
M("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T-2!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B7T%D;6EN:7-T<F'GXV\B"@HC.B!L:6(O87!I+G!H<#HQ
M-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP
M.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(D1A=&%?5')E92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B15]X8VQU:7(@0V]L
M=6YA(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S
M='(@(E]'<G5P;W,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")!7VIU9&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*
M;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65D
M861E<R!D82!?26UA9V5M+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?0V]N96-T
M87(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS
M9VED(")?3&]G(&]U="(*;7-G<W1R(")?1&5S8V]N96-T87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*
M;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")!7VQT97)A<B!,:6YK
M+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM
M<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]PY_5E<R(*"B,Z(&QI8B]A<&DN
M<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]097)M:7-S
M]65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B
M7U)E;6]V97(@3&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B
M7U-E='5P(@IM<V=S='(@(D-O;F9I9W5R85]R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?
M5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@
M7U1A8F5L82XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S
M(@IM<V=S='(@(E]5<W7A<FEO<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B8V%TX6QO
M9V\@9&4@96YD97)EYV]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@
M(F-A=.%L;V=O(&1E(&5N9&5R9>=O<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3$R"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")A9V5N9&$B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(F-A
M;&UO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*
M;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B:6UP
M;W-S[79E;"!C<FEA<B!A<G%U:79O(&1E(&1E<W1I;F\B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B:6UP;W-S[79E;"!A8G)I<B!A(&]R:6=E;2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R(")C;&EQ=64@87%U:2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD
M(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B97)R;R!D92!S:6YT87AE(&1A
M(&QI;FAA(&1E(&-O;6%N9&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G
M<W1R(")E<G)O(&1E(&-O;F9I9W5R8>?C;R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG(@IM<V=S='(@(G5M(&%R<75I=F\@8W+M=&EC;R!D;R!S
M:7-T96UA(&5S=.$@9F%L=&%N9&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS
M9W-T<B`B97)R;R!N;R!F;W)M871O(&1O<R!D861O<R(*"B,Z('1E;7!L871E
M<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B961I
M=&%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*
M;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")R96=I<W1R;R!NXV\@
M96YC;VYT<F%D;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<R"FUS9VED(")F86QL:6YG(@IM<V=S='(@(G%U961A(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Q"FUS9VED(")F:6QE
M(@IM<V=S='(@(F%R<75I=F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X
M,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S(@IM<V=S='(@(F$@<&%R=&ER(&1E("5S("@E<RD@X"`E<R`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U
M<W1I;F<B"FUS9W-T<B`B8G)I<V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS9VED(")H.B(*;7-G<W1R(")H.B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3<*
M;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM
M<V=S='(@(FYO;64@9&\@:&]S="#I(&1E<V-O;FAE8VED;R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(FEM961I871O(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G
M:60@(FEN;&EN92(*;7-G<W1R(")I;F-O<G!O<F%D;R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P
M=70@97)R;W(B"FUS9W-T<B`B97)R;R!D92!E;G1R861A+W-A[61A(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(F5R<F\@:6YT97)N;R!D
M;R!P<F]G<F%M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B;&EN:&%S72(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B8_-D:6=O(&1E(&5R<F\@
M)60@9&\@;6MI<V]F<R!E;G%U86YT;R!G97)A=F$@82!)4T\N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.`IM<V=I9"`B
M;6TB"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS
M9W-T<B`B;F]M92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G
M:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")NXV\@:6UP;&5M96YT861O
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(F[C;R!I;7!L96UE
M;G1A9&\@86EN9&$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M-`IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")B;&]C;R!D92!N;W1A<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<&]R8V5N=&%G96TB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R
M;6ES<VEO;B!D96YI960B"FUS9W-T<B`B4&5R;6ES<^-O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I
M9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@
M<')O=&]C;VPB"FUS9W-T<B`B97)R;R!R96UO=&\@;F\@<')O=&]C;VQO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G
M:60@(G)I<VEN9R(*;7-G<W1R(")N87-C96YT92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A
M:6QA8FQE(@IM<V=S='(@(G-E<G9IYV\@:6YD:7-P;V[M=F5L(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC
M97,B"FUS9W-T<B`B97AI8FER(&1I9F5R96[G87,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS
M,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%144"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*
M;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G-T96%D>2(*;7-G<W1R(")E
M<W3A=F5L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")E<G)O(&1E('-I<W1E
M;6$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.`IM<V=I9"`B
M=&%S:R!L:7-T(@IM<V=S='(@(FQI<W1A(&1E('1A<F5F87,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R
M87)Y(&9A:6QU<F4B"FUS9W-T<B`B9F%L:&$@=&5M<&]RX7)I82(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FTB"FUS9W-T<B`B<')E96YC:&$@<W5A('-E;FAA(&1U87,@=F5Z97,@<&%R
M82!C;VYF:7)M87(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U
M;FEF:6-A9&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W
M"FUS9VED(")U;FYA;65D(@IM<V=S='(@(G-E;2!N;VUE(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")S96QEY^-O(&1E('5S=>%R:6\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*
M;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,`IM<V=I9"`B=SHB"FUS9W-T
M<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I
M9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P;R]P=%]05"YP;P``````````````````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S(P-3(P`#$P-3$U-#,Q,#8S`#`Q-C0R
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M($AO<F1E(%!O<G1U9V%L(%!O<G1U9W5E<V4@=')A;G-L871I;VXN"B,@36%N
M=65L($UE;F5Z97,@9&4@4V5Q=65I<F$@/$UA;G5E;"Y397%U96ER83XL(#(P
M,#4N"B,@0F%S960@;VX@82!P<F5V:6]U<R!T<F%N<VQA=&EO;B!B>2!.=6YO
M($QO=7)E:7)O(#QN=6YO0&5T:"YP=#XL(#(P,#(N"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,2TR-"`P,3HQ."LP,#`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`R+3`Q+3(Q(#$X.C(R+3`P,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^
M7&XB"B),86YG=6%G92U496%M.B!0;W)T=6=A;"!0;W)T=6=U97-E(#QD979`
M;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB
M"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-#D*;7-G:60@(B(*(B`@+4TL("TM;65S<V%G93U-
M15-304=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H
M92!D969A=6QT(&]N97,N(@IM<V=S='(@(B(*(B`@+4TL("TM;65S<V%G93U-
M14Y304=%32!5<V%R(&5S=&$@;65N<V%G96T@9&4@8V]M971I;65N=&\@96T@
M=F5Z(&1A7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@;65N<V%G96T@
M<&]R(&]M:7-SXV\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4S"FUS9VED
M("(B"B(@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE
M('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&]<;B(*(B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F
M97)E;G0@8G)A;F-H('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@9V5N97)A=&5D(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*(B`@+6$L("TM
M861D/4%2455)5D\@("`@($%D:6-I;VYA<B!E<W1E(&%R<75I=F\@4$\@86\@
M8V]M<.IN9&EO+B!5=&EL('!A<F%<;B(*(B`@("`@("`@("`@("`@("`@("`@
M("`@(&EN8VQU:7(@=6T@8V]M<.IN9&EO(&1E('5M(')A;6\@9&EF97)E;G1E
M(&YO7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!C;VUPZFYD:6\@9V5R
M861O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3,*;7-G:60@(B(*(B`@
M+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H('1O('1H92`H2&]R9&4I(&)A
M<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E7&XB"B(@("`@("`@("`@("`@
M("`@("`@('5S960N(@IM<V=S='(@(B`@+6(L("TM8F%S93TO0T%-22`@0V%M
M:6YH;R!P87)A(&\@9&ER96-T\W)I;R!B87-E("A(;W)D92D@82!U<V%R+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.0IM<V=I9"`B(@HB("`M8RP@+2UC
M;VUP96YD:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI
M<R!C;VUP96YD:75M(&9I;&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@
M("!I;G-T96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I
M;B!T:&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U!4E%5
M("!);G1E9W)A<B!N;W9A<R!T<F%D=>?U97,@82!E<W1E(&%R<75I=F\@9&4@
M(@HB8V]M<.IN9&EO7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@92!N
MXV\@86\@8V]M<.IN9&EO('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA
M7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@<&%S=&$@:&]R9&4O<&\N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8S('!O+W1R86YS;&%T:6]N+G!H
M<#HX,2!P;R]T<F%N<VQA=&EO;BYP:'`Z.#<*;7-G:60@(B(*(B`@+6,L("TM
M8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS
M=&5A9"!O9B!T:&4@9&5F875L=%QN(@HB("`@("`@("`@("`@("`@("`@("`@
M("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T
M;W)Y*2XB"FUS9W-T<B`B(@HB("`M8RP@+2UC;VUP96YD:75M/4%2454@(%5S
M87(@97-T92!A<G%U:79O(&1E(&-O;7#J;F1I;R!E;2!V97H@9&\@87)Q=6EV
M;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@('!O<B!O;6ES<^-O("AC
M;VUP96YD:75M+G!O(&YA('!A<W1A(&AO<F1E+W!O+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,30*;7-G:60@(B`@+60L("TM9&5B=6<@("`@("`@4VAO
M=R!E<G)O<B!M97-S86=E<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RXB
M"FUS9W-T<B`B("`M9"P@+2UD96)U9R`@("`@("!-;W-T<F%R(&UE;G-A9V5N
M<R!D92!E<G)O(&1O<R!B:6[A<FEO<R!E>&5C=71A9&]S+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HU-`IM<V=I9"`B("`M9"P@+2UD:7)E8W1O<GD]1$E2
M("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B`@+60L("TM9&ER96-T;W)Y/5!!4U1!($-R:6%R('5M(&-O;7#J;F1I
M;R!N97-T82!P87-T82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U"FUS
M9VED("(@("UH+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A
M9V4N(@IM<V=S='(@(B`@+6@L("TM:&5L<"`@("`@("`@36]S=')A<B!E<W1A
M(&UE;G-A9V5M(&1E(&%J=61A+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT
M,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<@<&\O=')A;G-L871I;VXN<&AP.C<U
M"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI
M<R!L;V-A;&4N(@IM<V=S='(@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5
M<V%R(&%P96YA<R!E<W1A(&QO8V%L:7IAY^-O+B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HT-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$@<&\O=')A;G-L871I
M;VXN<&AP.C<Y"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-0IM<V=I9"`B("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T
M<B`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@97-T82!L;V-A;&EZ
M8>?C;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-34*;7-G:60@(B`@+6PL
M("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T<B`B
M("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-A<B!E<W1A(&QO8V%L:7IAY^-O
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.`IM<V=I9"`B("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H:7,@
M*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4W3
M1%5,3R`@("!#;VYS=')U:7(@87)Q=6EV;W,@34\@87!E;F%S('!A<F$@97-T
M92!M\V1U;&]<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,PIM<V=I9"`B("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI
M<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]
M3=-$54Q/("`@($QI;7!A<B!A<G%U:79O<R!03R!A<&5N87,@<&%R82!E<W1E
M(&WS9'5L;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0X"FUS9VED("(B"B(@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS;&%T:6]N<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO
M9'5L93U-TT153$\@("`@0V]M971E<B!A<R!T<F%D=>?U97,@87!E;F%S('!A
M<F$@97-T92!M\V1U;&]<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("`H
M2&]R9&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV,@IM<V=I9"`B("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F
M;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM
M;V1U;&4]3=-$54Q/("`@($-R:6%R(&\@87)Q=6EV;R!03R!A<&5N87,@<&%R
M82!E<W1E(&WS9'5L;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@("A(
M;W)D92DN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@P"FUS9VED("(@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U
M;&4]3=-$54Q/("`@($EN=&5G<F%R(&%R<75I=F]S(%!/(&%P96YA<R!P87)A
M(&5S=&4@;?-D=6QO7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@*$AO
M<F1E*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S8*;7-G:60@(B(*(B`@
M+6TL("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY
M(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M
M+6UO9'5L93U-TT153$\@("`@06-T=6%L:7IA<B!A<G%U:79O<R!D92!A:G5D
M82!A<&5N87,@<&%R82!E<W1E7&XB"B(@("`@("`@("`@("`@("`@("`@("`@
M("`@;?-D=6QO("A(;W)D92DN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V
M"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&]N;'D@
M=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@($%C='5A;&EZ87(@87!E;F%S(&5S=&4@;?-D=6QO("A(;W)D
M92DN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4X"FUS9VED("(@("UM+"`M
M+6UO9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!'97)A<B!A<F-H:79O(%!/5"!A<&5N87,@<&%R82!E<W1E
M(&WS9'5L;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<P"FUS9VED("(B"B(@("UN+"`M
M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R9V4@;F5W('1R86YS;&%T:6]N
M<R!T;R!T:&4@8V]M<&5N9&EU;2XB"FUS9W-T<B`B("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@($[C;R!I;G1E9W)A<B!N;W9A<R!T<F%D=>?U97,@;F\@8V]M
M<.IN9&EO+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-"!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#(@<&\O=')A;G-L871I;VXN<&AP.C@X"FUS9VED("(@("UN
M+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2XB
M"FUS9W-T<B`B("`M;BP@+2UN;RUC;VUP96YD:75M("`@($[C;R!U<V%R('5M
M(&-O;7#J;F1I;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$*;7-G:60@
M(B`@+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T
M871I<W1I8W,@:6X@82!L;V-A;"!F:6QE+B(*;7-G<W1R("(B"B(@("US+"`M
M+7-T871I<W1I8W,@("`@("`@1W5A<F1A<B!E<W1A=.US=&EC87,@9&4@=')A
M9'7GXV\@;G5M(&9I8VAE:7)O(&QO8V%L+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,38*;7-G:60@(B`@+70L("TM=&5S="`@("`@("`@4VAO=R!T:&4@
M97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U;B!A;GET:&EN9RXB"FUS
M9W-T<B`B("`M="P@+2UT97-T("`@("`@("!-;W-T<F%R(&]S('!R;V=R86UA
M<R!A(&5X96-U=&%R(&UA<R!NXV\@;R!F87IE<BXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`U"FUS9VED("(B"B(@(&-L96%N=7`@("`@($-L96%N<R!T
M:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E
M(&5N=')I97,N(@IM<V=S='(@(B(*(B`@8VQE86YU<"`@("`@3&EM<&%R(&]F
M(&%R<75I=F]S(%!/(&1E(&5N=')A9&%S('!O<B!T<F%D=7II<B!O=2!O8G-O
M;&5T87,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.`IM<V=I9"`B("!C
M;VUM:70@("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R
M=F5R+B(*;7-G<W1R("(@(&-O;6UI="`@("`@($-O;65T97(@87,@=')A9'7G
M]65S(&YO('-E<G9I9&]R($-64RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`Y"FUS9VED("(@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O
M('1H92!#5E,@<V5R=F5R+B(*;7-G<W1R("(@(&-O;6UI="UH96QP($-O;65T
M97(@87)Q=6EV;W,@9&4@86IU9&$@;F\@<V5R=FED;W(@0U93+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HY.0IM<V=I9"`B(@HB("!C;VUP96YD:75M("!2
M96)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E
M<G=R:71E<R!T:&5<;B(*(B`@("`@("`@("`@("`@8W5R<F5N="!C;VUP96YD
M:75M+B(*;7-G<W1R("(B"B(@(&-O;7!E;F1I=6T@(%)E8V]N<W1R=6ER(&\@
M87)Q=6EV;R!D92!C;VUPZFYD:6\N($%T96[GXV\Z($\@;F]V;R!A<G%U:79O
M7&XB"B(@("`@("`@("`@("`@('-O8G)E</5E+7-E(&%O(&%N=&EG;RXB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`P"FUS9VED("(@(&5X=')A8W0@("`@
M($=E;F5R871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RXB"FUS9W-T<B`B
M("!E>'1R86-T("`@("!'97)A<B!A<G%U:79O<R!M;V1E;&\@4$\@*"YP;W0I
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY.`IM<V=I9"`B("!H96QP("`@
M("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(@(&AE;'`@
M("`@("`@($UO<W1R87(@97-T82!M96YS86=E;2!D92!A:G5D82XB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3`Q"FUS9VED("(B"B(@(&EN:70@("`@("`@
M($-R96%T92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE
M+B!787)N:6YG.B!4:&ES7&XB"B(@("`@("`@("`@("`@(&]V97)W<FET97,@
M=&AE(&5X:7-T:6YG(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+B(*;7-G<W1R
M("(B"B(@(&EN:70@("`@("`@($-R:6%R('5M(&]U(&UA:7,@87)Q=6EV;W,@
M4$\@<&%R82!U;6$@;F]V82!L;V-A;&EZ8>?C;RY<;B(*(B`@("`@("`@("`@
M("`@071E;N?C;SH@3W,@;F]V;W,@87)Q=6EV;W,@<V]P<F5P]65M+7-E(&%O
M<R!A;G1I9V]S+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8*;7-G:60@
M(B`@;6%K92`@("`@("`@0G5I;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE
M('-P96-I9FEE9"!03R!F:6QE<RXB"FUS9W-T<B`B(@HB("!M86ME("`@("`@
M("!#;VYS=')U:7(@87)Q=6EV;W,@8FENX7)I;W,@34\@82!P87)T:7(@9&]S
M(&%R<75I=F]S7&XB"B(@("`@("`@("`@("`@(%!/(&5S<&5C:69I8V%D;W,N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-PIM<V=I9"`B(@HB("!M86ME
M+6AE;'`@("!-87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE
M(&)E:6YG('5P+71O+61A=&4@86YD7&XB"B(@("`@("`@("`@("`@('!R97!A
M<F4@=&AE(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M
M:&5L<"X@66]U7&XB"B(@("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M
M86ME+6AE;'`@049415(@=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H95QN
M(@HB("`@("`@("`@("`@("!H96QP(&9I;&4N(@IM<V=S='(@(B(*(B`@;6%K
M92UH96QP("`@36%R8V%R('1O9&%S(&%S(&5N=')A9&%S(&YO(&%R<75I=F\@
M6$U,(&1E(&%J=61A(&-O;6\@97-T86YD;UQN(@HB("`@("`@("`@("`@("!A
M8W1U86QI>F%D87,@92!P<F5P87)A<B!O(&%R<75I=F\@<&%R82!A('!R\WAI
M;6$@97AE8W7GXV]<;B(*(B`@("`@("`@("`@("`@9&4@=7!D871E+6AE;'`N
M($1E=F4M<V4@97AE8W5T87(@;6%K92UH96QP($1%4$])4R!D95QN(@HB("`@
M("`@("`@("`@("!U<&1A=&4M:&5L<"!E(&1E(')E=F5R(&\@87)Q=6EV;R!D
M92!A:G5D82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`R"FUS9VED("(B
M"B(@(&UE<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@=VET
M:"!T:&4@8W5R<F5N="!03R!T96UP;&%T92!F:6QE+B(*;7-G<W1R("(B"B(@
M(&UE<F=E("`@("`@($EN=&5G<F%R(&\@87)Q=6EV;R!03R!C;W)R96YT92!C
M;VT@;R!A<G%U:79O(&UO9&5L;R!03R`B"B)C;W)R96YT92XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`S"FUS9VED("(@('5P9&%T92`@("`@(%)U;B!E
M>'1R86-T(&%N9"!M97)G92!S97%U96YT+B(*;7-G<W1R("(@('5P9&%T92`@
M("`@($5X96-U=&%R(&5X=')A8W0@92!M97)G92!E;2!S97%UZFYC:6$N(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-`IM<V=I9"`B(@HB("!U<&1A=&4M
M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M
M('1H92!%;F=L:7-H(%A-3"!H96QP7&XB"B(@("`@("`@("`@("`@(&9I;&4@
M86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@;VYE<RXB"FUS9W-T
M<B`B(@HB("!U<&1A=&4M:&5L<"!%>'1R86ER('1O9&%S(&%S(&5N=')A9&%S
M(&YO=F%S(&4@;6]D:69I8V%D87,@9&\@87)Q=6EV;R!D95QN(@HB("`@("`@
M("`@("`@("!A:G5D82!834P@96T@:6YG;.IS(&4@:6YT96=RX2UL87,@8V]M
M(&%S(&5X:7-T96YT92XB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]T;W`N:6YC.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B`F(S$U
M,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B(*;7-G<W1R("(B"B(@)B,Q-3$[("5S
M(&5S=.$@<')O;G1O('!A<F$@969E8W1U87(@87,@;W!E<F'G]65S(&1E(&UA
M;G5T96[GXV\@;6%R8V%D87,@(@HB86)A:7AO+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S8X"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A
M9V\I(@IM<V=S='(@(B`H)7,@9&EA<R!A='+A<RDB"@HC.B!L:6(O2&]R9&4N
M<&AP.C$R-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I
M(@IM<V=S='(@(B`H0VAA=F4@9&4@86-E<W-O("5S*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S<V"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@
M9&%Y<RDB"FUS9W-T<B`B("AD96YT<F\@9&4@)7,@9&EA<RDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,W,@IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B
M("AH;VIE*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<T"FUS9VED("(@
M*'1O;6]R<F]W*2(*;7-G<W1R("(@*&%M86YHXRDB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W,`IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H
M;VYT96TI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-"!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(B!A="`B"FUS9W-T<B`B(&-O
M;2`B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B
M7"(E<UPB(&[C;R#I('5M82!E<V-O;&AA(';A;&ED82XB"@HC.B!L:6(O2&]R
M9&4O4F5G:7-T<GDN<&AP.C4U-"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.CDS
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@;N-O
M(&5S=.$@8V]N9FEG=7)A9&\@;F\@4F5G:7-T;R!D;R!(;W)D92XB"@HC.B!L
M:6(O2&]R9&4O5')E92YP:'`Z,38T"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB
M(')E<')E<V5N=&%D;W(@9&4@X7)V;W)E(&[C;R!E;F-O;G1R861O+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB(&9O:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@9W)U<&]S+B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S
M>7-T96TN(@IM<V=S='(@(EPB)7-<(B<@9F]I(&%D:6-I;VYA9&\@86\@<VES
M=&5M82!D92!P97)M:7-S]65S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S
M7"(@;N-O(&9O:2!C<FEA9&\Z("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD
M("5S(@IM<V=S='(@(B5D("5S(&4@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3$W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!B>71E<R!W<FET=&5N
M+B(*;7-G<W1R("(E9"!B>71E<R!E<V-R:71O<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C@T"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&]F("5D(&5N
M=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4B"FUS9W-T<B`B)60@9&4@)60@
M96YT<F%D82!M87)C861A<R!C;VUO(&%C='5A;&EZ861A<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(G!R979I<^-O(&1E("5D(&1I
M87,B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7W1O<"YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E
M<R`M($YO=&EF:6-AY^-O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B5S($%D;6EN:7-T<F'GXV\B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!);7!R97-SXV\@1&EG:71A;"(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,S`@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@S,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@
M(B5S($]P97)AY_5E<R!D92!-86YU=&5NY^-O("T@0V]N9FER;6'GXV\B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T
M<B`B0V]N9FEG=7)A<B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T
M<B`B)7,@4W5B<V-R979E<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A
M9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E
M<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!497)M;W,@9&\@06-O<F1O
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C4V."!L:6(O5D93+V9T<"YP:'`Z-C,V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R("(E<R!JX2!E>&ES=&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B
M"FUS9W-T<B`B)7,@96T@)7,@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,C@W('!O+W1R86YS;&%T:6]N+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:7,@;F]T('=R:71A8FQE+B(*;7-G<W1R(")NXV\@<V4@<&]D92!E
M<V-R979E<B!E;2`E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E
M<R#I(&]B<FEG873S<FEO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M
M:6YU=&]S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R
M,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&[C;R!F;VD@96YC;VYT<F%D
M;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T
M)R!F:7)S="XB"FUS9W-T<B`B)7,@;N-O(&9O:2!E;F-O;G1R861O+B!%>&5C
M=71A<B`G=')A;G-L871I;VX@97AT<F%C="<@<')I;65I<F\N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!A("5S(&1E("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B0V]N=&%C=&]S(&1E("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")#86QE;F3A<FEO(&1E("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX-S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(DYO=&%S(&1E("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!487-K;&ES="(*;7-G<W1R(")487)E9F%S(&1E("5S(@H*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4S(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.3@*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T
M<B`B+"!C;VT@<F%J861A<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&-O;2!R86IA9&%S("5S("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R
M:>%V96P@9&4@)7,@82`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#<P
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3(Y"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV.#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G
M<W1R("(M+2!E<V-O;&AA("TM(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S
M,C@@<&\O=')A;G-L871I;VXN<&AP.C$S,S`*;7-G:60@(BTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2(*;7-G<W1R("(M+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R
M($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@,3(@:&]R87,@*$%-
M+U!-*2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U
M<B!&;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92`R-"!H;W)A<R(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G
M<W1R("(R-"!H;W)A<R(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z-CD*
M;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\06YT97)I;W(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(CQG
M971T97AT/B!T86<@;F]T(&-L;W-E9"!I;B!F:6QE("5S+EQN(@HB3W!E;FEN
M9R!T86<@9F]U;F0@:6X@;&EN92`E9"XB"FUS9W-T<B`B(@HB971I<75E=&$@
M/&=E='1E>'0^('!O<B!F96-H87(@;F\@9FEC:&5I<F\@)7,N7&XB"B)!8G)I
M;F1O(&$@971I<75E=&$@96YC;VYT<F%D82!N82!L:6YH82`E9"XB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")%<W1E
M(&)L;V-O(&5X:6=E('5M(&UE8V%N:7-M;R!U<V%N9&\@8F%S97,@9&4@9&%D
M;W,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!F871A
M;"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDR,`IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`BR2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%!'
M4"!P87)A(&5N8W)I<'1A<B!A(&UE;G-A9V5M+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$Q-#4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(LD@;F5C97-SX7)I82!U;6$@8VAA=F4@</IB;&EC82!01U`@<&%R82!V
M97)I9FEC87(@82!A<W-I;F%T=7)A(&1E('5M82`B"B)M96YS86=E;2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-S<*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B)087)A(&1E8VEF<F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I
M87,@=6UA(&-H879E('#Z8FQI8V$@4$=0+"!U;6$@8VAA=F4@(@HB<')I=F%D
M82!01U`@92!U;6$@9G)A<V4M<&%S<V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.3DU"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB4&%R82!A<W-I;F%R('5M
M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@
M4$=0+"!U;6$@8VAA=F4@(@HB<')I=F%D82!01U`@92!U;6$@9G)A<V4M<&%S
M<V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"B)087)A(&1E8VEF<F%R('5M82!M96YS86=E
M;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U
M;6$@(@HB8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@9G)A<V4M<&%S<V4N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"B)087)A(&%S<VEN87(@=6UA(&UE;G-A9V5M('/C;R!N
M96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82`B"B)C
M:&%V92!P<FEV861A(%,O34E-12!E('5M82!F<F%S92UP87-S92XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@
M4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("+)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%
M('!A<F$@96YC<FEP=&%R('5M82!M96YS86=E;2XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B
M"FUS9W-T<B`B3OIV96YS(&1E(&UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B0VAU=FES8V]S(&1E($UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS
M9W-T<B`B0VAU=F$@9&4@;6%N:.,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R
M(")!9W5A8V5I<F]S(&1E(&UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R(").97;U97,@9&4@;6%N:.,B"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)
M($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R
M(@IM<V=S='(@(D%C97)C82!D97-T92!E9&ET;W(B"@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B06-E
M<F-A+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D)A<V5S(&%L:6YH
M861A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")#96YT<F]S(&%L:6YH
M861O<R(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!8V5S
M<V\@;F5G861O(&%O(&-R:6%R('!A<W1A(%9&4RXB"@HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N(@IM<V=S='(@(D%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q=6EV
M;R!61E,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!
M8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4@9&$@0V]N
M=&$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM
M<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(D-O;G1A(&-O;F=E;&%D
M82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S$W"FUS9VED(")!
M8V-O=6YT:6YG(@IM<V=S='(@(D-O;G1A8FEL:61A9&4B"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-30@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M,S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$V"FUS9VED(")!9&0B"FUS9W-T
M<B`B061I8VEO;F%R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,30@861M:6XO
M9W)O=7!S+G!H<#HR,34*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R
M(")!9&EC:6]N87(@1W)U<&\@1FEL:&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C@T(&QI8B](;W)D92]097)M<R]522YP:'`Z.#4*;7-G:60@(D%D
M9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(D%D:6-I;VYA<B!097)M:7-S
MXV\@1FEL:&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I
M9"`B061D($AE<F4Z(@IM<V=S='(@(D%C<F5S8V5N=&%R($%Q=6DZ(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,#@@861M:6XO9W)O=7!S+G!H<#HR,#D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B061D:6-I;VYA<B!.;W9O($=R
M=7!O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW,R!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C<T"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B061I8VEO;F%R($YO=F$@4&5R;6ES<^-O(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B061I
M8VEO;F%R('5M(&=R=7!O(&9I;&AO(&$@7"(E<UPB(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4S(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@7"(E<UPB(@IM<V=S='(@(D%D:6-I;VYA<B!U;6$@<&5R;6ES<^-O(&9I
M;&AA(&$@7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D
M9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")!9&EC:6]N87(@;F]V;R!U=&EL:7IA
M9&]R.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,C8*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B061I8VEO;F%R(&-O;'5N
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S4*;7-G
M:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")!9&EC:6]N87(@;F]V;W,@
M;65M8G)O<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS
M9VED(")!9&0@<&%I<B(*;7-G<W1R(")!9&EC:6]N87(@<&%R8V5I<F\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G
M<W1R(")!9&EC:6]N87(@;R!-96YU("5S(&-O;6\@0F%R<F$@3&%T97)A;"!-
M;WII;&QA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B061I8VEO
M;F%R(&%O<R!#;VYT86-T;W,Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R(")!9&EC:6]N87(@86]S(&UE=7,@8V]N=&%C=&]S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D%D:6-I
M;VYA<B!U=&EL:7IA9&]R(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL
M(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T
M:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB061I8VEO;F5I(%PB)7-<(B!A;R!S
M:7-T96UA+"!M87,@;N-O('!U9&4@861I8VEO;F%R(&EN9F]R;6'GXV\@9&4@
M<W5B<V-R:>?C;R`B"B)A9&EC:6]N86PZ("5S+B(*"B,Z('-I9VYU<"YP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B061I8VEO;F5I
M(%PB)7-<(B!A;R!S:7-T96UA+B!*X2!P;V1E(&5N=')A<BXB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.38R"FUS9VED(")!9&1I;F<@;F5W(&9I;&5S('1O
M(')E<&]S:71O<GDZ(@IM<V=S='(@(D%D:6-I;VYA;F1O(&YO=F]S(&%R<75I
M=F]S(&%O(')E<&]S:73S<FEO.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHT"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(D$@861IY^-O(&1E('5T:6QI>F%D;W)E<R!E<W3A(&1E<V%C
M=&EV861A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0S(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@
M(D5N9&5R9>=O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D-O;G1A8W1O<R(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B061M:6YI<W1R87(@+2!A=')I8G5I<B!P97)M:7-S]65S(&$@;W5T<F]S
M('5T:6QI>F%D;W)E<R(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!9&UI;FES=')AY^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,Y,@IM<V=I9"`B061S(@IM<V=S='(@(D%N^FYC:6]S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069E9V%N:7-TXV\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;&)A;FEA(@IM<V=S='(@(D%L8N)N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM
M<V=S='(@(D%R9^EL:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QC=6YH82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L:6YH87(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG
M;FUE;G0Z(@IM<V=S='(@(D%L:6YH86UE;G1O.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E1U9&\B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T
M<B`B5&]D;W,@;W,@571I;&EZ861O<F5S($%U=&5N=&EC861O<R(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,3(*;7-G:60@
M(D%L;"!'<F]U<',B"FUS9W-T<B`B5&]D;W,@;W,@1W)U<&]S(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&QI8B](;W)D92]097)M<R]522YP
M:'`Z-S<*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")4;V1A<R!A
M<R!097)M:7-S]65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B5&]D;W,@;W,@*'%U871R;RD@;&%D;W,B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@W,@IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(E!E<FUI=&ER(&WZ;'1I<&QO<R!E;F1E<F7G;W,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")097)M:71I<B!A=')I
M8G5IY^-O(&1O('1I<&\@9&4@;&ES=&%S(&]R9&5N861A<S\B"@HC.B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HT,#@*;7-G:60@(D%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(DKA(&5X:7-T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(D5N=')A9&$@24U34"!!;'1E<FYA=&EV82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM
M<V=S='(@(E!A;&%V<F$M4&%S<V4@24U34"!!;'1E<FYA=&EV82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3$*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%5S97)N86UE(@IM<V=S='(@(DYO;64@9&4@571I;&EZ861O<B!)35-0($%L
M=&5R;F%T:79O(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D5N9&5R
M9>=O(&EN=N%L:61O(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B36]D96QO<R!A;'1E
M<FYA=&EV;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*
M;7-G<W1R(")497AT;R!A;'1E<FYA=&EV;SHB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!3
M86UO82(*;7-G<W1R(")386UO82!!;65R:6-A;F$B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS
M9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@
M(D9O:2!E<W!E8VEF:6-A9&\@=6T@=F%L;W(@:6YVX6QI9&\N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-`IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O
M(&1E<V-O;FAE8VED;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R
M<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B06YG=6EL82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D5N
M=')E<&]S=&\@*'!R;WAY*2!!;O-N:6UO(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")297-P;W-T
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YTX7)C=&EC;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT[6=U82!E($)A
M<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H
M96QL+G!H<#HS-2!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T
M:6]N(@IM<V=S='(@(D%P;&EC8>?C;R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,SD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R
M(")!<&QI8V'GXV\@<')O;G1A+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T
M<B`B07!L:6-A<B!A(%!A<G1I;&AA<R!&:6QH87,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G
M<W1R(")!<')O=F%R(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C@S,`IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")486UA;FAO
M($%P<F]X:6UA9&\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<W(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,30*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B06)R:6PB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM
M<V=S='(@(D%RX6)I8V\@*%=I;F1O=W,M,3(U-BDB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW
M.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B5&%M86YH;R!D
M;R!&:6-H96ER;R!D92!!<G%U:79O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R(").;VUE(&1O($%R<75I=F\B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B5&5M(&$@
M8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&\@<&5D:61O(&1E('-U8G-C<FGG
MXV\@<&%R82`E<R`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*
M;7-G<W1R(")496T@82!C97)T97IA('%U92!Q=65R(')E;6]V97(@7"(E<UPB
M(&4@<75A:7-Q=65R('-U8BUG<G5P;W,_(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM
M<V=S='(@(D%R9V5N=&EN82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M
MZ6YI82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE
M;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FWI;FEO("A!4DU30TE)+3@I
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS
M9W-T<B`B07)T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L
M86YD(@IM<V=S='(@(DEL:&$@9&4@07-C96YSXV\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<G1E
M($%30TE)(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B4F5G:>-O(,%S:6$O4&%C
M[69I8V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$W"FUS9VED(")!
M<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<S\B"FUS9W-T<B`B4&5D:7(@8V]N9FER;6'GXV\@86YT97,@
M9&4@<F5A;&EZ87(@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\_(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,3(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R(")#;VQU;F%S(&1E(&%T<FEB=6GGXV\B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<U"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B5&5N=&%T:79A(&1E(')E;6_GXV\@
M9&4@=6T@9W)U<&\@:6YE>&ES=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HS.`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B5&5N=&%T:79A(&1E(')E;6_G
MXV\@9&4@=6UA('!E<FUI<W/C;R!I;F5X:7-T96YT92XB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HY.`IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1A=&EV82!D92!E
M9&GGXV\@9&4@=6UA('!E<FUI<W/C;R!I;F5X:7-T96YT92XB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B5&5N=&%T:79A(&1E
M(&5D:>?C;R!D92!U;6$@<&%R=&EL:&$@:6YE>&ES=&5N=&4N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071R:6)U=&]S
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U
M9W5S="(*;7-G<W1R(")!9V]S=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T
M<B`B075S='+A;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("+!=7-T<FEA
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?8WER<W%L.B!!(&5X=&5N<^-O(&EM87`@;F5C97-S
MX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H
M7V-Y<G5S.B!/(&UE8V%N:7-M;R!NXV\@=&5M(&%S(&-A<&%C:61A9&5S(&YE
M8V5S<^%R:6%S+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C(*
M;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@02!E>'1E;G/C;R!I;6%P
M(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D
M92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F
M='`Z($$@97AT96YSXV\@1E10(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R
M861A+B!#;VUP:6QE(&\@4$A0(&-O;2!A("(*(F]PY^-O("TM96YA8FQE+69T
M<"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:6UA<#H@02!E>'1E;G/C;R!)34%0(&YE8V5S<^%R:6$@
M;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!!(&5X=&5N<^-O
M(&MR8C4@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-3@*;7-G:60@(D%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VQD87`Z($$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC
M;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)!=71H7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R('5T:6QI>F%D
M;W(@)7,N($5I<R!O('%U92!O('-E<G9I9&]R(&1I<W-E.B`B"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B
M075T:%]L9&%P.B!);7!O<W/M=F5L(')E;6]V97(@;R!U=&EL:7IA9&]R("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M(@IM<V=S='(@(D%U=&A?;&1A<#H@26UP;W-S[79E;"!A8W1U86QI>F%R(&\@
M=71I;&EZ861O<B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V
M"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!!(&5X=&5N<^-O($U#04P@
M;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M<VUB875T:#H@02!E>'1E;G/C;R!S;6)A=71H(&YE8V5S<^%R:6$@;N-O(&9O
M:2!E;F-O;G1R861A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T
M<B`B02!A=71E;G1I8V'GXV\@9F%L:&]U(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,B"FUS9W-T<B`B02!A=71E;G1I8V'GXV\@9F%L:&]U+B`E
M<R(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G
M<W1R(")!(&%U=&5N=&EC8>?C;R!F;VD@<F5J96ET861A('!E;&\@<V5R=FED
M;W(@4D%$2553+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C@*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!
M(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!&5%`@9F%L:&]U+B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.#,*;7-G:60@(D%V86EL86)L92!F
M:65L9',Z(@IM<V=S='(@(D-A;7!O<R!D:7-P;V[M=F5I<SHB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B86EJXV\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")$
M97-C=6QP87,@7")"3T9(7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM
M<V=S='(@(D9U;F1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R
M(")#;W(@9&\@1G5N9&\B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX
M,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")086QA
M=G)A+5!A<W-E(&ME<F)E<F]S(&5R<F%D82XB"@HC.B!L:6(O2&]R9&4O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R(").;VUE(&1E(%5T:6QI>F%D;W(@:V5R8F5R;W,@97)R861O+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%A;6%S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I
M;B(*;7-G<W1R(")"87+I;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W
M"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"X6QT:6-O
M("A)4T\M.#@U.2TQ,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A
M;F=L861E8VAE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(DQI;FAA(&)A<V4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QA<G5S(@IM<V=S='(@(D)I96QO<G+Z<W-I82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E
M;&=I=6TB"FUS9W-T<B`B0NEL9VEC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R
M(")"96QI>F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G
M<W1R(")"=73C;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")!;FEV97)SX7)I;R(*
M"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D\@8FQO8V\@7"(E<UPB(&1A(&%P
M;&EC8>?C;R!<(B5S7"(@;N-O(&9O:2!E;F-O;G1R861O+B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN
M9W,B"FUS9W-T<B`B0V]N9FEG=7)AY_5E<R!D92!";&]C;W,B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B
M"FUS9W-T<B`B5&EP;R!D92!";&]C;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(").
M96=R:71O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VSM=FEA(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y,0IM<V=I9"`B0F]O:VUA<FMS
M(@IM<V=S='(@(DUA<F-A9&]R97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS
M9W-T<B`B0F]R9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R
M(")%<W!E<W-U<F$@9&$@8F]R9&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*
M;7-G<W1R(")";W)D87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA
M(@IM<V=S='(@(D+S<VYI82U(97)Z96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")!;6)A<R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-U86YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")"
M;W1T;VTB"FUS9W-T<B`B0F%S92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS
M9W-T<B`B26QH82!";W5V970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A
M<VEL(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*
M;7-G<W1R(")497)R:73S<FEO($)R:73B;FEC;R!D;R!/8V5A;F\@S6YD:6-O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A
M<G5S<V%L86TB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D)U:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N
M+BXB"FUS9W-T<B`B0V]N<W1R=6EN9&\@87)Q=6EV;W,@34\@<&%R82!O(&WS
M9'5L;R`E<RXN+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0G5I;&1I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R
M(")#;VYS=')U:6YD;R!L;V-A;&EZ8>?C;R`E<RXN+B`B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG
M87)I82(*;7-G<W1R(")"=6QGX7)I82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B
M"FUS9W-T<B`B3&ES="!)=&5M:7IA9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B0G5R<75I;F$@1F%S;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T
M<B`B0G5R^FYD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*
M;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")0;VYT;W,@9&4@1&ES=')I8G5I
MY^-O($-23"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")0<F]P<FEE9&%D97,@9&$H<RD@0^E?;'5L82AS*2XN+B(*"B,@
M8RUF;W)M870*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,`IM
M<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B
M26YI8VEA;&EZ8>?C;R!D82!<(F-A8VAE7"(@;N-O(&9O:2!C;VYC;'7M9&$N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30X"FUS9VED(")#86QE;F1A<B(*
M;7-G<W1R(")#86QE;F3A<FEO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-`IM<V=I9"`B0V%L;2(*;7-G<W1R(")#86QM;R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")#86UB;V1I82(*;7-G<W1R(")#86UB;V1J82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N
M(@IM<V=S='(@(D-A;6%R]65S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(B(*(D[C;R!P;W-S;R!R96EN:6-I87(@82!P86QA=G)A+7!A<W-E(&%U=&]M
M871I8V%M96YT92P@8V]N=&%C=&4@;R!S974@(@HB861M:6YI<W1R861O<B!D
M92!S:7-T96UA<RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U
M(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S
M='(@(DEM<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@24U!4#H@)7,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%N863A(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$W"FUS9VED(")#86YC96PB"FUS9W-T<B`B0V%N8V5L87(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R
M;V)L96T@4F5P;W)T(@IM<V=S='(@(D-A;F-E;&%R(%)E;&%T\W)I;R!D92!0
M<F]B;&5M87,B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C4V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(D[C;R!C;VYS:6=O(')E;6]V97(@;R!F:6-H96ER;R!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(D[C;R!C;VYS:6=O(&5N8V]N=')A<B!U;2!D:7)E
M8W3S<FEO('1E;7!O<N%R:6\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP
M.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(@IM<V=S='(@(DEM<&]S<^UV96P@8V]N=&EN=6%R('-E
M;2!O('!A<N)M971R;R`G=&%R9V5T1FEL92<N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M
M;W9E<B!A('!A<W1A(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N
M<&AP.C$Q,B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(@IM<V=S='(@(DEM<&]S<^UV96P@<F5M;W9E<BP@97AI<W1E;2`E9"!F
M:6QH;W,N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3$R"FUS
M9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P
M<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T
M;W)E9"XB"FUS9W-T<B`B(@HB3N-O(.D@<&]S<^UV96P@<F5O<F1E;F%R.B!O
M(&[Z;65R;R!D92!E;G1R861A<R!F;W)N96-I9&%S(&[C;R!C;W)R97-P;VYD
M92!A;R`B"B)N^FUE<F\@9W5A<F1A9&\N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@96YC86UI;FAA<B!A(&UE;G-A9V5M('!A<F$@;R!N^FUE<F\@:6YD
M:6-A9&\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")297#Z8FQI8V$@
M9&4@0V%B;R!697)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B
M3&5G96YD82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B
M0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(D-A=&5G;W)I87,@92!#
M;W)E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("));&AA<R!#
M86EMXV\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")496QE9F]N92!#96QU;&%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R
M:65D861E<R!D87,@0^EL=6QA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM
M<V=S='(@(D5N8VAI;65N=&\@9&%S($/I;'5L87,Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B
M0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D87,@8^EL
M=6QA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(D5S<&'G86UE
M;G1O(&1A<R!CZ6QU;&%S.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<T
M"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5&5L96WS=F5L(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM
M,30I(@IM<V=S='(@(D/I;'1I8V\@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G
M:60@(D-E;G1E<B(*;7-G<W1R(")#96YT<F%R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!#96YT<F\@069R
M:6-A;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B175R;W!A($-E
M;G1R86P@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M4&]R;65N;W)E<R!D;R!#97)T:69I8V%D;R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G
M<W1R(")$;VYO(&1O($-E<G1I9FEC861O(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(E!O;.UT:6-A<R!D92!#97)T:69I8V%D;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA
M9"(*;7-G<W1R(")297#Z8FQI8V$@9&\@0VAA9&4B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDW"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B06QT97)A<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(D%L
M=&5R92!O(&YO;64@92!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!V97+C;R!Q
M=6%N9&\@;&5R96T@92!R97-P;VYD97)E;2#@<R`B"B)S=6%S(&UE;G-A9V5N
M<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(D-A<F%C=&5R92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B5F5R:5]F:6-A
M<B!,:6=AY^-O+BXN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I
M<FU?=&]P+FEN8SHQ,PIM<V=I9"`B0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB
M"FUS9W-T<B`B36%R<75E(&%S(&]P97)AY_5E<R!Q=64@9&5S96IA(&5X96-U
M=&%R(&YE<W1E(&UO;65N=&\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B4F5P
M^F)L:6-A(&1O($-H:6QE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B4F5P^F)L
M:6-A(%!O<'5L87(@9&$@0VAI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(D-H:6[J<R!3:6UP;&EF:6-A9&]S("A'0C(S,3(I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I(@IM<V=S='(@(D-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2DB"@HC
M.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E
M(&$@<&%S<W=O<F0B"FUS9W-T<B`B17-C;VQH82!A('!A;&%V<F$M<&%S<V4B
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO
M;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B17-C;VQH82!U;2!.;VUE(&1E(%5T
M:6QI>F%D;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDP"FUS9VED
M(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(D5S8V]L
M:&$@8V]M;R!M;W-T<F%R(&%S(&1A=&%S.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R(")%<V-O;&AA(&\@97-T:6QO(&1A<R!L:7-T82`H<&%R82!L:7-T87,@
M;W)D96YA9&%S*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B
M26QH82!D;R!.871A;"(*"B,Z(&QI8B]61E,N<&AP.C8Q-2!L:6(O3F5T+U--
M4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").XV\@9F]I(&5N8V]N=')A
M9&$@82!D969I;FGGXV\@9&$@8VQA<W-E("5S+B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HX-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE86YI;F<@=7`@
M4$\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R("),:6UP86YD;R!O
M<R!A<G%U:79O<R!03R!D;R!M\V1U;&\@)7,N+BXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#8W"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%N:6YG('5P
M(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B3&EM<&%N9&\@82!L;V-A;&EZ8>?C
M;R`E<RXN+B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B3&EM<&%R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("),:6UP87(@971I<75E=&%S
M(&1O($U33V9F:6-E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S
M(@IM<V=S='(@(DQI;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R.B`E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ-@IM<V=I9"`B0VQE
M87(@=7-E<B(*;7-G<W1R("),:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#
M;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B3&EM<&%R(&1A9&]S(&1O('5T:6QI
M>F%D;W(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("),:6UP82!487)D
M92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?8F]T=&]M+FEN
M8SHV"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")#;&EQ=64@
M<&%R82!#;VYT:6YU87(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R
M(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#
M;&]S92!7:6YD;W<B"FUS9W-T<B`B1F5C:&%R(&IA;F5L82(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3OIV
M96YS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(").^G9E;G,@36%T:6YA
M:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D5N979O861O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B26QH87,@0V]C;W,@*$ME
M96QI;F<I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHT"FUS
M9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(D-O;&%P<V%R($)A<G)A
M($QA=&5R86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R(")";W)D87,@0V]L87!S861A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S
M='(@(E)E</IB;&EC82!D82!#;VST;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#
M;VQO<B(*;7-G<W1R(")#;W)E<R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL
M96-T:6]N+G!H<#HR.3D@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,P,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#<R
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3$*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3(*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C@*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-CD*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#8*;7-G:60@(D-O
M;&]R(%!I8VME<B(*;7-G<W1R(")086QE=&4B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C@T-0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")3
M96QE8^?C;R!D92!C;W)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")#;VQU
M;F%S.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30W"FUS9VED(")#;VQU
M;6X@=&ET;&5S(@IM<V=S='(@(E3M='5L;W,@9&%S(&-O;'5N87,B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@V"FUS9VED(")#;VUI8W,B"FUS
M9W-T<B`B0D0B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O
M;6UA;F0B"FUS9W-T<B`B0V]M86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")#;VYS;VQA(&1E
M($-O;6%N9&]S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,X"FUS9VED(")#
M;VUM86YD(&]P=&EO;G,Z(@IM<V=S='(@(D]PY_5E<R!D;R!C;VUA;F1O.B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY-PIM<V=I9"`B0V]M;6%N9',Z(@IM
M<V=S='(@(D-O;6%N9&]S.B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0P,@IM<V=I9"`B0V]M;65N="(*;7-G<W1R(")#;VUE;G3A<FEO(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P,#`*;7-G:60@(D-O;6UI='1I;F<Z(@IM
M<V=S='(@(D-O;65T96YD;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(").;VUE($-O;75M
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M;W)O<R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY
M(@IM<V=S='(@(D5M<')E<V$B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H
M<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY-R!L
M:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]M<&]S92!-97-S86=E("@E<RDB"FUS9W-T<B`B17-C
M<F5V97(@*"5S*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I
M9"`B0V]M<'5T97)S(@IM<V=S='(@(D-O;7!U=&%D;W)E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*;7-G:60@(D-O;F1I=&EO;B(*
M;7-G<W1R(")#;VYD:>?C;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y
M"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D-O;F1IY_5E<R(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I
M9F9E<F5N8V5S(@IM<V=S='(@(D1I9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B02!C;VYF:6=U<F'G
MXV\@97-TX2!D97-A8W1U86QI>F%D82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS
M9W-T<B`B0V]N9FEG=7)A<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S<*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T
M<B`B0V]N9FER;64@82!086QA=G)A+5!A<W-E(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`B4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1O($-O;F=O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R
M(")297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\@0V]N9V\B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*
M;7-G<W1R(")#;VYE>.-O(&9A;&AO=2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B
M0V]N97CC;R!F86QH;W4Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C<W.0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")#;VYE>.-O(&%O('-E<G9I9&]R(&1E(&-H
M879E<R!P^F)L:6-A<R!R96-U<V%D82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RDB"FUS9W-T<B`B0V]N97CC;R!A;R!S97)V:61O<B!D92!C:&%V97,@</IB
M;&EC87,@<F5C=7-A9&$N(%)A>N-O.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<V,@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B0V]N97CC;R!A;R!S97)V:61O<B!&5%`@<F5C=7-A
M9&$N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM
M<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D-O;G1A8W1O<R!A9&EC:6]N861O
M<R!C;VT@<W5C97-S;R!A;R!S974@;&EV<F\@9&4@96YD97)EYV]S+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT
M96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B5&EP;R!D
M92!C;VYT9?ID;R!D;R!A<G%U:79O(&-O;7!R:6UI9&\Z("(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<
M(B(*;7-G<W1R(")#;VYT9?ID;R!D92`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT
M:6YU87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B26QH87,@0V]O
M:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE
M(@IM<V=S='(@(D)O;&EN:&\@8VAI;NIS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y
M(@IM<V=S='(@(D-O<&EA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(D-O<&EA<B!S96QE8^?C;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'EI;F<@)7,@=&\@)7,B"FUS
M9W-T<B`B0V]P:6%N9&\@9&4@)7,@<&%R82`E<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I
M8V$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($-O<W1A(%)I8V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;W1E(&0G279O:7)E(@IM<V=S='(@(E)E</IB;&EC82!D82!#;W-T82!D;R!-
M87)F:6TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-38*;7-G:60@
M(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&5N8W)I<'1A<B!A(&UE;G-A9V5M(&-O;2!01U`N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`S,PIM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!01U`N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5N
M8W)I<&%R(&$@;65N<V%G96T@8V]M(%,O34E-12XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@87-S:6YA
M<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@861I8VEO;F%R(&\@8V]N=&%C=&\N("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,3$P"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B1F%L:&$@;F$@;&EG8>?C;R`H8FEN9"D@86\@
M<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E
M+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L('9E<FEF:6-A<B!O('-A
M;&1O+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E
M<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C
M;VYE8W1A<B!A;R!S97)V:61O<B!<(B5S7"(@=7-A;F1O($944#H@)7,B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<R(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(&-O<&EA<B`E<R!P87)A("5S(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&-R:6%R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@
M)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@Q('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#<W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&-R:6%R('!A<W1A(&1E(&QO8V%L:7IAY^-O('!A
M<F$@82!L;V-A;&EZ8>?C;R`E<SHB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,3`U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!D97-E;F-R:7!T87(@;W,@9&%D
M;W,@8V]M(&\@4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!D97-E;F-R:7!T87(@;W,@9&%D;W,@
M8V]M(%,O34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M(&-O;G1A8W1O+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!R96UO=F5R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@7")S8W)I
M<'1<(B!D92!A8W1U86QI>F'GXV\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS
M.`IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@
M9&5T97)M:6YA<B!O(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@
M9&\@(@HB9&5S=&EN873A<FEO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T
M97(@;R!L:79R;R!D92!E;F1E<F7G;W,@8V]M<&QE=&\N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O
M(&-O;7!L971A+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES
M="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@;V)T97(@82!L:7-T82!C;VUP;&5T82!D87,@;&ES=&%S(&1E(&1I
M<W1R:6)U:>?C;RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@
M8V%R<F5G87(@97-T<F%TZ6=I82!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<^UV96P@;6MD:7(@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<P.`IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@HB
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T
M:7(@9&\@<V5R=FED;W(@9&4@8VAA=F5S("(*(G#Z8FQI8V%S+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@
M9F]R('=R:71I;F<N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@
M7"(E<UPB('!A<F$@97-C<FET82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0U"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER("5S+B(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!M\V1U;&\@9&4@
M36%N=71E;N?C;R!D92!487)E9F%S("5S(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!P87-T82!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!L97(@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(')E:6YI8VEA<B!A('!A;&%V
M<F$M<&%S<V4@9&\@=71I;&EZ861O<B!I;F1I8V%D;RX@06QG=6T@;W4@(@HB
M=&]D;W,@;W,@<&]R;65N;W)E<R!NXV\@97-T879A;2!C;W)R96-T;W,N(%!O
M<B!F879O<B!T96YT92!D92!N;W9O(&]U("(*(F-O;G1A8W1E(&\@<V5U(&%D
M;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<V4@<')E8VES87(@9&4@;6%I<R!A
M:G5D82XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!!0TPB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&EV<F\@9&4@96YD97)EYV]S
M+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B
M=&5R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&ES=&%S(&1E(&1I<W1R
M:6)U:>?C;RX@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-O;7!E=.IN8VEA<R!D;R!S
M97)V:61O<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@
M(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!R979E<G1E<B!A(&-O;F9I9W5R8>?C;RXB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB
M+B(*;7-G<W1R("));7!O<W/M=F5L(')M9&ER(%PB)7-<(BXB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@)7,N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4W"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A
M(&-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D82XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G
M=6%R9&$Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!G=6%R9&%R(&\@7")S8W)I<'1<(B!D92!A8W1U86QI>F'GXV\@96TZ(%PB
M)7-<(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&=U
M87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$@)7,N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M
M=F5L(&=U87)D87(@;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@4&]D
M92!U<V%R('5M82!D87,@(@HB;W#G]65S('!A<F$@9W5A<F1A<B!O(&/S9&EG
M;R!E;2`E<R!O=2!C;W!I87(@;6%N=6%L;65N=&4@;R!C\V1I9V\@86)A:7AO
M("(*(G!A<F$@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(P
M"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!P<F]C=7)A<B!N;R!S97)V:61O<B!,
M1$%0+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&1E<VQI
M9V%R(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI
M>F%R(&-O;G1A8W1O+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!A8W1U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E
M<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E
M<UPB.B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R(&$@
M8V]N9FEG=7)AY^-O('!A<F$@7"(E<UPB.B`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-3@*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(B(*(D[C;R!E;F-O;G1R96D@82!"87)R82!,871E<F%L(&1O($UO
M>FEL;&$N($%S<V5G=7)E+7-E('%U92!A(&)A<G)A(&QA=&5R86P@(@HB97-T
MX2!A8F5R=&$N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S
M97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!A=')I
M8G5I<B!A;R!U=&EL:7IA9&]R(%PB)7-<(B!O<R!S96=U:6YT97,@9&ER96ET
M;W,@<V]B<F4@82`B"B)P87-T82!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,C$*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")4
M97AT;R!#;VYT861O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S`*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M0W5R<V]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)I
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0W)I
M87(@=6UA(&QI9V'GXV\B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDS"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@
M(D-R:6%R('5M82!N;W9A(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B
M0W)I87(@<W5B+7!A<W1A<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S
M-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Q-`IM<V=I9"`B0W)E871O<B!0
M97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(&1O($-R:6%D;W(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(R.0IM<V=I9"`B0W)E9&ET(&-A<F0@
M;G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(E)E</IB;&EC82!D82!#<F_A8VEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0W5B82(*;7-G<W1R(")297#Z8FQI8V$@9&4@0W5B82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E
M<R(*;7-G<W1R(")1=6%T<F\@9F%S97,@8V]R<F5N=&5S(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#
M=7)R96YT(%1I;64B"FUS9W-T<B`B1&%T82](;W)A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED
M(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")54DP@8V]R<F5N=&4@Z2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE
M<B(*;7-G<W1R(")%<W1A9&\@9&\@5&5M<&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@
M(@IM<V=S='(@(E-I='5AY^-O(&%C='5A;#H@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S
M='EL92(*;7-G<W1R(")%<W1I;&\@86-T=6%L(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O
M;F%L:7IA<B!A<R!T87)E9F%S('%U92!S97+C;R!E>&5C=71A9&%S(&%Q=6%N
M9&\@;R!L;V=I;B!N;R`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R
M(")#;W)T87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(D-O<G1A
M<B!A('-E;&5CY^-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(E)E</IB;&EC
M82!D92!#:&EP<F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I
M9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B0VER[6QI8V\@*$M/23@M
M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B0VER[6QI8V\@*%=I;F1O=W,M
M,3(U-BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D-I<NUL:6-O+U5C
M<F%N:6%N;R`H2T])."U5*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S
M='(@(E)E</IB;&EC82!#:&5C82(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,C,@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&EA<FEA;65N=&4B"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`B3F%V96=A9&]R(&1E(,%R=F]R92!D92!$861O<R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,SDX(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B
M1&%T92!296-E:79E9"(*;7-G<W1R(")$871A(&1E(%)E8V5PY^-O(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#8*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(E-E;&5CY^-O(&1E(&1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3`*;7-G:60@(D1A>2(*;7-G<W1R(")$:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@
M(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E)E;6]V97(@0V]?;'5N82(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E
M<B(*;7-G<W1R(")$97IE;6)R;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(&1E8VEM86ES(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(E)E9'5Z:7(@:6YD96YT8>?C;R(*"B,Z
M(&QI8B]P<F5F<RYP:'`Z,3$Q(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(E!O<B!/;6ES<^-O(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*;7-G:60@
M(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B0V]R(%!O<B!/;6ES<^-O(@H*(SH@
M;&EB+TAO<F1E+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N
M=&ET>2(*;7-G<W1R("))9&5N=&ED861E(%!A9'+C;R(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$Q.2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-@IM
M<V=I9"`B1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S
M(%!O<B!/;6ES<^-O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<*
M;7-G:60@(D1E9F%U;'0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E
M<R!P;W(@;VUI<W/C;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM
M<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6YIY_5E<R(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S(@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,CDU(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$U"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,S,R('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3D@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`B4F5M;W9E<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@Y(&%D;6EN
M+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B
M4F5M;W9E<B!'<G5P;R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-C,@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-PIM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B4F5M;W9E<B!097)M:7-SXV\B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B4F5M;W9E<B!E('!U<F=A<B!M96YS
M86=E;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")296UO
M=F5R(&/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T
M<B`B4F5M;W9E<B!C;VQU;F$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R(")296UO=F5R(&UO9&5L;R!A;'1E<FYA=&EV;R!E>&ES=&5N=&4B
M"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4P(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E)E;6]V97(@<&5R;6ES<_5E
M<R!D92!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E
M<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E)E;6]V97(@
M<&5R;6ES<_5E<R!P87)A("<E<R<@92!Q=6%I<W%U97(@<W5B+7!E<FUI<W/U
M97,_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")296UO=F5R
M(&QI;FAA(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN
M8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@
M(E)E;6]V97(@:61E;G1I9&%D92!S96QE8V-I;VYA9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G
M:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B4F5M;W9E
M<B!A(&-O;'5N82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B1&5L971E('1H
M92!C=7)R96YT(')O=R(*;7-G<W1R(")296UO=F5R(&$@;&EN:&$@8V]R<F5N
M=&4B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0X"FUS9VED(")$96QE
M=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*
M;7-G<W1R(")296UO=F5R(&5S=&$@<&5R;6ES<^-O(&4@=&]D87,@87,@<W5A
M<R!S=6(M<&5R;6ES<_5E<S\B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B7")38W)I<'1<(B!D92!A8W1U
M86QI>F'GXV\@7"(E<UPB(')E;6]V:61O+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Y-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I
M9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R(")-;VUE;G1O(&1E(&5N=')E9V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1I;F%M87)C82(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$Q,"!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,30@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(T"FUS9VED(")$97-C<FEB92!T:&4@
M4')O8FQE;2(*;7-G<W1R(")$97-C<F5V82!O(%!R;V)L96UA(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G
M<W1R(")$97-C<FGGXV\B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B
M1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")0
M;W)M96YO<F5S("AT86UBZ6T@;F\@<F5G:7-T;RP@7")L;V=<(BP@9&\@2&]R
M9&4I.B(*"B,Z(&QI8B](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M(")/<R!D971A;&AE<R!F;W)A;2!E;G9I861O<R!P87)A(&\@861M:6YI<W1R
M861O<B!D;R!S:7-T96UA+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.3@*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D1E<V5N=F]L=FEM
M96YT;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@
M4&]I;G0B"FUS9W-T<B`B4&]N=&\@9&4@3W)V86QH;R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(E!O;G1O(&1E($]R=F%L:&\@;F$@^FQT:6UA(&AO<F$Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@
M(D1E=R!P;VEN=#H@(@IM<V=S='(@(E!O;G1O(&1E(&]R=F%L:&\Z("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G
M:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(D1I<F5CY^-O
M(&1A(&5S<75E<F1A('!A<F$@82!D:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N
M(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B1&ER96/GXV\@9&$@9&ER96ET82!P
M87)A(&$@97-Q=65R9&$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=/-R:6\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C4X"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_(@IM<V=S='(@(DUO<W1R87(@=&5M<&]S(&-O;2`R-"!H;W)A<S\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&4@5FES=6%L:7IAY^-O(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@X"FUS9VED(")$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(DUO<W1R87(@<')E=FESXV\@
M<&]R;65N;W)I>F%D82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G
M:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B36]S=')A<B!P
M<F5V:7/C;R`H5$%&*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$V"FUS
M9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1E('9I<W5A
M;&EZ8>?C;R(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B3F]T:69I8V'G
MXV\@9&4@1&ES<&]S:>?C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J
M:6)U=&DB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,S$U"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S
M='(@(D[C;R!R96UO=F5R(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C(T"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<"(*;7-G<W1R(").XV\@=71I;&EZ92!O(&UA:6YT96YA;F-E+G!H<"!D
M:7)E8W1A;65N=&4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ.0IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B)!('!R:6UE:7)A(&QI;FAA
M(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!392!S:6TL(&%S<VEN86QA
M<B!E<W1A(&-A:7AA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN
M:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB
M;&EC82!$;VUI;FEC86YA(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C@T,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B4F5C96)E<B(*"B,Z
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B4F5C96)E<B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C4*;7-G:60@(D1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@
M(D1E<V-A<G)E9V%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(%PB
M<V-R:7!T7"(@4$A0+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3`X"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("),:7-T82!D92!D97-E;G)O
M;&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G
M<R(*;7-G<W1R(")$<F]G87,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,#(*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W)R96EO(&5L96-T<O-N
M:6-O(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U
M861O<B(*;7-G<W1R(")297#Z8FQI8V$@9&\@17%U861O<B(*"B,Z(&QI8B](
M;W)D92]097)M<RYP:'`Z,CDT('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS
M9VED(")%9&ET(@IM<V=S='(@(D5D:71A<B(*"B,Z(&QI8B](;W)D92]";&]C
M:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I
M9"`B161I="!";&]C:R(*;7-G<W1R(")%9&ET87(@0FQO8V\B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$X."!A9&UI;B]G<F]U<',N<&AP.C(Q-@IM<V=I9"`B
M161I="!'<F]U<"(*;7-G<W1R(")%9&ET87(@1W)U<&\B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C8R(&QI8B](;W)D92]097)M<R]522YP:'`Z.#8*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")%9&ET87(@4&5R;6ES
M<_5E<R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B161I=&%R(%!E<FUI<W/U97,B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D
M:71A<B!P97)M:7-S]65S(&1E("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B161I
M=&%R(&]PY_5E<R!D93HB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5D:71A
M<B!P97)M:7-S]65S(&1E(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B161I=&%R('!E<FUI<W/U97,@9&4@)7,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO
M;B(*;7-G<W1R(")%9'5C8>?C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G
M:7!T;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B4F5P^F)L:6-A
M(&1E($5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(D5L96UE;G1O+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S`@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(D-O<G)E
M:6\@16QE8W1R\VYI8V\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$R"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#`*;7-G:60@(D5M86EL
M($%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@0V]R<F5I;R!%;&5C='+S
M;FEC;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.38T"FUS9VED(")%;6%I
M;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B3W,@96YD97)EYV]S
M('3J;2!Q=64@8V]I;F-I9&ER+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.3DP"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")-
M96YS86=E;2!C;VT@8V]N9FER;6'GXV\B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C@P"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T
M<B`B4^UM8F]L;W,@9&4@16UOY^-O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S
M='(@(DUE;G-A9V5M('9A>FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C$R.`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")396T@<F5S
M=6QT861O<RXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*
M;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")396T@=&5R;6]S
M(&1E('!R;V-U<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,U"FUS
M9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")!8W1I=F%R(&EN<V5RY^-O(&1E
M(&EM86=E;G,@9&4@1V%L97)I87,@1F]T;V=RX69I8V%S(&YO('1E>'1O/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3`*;7-G:60@(D5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%C=&EV87(@;65N
M=2!D92!C;VYT97AT;R!N;R!B;W3C;R!D:7)E:71O(&1O(')A=&\_(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,3`*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D%N;R!D92!F:6TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")!=6UE;G1A<B!%9&ET;W(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$S"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB26YT
M<F]D=7IA('5M82!P97)G=6YT82!D92!S96=U<F%NYV$@<75E('-E<N$@8V]N
M=FED861O(&$@<F5S<&]N9&5R('-E("(*(G!R96-I<V%R(&1E(')E:6YI8VEA
M<B!A('-U82!P86QA=G)A+7!A<W-E+"!E+F<N+"`G8V]M;R!S92!C:&%M82!O
M('-E=2!A;FEM86P@(@HB9&4@97-T:6UAY^-O/R<Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS
M9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B26YT<F]D
M=7IA(&\@55),(&1A(&EM86=E;2!A<75I(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$Q-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<FEE<SH@)60@=&]T
M86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK
M;F]W;B(*;7-G<W1R("(B"B)%;G1R861A<SH@)60@=&]T86PL("5D(&%C='5A
M;&EZ861A<RP@)60@;F]V87,L("5D(&%L=&5R861A<RP@)60@9&5S8V]N:&5C
M:61A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D=U:6[I
M($5Q=6%T;W)I86PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5S=&%D;R!D
M82!%<FET<F5I82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@HC.B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C<Y"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@
M(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B17)R;R!N82!M
M96YS86=E;2!D92!C;W)R96EO(&5L96-T<O-N:6-O+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T
M<B`B17)R;R!A;R!E<V-R979E<B!<(B5S7"(N(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(R('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,S<W"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#,X('!O+W1R
M86YS;&%T:6]N+G!H<#HQ-3`Q"FUS9VED(")%<G)O<CH@(@IM<V=S='(@(D5R
M<F\Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($5S
M=/-N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")297#Z8FQI8V$@1&5M
M;V-RX71I8V$@1F5D97)A;"!D82!%=&GS<&EA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`BR71I8V\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM
M<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*
M;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`Q-2!M:6YU
M=&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,B!M:6YU=&]S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,R."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<Y"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D-A9&$@,S`@
M<V5G=6YD;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,P(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R(")#861A(#4@;6EN=71O<R(*"B,Z(&QI8B](;W)D92]-86EN=&5N
M86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D-A9&$@
M16YT<F%D82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S(*;7-G:60@
M(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#861A(&UE:6$@:&]R82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,CD@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D-A9&$@;6EN
M=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C@*;7-G:60@
M(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")686QO<F5S(&5X96UP;&\Z(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU
M,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")%>&5C=71E(@IM<V=S
M='(@(D5X96-U=&%R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(Y.2!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,S(P('!O+W1R86YS;&%T:6]N+G!H<#HS-C(*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C0T,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-30Q
M('!O+W1R86YS;&%T:6]N+G!H<#HV,#$*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C<P,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S,W('!O+W1R86YS;&%T:6]N+G!H
M<#HW.3@*(SH@<&\O=')A;G-L871I;VXN<&AP.C@W-2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.3DT('!O+W1R86YS;&%T:6]N+G!H<#HQ,#$V"FUS9VED(")%>&5C
M=71I;F<Z(@IM<V=S='(@(D5X96-U=&%N9&\Z(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z,SDT"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B17AP
M86YD:7(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")-;W-T<F%R($)A<G)A($QA
M=&5R86PB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G
M:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(G*2<@97-P97)A9&\B"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B17-P
M97)A=F$@=6UA('-I;7!L97,@<&%L879R82!O=2!U;2!T97)M;R!D92!P<F]C
M=7)A(&5N=')E(&%S<&%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#`Q"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T82!D92!%
M>'!I<F'GXV\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-@IM
M<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B17AP;V5N=&4B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5X=')A8W1I
M;F<@9G)O;2`E<RXN+B`B"FUS9W-T<B`B17AT<F%I;F1O(&1E("5S+BXN("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O<B!D;R!0<FEM96ER
M;R!0;&%N;R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B0V%R<F5G87(@8V]N9FEG
M=7)AY^-O(&1E(&EN<W1A;&'GXV\@<&]R($944"(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E
M9F5R96YC97,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<'5X87(@87,@
M<')E9F5RZFYC:6%S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$P
M,`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(D9A;&AA(&YA(&QI9V'GXV\@86\@<V5R=FED;W(@3$1!4"XB"@HC
M.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")&86QH82!N82!L:6=A
MY^-O(&%O('-E<G9I9&]R(%--0BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C`S
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E
M<UPB+B(*;7-G<W1R(")&86QH82!A;R!C;W!I87(@9&4@7"(E<UPB+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HV,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")&86QH82!A;R!C;W!I
M87(@<&%R82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z
M.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B1F%L:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!3
M05-,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV-#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")&86QH
M82!A;R!M;W9E<B!P87)A(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")"
M;VTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T
M<B`B26QH87,@1F%L:VQA;F0@*$UA;'9I;F%S*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B26QH87,@1F%R;V4B"@HC.B!L:6(O2&]R9&4O0TQ)
M+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%<G)O($9A
M=&%L.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W
M"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E=F5R
M96ER;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(D%P87)E;G1A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@
M(D%P87)E;G1A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B06QG=6YS
M($%G=6%C96ER;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")!
M;&=U;G,@3F5V]65S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#4*;7-G
M:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871R:7H@9&4@8V%M<&]S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R
M(")#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&5S(@IM<V=S='(@(D-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#8*;7-G:60@(D9I
M;&4@36%N86=E<B(*;7-G<W1R(")'97-TXV\@9&4@1FEC:&5I<F]S(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(").;VUE(&1O
M($%R<75I=F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDY-`IM<V=I9"`B
M1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96/GXV\@9&\@87)Q=6EV;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#@X"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R(")#87)R96=A;65N=&\@9&4@87)Q=6EV;R(*"B,Z(&QI8B](
M;W)D92]"<F]W<V5R+G!H<#HX-C,*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R(")#87)R96=A;65N=&]S(&1E(&9I8VAE:7)O
M<R!NXV\@<^-O('-U<&]R=&%D;W,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R;W,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FSB;F1I82(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S$*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B475A
M<G1O($-R97-C96YT92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B475A<G1O($-R97-C96YT92(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")&
M:7AA<B!RX6-I;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,30*;7-G:60@(D9L:7`B"FUS9W-T<B`B26YV97)T97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R
M"FUS9VED(")&;&]A="(*;7-G<W1R(")&;'5T=6%N=&4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM
M<V=S='(@(DYE=F]E:7)O(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$V,"!L:6(O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(D$@<&%S=&$@)7,@;N-O(&5X
M:7-T92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D-O<B!D;R!497AT
M;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*
M;7-G<W1R(")#;VUI9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E!A<F$@;F%V
M96=A9&]R97,@<75E(&[C;R!S=7!O<G1A;2!I;6%G96YS(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S
M='(@(E!R979I<^-O("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<Q"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A
M('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D1I87,@9&4@4')E=FESXV\@*&YO
M=&4M<V4@<75E(&%S('!R979I<_5E<R!I;F-L=65M('1A;G1O(&1I87,@8V]M
M;R!N;VET97,[("(*(G5M('9A;&]R(&1E;6%S:6%D;R!G<F%N9&4@<&]D92!R
M97-U;'1A<B!N=6T@8FQO8V\@;75I=&\@;&%R9V\I(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY.`IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(D5S<75E8V5U+7-E(&1A('!A;&%V<F$M<&%S<V4_(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1F]R;7,B
M"FUS9W-T<B`B36]D96QO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")$:71O<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@
M(E1I<&\@9&4@9&ET;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D1I=&]S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(D1I
M=&]S(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED
M(")&;W)U;7,B"FUS9W-T<B`B1O-R=6YS(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4F5E;G9I
M;W,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&;W5N9"!A<'!L:6-A=&EO;G,Z("5S(@IM<V=S='(@(D%P;&EC
M8>?U97,@*&WS9'5L;W,I(&5N8V]N=')A9&%S.B`E<R(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ-#4R"FUS9VED(")&;W5N9"!D:7)E8W1O<FEE<SHB"FUS
M9W-T<B`B4&%S=&%S(&5N8V]N=')A9&%S.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@
M(C:J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(DUO;&1U<F%S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1G)A;F-E(@IM<V=S='(@(E)E</IB;&EC82!&<F%N8V5S82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE
M=')O<&]L:71A;B(*;7-G<W1R(")&<F%NYV$L($UE=')O<&]L:71A;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D=U:6%N82!&<F%N8V5S82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O;&ENZ7-I82!&
M<F%N8V5S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M(@IM<V=S='(@(E1E<G)A<R!!=7-T<F%I<R!E($%N=.%R8W1I8V%S($9R86YC
M97-A<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T
M"FUS9VED(")&<F]M(@IM<V=S='(@(D1E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S0X"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.30*;7-G:60@
M(D9R;VT@=&AE("(*;7-G<W1R(")$92`B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G
M<W1R(")$97-C<FGGXV\@0V]M<&QE=&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#(@;&EB+T)L;V-K+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N
M(@IM<V=S='(@(DQU82!#:&5I82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,SD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VUE
M($-O;7!L971O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B
M1G5Z>GDB"FUS9W-T<B`B1&EF=7-A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@
M(E)E</IB;&EC82!'86)O;F5S82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L97)I82!D92!O;F1E
M(')E=&ER87(@82!I;6%G96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ
M(@IM<V=S='(@(D=A;&5R:6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(E)E
M</IB;&EC82!D82!'XFUB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B1V5R87(@0V]N9FEG=7)AY^-O("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C$P"FUS9VED(")'96YE
M<F%T960@0V]D92(*;7-G<W1R(")#\V1I9V\@1V5R861O(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C0W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T
M:6YG('-T871U<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(D=E<F%N9&\@
M;R!E<W1A9&\@9&\@;?-D=6QO("5S+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G
M<W1R(")'9?-R9VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")297#Z8FQI
M8V$@1F5D97)A;"!D82!!;&5M86YH82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,S<Q"FUS9VED(")'971O<'0@17)R;W(Z("(*;7-G<W1R(")%<G)O(&5M
M(&=E=&]P=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")297#Z8FQI8V$@9&\@
M1V%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R(").;VUE(%!R\W!R:6\B"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B27(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")'
M]F1E;"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O
M;V=L92!396%R8V@B"FUS9W-T<B`B4&5S<75I<V$@1V]O9VQE(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`IM<V=I9"`B1W)A
M>7-C86QE(@IM<V=S='(@(D[M=F5I<R!D92!C:6YZ96YT;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'
M<F5E8V4B"FUS9W-T<B`B1W+I8VEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<F5G
M;R`H25-/+3@X-3DM-RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)O
M;F5LXFYD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R86YA9&$B"@HC
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<P"FUS9VED(")'<F]U<"!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')AY^-O(&1E($=R=7!O<R(*"B,Z
M(&QI8B](;W)D92]'<F]U<"YP:'`Z-3@*;7-G:60@(D=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DYO;65S(&1E(&=R=7!O<R!NXV\@
M<&]D96T@97-T87(@=F%Z:6]S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,C`Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,C<W"FUS9VED(")'<F]U<"!P
M97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(&1E(&=R=7!O(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z,3<V(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C4P(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U
M<&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D86QU<&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*
M;7-G<W1R(")297#Z8FQI8V$@9&$@1W5A=&5M86QA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R
M;G-E>2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R-R!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(P-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S
M]65S(&1A<R!6:7-I=&%S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(X
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`V"FUS9VED(")'=65S="!P97)M
M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(&1A<R!6:7-I=&%S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Q-PIM<V=I9"`B1W5E<W1B;V]K
M(@IM<V=S='(@(DQI=G)O(&1E(%9I<VET87,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS
M9W-T<B`B1W5I;NDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B
M1W5I;NDM0FES<V%U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B4F5P^F)L
M:6-A($-O+6]P97)A=&EV82!D82!'=6EA;F$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B3R!(5$U,07)E82!R96-U<V$M
M<V4@8V]B87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!CZ6QU;&$@9&$@
M;&EN:&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M(")/($A434Q!<F5A(')E8W5S82US92!C;V)A<F1E;65N=&4@82!R96UO=F5R
M(&$@^FQT:6UA(&-O;'5N82!D82!T86)E;&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R(")/($A434Q!<F5A(')E8W5S82US92!C;V)A
M<F1E;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&QI;FAA(&1A('1A8F5L82XB
M"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71E;G1I8V'G
MXV\@2%104"!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*
M;7-G<W1R(")297#Z8FQI8V$@9&\@2&%I=&DB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,#(*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@
M(D%L9V]R:71M;R!D92!<(DAA<VA<(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DYE
M8FQI;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3$Y(&QI8B](;W)D92]&
M;W)M+G!H<#HR.3,Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B
M"FUS9W-T<B`B26QH87,@2&5A<F0@92!-8T1O;F%L9"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4
M+5-T;W)M(@IM<V=S='(@(E1E;7!O<F%L+50@1F]R=&4B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI
M(@IM<V=S='(@(DAE8G)E=2`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@
M(DAE:6=H="(*;7-G<W1R(")!;'1U<F$B"@HC.B!L:6(O2&]R9&4O2&5L<"YP
M:'`Z,3<Y(&QI8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G
M:60@(DAE;'`B"FUS9W-T<B`B06IU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D
M:71O<B(*;7-G<W1R(")!:G5D82!S;V)R92!O(&5D:71O<B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S<S"FUS9VED(")(96QP97(B"FUS9W-T<B`B06IU
M9&$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.34*;7-G:60@(B(*(DAE;'!E
M<B!A<'!L:6-A=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T
M:6]N<R!F;W(@=&AE($AO<F1E7&XB"B)F<F%M97=O<FL@86YD(&ET<R!A<'!L
M:6-A=&EO;G,N7&XB"B)&;W(@86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I
M;&4@4D5!1$U%(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)!<&QI
M8V'GXV\@875X:6QI87(@<&%R82!C<FEA<B!E(&UA;G1E<B!T<F%D=>?U97,@
M9&$@<&QA=&%F;W)M85QN(@HB2&]R9&4@92!D87,@<W5A<R!A<&QI8V'G]65S
M("AM\V1U;&]S*2Y<;B(*(E!A<F$@=6UA(&EN=')O9'7GXV\@;&5R(&\@9FEC
M:&5I<F\@4D5!1$U%(&YE<W1A('!A<W1A+B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V;I<FEO
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3<@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B07%U:2!E<W3A(&\@:6[M8VEO
M(&1O(&%R<75I=F\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B06QT82(*"B,Z(&QI
M8B](;W)D92](:7-T;W)Y+G!H<#HS,C$*;7-G:60@(DAI<W1O<GD@96YT<GD@
M;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B3F]M97,@9&%S(&5N
M=')A9&%S(&AI<W3S<FEA<R!NXV\@<&]D96T@97-T87(@=F%Z:6]S(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHT"FUS9VED(")(;U]M92(*;7-G<W1R(")#85]S
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM
M<V=S='(@(D5S=&%D;R!D82!#:61A9&4@9&\@5F%T:6-A;F\B"@HC.B!L:6(O
M2&]R9&4N<&AP.C$T,S4*;7-G:60@(DAO;64B"FUS9W-T<B`B0V%S82(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E
M<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@0V%S82(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM
M<V=S='(@(E1E;&5F;VYE(&1E($-A<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM
M<V=S='(@(E)E</IB;&EC82!D87,@2&]N9'5R87,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R(")(;VYG=65C;VYG=64B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,CD*;7-G:60@(DAO<F1E('1R86YS
M;&%T:6]N(&=E;F5R871O<B(*;7-G<W1R(")'97)A9&]R(&1E('1R861UY_5E
M<R!(;W)D92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#(P"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z($1A9&]S(%A-3"`E<R!I;G;A;&ED;W,@;F$@;65N<V%G96T@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;FAU;6$@;65N<V%G96T@
M8V]R<F5S<&]N9&4@86\@;V)J96-T;R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!.96YH=6T@;V)J96-T;R!D;R!T:7!O("5S(&5N
M8V]N=')A9&\@;F$@;65N<V%G96T@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$R,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@4F5M;^?C;R!D92`E<R!<(B5S7"(@=&5V92!S=6-E<W-O(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,34T"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4VEN8W)O;FEZ8>?C;R!D92`E
M<R!<(B5S7"(@=&5V92!S=6-E<W-O(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!/(&UO=&]R(&1E(&EN=&5G<F'GXV\@<F5Q=65R
M(&$@97AT96YSXV\@4$A0("=D;VUX;6PG(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HT.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@HB2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@8W)I87(@
M=6UA(&YO=F$@X7)V;W)E<R!834P@<&%R82!O(&]B:F5C=&\@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$R,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!)1"!-
M24U%('!A<F$@82!P87)T92!D92!T:7!O("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,34Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B`E
M<R!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3N-O
M(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B!P87)T:6QH87,Z("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!087)T:6QH82!<(B5S7"(@9&5S8V]N:&5C:61A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I
M9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(E1R8>=O($AO<FEZ;VYT86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R
M"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B16YC:&EM96YT
M;R!H;W)I>F]N=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R
M:7IO;G1A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D-O;6\@8VAE9V]U(&%Q=6D_
M("A0;W(@9F%V;W(@<F5P;W)T92UO(2DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1
M=6%N=&%S(&-O;'5N87,@<')E=&5N9&4@:G5N=&%R/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(X"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B475A;G1O<R!C86UP;W,@
M*&-O;'5N87,I(&5X:7-T96T_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1A<R!L
M:6YH87,@<')E=&5N9&4@:G5N=&%R/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@
M(DAU;6ED:71Y(@IM<V=S='(@(DAU;6ED861E(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-PIM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R
M(")(=6UI9&%D93H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS
M9VED(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1A<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M2'5N9V%R>2(*;7-G<W1R(")297#Z8FQI8V$@9&$@2'5N9W)I82(*"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!C<FEAY^-O(&1A(&-A
M:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,B"@HC.B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(E)E;6_GXV\@9&$@8V%I>&$@<&]S=&%L($E-
M05`@9F%L:&]U.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M-SD@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B0W)I8>?C;R!D92!Q=6]T82!D92!C86EX82!P;W-T86P@
M24U!4"!F86QH;W4Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,3<*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@25`B"@HC.B!L
M:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")%;F1E<F7G;R!)4"!I;F1I<W!O
M;NUV96PN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G
M:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M(@IM<V=S='(@(D5N9&5R9>=O($E0(&9O<F$@9&\@8FQO8V\@0TE$4B!P97)M
M:71I9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B5FEO
M;&'GXV\@9&4@8FQO<75E:6\@9&4@25`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E
M<G0@4F]W($)E9F]R92(*;7-G<W1R("))7VYS97)I<B!,:6YH82!!;G1E<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R(")297#Z8FQI8V$@9&$@27-LXFYD
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`B07!E;F%S(,UC;VYE<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-CD*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R
M("+-8V]N97,@8V]M(%1E>'1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").;VUE(&1A
M(&ED96YT:61A9&4Z(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C4X.0HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M(@IM<V=S='(@(E-E(&[C;R!F;W(@;6]S=')A9&\@8V]R<F5C=&%M96YT92P@
M)7,@<&%R82!O(&%B<FER(&YU;6$@;F]V82!J86YE;&$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0T-PIM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E
M92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@
M;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)392!NXV\@=FER('%U86QQ=65R(.UC
M;VYE(&%O('5S87(@;R!);G1E<FYE="!%>'!L;W)E<BP@<&]D92!P<F5C:7-A
M<B!D92`B"B)S96QE8V-I;VYA<B!E<W1A(&-A:7AA('!A<F$@9&5S;&EG87(@
M82!T<F%N<W!A<NIN8VEA+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ-3@*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G
M<W1R("(B"B)392!V:7(@97-T82!M96YS86=E;2!N;6%S(&[C;R!A(&EM86=E
M;2!P<F]P<FEA;65N=&4@9&ET82P@82!I;6%G96T@<75E("(*(G!R971E;F1E
M(&-A<G)E9V%R(&[C;R!P;V1E('-E<B!M;W-T<F%D82!P96QO('-E=2!N879E
M9V%D;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G
M<W1R(")0<F5V:7/C;R!D82!);6%G96TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@
M55),(@IM<V=S='(@(E523"!D82!I;6%G96TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@
M(DEM86=E(%523#HB"FUS9W-T<B`B55),(&1A(&EM86=E;3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("));6%G96T@
M9&4@9V%L97)I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y.B(*;7-G<W1R("));6%G96T@9&4@9V%L97)I83HB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<V,@IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@
M(D-A<G)E9V%M96YT;R!D82!I;6%G96TB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DEM86=E;G,B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHQ,`HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1A<BP@4&%S
M<V\@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M0V%M<&\@:6UP;W)T861O.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S,*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0V%M
M<&]S(&EM<&]R=&%D;W,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R("));E]S97)I<B!,:6YH82!$97!O:7,B"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0_-D:6=O(&1E(&%CY^-O(&EN
M=')O9'5Z:61O(&5S=.$@:6YC;W)R96-T;RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(").;VUE(&1E('5T:6QI>F%D
M;W(@;W4@<&%L879R82UP87-S92!E<G)A9&]S+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*(DYO;64@9&4@=71I;&EZ861O<B!O=2!E;F1E<F7G
M;R!A;'1E<FYA=&EV;R!E<G)A9&]S+B!#;VYT86-T92!O('-E=2`B"B)A9&UI
M;FES=')A9&]R(&1E('-I<W1E;6$@<&%R82!O8G1E<B!A:G5D82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B075M96YT87(@82!);F1E;G1A
MY^-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@S6YD
M:6$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-#$@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS
M9W-T<B`B571I;&EZ861O<F5S($EN9&EV:61U86ES(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O
M;F5S:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($EN9&]NZ7-I82(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O
M(@IM<V=S='(@(DEN9F]R;6'GXV\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C0V"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA
MY^-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.`IM<V=I
M9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B
M26YF;W)M8>?C;R!JX2!NXV\@97-TX2!D:7-P;V[M=F5L(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C4X,@HC+"!P:'`M9F]R;6%T"FUS9VED("));FET:6%L
M:7II;F<@;6]D=6QE("5S+BXN("(*;7-G<W1R("));FEC:6%L:7IA;F1O(&\@
M;?-D=6QO("5S+BXN("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU;6X@
M069T97(B"FUS9W-T<B`B26YS97)I<B!#7V]L=6YA($1E<&]I<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(DEN<V5R:7(@26UA
M9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(DEN<V5R:7(@5&%B
M96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN<V5R:7(@
M3&EG8>?C;R#@(%=E8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@7T-O;'5N82!!;G1E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B26YS:7)I<B!U;6$@;F]V82!C;VQU;F$@9&5P;VES
M(&1A(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS:7)I<B!U
M;6$@;F]V82!C;VQU;F$@86YT97,@9&$@8V]R<F5N=&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(DEN<VER:7(@=6UA(&YO=F$@;&EN:&$@9&5P;VES(&1A(&-O<G)E
M;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8P"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS:7)I<B!U;6$@;F]V82!L:6YH
M82!A;G1E<R!D82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS
M97)I<B!U;2!P87+A9W)A9F\@87#S<R!O(&[S(&-O<G)E;G1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B26YS97)I<B!U;2!P87+A9W)A9F\@86YT97,@9&\@
M;O,@8V]R<F5N=&4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I
M9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("));G-I<FER
M(&UO9&5L;R!A;'1E<FYA=&EV;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,S$*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H
M('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B
M"B));G1R;V1U>F$@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC
M;R!O;F1E('!O<W-A(')E8V5B97(@82!N;W9A("(*(G!A;&%V<F$M<&%S<V4Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B26YS
M:7)I<B!CZ6QU;&$@87#S<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R("));G-E<FER(&/I;'5L87,@86YT97,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS
M9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@8^EL
M=6QA(&1E<&]I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(DEN<V5R:7(@8V]L=6YA(&%N=&5S(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`B26YS97)I<B!M96YS86=E;G,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B26YS97)I<B!P87+A
M9W)A9F\@86YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@
M8F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@<&%RX6=R869O(&%N=&5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));G-E<FER(&QI
M;FAA(&1E<&]I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM
M<V=S='(@(DEN<V5R:7(@;&EN:&$@86YT97,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(R"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(DEN=')O9'5Z
M82!A(')E<W!O<W1A(&5X:6=I9&$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R
M86[G83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN
M<V5R:7(O36]D:69I8V%R($EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@
M3&EN:R(*;7-G<W1R("));G-E<FER+TUO9&EF:6-A<B!,:6=AY^-O(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B0W+I9&ET;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I
M87(@<&%R82!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RXB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET+B(*;7-G<W1R(")#<NED:71O(&EN<W5F:6-I96YT92XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G
M<W1R("));G1E:7)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S,*;7-G
M:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("),:7-T82!D92!I;G1E:7)O<R(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED
M("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")5
M1$@@*%5S97(@1&%T82!(96%D97(I(&EN=N%L:61O+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]Z:7`N<&AP.C$W,"!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HR,#$*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS
M9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(D1A9&]S(%I)4"!I;G;A
M;&ED;W,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("))
M;G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")!<&QI8V'GXV\@:6YVX6QI
M9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DE$(&1E(&QO=&4@
M*%PB8F%T8VA<(BD@:6YVX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P.#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R,S,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R.3@*;7-G:60@(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(D]S(&1A9&]S('-U8FUE
M=&ED;W,@<^-O(&EN=N%L:61O<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+B(*;7-G<W1R(")%;F1E<F7G;R!D92!D97-T:6YO(&EN=N%L:61O
M+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C@Q(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T
M<B`B1F]R;6%T;R!D;R!A<G%U:79O(&EN=N%L:61O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-`IM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B0VAA=F4@9&$@;&EC96[G82!I;G;A;&ED82XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34X"FUS9VED("));G9A
M;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("),;V-A;&EZ8>?C;R!I
M;G;A;&ED82!E<W!E8VEF:6-A9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM
M<V=S='(@(FUS9U]T>7!E(&EN=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+B(*;7-G<W1R(")A<&E?:60@:6YVX6QI9&\@;W4@96T@9F%L
M=&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*
M;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R
M(")087+B;65T<F]S(&EN=N%L:61O<R!O=2!E;2!F86QT82XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-#,*;7-G:60@(DEN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(E!E<FUI<W/C;R!P87)E;G1A;"!I;G;A
M;&ED82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38P"FUS
M9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DE$(&1E('!A<F-E
M:7)O(&EN=N%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C(*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")#
M\V1I9V\@9&4@<')O9'5T;R!I;G;A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O
M;"XB"FUS9W-T<B`B4')O=&]C;VQO(&EN=N%L:61O+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D1E<W1I;F%T
MX7)I;R!I;G;A;&ED;SH@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,#0S(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(R,`IM<V=I9"`B26YV86QI
M9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3V)J96-T;R!D92!P87)T:6QH82!I
M;G;A;&ED;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")%
M;F1E<F7G;R!D82!O<FEG96T@:6YVX6QI9&\N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R(")$861O<R!U;FEC;V1E(&EN=N%L:61O<RXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(U"FUS9VED("));G9E;G1O
M<GDB"FUS9W-T<B`B26YV96YTX7)I;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B(*;7-G<W1R(")297#Z8FQI8V$@27-LXFUI8V$@9&\@
M27+C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R(")297#Z8FQI8V$@9&\@27)A
M<75E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(E)E</IB;&EC82!D82!)
M<FQA;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B
M27-L92!O9B!-86XB"FUS9W-T<B`B26QH82!D92!-86XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T
M960@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&]R86ES+50@27-O;&%D;W,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DES<F%E;"(*;7-G<W1R(")%<W1A9&\@9&4@27-R865L(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*
M;7-G<W1R(")%;6ES<V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B273A;&EC
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B4F5P^F)L:6-A($ET86QI86YA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<T(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G
M<W1R(")*86YE:7)O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87#C;R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]NZG,@*$E33RTR,#(R+4I0*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R(")*97)S97DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")296EN
M;R!(87-H96UI=&$@9&$@2F]R9.)N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@P(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QH;R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-SD@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM
M<V=S='(@(DIU;FAO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*
M=7-T:69I8V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S
M='(@(D-E;G1R87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S
M='(@(DIU<W1I9FEC87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM
M<V=S='(@(DIU<W1I9FEC87(@X"!%<W%U97)D82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*
M=7-T:69Y(%)I9VAT(@IM<V=S='(@(DIU<W1I9FEC87(@X"!$:7)E:71A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(E)E</IB;&EC82!D;R!#87IA
M<75I<W3C;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#8*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(E!R97-E<G9A
M<B!O(&]R:6=I;F%L/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B4F5P^F)L
M:6-A(&1O(%%UZ6YI82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(D\@<V5R=FED;W(@2V5R8F5R;W,@<F5J96ET;W4@82!A
M=71E;G1I8V'GXV\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS
M9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(").;W9A=&]S(&YO(%PB2V5R
M;F5L7"(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@
M(DME>2!#<F5A=&EO;B(*;7-G<W1R(")#<FEAY^-O(&1A($-H879E(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`S"FUS9VED(")+97D@1FEN9V5R
M<')I;G0B"FUS9W-T<B`B26UP<F5S<^-O(&1I9VET86P@9&$@8VAA=F4B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#$*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B0V]M<')I;65N=&\@9&$@8VAA=F4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@
M(E1I<&\@9&$@0VAA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E5T:6QI>F'GXV\@9&$@
M0VAA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,CD*;7-G:60@
M(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B02!C:&%V92!JX2!E>&ES=&4@;F\@<V5R=FED;W(@9&4@8VAA
M=F5S('#Z8FQI8V%S+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM
M<V=I9"`B2VED<R(*;7-G<W1R(")-:?ID;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I
M(@IM<V=S='(@(E%U:7)I8F%T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4F5P^F)L:6-A(%!O
M<'5L87(@1&5M;V-RX71I8V$@9&$@0V]R96EA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($-O<F5I82(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B0V]R96%N;R`H155#+4M2*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(DMU=V%I="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R
M(")297#Z8FQI8V$@475I<F=U:7IE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E]$:7-P;W-IY^-O
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW.2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C4W"FUS9VED("),86YG=6%G92(*;7-G<W1R("))9&EO;6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM
M<V=S='(@(E)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A($QA;R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DQA<W0@2&%L9B(*;7-G
M<W1R(")1=6%R=&\@1&5C<F5S8V5N=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#@@;&EB+T)L;V-K+VUO;VXN<&AP.CDP"FUS9VED("),87-T(%%U87)T
M97(B"FUS9W-T<B`B475A<G1O($1E8W)E<V-E;G1E(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B
MVFQT:6UA($%C='5A;&EZ8>?C;SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-C@V"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S
M='(@(MIL=&EM82!E;G1R861A.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HV.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<R(*;7-G<W1R("+:;'1I;6$@96YT<F%D83H@)7,@9&4@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z-C@S"FUS9VED("),87-T(&QO9VEN.B!.979E
M<B(*;7-G<W1R("+:;'1I;6$@96YT<F%D83H@3G5N8V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@3&5T\VYI82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DQE:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D1I<W!O<VGGXV\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED
M("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(D1E:7AA<B!V
M87II;R!P87)A(&9I8V%R('-E;2!B;W)D82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*
M;7-G<W1R("),[6)A;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B17-Q
M=65R9&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q.`IM<V=I9"`B3&5F
M="!H96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO(&1A(&5S<75E<F1A(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,30*;7-G:60@(DQE9G0@=F%L=65S(@IM
M<V=S='(@(E9A;&]R97,@X"!E<W%U97)D82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*
M;7-G<W1R("),97-O=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB
MZ7)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R
M(")'<F%N9&4@2F%M86AI<FEY82!3;V-I86QI<W1A(%!O<'5L87(@P7)A8F4@
M9&$@3.UB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&ES
M=&5N<W1A:6YE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B0VAU=F$@
M7")-;VQH82U4;VQO<UPB(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B0VAU
M=FES8V]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B0VAU=FES
M8V]S($UA=&EN86ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")#
M:'5V:7-C;W,@5F5S<&5R=&EN;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B
M"FUS9W-T<B`B4&5Q=65N;R!!9W5A8V5I<F\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W
M:71H(%1H=6YD97(B"FUS9W-T<B`B0VAU=FES8V\@8V]M(%1R;W9O861A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B475E9&$@9&4@3F5V92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),
M:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(").979E(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R(")<(DQI
M;65R:6-K7"(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q-0IM<V=I9"`B
M3&EN:R(*;7-G<W1R("),:6=AY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED("),:6YK('!O
M:6YT<R!T;SHB"FUS9W-T<B`B3&EG8>?C;R!A<&]N=&$@<&%R83HB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-@IM<V=I9"`B3&EN:R!T:&4@96UA:6P@
M861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*
M;7-G<W1R("(B"B),:6=A<B!O(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\@X"!PX6=I;F$@9&4@8V]M<&]S:>?C;R!A;R!M;W-T<F%R(@H*(SH@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED
M("),:6YK<R(*;7-G<W1R("),:6=AY_5E<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(D)O;&EN
M:&\@;&EN=7CJ<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(DQI<W1A("T@;R!U=&EL:7IA9&]R('!O9&4@=F5R(&$@<&%S=&$B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED("),:7-T($1A=&%B
M87-E<R(*;7-G<W1R("),:7-T87(@0F%S97,@9&4@1&%D;W,B"@HC.B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC
M<R(*;7-G<W1R(")-;W-T<F%R(%3S<&EC;W,@9&4@06IU9&$B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R
M("),:7-T87(@5&%B96QA<R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W1A9V5M
M+4%R<75I=F\B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T86=E;2U!:G5D82(*"B,Z
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)
M9"(*;7-G<W1R("))1"!D82!,:7-T82(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T
M86=E;2U$;VYO(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS
M"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES=&%G96TM4W5B;6ES<_5E
M<R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B
M3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&%G96TM4W5B<V-R:71A<R(*
M"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES
M="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T86=E;2U.XV\@<W5B<V-R:71A
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I
M9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B02!L:7-T
M86=E;2!D92!U=&EL:7IA9&]R97,@97-TX2!D97-A8W1I=F%D82XB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS
M9W-T<B`B3&ET97)A='5R83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R
M(")297#Z8FQI8V$@9&$@3&ET=>)N:6$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3,S.`IM<V=I9"`B3&]A9&EN9R!L:6)R87)I97,N+BXB"FUS9W-T<B`B
M0V%R<F5G86YD;R!B:6)L:6]T96-A<RXN+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.CDR"FUS9VED("),;V%D:6YG+BXN(@IM<V=S
M='(@(D-A<G)E9V%N9&\N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3DY"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B5&5M<&\@
M;&]C86PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),
M;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B3&]C86QI>F'GXV\@92!&=7-O($AO
M<N%R:6\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(DQO8V%L:7IAY^-O(@H*(SH@;&]G:6XN<&AP.C$V,B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,38T('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX-@IM<V=I9"`B3&]G(&EN
M(@IM<V=S='(@(D5N=')A<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B4V%I<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM
M<V=S='(@(E1A<F5F87,@9&4@16YT<F%D82(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY,S$*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM
M<V=S='(@(B(*(D$@875T96YT:6-AY^-O(&9A;&AO=2!P;W(@;R!.;VUE(&1E
M(%5T:6QI>F%D;W(@;W4@82!086QA=G)A+5!A<W-E(&5S=&%R96T@(@HB:6YC
M;W)R96-T;W,N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDR-PIM<V=I9"`B
M3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")!(&%U=&5N=&EC8>?C;R!F86QH;W4N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C<*;7-G:60@(DQO;F<@=&5X
M="(*;7-G<W1R(")497AT;R!L;VYG;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")!;6]R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*
M;7-G<W1R(")"86EX;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE
M='1E<G,B"FUS9W-T<B`B3&5T<F%S(&=R96=A<R!M:6[Z<V-U;&%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),971R
M87,@;&%T:6YA<R!M:6[Z<V-U;&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R(").^FUE<F]S(')O;6%N;W,@;6EN^G-C
M=6QO<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U<F=O
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,R!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DU/5$0B"FUS9W-T
M<B`B34]41"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R(")/(&%N97AO($U3+51.148@;N-O(&-O;G1I;FAA(&1A9&]S
M+B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C
M86\B"FUS9W-T<B`B36%C874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86-E9/-N:6$L
M($%N=&EG82!297#Z8FQI8V$@2G5G;W-L879A(&1A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A
M9V%S8V%R(@IM<V=S='(@(DUA9&%GX7-C87(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEA(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S
M='(@(D-O<G)E:6\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<W
M"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@
M0V]R<F5I;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,`IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R
M(")&87IE<B!L:5]G8>?C;RXN+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,S4W"FUS9VED(")-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A
M;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N(@IM<V=S='(@(B(*(D%S
M<V5G=7)E+7-E(&1E('%U92!T96T@;R!014%2(&EN<W1A;&%D;R!E(&YO(&-A
M;6EN:&\@9&4@:6YC;'5S]65S("AI;F-L=61E("(*(G!A=&@I+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV-S@@<&\O=')A;G-L871I;VXN<&AP.C$P-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B36%K:6YG(&1I<F5C=&]R>2`E<R(*;7-G
M<W1R(")#<FEA;F1O(&$@<&%S=&$@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G
M<W1R(")-86QA=6DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;.%S
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=F%S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED
M("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)':7)A(&$@;&ES
M=&$@9&4@8V%T96=O<FEA<R!Q=64@<&]D92!A=')I8G5I<B!A;W,@:71E;G,L
M(&)E;2!C;VUO(&%S(&-O<F5S("(*(G%U92!L:&5S(&5S=.-O(&%S<V]C:6%D
M87,N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,SD*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87!A($UA<#(T(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-PHC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-`IM<V=I9"`B36%P
M475E<W0@;6%P(@IM<V=S='(@(DUA<&$@36%P475E<W0B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<V(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B
M36%RYV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B36%R9V5M(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B36%R8V%R(&-O
M;6\@3&ED82].XV\@;&ED82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N
M($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B36%R8V%R(&1E(&]U=')A
M<R!F;W)M87,@*&4N9RXL($EM<&]R=&%N=&4O4&]R(')E<W!O;F1E<BDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B26QH87,@36%R<VAA
M;&PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6-A(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,3$*;7-G:60@(DUA=&-H
M:6YG(&9I96QD<R(*;7-G<W1R(")#86UP;W,@<75E(&-O<G)E<W!O;F1E;2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:73B;FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<NUC:6\B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W
M960@8W)E9&ET+B(*;7-G<W1R(")-X7AI;6\@8W+I9&ET;R!P97)M:71I9&\N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")-X7AI
M;6\@;OIM97)O(&1E('!A<G1E<R!N=6UA(&UE;G-A9V5M(&5X8V5D:61O+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>%X:6UA(&YA
M<R#Z;'1I;6%S(#(T(&AO<F%S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,Z("(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N
M9W1H(@IM<V=S='(@(D-O;7!R:6UE;G1O(&WA>&EM;R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S@@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%I
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T
M<B`B365D:6-I;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$Y"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE;6)R;W,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")-96YU(&UO9&4Z(@IM
M<V=S='(@(DUO9&\@9&\@;65N=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL
M<R(*;7-G<W1R(")5;FER(&/I;'5L87,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@86QL("5S+G!O
M(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN("(*;7-G<W1R("));G1E9W)A
M;F1O('1O9&]S(&]S(&9I8VAE:7)O<R`E<RYP;R!C;VT@;R!C;VUPZFYD:6\N
M+BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,X"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE<F=I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R("));G1E9W)A
M;F1O(&$@;&]C86QI>F'GXV\@)7,N+BX@(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG('1H92!03R!F
M:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B26YT
M96=R86YD;R!O(&%R<75I=F\@4$\@9&4@)7,@8V]M(&\@8V]M<.IN9&EO+BXN
M("(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN(@IM
M<V=S='(@(DEN=&5G<F%N9&\@82!T<F%D=>?C;R!D;R!M\V1U;&\@)7,N+BXB
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,S`*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B365N<V%G96TB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*
M(DUE;G-A9V5N(%9E<FEF:6-A9&$@8V]M(%-U8V5S<V\L(&UA<R!O(&-E<G1I
M9FEC861O(&1O('-U8G-C<FET;W(@;N-O('#T9&4@(@HB<V5R('9E<FEF:6-A
M9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*
M;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365N<V%G96T@97AP
M:7)O=2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G
M<W1R(")4:7!O(&1E(&UE;G-A9V5M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(DUE=&5O<F]L;V=I
M82!-151!4B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;V-O($U%5$%2
M(&EN9&ES<&]N[79E;"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM
M<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B(@HB0FQO8V\@345405(@:6YD:7-P;V[M=F5L+B!/<R!P;W)M96YO<F5S
M(&9O<F%M(')E9VES=&%D;W,@<&%R82!O("(*(F%D;6EN:7-T<F%D;W(N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,@IM<V=I9"`B365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")!($UE=&%R1$(@;N-O
M(&5S=.$@8V]N96-T861A+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS
M9VED(")-971H;V0B"FUS9W-T<B`B3>ET;V1O(@H*(SH@;&EB+TAO<F1E+U)0
M0R]X;6QR<&,N<&AP.C@Q(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN
M960B"FUS9W-T<B`B3R!MZ71O9&\@7"(E<UPB(&[C;R!E<W3A(&1E9FEN:61O
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-Z71R:6-O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B3>EX:6-O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EC<F]N
MZ7-I82P@17-T861O<R!&961E<F%D;W,@9&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L
M92(*;7-G<W1R(")#96YT<F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")4:7!O($U)
M344B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WM;FEM
M82!N87,@^FQT:6UA<R`R-"!H;W)A<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M(")496UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@-B!H;W)A<R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3<*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R(")%<W!E;&AO(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUI<V-E
M;.)N96$B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"FUS9VED(")-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!A
M8V]T92!(5%107U)E<75E<W0@9&\@4$5!4B!E;2!F86QT82XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3$T"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB
M0V]N9FEG=7)AY^-O(&5M(&9A;'1A+B!497+A(&1E(&$@9V5R87(@86=O<F$@
M<V4@<75I<V5R('5S87(@97-T82!A<&QI8V'GXV\N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S
M<V%G92!)1"XB"FUS9W-T<B`B240@9&$@;65N<V%G96T@96T@9F%L=&$N(@H*
M(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I
M9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T
M<B`B4&%C;W1E($UA:6P@9&\@4$5!4B!E;2!F86QT82XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S
M97-S:6]N($E$+B(*;7-G<W1R("))1"!D82!S97-SXV\@96T@9F%L=&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM
M<V=I9"`B36\B"FUS9W-T<B`B,JHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(D-O<G)E:6\@
M3?-V96PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D97)A9&\B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")$871A
M(&1E($UO9&EF:6-AY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")-;V1I9GD@55),(@IM
M<V=S='(@(DUO9&EF:6-A<B!54DPB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C4W"FUS9VED(")-;V1U;&4B"FUS9W-T<B`B3?-D=6QO(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T
M<B`B3?-D=6QO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G
M<W1R(")297#Z8FQI8V$@9&$@36]L9&]V82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM
M<V=S='(@(E!R:6YC:7!A9&\@9&\@3?-N86-O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI
M82(*;7-G<W1R(")-;VYG\VQI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-3DS"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-ZG,@92!A;F\B
M"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT
M:&QY(@IM<V=S='(@(DUE;G-A;&UE;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T
M(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM
M<V=S='(@(D9A<V4@9&$@3'5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(E)E:6YO(&1E($UA<G)O8V]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R
M(")3;V)R971U9&\@3&EM<&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R
M(")3;V)R971U9&\@16YE=F]A9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S
M='(@(E-O8G)E='5D;R!3;VQA<F5N9V\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HT,C@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")$97-C
M97(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S(*;7-G:60@
M(DUO=F4@3&5F="(*;7-G<W1R(")-;W9E<B!P87)A(&$@17-Q=65R9&$B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S8*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`B36]V97(@<&%R82!A($1I<F5I=&$B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,C0*;7-G:60@(DUO=F4@57`B"FUS
M9W-T<B`B4W5B:7(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#DV"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1&5S8V5R(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-2!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"FUS9VED(")-;W9E
M('5P(@IM<V=S='(@(E-U8FER(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S
M='(@(E)E</IB;&EC82!D92!-;^=A;6)I<75E(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q.#4*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<R(*;7-G<W1R("),:7-T87,@9&4@9&5S96YR;VQA<B!M=6QT:2UN[79E;"(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0S"FUS9VED(")-=6QT:7!L92!S
M96QE8W1I;VXB"FUS9W-T<B`B4V5L96/GXV\@;?IL=&EP;&$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,Q(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,S@*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B02!-:6YH82!#
M;VYT82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@
M(DUY(%!O<G1A;"(*;7-G<W1R(")/($UE=2!0;W)T86PB"@HC.B!S97)V:6-E
M<R]P;W)T86PO961I="YP:'`Z,3(T"FUS9VED(")->2!0;W)T86P@3&%Y;W5T
M(@IM<V=S='(@(D1I<W!O<VGGXV\@9&\@4&]R=&%L(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N
M;6%R(@IM<V=S='(@(E5N:>-O(&1E($UY86YM87(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-PIM<V=I9"`B3D\L
M($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(D[C;RP@;N-O(&-O;F-O<F1O(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").86UI8FEA(@IM<V=S='(@(E)E</IB;&EC82!D82!.86WM8FEA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB
M"FUS9W-T<B`B3F5P86PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(E)E:6YO(&1O<R!08>US97,@0F%I>&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S
M($%N=&EL;&5S(@IM<V=S='(@(D%N=&EL:&%S($AO;&%N9&5S87,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B55),(&1E($)A<V4@3F5T<V-A<&4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E(%)E=F]G8>?C;R!#
M02!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U
M"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(E523"!C
M;VT@82!P;VSM=&EC82!D92!#02!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R(")54DP@9&4@4F5N;W9AY^-O($YE='-C87!E(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(E523"!D92!2979O9V'GXV\@3F5T<V-A
M<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYO;64@9&\@<V5R
M=FED;W(@4U-,($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B
M"FUS9W-T<B`B0V]M96YTX7)I;R!D92!C97)T:69I8V%D;R!.971S8V%P92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E1I<&\@9&4@8V5R=&EF
M:6-A9&\@3F5T<V-A<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C,Y"FUS9VED(").971W;W)K(@IM<V=S='(@(E)E9&4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,30@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R
M-PHC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(").979E<B(*
M;7-G<W1R(").=6YC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R
M(").;W9A($-A;&5D\VYI82(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C(W"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B
M3F]V82!#871E9V]R:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-SD*;7-G
M:60@(DYE=R!-;V]N(@IM<V=S='(@(DQU82!.;W9A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE
M("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]V;R!.;VUE(&1E(%5T:6QI>F%D;W(@
M*&]P8VEO;F%L*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F]V
M82!:96SB;F1I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T
M<B`B3F]V82!J86YE;&$@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(V,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W3M
M8VEA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.34*;7-G:60@
M(DYE=W-G<F]U<',B"FUS9W-T<B`B1W)U<&]S(&1E($YO=.UC:6%S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z-#8*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,S<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,S(*;7-G:60@(DYE>'0B
M"FUS9W-T<B`B4'+S>&EM82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM
M<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(")0<O-X:6UA<R`T($9A<V5S
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HS-S0*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")0
M<O-X:6UA<R!O<.?U97,B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P
M,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4'+S>&EM83XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M8V%R86=U82(*;7-G<W1R(")297#Z8FQI8V$@9&$@3FEC87+A9W5A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<B(*;7-G<W1R(")297#Z8FQI8V$@9&\@3NUG97(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R:6$B"FUS9W-T<B`B4F5P^F)L:6-A($9E9&5R86P@9&$@3FEG
M97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C@*;7-G
M:60@(DYI9VAT(@IM<V=S='(@(DYO:71E(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S
M='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#@U"FUS9VED(").;R(*;7-G<W1R(").XV\B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS9VED(").;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*
M;7-G<W1R("(B"B).XV\@:.$@9&%D;W,@9&4@8V]N9FEG=7)AY^-O(&1I<W!O
M;NUV96ES(&5M(')E;&'GXV\@86]S('%U86ES(&UO<W1R87(@(@HB9&EF97)E
M;N=A<RXB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").
M;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*
M;7-G<W1R(").XV\@:.$@;F5N:'5M82!E<W1R873I9VEA(&1I<W!O;NUV96P@
M<&%R82!R96%L:7IA<B!I;6%G96YS($E33RXB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA
M=&4N(@IM<V=S='(@(D[C;R!HX2!M;V1E;&\@9&4@;&]T92!<(F)A=&-H7"(N
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-SD@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z,C,P"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C(U,@IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U
M97-T960@<&]S:71I;VXB"FUS9W-T<B`B3N-O(&5X:7-T92!B;&]C;R!N82!P
M;W-IY^-O(&EN9&EC861A(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z
M-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R;F5C:61O('5M
M(&YO;64@9&4@8V%L96YDX7)I;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG
M92XB"FUS9W-T<B`B4V5M(&UO9&EF:6-AY_5E<RXB"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$T,`IM<V=I9"`B3F\@8VAI;&0@<&5R;6ES<VEO;G,@
M87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN(@IM<V=S='(@(D[C
M;R!S92!P;V1E(&%D:6-I;VYA<B!P97)M:7-S]65S(&1E(&9I;&AO<R!A8F%I
M>&\@9&5S=&4@;NUV96PN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8Q"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P
M97)M:7-S:6]N+B(*;7-G<W1R(").XV\@<V4@<&]D92!A9&EC:6]N87(@9FEL
M:&]S(&$@97-T82!P97)M:7-SXV\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$S-S<*;7-G:60@(DYO(&-O;6UA;F0@<W!E8VEF:65D+B(*;7-G<W1R(").
M96YH=6T@8V]M86YD;R!E<W!E8VEF:6-A9&\N(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-C<@;&EB+TAO<F1E+G!H<#HT-S<@;&EB+TAO<F1E+U5T:6PN<&AP.C<W
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(D[C;R!F;VD@97-P
M96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R82`E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S0Q"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS
M9W-T<B`B(@HB3N-O(&9O:2!E<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O(&1E
M(&-O;F9I9W5R8>?C;R!P87)A(%9&4R!B87-E861O(&5M($944"XB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z-3DQ"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@HB
M3N-O(&9O:2!E<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R
M8>?C;R!N96-E<W/A<FEA('!A<F$@;R!61E,@(@HB8F%S96%D;R!E;2!344PN
M(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S`T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R("(B"B).XV\@9F]I(&5S<&5C:69I8V%D82!A(&EN9F]R
M;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S<^%R:6$@<&%R82!O(%9&4R`B
M"B)B87-E861O(&5M(%-13"U&:6QE+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS
M9W-T<B`B0W+I9&ET;R!E<V=O=&]U+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+B(*;7-G<W1R(").96YH=6T@9&5S=&EN873A<FEO(&9O:2!F;W)N96-I
M9&\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F\@96YT<GD@=VET:"!T:&4@:60@7"(E<UPB(&5X:7-T<R!I
M;B!T:&4@;W)I9VEN86P@:&5L<"!F:6QE+B(*;7-G<W1R("(B"B).XV\@97AI
M<W1E('%U86QQ=65R(&5N=')A9&$@8V]M(&\@:60@7"(E<UPB(&YO(&%R<75I
M=F\@9&4@86IU9&$@;W)I9VEN86PN(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N
M<&AP.C@X,0IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(").XV\@
M<V4@8V%R<F5G;W4@;F%D82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#$S
M('!O+W1R86YS;&%T:6]N+G!H<#HU,C(*;7-G:60@(DYO(&QO8V%L92!S<&5C
M:69I960N(@IM<V=S='(@(DYE;FAU;6$@;&]C86QI>F'GXV\@97-P96-I9FEC
M861A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(D9A;'1A
M(&EN9&EC87(@=6UA(&QO8V%L:7IAY^-O+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-38*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D
M+B(*;7-G<W1R(")!(&QO8V%L:7IAY^-O(&[C;R!F;VD@97-P96-I9FEC861A
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G
M:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYE;FAU;6$@;65N
M<V%G96T@9F]I(&9O<FYE8VED82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS
M9W-T<B`B3F5N:'5M(&YO;64@97-P96-I9FEC861O+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S
M<&5C:69I960N(@IM<V=S='(@(DYE;FAU;2!N^FUE<F\@97-P96-I9FEC861O
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E-E;2!D:71O<R!O9F5N<VEV;W,B
M"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U
M=&5N=&EC8>?C;R!(5%10+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP
M.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V
M<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!)34%0+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D[C
M;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC
M8>?C;R!+97)B97)O<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY
M-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M
M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!,1$%0+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX
M-`HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U
M=&5N=&EC8>?C;R!,;V=I;BXB"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N
M<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!F;W)N96-I9&$@
M<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O(%!!4U-71"XB"@HC
M.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
MXV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I
M8V'GXV\@4TU"+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X
M-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3N-O(&9O:2!I
M;F1I8V%D;R!C86UI;FAO('!A<F$@;R!B:6[A<FEO($]P96Y34TPN($\@8FEN
MX7)I;R!/<&5N4U-,(.D@(@HB;F5C97-SX7)I;R!P87)A('1R86)A;&AA<B!C
M;VT@9&%D;W,@4$M#4R`Q,BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S
M='(@(D[C;R!HX2!S=6)S8W)IY_5E<R!P96YD96YT97,N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I
M9"`B3F\@<G5L97,B"FUS9W-T<B`B4V5M('1R8>=O<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@
M(DYO('-I9&5S(@IM<V=S='(@(E-E;2!L861O<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,C4*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3N-O(&CA('!A
M<W1A('1E;7!O<N%R:6$@9&ES<&]N[79E;"!P87)A(%PB8V%C:&5<(BXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"FUS9VED(").
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3N-O
M(&9O<F%M(&5N=FEA9&]S(&\@;F]M92!D;R!U=&EL:7IA9&]R(&]U(&$@<&%L
M879R82UP87-S92XB"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P
M"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(").
MXV\@9F]R86T@<F5T;W)N861O<R!D861O<R!E;2!834P@=N%L:61O<R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.3,@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDP,PHC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3$T(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY,S$*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R
M(")396T@=F%L;W)E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*
M;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B).
MXV\@9F]I(&5N8V]N=')A9&$@=F5R<^-O(&YA(&-O;F9I9W5R8>?C;R!O<FEG
M:6YA;"X@4F5G96YE<F%R(&-O;F9I9W5R8>?C;RXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO
M=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(").XV\@9F]I(&5N8V]N=')A9&$@=F5R<^-O(&YA('-U82!C;VYF
M:6=U<F'GXV\N(%)E9V5N97)A<B!C;VYF:6=U<F'GXV\N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$V('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,@IM<V=I9"`B3F]N92(*;7-G<W1R(").96YH
M=6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(").96YH
M=6T@*'5S87(@:6UP;.UC:71O*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(").\W)D
M:6-O("A)4T\M.#@U.2TQ,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(DEL:&$@9&4@3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FZ7)I;R!.;W)T92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($UA<FEA
M;F%S(&1O($YO<G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B4F5I;F\@
M9&$@3F]R=65G82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P
M"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B3G5N8V$@1&5P;VES(&1E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"
M969O<F4B"FUS9W-T<B`B3G5N8V$@06YT97,@9&4B"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C,S,0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(D[C
M;R#I('5M(&1I<F5C=/-R:6\B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z
M-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX
M,PHC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.CDT"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3N-O(&EM
M<&QE;65N=&%D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(E!O<B!A=')I
M8G5I<B(*"B,Z(&QI8B]61E,N<&AP.C$W-2!L:6(O5D93+G!H<#HQ.3,@;&EB
M+U9&4RYP:'`Z,C$P(&QI8B]61E,N<&AP.C(R-@HC.B!L:6(O5D93+G!H<#HR
M-#(@;&EB+U9&4RYP:'`Z,C4W(&QI8B]61E,N<&AP.C(W-"!L:6(O5D93+G!H
M<#HS,#<*(SH@;&EB+U9&4RYP:'`Z,S8W(&QI8B]61E,N<&AP.C0T-B!L:6(O
M5D93+G!H<#HU,34@;&EB+U9&4RYP:'`Z-3,R"B,Z(&QI8B](;W)D92]397-S
M:6]N2&%N9&QE<BYP:'`Z,30S(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,34X"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<S(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&QI8B](;W)D92]3
M97-S:6]N2&%N9&QE<BYP:'`Z,C,T"FUS9VED(").;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R(").XV\@<W5P;W)T861O+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M-C0*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&%S(@H*(SH@<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RXB"FUS9W-T<B`B3F%D82!P87)A(&YA=F5G87(L('9O;'1E
M('!A<F$@='+A<RXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER
M;5]T;W`N:6YC.C$P"FUS9VED(").;W1I8V4B"FUS9W-T<B`B3F]T82(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E
M<B(*;7-G<W1R(").;W9E;6)R;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`B3OIM97)O(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,C<*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S
M(@IM<V=S='(@(D[Z;65R;R!D92!C87)A8W1E<F5S(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM
M<V=S='(@(D[Z;65R;R!D92!C;VQU;F%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C,@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D[Z
M;65R;R!D92!L:6YH87,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"B).82!L
M:7-T82!D92!D:7-T<FEB=6GGXV\@:.$@;OIM97)O<R!Q=64@;N-O(&9O<F%M
M(&5S<&5C:69I8V%D;W,@<&%R82`B"B)A8W1U86QI>F'GXV\N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T('!O+W1R86YS
M;&%T:6]N+G!H<#HQ-#@*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-#@*;7-G
M:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@Q,0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5C
M=&\B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B
M3V)J96-T($-R96%T;W(B"FUS9W-T<B`B0W)I861O<B!D;R!/8FIE8W1O(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,W(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,C$U"FUS9VED(")/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<R(*
M;7-G<W1R(")097)M:7-S]65S(&1O(&-R:6%D;W(@9&\@;V)J96-T;R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R
M(")/8W1A;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS
M9VED(")/8W1O8F5R(@IM<V=S='(@(D]U='5B<F\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(D9I;'1R;R!D92!M871E<FEA;"!O9F5N<VEV;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,#$*;7-G:60@(D]F9FEC92(*;7-G<W1R(")'86)I
M;F5T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")3=6QT86YA=&\@9&\@3VWC
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED
M(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*
M;7-G<W1R(")3\R!O<R!S97)V:61O<F5S($E-05`@<W5P;W)T86T@<&%S=&%S
M('!A<G1I;&AA9&%S+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM
M<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B07!E;F%S
M(&1I=&]S(&]F96YS:79O<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4R
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<R"FUS9VED(")/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E/S(.D@<&5R;6ET:61O('5M
M(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\N(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R
M("(B"B)!<&5N87,@;R!D;VYO(&]U('5M(&%D;6EN:7-T<F%D;W(@9&4@<VES
M=&5M87,@<&]D92!A;'1E<F%R(&$@=&ET=6QA<FED861E(&1E("(*(G5M82!P
M87)T:6QH82!O=2!A<R!P97)M:7-S]65S(&1O('-E=2!D;VYO(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D%B<F4@;G5M82!N;W9A(&IA;F5L82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+B(*;7-G<W1R("(B"B)%<G)O($]P96Y34TPZ($[C;R!F;VD@<&]S<^UV
M96P@97AT<F%I<B!D861O<R!D92!U;6$@<&%R=&4@87-S:6YA9&$@8V]M(%,O
M(@HB34E-12XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B06)R92!E<W1A(&QI9V'GXV\@;G5M82!N
M;W9A(&IA;F5L82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I
M9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")3:7-T96UA($]P97)A=&EV
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C(Y('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]PY_5E<R!D;R`E
M<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3(*;7-G:60@(D]P=&EO;G,Z
M(@IM<V=S='(@(D]PY_5E<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T
M<B`B3&ES=&$@3W)D96YA9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IA
MY^-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@
M(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B56YI9&%D92!/<F=A;FEZ
M86-I;VYA;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G
M:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI>F'GXV\B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I
M;VX@=&5M<&QA=&4B"FUS9W-T<B`B36]D96QO(&]R:6=I;F%L(&1A(&%P;&EC
M8>?C;R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B
M36]D96QO<R!O<FEG:6YA:7,@96T@)7,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B
M3W1H97(B"FUS9W-T<B`B3W5T<F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,0IM<V=I9"`B3W1H97(@26YF;W)M
M871I;VXB"FUS9W-T<B`B3W5T<F%S($EN9F]R;6'G]65S(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!$;VYO(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!004T@;N-O
M(&5S=.$@9&ES<&]N[79E;"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,C4S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M07-S:6YA='5R82!$:6=I=&%L(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$R.3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R
M(")$861O<R!E;F-R:7!T861O<R!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,S4Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")#
M:&%V92!0^F)L:6-A(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$S,S,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T
M<B`B1&%D;W,@07-S:6YA9&]S+T5N8W)I<'1A9&]S(&-O;2!01U`B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@
M(D/S9&EG;R!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@
M(E!(4"!3:&5L;"(*;7-G<W1R(")#;VUA;F1O<R!02%`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG
M:'0@4F%I;B(*;7-G<W1R(")#:'5V:7-C;W,@<&5L82!487)D92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(D%G=6%C96ER;W,@9&4@5&%R9&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B
M4$T@4VYO=R(*;7-G<W1R(").979E(.`@5&%R9&4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(DYE=O5E<R#@(%1A<F1E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*
M;7-G<W1R(")3;VP@X"!487)D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R
M(")496UP;W)A:7,M5"#@(%1A<F1E(@H*(SH@;&EB+V%P:2YP:'`Z,3(X"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(D-O;6%N9&]S(%!?2%`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V
M"FUS9VED(")0861D:6YG(@IM<V=S='(@(D5N8VAI;65N=&\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(E)E</IB;&EC82!)<VSB;6EC82!D;R!087%U
M:7-TXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")297#Z8FQI8V$@9&4@
M4&%L874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D(@IM<V=S='(@(E1E<G)I=/-R:6\@4&%L97-T:6YI86YO(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")086YA;6$B"FUS9W-T<B`B4&%N86WA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@
M1W5I;F5A(@IM<V=S='(@(E!A<'5A($YO=F$@1W5I;NDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R(")297#Z8FQI8V$@9&\@4&%R86=U86DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B
M4&%R=&QY($-L;W5D>2(*;7-G<W1R(")087)C:6%L;65N=&4@16YC;V)E<G1O
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Q.0HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DY"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S,@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S8R"FUS9VED(")087-S=V]R9"(*;7-G<W1R
M(")086QA=G)A+5!A<W-E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HQ,S(R"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%L
M879R82U087-S92!I;F-O<G)E8W1A(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D
M:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4@;F5C
M97-SX7)I82!P87)A(&%U=&5N=&EC8>?C;R!2041)55,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`U-`IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B4&%L879R82U087-S92!C;VT@8V]N9FER;6'GXV\B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A
M<W-W;W)D.B(*;7-G<W1R(")086QA=G)A+5!A<W-E.B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S
M='(@(E!A;&%V<F$M4&%S<V4Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`S-0HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB
M"FUS9W-T<B`B07,@<&%L879R87,M<&%S<V4@=.IM(&1E('-E<B!I9W5A:7,N
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E
M(@IM<V=S='(@(D-O;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B
M"FUS9W-T<B`B0V]L87(@9&4@<F5C;W)T97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S
M='(@(D-A;6EN:&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M-`IM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")3=6)S8W)IY_5E
M<R!096YD96YT97,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS
M9VED(")096]P;&4B"FUS9W-T<B`B4&5S<V]A<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT
M(@IM<V=S='(@(E!E<F-E;G1A9V5M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHV"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B17AE8W5T87(@3W!E<F'G]65S
M(&1E($UA;G5T96[GXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDX
M"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_(@IM<V=S='(@(D5X96-U=&%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O
M(&%Q=6%N9&\@9&$@96YT<F%D83\B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-C$@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HV-PIM<V=I9"`B4&5R;6ES<VEO;B(*;7-G
M<W1R(")097)M:7-SXV\B"@HC(&,M9F]R;6%T"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<
M(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(D$@<&5R;6ES<^-O(%PB)7-<
M(B!NXV\@9F]I(')E;6]V:61A+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C(R-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*;7-G
M:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-T<F'GXV\@9&4@4&5R;6ES<_5E<R(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,30U(&QI8B](;W)D92]097)M<R]522YP:'`Z,30X"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,34R"FUS9VED(")097)M:7-S:6]N<R!F;W(B
M"FUS9W-T<B`B4&5R;6ES<_5E<R!D92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B
M26YF;W)M8>?U97,@4&5S<V]A:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B
M4&5R^B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T
M<R(*;7-G<W1R(")!;FEM86ES(&1E($5S=&EM8>?C;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI
M;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I;F%S(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@
M(E1E;&5F;VYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G<F%F:6%S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B
M4&ET8V%I<FXB"FUS9W-T<B`B26QH87,@4&ET8V%I<FXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(E#M>&5I<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")0;&%T:71U9&5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(E!O<B!F879O<B!C;&EQ=64@<V]B<F4@=6UA(&/I;'5L82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.`IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")0;W(@9F%V;W(@8V]N9FER;64@
M<V4@<F5A;&UE;G1E('!R971E;F1E(')E;6]V97(@97-T92!E;&5M96YT;SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-34*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B4&]R(&9A=F]R(&-O
M;F9I<FUE('-E(')E86QM96YT92!P<F5T96YD92!D97-L:6=A<B!E<W1E(&5L
M96UE;G1O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3<P"FUS9VED(")0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R(")0;W(@
M9F%V;W(@:6YT<F]D=7IA('5M(&WJ<R!E('5M(&%N;RXB"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T
M<B`B4&]R(&9A=F]R(&EN=')O9'5Z82!O(&YO;64@9&$@;F]V82!C871E9V]R
M:6$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E!O<B!F879O
M<B!I;G1R;V1U>F$@=6T@96YD97)EYV\@25`@=N%L:61O+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-C4Y"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+B(*;7-G<W1R("(B"B)0;W(@9F%V;W(@:6YT<F]D=7IA('5M82!D871A(';A
M;&ED83L@=F5R:69I<75E(&\@;OIM97)O(&1E(&1I87,@9&\@;>IS+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-#4P"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!T:6UE+B(*;7-G<W1R(")0;W(@9F%V;W(@:6YT<F]D=7IA('5M
M82!H;W)A(';A;&ED82XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN(@IM<V=S='(@(E!O<B!F879O<BP@9F]R;F7G82!U;6$@8G)E
M=F4@9&5S8W)IY^-O(&1O('!R;V)L96UA+B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,3@@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,@IM
M<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O
M<F0B"FUS9W-T<B`B4&]R(&9A=F]R+"!I;G1R;V1U>F$@;R!S974@3F]M92!D
M92!5=&EL:7IA9&]R(&4@82!S=6$@4&%L879R82U087-S92(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB4&]R(&9A=F]R(&QE:6$@;R!T97AT
M;R!S96=U:6YT92X@5&5M(&1E($-/3D-/4D1!4B!C;VT@;W,@=&5R;6]S(&1E
M<W1E(&%C;W)D;R`B"B)P87)A('5S87(@;R!S:7-T96UA+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ-PIM<V=I9"`B4&QE87-E(')E<&]R="!A;GD@8G5G
M<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RXB"FUS9W-T<B`B4&]R(&9A=F]R
M(')E<&]R=&4@;W,@97)R;W,@<&%R82!I,3AN0&QI<W1S+FAO<F1E+F]R9R(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS
M9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S
M='(@(E!O<B!F879O<B!I;G1R;V1U>F$@;R!N;VUE(&1A(&YO=F$@8V%T96=O
M<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;/-N:6$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(E!O;.UT:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M-`IM<V=I9"`B4&]L;',B"FUS9W-T<B`B4V]N9&%G96YS(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&]R='5G86PB"FUS9W-T<B`B4F5P^F)L:6-A(%!O<G1U9W5E<V$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B4&]S:6-I;VYA;65N=&\@9&5S=&$@:6UA9V5M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:6-I;VYA;65N=&\@
M9&5S=&$@=&%B96QA(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"DB"FUS9W-T<B`B7")0;W-T7"(@<&%R82!E<W1A('!A<W1A
M("ANXV\@Z2!R97%U:7-I=&\@9&\@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M("(*;7-G<W1R(")0<F5C:7!I=&'GXV\@;F%S(/IL=&EM87,@)7,@:&]R82AS
M*3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I
M9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")0<F]B86)I
M;&ED861E(&1E/&)R("\^4')E8VEP:71AY^-O(@H*(SH@;&EB+TAO<F1E+U!R
M969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z
M($$@97AT96YSXV\@3$1!4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D
M82XB"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@
M(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@02!E>'1E;G/C;R!D
M92!S97-SXV\@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S
M='(@(E!R97-SXV\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E<W/C;R!A
M;R!N[79E;"!D;R!M87(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C,*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B4')E<W/C;SH@
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B4')E=FESXV\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R(")0<F5V97(@82!I;6%G96T@;G5M82!N;W9A(&IA;F5L
M82(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8P(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,S8T"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S
M='(@(D]PY_5E<R!A;G1E<FEO<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B
M"FUS9W-T<B`B26UP<FEM:7(@;R!D;V-U;65N=&\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@
M(D-H879E(%!R:79A9&$B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS
M9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96UA(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM
M<V=S='(@(D1E<V-R:>?C;R!D;R!0<F]B;&5M82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,3,*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R
M;VIE8W1O<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$R(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3@Y"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")-
M96YS86=E;2UP<F]N=&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L
M:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;6\@9&4@0VAA=F4@
M4/IB;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0T"FUS
M9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B26YF;W)M8>?C;R!3;V)R
M92!A($-H879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C,P"FUS
M9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R(")/('!A<B!D92!C:&%V97,@4'5B;&EC82]0
M<FEV861A(&[C;R!F;VD@9V5R861A(&-O;2!S=6-E<W-O+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!U97)T;R!2:6-O(@IM<V=S='(@(E!O<G1O(%)I8V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1
M871A<B(*;7-G<W1R(")%<W1A9&\@9&\@46%T87(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C(*;7-G:60@(E%U97)Y(@IM<V=S='(@(E!E9&ED;R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*
M;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(D-H879E
M(%#Z8FQI8V$@4E-!("@E9"!B:70I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(R-C4*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")396QE8^?C
M;R!<(G+A9&EO7"(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")#:'5V82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")2
M86EN($5A<FQY(@IM<V=S='(@(D-H=79A($UA=&EN86PB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,
M871E(@IM<V=S='(@(D-H=79A(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W
M97(B"FUS9W-T<B`B06=U86-E:7)O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS
M9W-T<B`B0VAU=F$@92!.979E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R
M(")#:'5V82!A($YE=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM
M<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B1&ET;R!!;&5A=/-R:6\B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV."!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T
M<B`B4F5L8>?C;R(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDS('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P
M"FUS9VED(")296%D(@IM<V=S='(@(DQE<B(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G
M<W1R("),97(@;65N<V%G96YS(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R(")1=65R(&UE<VUO(')E;6]V97(@)7,_($5S=&$@;W!E<F'GXV\@;N-O
M('1E;2!R96=R97-S;RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U
M<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(B(*(E)E;6]V97(@;65S;6\@;W,@9&%D;W,@
M9&\@=71I;&EZ861O<B`E<S\@17-T82!O<&5R8>?C;R!NXV\@=&5M(')E9W)E
M<W-O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(E)E9F%Z(&$@<W5A(/IL=&EM82!A8^?C;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#,*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.B(*;7-G<W1R(")2969R97-C87(@16QE;65N=&]S(&1E($UE;G4@1&EN
MXFUI8V\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,PIM<V=I9"`B
M4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B4F5F<F5S8V%R(%9I<W5A
M;&EZ8>?C;R!D;R!0;W)T86PZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B17AP<F5S<^-O(%)E9W5L87(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(T.`IM<V=I9"`B4F5L871I;VYS
M:&EP($)R;W=S97(B"FUS9W-T<B`B3F%V96=A9&]R(&1E(%)E;&'G]65S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS
M9W-T<B`B3V)S97)V8>?U97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")397)V:61O<F5S
M(%)E;6]T;W,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R(")54DP@4F5M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N
M<'0O:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ-0IM<V=I
M9"`B4F5M;W9E(@IM<V=S='(@(E)E;6]V97(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R
M(")296UO=F5R($)L;V-O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")2
M96UO=F5R(&-O;'5N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S
M='(@(E)E;6]V97(@9F]R;6%T8>?C;R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3,V"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")296UO
M=F5R('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#4*;7-G:60@
M(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(*;7-G<W1R(")296UO=F5R(&\@7")S8W)I<'1<(B!G=6%R
M9&%D;R!D82!P87-T82!T96UP;W+A<FEA(&1O('-E<G9I9&]R+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")296UO=F5R(&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#D*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B
M"FUS9W-T<B`B4F5M;W9E<B!E<W1E(&[S(&1O(&1O8W5M96YT;R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,38*;7-G:60@(E)E;6]V
M92!U<V5R(@IM<V=S='(@(E)E;6]V97(@571I;&EZ861O<B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4F5M;W9E<B!U=&EL:7IA
M9&]R.B`E<R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G
M:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5S<&]N9&5R
M(&%O('!E9&ED;RX@0_-D:6=O(&1E(&5R<F\@9&5V;VQV:61O.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30T"FUS9VED(")297%U97-T
M960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D\@<V5R
M=FGG;R!P961I9&\@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3<T(&QI8B](;W)D92YP:'`Z-#@W"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(EPB)7-<(B!O8G)I9V%T\W)I;R!NXV\@9F]I
M(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@9&4@)7,N(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C4Y-R!L:6(O5D93+V9T<"YP:'`Z-S0W(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C<Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B7"(E<UPB(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC
M861O(&YA(&-O;F9I9W5R8>?C;R!61E,N(@H*(SH@;&EB+TAO<F1E+U5T:6PN
M<&AP.C<X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S
M7"(@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG
M=7)AY^-O+B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C@*
M;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(D-A;7!O($]B<FEG873S
M<FEO(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,S.2!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$U"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT-`IM<V=I9"`B4F5S970B"FUS9W-T<B`B3&EM<&%R
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E
M<V5T(%!A<W-W;W)D(@IM<V=S='(@(E)E:6YI8VEA<B!086QA=G)A+5!A<W-E
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E
M<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4F5I;FEC:64@82!3=6$@4&%L
M879R82U087-S92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8U"FUS9VED(")2
M97-U;'1S(@IM<V=S='(@(E)E<W5L=&%D;W,B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.#(Q"FUS9VED(")297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.B(*
M;7-G<W1R(")297-U;'1A9&]S("AI;F-L=6EN9&\@2&]R9&4I.B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HX,3D*;7-G:60@(E)E<W5L=',Z(@IM<V=S='(@
M(E)E<W5L=&%D;W,Z(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R(")6;VQT87(@X',@3W#G]65S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:>-O(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED
M(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")2179E<G1E<B!#;VYF
M:6=U<F'GXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"FUS9VED
M(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1E
M($5D:>?C;R!2:6-A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS
M9VED(")2:61D;&5S(@IM<V=S='(@(D%D:79I;FAA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`B1&ER96ET82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3(P"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO
M(&1A(&1I<F5I=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q-@IM<V=I
M9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E9A;&]R97,@X"!D:7)E:71A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O
M<')I961A9&5S(&1A($QI;E]H82XN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E)E9W)A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2;VWI;FEA(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P.`IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R(")2;V1A<B`Q.#`B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"FUS9VED(")2;W1A=&4@3&5F="(*
M;7-G<W1R(")2;V1A<B#@($5S<75E<F1A(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Q,0IM<V=I9"`B4F]T871E(%)I9VAT(@IM
M<V=S='(@(E)O9&%R(.`@9&ER96ET82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P
M97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!,:6YH82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*
M;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D
M82!L:6YH82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("),:6YH87,Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B5')AYV]S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<R(*;7-G<W1R(")4<F'G;W,@87!A<F5C97+C;R!E;G1R92!T;V1A<R!A<R!L
M:6YH87,@92!C;VQU;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B5')AYV]S(&%P87)E
M8V5RXV\@87!E;F%S(&5N=')E(&%S(&-O;'5N87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")4
M<F'G;W,@87!A<F5C97+C;R!A<&5N87,@96YT<F4@;&EN:&%S(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(D5X96-U
M=&%R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(D9E
M9&5R8>?C;R!2=7-S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")297#Z
M8FQI8V$@9&\@4G5A;F1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R(")!<W-I;F%T=7)A($-R:7!T;V=RX69I8V$@4R]-24U%(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%
M;F-R>7!T960@365S<V%G92(*;7-G<W1R(")-96YS86=E;2!%;F-R:7!T861A
M(&-O;2!3+TU)344B"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")!=71E;G1I8V'GXV\@4T%33"!I;F1I<W!O;NUV96PN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U.0IM<V=I9"`B4TU3($UE<W-A
M9VEN9R(*;7-G<W1R(")-96YS86=E;G,@4TU3(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B0V]M86YD;W,@
M4U%,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,`IM<V=I9"`B
M4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R
M(")354-%4U-/(@H*(SH@;&EB+V%P:2YP:'`Z,3,R"FUS9VED(")37U%,(%-H
M96QL(@IM<V=S='(@(D-O;6%N9&]S(%-?44PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R
M(")SX2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386YT82!(
M96QE;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R
M(")3XV\@2VET=',@92!.979I<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS
M9W-T<B`B4V%N=&$@3/IC:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD
M($UI<75E;&]N(@IM<V=S='(@(E/C;R!0961R;R!E($UI<75E;&]N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM
M<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T
M<B`B4^-O(%9I8V5N=&4@92!'<F5N861I;F5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M
M92`H7W-E;&8I(@IM<V=S='(@(DUE<VUA(&UO;&1U<F$@*%]S96QF*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(D5S=&%D;R!);F1E<&5N9&5N=&4@9&$@
M4V%M;V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E)E</IB;&EC
M82!397)E;NUS<VEM82!D92!3XV\@36%R:6YO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O
M;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E/C;R!4;VWI(&4@4'+M;F-I<&4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L
M;&ET92!0<F]V:61E<B(*;7-G<W1R(")&;W)N96-E9&]R(&1O(%-A=.EL:71E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(D%RX6)I82!3875D
M:71A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED
M(")3879E(@IM<V=S='(@(D=U87)D87(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM
M<V=S='(@(D=U87)D87(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)R5S)R(*
M;7-G<W1R(")'=6%R9&%R("<E<R<B"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B1W5A<F1A<B!/
M<.?U97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<P"FUS9VED("(B
M"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*(D=U87)D87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M
M(%PB<V-R:7!T7"(@4$A0(&YO(&1I<F5C=/-R:6\@=&5M<&]RX7)I;R`B"B)D
M;R!S974@<V5R=FED;W(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B1W5A<F1E:2!C;VYF:6=U<F'GXV\@)7,N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B1W5A<F1E:2!O(%PB<V-R:7!T7"(@9&4@86-T=6%L:7IAY^-O(&5M.B!<
M(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")496UP
M;W)A:7,M5"!$:7-P97)S;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B0VGJ;F-I82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B4')O8W5R
M87(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<X"FUS9VED(")3
M96%R8V@@16YG:6YE<R(*;7-G<W1R(")-;W1O<F5S(&1E(%!R;V-U<F$B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")396%R8VAI;F<@2&]R9&4@87!P;&EC871I;VYS(&EN("5S(@IM<V=S='(@
M(E!R;V-U<F%N9&\@87!L:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S"FUS9VED(")396%R8VAI;F<@
M9V5T=&5X="!B:6YA<FEE<RXN+B(*;7-G<W1R(")0<F]C=7)A;F1O(&]S(&)I
M;N%R:6]S(&1E(&=E='1E>'0N+BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDW,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(E-E;&5C8VEO;F%R
M($%R<75I=F]S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U-@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE8V-I
M;VYE('5M82!D871A(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")396QE
M8V-I;VYE('5M(&=R=7!O(&$@86-R97-C96YT87(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B
M"FUS9W-T<B`B4V5L96-C:6]N87(@=6T@;F]V;R!D;VYO(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V
M97(B"FUS9W-T<B`B4V5L96-C:6]N92!U;2!S97)V:61O<B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R
M('1O(&%D9"(*;7-G<W1R(")396QE8V-I;VYE('5M('5T:6QI>F%D;W(@82!A
M9&EC:6]N87(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8V,@IM<V=I9"`B
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E-E;&5C8VEO
M;F4@=&]D;W,@;W,@8V]M<&]N96YT97,@9&$@9&%T82XB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$Q"FUS9VED(")396QE8W0@
M86X@;V)J96-T(@IM<V=S='(@(E-E;&5C8VEO;F4@=6T@;V)J96-T;R(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T
M97AT(&%R96$N(@IM<V=S='(@(B(*(E-E;&5C8VEO;F4@;W,@8V%R86-T97)E
M<R!N87,@8V%I>&%S(&%B86EX;RX@4&]D97+A(&5N=.-O(&-O<&GA+6QO<R!E
M(&-O;.$M(@HB;&]S(&YA(.%R96$@9&4@=&5X=&\N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D82!D
M871A.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&\@
M9F]R;6%T;R!D82!D871A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.#D*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")396QE8V-I;VYE(&$@:61E;G1I
M9&%D92!Q=64@<')E=&5N9&4@86QT97)A<CHB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CHB"FUS9W-T<B`B4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A<R!H;W)A
M<SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O
M<FUA=&\@9&$@:&]R83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C8T"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B4V5L96-C:6]N92!D;VES(&-A;7!O<R!R96QA8VEO;F%D;W,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+B(*;7-G<W1R(")%<V-O;&AA(&\@<V5U(&-O;FIU;G1O
M(&1E(&-O<F5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#`*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M4V5L96-C:6]N92!O('-E=2!I9&EO;6$@<')E9F5R:61O.B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(D5N=FEA<B!296QA=/-R:6\@9&4@4')O8FQE
M;6%S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M,0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B16YV:6%R(%--4R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G
M:60@(E-E;F5G86PB"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%-E;F5G86PB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`B(%-E;G-O<CH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")3971E;6)R;R(*"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I
M82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3Z7)V:6$@92!-;VYT96YE9W)O
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E
M<FEA;"!.=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E(%/I<FEE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.`IM<V=I9"`B4V5R=F5R(&1A
M=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1&%D;W,@9&\@
M<V5R=FED;W(@97)R861O<R!O=2!I;F1I<W!O;NUV96ES+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N
M($E$(&5X<&ER960N(@IM<V=S='(@(DE$(&1E('-E<W/C;R!E>'!I<F]U+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S$S"FUS9VED(")3970B"FUS9W-T
M<B`B071R:6)U:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G
M:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB17-T
M86)E;&7G82!O<.?U97,@<75E(&QH92!P97)M:71A;2!R96EN:6-I87(@82!S
M=6$@<&%L879R82UP87-S92!S92!A;&=U;6$@(@HB=F5Z(&1E;&$@<V4@97-Q
M=65C97(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(D5S<&5C:69I8V%R('-E<G9I
M9&]R97,@<F5M;W1O<R!Q=64@9&5S96IA(&%C961E<B!N;R!S974@<&]R=&%L
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+B(*;7-G<W1R("(B"B)396QE8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F
M97)I9&\L(&\@<V5U(&9U<V\@:&]RX7)I;R!E(&%S('-U87,@;W#G]65S(&1E
M("(*(F1A=&%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I
M9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H
M96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P
M=&EO;G,N(@IM<V=S='(@(B(*(D5S8V]L:&$@82!S=6$@87!L:6-AY^-O(&EN
M:6-I86PL(&\@97-Q=65M82!D92!C;W)E<RP@;R!R969R97-C86UE;G1O(&1E
M("(*(G#A9VEN87,@92!O=71R87,@;W#G]65S(&1E('9I<W5A;&EZ8>?C;RXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"FUS9VED(")3971U<"(*
M;7-G<W1R(")#;VYF:6=U<F%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,SD*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4B"FUS9W-T<B`B7")38W)I<'1S7"(@9&4@86-T=6%L:7IAY^-O
M(&1I<W!O;NUV96ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W-`IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T
M:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B5N%R:6%S(&QO8V%L:7IAY_5E<R!P
M;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O.B`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L
M;&5S(@IM<V=S='(@(E-E:6-H96QE<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-3$*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(D-O;7!R87,B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B
M4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")"<F5V92!3=6WA<FEO(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0S.`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K
M97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(D1E=F5M
M+7-E(&1E9FEN:7(@=&5C;&%S(&1E(&%C97-S;R!P87)A(&$@;6%I;W)I82!D
M87,@;&EG8>?U97,_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3(@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B36]S=')A<B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-3@*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB36]S=')A<B!D:69E
M<F5NYV%S(&5N=')E(&$@8V]N9FEG=7)AY^-O(&=U87)D861A(&4@87%U92!F
M;VD@86=O<F$@9V5R861A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.#(*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`B36]S=')A<B!M;VUE;G1O(&1A(/IL=&EM82!E;G1R861A
M(&YO('-I<W1E;6$_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C8*;7-G
M:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B36]S
M=')A<B!O<.?C;R!P87)A('!R97-E<G9A<B!O(&]R:6=I;F%L(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,3(*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S
M='(@(DUO<W1R87(@<&%L971E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4Q.`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*
M;7-G<W1R(")-;W-T<F%R(&$@8F%R<F$@9&4@;65N=2!C;VT@87,@;W!E<F'G
M]65S('-O8G)E('1A8F5L87,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/R(*;7-G<W1R(")-;W-T<F%R(&\@365N=2`E<R#@(&5S<75E
M<F1A/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R(")-;W-T<F%R(&$@8V%I>&$@9&4@9&GA
M;&]G;R!D87,@4')O<')I961A9&5S(&1E($/I;'5L87,@9&4@5&%B96QA/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R
M;W!R:65D861E<R!D92!486)E;&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A
M<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!,:6YH
M87,@9&4@5&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")3:&]W('1H92!I;6%G92!P
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")-;W-T<F%R(&$@8V%I>&$@9&4@
M9&GA;&]G;R!D87,@4')O<')I961A9&5S(&1E($EM86=E;2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-S8T"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R
M(")-;W-T<F%R(&-A<G)E9V%M96YT;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@
M(D%G=6%C96ER;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")!9W5A
M8V5I<F]S($UA=&EN86ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")!
M9W5A8V5I<F]S(%9E<W!E<G1I;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y(@IM<V=S='(@(D%G=6%C96ER;W,@;F$@5FEZ:6YH86[G82(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,Y.0IM<V=I9"`B4VAR:6YK
M(@IM<V=S='(@(D5N8V]L:&5R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-CDR(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<U-`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,3(@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z.#<T"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.CDP.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY-#8*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3<T(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C$P,#0*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")%;F-O
M;&AA(&]U(&UO=F$@;RAS*2!B;&]C;RAS*2!V:7II;FAO*',I('!R:6UE:7)O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-E<G)A($QEXV\B
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG
M;B!U<"(*;7-G<W1R(")3=6)S8W)E=F5R(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY,@IM<V=I9"`B4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E
M9"(*;7-G<W1R(")3=6)S8W)E=F$L('-E(&%I;F1A(&[C;R!E<W3A(')E9VES
M=&%D;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED
M(")3:6=N871U<F4B"FUS9W-T<B`B07-S:6YA='5R82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I
M=&AM(@IM<V=S='(@(D%L9V]R:71M;R!D92!!<W-I;F%T=7)A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4VEN9V%P;W)E(@IM<V=S='(@(E)E</IB;&EC82!D92!3:6YG87!U<F$B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,C0W(&QI8B](;W)D92]&;W)M+G!H<#HR.3(Y(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3(R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE(@IM
M<V=S='(@(E1A;6%N:&\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]B;W1T;VTN:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`B4V%L=&%R($UA;G5T96[GXV\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#,Q('!O+W1R86YS;&%T:6]N+G!H<#HT.#0@<&\O=')A;G-L871I;VXN
M<&AP.C8V-@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#8P('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C(S"FUS9VED(")3:VEP<&5D+BXN(@IM<V=S='(@(D[C;R!P
M<F]C97-S861O+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B17-L
M;W;A<75I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E)E</IB;&EC
M82!D82!%<VQO=NEN:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R(").979E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@
M(E-N;W<@4VAO=V5R(@IM<V=S='(@(DYE=N-O(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R
M<R(*;7-G<W1R(").97;U97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM
M<V=S='(@(DYE=O5E<R!-871I;F%I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T
M92(*;7-G<W1R(").97;U97,@5F5S<&5R=&EN;W,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(D%L
M='5R82!D92!N979E.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM
M<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B36]S
M=')A<B!E<75I=F%L96YT92!N82#A9W5A.B`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N
M($ES;&%N9',B"FUS9W-T<B`B26QH87,@4V%L;VWC;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O
M;6%L:6$B"FUS9W-T<B`B4V]MX6QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")#86[G]65S
M(&4@4&]E;6%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C4*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5CY^-O(&1O('-E
M;G1I9&\@9&$@;W)D96YAY^-O(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3@Y"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"FUS9VED(")3;W5R
M8V4@861D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!D92!O<FEG96TB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`BP69R:6-A(&1O(%-U;"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A
M;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B175R;W!A(&1O(%-U;"`H25-/+3@X
M-3DM,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D=E\W)G:6$@9&\@4W5L(&4@26QH
M87,@4V%N9'=I8V@@9&\@4W5L(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R(")(96UI<V;I<FEO(%-U;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(D5S<&'G;R!E;G1R92!C
MZ6QU;&%S(&%D:F%C96YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")%<W!AYV\@96YT<F4@
M;R!C;VYT9?ID;R!E(&$@8F]R9&$@9&4@=6UA(&/I;'5L82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")%<W!A
MYV%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B17-P8>=A;65N
M=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@
M(D5S<&'G86UE;G1O(&4@96YC:&EM96YT;R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G
M<W1R(")296EN;R!D92!%<W!A;FAA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(D-O<G)E:6\@;N-O('-O
M;&EC:71A9&\B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@
M(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(DEN<V5R:7(@0V%R
M86-T97(@17-P96-I86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(D1I=FED:7(@8^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN
M(@IM<V=S='(@(D%D:6-I;VYA<B!C;VQU;F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI
M="!R;W<B"FUS9W-T<B`B1&EV:61I<B!L:6YH82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(D1E<W!O<G1O
M<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E)E</IB;&EC82!$96UO
M8W+A=&EC82!3;V-I86QI<W1A(&1O(%-R:2!,86YK82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-2!L:6(O0FQO8VLO;65T87(N<&AP.C<T
M"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")0861RXV\B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3
M=&%R(%1R96LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y-2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C@P.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!
M;F\@9&4@:6[M8VEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(D5S=&%D;R!O
M=2!0<F]V[6YC:6$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U<R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HT.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W1A
M='5S(&9O<B!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(D5S=&%D;R!D82!L;V-A
M;&EZ8>?C;R`E<RXN+B`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q-`IM
M<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92!A<FUA
M>F5N86UE;G1O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*
M;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O(&1E(%)U
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B4F%S=7)A9&\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B
M"FUS9W-T<B`B3&ES=&$@9&4@8V%D96EA<R!D92!C87)A8W1E<F5S(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S0*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E)E=&ER87(@9&]M[6YI;R!D;R!E
M;F1E<F7G;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(D5S
M=&EL;R!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(F1O(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`B07-S=6YT;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(@
M;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q,@IM<V=I9"`B4W5B;6ET
M(@IM<V=S='(@(E-U8FUE=&5R(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*
M(D9O:2!S=6)M971I9&\@<&5D:61O('!A<F$@861I8VEO;F%R(%PB)7-<(B!A
M;R!S:7-T96UA+B!.XV\@<&]D97+A(&5N=')A<B`B"B)E;G%U86YT;R!O('-E
M=2!P961I9&\@;N-O(&9O<B!A<')O=F%D;RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B
M"FUS9W-T<B`B26YF97)I;W(@X"!L:6YH82(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,#4@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U8V5S<V\B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB3&EM<&5Z82!D;R!S:7-T96UA(&1O
M<R!D861O<R!D;R!U=&EL:7IA9&]R(%PB)7-<(B!R96%L:7IA9&$@8V]M('-U
M8V5S<V\N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B4F5M;^?C;R!D92!<(B5S7"(@
M8V]M('-U8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(E)E;6_GXV\@9&4@7"(E<UPB(&1O('-I
M<W1E;6$@8V]M('-U8V5S<V\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B0V]N9FEG=7)A
MY^-O(')E=F5R=&ED82!C;VT@<W5C97-S;RX@4F5C87)R96=U92!P87)A('9E
M<B!A<R!M=61A;N=A<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-34*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0V]N9FEG
M=7)AY^-O(&1E('-A;'9A9W5A<F1A(&=U87)D861A(&-O;2!S=6-E<W-O+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R(")&:6-H96ER;R!D92!C;VYF:6=U<F'G
MXV\@9&4@<V%L=F%G=6%R9&$@)7,@9W5A<F1A9&\@8V]M('-U8V5S<V\N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@86-T
M=6%L:7IA9&\@8V]M('-U8V5S<V\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@97-C
M<FET;R!C;VT@<W5C97-S;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E)E
M</IB;&EC82!D;R!3=63C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B4F5S=6UO(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8V"FUS9VED
M(")3=6X@4FES92(*;7-G<W1R(").87-C97(@9&\@4V]L(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C<Q"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(E#T
M<B!D;R!3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4V]L87)E;F=O(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES
M92(*;7-G<W1R(").87-C97(@9&\@4V]L(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR
M:7-E+U-U;G-E="(*;7-G<W1R(").87-C97(O4/1R(&1O(%-O;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#,*;7-G:60@(E-U;G)I<V4Z
M("(*;7-G<W1R(").87-C97(@9&\@4V]L.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970B"FUS9W-T<B`B4/1R
M(&1O(%-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#8*
M;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(E#T<B!D;R!3;VPZ("(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(E-U<&5R:6]R(.`@;&EN:&$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0S"FUS9VED(")3=7!P;W)T(@IM
M<V=S='(@(E-U<&]R=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3
M=7)I;F%M92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS
M9VED(")3=7)N86UE(@IM<V=S='(@(D%P96QI9&\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(&4@2F%N($UA
M>65N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E)E:6YO(&1A(%-U
M87II;.)N9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(E)E:6YO(&1A
M(%-UZ6-I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=>WG82(*
M"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D5R<F\@9&4@<VEN
M=&%X92!N;W,@=&5R;6]S(&1E('!R;V-U<F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@
M07)A8B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@P7)A8F4@4^UR:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM
M<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")496UP;W)A;"U4(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O
M<FT@86YD(%=I;F1Y(@IM<V=S='(@(E1E;7!O<F%L+50@92!696YT;W-O(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G
M:60@(E0M4W1O<FUS(@IM<V=S='(@(E1E;7!O<F%I<RU4(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O
M<FUS($5A<FQY(@IM<V=S='(@(E1E;7!O<F%I<RU4($UA=&EN86ES(@H*(SH@
M;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM
M<V=S='(@(D%R<75I=F\@5%-6(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H
M<#HQ,S8*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A8F5L82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G
M:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A
M(%1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T
M<B`B4')O<')I961A9&5S(&1A('1A8F5L82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")486EW86XB"FUS9W-T<B`B1F]R;6]S82(*"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@
M0VAI;F$B"FUS9W-T<B`B1F]R;6]S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%1A9&II<75I<W3C;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>N)N
M:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(D%L=F\Z(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$W,PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B
M5&%R969A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS
M9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!496QE
M9F]N92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP
M(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")496UP97)A='5R82!D82#Z;'1I
M;6$@:&]R83HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B
M5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U<F$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED(")496UP97)A='5R93H@
M(@IM<V=S='(@(E1E;7!E<F%T=7)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M
M<&5R871U<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S*2`F9&5G.R5S(@H*
M(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HR,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3R!M
M;V1E;&\@7"(E<UPB(&[C;R!F;VD@96YC;VYT<F%D;RXB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!-;V1E;&]S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,3$*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X
M=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"FUS9VED(")497AT
M($]N;'DB"FUS9W-T<B`B07!E;F%S(%1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X
M="!A;&EG;B(*;7-G<W1R(")!;&EN:&%M96YT;R!D;R!T97AT;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@
M(E1E>'1T;W`B"FUS9W-T<B`B5&]P;R!D;R!T97AT;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM
M<V=S='(@(C6J(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@
M(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1A:6QA;F3J<R`H5$E3+38R,"DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")296EN;R!D82!486ELXFYD
M:6$B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3(S"FUS9VED(")4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(D]B<FEG861O('!O
M<B!U<V%R(&5S=&4@<VES=&5M82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@)7,@:&5L<"!F:6QE(&9O
M<B`E<R!D;V5S;B=T('EE="!E>&ES="X@0W)E871I;F<@82!N97<@;VYE+B(*
M;7-G<W1R(")/(&%R<75I=F\@9&4@86IU9&$@)7,@<&%R82`E<R!NXV\@97AI
M<W1E(&%I;F1A+B!#<FEA;F1O('5M(&YO=F\N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C<S-PIM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N
M[79E;"XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(D\@96YG96YH;R!D
M92!I;G1E9W)AY^-O($AO<F1E+TMO;&%B(&[C;R!S=7!O<G1A(%PB)7-<(B(*
M"B,Z(&QI8B].970O24U34"]";V]K+G!H<#HQ,CDT"FUS9VED(")4:&4@24U3
M4"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")/(')E
M9VES=&\@*%PB;&]G7"(I($E-4U`@;N-O('#T9&4@<V5R(&EN:6-I86QI>F%D
M;RXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,CD*;7-G:60@(E1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'DB"FUS9W-T<B`B02!C;&%S<V4@36%I;G1E;F%N8V4Z.B!NXV\@9F]I(&-A
M<G)E9V%D82!C;VT@<W5C97-S;R(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")!(&IA;F5L82!D92!/<.?U97,@
M9F5C:&]U+B!38>UN9&\N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ-3@@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HQ-CD@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ
M.#`*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ.3(@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HR,#,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,C$*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HR,S,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-S(*;7-G:60@
M(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O
M('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB3R!A9&UI;FES=')A9&]R
M('1E;2!D92!C;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!D92!P97)M:7-S]65S
M('!E<FUA;F5N=&4@<V4@(@HB<75I<V5R('5S87(@4&5R;6ES<_5E<RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")!<&5N
M87,@;R!L861O(&EN9F5R:6]R(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B)/(&[Z;65R;R!D
M92!)1"!D;R!C;VYT86-T;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9F]I(&1E
M:7AA9&\@96T@8G)A;F-O(&]U("(*(F[C;R!F;VD@96YC;VYT<F%D;R!N82!B
M87-E(&1E(&1A9&]S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D\@8V]N=&%C
M=&\@9F]I(&%D:6-I;VYA9&\@X"!L:7-T82!D92!C;VYT86-T;W,@8V]M('-U
M8V5S<V\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$T.0IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@HB3R!B;&]C;R!D92!A<W-I;F%T=7)A(%!'4"!D97-T86-A9&\@Z2!N96-E
M<W/A<FEO('!A<F$@=F5R:69I8V%R('5M82!M96YS86=E;2`B"B)A<W-I;F%D
M82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(D\@240@9&$@;&ES=&$@9&4@9&ES
M=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E
M;2!B<F%N8V\@;W4@(@HB;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@
M9&%D;W,N(@H*(R!C+69O<FUA=`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N(@IM<V=S='(@(D$@;&ES=&$@9&4@9&ES=')I8G5I
MY^-O(&[C;R!F;VD@97-P96-I9FEC861A+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")!<R!F=6YC
M:6]N86QI9&%D97,@9&4@96YC<FEP=&'GXV\@97AI9V5M('5M82!L:6=AY^-O
M('-E9W5R82XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-2!L:6(O2&]R9&4N<&AP
M.C0X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D\@87)Q=6EV;R`E<R!D
M979E<FEA(&-O;G1E<B!U;2!A=')I8G5T;R`E<RXB"@HC.B!L:6(O2&]R9&4N
M<&AP.C$V."!L:6(O2&]R9&4N<&AP.C0W.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+B(*;7-G<W1R(")/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT97(@86QG=6YS
M(&%T<FEB=71O<R`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$U,@IM<V=I
M9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM
M<V=S='(@(D\@9FEC:&5I<F\@;N-O('!O9&4@<V5R(&-O<&EA9&\@<&%R82!S
M:2!P<O-P<FEO+B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-C`*;7-G:60@
M(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")/(&9I8VAE
M:7)O(&[C;R!C;VYTZ6T@9&%D;W,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM
M<V=S='(@(D%B86EX;R!E<W3C;R!O<R!C86)EYV%L:&]S(&1E<W1A(&UE;G-A
M9V5M+VUE;G-A9V5M(')F8S@R,BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@
M=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I
M96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO
M=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T
M('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A
M;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D\@;6]D;R!D
M92!E8W+C(&EN=&5I<F\@8V%U<V$@<')O8FQE;6%S(&YO($EN=&5R;F5T($5X
M<&QO<F5R+"!D979I9&\@82!E<G)O<R`B"B)N;R!N879E9V%D;W(@<75E(&[C
M;R!C;VYS96=U:6UO<R!U;'1R87!A<W-A<BX@(%!O9&4@<W5R9VER(&QI>&\L
M('!O9&5M("(*(F1E<V%P87)E8V5R(&9U;F-I;VYA;&ED861E<R!D;R!E9&ET
M;W(@92]O=2!O('-E=2!N879E9V%D;W(@<&]D92!A8F]R=&%R+B!392`B"B)O
M('-E=2!S:7-T96UA(.D@=6T@5VEN9&]W<R`Y>"P@Z2!M=6ET;R!P<F]VX79E
M;"!Q=64@;V)T96YH82!U;2`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT
M)R!E('!R96-I<V4@9&4@<F5I;FEC:6%R(&\@<VES=&5M82Y<7&Y<7&Y&;VD@
M879I<V%D;RX@(%!O<B`B"B)F879O<B!P<F5S<VEO;F4@3TL@<V4@86EN9&$@
M87-S:6T@<75I<V5R(&5X<&5R:6UE;G1A<B!O(&5D:71O<B!D92!E8W+C("(*
M(FEN=&5I<F\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.3<@<&\O=')A
M;G-L871I;VXN<&AP.C$R,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&AE
M;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM;"(*;7-G<W1R(")/
M(&9I8VAE:7)O(&1E(&%J=61A("5S(&[C;R!C;VUEYV$@8V]M(#P_>&UL(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B02!I9&5N=&ED861E(%PB)7-<(B!F;VD@<F5M;W9I9&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM
M<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B07!E;F%S
M(&\@;&%D;R!E<W%U97)D;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$T-@IM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*(D$@;&]C86QI>F'GXV\@9&\@87)Q=6EV;R!E>&5C=73A=F5L
M(&1E($=N=5!'('1E;2!D92!S97(@:6YD:6-A9&$@X"!C;&%S<V4@(@HB0W)Y
M<'1?<&=P.CHN(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)!(&UE;G-A
M9V5M(&5N=FEA9&$@96T@)7,@<&%R82`E<R!C;VT@87-S=6YT;R!<(B5S7"(@
M9F]I(&UO<W1R861A+EQN(@HB3N-O(&CA(&=A<F%N=&EA(&1E('%U92!A(&UE
M;G-A9V5M('1E;FAA('-I9&\@<F5A;&UE;G1E(&QI9&$@;W4@8V]M<')E96YD
M:61A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<X"FUS9VED(")4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B
M"FUS9W-T<B`B3R!N;VUE(&$@=7-A<B!Q=6%N9&\@;&EG86YD;R#@('#A9VEN
M82!D92!C;VUP;W-IY^-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@
M9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")/
M(&WS9'5L;R!O<&5N<W-L(.D@;F5C97-SX7)I;R!P87)A(&$@8VQA<W-E($AO
M<F1E7T-R>7!T7W-M:6UE.CHN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E
M<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E
M9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*
M(D$@;W#GXV\@7"(E<UPB(&[C;R!P]&1E('-E<B!G=6%R9&%D82P@<&]I<R!O
M<R!S975S(&1A9&]S(&5X8V5D96T@82!D:6UE;G/C;R`B"B)MX7AI;6$@<&5R
M;6ET:61A(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=V5B8W!P+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L
M+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U
M<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD
M(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(D\@<')O9W)A;6$@=7-A9&\@
M<&%R82!V97(@97-T92!T:7!O(&1E(&1A9&]S("@E<RD@;N-O(&9O:2!E;F-O
M;G1R861O(&YO("(*(G-I<W1E;6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B07!E;F%S(&]S(&QA9&]S
M(&5S<75E<F1O(&4@9&ER96ET;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R(")!<&5N87,@;R!L861O(&1I<F5I=&\B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R(")/('-E<G9I9&]R(%PB)7-<(B!F;VD@<F5M;W9I9&\N(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(D\@<V5R=FED;W(@7"(E<UPB(&9O:2!G=6%R9&%D;RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R
M(")/('!E9&ED;R!D92!S=6)S8W)IY^-O(&1E("5S(&9O:2!R96UO=FED;RXB
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR.3`*;7-G:60@(E1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!(&QI
M;FAA(&EN9&EC861A(&[C;R!E>&ES=&4N(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@
M7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")/(&%R<75I=F\@=&5M
M<&]RX7)I;R!<(B5S7"(@;N-O(&5X:7-T92XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")!<&5N87,@;W,@
M;&%D;W,@<W5P97)I;W(@92!I;F9E<FEO<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T
M;W`@<VED92!O;FQY(@IM<V=S='(@(D%P96YA<R!O(&QA9&\@<W5P97)I;W(B
M"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,S`W"FUS9VED(")4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS
M9W-T<B`B3W,@9&%D;W,@8V%R<F5G861O<R!P97)D97)A;2US92!D97-D92!O
M('!A<W-O(&%N=&5R:6]R+B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z
M,C0P(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D\@87)Q
M=6EV;R!C87)R96=A9&\@;N-O('#T9&4@<V5R(&=U87)D861O+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT."!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3`Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3R!B;&]C;R!W96%T:&5R+F-O
M;2!NXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(D[C;R!HX2!O<.?U97,@9&ES<&]N[79E:7,N(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,T,0IM<V=I9"`B5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM
M<V=S='(@(D[C;R!HX2!P87)T97,@<75E('!O<W-A;2!S97(@;6]S=')A9&%S
M(&5M(&QI;FAA+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`S"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R
M("(B"B)(X2!D96UA<VEA9&]S(&-A<F%C=&5R97,@;F5S=&4@8V%M<&\N($EN
M=')O9'5Z:74@)7,@8V%R86-T97)E<SL@=&5M(&1E("(*(FEN=')O9'5Z:7(@
M;65N;W,@9&\@<75E("5S+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8P
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E(&1O97-N)W0@>65T(&5X:7-T
M(&$@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B3N-O(&5X:7-T92!A:6YD
M82!U;2!A<G%U:79O(&1E(&%J=61A('!A<F$@)7,N(@H*(SH@<VEG;G5P+G!H
M<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E
M;3H@)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!P<F]B;&5M82!N82!A9&GGXV\@
M9&4@7"(E<UPB(&%O('-I<W1E;6$Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M.B`B"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!P<F]B;&5M82!A;R!L:6UP87(@
M;W,@9&%D;W,@9&\@=71I;&EZ861O<B!<(B5S7"(@9&\@<VES=&5M82XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B3V-O<G)E=2!U;2!P<F]B;&5M82!N82!R96UOY^-O
M(&1E(%PB)7-<(B!D;R!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B3V-O<G)E=2!U;2!P<F]B;&5M
M82!A;R!A8W1U86QI>F%R(%PB)7-<(CH@)7,N(@H*(SH@;&EB+TAO<F1E+T)R
M;W=S97(N<&AP.C@X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L
M;V%D960N(@IM<V=S='(@(B(*(DAO=79E('5M('!R;V)L96UA(&-O;2!O(&-A
M<G)E9V%M96YT;R!D;R!F:6-H96ER;SH@)7,@;N-O(&9O:2!C87)R96=A9&\N
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)/8V]R<F5U
M('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D;R!A<G%U:79O.B!/
M("5S(&5X8V5D92!O('1A;6%N:&\@(@HB;>%X:6UO('!E<FUI=&ED;R`H)60@
M8GET97,I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!P<F]B;&5M82!C;VT@;R!C
M87)R96=A;65N=&\@9&\@87)Q=6EV;SH@3R`E<R!F;VD@87!E;F%S("(*(G!A
M<F-I86QM96YT92!C87)R96=A9&\N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D]C;W)R974@
M=6T@97)R;R!A;R!M;W-T<F%R(&5S=&$@<&%R=&4@9&$@;65N<V%G96TB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B
M3V-O<G)E=2!U;2!E<G)O(&%O(&EM<&]R=&%R(&1A9&]S(&1E(&-O;G1A8W1O
M+B(*"B,Z(&QI8B](;W)D92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*
M;7-G<W1R(")/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T87(@9&%D;W,@:4-A
M;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F
M;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD
M+B(*;7-G<W1R("(B"B)/8V]R<F5U('5M(&5R<F\@;F\@9F]R;75LX7)I;R!D
M92!C;VYF:6=U<F'GXV\N(%1A;'9E>B!T96YH82!O;6ET:61O('5M(&-A;7!O
M("(*(F]B<FEG873S<FEO+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`W
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,3$S('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,C0U"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE
M("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@(@HB
M9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM
M;"!P87)S97(N(@IM<V=S='(@(B(*(D]C;W)R974@=6T@97)R;R!A;R!A8G)I
M<B!O(&%R<75I=F\@)7,N($5X<&5R:6UE;G1E(&5X96-U=&%R('1R86YS;&%T
M:6]N+G!H<"`B"B)C;VT@82!O<.?C;R`M9"!P87)A(&-O;G-E9W5I<B!V97(@
M87,@;65N<V%G96YS(&1E(&5R<F\@9&\@86YA;&ES861O<B!834PN(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A
M9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(D]C;W)R974@=6T@97)R;R!A;R!R96%L:7IA<B!A
M(&9U;N?C;R!D92!L:79R;R!D92!E;F1E<F7G;W,@97-P96-I9FEC861A+B!0
M;W(@(@HB9F%V;W(@=&5N=&4@9&4@;F]V;R!M86ES('1A<F1E+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)/8V]R<F5U
M('5M(&5R<F\@86\@86-T=6%L:7IA<B!O<R!P;W)M96YO<F5S(&1O(&-O;G1A
M8W1O+B!0;W(@9F%V;W(@=&5N=&4@9&4@(@HB;F]V;R!M86ES('1A<F1E+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(D]C;W)R974@=6T@97)R;R!A;R!A8W1U86QI>F%R(&$@;&ES=&$@9&4@9&ES
M=')I8G5IY^-O+B!0;W(@9F%V;W(@=&5N=&4@9&4@(@HB;F]V;R!M86ES('1A
M<F1E+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*
M;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(D5S=&4@<V5R=FED;W(@24U!4"!NXV\@
M<W5P;W)T82!P87)T:6QH82!D92!P87-T87,N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D[C;R!P
M87)E8V4@<V5R('5M(&%R<75I=F\@<F%R(';A;&ED;RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B3N-O
M('!A<F5C92!S97(@=6T@87)Q=6EV;R!Z:7`@=N%L:61O+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,30T"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B3N-O('!A<F5C
M92!S97(@=6UA(&[Z;65R;R!D92!C87)TXV\@=N%L:61O+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%<W1E(&-O;G1R
M;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@871R87;I<R!D
M;R!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI+"!U<V%N
M9&\@82!!4$D@2%144"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*
M(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D
M92!M96YS86=E;G,@871R87;I<R!D;R!S;7,R;6%I;"`H:'1T<#HO+R(*(G-M
M<S)E;6%I;"YC;VTI+"!U<V%N9&\@82!!4$D@2%144"(*"B,Z(&QI8B].970O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@
M5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N
M="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M(@IM<V=S='(@(B(*(D5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!O(&5N=FEO
M(&1E(&UE;G-A9V5N<R!V:6$@4TU44"!A=')A=NES(&1A(%9O9&%F;VYE("(*
M(DETX6QI82!E(&%P96YA<R!P87)A(&[Z;65R;W,@5F]D869O;F4N($5X:6=E
M('5M82!C;VYT82!D92!C;W)R96EO("(*(F5L96-T<O-N:6-O(&YA(%9O9&%F
M;VYE($ETX6QI82`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M-38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,#`@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-3D*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-#`@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3D@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P,#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P-SD@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M-3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3,*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V-38@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,S8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,W,C,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,W,S$*;7-G:60@(E1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N(@IM<V=S='(@(D5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")%<W1E(&-A
M;7!O('!O9&4@8V]N=&5R(&%P96YA<R!I;G1E:7)O<RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0Q-PIM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B17-T92!C
M86UP;R!P;V1E(&%P96YA<R!C;VYT97(@;OIM97)O<R!E(&\@<^UM8F]L;R!D
M;VES+7!O;G1O<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y-`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB
M"FUS9W-T<B`B17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E
M<R!O8W1A:7,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@=&5M
M(&1E(&-O;G1E<B!U;6$@;&ES=&$@9&4@:6YT96ER;W,@<V5P87)A9&]S('!O
M<B!E<W!AYV]S(&]U("(*(G;M<F=U;&%S+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BXB"FUS9W-T<B`B17-T92!C86UP;R!T96T@9&4@<V5R('5M(&[Z;65R
M;R!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S4*;7-G:60@
M(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB
M"FUS9W-T<B`B(@HB17-T92!C86UP;R!T96T@9&4@8V]N=&5R('5M(&/S9&EG
M;R!D92!C;W(@;F\@9F]R;6%T;R!21T(@:&5X861E8VEM86PL('!O<B`B"B)E
M>&5M<&QO("<C,3(S-&%F)RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38Q
M"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M(@IM<V=S='(@(D5S=&4@;6]D96QO(&KA(&9O:2!P<F]C97-S861O+B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(DES=&\@Z2`E<RXB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,B"FUS9W-T<B`B(@HB17-T92#I('5M(&]B:F5C=&\@2V]L86(@1W)O=7!W
M87)E+B!087)A('9E<B!E<W1E(&]B:F5C=&\@<')E8VES82!D92!U;2`B"B)C
M;&EE;G1E(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@<75E(&-O;FAEYV$@;R!F
M;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82`B"B)U;6$@;&ES=&$@9&4@
M8VQI96YT97,@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!N97-S87,@8VER8W5N
M<W3B;F-I87,@=FES:71E("5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C4X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BXB"FUS9W-T<B`B17-T82!M96YS86=E;2!F;VD@97-C<FET
M82!N=6T@8_-D:6=O("@E<RD@9&EF97)E;G1E(&1O('-E=2XB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D5S=&4@;OIM97)O('!R96-I
M<V$@9&4@<V5R('!E;&\@;65N;W,@=6TN(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$S,#0*;7-G:60@(E1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@
M=&AE(&-O;6UA;F0@;&EN92XB"FUS9W-T<B`B17-T92!<(G-C<FEP=%PB('1E
M;2!S97(@97AE8W5T861O(&$@<&%R=&ER(&1E('5M82!L:6YH82!D92!C;VUA
M;F1O<RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R(&[C;R!C;VYS96=U92!D
M97-C;VUP<FEM:7(@87)Q=6EV;W,@>FEP(&]U(&=Z:7`N(@H*(SH@;&EB+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ-#<*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B17-T92!S:7-T96UA(&5N
M8V]N=')A+7-E(&1E<V%C=&EV861O+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(D5S=&$@=F%L;W(@=&5M(&1E('-E<B!U;2!N^FUE<F\N(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(*;7-G<W1R(")%<W1A(&IA;F5L82!T96T@9&4@<V5R(&-H86UA9&$@
M82!P87)T:7(@9&4@=6UA(&IA;F5L82!D92!/<.?U97,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E
M<B(*;7-G<W1R(")4<F]V;V%D82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,C(*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B0FEL:&5T97,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R-PIM<V=I9"`B5&EM92(*;7-G<W1R
M(")$871A+TAO<F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`X
M"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E-E9W5I;65N=&\@5&5M
M<&]R86PB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@
M9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&\@=&5M<&\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C4S.`IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L96/GXV\@9&%T82]H;W)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B
M"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT
M:7`I.B(*;7-G<W1R(")4[71U;&\@*&1I8V$I.B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")0
M87)A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R
M-@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W
M:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&%R82!S96QE8V-I;VYA<B!M
M^FQT:7!L;W,@:71E;G,L(&-A<G)E9W5E(&5M($-O;G1R;VP@*%!#*2!O=2!#
M;VUM86YD("A-86,I("(*(F5N<75A;G1O(&-L:6-A<BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDY"FUS9VED(")4;V1A>2(*;7-G<W1R
M(")(;VIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E1R
M;V-A<B!&;VYT92!(5$U,(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")297#Z
M8FQI8V$@5&]G;VQE<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O
M<75E;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,0IM
M<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B06UA;FCC(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N
M9V$B"FUS9W-T<B`B4F5I;F\@9&\@5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*
M;7-G<W1R(")4;W!O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R
M(")-;VQD=7)A(&1E('1O<&\@*%]T;W`I(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C8U-PIM<V=I9"`B5')A;G-L871E9"(*;7-G<W1R(")4<F%D=7II9&%S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA
M=&EO;G,B"FUS9W-T<B`B5')A9'7G]65S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@
M86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN9&%D92!E(%1O8F%G;R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-SDQ"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM
M<V=S='(@(E9E<F1A9&5I<F\@;W4@9F%L<V\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R
M("(SJB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A
M(%1U;NUS:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B4F5P^F)L:6-A
M(&1A(%1U<G%U:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I
M9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R8V\@*$E33RTX
M.#4Y+3DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<G%U
M96UE;FES=.-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S
M(@IM<V=S='(@(DEL:&%S(%1U<F-A<R!E($-A:6-O<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U
M=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR
M-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R(")%<V-R979A
M(&$@<W5A(&5S8V]L:&$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U-PIM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(LUN9&EC92!5
M+E8N.B`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@
M(E523"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*
M;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R="(*;7-G<W1R(")54DP@9&\@<V5U(')E;&%T\W)I;R!D92!E<W1A9&\@
M9&\@96YV:6\@9&4@7")S8W)I<'1S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@
M(E523#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B4F5P^F)L:6-A(&1O
M(%5G86YD82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56-RXFYI82(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,U"FUS9VED(")5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M86-E9&5R(.`@<&%S=&$@5D93+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*(D[C;R!F;VD@
M<&]S<^UV96P@861I8VEO;F%R(&EN9F]R;6'GXV\@9&4@=71I;&EZ861O<B!E
M>'1R82!A<75A;F1O(&1A("(*(G-U8G-C<FGGXV\N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!M=61A<B!A<R!P97)M:7-S]65S(&1O(&%R<75I
M=F\@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,P."!L:6(O
M5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!M=61A<B!A<R!P97)M:7-S]65S(&1O
M(&%R<75I=F\@5D93("5S+R5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!M=61A<B!P87)A("5S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,S<Q"FUS9VED(")5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&QI9V%R(&%O('-E<G9I9&]R(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z-S4V"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!L:6=A<B!U<V%N9&\@4U-,+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,34X(&QI8B]61E,O9FEL92YP:'`Z,38S(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C$X.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C
M;W!I87(@;R!A<G%U:79O(%9&4RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S`S
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8W)I
M87(@82!P87-T82!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,C<W(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HR-#@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4RXB
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8W)I
M87(@;R!A<G%U:79O(%9&4RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Y.`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!U;2!A<G%U:79O(%9&4R!V87II
M;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-B!L:6(O2&]R
M9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9&5S8V]M
M<')I;6ER(&]S(&1A9&]S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(')E;6]V97(@7"(E<UPB+"!P;VES(&$@<&%S=&$@;N-O(&5S=.$@
M=F%Z:6$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW.2!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R
M96UO=F5R(%PB)7-<(CH@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-30@
M;&EB+U9&4R]S<6PN<&AP.C,Q-"!L:6(O5D93+VUU<W%L+G!H<#HS,3$*(SH@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`E<RP@<&]I
M<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA(@H*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S0P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,@<F5C
M=7)S:79A;65N=&4N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-C`@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-0HC.B!L:6(O
M5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S,V"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4RXB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z,S,Y(&QI8B]61E,O<W%L+G!H<#HS-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S
M=&$@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3<P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O
M(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8@;&EB+U9&
M4R]S<6PN<&AP.C(Q,"!L:6(O5D93+VUU<W%L+G!H<#HQ-C<*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS-S`*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<X
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!A<G%U:79O(%9&4RXB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z,S(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!R96UO=F5R(')E8W5R<VEV86UE;G1E.B`E<RXB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z-S(P"FUS9VED(")5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&1E=&5R;6EN87(@82!P87-T82!C;W)R96YT92XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&5X=')A:7(@;W,@<&]R;65N;W)E<R!D;R!C97)T:69I8V%D;R(*"B,Z
M(&QI8B].970O24U34"YP:'`Z-#4Q(&QI8B].970O24U34"]!=71H+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@;&5R(&$@9&5F
M:6YIY^-O(&1E("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Y(&QI8B]6
M1E,O9FEL92YP:'`Z,3,T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U.`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C,*;7-G:60@(E5N86)L92!T;R!M;W9E
M(%9&4R!F:6QE+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&UO=F5R(&\@
M87)Q=6EV;R!61E,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@5D93
M(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P-2!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HQ,C(@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3(U"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@5D93('!A<F$@
M97-C<FET82XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8W(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&%R<75I=F\@5D93
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(&-O;7!R:6UI9&\N
M(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B3N-O(&-O;G-I
M9V\@;&5R(&\@87)Q=6EV;SH@(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HU.3(*
M;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!L97(@82!P87-T82!V9G-R;V]T
M+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!R96YO;65A<B`E<R!C;VUO("5S.B!A('!A<W1A(&1E(&1E<W1I;F\@
M:N$@97AI<W1E(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@82!P87-T82!61E,N(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(')E;F]M96%R(&$@<&%S=&$@5D93.B`E<RXB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(')E;F]M96%R(&\@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-3,S(&QI8B]61E,O;75S<6PN<&AP.C(R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q
M=6EV;R!61E,@)7,O)7,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(T-2!L:6(O
M5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(W-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR
M.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,N(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L
M92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&5X96-U=&%R("=M:VES;V9S)RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C
M;VYV97)T97(@97-T92!D;V-U;65N=&\@5V]R9"(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HQ,C(@;&EB+U9&4R]F='`N<&AP.C$R-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R(&%R<75I=F\@5D93(%PB)7-<
M(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Q,@IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!E<V-R979E<B!O(&%R<75I=F\@5D93("AC;W!Y*"D@
M9F%L:&]U*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,U"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B3N-O
M(&-O;G-I9V\@<F5M;W9E<B`G)7,G.B`E<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B
M"FUS9W-T<B`B4W5B;&EN:&%D;R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")$97-F87IE<B!!
M;'1E<F'G]65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS
M9W-T<B`B1&5S9F%Z(&$@<W5A(/IL=&EM82!A8^?C;R(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B4F5S<&]S=&$@
M:6YE<W!E<F%D82!D;R!S97)V:61O<B!N82!C;VYE>.-O.B`B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O
M.B`B"FUS9W-T<B`B4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!A
M.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-`IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")396T@8V%T96=O<FEA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX
M*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R
M86(@16UI<F%T97,B"FUS9W-T<B`B16UI<F%D;W,@P7)A8F5S(%5N:61O<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B4F5I;F\@56YI9&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(D5S=&%D;W,@56YI
M9&]S(&1A($%MZ7)I8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R
M($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B26QH87,@365N;W)E<R!$:7-T
M86YT97,@9&]S($5S=&%D;W,@56YI9&]S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8Q(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@
M(E5N:71S(@IM<V=S='(@(E5N:61A9&5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q.0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W
M;B(*;7-G<W1R(")$97-C;VYH96-I9&\B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")A<&EM<V=I9"`H240@9&4@365N
M<V%G96T@9&4@05!)*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+B(*;7-G<W1R(")C;&EM<V=I9"!D97-C;VYH96-I9&\@*$E$
M(&1E($UE;G-A9V5M(&1E($-L:65N=&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ-3`Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@8V]M;6%N
M9#H@)7,B"FUS9W-T<B`B0V]M86YD;R!D97-C;VYH96-I9&\Z("5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-@IM<V=I9"`B56YK;F]W
M;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B1F]I(&9O<FYE8VED82!U
M;6$@;&]C86QI>F'GXV\@9&5S8V]N:&5C:61A+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N
M86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(").;VUE(&1E('5T:6QI>F%D;W(@
M;W4@<&%L879R82UP87-S92!E<G)A9&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")296UO=F5R(&QI9V'G
MXV\@9&\@96QE;65N=&\@8V]R<F5N=&4B"@HC.B!L:6(O2&]R9&4O261E;G1I
M='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")396T@;F]M92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*
M;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@
M0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B
M(@HB4&]R(')A>O5E<R!D92!S96=U<F%NYV$L(%PB<V-R:7!T<UPB('-E;2!P
M<FEV:6SI9VEO(&[C;R!P;V1E;2!A8V5D97(@82`B"B)#;W)T87(O0V]P:6%R
M+T-O;&%R('!R;V=R86UA=&EC86UE;G1E+B!#87)R96=U92!E;2!/2R!P87)A
M('9E<B!U;6$@;F]T82`B"B)TZ6-N:6-A(&5M(&UO>FEL;&$N;W)G('%U92!L
M:&4@;6]S=')A<N$@8V]M;R!A=71O<FEZ87(@=6T@7")S8W)I<'1<(B!A("(*
M(F%C961E<B!A;W,@<F5C;W)T97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L
M;W(B"FUS9W-T<B`B4F5M;W9E<B!C;VQO<F'GXV\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8X-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.CDR-@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B
M56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(D5X=&5N<^-O(&[C;R!3
M=7!O<G1A9&$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED(")5
M;G1R86YS;&%T960B"FUS9W-T<B`B4&]R('1R861U>FER(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3@S
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`B36]D:69I8V%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&4@)7,B"FUS9W-T<B`B06-T=6%L:7IA<B`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*;7-G:60@(E5P9&%T92!U<V5R(@IM
M<V=S='(@(D%C='5A;&EZ87(@=71I;&EZ861O<B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3,W(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@86-T=6%L:7IA9&\N(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P.3(@<&\O=')A;G-L871I;VXN<&AP.C$R
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871I;F<@)7,@:&5L<"!F:6QE
M(&9O<B`E<RXB"FUS9W-T<B`B06-T=6%L:7IA;F1O(&%R<75I=F\@9&4@86IU
M9&$@)7,@<&%R82`E<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B7")3
M8W)I<'1<(B!D92!A8W1U86QI>F'GXV\@<F5M;W9I9&\N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3@R"FUS9VED(")5<&QO860B"FUS9W-T<B`B57!L;V%D(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X.0IM<V=I9"`B57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM
M<V=S='(@(D-A<G)E9V%D;W,@;F\@<V5R=FED;W(@=&]D;W,@;W,@87)Q=6EV
M;W,@9&4@:6YS=&%L8>?C;R!D92!A<&QI8V'G]65S+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G
M:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&5T<F%S(&QA=&EN
M87,@96T@;6%I^G-C=6QA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N
M(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!R;VUA;F]S(&5M(&UA:?IS8W5L
M87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E)E</IB;&EC82!/<FEE
M;G1A;"!D;R!5<G5G=6%I(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,U('!O
M+W1R86YS;&%T:6]N+G!H<#HY,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3,*;7-G
M:60@(E5S86=E.B(*;7-G<W1R(")5=&EL:7IAY^-O.B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")5<V%R(&\@0V]R<F5N
M=&4Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")5<V%R(%-33"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B
M"B)5<V%R('-E(&\@;F]M92!D92!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP
M87-S92!F;W)E;2!D:69E<F5N=&5S(&YO('-E<G9I9&]R("(*(DE-4U`N(@H*
M(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HV,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S
M='(@(E5T:6QI>F%D;W(@)7,@;N-O(&5S=.$@875T;W)I<V%D;R!P87)A("5S
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')AY^-O(&1E(%5T:6QI>F%D;W)E
M<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1O(%5T:6QI>F%D;W(B"@HC.B!S
M:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R
M(")296=I<W1O(&1E(%5T:6QI>F%D;W)E<R(*"B,Z('-I9VYU<"YP:'`Z,C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N(@IM<V=S='(@(D\@4F5G:7-T;R!D92!5=&EL:7IA9&]R
M97,@97-TX2!I;F%C=&EV;RXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M-S(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#8*;7-G:60@(E5S97(@<&5R
M;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!U=&EL:7IA9&]R(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV."!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E
M<FYA;64B"FUS9W-T<B`B3F]M92!D92!5=&EL:7IA9&]R(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")/($YO
M;64@9&4@571I;&EZ861O<B!<(B5S7"(@:N$@97AI<W1E+B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM
M<V=S='(@(DYO;64@9&4@571I;&EZ861O<CHB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(DYO
M;64@9&4@571I;&EZ861O<CH@(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HR,3D*;7-G:60@(E5S97)S(@IM<V=S='(@(E5T:6QI>F%D;W)E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S
M(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5T:6QI>F%D;W)E<R!D;R!S:7-T
M96UA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B4F5P^F)L:6-A
M(&1O(%5Z8F5Q=6ES=.-O(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,#$@;&EB
M+U9&4R]F:6QE+G!H<#HQ.#@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D$@<&%S=&$@5D93(&[C;R!E>&ES=&4N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I
M;VXB"FUS9W-T<B`B075SZFYC:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM
M<V=S='(@(D%S(&QO8V%L:7IAY_5E<R!VX6QI9&%S(&5N8V]N=')A9&%S(&EN
M8VQU96TZ(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(E9A;&ED861E+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N(@IM<V=S='(@(E9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@9&5S
M=&4@:6YS=&%N=&4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M5F%L;W(@97AC961E(&\@8V]M<')I;65N=&\@;>%X:6UO(&1E("5S+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C0U(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C8W(&QI8B](;W)D92]&;W)M+G!H<#HR,S$U"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3(W"FUS9VED(")686QU97,B"FUS9W-T<B`B5F%L;W)E<R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3$P(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3@W"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B4&]S
M<^UV96P@=F%L;W)E<R!A(&5S8V]L:&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*
M;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,@IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:>%V96PB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO
M;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E
M9"!W:71H+B(*;7-G<W1R(")697)I9FEC8>?C;R!F86QH;W4@+2!E<W1A(&UE
M;G-A9V5M('!O9&4@=&5R('-I9&\@861U;'1E<F%D82XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R
M(")697)SXV\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS
M9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B0V]N=')O;&\@9&4@5F5R
M<_5E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D%L
M:6YH86UE;G1O(%9E<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*
M;7-G<W1R(")#86SG;R!697)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G
M<W1R(")697)T:6-A;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(DUU:71O
M($%L=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")297#Z8FQI8V$@
M4V]C:6%L:7-T82!D;R!6:65T;F%M92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I
M971N86UI=&$@*%9)4T-)22DB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.34Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B5FES=6%L:7IA<B`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*
M;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B5F5R
M('5M82!PX6=I;F$@97AT97)N82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HX,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*
M;7-G<W1R(")6:7-U86QI>F%R(&-O;6\@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("));&AA<R!6:7)G96YS($)R:73B
M;FEC87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R
M("));&AA<R!6:7)G96YS($%M97)I8V%N87,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")6:7-I8FEL
M:61A9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Q"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I;&ED861E.B`B"@HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED
M(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)
M=.%L:6$@=FEA(%--5%`B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B059)
M4R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"B,L('!H<"UF;W)M
M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+B(*;7-G<W1R(")!5$5.Q\-/(2$A(%)%34]602!/(%PB4T-225!4
M7"(@34%.54%,345.5$4@1$4@)7,N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&
M=71U;F$B"FUS9W-T<B`B5V%L;&ES(&4@1G5T=6YA(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"FUS9VED(")7
M87)N:6YG(@IM<V=S='(@(D%V:7-O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@Q('!O+W1R86YS;&%T:6]N+G!H
M<#HW,3$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<R-2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`V,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V.0HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3`W-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`Y-PHC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P
M-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3(S-0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(T-2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3(U,2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(W,0IM<V=I9"`B5V%R
M;FEN9SH@(@IM<V=S='(@(D%V:7-O.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(T
MJB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B
M5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0<F5V:7/C;R!D;R!496UP;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,34*;7-G:60@(E=E
M871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")$861O<R!M971E;W)O
M;/-G:6-O<R!F;W)N96-I9&]S('!O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G
M<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<V"FUS
M9VED(")796(@4VET92(*;7-G<W1R(")0X6=I;F$B"@HC.B!L:6(O2&]R9&4O
M36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V5M
M86YA;&UE;G1E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*
M;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0F5M+79I;F1A*&\I(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C4S"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B
M"FUS9W-T<B`B0F5M+79I;F1A*&\I(&$@)7,B"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0F5M
M+79I;F1A*&\I+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")/8VED96YT86P@
M*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G
M:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")/8VED96YT86P@
M*$E33RTX.#4Y+3$U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M(")386%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B475E(&%P;&EC8>?C;R!D979E
M(&\@)7,@;6]S=')A<B!A</-S(&$@96YT<F%D83\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B475A;"#I(&\@8V%R86-T97)E(&1E
M;&EM:71A9&]R/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(T
M"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@
M(E%U86P@Z2!O(&-A<F%C=&5R92!D92!C:71AY^-O/R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E%U
M92!F87-E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@
M(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BXB"FUS9W-T<B`B475E(%PB<&QU9VEN<UPB(&%C=&EV87(@<&%R82!A
M($5D:>?C;R!2:6-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(DQA
M<F=U<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R-`IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQA<F=U<F$@96T@=6YI9&%D97,@
M0U-3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B3&%R9W5R
M82!D;R!-96YU("5S(.`@97-Q=65R9&$@*'1E;2!E9F5I=&\@;F$@<'+S>&EM
M82!E;G1R861A*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S
M='(@(DQA<F=U<F$@9&$@=&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS
M9W-T<B`B56YI9&%D92!D92!L87)G=7)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R("),87)G=7)A.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C@*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B5F5N=&\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I
M9"`B5VEN9"!%87)L>2(*;7-G<W1R(")696YT;R!-871I;F%L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T
M<R(*;7-G<W1R(")696QO8VED861E(&1O('9E;G1O(&5M(&[S<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R(")6
M96YT;SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,P"FUS
M9VED(")7:6YD.B`B"FUS9W-T<B`B5F5N=&\Z("(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E-A8F5D;W)I
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#(*;7-G:60@(E=I
M<VAL:7-T<R(*;7-G<W1R("),:7-T87,@9&4@1&5S96IO<R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")4<F%B
M86QH;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7
M;W)K($%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@*$5M<')E9V\I(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O
M<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O;F4@*$5M<')E9V\I(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$Q-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)I
M=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E<RXB"FUS9W-T<B`B17-C<F5V
M96YD;R!A<G%U:79O(&1E(&%J=61A(&%C='5A;&EZ861O('!A<F$@)7,N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S,0IM<V=I9"`B6"U2968B
M"FUS9W-T<B`B4F5F97+J;F-I87,@8W)U>F%D87,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S(@IM<V=S='(@(E)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")5=&EL:7IAY^-O(&1E($-H
M879E($5X=&5N9&ED82!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M92(*;7-G<W1R(").;VUE($%L=&5R;F%T:79O(&1E(%-U:F5I=&\@6#4P
M.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(DED96YT
M:69I8V%D;W(@0VAA=F4@9&4@4W5J96ET;R!8-3`Y=C,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO
M;G,B"FUS9W-T<B`B17AT96YS]65S(%@U,#EV,R(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!02(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#8@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R(")!
M04%!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B36%P82!986AO;R$B"@HC
M.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB
M"FUS9W-T<B`B06YU86QM96YT92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@
M(DGI;65N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@X-0IM<V=I9"`B665S(@IM<V=S='(@(E-I;2(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHV"FUS9VED(")997,L
M($D@06=R964B"FUS9W-T<B`B4VEM+"!#;VYC;W)D;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)%<W3A(&5M($U/1$\@
M9&4@5$585"X@(%5S92!O(&)O=.-O(%L\/ET@<&%R82!T<F]C87(@<&%R82!O
M(&UO9&\@5DE354%,+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3(Y-PIM<V=I9"`B
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B3N-O(&5S=.$@
M875T96YT:6-A9&\N(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*
M;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(").XV\@<&]D92!T97(@;R!C87)A
M8W1E<F4@)UQ<)R!N;R!S974@;F]M92!C;VUP;&5T;RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3@U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-@IM<V=I
M9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*
M;7-G<W1R(").XV\@:6YT<F]D=7II=2!U;2!E;F1E<F7G;R!D92!C;W)R96EO
M(&5L96-T<O-N:6-O(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z
M,C<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N
M>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S
M<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(D[C;R!M87!E
M;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I=F\@:6UP;W)T861O('!A<F$@;W,@
M8V%M<&]S(&-O<G)E<W!O;F1E;G1E<R`B"B)E;2`E<RXB"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3(S"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N(@IM<V=S='(@(D%C86)O=2!D92!S86ER+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T
M:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"XB"FUS9W-T<B`B(@HB5&5M(&1E(&EN=')O9'5Z:7(@=6T@;OIM97)O
M(&1E('1E;&5M\W9E;"!VX6QI9&\L('/S(&-O;2!D[6=I=&]S+"!M87,@8V]M
M('5M("(*(B<K)R!O<&-I;VYA;"!P87)A(&\@<')E9FEX;R!I;G1E<FYA8VEO
M;F%L+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")496T@9&4@
M:6YT<F]D=7II<B!U;2!V86QO<B!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB
M5&5M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&+A<VEC;R!P87)A($1A
M=&%4<F5E('-E('%U:7-E<B!U<V%R("(*(E-U8G-C<FGG]65S(@H*(SH@;&EB
M+TAO<F1E+G!H<#HT,S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+B(*;7-G<W1R(")496T@9&4@8V]N9FEG=7)A<B!U;2!M96-A
M;FES;6\@8F%S92!P87)A(&\@5D93+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`B1&5V92!D97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D
M92!E;G9I87(@;R!R96QA=/-R:6\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(E1E
M;2!D92!I;G1R;V1U>FER(&\@55),(&1O(')E8W5R<V\@<75E(&5S=&$@;&EG
M8>?C;R!S92!R969E<F4B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R(")496T@9&4@<V5L96-C:6]N87(@=6T@<V5R=FED
M;W(@82!R96UO=F5R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS
M9W-T<B`B1&5V92!E<W!E8VEF:6-A<B!O('5T:6QI>F%D;W(@82!L:6UP87(N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")$979E(&5S<&5C
M:69I8V%R(&\@;F]M92!D;R!U=&EL:7IA9&]R(&$@<F5M;W9E<BXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"XB"FUS9W-T<B`B5&5M(&1E(&5S<&5C:69I8V%R(&\@;F]M92!D;R!U
M=&EL:7IA9&]R(&$@861I8VEO;F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T
M-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+B(*;7-G<W1R(")496T@9&4@97-P96-I9FEC87(@;R!U=&EL:7IA9&]R
M(&$@86-T=6%L:7IA<BXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2XB"FUS9W-T<B`B5&5M(&1E(&5S<&5C:69I8V%R(&$@86/GXV\@
M82!D97-E;7!E;FAA<BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HW,@IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E
M9V]R>2!N86UE+B(*;7-G<W1R(")496T@9&4@:6YT<F]D=7II<B!U;2!N;W9O
M(&YO;64@9&4@8V%T96=O<FEA+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@
M86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B5&5M(&1E(&9O<FYE
M8V5R('5M(&[Z;65R;R!D92!T96QE9F]N92!I=&%L:6%N;R(*"B,Z(&QI8B](
M;W)D92]!=71H+G!H<#HY,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E
M<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(D$@<W5A('-E<W/C;R`E<R!E>'!I<F]U+B!0;W(@9F%V;W(@96YT
M<F4@9&4@;F]V;RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D\@<V5U
M($5N9&5R9>=O(&1E($-O<G)E:6\@16QE8W1R\VYI8V\Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S
M.B(*;7-G<W1R(")/('-E=2!E;F1E<F7G;R!<(D1E.EPB(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D$@<W5A
M($EN9F]R;6'GXV\B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@HB3R!S974@96YD97)EYV\@25`@<&%R96-E
M('1E<B!M=61A9&\@9&5S9&4@;R!I;NUC:6\@9&$@<V5S<^-O("5S+B!087)A
M("(*(F=A<F%N=&ER(&$@<W5A('-E9W5R86[G82P@9&5V92!A=71E;G1I8V%R
M+7-E(&1E(&YO=F\N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")/(%-E=2!.;VUE(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.CD*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)/('-E
M=2!M96-A;FES;6\@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C
M;R!D92!U=&EL:7IA9&]R97,@;W4@97-T82`B"B)O<.?C;R!F;VD@9&5S86-T
M:79A9&$@<&]R(&%L9W5M(&]U=')O(&UO=&EV;RXB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.CD*;7-G:60@(B(*(EEO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB3R!S974@;65C86YI<VUO
M(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T82!L:7-T86=E;2!D92!U=&EL
M:7IA9&]R97,@;W4@97-T82`B"B)O<.?C;R!F;VD@9&5S86-T:79A9&$@<&]R
M(&%L9W5M(&]U=')O(&UO=&EV;RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3$Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB3R!S974@;F%V96=A
M9&]R('!A<F5C92!T97(@;75D861O(&1E<V1E(&\@:6[M8VEO(&1A('-E<W/C
M;R`E<RX@4&%R82!G87)A;G1I<B`B"B)A('-U82!S96=U<F%NYV$L(&1E=F4@
M875T96YT:6-A<BUS92!D92!N;W9O+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES(&9E871U<F4N(@IM<V=S='(@(D\@<V5U(&YA=F5G861O<B!NXV\@<W5P
M;W)T82!E<W1A(&9U;F-I;VYA;&ED861E+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB3R!S974@
M;F%V96=A9&]R(&[C;R!S=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O
M+B!0<F5S<VEO;F4@0V]N=')O;"\B"B)#;VUM86YD("L@4"!P87)A(&EM<')I
M;6ER+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#D*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(D9U<V\@:&]RX7)I;R!A
M8W1U86PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,`IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("))9&5N=&ED861E('!A
M9'+C;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED(")9
M;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B3F]M92!C;VUP;&5T;R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ-#4*;7-G:60@(B(*(EEO=7(@9V5T=&5X="!V
M97)S:6]N(&ES('1O;R!O;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA
M=&EV96QY+EQN(@HB3F]T(&%L;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D
M+B(*;7-G<W1R("(B"B)!('-U82!V97)SXV\@9&\@9V5T=&5X="#I(&1E;6%S
M:6%D;R!A;G1I9V$L(&[C;R!S=7!O<G1A;F1O(%!(4"!D92!F;W)M82`B"B)N
M871I=F$N($YE;2!T;V1A<R!A<R!C861E:6%S(&1E(&-A<F%C=&5R97,@<V5R
MXV\@97AT<F'M9&%S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,B"FUS9W-T<B`B02!S=6$@;F]V82!P86QA=G)A+7!A<W-E
M('!A<F$@)7,@Z3H@)7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U
M-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!<R!S=6%S
M(&]PY_5E<R!F;W)A;2!A;'1E<F%D87,@873I(&%O(&9I;F%L(&1E<W1A('-E
M<W/C;RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")!<R!S
M=6%S(&]PY_5E<R!F;W)A;2!A8W1U86QI>F%D87,N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970B"FUS9W-T<B`B02!S=6$@<&%L879R82UP87-S92!F;VD@
M<F5C<FEA9&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM
M<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@
M>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O
M<F0N(@IM<V=S='(@(B(*(D$@<W5A('!A;&%V<F$M<&%S<V4@9F]I(')E8W)I
M861A+"!V97)I9FEQ=64@;R!S974@8V]R<F5I;R!E;&5C='+S;FEC;R!E("(*
M(F5N=')E(&-O;2!A('-U82!N;W9A('!A;&%V<F$M<&%S<V4N(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T
M92!S97)V97)S.B(*;7-G<W1R(")/<R!S975S('-E<G9I9&]R97,@<F5M;W1O
M<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*
M=6=O<VSA=FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED("):86ER92(*;7-G<W1R("):86ER92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*
M;7-G<W1R("):XFUB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("):
M:6UB86)UZ2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B
M6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R(");17-C;VYD97(@5&5X=&\@0VET861O72(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C4V"FUS9VED(");4')O8FQE;2!297!O<G1=
M(@IM<V=S='(@(EM296QA=/-R:6\@9&4@4')O8FQE;6%S72`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");36]S=')A<B!497AT;R!#:71A
M9&\@+2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");36]S=')A<B!497AT;R!#:71A
M9&\@+2`E<R!L:6YH87-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YH
M82`E<R!D92`E<UTB"@HC.B!L:6(O2&]R9&4N<&AP.C$T-#$@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(E]!9&UI;FES=')AY^-O(@H*(SH@;&EB+V%P:2YP:'`Z,3,V"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]#;VYS;VQA(@H*(SH@;&EB+V%P:2YP:'`Z
M,3(T"FUS9VED(")?1&%T851R964B"FUS9W-T<B`BP7)?=F]R92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B7U)E;6]V97(@3&EN:&$B
M"@HC.B!L:6(O87!I+G!H<#HQ,38*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B
M7T=R=7!O<R(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](
M96QP(@IM<V=S='(@(D%?:G5D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A(%]);6%G96TB
M"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM
M<V=S='(@(E]%;G1R87(B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DP"FUS
M9VED(")?3&]G(&]U="(*;7-G<W1R(")?4V%I<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B
M7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]-;V1I9FEC87(@3&EG8>?C;R(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM
M<V=S='(@(E]/<.?U97,B"@HC.B!L:6(O87!I+G!H<#HQ,C`*;7-G:60@(E]0
M97)M:7-S:6]N<R(*;7-G<W1R(")?4&5R;6ES<_5E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I
M9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]296UO=F5R($QI9V'GXV\N
M+BXB"@HC.B!L:6(O87!I+G!H<#HQ,#@*;7-G:60@(E]3971U<"(*;7-G<W1R
M(")?0V]N9FEG=7)AY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")?5&%B;&4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@7U1A8F5L82(*"B,Z
M(&QI8B]A<&DN<&AP.C$Q,@IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]5=&EL
M:7IA9&]R97,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y,`IM<V=I9"`B
M861D<F5S<R!B;V]K(@IM<V=S='(@(F-O;G1A8W1O<R(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HW,3$*;7-G:60@(F%N(&5R<F]R(&AA<R!O8V-U<F5D.B(*
M;7-G<W1R(")O8V]R<F5U('5M(&5R<F\Z(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HX.#(*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(F-A;&5N9.%R:6\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(F-A
M;&UO(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.0IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R(")C;&EQ=64@87%U:2(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HT-#4@<&\O=')A;G-L871I;VXN<&AP.C4U,"!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-C$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-#D@
M<&\O=')A;G-L871I;VXN<&AP.C@Q,"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@W
M"FUS9VED(")D;VYE(@IM<V=S='(@(F9E:71O(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C4U,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@T('!O+W1R86YS;&%T
M:6]N+G!H<#HV,3,*(SH@<&\O=')A;G-L871I;VXN<&AP.C<W."!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#$R('!O+W1R86YS;&%T:6]N+G!H<#HX.3`*;7-G:60@
M(F9A:6QE9"(*;7-G<W1R(")F86QH;W4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R
M(")D:6UI;G5I;F1O(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@U.0IM
M<V=I9"`B9FEL92(*;7-G<W1R(")F:6-H96ER;R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,CD*;7-G:60@(F9O=6YD.B`B"FUS9W-T<B`B96YC;VYT<F%D
M;SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R
M(")D;R`E<R`H)7,I(.!S("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S.`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")R86IA9&%S
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM
M<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S,Q"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*
M;7-G<W1R(")I;65D:6%T;R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`B96T@;&EN:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(FQI;FAA<UTB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B17)R;R!M:VES;V9S(&-O;2!C\V1I9V\@)60@86\@
M8V]N<W1R=6ER($E33RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S0R"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,C@X('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR,#4*;7-G:60@(FYA;64B"FUS9W-T<B`B;F]M92(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HS-S@*;7-G:60@(FYO="!C:&%N9V5D(@IM<V=S='(@
M(G-E;2!A;'1E<F'G]65S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,0IM
M<V=I9"`B;F]T(&9O=6YD(@IM<V=S='(@(F[C;R!E;F-O;G1R861O(@H*(SH@
M;&EB+TAO<F1E+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B
M"FUS9W-T<B`B;N-O(&EM<&QE;65N=&%D82(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*
M;7-G<W1R(")A:6YD82!P;W(@:6UP;&5M96YT87(B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C@W-`IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")C861E<FYO
M(&1E(&YO=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P97)C
M96YT86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P[7AE:7,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM
M<V=I9"`B<FES:6YG(@IM<V=S='(@(G-U8FEN9&\B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.CDX"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S
M='(@(FUO<W1R87(@9&EF97)E;N=A<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*
M;7-G<W1R(")S;7,R96UA:6P@=FEA($A45%`B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")S<R(*;7-G<W1R(")S
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B97-TX79E;"(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.#DX"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B;&ES
M=&$@9&4@=&%R969A<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L
M;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z(@IM<V=S='(@(D\@9FEC:&5I<F\@
M4$\@<&%R82!O(&QO8V%L92`E<R!NXV\@97AI<W1E+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(FEN=')O9'5Z82!A('!A;&%V<F$M<&%S<V4@9'5A<R!V97IE<RP@<&%R82!C
M;VYF:7)M8>?C;R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N
M:69I8V%D;R(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED
M(")U;FYA;65D(@IM<V=S='(@(G-E;2!N;VUE(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C,W-0IM<V=I9"`B=7!D871E9"(*;7-G<W1R(")A8W1U86QI>F%D
M;R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@
M<V5L96-T(@IM<V=S='(@(G-E;&5C8VEO;F%D82!P96QO('5T:6QI>F%D;W(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED
M(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C0*;7-G:60@(G<Z(@IM<V=S='(@(E)E96YC
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W
M96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!O+VYB7TY/+G!O````````````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V-C4T,C8`,3`U,34T,S$P-C,`,#$V
M-#`S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@3F]R=V5G:6%N($AO<F1E(%1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H
M0RD@,C`P,2TR,#`R($AO<F1E(%!R;VIE8W0N"B,@3WES=&5I;B!3=&5I;6QE
M<B`\;WES=&5I;D!R97AT82YN970^+"`R,#`Q+@HC(%1O<G-T96EN(%,N($AA
M;G-E;B`\:'5L96)O97)`=&5C:&)E92YN;SXL(#(P,#(N"B,@06YD<F5A<R!'
M=6YL96EK<VMA87,@/&%N9')E87-`9W5N;&5I:W-K86%S+FYO/BP@,C`P,RX*
M(R!'96ER($\N($AO9V)E<F<@/&AO<F1E0'-K>61I=F5R+FYO/BP@,C`P-2X*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R
M9&4@,RXP+C1<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TP-2TQ."`Q
M,CHT,RLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3`U+3$X(#$T
M.C,W*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@1V5I<B!/+B!(;V=B97)G
M(#QH;W)D94!S:WED:79E<BYN;SY<;B(*(DQA;F=U86=E+51E86TZ($YO<G=E
M9VEA;B`H0F]K;6%L*2`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.0IM<V=I9"`B
M(@HB("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES(&-O;6UI="!M
M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RXB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4S"FUS9VED("(B"B(@("UA+"`M
M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE('1O('1H92!C;VUP
M96YD:75M+B!5<V5F=6P@=&]<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@
M(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E;G0@8G)A;F-H
M('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N97)A=&5D
M(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,3,*;7-G:60@(B(*(B`@+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H
M('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E
M7&XB"B(@("`@("`@("`@("`@("`@("`@('5S960N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HV.0IM<V=I9"`B(@HB("`M8RP@+2UC;VUP
M96YD:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C
M;VUP96YD:75M(&9I;&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!I
M;G-T96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T
M:&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV,R!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.#$@<&\O=')A;G-L871I;VXN<&AP.C@W"FUS
M9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H:7,@8V]M
M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U;'1<;B(*(B`@("`@
M("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE
M(&AO<F1E+W!O(&1I<F5C=&]R>2DN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,30*;7-G:60@(B`@+60L("TM9&5B=6<@("`@("`@4VAO
M=R!E<G)O<B!M97-S86=E<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RXB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4T"FUS9VED("(@
M("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N9&EU;2!I;B!T
M:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$Q-0IM<V=I9"`B("`M:"P@+2UH96QP("`@("`@("!3:&]W('1H:7,@
M:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#(@<&\O=')A;G-L871I;VXN<&AP.C8W('!O+W1R86YS;&%T:6]N+G!H
M<#HW-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY
M('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#<@<&\O=')A;G-L871I;VXN<&AP.C8Q('!O+W1R86YS;&%T:6]N+G!H
M<#HW.0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4*;7-G:60@(B`@+6PL("TM
M;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-0IM<V=I9"`B("`M;"P@+2UL;V-A
M;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-C@*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@
M;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,*
M;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.`IM<V=I9"`B(@HB("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C8R"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@
M0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#`*;7-G:60@
M(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F:6QE<R!O;FQY
M(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S8*;7-G:60@(B(*(B`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.#8*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@;VYL
M>2!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-3@*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<P"FUS9VED
M("(B"B(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R9V4@;F5W
M('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C8T('!O+W1R86YS;&%T:6]N+G!H<#HX
M,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@*;7-G:60@(B`@+6XL("TM;F\M8V]M
M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$*;7-G:60@(B`@+7,L("TM<W1A
M=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I<W1I8W,@:6X@
M82!L;V-A;"!F:6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3$V"FUS9VED("(@("UT+"`M+71E<W0@("`@("`@(%-H;W<@=&AE(&5X
M96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY=&AI;F<N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#4*;7-G:60@(B(*(B`@
M8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U<"!F<F]M('5N=')A
M;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RXB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P.`IM<V=I9"`B("!C;VUM:70@("`@("!#
M;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y"FUS9VED("(@(&-O;6UI
M="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#5E,@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3D*;7-G:60@(B(*
M(B`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F:6QE+B!7
M87)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE7&XB"B(@("`@("`@("`@("`@
M(&-U<G)E;G0@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P,`IM<V=I9"`B("!E>'1R86-T("`@("!'96YE<F%T92!0
M3R!T96UP;&%T92`H+G!O="D@9FEL97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HY.`IM<V=I9"`B("!H96QP("`@("`@("!3:&]W('1H
M:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`Q"FUS9VED("(B"B(@(&EN:70@("`@("`@($-R96%T92!O;F4@
M;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG.B!4
M:&ES7&XB"B(@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG
M(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`V"FUS9VED("(@(&UA:V4@("`@("`@($)U:6QD
M(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<*;7-G:60@
M(B(*(B`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,
M(&AE;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9%QN(@HB("`@("`@("`@
M("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@;F5X="!E>&5C=71I;VX@
M;V8@=7!D871E+6AE;'`N(%EO=5QN(@HB("`@("`@("`@("`@("!S:&]U;&0@
M;VYL>2!R=6X@;6%K92UH96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I
M<VEN9R!T:&5<;B(*(B`@("`@("`@("`@("`@:&5L<"!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`R"FUS9VED("(B"B(@(&UE
M<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@
M8W5R<F5N="!03R!T96UP;&%T92!F:6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`S"FUS9VED("(@('5P9&%T92`@("`@(%)U;B!E
M>'1R86-T(&%N9"!M97)G92!S97%U96YT+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`T"FUS9VED("(B"B(@('5P9&%T92UH96QP($5X
M=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N
M9VQI<V@@6$U,(&AE;'!<;B(*(B`@("`@("`@("`@("`@9FEL92!A;F0@;65R
M9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B(*;7-G<W1R("(B"B(@)B,Q-3$[("5S(&5R(&ML87(@9F]R(.4@=71F
M^')E('9E9&QI:V5H;VQD<V]P97)A<VIO;F5N92!S;VT@97(@=F%L9W0@(@HB
M;F5D96YF;W(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R!D
M86=E<B!S:61E;BDB"@HC.B!L:6(O2&]R9&4N<&AP.C$R.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H:'5R=&EG
M=&%S="`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H:6YN96X@
M)7,@9&%G97(I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-38*;7-G:60@
M(B`H=&]D87DI(@IM<V=S='(@(B`H:2!D86<I(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S-3@*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H:2!M
M;W)G96XI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-30*;7-G:60@(B`H
M>65S=&5R9&%Y*2(*;7-G<W1R("(@*&D@9^5R*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,30*;7-G:60@(B!A="`B"FUS9W-T<B`B(&1E
M;B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!O
M9R`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&)Y=&5S('=R:71T96XN(@IM<V=S='(@(B5D(&)Y=&5S
M('-K<F5V970N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M
M=&\M9&%T92(*;7-G<W1R("(E9"!A=B`E9"!O<'!F^')I;F=E<B!M87)K970@
M<V]M(&]P<&1A=&5R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM
M<V=S='(@(B5D+61A9V5R<R!V87)S96PB"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;F]T:6-E7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(%1I;"!I;F9O(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S(&%D;6EN:7-T
M<F%S:F]N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@
M1FEN9V5R<')I;G0B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M.#4W(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;B(*;7-G<W1R("(E<R!V961L:6ME:&]L9'-O<&5R87-J;VYE<B`M($)E
M:W)E9G1E;'-E(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C`Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(B5S(&EN<W1I;&QI;F=E<B(*"B,Z(&QI8B](;W)D
M92]!=71H+U-I9VYU<"YP:'`Z,C<V"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-I9VX@57`B"FUS9W-T<B`B)7,@<F5G:7-T<F5R:6YG(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S
M(&%V=&%L979I;&OE<B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HU.38@;&EB+U9&
M4R]F='`N<&AP.C8V-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B)7,@9FEN;F5S(&%L;&5R961E+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34W(&QI8B]";&]C:R]M971A<BYP:'`Z,38S
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0S(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S('#E("5S("5S(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@
M(B5S(&AA<B!K86YS96QL97)T("5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R
M("(E<R!H87(@8F5S=F%R="!E;B!F;W)E<W#X<G-E;"!O;2!I;F9O<FUA<VIO
M;B!A;F?E96YD92!L961I9R]O<'!T871T+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RXB"FUS
M9W-T<B`B)7,@:&%R('-V87)T('#E(&EN=FET87-J;VYE;B!T:6P@)7,N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(&AA<B!S96YD="!D96<@:6YF;W)M
M87-J;VX@;VT@;&5D:6<O;W!P=&%T="XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,C@W('!O+W1R86YS;&%T:6]N+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:7,@;F]T('=R:71A8FQE+B(*;7-G<W1R("(E<R!E<B!S:W)I
M=F5B97-K>71T970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@
M97(@<.5K<F5V9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71T
M97(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,S,Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@:6MK92!F=6YN970N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N
M;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER<W0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@9F]R97-P^'(@
M:6YF;W)M87-J;VX@;VT@;N5R(&1U(&5R(&QE9&EG+V]P='1A='0N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@
M)7,N(@IM<V=S='(@(B5S(&9O<F5S</AR(&1I;B!D96QT86=E;'-E('#E("5S
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@+2`E
M<R!A=B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@861D
M('1O("5S+B(*;7-G<W1R("(E<R#X;G-K97(@Y2!L96=G92!T:6P@)7,N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`R"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R
M92!O9B`E<RXB"FUS9W-T<B`B)7,@^&YS:V5R(.4@9VKX<F4@9&5G(&]P<&UE
M<FMS;VT@<.4@)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T
M;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM
M<V=S='(@(B5S(/AN<VME<B#E(&UO='1A(&1E;B!S:7-T(&]P<&1A=&5R=&4@
M:6YF;W)M87-J;VYE;B!O;2`E<RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDQ,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*
M;7-G<W1R(")!9&1R97-S96)O:R!F;W(@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDP-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(DMA;&5N9&5R(&9O<B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.#DV"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R(").;W1A=&)L;VMK(&9O<B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.3(P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B
M"FUS9W-T<B`B3W!P9V%V96QI<W1E(&9O<B`E<R(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@;&EB+TAO
M<F1E+T-,22YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(&5R(&EK:V4@970@
M9WEL9&EG('9A;&<N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HU.#(@
M;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HY.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T
M<GDN(@IM<V=S='(@(B<E<R<@97(@:6MK92!C;VYF:6=U<F5R="!I($AO<F1E
M(%)E9VES=&5R970N(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP.C$V,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"XB"FUS9W-T<B`B)7,@:6MK92!F=6YN970N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-PHC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)7,@8FQE(&QA
M9W0@=&EL(&=R=7!P97-Y<W1E;65T+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('=A<R!A9&1E
M9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G(&)L
M92!L86=T('1I;"!R971T:6=H971S<WES=&5M970N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G
M<W1R("(E<R!B;&4@:6MK92!O<'!R971T970Z("5S+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3@V(&QI8B]";&]C:R]M971A<BYP:'`Z,3DQ"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T
M<B`B)7,@<.4@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B+"!V87)I86)E;"!M96QL;VT@)7,@;V<@)7,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`U,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-CDQ"FUS9VED
M("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=F5L9R`M+2(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,S`Y('!O+W1R86YS;&%T:6]N+G!H<#HQ,S$Q"FUS
M9VED("(M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA
M="(*;7-G<W1R("(Q,B!4:6UE<G,@9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"!4
M:6UE<G,@9F]R;6%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*
M;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('1I;65R(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(\9V5T
M=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RY<;B(*(D]P96YI;F<@
M=&%G(&9O=6YD(&EN(&QI;F4@)60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3$W"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(D5N(&1A=&%B87-E
M:V]B;&EN9R!E<B!PY6MR979D(&9O<B!D96YN92!B;&]K:V5N+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,38V"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R(")%;B!F871A;"!F96EL(&AA<B!O<'!S=.5T="(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDT,0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B16X@;V9F96YT;&EG(%!'4"UN^&MK96P@97(@<.5K<F5V9"!F;W(@
MY2!K<GEP=&5R92!M96QD:6YG96XN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3$V-PIM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B16X@;V9F
M96YT;&EG(%!'4"UN^&MK96P@97(@<.5K<F5V9"!F;W(@Y2!V97)I9FES97)E
M('-I9VYE<G0@;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,#DX"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB16X@;V9F96YT;&EG(%!'4"UN
M^&MK96PL('!R:79A="!01U`M;OAK:V5L(&]G('!A<W-P:')A<V4@97(@<.5K
M<F5V9"!F;W(@Y2`B"B)D96MR>7!T97)E(&5N(&UE;&1I;F<N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-PIM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5N
M(&]F9F5N=&QI9R!01U`M;OAK:V5L+"!P<FEV870@4$=0+6[X:VME;"!O9R!P
M87-S<&AR87-E(&5R('#E:W)E=F0@9F]R(.4@(@HB<VEG;F5R92!E;B!M96QD
M:6YG+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@HB16X@;V9F96YT;&EG(%,O34E-12UN^&MK
M96PL('!R:79A="!3+TU)344M;OAK:V5L+"!O9R!P87-S<&AR87-E(&5R('#E
M:W)E=F0@(@HB9F]R(.4@9&5K<GEP=&5R92!E;B!M96QD:6YG+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#0Y"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB16X@;V9F96YT;&EG(%,O34E-12UN^&MK96PL('!R:79A="!3+TU)
M344M;OAK:V5L+"!O9R!P87-S<&AR87-E(&5R('#E:W)E=F0@(@HB9F]R(.4@
M<VEG;F5R92!E;B!M96QD:6YG+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,S@R"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI
M9R!3+TU)344M;OAK:V5L(&5R('#E:W)E=F0@9F]R(.4@:W)Y<'1E<F4@96X@
M;65L9&EN9RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(U
M"B,L(&9U>GIY"FUS9VED(")!32!286EN(@IM<V=S='(@(E)E9VX@<.4@9F]R
M;6ED9&%G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(V
M"B,L(&9U>GIY"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(E)E9VYB>6=E
M<B!PY2!F;W)M:61D86=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,C<*(RP@9G5Z>GD*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R(")3;OAB>6=E<B!PY2!F;W)M:61D86=E;B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`T"FUS9VED
M(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B
M"FUS9W-T<B`B3VT@9&5N;F4@961I=&]R96XB"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3VTN+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T
M"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B06)S;VQU='0@;F5D97)S="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*
M;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")!8G-O;'5T="!M:61T(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0P"FUS9VED
M(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")';V1K:F5N;B!F;W)E<W#X<G-E
M;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X
M,0IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B1V]D=&%T="(*"B,Z(&QI8B]6
M1E,O;75S<6PN<&AP.C(X-0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")4:6QG86YG(&YE:W1E="!V960@
M;W!P<F5T=&5L<V4@878@5D93(&MA=&%L;V<N(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3,X"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+B(*;7-G<W1R(")4:6QG86YG(&YE:W1E="!V960@;W!P<F5T=&5L<V4@
M878@5D93(&9I;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G
M:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B2V]N=&\@4&%S<V]R9"(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2V]N=&\@9G+X<V5T+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(D%C8V]U;G1I
M;F<B"FUS9W-T<B`B0F]K:&]L9&EN9R]!8V-O=6YT:6YG(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4Q"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8R-0IM<V=I9"`B06-T:6]N
M<R(*;7-G<W1R(")(86YD;&EN9V5R(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4T(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,V"B,Z('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHQ-"!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHQ-@IM<V=I9"`B061D(@IM<V=S='(@(DQE9V<@=&EL
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,30@861M:6XO9W)O=7!S+G!H<#HR
M,34*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("),96=G('1I;"!U
M;F1E<F=R=7!P92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#$@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HX,@IM<V=I9"`B061D($-H:6QD(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B3&5G9R!T:6P@=6YD97)R971T:6=H971E<B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B3&5G9R!T:6P@:&5R.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C`X(&%D;6EN+V=R;W5P<RYP:'`Z,C`Y"FUS9VED(")!9&0@3F5W($=R;W5P
M(@IM<V=S='(@(DQE9V<@=&EL(&YY(&=R=7!P92(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-S`@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW,0IM<V=I
M9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(DQE9V<@=&EL(&YY(')E
M='1I9VAE="(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@
M=&\@)R5S)R(*;7-G<W1R("),96=G('1I;"!E;B!U;F1E<F=R=7!P92!T:6P@
M)R5S)R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O("<E<R<B"FUS9W-T<B`B3&5G9R!T:6P@
M=6YD97)R971T:6=H970@=&EL("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(DQE9V<@=&EL(&YY
M(&)R=6ME<CHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(Y"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(DQE9V<@=&EL(&MO
M;&]N;F4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,U
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B3&5G9R!T:6P@;GEE
M(&UE9&QE;6UE<B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S
M"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("),96=G('1I;"!P87(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R
M("),96=G('1I;"`E<R!M96YY96X@<V]M($UO>FEL;&$@4VED96)A<B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8S,0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S<*;7-G:60@
M(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(DQE9V<@=&EL(&D@
M;6EN(&MA;&5N9&5R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HW-`IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B
M3&5G9R!T:6P@:2!A9&1R97-S96)O:SHB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C@Q"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B
M;V]K(@IM<V=S='(@(DQE9V<@=&EL(&D@;6EN(&%D9')E<W-E8F]K(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(DQE
M9V<@=&EL(&)R=6ME<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("4B"B)S+B(*;7-G<W1R("(B"B),82!T:6P@)R5S)R!I('-Y<W1E;65T+"!M
M96X@:W5N;F4@:6MK92!L96=G92!T:6P@96MS=')A(')E9VES=')E<FEN9W-I
M;F9O.B`E(@HB<RXB"@HC.B!S:6=N=7`N<&AP.C0V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+B(*;7-G<W1R("),82`G)7,G('1I;"!S>7-T96UE="X@1'4@:V%N
M(&QO9V=E(&EN;B!NY2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.34V"FUS
M9VED(")!9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ(@IM<V=S='(@
M(DQA('1I;"!N>64@9FEL97(@:2!R97!O<VET;W)Y.B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHT"FUS9VED(")!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(DUU;&EG:&5T(&9O<B#E(&QE9V=E('1I
M;"!N>64@8G)U:V5R92!E<B!D96%K=&EV97)T+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#,X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<V"FUS
M9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`B061R97-S92!";VLB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3<*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F5R("T@<V5T="!R
M971T:6=H971E<B!F;W(@86YD<F4@8G)U:V5R92(*"B,Z(&%D;6EN+VEN9&5X
M+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A<VIO;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#8*;7-G:60@(D%D<R(*;7-G
M<W1R(")296ML86UE<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B06QG97)I82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q
M,`IM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!
M;&EG;B(*;7-G<W1R(")*=7-T97)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G
M<W1R(")*=7-T97)I;F<Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W
M"FUS9VED(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$Q."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED
M(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")!;&QE(&%U=&5N
M=&ES97)T92!B<G5K97)E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI
M;B]G<F]U<',N<&AP.C(Q,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")!
M;&QE($=R=7!P97(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,S@@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-`IM<V=I9"`B06QL(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(D%L;&4@<F5D9&EG:&5T97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!
M;&P@9F]U<B!S:61E<R(*;7-G<W1R(")!;&QE(&9I<F4@<VED97(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@U-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S(@IM<V=S='(@(E1I;&QA='0@9FQE<F4@861R97-S97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(S"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")4:6QL871T(&5N
M9')I;F<@878@9F]R;6%T970@<.4@;G5M;65R97)T92!L:7-T97(_(@H*(SH@
M;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-#`S"FUS9VED(")!;')E861Y
M(&5X:7-T<R(*;7-G<W1R(")%:W-I<W1E<F5R(&%L;&5R961E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R,@IM<V=I9"`B06QT97)N871E($E-4U`@
M3&]G:6XB"FUS9W-T<B`B06QT97)N871I=B!)35-0($QO9VEN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Y-@IM<V=I9"`B06QT97)N871E($E-4U`@
M4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I=G0@24U34"!P87-S;W)D(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X.`IM<V=I9"`B06QT97)N871E
M($E-4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N871I=G0@24U34"!B<G5K
M97)N879N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G
M:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L=&5R;F%T
M:78@92UP;W-T(&%D<F5S<V4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")!;'1E<FYA
M=&EV92!M86QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z
M(@IM<V=S='(@(D%L=&5R;F%T:78@=&5K<W0Z(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B06UE<FEC86X@
M4V%M;V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HY
M-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-PIM<V=I9"`B06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")%;B!U;&]V;&EG('9E
M<F1I('9A<B!O<'!G:71T+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$R,`IM<V=I9"`B
M06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYY;2!0<F]X>2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS
M9W-T<B`B4W9A<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS,"!L:6(O2&]R
M9&4O0FQO8VLO54DN<&AP.C4Y"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(E!R;V=R
M86TB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`B4')O9W)A;6QI<W1E(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$S,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A
M9'DN(@IM<V=S='(@(E!R;V=R86UM970@97(@:VQA<G0N(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD
M(%-H87)E<R(*;7-G<W1R(")/<'!D871E<B!O9W/E(')E:W5R<VEV="!N961O
M=F5R(&9O<B!U;F1E<FUA<'!E<B]F:6QE<B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C,S"FUS9VED(")!<'!R;W9E(@IM<V=S='(@
M(D=O9&MJ96YN(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U
M-PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")/;71R96YT;&EG
M('-T^')R96QS92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X
M"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W,0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8R(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*
M;7-G<W1R(")&:6QS=/AR<F5L<V4@<.4@87)K:79E="(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8Q(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B07)K:79N879N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHY"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D5R
M(&1U(%-)2TM%4B!PY2!A="!D=2!V:6P@9FIE<FYE(')E9VES=')E<FEN9W-F
M;W)E<W#X<G-E;&5N(&9O<B`E<S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@9&5L971E("<E<R<@86YD(&%N>2!S=6(M9W)O
M=7!S/R(*;7-G<W1R(")%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('-L971T
M92`G)7,G(&]G(&1E;G,@=6YD97)G<G5P<&5R/R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<R"FUS9VED(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*
M;7-G:60@(D%R="(*;7-G<W1R(")+=6YS="(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D%R=6)A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I:2!K=6YS
M="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,34*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")"92!O
M;2!B96MR969T96QS92!F^'(@9VIE;FYO;6;X<FEN9R!A=B!V961L:6ME:&]L
M9'-O<&5R87-J;VYE<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,#DX"FUS
M9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B2V]L;VYN96%N=FES
M;FEN9R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C$V-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR
M-#D*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S$X
M"FUS9VED(")!='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!R97!L>2!T
M;R!A(')E<75E<W0@>6]U('-E;G0B"FUS9W-T<B`B5F5D;&%G="!I('-V87)E
M="!E<B!E;B!I0V%L96YD87(@9FEL(&9O<B!E;B!F;W)E<W#X<G-E;"!D=2!S
M96YD=&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<U"FUS9VED(")!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B1F]R
M<_AK=&4@Y2!S;&5T=&4@96X@9W)U<'!E('-O;2!I:VME(&5K<VES=&5R97(N
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HS.`IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B1F]R<_AK=&4@Y2!S;&5T=&4@96X@<F5T=&EG:&5T('-O;2!I:VME(&5K
M<VES=&5R97(N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.3@*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")&;W)S^&MT92#E(')E9&EG97)E(&5N(')E='1I9VAE="!S;VT@
M:6MK92!E:W-I<W1E<F5R+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+B(*;7-G<W1R(")&;W)S^&MT92#E(')E9&EG97)E(&5N(&1E;'0@<F5S
M<W5R<R!S;VT@:6MK92!E:W-I<W1E<F5R+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4W-PIM<V=I9"`B071T96YD965S(@IM
M<V=S='(@(D1E;'1A9V5R92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R
M:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B075S=')I82(*;7-G<W1R
M("+8<W1E<G)I:V4B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C$V
M,PIM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ($MA;B!I:VME(&9I
M;FYE(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E;BXB"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,W"FUS9VED(")!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z($)A8VME;F0@:6YN96AA<B!I:VME(&[X9'9E
M;F1I9R!F=6YK<VIO;F%L:71E="XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U
M<RYP:'`Z,3(T"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($MA;B!I
M:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E;BXB"@HC
M.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C0P"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*(D%U=&A?9G1P.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!&
M5%`@=71V:61E;'-E;BX@2V]M<&EL97(@4$A0(&UE9"`M+2(*(F5N86)L92UF
M='`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C@*;7-G:60@(D%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VEM87`Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD
M:6=E($E-05`@=71V:61E;'-E;BXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U
M+G!H<#HU,PIM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@2V%N(&EK:V4@
M9FEN;F4@9&5N(&[X9'9E;F1I9V4@:W)B-2!U='9I9&5L<V5N+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C8Q"FUS9VED(")!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]L9&%P.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!,1$%0('5T
M=FED96QS96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3@Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T
M<B`B075T:%]L9&%P.B!+=6YN92!I:VME(&QE9V=E('1I;"!B<G5K97(@)7,N
M(%-E<G9E<F5N('-A.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!+=6YN92!I:VME
M(&9J97)N92!B<G5K97)E;B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C(X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($MU;FYE
M(&EK:V4@;W!P9&%T97)E(&)R=6ME<B`E<R(*"B,Z(&QI8B](;W)D92]!=71H
M+VUC86PN<&AP.C4P"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!+86X@
M:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!-0T%,('5T=FED96QS96XN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV-0IM<V=I9"`B075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?<VUB875T:#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E
M;F1I9V4@<VUB875T:"!U='9I9&5L<V5N+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960B"FUS9W-T<B`B075T96YT:7-E<FEN9R!F96EL970B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8Y(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")!=71E;G1I<V5R:6YG
M(&9E:6QE="X@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$X
M,0IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BXB"FUS9W-T<B`B075T96YT:7-E<FEN9R!N96MT970@878@4D%$2553
M('1J96YE<BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#`P"FUS9VED(")!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T
M96YT:7-E<FEN9R!M;W0@1E10('1J96YE<F5N(&9E:6QE="XB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C@S"FUS9VED(")!=F%I;&%B;&4@9FEE
M;&1S.B(*;7-G<W1R(")4:6QG:F5N9V5L:6=E(&9E;'0Z(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C$T"FUS9VED(")!=V%I
M=&EN9R!297-P;VYS92(*;7-G<W1R(")696YT97(@<.4@<W9A<B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"!%>&-U
M<V5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")"86MG<G5N
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0F%K9W)U;FYS
M9F%R9V4B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")&96EL(&ME<F)E<F]S
M('!A<W-O<F0N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G
M:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B1F5I;"!K97)B
M97)O<R!B<G5K97)N879N+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W,PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"87)B861O
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,PIM<V=I
M9"`B0F%R92(*;7-G<W1R(")";&%N:R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I
M<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S96MA=&%L;V<@
M9F]R(&=R869I:VL@)R5S)R!B;&4@:6MK92!F=6YN970N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED
M(")"87-E;&EN92(*;7-G<W1R(")'<G5N;FQI;FIE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0F5L87)U
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&EG82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"96YI;B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D)H=71A;B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Q-`IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B0G5R<V1A9R(*"B,Z(&QI
M8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D)L;VMK(%PB)7-<(B!A=B!P<F]G<F%M;65T
M(%PB)7-<(B!B;&4@:6MK92!F=6YN970N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R
M(")";&]K:R!I;FYS=&EL;&EN9V5R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(D)L;VMK
M('1Y<&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B1F5T(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]L:79I
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@V
M"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B0F]K;65R:V5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B0F]R9&5R(@IM<V=S='(@(E)A;6UE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H
M:6-K;F5S<SHB"FUS9W-T<B`B4F%M;65T>6MK96QS93HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED
M(")";W)D97)S(@IM<V=S='(@(E)A;6UE<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)O<VYI82!A;F0@
M2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D)E9V=E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0F]T
M<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M0G5N;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0G)A>FEL(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0G)U;F5I($1A<G5S<V%L
M86TB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8V,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE
M("5S+BXN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0G5I;&1I;F<@;&]C86QE("5S+BXN("(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(E!U;FMT;&ES=&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"=7)K
M:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDW"FUS9VED(")#35,B
M"FUS9W-T<B`B0TU3(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8R,0IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0
M;VEN=',B"FUS9W-T<B`B0U),($1I<W1R:6)U<VIO;G-P=6YK=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(D5G96YS
M:V%P97(@9F]R(&-?96QL92XN+B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T
M,PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`Y"FUS9VED(")#86QM(@IM<V=S
M='(@(E-T:6QL92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O
M;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B2V%N(&EK:V4@;G5L;'-T:6QL92!P87-S;W)D(&%U=&]M871I<VLL(&MO
M;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C(T,2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C,Q,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<R(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@24U!4"!T:F5N
M97)E;CH@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$T('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$W"FUS9VED(")#86YC96PB"FUS9W-T<B`B079B<GET(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")!=F)R>70@<')O8FQE;7)A
M<'!O<G0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C8Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA
M;B!I:VME('-L971T92!F:6QE;B!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#<*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4S"FUS
M9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA;B!I:VME(&9I;FYE(&5N('1E;7`M:V%T86QO9RXB"@HC.B!L:6(O
M5D93+TE33U=R:71E<BYP:'`Z.3<*;7-G:60@(D-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B2V%N(&EK
M:V4@9F]R='-E='1E('5T96X@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z,C8U"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK
M:V4@<VQE='1E(&MA=&%L;V=E;B!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A
M=&%4<F5E+G!H<#HQ,3(@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3<X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4L("5D(&)A<FX@
M96MS:7-T97)E<BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU
M,#0*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M(@HB<W1O<F5D+B(*;7-G<W1R("(B"B)+86X@:6MK92!E;F1R92!R96MK96;X
M;&=E;BP@86YT86QL970@;W!P9OAR:6YG97(@=F%L9W0@9F]R(&]M<V]R=&5R
M:6YG("(*(G-T96UM97(@:6MK92!M960@86YT86QL970@;&%G<F5D92!O<'!F
M^')I;F=E<BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q.`IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BXB"FUS9W-T<B`B2V%N(&EK:V4@<V5N9&4@;65L9&EN9V5N('1I
M;"!D970@<W!E<VEF:7-E<G1E(&YU;6UE<F5T+B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-A<&4@5F5R
M9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")5
M=&1R86<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A
M=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R:65R(&]G(&5T
M:6ME='1E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@W"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-PIM<V=I9"`B
M0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED
M(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B16=E;G-K87!E<B!F;W(@8V5L
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("),=69T(')U;F1T
M(&EN;FAO;&0@878@8V5L;&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T
M:65S(@IM<V=S='(@(D5G96YS:V%P97(@9F]R(&-E;&QE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E
M;&P@<W!A8VEN9SHB"FUS9W-T<B`B3'5F="!R=6YD="!C96QL96XZ(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C8*;7-G:60@(D-E;&QP:&]N92(*;7-G
M<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M-`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(E-E;G1E<B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-E;G1R
M86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HW,C,*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B1&5T
M86QJ97(@9F]R('-E<G1I9FEK870B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8R,`IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T
M<B`B4F5T=&YI;F=S;&EN:F5R(&9O<B!S97)T:69I:V%T(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")#
M:&%D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4Y-@IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(D]R
M9'-T>7)E<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@(D-H86YG92(*
M;7-G<W1R(")%;F1R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(B(*(D5N9')E(&YA=FX@;V<@861R97-S92!S;VT@
M;6]T=&%K97)E('-E<B!NY7(@9&4@;&5S97(@;V<@<W9A<F5R('#E('!O<W1E
M;B!D:6XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")496=N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")3:F5K7VL@;&EN
M:RXN+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI
M;F,Z,3,*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH
M<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@
M(E9E;&<@9&4@;W!E<F%S:F]N96YE(&1U('9I;"!U=&;X<F4@;N4N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0VAI;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-PIM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR.#(*
M;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E9E;&<@971T('!A
M<W-O<F0B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(X,0IM<V=I
M9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B5F5L9R!E='0@8G)U:V5R
M;F%V;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0U,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV
M,C8*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(E9E;&<@:&%N
M9&QI;F<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`IM<V=I9"`B
M0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")696QG(&AV
M;W)D86X@9'4@=FEL('9I<V4@9&%T;V5R.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R(")696QG('-T:6P@<.4@;&ES=&5T>7!E("AF;W(@;G5M;65R97)T92!L
M:7-T97(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O5D93+G!H<#HV-34@;&EB+TYE="]335,N<&AP.C,Q,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B2VQA<W-E9&5F:6YI<VIO;B!F;W(@)7,@8FQE(&EK:V4@
M9G5N;F5T+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE86YI;F<@=7`@4$\@9FEL97,@9F]R(&UO9'5L92`E
M<RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L96%N:6YG('5P(&QO8V%L92`E<RXN+B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R
M.`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2VQA<G0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-
M4T]F9FEC92!T86=S(@IM<V=S='(@(D9J97)N($U33V9F:6-E('1A9W,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B1FIE<FX@
M8G)U:V5R.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ-@IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")&:F5R;B!B<G5K97(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-PIM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D9J97)N(&)R=6ME<F1A=&$B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:VL@9F]R(.4@
M9F]R='-E='1E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#8*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI
M8VMA=&5L;"!V:6$@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@
M5VEN9&]W(@IM<V=S='(@(DQU:VL@=FEN9'4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(T,@IM<V=I9"`B0VQO=61S(@IM<V=S='(@(E-K>65R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R.0IM<V=I9"`B0VQO=61Y
M(@IM<V=S='(@(E-K>65T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHT"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E-LY2!S86UM
M96X@<VED96QI;FIE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S
M(@IM<V=S='(@(E-A;6UE;G-LY71T(')A;6UE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V]L;VUB:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D9A
M<F=E(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y-R!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDX"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-S(@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHU,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHU,@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV.`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S
M='(@(D9A<F=E=F5L9V5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S4*
M;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B1F%R9V5V86QG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*
M(RP@9G5Z>GD*;7-G:60@(D-O;',Z(@IM<V=S='(@(DMO;&]N;F5R.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.3,P"FUS9VED(")#;VQU;6X@=&ET;&5S
M(@IM<V=S='(@(DMO;&]N;F4M=&ET;&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(X.0IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(E1E9VYE<V5R
M:65R(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(DMO;6UA;F1O(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P
M"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DMO;6UA;F1O=FEN9'4B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S@*;7-G:60@(D-O;6UA;F0@;W!T
M:6]N<SHB"FUS9W-T<B`B5F%L9R!F;W(@:V]M;6%N9&\Z(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.CDW"FUS9VED(")#;VUM86YD<SHB"FUS9W-T<B`B2V]M
M;6%N9&]E<CHB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HS.3D*;7-G
M:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M;65N=&%R(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.CDY-0IM<V=I9"`B0V]M;6ET=&EN9SHB"FUS9W-T<B`B4VIE
M:VL@:6YN.B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DP"FUS
M9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(")686YL:6<@;F%V;B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED
M(")#;VUO<F]S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0R"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D9I<FUA
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-CDW
M"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B1F5R9&EG(@H*(SH@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E>'0O
M1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP
M:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;7!O<V4@365S<V%G92`H
M)7,I(@IM<V=S='(@(E-K<FEV(&UE;&1I;F<@*"5S*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(D1A
M=&%M87-K:6YE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0W"FUS9VED
M(")#;VYD:71I;VYS(@IM<V=S='(@(E9I;&OE<B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C@Y"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M(@IM<V=S='(@(D9O<G-K:F5L;&5R(&D@:6YN<W1I;&QI;F=E;F4B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(U"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&YE961S('5P9&%T:6YG+B(*;7-G<W1R("));FYS=&EL;&EN9V5R(&)E:/AV
M97(@;W!P9&%T97)I;F<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.CDY
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")+
M;VYF:6=U<F5R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS-PIM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")"96MR
M969T('!A<W-O<F0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#8@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q.0IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960N(@IM<V=S='(@(E1I;&MO8FQI;F<@;6ES;'EK=&5S+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#8@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q.0IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960Z("(*;7-G<W1R(")4:6QK;V)L:6YG(&UI<VQY:W1E<SH@(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDS"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(DMO8FQI;F=E;B!T:6P@9&5N(&]F9F5N=&QI9V4@;OAK:V5L=&IE;F5R96X@
M9F5I;&5T+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")+;V)L
M:6YG96X@=&EL(&1E;B!O9F9E;G1L:6=E(&[X:VME;'1J96YE<F5N(&9E:6QE
M="X@Q7)S86LZ("5S("@E<RDB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-SDT"FUS
M9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")+;V)L:6YG96X@=&EL($944"!T:F5N97)E;B!M:7-L>6MT97,N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU-@IM<V=I9"`B0V]N
M=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1E;F4@8FQE(&QA9W0@=&EL(&%D<F5S
M<V5B;VME;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Y
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1E;G1S(&]F("<E<R<B"FUS9W-T<B`B26YN:&]L9"!I("<E<R<B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN
M=64B"FUS9W-T<B`B1F]R='-E='0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;V]K($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#
M;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM
M<V=S='(@(DMO<&EE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@
M(DMO<&EE<B!V86QG="!O;7+E9&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y:6YG("5S('1O("5S(@IM
M<V=S='(@(DMO<&EE<F5R("5S('1I;"`E<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-O<W1A(%)I8V$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO
M="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VME(%!'
M4"UK<GEP=&5R92!M96QD:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@4$=0+7-I9VYE<F4@;65L9&EN9R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#$Q"FUS9VED(")#;W5L9"!N;W0@
M4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK92!K
M<GEP=&5R92!M96QD:6YG96X@;65D(%,O34E-12XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C0X-0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK:V4@<VEG;F5R92!M96QD
M:6YG96X@;65D(%,O34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!L96=G92!T:6P@
M:V]N=&%K=#H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,3,*
M;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(")4:6QK;V)L:6YG('1I;"!,1$%0+7-E<G9E<B!F96EL970N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-"!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK
M92!S:F5K:V4@=&EL9VIE;F=E;&EG(&MR961I='0N("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,B"FUS
M9W-T<B`B2VQA<G1E(&EK:V4@Y2!K;V)L92!T:6P@=&IE;F5R96X@)R5S)R!V
M960@8G)U:R!A=B!&5%`Z("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O<'D@)7,@=&\@
M)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!K;W!I97)E("5S('1I;"`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!L86=E(&1I<W1R:6)U<VIO;G-L
M:7-T92X@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@Q('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#8U"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.B(*;7-G
M<W1R(")+=6YN92!I:VME(&]P<')E='1E(&QO8V%L92!K871A;&]G(&9O<B!L
M;V-A;&4@)7,Z(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R-@IM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@9&5K<GEP=&5R92!01U`@;65L9&EN9RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4T,`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DMU;FYE(&EK:V4@9&5K<GEP=&5R
M92!3+TU)344@;65L9&EN9RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C4P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2VQA<G1E(&EK:V4@Y2!S;&5T
M=&4@:V]N=&%K="X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DML87)T92!I:VME
M(.4@<VQE='1E(&1I<W1R:6)U<VIO;G-L:7-T92X@)7,B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S
M='(@(DMU;FYE(&EK:V4@<VQE='1E('-E='5P(&]P<&=R861E<FEN9W-S8W)I
M<'0@)R5S)RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y.2!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3D*;7-G:60@(D-O=6QD(&YO="!D
M971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G
M<W1R(")+=6YN92!I:VME(&9I;FYE(&UO='1A:V5R<R!E+7!O<W0@861R97-S
M92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@X"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*
M;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&AE;&4@861R97-S96)O:V5N
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,3`*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B2W5N;F4@:6MK92!U="!H96QE(&1I<W1R:6)U<VIO;G-L
M:7-T96XN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0V
M,0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT
M92!U="!H96QE(&QI<W1E;B!M960@9&ES=')I8G5S:F]N<VQI<W1E<BXB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8Y
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2`G)7,G+B(*;7-G<W1R(")+=6YN92!I:VME(&QA<W1E(&EN;B!S=')A=&5G
M:2`G)7,G+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$Q,0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!O
M<'!R971T92!K871A;&]G96X@)R5S)RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW,C`*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N
M=&4@=70@;V9F96YT;&EG(&[X:VME;"!F<F$@;OAK:V5L=&IE;F5R96XN(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C<P,B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,U-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92#E
M<&YE("5S+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+B(*;7-G<W1R(")+=6YN92!I:VME
M(.5P;F4@)R5S)R!F;W(@<VMR:79I;F<N(@H*(SH@;&EB+TAO<F1E+TUA:6YT
M96YA;F-E+G!H<#HT,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B2V%N
M(&EK:V4@Y7!N92!-86EN=&5N86YC95]487-K+6UO9'5L96X@)7,B"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92#E<&YE(&MA=&%L;V=E;B`G
M)7,G+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DMU;FYE(&EK
M:V4@;&5S92`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U
M"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@HB2W5N;F4@:6MK92!N=6QL<W1I;&QE('!A<W-O<F1E="!F
M;W(@9&5N(&9O<F5S<'5R=&4@8G)U:V5R96XN($YO96X@96QL97(@86QL92`B
M"B)D971A;&IE;F4@97(@=7)I:W1I9V4N($9O<G/X:R!I9VIE;B!E;&QE<B!K
M;VYT86MT(&%D;6EN:7-T<F%T;W)E;B!H=FES(&1U("(*(G1R96YG97(@>71T
M97)L:6=E<F4@:&IE;'`N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Q."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Y
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#8@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,SDX"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@=70@04-,(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&%D<F5S<V5B;VLN("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@=70@9&ES
M=')I8G5S:F]N<VQI<W1E+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B2W5N
M;F4@:6MK92!H96YT92!U="!D:7-T<FEB=7-J;VYS;&ES=&4N("5S(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(V"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,S`*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S
M97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT
M92!U="!I;F9O<FUA<VIO;B!O;2!T:F5N97)E;G,@9G5N:W-J;VYA;&ET971E
M<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W5N;F4@:6MK
M92!R979E<G1E<F4@:V]N9FEG=7)A<VIO;F5N92XB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@)R5S)RXB"FUS9W-T<B`B
M2W5N;F4@:6MK92!F:F5R;F4@:V%T86QO9V5N("<E<R<N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!L86=R92`E<R!K;VYF:6=U<F%S:F]N+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G
M<W1R(")+=6YN92!I:VME(&QA9W)E(&5N(&)A8VMU<"!K;VYF:6=U<F%S:F]N
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G<F4@96X@8F%C:W5P(&-O;F9I
M9W5R87-J;VXZ("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z("<E<R<N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G
M<F4@<V5T=7`@;W!P9W)A9&5R:6YG<RUS8W)I<'1E="!T:6PZ("<E<R<N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=R92!B86-K=7`@:V]N
M9FEG=7)A<VIO;G-F:6QE;B`E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S
M92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M(@IM<V=S='(@(B(*(DMU;FYE(&EK:V4@;&%G<F4@:V]N9FEG=7)A<VIO;G-F
M:6QE;B`E<RX@1'4@:V%N(&5N=&5N(&)E;GET=&4@9&5G(&%V(&5N(&%V("(*
M(FUU;&EG:&5T96YE(&9O<B#E(&QA9W)E(&1A=&$@=&EL8F%K92!T:6P@)7,@
M96QL97(@:V]P:65R92!K;V1E;B!U;F1E<B`B"B)M86YU96QT('1I;"`E<RXB
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C,*;7-G:60@(D-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I
M:VME('5T9OAR92!S^&L@<.4@3$1!4"!T:F5N97)E;BXB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK("<E<R<N(@IM<V=S
M='(@(DMU;FYE(&EK:V4@9FIE<FYE("<E<R<N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMU;FYE(&EK
M:V4@;W!P9&%T97)E(&MO;G1A:W0N("5S(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+
M=6YN92!I:VME(&]P<&1A=&5R92!D:7-T<FEB=7-J;VYS;&ES=&5N+B`E<R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@
M)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!S:W)I=F4@:V]N9FEG=7)A<VIO;B!F
M;W(@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4V"FUS
M9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R(")+=6YN92!I:VME
M(&9I;FYE($UO>FEL;&$@4VED96)A<BX@4VIE:VL@870@9&5N(&5R(.5P96XN
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9&XG="!G:79E('5S97(@)R5S)R!T:&4@
M9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`G)7,G.B`E<R(*;7-G
M<W1R(")"<G5K97)E;B`G)7,G(&)L92!G:71T(&;X;&=E;F1E(')E='1I9VAE
M=&5R('1I;"!M87!P96X@)R5S)SH@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30Q-@IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E1A;'0@=&5K
M<W0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B
M0V]U;G1R>2(*;7-G<W1R("),86YD(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)S97(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDW"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$*;7-G:60@(D-R96%T92(*;7-G<W1R(")/<'!R971T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8W"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D]P<')E='0@96X@
M;&EN:R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.#D*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B3W!P<F5T="!E
M;B!N>2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-0IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D]P<')E='0@=6YD
M97)M87!P97(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S8@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HR,C(*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B4F5T=&EG:&5T97(@9F]R(&5I97(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(Q-0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM
M<V=S='(@(DMR961I='1K;W)T;G5M;65R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(D-R;V%T:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@4&AA<V4B"FUS9W-T<B`B1VIE
M;&1E;F1E(&9A<V4B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO
M8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")'
M:F5L9&5N9&4@=&ED(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R(")':F5L9&5N9&4@55),(&5R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S
M='(@(D=J96QD96YD92!VYG(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,S"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(D=J96QD96YD92!U='-I:W1E<CH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*
M;7-G<W1R(")':F5L9&5N9&4@<W1I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")4:6QP87-S(&]P
M<&=A=F5R('-O;2!K:OAR97,@=F5D(&EN;FQO9V=I;F<@=&EL("5S+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DML:7!P('5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R(")+;&EP<"!U="!V86QG="!O;7+E9&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B2WEP<F]S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S@*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C,@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*
M(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HS.`IM<V=I9"`B1&%I;'DB
M"FUS9W-T<B`B1&%G;&EG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0R,PIM<V=I9"`B1&%T82(*;7-G<W1R(")$871A(@H*(SH@861M:6XO9&%T
M871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@
M(D1A=&%4<F4@=71F;W)S:V5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M.#(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S<*;7-G:60@
M(D1A=&4B"FUS9W-T<B`B1&%T;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$R"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@
M(D1A=&\@36]T=&%T="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDV"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")$871O('9A;&<B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<W"FUS9VED(")$87DB"FUS
M9W-T<B`B1&%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G
M<W1R(")3;&5T="!K;VQO;FYE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E<V5M8F5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D1E<VEM
M86QT86QL(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C@U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")!=G-LY71T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(E)E9'5S97(@:6YN<GEK:R(*
M"B,Z(&QI8B]P<F5F<RYP:'`Z,3`X(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,3DQ"FUS9VED(")$969A=6QT(@IM<V=S='(@(E-T86YD87)D(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*;7-G:60@
M(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A<F0@9F%R9V4B"@HC.B!L
M:6(O2&]R9&4O261E;G1I='DN<&AP.CDR"FUS9VED(")$969A=6QT($ED96YT
M:71Y(@IM<V=S='(@(E-T86YD87)D:61E;G1I=&5T(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3$Y(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`T"FUS
M9VED(")$969A=6QT(%!E<FUI<W-I;VYS(@IM<V=S='(@(E-T86YD87)D(')E
M='1I9VAE=&5R(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#4*;7-G
M:60@(D1E9F%U;'0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4W1A;F1A<F0@<F5T
M=&EG:&5T97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:7-J;VYE<B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,PIM<V=I9"`B1&5L
M96=A=&4@<&]S:71I;VXB"FUS9W-T<B`B1&5L96=E<B!P;W-I<VIO;B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y,PIM<V=I
M9"`B1&5L96=A=&5D(@IM<V=S='(@(D1E;&5G97)T(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3<@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,C<*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HS-#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.2!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3,*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D1E;&5T92(*;7-G<W1R(")3
M;&5T="(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@Y(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B4VQE='0@9W)U
M<'!E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HV,"!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C@T"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G
M<W1R(")3;&5T="!R971T:6=H970B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.38*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B4VQE='0@;V<@9FIE<FX@;65L9&EN9V5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM
M<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B4VQE='0@8V5L;&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E-L971T(&MO;&]N;F4B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")3;&5T="!E:W-I
M<W1E<F5N9&4@86QT97)N871I=B!M86PB"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4P(&QI8B](;W)D92]097)M<R]522YP:'`Z,S(V"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G
M<W1R(")&:F5R;B!R971T:6=H971E;F4@=&EL("<E<R<B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_(@IM<V=S='(@(D9J97)N(')E='1I9VAE=&5N92!T:6P@)R5S)R!O9R!A
M;&QE('5N9&5R+7)E='1I9VAE=&5R/R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R
M;W<B"FUS9W-T<B`B4VQE='0@<F%D(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E
M;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y(@IM<V=S='(@(E-L971T('9A;&=T(&ED96YT:71E="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-@IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")3
M;&5T="!G:F5L9&5N9&4@:V]L;VYN92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")3;&5T="!G:F5L9&5N9&4@<F%D
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT.`IM<V=I9"`B1&5L971E
M('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS
M9W-T<B`B4VQE='1E(&1E;FYE(')E='1I9VAE=&5N(&]G(&%L;&4@=6YD97(M
M<F5T=&EG:&5T97(_(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C
M<FEP="`G)7,G+B(*;7-G<W1R(")3;&5T="!S971U<"!O<'!G<F%D97)I;F=S
M+7-C<FEP="`G)7,G+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.#4@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8Q.0HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,0IM<V=I9"`B1&5L:79E<GD@
M=&EM92(*;7-G<W1R("),979E<FEN9W-T:60B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$96YM87)K(@IM
M<V=S='(@(D1A;FUA<FLB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV-#(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R(")!
M=G-LY2!F;W)E<W#X<G-E;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0W,0IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E
M+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`B079S;.4@9F]R97-P^')S96P@
M9F]R(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXB"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HY-2!S97)V:6-E<R]P<F]B;&5M+G!H<#HY.2!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,#D*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(D)E<VMR:78@<')O8FQE;65T(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDS,R!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU-C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B0F5S:W)I
M=F5L<V4B"@HC.B!L:6(O2&]R9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&IE<B`H
M;V=SY2!I($AO<F1E)W,@;&]G9V9I;"DZ(@H*(SH@;&EB+TAO<F1E+G!H<#HR
M,#4*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L:F5R(&AA<B!B;&ET="!L;V=G
M970@9F]R(&%D;6EN:7-T<F%T;W)E;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3DS"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")5='9I
M:VQI;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-0IM<V=I9"`B1&5W
M(%!O:6YT(@IM<V=S='(@(D1O9V=P=6YK="(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDR"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(D1O9V=P=6YK="!F;W(@9&5N('-I<W1E('1I;65N.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DP"FUS9VED(")$97<@<&]I
M;G0Z("(*;7-G<W1R(")$;V=G<'5N:W0Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(E)E=&YI;F<@9G)A('9E;G-T<F4@;6]T
M(&CX>7)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T
M<B`B4F5T;FEN9R!F<F$@:/AY<F4@;6]T('9E;G-T<F4B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DMA
M=&%L;V<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED(")$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(E9I<R`R-"UT:6UE<G,@
M=&ED97(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5FES;FEN9W-V86QG(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX,PIM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*2(*;7-G<W1R(")6:7,@9F]R=F%R<V5L("A4048I(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,#8*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S
M='(@(E9I<VYI;F=S9F]R;6%T(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H
M<#HR,#,*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R
M(")-96QD:6YG(&]M(&]R9&YI;F<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,S(W"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@
M(DEK:V4@<VQE='0B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C0*
M;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M(@IM<V=S='(@(DEK:V4@Y7!N92!M86EN96YA;F-E+G!H<"!D:7)E:W1E(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3D*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C
M;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O
M>#HB"FUS9W-T<B`B2W)Y<W,@878@:&5R(&AV:7,@9&5N(&;X<G-T92!R861E
M;B!I;FYE:&]L9&5R(&9E;'0M;F%V;F5T.B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#8X"FUS9VED(")$
M;W=N;&]A9"(*;7-G<W1R("),87-T(&YE9"(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HX-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1O=VYL;V%D("5S(@IM<V=S='(@(DQA<W0@;F5D("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$U-@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B3&%S="!N
M960@9V5N97)E<G0@:V]N9FEG=7)A<VIO;B!S;VT@4$A0('-C<FEP="XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,0IM<V=I9"`B1')O<"!D;W=N(&QI
M<W0B"FUS9W-T<B`B3F5D=')E:VMS;&ES=&4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(DUE9&ES:6YE<B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y.0IM<V=I9"`B12U-86EL
M(@IM<V=S='(@(D4M<&]S="(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B15)2(@IM<V=S='(@(D52
M4B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HR.38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D
M:70B"FUS9W-T<B`B4F5D:6=E<B(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP
M:'`Z-3$@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I
M="!";&]C:R(*;7-G<W1R(")2961I9V5R92!B;&]K:R(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3@X(&%D;6EN+V=R;W5P<RYP:'`Z,C$V"FUS9VED(")%9&ET
M($=R;W5P(@IM<V=S='(@(E)E9&EG97(@1W)U<'!E(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HU.2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@S"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B4F5D:6=E<B!R971T:6=H
M971E<B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5D:6=E<B!R971T:6=H=&5R
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")2
M961I9V5R(')E='1I9VAE=&5R(&9O<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.CD*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(E)E9&EG97(@=F%L9R!F;W(Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<R(*;7-G<W1R(")2961I9V5R(')E='1I9VAE=&5R(&9O<B`E<R(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P-"!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I
M;VYS(&9O<B`G)7,G(@IM<V=S='(@(E)E9&EG97(@<F5T=&EG:&5T97(@9F]R
M("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C
M871I;VXB"FUS9W-T<B`B3W!P;.9R:6YG(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B16=Y<'0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`X"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N="XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R(")%;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4S
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(W"FUS9VED(")%
M;6%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X.2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$R
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#`*;7-G:60@
M(D5M86EL($%D9')E<W,B"FUS9W-T<B`B12UP;W-T861R97-S92(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.30W"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`B12UP;W-T861R97-S92!MY2!S=&5M;64N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S,*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D4M<&]S="!M960@8F5K<F5F=&5L
M<V4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C@P
M"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B1OAL96QS97(B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B16UP='D@
M;65S<V%G92XB"FUS9W-T<B`B5&]M(&UE;&1I;F<N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,3,Q"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S
M='(@(E1O;70@<F5S=6QT870N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D
M<RYP:'`Z,3$T"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M5/AM('/X:V5K<FET97)I97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3,R"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")!:W1I=F5R(&UU;&EG
M:&5T(&9O<B#E('-E='1E(&EN;B!B:6QD97(@9G)A(&=A;&QE<FEE<B!I('1E
M:W-T96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B06MT
M:79E<F4@:/AY<F5K;&EK:R!M96YY/R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0T.`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU-3,*;7-G:60@(D5N9"(*;7-G<W1R(")3;'5T
M="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DQ(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#`P"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("+%<G-S;'5T="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*
M;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(D=J^'(@961I=&]R96X@
M<W3X<G)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,0IM<V=I9"`B
M(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D
M+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S
M='(@(B(*(E-K<FEV(&EN;B!E='0@<VEK:V5R:&5T<W-P^')S;>5L('-O;2!D
M=2!V:6P@8FQI('-P=7)T(&]M(&AV:7,@9'4@^&YS:V5R(.4@(@HB;G5L;'-T
M:6QL92!P87-S;W)D970@9&ET="P@9BYE:W,N("=H=F$@97(@;F%V;F5T('#E
M(&MJYFQE9'ER970@9&ET=#\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@
M=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(E-K<FEV(&EN;B!A9')E<W-E
M;B!T:6P@8FEL9&5T(&AE<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,34Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')I97,Z("5D('1O=&%L+"`E9"!U
M<"UT;RUD871E+"`E9"!N97<L("5D(&-H86YG960L("5D('5N:VYO=VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU,0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A
M;"]I;F1E>"YP:'`Z-S@*;7-G:60@(D5R<F]R(@IM<V=S='(@(D9E:6PB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ.34*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C<X"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T
M<B`B1F5I;"!V960@<V5N9&EN9R!A=B!S=F%R.B`E<R(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(")%<G)O<B!W:71H
M(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D9E:6P@;65D(&4M<&]S="!M96QD
M:6YG96XN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,30S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R
M:71I;F<@)R5S)RXB"FUS9W-T<B`B1F5I;"!V960@<VMR:79I;F<@=&EL("<E
M<R<N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-3(R('!O+W1R86YS;&%T:6]N+G!H<#HQ,S4X"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ-#$Y('!O+W1R86YS;&%T:6]N+G!H<#HQ-#@R"FUS9VED
M(")%<G)O<CH@(@IM<V=S='(@(D9E:6PZ("(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5S=&]N:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D5U<F]P92(*
M;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(Y
M"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DAV97)T(#$U+B!M
M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")%
M=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2'9E<G0@,BX@;6EN=71T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DAV97)T
M(#,P+B!S96MU;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(X(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(D5V97)Y(#4@;6EN=71E
M<R(*;7-G<W1R(")(=F5R="`U+B!M:6YU='0B"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C,Y"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")(
M=F5R(&EN;FQO9V=I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,P
M"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B2'9E<B!H86QV=&EM
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(DAV
M97)T(&UI;G5T="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(X
M"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B16MS96UP96QV97)D
M:65R.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW-B!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$S-@IM<V=I9"`B17AE8W5T
M92(*;7-G<W1R(")+:OAR(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(Y.2!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,S(P('!O+W1R86YS;&%T:6]N+G!H<#HS-C(*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C0T,2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-30Q('!O+W1R86YS;&%T:6]N+G!H<#HV,#$*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<P,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S,W('!O+W1R86YS;&%T:6]N
M+G!H<#HW.3@*(SH@<&\O=')A;G-L871I;VXN<&AP.C@W-2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.3@Y('!O+W1R86YS;&%T:6]N+G!H<#HQ,#$Q"FUS9VED(")%
M>&5C=71I;F<Z(@IM<V=S='(@(DMJ^')E<CHB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HS.#8*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")5='9I
M9"(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*;7-G:60@
M(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(E5T=FED(%-I9&5B87(B"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-CD*;7-G:60@(D5X<&5C=&5D
M("<I)R(*;7-G<W1R(")&;W)V96YT970@)RDG(@H*(SH@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z,3<V"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(D9O<G9E;G1E="!B;&%N
M:W0@;W)D(&5L;&5R('%U;W1E="!S^&ME:W)I=&5R:64B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HS.3@*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R(")5=&SX<'-D871O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5K<W!O;F5N="(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17AT<F%C=&EN9R!F<F]M("5S+BXN("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS
M9VED(")&1R!#;VQO<B(*;7-G<W1R(")&;W)G<G5N;G-F87)G92(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S$*;7-G:60@(D944"!U<&QO860@;V8@
M<V5T=7`B"FUS9W-T<B`B3W!P;&%S=&EN9R!A=B!S971U<"!V:6$@1E10(@H*
M(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C0P"FUS9VED(")&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B571H96YT:6YG(&%V
M(&EN<W1I;&QI;F=E<B!F96EL970N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,3`S"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B5&EL:V]B;&EN9R!T:6P@3$1!4"UT:F5N97(@9F5I
M;&5T+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z,3`S"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")4:6QK
M;V)L:6YG('1I;"!334(M=&IE;F5R(&9E:6QE="XB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z-C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")&96EL970@=F5D(&MO<&EE<FEN9R!F
M<F$@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R
M(")&96EL970@=F5D(&MO<&EE<FEN9R!T:6P@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92]!=71H+W-A<VPN<&AP.CDR"FUS9VED(")&86EL960@=&\@8W)E871E
M(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(D9E:6QE="!V960@;W!P
M<F5T=&5L<V4@878@;GD@4T%33"!K;V)L:6YG+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HV-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@
M=&\@7"(E<UPB+B(*;7-G<W1R(")&96EL970@=F5D(&9L>71T:6YG('1I;"!<
M(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM
M<V=I9"`B1F%I<B(*;7-G<W1R(")096YT(';F<B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&87)O92!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S-0IM
M<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D9A=&%L($9E:6PZ("(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")&
M87@B"FUS9W-T<B`B1F%X(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q.`IM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R(")&^&QE<R!S;VTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3DT"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B1OAL97,@<V]M
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,Q"FUS9VED
M(")&97<@4VAO=V5R<R(*;7-G<W1R(")&Y2!B>6=E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S(*;7-G:60@(D9E=R!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B1N4@<V[X8GEG97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DR.`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(D9E;'1M871R
M:7-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S
M='(@(D%N=&%L;"!F:6QE<CH@)7,@9FEL97(B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G
M<W1R(")!;G1A;&P@9FEL97(Z("5S(&9I;&5R(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,T.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@
M(D9I;&)E:&%N9&QE<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&:6QE($YA
M;64B"FUS9W-T<B`B1FEL;F%V;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.3@P"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")&:6QV86QG(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T.#,*;7-G:60@(D9I;&4@=7!L;V%D
M(@IM<V=S='(@(DQA<W0@;W!P(&9I;&5R(@H*(SH@;&EB+TAO<F1E+T)R;W=S
M97(N<&AP.C@W-`IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(D]P<&QA<W1I;F<@878@9FEL97(@<W3X='1E<R!I:VME+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX-@IM<V=I9"`B1FEL=&5R
M<R(*;7-G<W1R(")&:6QT97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S$*;7-G:60@(D9I<G-T($AA;&8B
M"FUS9W-T<B`B1OAR<W1E(&AA;'9MY6YE(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R(")&^')S=&4@:W9A<G1MY6YE(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.0IM<V=I9"`B1FEX(')A=&EO
M(@IM<V=S='(@(D9A<W0@9F]R:&]L9"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,30*;7-G:60@(D9L:7`B"FUS9W-T<B`B4VYU
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B1FQY="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S,*;7-G:60@(D9O9R(*;7-G<W1R
M(")4Y6ME(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$V,R!L:6(O5D93+VUU<W%L
M+G!H<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T(@IM<V=S='(@(DUA<'!E;B`E<R!E:W-I<W1E<F5R(&EK:V4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R
M"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D9O;G1F87)G92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")-
M870B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(D9O<B!N971T;&5S97)E('-O;2!I
M:VME('-T^'1T97(@8FEL9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,S(*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(D9O<G9A<G-E;"`H
M5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-`IM<V=I
M9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F
M;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*
M;7-G<W1R("(B"B)!;G1A;&P@9&%G97)S(&9O<G9A<G-E;"`H=N9R(&]B<R!P
MY2!A="!D970@<F5T=7)N97)T92!F;W)V87)S;&5T(&EN;F5H;VQD97(@(@HB
M8N5D92!D86<@;V<@;F%T=#L@96X@<W1O<B!V97)D:2!H97(@:V%N(')E<W5L
M=&5R92!I(&5N('-T;W(@8FQO:VLI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY-0IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S
M='(@(D=L96UT('!A<W-O<F1E=#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#,Q"FUS9VED(")&;W)M<R(*;7-G<W1R(")3:VIE;6%E<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G
M<W1R(")3:VIE8FYE+VQY:VME(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B5'EP92!S:VIE8FYE
M+VQY:VME(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&
M;W)T=6YE<R(*;7-G<W1R(")3:VIE8FYE<B]L>6MK92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")3
M:VIE8FYE<B]L>6MK92`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0Q-`IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M97(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4X"FUS9VED(")&;W)W87)D<R(*;7-G
M<W1R(")6:61E<F5S96YD=&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&;W5N9"!A<'!L:6-A=&EO;G,Z("5S
M(@IM<V=S='(@(D9A;G0@<')O9W)A;6UE;F4Z("5S(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$T,S,*;7-G:60@(D9O=6YD(&1I<F5C=&]R:65S.B(*;7-G
M<W1R(")&86YT(&MA=&%L;V=E;F4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B1G(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B4F%M;65R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1G)A;F-E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,3<*;7-G
M:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("),961I9R]O<'!T
M871T+6EN9F]R;6%S:F]N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-#(W"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB"FUS9W-T
M<B`B3&5D:6<O;W!P=&%T="!S=F%R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#(R"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S
M="(*;7-G<W1R("),961I9R]O<'!T871T(&9O<F5S</AR<V5L(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C<R"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T,0IM<V=I9"`B1G)E
M92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4B"FUS9W-T<B`B4W9A<B!PY2!L961I
M9R]O<'!T871T(&9O<F5S</AR<V5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW.0IM
M<V=I9"`B1G)O;2(*;7-G<W1R(")&<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$Q"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1G)A
M("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED
M(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&P@8F5S:W)I=F5L<V4B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#(@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$X,0IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(D9U;&QMY6YE(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS.0IM<V=I9"`B1G5L
M;"!.86UE(@IM<V=S='(@(D9U;&QT(&YA=FXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C4W"FUS9VED(")&=7IZ>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'86)O
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&QE<FD@9'4@^&YS:V5R(.4@:&5N
M=&4@8FEL9&4@9G)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R(")'86QL97)I.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N97)E<B`E
M<R!K;VYF:6=U<F%S:F]N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL.C$P"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'
M96YE<F5R="!K;V1E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'96YE<F%T:6YG('-T871U<R!F;W(@;6]D=6QE
M("5S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3,U,@IM<V=I9"`B1V5T;W!T($5R<F]R.B`B"FUS9W-T<B`B1V5T;W!T
M($9E:6PZ("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=I8G)A
M;'1A<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y.0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")':71T($YA=FXB"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-@IM<V=I9"`B1V\B"FUS9W-T
M<B`B1V\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O
M961E;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q
M"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(E/X:R!PY2!';V]G;&4B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"FUS
M9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B1W+E=&]N92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'<F5E
M8V4B"FUS9W-T<B`B2&5L;&%S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#$*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'<F5E;FQA;F0B"FUS9W-T<B`B1W+X;FQA;F0B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5N861A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<P"FUS9VED(")'
M<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P<&4@861M:6YI<W1R
M87-J;VXB"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4W"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")'<G5P<&5N879N
M(&MA;B!I:VME(';F<F4@=&]M;64B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HR,#$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.#4*;7-G:60@(D=R;W5P
M('!E<FUI<W-I;VYS(@IM<V=S='(@(D=R=7!P97)E='1I9VAE=&5R(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z,3<V(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C4X(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U
M<'!E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M86TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(Q,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")2971T
M:6=H971E<B!F;W(@9VIE<W0B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,C@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,30*;7-G:60@(D=U97-T('!E
M<FUI<W-I;VYS(@IM<V=S='(@(E)E='1I9VAE=&5R(&9O<B!G:F5S="(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R(")':F5S=&5B;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS,S$*;7-G:60@(DA((@IM<V=S='(@(DA((@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDU-0IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A
M(&YE:W1E<B#E('-L971T92!D96X@<VES=&4@8V5L;&5N(&D@96X@<F%D+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R
M96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S:7-T92!K;VQO;FYE;B!I('1A8F5L
M;&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-
M3$%R96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S:7-T92!R861E;B!I('1A8F5L
M;&5N+B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$V-`IM<V=I9"`B
M2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DA45%`@
M875T96YT:7-E<FEN9R!I:VME(&9U;FYE="XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DAA:71I(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y.0IM<V=I
M9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S:"UA;&=O<FET;64B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,T"FUS9VED(")(87IE
M(@IM<V=S='(@(D1I<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,30@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,C$*;7-G:60@(DAE861E<B(*;7-G<W1R(")(
M;V1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS
M9VED(")(96EG:'0B"FUS9W-T<B`B2/AY9&4B"@HC.B!L:6(O2&]R9&4O2&5L
M<"YP:'`Z,3<Y(&QI8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*
M;7-G:60@(DAE;'`B"FUS9W-T<B`B2&IE;'`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG
M(&5D:71O<B(*;7-G<W1R(")(:F5L<"!T:6P@8G)U:R!A=B!E9&ET;W(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.`IM<V=I9"`B2&5L<&5R(@IM<V=S
M='(@(DAJ96QP97(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.34*;7-G:60@
M(B(*(DAE;'!E<B!A<'!L:6-A=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN
M('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E7&XB"B)F<F%M97=O<FL@86YD
M(&ET<R!A<'!L:6-A=&EO;G,N7&XB"B)&;W(@86X@:6YT<F]D=6-T:6]N(')E
M860@=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE
M<F4B"FUS9W-T<B`B2&%L=FMU;&4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M(")(97(@97(@8F5G>6YN96QS96X@<.4@9FEL96XZ(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,W-@IM<V=I9"`B2&EG:"(*;7-G<W1R(")(
M^'DB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z,S(R"FUS9VED(")(:7-T
M;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DAI
M<W1O<FEE;W!P9OAR:6YG97(@<.4@:&$@;F%V;B!S;VT@:6MK92!E<B!T;VUM
M92(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-`IM<V=I9"`B2&]?;64B"FUS9W-T
M<B`B2&IE7VTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$U"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$T-C8*;7-G:60@
M(DAO;64B"FUS9W-T<B`B2&IE;2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(U(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,34X"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B2&IE;6UE861R
M97-S92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DS
M"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@:&IE;6UE(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F<@2V]N
M9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C(*
M;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$S,3`*;7-G:60@(DAO<F1E('1R86YS;&%T:6]N(&=E;F5R871O
M<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0R,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@
M9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!59WEL9&EG("5S(%A-3"!D871A(&9U;FYE="!I(&UE;&1I;F<@
M)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(W-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN9V5N(&UE;&1I
M;F<@<&%S<V5R(&UE9"!O8FIE:W1E="`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!);G1E="!O8FIE:W0@878@='EP96X@)7,@9G5N
M;F5T(&D@;65L9&EN9R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(S
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!&
M:F5R;F5T("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$X
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY('-Y;F-H<F]N:7-E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(%-Y;FMR;VYI<V5R=&4@)7,@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E9W)A<VIO;G-M;W1O<F5N(&MR
M979E<B!02%`@)V1O;7AM;"<@=71V:61E;'-E(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HT.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@;W!P<F5T=&4@;GET
M="!834P@=')E(&9O<B!O8FIE:W1E="`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,3(S,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!+=6YN92!I:VME(&9J97)N92`E<R!<(B5S7"(Z("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+=6YN
M92!I:VME(&AE;G1E($U)344@240@9F]R(&1E;&5N(&%V('1Y<&4@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+=6YN92!I:VME('-Y;FMR
M;VYI<V5R92`E<R!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,S$P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@2W5N;F4@:6MK92!S>6YK<F]N:7-E<F4@9&5L=&4@<F5S<W5R<V5R
M.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S$X"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@56MJ96YT(&1E;'0@<F5S<W5R<R!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B2&]R:7-O;G1A
M;"!L:6YJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(
M;W)I<V]N=&%L('!A9&1I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R
M(")(;W)I<V]N=&%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B2'9O<F1A;B!K;VT@
M9'4@:&ET/R`H5F5N;FQI9W-T(')A<'!O<G1E<B$I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B2'9O<B!M86YG92!K;VQO;FYE<B#X;G-K97(@9'4@Y2!S;.4@<V%M
M;65N/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(X"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B2'9O<B!M86YG92!F96QT97(@*&MO;&]N;F5R*2!E<B!D970_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`B2'9O<B!M86YG92!R861E<B#X;G-K97(@9'4@Y2!S;.4@
M<V%M;65N/R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(X"FUS9VED(")(
M=6UI9&ET>2(*;7-G<W1R(")&=6MT:6=H970B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$W"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@
M(D9U:W1I9VAE=#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS
M9VED(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1E<B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B
M2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP
M:'`Z,3<V(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C(S"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(D]P<')E='1E;'-E(&%V($E-05`@<&]S=&)O:W,@9F5I;&5T
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,C`@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HR.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4VQE
M='1I;F<@878@24U!4"!P;W-T8F]K<V5N(&9E:6QE=#H@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3@S(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D]P<')E='1E;'-E
M(&%V(&MV;W1E('#E($E-05`@<&]S=&)O:W,@9F5I;&5T.B`E<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,S$R"FUS9VED("))4"!!9&1R97-S(@IM<V=S
M='(@(DE0($%D<F5S<V4B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H
M<#HX,@IM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("))4"!!9')E<W-E(&EK:V4@=&EL9VIE;F=E;&EG+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VEP8F%S:6,N<&AP.CDT"FUS9VED("))4"!!9&1R97-S(&YO="!W
M:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"!!9')E<W-E
M(&EK:V4@:6YN96YF;W(@=&EL871T92!#2412(&)L;VMK+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED("))4"!L;V-K
M9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(D)R=61D('#E($E0(&QO8VMD;W=N
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@
M(E-?971T(&EN;B!N>2!R860@9OAR(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED("))8V5L86YD(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(DEC
M;VYS($]N;'DB"FUS9W-T<B`B2W5N(&EK;VYE<B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@
M)7,B"FUS9W-T<B`B26MO;F5R(&9O<B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("))
M:V]N97(@;65D('1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("))9&5N=&ET971E
M;G,@;F%V;CHB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-C`X
M"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS
M9W-T<B`B2'9I<R!D96X@:6MK92!V:7-E<R!R:6MT:6<L("5S(&9O<B#E(.5P
M;F4@:2!N>71T('9I;F1U+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#4*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T
M<B`B(@HB2'9I<R!D=2!I:VME('-E<B!N;V5N(&EK;VYE<B!NY7(@9'4@8F5N
M>71T97(@26YT97)N970@17AP;&]R97(L(&MA;B!D970@(@HB:&5N9&4@9'4@
M=')E;F=E<B#E(&MR>7-S92!A=B!D96YN92!B;VMS96X@9F]R(.4@<VMR=2!A
M=B!T<F%N<W!A<F5N="!03D<N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$U.`IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM
M<V=S='(@(B(*(DAV:7,@9'4@<V5R(&1E;FYE(&UE;&1I;F=E;B!M96X@:6YT
M970@8FEL9&4L(&MA;B!D970@:&5N9&4@870@8FEL9&5T(&1U('9I;"`B"B)L
M87-T92!O<'`@:6MK92!K86X@=FES97,@:2!D:6X@;F5T=&QE<V5R+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B1F]R:.5N
M9'-V:7-N:6YG(&%V(&)I;&1E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R(")":6QD96%D<F5S<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E
M(%523#HB"FUS9W-T<B`B0FEL9&5A9')E<W-E.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(D)I;&1E(&9R82!G86QL
M97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM
M<V=S='(@(D)I;&1E(&9R82!G86QL97)I.B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-S0Y"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B3W!P;&%S
M=&EN9R!A=B!B:6QD92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS
M9VED("));6%G97,B"FUS9W-T<B`B0FEL9&5R(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-R!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T97)I;F<L('-T96<@)60B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B26UP;W)T97)T
M92!F96QT.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S,*
M;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T97)T92!F
M96QT.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C<P,0IM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R(")5;F1E<B!A<F)E:60B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(E]3
M971T(&EN;B!R860@971T97(B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HQ-#$*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB
M"FUS9W-T<B`B1F5I;"!H86YD;&EN9W-K;V1E(&=I='0N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U-PIM<V=I9"`B26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B56=Y;&1I9R!B
M<G5K97)N879N(&]G+V5L;&5R('!A<W-O<F0N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HB1F5I;"!B<G5K97)N879N(&5L;&5R(&%L=&5R;F%T
M:78@861R97-S92X@5F5N;FQI9W-T(&9O<G/X:R!I9VIE;B!E;&QE<B`B"B)K
M;VYT86MT('-Y<W1E;6%D;6EN:7-T<F%T;W)E;B!D:6X@9F]R('ET=&5R;&EG
M97)E<F4@:&IE;'`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@
M(MAK(&EN;G)Y:VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$T,2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("));F1I
M=FED=65L;&4@8G)U:V5R92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS
M9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C0Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O
M<FUA<VIO;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R(")3971T(&EN;B!K7V]L;VYN92!E='1E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I
M9"`B26YS97)T($EM86=E(@IM<V=S='(@(E-E='0@:6YN(&)I;&1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I
M9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(E-E='0@:6YN('1A8F5L;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R(")3971T(&EN;B!W96)L:6YK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,S"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T
M<B`B4V5T="!I;FX@7VMO;&]N;F4@9OAR(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M(")3971T(&EN;B!E;B!N>2!K;VQO;FYE(&5T=&5R(&1E;B!G:F5L9&5N9&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R(")3971T(&EN;B!E;B!N>2!K;VQO;FYE
M(&;X<B!D96X@9VIE;&1E;F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")3971T(&EN
M;B!E;B!N>2!R860@971T97(@9&5N(&=J96QD96YD92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(E-E='0@:6YN(&5N(&YY(')A9"!F^'(@9&5N(&=J96QD96YD92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B4V5T="!I;FX@;&EN:F5S:VEF="!E='1E
M<B!D96X@9VIE;&1E;F1E(&YO9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
M4V5T="!I;FX@;&EN:F5S:VEF="!F^'(@9&5N(&=J96QD96YD92!N;V1E;B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(E-E='0@:6YN(&%L=&5R;F%T:78@
M;6%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R.0IM<V=I9"`B26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(E-E='0@:6YN(&5N(&4M<&]S
M="!A9')E<W-E(&1U(/AN<VME<B#E(&UO='1A(&1E="!N>64@<&%S<V]R9&5T
M('#E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@
M(E-E='0@:6YN(&-E;&QE(&5T=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E
M;&P@8F5F;W)E(@IM<V=S='(@(E-E='0@:6YN(&-E;&QE(&5T=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")3971T(&EN
M;B!K;VQO;FYE(&5T=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B
M969O<F4B"FUS9W-T<B`B4V5T="!I;FX@:V]L;VYN92!F^'(B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(DEN<V5R="!M
M97-S86=E<R(*;7-G<W1R(")3971T(&EN;B!M96QD:6YG97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*
M;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B4V5T="!I
M;FX@;&EN:F5S:VEF="!E='1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B4V5T="!I;FX@;&EN:F5S:VEF="!F
M^'(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(E-E
M='0@:6YN(')A9"!E='1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F
M;W)E(@IM<V=S='(@(E-E='0@:6YN(')A9"!F^'(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C(P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(E-E='0@
M:6YN(&1E="!PY6MR979D92!S=F%R970@=&EL(&;X;&=E;F1E('-I:VME<FAE
M='-S</AR<VWE;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S
M='(@(E-E='0@:6YN+W)E9&EG97)E(&)I;&1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(E-E='0@:6YN+W)E9&EG97)E(&QI;FLB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8X"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(")):VME(&YO:R!K<F5D:71T(&9O<B#E(&MU;FYE
M('-E;F1E('1I;"!D:7-T<FEB=7-J;VYS;&ES=&5N+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C`*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70N(@IM<V=S='(@(DEK:V4@;F]K(&MR961I='0N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-S`*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B
M26YT96=E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(X"B,L(&9U>GIY
M"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B26YT96=E<B!L:7-T92(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(X,PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3(*;7-G
M:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N
M="XB"FUS9W-T<B`B56=Y;&1I9R!H86YD;&EN9R!V86QG="!F;W(@9&5N;F4@
M:V]M<&]N96YT96XN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN(@IM<V=S='(@(E5G>6QD:6<@541(+B`H57-E<B!$871A($AE861E<BDN
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI
M9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B56=Y;&1I9R!P<F]G<F%M+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(Q"FUS9VED("))
M;G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")59WEL9&EG(&)A=&-H($E$(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q-#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,38*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R.#$*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM
M<V=S='(@(E5G>6QD:6<@9&%T82!S96YD="XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+B(*;7-G<W1R(")59WEL9&EG(&UO='1A:V5R(&%D<F5S
M<V4N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z.#0@;&EB+TAO
M<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`S"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]D8G@N<&AP.C(R,PIM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G
M<W1R(")59WEL9&EG(&9I;&9O<FUA="(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$V"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R(")59WEL9&EG(&UE;&1I;F=S='EP92(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+B(*;7-G<W1R(")59WEL9&EG(&5L;&5R(&UA;F=L96YD
M92!A<&E?:60N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*
M;7-G<W1R(")59WEL9&EG(&5L;&5R(&UA;F=L96YD92!P87)A;65T97)E+B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HT,PIM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B56=Y;&1I9V4@<F5T=&EG
M:&5T97(N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,34*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E5G>6QD:6<@
M<')O=&]K;VQL+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HY,0HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@
M)R5S)R(*;7-G<W1R(")59WEL9&EG(&UO='1A:V5R.B`G)7,G(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,#<Q(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T
M.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B56=Y;&1I
M9R!D96QT(&]B:F5K="(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$P"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G
M<W1R(")59WEL9&EG(&MI;&1E861R97-S92(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S(P"FUS9VED("));G9A;&ED('5N:6-O9&4@
M9&%T82XB"FUS9W-T<B`B56=Y;&1I9R!U;FEC;V1E(&1A=&$N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(DEN;FAO;&0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,U"FUS9VED("))<V]L871E
M9"!4+5-T;W)M<R(*;7-G<W1R("))<V]L97)T92!T;W)D96XM<W1O<FUE<B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C0Y"FUS9VED("))<W-U97(B"FUS9W-T<B`B571G:79E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DMU<G-I=B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B271A
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S0@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y
M(@IM<V=S='(@(DIA;G5A<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(DIA<&%N97-E("A)
M4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2F]R
M9&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(DIU;&DB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<Y(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,38*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-T97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B36ED='-T:6QL(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3<*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")"
M;&]K:VIU<W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$T"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($QE
M9G0B"FUS9W-T<B`B5F5N<W1R96IU<W1E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"B,L(&9U>GIY"FUS
M9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(DCX>7)E:G5S=&5R(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS
M9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME97`@;W)I9VEN86P_
M(@IM<V=S='(@(D)E:&]L9&4@;W)G:6YA;#\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DME;GEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@W"FUS9VED
M(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DME<F)E<F]S('1J96YE<F5N(&%V=FES=&4@875T96YT:7-E<FEN
M9V5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R
M;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L($YY8F5G>6YN97)E(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDW"FUS9VED(")+97D@0W)E871I
M;VXB"FUS9W-T<B`B3OAK:V5L9V5N97)E<FEN9R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S
M='(@(D[X:VME;"!F:6YG97)P<FEN="(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C,Y.`IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(").^&MK96P@
M;&5N9V1E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDW"FUS9VED
M(")+97D@5'EP92(*;7-G<W1R(").^&MK96P@='EP92(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C(R"FUS9VED(")+97D@57-A9V4B"FUS9W-T
M<B`B3OAK:V5L8G)U:R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<T
M,PIM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R(").^&MK96P@96MS:7-T97)E<B!A;&QE<F5D92!P
MY2!D96X@;V9F96YT;&EG92!N^&MK96QT:F5N97)E;BXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B0F%R;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-PIM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B571?<V5E;F1E(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C4W"FUS9VED("),86YG=6%G92(*;7-G<W1R(")3<'+E:R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3&%S="!(
M86QF(@IM<V=S='(@(E-I<W1E(&AA;'1I;64B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#@@;&EB+T)L;V-K+VUO;VXN<&AP.CDP"FUS9VED("),87-T(%%U
M87)T97(B"FUS9W-T<B`B4VES=&4@:W9A<G1E<B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,30Y"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E-I
M<W1E(&]P<&1A=&5R:6YG.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
M4VES=&4@:6YN;&]G9VEN9SH@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-CDS"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`B4VES=&4@:6YN;&]G9VEN9SH@)7,@9G)A("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.C8X.`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V
M97(B"FUS9W-T<B`B4VES=&4@:6YN;&]G9VEN9SH@06QD<FDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R("),;W8B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U
M="(*;7-G<W1R(")5='-E96YD92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`BV&YS:V5S(&EN9V5N(')A;6UE<B!L87(@9'4@
M9F5L=&5T(';F<F4@=&]M="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B5F5N<W1R92(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3`T"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M(")696YS=')E(&AO9&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,`IM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F5N<W1R92!V97)D:65R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB97)I82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S8*;7-G:60@(DQI9VAT
M($1R:7IZ;&4B"FUS9W-T<B`B3&5T="!D=7-K<F5G;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S<*;7-G:60@(DQI9VAT(%)A:6XB"FUS
M9W-T<B`B3&5T="!R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,S.`IM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("),971T
M(&9O<FUI9&1A9W-R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,S.0IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(DQE='0@
M971T97)M:61D86=S<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-#`*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DQE
M='1E(')E9VYB>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-#$*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@
M(DQE='0@<F5G;B!M960@=&]R9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,T,@IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),971T
M('-N^&9A;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0S
M"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("),971T92!S;OAB
M>6=E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM
M97)I8VLB"FUS9W-T<B`B3&EM97)I8VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@P,@IM<V=I9"`B3&EN:R(*;7-G<W1R("),:6YK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS
M9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3&EN:R!P96ME<B!T:6PZ
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3D*;7-G:60@(DQI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<B"FUS9W-T<B`B3&EN:R!E+7!O<W0@861R97-S96X@=&EL("=S:W)I
M=B!N>2<M<VED92!V960@=FES;FEN9R(*"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]H=&UL,G1E>'0N<&AP.C$X,0IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B
M3&EN:V5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),
M:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@@0V]O:VEE(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED("),:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES="`M(&)R=6ME<F5N
M(&MA;B!S92!M87!P96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,X"FUS
M9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("),:7-T(&1A=&%B87-E<B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE
M;'`@5&]P:6-S(@IM<V=S='(@(D5M;F5R(&D@2&IE;'`B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,W"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("),
M:7-T('1A8F5L;&5R(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-C,W"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES=&4M87)K:78B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,S(*;7-G:60@(DQI
M<W0M2&5L<"(*;7-G<W1R("),:7-T96AJ96QP(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-C,Y"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI
M<W1E+4ED(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-C,U"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(D5I97(@878@;&ES=&4B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,S8*;7-G:60@(DQI<W0M4&]S
M="(*;7-G<W1R("),:7-T92UP;W-T(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-C,T"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R(")!
M8F)O;F5R('#E(&QI<W1E(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-C,S"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(E-T;W!P
M(&%B8F]N;F5M96YT('#E(&QI<W1E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHT"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R(")-=6QI9VAE="!F;W(@Y2!L:7-T92!B<G5K97)E(&5R
M(&1E86MT:79E<G0N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS
M9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI='1E<F%T=7(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3,Q.0IM<V=I9"`B3&]A9&EN9R!L:6)R87)I97,N+BXB"FUS9W-T<B`B3&%S
M=&5R(&)I8FQI;W1E:V5R+BXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z.#8*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&%S
M=&5R+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-`IM
M<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DQO:V%L('1I9#HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM
M92(*;7-G<W1R(")3<'+E:R!O9R!T:60B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4Y-2!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU-S`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8P(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HR,@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C8S"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),;VMA<VIO;B(*"B,Z(&QO
M9VEN+G!H<#HQ-34@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$V-"!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*
M;7-G:60@(DQO9R!I;B(*;7-G<W1R("),;V=G(&EN;B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3@*;7-G:60@(DQO9R!O=70B"FUS9W-T
M<B`B3&]G9R!U="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(DEN;FQO9V=I;F=S;W!P9V%V97(B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.34R"FUS9VED("),;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("),;V=I;B!F96EL970@9F]R9&D@
M8G)U:V5R;F%V;F5T(&5L;&5R('!A<W-O<F1E="!D=2!S:W)E=B!I;FX@=F%R
M(&9E:6PN(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDT.`IM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R("),;V=I;B!F96EL970N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S-C(*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),
M86YG('1E:W-T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED
M("),;W9E(@IM<V=S='(@(DMJYG)L:6=H970B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S<T"FUS9VED("),;W<B"FUS9W-T<B`B3&%V(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")3
M;>4@9W)E<VME(&)O:W-T879E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B4VWE(&QA=&EN<VME(&)O:W-T879E<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDP"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS-#(@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$P('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-38*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1N968N<&AP.C,Y"FUS9VED(")-4RU43D5&($%T=&%C
M:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HT,`HC+"!F
M=7IZ>0IM<V=I9"`B35-'(@IM<V=S='(@(D-64R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I
M9"`B36%C86\B"FUS9W-T<B`B3&]K87-J;VXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3$*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R
M(")%+7!O<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S$*;7-G
M:60@(DUA:6PB"FUS9W-T<B`B26YN8F]K<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,30*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0P"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,S,X"FUS9VED(")-86ME('-U<F4@=&AA="!Y
M;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A
M=&@N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-S@@<&\O
M=')A;G-L871I;VXN<&AP.C$P-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DUA:VEN9R!D:7)E8W1O<GD@)7,B"FUS9W-T<B`B4V]R=&5R:6YG<W)E
M:VME9OAL9V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")%
M+7!O<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(D4M
M<&]S="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B4&]S
M="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R(")0;W-T(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"B,L
M(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")%+7!O<W0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES
M="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L
M(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#0P"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW.`HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B36%P
M475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-S8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8W"B,L(&9U>GIY"FUS9VED(")-87)C:"(*;7-G<W1R(")3^&LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`B061V87)S
M96PB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(DUA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%R<VAA;&P@27-L86YD
M<R(*;7-G<W1R(")/<'!D871E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%R=&EN
M:7%U92(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3$Q"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B
M4V%M<W9A<F5N9&4@9F5L="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%U<FET86YI
M82(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B36%U<FET
M:75S(@IM<V=S='(@(D%D=F%R<V5L(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,C0*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3<*(RP@9G5Z>GD*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+B(*;7-G<W1R(")-96QD:6YG96X@8FQE('-L971T970N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#0*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M-@IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S,0IM<V=I9"`B36%X:6UU;2!L
M96YG=&@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DUA>2(*;7-G<W1R(")$86=L:6<B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"B,L(&9U>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(E5T<V5E;F1E(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")-
M961I8VEN92(*;7-G<W1R(")!=G-LY71T(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,Q"FUS9VED(")-965T:6YG($-A;F-E
M;&QA=&EO;B(*;7-G<W1R(")-^'1E879L>7-N:6YG(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`S"FUS9VED(")-965T:6YG
M($EN9F]R;6%T:6]N(@IM<V=S='(@(DWX=&5I;F9O<FUA<VIO;B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.0IM<V=I9"`B
M365E=&EN9R!0<F]P;W-A;"(*;7-G<W1R(")-^'1E:6YN:V%L;&5L<V4B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C4*;7-G
M:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B3?AT97-V87(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,30*;7-G:60@(DUE
M971I;F<@57!D871E(@IM<V=S='(@(DWX=&5O<'!D871E<FEN9R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q.0IM<V=I9"`B
M365E=&EN9R!5<&1A=&4@4F5Q=65S="(*;7-G<W1R(")&;W)E<_AR<V5L(&]M
M(&WX=&5O<'!D871E<FEN9R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,3D*(RP@9G5Z>GD*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B
M365M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(DUE
M;G4@;6]D93HB"FUS9W-T<B`B365N>6UO9'5S.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*(RP@9G5Z>GD*
M;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(DUE;&1I;F=S9F5L="(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HU,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365R9VEN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW.#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365R9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E
M;F1I=6TN+BX@(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R9VEN9R!T<F%N<VQA=&EO;B!F
M;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,@IM<V=I9"`B365S<V%G
M92(*;7-G<W1R(")-96QD:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HR,C8*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U
M;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E
M("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q.0HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R(")-96QD:6YG<V9E;'0B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DQ(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,C8*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,S,@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C@*
M(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")-96QD:6YG
M<V1A=&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*(RP@9G5Z>GD*;7-G
M:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B4W1A<G0B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")$970@97(@:6YG96X@;65L9&EN9V5R
M(&D@9&5N;F4@<&]S=&)O:W-E;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B1&5T86QJ97(@:&%R(&)L:71T(&QO9V=E="!F
M;W(@861M:6YI<W1R871O<F5N+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C<P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"B,L(&9U>GIY"FUS9VED(")-971H;V0B"FUS9W-T<B`B3&%V97-T(@H*(SH@
M;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@R(&QI8B](;W)D92]24$,O<V]A
M<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@
M)R5S)R!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-87!P96)R=6L@97(@:6MK
M92!T:6QG:F5N9V5L:6<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S,*;7-G:60@(DUE=')I8R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R(")3:VIU;'0B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z-#$*;7-G:60@(DUI
M;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M.`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`P"FUS9VED(")-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C$W"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B
M"FUS9W-T<B`B1F5I;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-CDW(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0Y"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,#4*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PHC+"!F=7IZ>0IM<V=I9"`B36ES
M<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")$96YN92!M96QD:6YG96X@=&EL
M(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU-PIM
M<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*(RP@9G5Z>GD*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T
M<B`B1&5N;F4@;65L9&EN9V5N('1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(DUO(@IM
M<V=S='(@(D9L>71T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R
M,@HC+"!F=7IZ>0IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B3GD@<&]S
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S4*(RP@9G5Z
M>GD*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(E-I<W0@;6]D:69I<V5R="(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8Y(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@X"B,L(&9U>GIY"FUS9VED(")-;V1I9FEE9"!$871E
M(@IM<V=S='(@(E-I<W0@;6]D:69I<V5R="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@HC+"!F=7IZ>0IM
M<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")%;F1R92(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HV-3<*(RP@9G5Z>GD*;7-G:60@(DUO9'5L92(*;7-G<W1R
M(")2;VQL92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-CDW"B,L
M(&9U>GIY"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(E)O;&QE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*(RP@9G5Z>GD*
M;7-G:60@(DUO;F%C;R(*;7-G<W1R("),;VMA<VIO;B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM
M<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B5&EL(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U.#<*(RP@9G5Z>GD*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM
M<V=S='(@(E-L=71T('#E(&UE;&1I;F=E;B(*"B,Z(&QI8B](;W)D92]-86EN
M=&5N86YC92YP:'`Z,S8*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B3>5N961T
M;&EG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B
M36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-;W)O8V-O(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#0*(RP@
M9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")+;W!I97(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0U"B,L(&9U>GIY"FUS
M9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(DMO<&EE<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#8*(RP@9G5Z>GD*;7-G:60@(DUO
M<W1L>2!3=6YN>2(*;7-G<W1R(")+;W!I97(B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HT,C`*(RP@9G5Z>GD*;7-G:60@(DUO=F4@1&]W;B(*
M;7-G<W1R(")F;'ET="!N960B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HT,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")F
M;'ET="!O<'`B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,C@*
M(RP@9G5Z>GD*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B1FQY='0@=&EL
M(&CX>7)E(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#$V"B,L
M(&9U>GIY"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(F9L>71T(&]P<"(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.3<*;7-G:60@
M(DUO=F4@9&]W;B(*;7-G<W1R(")F;'ET="!N960B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.3<*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
M9FQY='0@;W!P(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")-;WIA;6)I<75E(@IM<V=S
M='(@(D%D=F%R<V5L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-C@*;7-G
M:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R-@HC+"!F=7IZ>0IM<V=I9"`B375L
M=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(D9I;'1E<FEN;G-T:6QL:6YG97(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,T(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B2V]N7W1O97(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N
M<&AP.C4Q"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+V5D:70N<&AP.C$R-`IM<V=I9"`B37D@4&]R=&%L($QA>6]U
M="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`B;F%V;B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?
M8F]T=&]M+FEN8SHW"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDW(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`U"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T;F5F+G!H<#HT,2!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU.#,*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%V;B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYA=7)U(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C<P-@IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(E1R96YG97(@:&%N
M9&QI;F<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYY('!O
M<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYY
M('!O<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B
M"FUS9W-T<B`B3GD@<&]S="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C`U"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-PIM<V=I9"`B3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,#D*;7-G:60@(DYE='-C87!E($-!('!O;&EC
M>2!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,#@*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`V"FUS9VED(").971S
M8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8Q,`IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C$Q"B,L(&9U>GIY"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT(@IM<V=S='(@(DEN=&5T('!E<G-O;FQI9R!S97)T:69I:V%T('1I
M;&=J96YG96QI9RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P
M-`HC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*
M;7-G<W1R(")3971T(&EN;B!S97)T:69I:V%T(&AE<B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-#(*(RP@9G5Z>GD*;7-G:60@(DYE='=O<FLB
M"FUS9W-T<B`B3GDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<V"FUS9VED(").979E<B(*;7-G<W1R(")!;&1R:2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("),96=G('1I;"!E
M;B!N>2!K;VYT86MT(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G
M<W1R(")&:7)M86MA=&5G;W)I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V
M(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Y
M"B,L(&9U>GIY"FUS9VED(").97<@36]O;B(*;7-G<W1R(").>2!P;W-T(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B
M3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY
M"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").>2!P;W-T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B
M3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B3F5W<R(*;7-G<W1R
M(").>6AE=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P<&4B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHR,2!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHT-@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$S-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHS,@IM<V=I9"`B3F5X
M="(*;7-G<W1R(").97-T92(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z
M,3$U(&QI8B](;W)D92]522]086=E<BYP:'`Z,3$V"FUS9VED(").97AT(%!A
M9V4B"FUS9W-T<B`B3F5S=&4@<VED92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="!0:&%S92(*;7-G<W1R(").97-T
M92!S:61E(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HS-S`*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R(")4:6QB86ME('1I;"!686QG(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:6-A
M<F%G=6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G
M<W1R(")!;&1R:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M(")!;&1R:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*
M(RP@9G5Z>GD*;7-G:60@(DYI9VAT(@IM<V=S='(@(DCX>65S="(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B3FEU92(*;7-G<W1R(")/8G,A(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.`IM<V=I9"`B3F\B"FUS9W-T
M<B`B3F5I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HQ
M-@IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(N<&AP.C$Q,0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,C(*;7-G:60@(DYO(&)A=&-H
M('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HW."!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR,C0*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C0V"FUS9VED(").;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S
M:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-34*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS
M9W-T<B`B06YG<F4@96YD<FEN9V5R(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ-#0*;7-G:60@(DYO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B
M92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DYO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B<E<R<@8FQE(&QA9W0@=&EL(')E='1I9VAE='-S>7-T96UE="XB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U.`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V]M;6%N9"!S<&5C:69I960N(@IM<V=S='(@(DEN9V5N(&)R=6ME<B!V86QG
M="XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W,R!L:6(O2&]R9&4N<&AP.C0Y,R!L
M:6(O2&]R9&4O571I;"YP:'`Z-S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF
M:7-E<G0@9F]R(%-13"UK871E9V]R:65R+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW-S,*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("));F=E;B!K
M;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!,1$%0+6EN<W1I;&QI
M;F=E;F4N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C4Y-0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E
M<VEF:7-E<G0@9F]R(%-13"UK871E9V]R:65R+B(*"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C<U-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS
M9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@
M4U%,+6MA=&5G;W)I97(N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,C,*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C4Y"B,L(&9U
M>GIY"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
M26YG96X@;65L9&EN9V5R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@96YT<GD@=VET:"!T:&4@:60@)R5S
M)R!E>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@Y,@HC+"!F=7IZ>0IM<V=I
M9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")6:7,@<VQE='1E9&4@96QE
M;65N=&5R(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"B,L(&9U>GIY
M"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B26YG96X@=F5D;&5G
M9R!F=6YN970N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-3(R"B,L(&9U>GIY"FUS9VED(").;R!L;V-A;&4@<W!E
M8VEF:65D+B(*;7-G<W1R("));F=E;B!B<G5K97(@=F%L9W0N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C$*(RP@9G5Z>GD*
M;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B4W9A<B!T:6P@
M;&ES=&5N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U
M.`HC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T
M<B`B26YG96X@;65L9&EN9V5R(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8V,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I
M960N(@IM<V=S='(@(DEN9V5N(&)R=6ME<B!V86QG="XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8R"B,L(&9U>GIY"FUS9VED(").
M;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("));F=E;B!B<G5K97(@=F%L
M9W0N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"B,L(&9U>GIY"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B26YG96X@=F5D
M;&5G9R!F=6YN970N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3,*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N
M(&5R('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O
M<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U
M+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K
M;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E
M<FEN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY-PHC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E
M<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C@R(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX
M.`HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"B,L(&9U>GIY"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E
M<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W!A<W-W9"YP:'`Z,3,Y"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("))
M;F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!344PM875T
M96YT:7-E<FEN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@Y"B,L
M(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R
M('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,3@*;7-G:60@(B(*(DYO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$Y"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DYO
M=&%T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R
M("));F=E;B!M96QD:6YG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-38*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")696YN;&ES="!S
M:W)I=B!I;FX@8G)U:V5R;F%V;B!O9R!P87-S;W)D(@H*(SH@;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=F%L:60@
M6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B26YG96X@=D-A<F0@9&%T82!F
M=6YN970N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3`V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY,3<@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDS-`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@=F%L=65S(@IM<V=S='(@(DEN9V5N(&UE;&1I;F=E<B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3`*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,#0*
M;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R(")):VME(&1E;'1A9V5R
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.#@*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B26YG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(").;W)D
M:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@
M(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`HC+"!F=7IZ
M>0IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(:F5L<"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.`HC+"!F=7IZ>0IM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<FUA;"(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L(&9U>GIY"FUS9VED
M(").;W0@069T97(B"FUS9W-T<B`B26MK92!K;&%D9"(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C8S"B,L(&9U>GIY"FUS9VED(").;W0@0F5F
M;W)E(@IM<V=S='(@(DEK:V4@:VQA9&0B"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C,U-@HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(E-O<G1E<FEN9W-R96MK96;X;&=E(@H*(SH@;&EB+U9&4R])4T]7<FET97(N
M<&AP.C8W(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-#D*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C8P"B,L(&9U>GIY"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM
M<V=S='(@(DEK:V4@<VQE='1E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B26MK92!S;&5T=&5T(@H*(SH@;&EB+U9&4RYP:'`Z,3@T(&QI
M8B]61E,N<&AP.C(P,R!L:6(O5D93+G!H<#HR,C$@;&EB+U9&4RYP:'`Z,C,X
M"B,Z(&QI8B]61E,N<&AP.C(U-2!L:6(O5D93+G!H<#HR-S$@;&EB+U9&4RYP
M:'`Z,C@Y(&QI8B]61E,N<&AP.C,R-0HC.B!L:6(O5D93+G!H<#HS.#@@;&EB
M+U9&4RYP:'`Z-#<R(&QI8B]61E,N<&AP.C4T-"!L:6(O5D93+G!H<#HU-C(*
M(RP@9G5Z>GD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(D1E;B!F
M;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK:V4@<W1O='1E="XB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-R!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,34Y"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1A=&5R
M(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B
M3F]T:6-E(@IM<V=S='(@(D]B<R$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@T(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
M06QD<FDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`T,0HC+"!F=7IZ>0IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30R,@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E
M<G,B"FUS9W-T<B`B,3`P('1E9VXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-`HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS
M9W-T<B`B06YT86QL(&MO;&]N;F5R(&D@;W!P<W5M;65R:6YG<W9I<VYI;F=E
M;CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30Q."!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@HC+"!F=7IZ>0IM
M<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B06YT86QL(&MO;&]N;F5R
M(&D@;W!P<W5M;65R:6YG<W9I<VYI;F=E;CHB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(").=6UB97)S
M(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R(")$=2!L86=E<B!E;B!D:7-T<FEB=7-J;VYS(&QI<W1E
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0X
M,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-C,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T('!O
M+W1R86YS;&%T:6]N+G!H<#HQ-#@*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S
M,CD*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T
M(@IM<V=S='(@(D5M;F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B
M3V)J96MT970@8FQE(&EK:V4@9G5N;F5T(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3,W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C(S"B,L(&9U>GIY
M"FUS9VED(")/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<R(*;7-G<W1R(")/
M<F1S='ER97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y.0HC+"!F=7IZ
M>0IM<V=I9"`B3V-T86PB"FUS9W-T<B`B1&%G;&EG(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,R!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E
M(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S`T"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2V]N=&]R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")/;6%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@
M<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B1&5N;F4@=&IE;F5R
M96X@<W3X='1E<B!I:VME(&1E;&EN9R!A=B!M87!P97(N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R("));F=E;B!V961L96=G(&9U;FYE="XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@S-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DU-0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R(")%<&]S=&%D<F5S<V5N(&1I;CHB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"B,L(&9U>GIY
M"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")6:7-E(&EN
M;FAO;&0@:2!E="!E9V5T('9I;F1U+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,C4W"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@
M97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-30*(RP@9G5Z>GD*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B2&5N=&4@;GEE(&UE;&1I;F=E<B!I
M(&5T(&5G970@=FEN9'4_(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S
M"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8P,`IM<V=I9"`B3W!T
M:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B5F%L9V9R:2!D96QT86=E<B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P
M=&EO;G,B"FUS9W-T<B`B5F%L9R(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HR
M.2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")686QG(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B3W!T:6]N
M<SHB"FUS9W-T<B`B5F%L9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G:60@(D]R9&5R960@3&ES
M="(*;7-G<W1R(")696QG(&QI<W1E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G
M<W1R(")/<F=A;FES97)I;F<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y,@HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*
M;7-G<W1R(")/<F=A;FES97)I;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3(W"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7-E
M<FEN9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"B,L(&9U>GIY"FUS
M9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")(
M86YD;&EN9V5R(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,C`@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M.0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B06YN96X@:6YF
M;W)M87-J;VXB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"B,L
M(&9U>GIY"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("),86=R
M92!686QG(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HX,PHC+"!F=7IZ
M>0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D]M861R97-S97)I;F<@9F5I;&5T+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$R-SD*(RP@9G5Z>GD*;7-G:60@(E!'4"!$:6=I
M=&%L(%-I9VYA='5R92(*;7-G<W1R(")3:WEG9V5L96=G('-I9VYA='5R/R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,C@*(RP@9G5Z>GD*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`M:W)Y<'1E<B!M
M96QD:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,X-PHC+"!F
M=7IZ>0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B3V9F96YT;&EG
M(%!'4"UN^&MK96QR:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3,V-@HC+"!F=7IZ>0IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M82(*;7-G<W1R(")01U`@<VEG;F5R+VMR>7!T97(@;65L9&EN9R(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G
M:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S0X"B,L(&9U>GIY"FUS9VED(")032!,:6=H="!286EN
M(@IM<V=S='(@(DQO9V<@:6YN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,T.0HC+"!F=7IZ>0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R
M(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC
M+"!F=7IZ>0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,0HC+"!F=7IZ>0IM<V=I9"`B
M4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4R"B,L(&9U>GIY"FUS9VED(")032!4+5-T
M;W)M<R(*;7-G<W1R(")&<F$B"@HC.B!L:6(O87!I+G!H<#HQ,C8*;7-G:60@
M(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@HC+"!F=7IZ>0IM<V=I9"`B
M4&%D9&EN9R(*;7-G<W1R(")5='9I9&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B1&%T;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E!A
M;&%U(@IM<V=S='(@(D4M<&]S="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED
M(")086YA;6$B"FUS9W-T<B`B;F%V;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!A<'5A($YE=R!'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4&%R86=U87DB
M"FUS9W-T<B`B12UP;W-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,T-PHC+"!F=7IZ>0IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M(")+;W!I97(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<T(&QI8B](;W)D92]&;W)M+G!H<#HR,#`R"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3<@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-C<*;7-G:60@(E!A<W-W;W)D
M(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C$S-30*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*
M;7-G<W1R(")087-S;W)D(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H
M<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R
M87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,W"B,L(&9U>GIY"FUS9VED(")0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")6:7,@;6%I;&QI
M<W1E(&EN9F]R;6%S:F]N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4&%S
M<V]R9"(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,3@*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(E!A<W-P:')A
M<V4@<W1E;6UE<B!I:VME(&]V97)E;G,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B1&%T
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*(RP@
M9G5Z>GD*;7-G:60@(E!A=&@B"FUS9W-T<B`B1&%T;R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C0@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHT"FUS9VED(")096YD:6YG(%-I9VYU<',Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E)O;&QE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*(RP@9G5Z>GD*
M;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4VMR:78@=70B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.C8*;7-G:60@(E!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")5=&;X<B!V
M961L:6ME:&]L9'-O<&5R87-J;VYE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.38*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\B"FUS9W-T<B`B571F^'(@=F5D;&EK96AO;&1S;W!E<F%S
M:F]N97(@=F5D(&EN;FQO9V=I;F<_(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C8Q(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV-`HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(E!E<FUI
M<W-I;VXB"FUS9W-T<B`B4&5R<V]N;&EG(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES
M<VEO;B`G)7,G(&YO="!D96QE=&5D+B(*;7-G<W1R(")$96X@9F]R97-P=7)T
M92!O<'!G879E;B!E<B!I:VME(&EM<&QE;65N=&5R="XB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HR,C0@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.CDS
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("(E<R!01U`@861M:6YI<W1R87-J;VXB"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T.2!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$U,@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@HC+"!F=7IZ
M>0IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R(@IM<V=S='(@(E!E<G-O;FQI9R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@
M26YF;W)M871I;VXB"FUS9W-T<B`B4&5R<V]N;&EG(&EN9F]R;6%S:F]N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:&EL
M:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y.0IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#<*;7-G:60@(E!H;W1O
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")0:71C86ER;B(*;7-G
M<W1R(")$871O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT.`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*
M;7-G<W1R(")%<B!D=2!324M+15(@<.4@870@9'4@^&YS:V5R(.4@<VQE='1E
M(&1E('9A;&=T92!O<'!F^')I;F=E;F4_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N(@IM<V=S='(@(D5R(&1U(%-)2TM%4B!PY2!A="!D=2#X
M;G-K97(@Y2!S;&5T=&4@9&4@=F%L9W1E(&]P<&;X<FEN9V5N93\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4U-@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B5F5N;FQI9W-T
M('-K<FEV(&EN;B!D970@;GEE(&YA=FYE=#HB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS
M9W-T<B`B5F5N;FQI9W-T('-K<FEV(&EN;B!N879N970@<.4@9&5N(&YY92!M
M87!P96XZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R.3D*(RP@9G5Z>GD*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S
M='(@(E9E;FYL:6=S="!R971T('1V971Y9&EG92!E;&QE<B!U9WEL9&EG92!A
M9')E<W-E<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U,@IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T,S0*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I=B!I;FX@9&5T
M(&YY92!N879N970Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+B(*;7-G<W1R(")696YN;&EG<W0@9VD@970@<V%M;65N9')A9R!A
M=B!P<F]B;&5M970N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M."!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")6
M96YN;&ES="!S:W)I=B!I;FX@8G)U:V5R;F%V;B!O9R!P87-S;W)D(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C$R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3<*;7-G:60@(E!L96%S92!R97!O<G0@86YY(&)U9W,@=&\@:3$X
M;D!L:7-T<RYH;W)D92YO<F<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T,`IM<V=I9"`B(@HB4&QE87-E
M(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S
M96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S
M='(@(B(*(E9E;FYL:6=S="!S92!O=F5R(&1E;B!F^&QG96YD92!I;F9O<FUA
M<VIO;F5N+"!V96QG('/E(&5N(&AA;F1L:6YG(&9R82!M96YY96X@(@HB;F5D
M96YU;F1E<BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT,S4*;7-G:60@(E!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@
M=&AE(&UE;G4@8F5L;W<N(@IM<V=S='(@(E9E;FYL:6=S="!V96QG(&5N(&AA
M;F1L:6YG(&9R82!M96YY96X@;F5D96YU;F1E<BXB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")6
M96YN;&EG<W0@<VMR:78@:6YN(&1E="!N>64@;F%V;F5T.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*(RP@9G5Z
M>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B4&]L:71I8W,B"FUS
M9W-T<B`B4VSE('-A;6UE;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-38*(RP@9G5Z>GD*;7-G:60@(E!O;&QS(@IM<V=S='(@(E-LY2!S86UM
M96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*
M;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*
M;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C0@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U!R969S+VQD87`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:6UP.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG
M92!)34%0('5T=FED96QS96XN(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I
M;VXN<&AP.C,V"B,L(&9U>GIY"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?:6UP.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!)34%0('5T
M=FED96QS96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y.`HC
M+"!F=7IZ>0IM<V=I9"`B4')E<V5N=&%T:6]N<R(*;7-G<W1R(")&;W)R:6=E
M(&UE;&1I;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,PHC+"!F=7IZ
M>0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4W"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(*;7-G<W1R(")087-S;W)D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B4')E<W-U
M<F4Z("(*;7-G<W1R(")087-S;W)D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$X.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B
M"FUS9W-T<B`B1F]R:.5N9'-V:7-N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"B,L(&9U>GIY
M"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B5FES('9E9&QE9V<@:2!E="!E9V5T('9I;F1U(@H*(SH@;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<#HW,2!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C<R
M"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(D9O<G)I9V4@<VED92(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,S8P"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(D9O<G)I9V4@;65L9&EN9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P
M.0HC+"!F=7IZ>0IM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B1&EN('!R
M:79A=&4@;OAK:V5L(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F
M=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(");4')O8FQE;7)A<'!O<G1=
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3$R"FUS9VED(")0<F]B;&5M
M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)L96UB97-K<FEV96QS92(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,38*;7-G:60@(E!R;VIE8W1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#DU(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3<R"B,L(&9U>GIY"FUS9VED(")0<F]M<'0@=&5X
M="(*;7-G<W1R(")2971T970@=&5K<W0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,#D*(RP@9G5Z>GD*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B1&EN(&]F9F5N=&QI9V4@;OAK:V5L(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@(E!U8FQI8R!+97D@06QG
M;W)I=&AM(@IM<V=S='(@(D]F9F5N=&QI9R!01U`M;OAK:V5L<FEN9R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B4&5R<V]N;&EG(%!'4"UN^&MK96QP87(@9V5N97)E
M<G0N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B
M4')O=&]K;VQL.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E%A=&%R(@IM<V=S='(@
M(E-T87)T(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C<P"FUS9VED(")1=65R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@
M*"5D(&)I="DB"FUS9W-T<B`B3V9F96YT;&EG(%!'4"UN^&MK96P@=&5K<W0B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T.`HC+"!F=7IZ>0IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(D9I;'1E<FEN;G-T:6QL:6YG97(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4S"B,L(&9U>GIY
M"FUS9VED(")286EN(@IM<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,U-`HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!%
M87)L>2(*;7-G<W1R(")!=G-LY71T.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4U"B,L(&9U>GIY"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B3&]G9R!I;FXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4V"B,L(&9U>GIY"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")6
M:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-PHC+"!F
M=7IZ>0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")6:7-T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U.`HC+"!F=7IZ>0IM<V=I
M9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B4F%N9&]M($9O<G1U;F4B
M"FUS9W-T<B`B3F]T871E<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C<Q(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"B,L
M(&9U>GIY"FUS9VED(")2871I;R(*;7-G<W1R("),;VMA<VIO;B(*"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,CDU('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"B,L(&9U>GIY"FUS9VED(")2
M96%D(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S
M(@IM<V=S='(@(DYY92!M96QD:6YG97(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@
M9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VXB"FUS9W-T<B`B1VIE;F]P<'1A('-E<VIO;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(E)E9G)E<V@@1'EN86UI
M8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,Q"B,L(&9U>GIY"FUS9VED(")2969R97-H(%!O<G1A;"!6
M:65W.B(*;7-G<W1R(")/<'!D871E<B!M87!P979I<VYI;F<Z(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@X.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(P-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(R-PHC+"!F=7IZ>0IM<V=I9"`B4F5G97@B
M"FUS9W-T<B`B3G5L;'-T:6QL(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M,S0*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S(T"FUS9VED(")296UA<FMS(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0U-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M-S8*;7-G:60@(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(DAU<VL@;&5D:6<O;W!P=&%T="UI;F9O<FUA<VIO;BXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"B,L(&9U>GIY"FUS9VED(")2
M96UO=&4@4V5R=F5R<R(*;7-G<W1R(")4:F5N97(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C0P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*
M;7-G<W1R(")&:F5R;B!P87(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R
M(")&:F5R;B!K:6QD92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,S(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS
M9W-T<B`B1FIE<FX@:VEL9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R
M;6%T=&EN9R(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3@*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@(E-L971T(&9R82!K86QE
M;F1E<F5N(&UI;B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,V
M"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3DV"FUS9VED(")296UO=F4@<V%V960@
M<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM
M<V=S='(@(D9J97)N(&MI;&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]V92!U<V5R(@IM<V=S='(@(D9J97)N(&MI;&1E(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B1FIE<FX@:VEL
M9&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ
M.3<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C@P
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T.0IM
M<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B4W9A<B!S96YD="XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3D*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8X"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0W.`IM<V=I9"`B4F5P
M;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B4W9A<B!A
M="!M96QD:6YG96X@:6MK92!S=/AT=&5S(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8V"FUS9VED(")297!L>2!W:71H(&9R
M964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B4W9A<B!M960@
M;&5D:6<O;W!P=&%T="!F;W(@9&4@;F5S=&4@=&\@;>5N961E;F4N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8U"FUS9VED
M(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(E-V87(@;65D(&1E;B!F;W)E<W!U<G1E(&QE9&EG+V]P<'1A
M='0M:6YF;W)M87-J;VYE;BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HQ.#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<&QY.B`E<R(*;7-G<W1R(")3=F%R.B(*"B,Z(&QI8B](;W)D92]24$,O
M>&UL<G!C+G!H<#HQ,SD*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS
M=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,3@P(&QI8B](;W)D92YP:'`Z-3`S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@
M:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4.5K<F5V9"`G=6ED)R!E
M<B!I:VME('-P97-I9FES97)T(&D@:6YS=&EL;&EN9W-K;VYF:6=U<F%S:F]N
M96XN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8P,2!L:6(O5D93+V9T<"YP:'`Z
M-S<Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0Y6MR979D("=U:60G(&5R(&EK
M:V4@<W!E<VEF:7-E<G0@:2!I;G-T:6QL:6YG<VMO;F9I9W5R87-J;VYE;BXB
M"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S8Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B4.5K<F5V9"`G=6ED)R!E<B!I:VME('-P
M97-I9FES97)T(&D@:6YS=&EL;&EN9W-K;VYF:6=U<F%S:F]N96XN(@H*(SH@
M;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R.0IM<V=I9"`B4F5Q=6ER
M960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-3DR"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N
M="(*;7-G<W1R(")/8FQI9V%T;W)I<VL@9&5L=&%G97(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,Y(&QI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<#HS,38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0T
M"FUS9VED(")297-E="(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@
M4&%S<W=O<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(D=J96YO<'!T82!S97-J;VXB"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-C8@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q
M;'-H96QL+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R
M(")3^&ME<F5S=6QT870B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(Q"FUS
M9VED(")297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$Y"B,L(&9U>GIY"FUS9VED(")297-U
M;'1S.B(*;7-G<W1R(")3^&ME<F5S=6QT870B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL
M(%9A;&<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DW(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2975N:6]N(@IM<V=S='(@(D]B
M<V5R=F5R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")2979E<G0@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R(")"92!O;2!L979E<FEN9W-B96MR969T96QS
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S`*(RP@9G5Z>GD*;7-G
M:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")4:6QB86ME
M('1I;"!686QG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"B,L(&9U
M>GIY"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E-K:G5L="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC+"!F
M=7IZ>0IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B2/AY97-T(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,#8*(RP@9G5Z>GD*;7-G:60@(E)I9VAT(&AE861E
M<B(*;7-G<W1R(")%:W-E;7!E;'9E<F1I97(Z(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,Q,#(*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G
M<W1R(")%:W-E;7!E;'9E<F1I97(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"B,L(&9U>GIY"FUS9VED
M(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B3&%V('!R:6]R:71E="(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,W(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I9"`B4F]L
M92(*;7-G<W1R(")2;VQL92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)O;6%N:6$B
M"FUS9W-T<B`B3F]R;6%L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(#$X,"(*;7-G
M<W1R(")F;'ET="!O<'`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C`U"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@3&5F="(*;7-G
M<W1R(")F;'ET="!O<'`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C$Q"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS
M9W-T<B`B1FQY='0@=&EL(&CX>7)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0HC+"!F=7IZ>0IM<V=I9"`B
M4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B3&%V('!R:6]R:71E="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*
M(RP@9G5Z>GD*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(DQA=B!P
M<FEO<FET970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B4VSE
M('-A;6UE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@
M(E)O;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Y"B,L(&9U>GIY"FUS9VED(")2=6XB"FUS9W-T<B`B3V)S97)V97(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`HC+"!F
M=7IZ>0IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS,#`*;7-G:60@(E,O34E-12!#<GEP
M=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N
M8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(DMR>7!T97(@;65D(%,O34E-12(*
M"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@V"B,L(&9U>GIY"FUS9VED
M(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D]M861R97-S97)I;F<@9F5I;&5T+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT.#$*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B
M"FUS9W-T<B`B365L9&EN9W-V:7-N:6YG(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B4U,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W-0IM<V=I
M9"`B4U-((@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS.`IM<V=I9"`B4U5#0T534R(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ,S`*;7-G:60@(E-?44P@4VAE;&PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B4V$B"FUS9W-T<B`B3&%G<F4@<V]M
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4V%I
M;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B4V%M
M;V$B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PHC+"!F=7IZ>0IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-A;R!4;VUE
M(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E
M<B(*;7-G<W1R(")3=&%T+T9Y;&ME("A!<F)E:60I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%U
M9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("),86=R92!S;VTB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("),86=R92!S;VTB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E("<E<R<B"FUS9W-T<B`B3&%G<F4@
M<V]M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V
M92!/<'1I;VYS(@IM<V=S='(@(DQA9W)E(%9A;&<B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38Q"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C8Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")396YD('-I<W1E
M(&EN9F]R;6%S:F]N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`G)7,G+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9V4@
M5D93+6)A8VME;F0Z("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED(")38VEE;F-E(@IM<V=S='(@(E-I9VYE<G0B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-2!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHQ-PIM<V=I9"`B4V5A<F-H(@IM<V=S='(@
M(E/X:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*(RP@9G5Z
M>GD*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E/X:R`E<R(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")396%R8VAI;F<@2&]R9&4@87!P;&EC871I;VYS(&EN("5S(@IM
M<V=S='(@(DEN;G-T:6QL:6YG97(@9F]R('/X:R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C,*(RP@9G5Z>GD*;7-G:60@(E-E87)C:&EN9R!G971T97AT
M(&)I;F%R:65S+BXN(@IM<V=S='(@(DEN;G-T:6QL:6YG97(@9F]R('/X:R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.34X"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@1FEL97,B"FUS9W-T<B`B5F5L9R!A;&QE(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R(")696QG(&5N(&1A=&\B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9W)O
M=7`@=&\@861D(@IM<V=S='(@(E9E;&<@96X@:V]N=&\B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M82!N97<@;W=N97(B"FUS9W-T<B`B5F5L9R!I;F=E;B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&$@<V5R=F5R(@IM<V=S='(@(E9E;&<@96X@9&%T;R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,34V"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M82!U<V5R('1O(&%D9"(*;7-G<W1R(")696QG(&5T(&9E;'0B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C8U-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E9E;&<@96X@9&%T;R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX,30*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5F5L9R!I;F=E
M;B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E9E;&<@:V%R
M86MT97)E;F4@9'4@=')E;F=E<B!F<F$@8F]K<V5N('5N9&5R+B!$=2!K86X@
M9&5R971T97(@:V]P:65R92!O9R`B"B)L:6UE(&1E;2!I;FX@9G)A('1E:W-T
M9F5L=&5T+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")696QG(&1A
M=&]S:VEL;&5T96=N.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T
M"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")696QG
M(&1A=&]F;W)M870B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.C@U"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z(@IM<V=S='(@(E9E;&<@9&%T;W-K:6QL971E9VXZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!F;W)M870Z(@IM<V=S='(@(E9E;&<@=&ED<V9O<FUA=#HB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C8T"FUS9VED(")396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5F5L9R!T;R!S86US=F%R96YD92!F
M96QT+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.38*;7-G:60@(E-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(S.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R(")696QG(/AN<VME="!S<'+E:SHB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3,*;7-G
M:60@(E-E;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(E-E;F0@<VES
M=&4@:6YF;W)M87-J;VXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")3
M96YD('!R;V)L96UR87!P;W)T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV-`HC+"!F=7IZ>0IM<V=I9"`B4V5N9"!335,B"FUS
M9W-T<B`B4V5N9"!M96QD:6YG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V5N96=A;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-`HC+"!F=7IZ>0IM<V=I
M9"`B4V5N<V]R.B`B"FUS9W-T<B`B("`@($5M;F4Z("(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#(@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"B,L(&9U>GIY"FUS9VED(")397!T96UB
M97(B"FUS9W-T<B`B365M;R(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<R-0HC+"!F=7IZ
M>0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").879N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@9G5Z>GD*;7-G
M:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B365L9&EN9W-F96QT
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R.38*(RP@9G5Z>GD*;7-G:60@
M(E-E="(*;7-G<W1R(")696QG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B
M4V5T="!S:61E(&]P<&1A=&5R:6YG+"!O9R!V:7-N:6YG<R!V86QG+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B(@HB
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(E-E='0@<VED92!O<'!D871E<FEN9RP@;V<@=FES;FEN9W,@
M=F%L9RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"B,L(&9U>GIY
M"FUS9VED(")3971U<"(*;7-G<W1R(")696QG(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S@*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<S"B,L(&9U>GIY"FUS9VED(")3:&]P<&EN9R(*;7-G
M<W1R(")6:7-T(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R
M="!S86UM96YD<F%G.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S8*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W.0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R(*;7-G<W1R(")6:7-T(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T.0IM<V=I9"`B(@HB4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@P"FUS9VED(")3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-S4S"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#`R"B,L(&9U>GIY"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")6
M:7-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q-0HC+"!F=7IZ>0IM
M<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R
M(")6:7-E(&9I;'1E<FEK;VYE="!I(&UE;GEE;C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")6:7-E(&9I
M;'1E<FEK;VYE="!I(&UE;GEE;C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B1F]R:.5N9'-V:7-N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")&;W)H
MY6YD<W9I<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")&;W)HY6YD
M<W9I<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN
M9R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S4Q"B,L(&9U>GIY"FUS9VED
M(")3:&]W('5P;&]A9"(*;7-G<W1R(")6:7,@<VQE='1E9&4@96QE;65N=&5R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U.0HC+"!F=7IZ
M>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,V,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R
M<R!%87)L>2(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8R"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS.3$*(RP@9G5Z>GD*
M;7-G:60@(E-H<FEN:R(*;7-G<W1R("),;V=G(&EN;B(*"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C8X-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HW-#8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#`T(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C@V-@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HY,#$@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M.3,X"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDV-B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HY.38*;7-G:60@(E-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S@*(RP@9G5Z>GD*;7-G
M:60@(E-I9VX@=7`B"FUS9W-T<B`B4VEG;F5R="(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.#D*;7-G:60@(E-I9VX@=7`@:68@;F]T(')E9VES
M=&5R960B"FUS9W-T<B`B4F5G:7-T<F5R(&1E9R!O;2!I:VME(')E9VES=')E
M<G0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<S-@HC+"!F=7IZ
M>0IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D1I;B!S:6=N871U<CHB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<S-0HC+"!F=7IZ>0IM<V=I
M9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")$:6X@<VEG;F%T=7(Z
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-0HC+"!F=7IZ>0IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(D1I;B!S
M:6=N871U<CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DQ(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C`W(&QI8B](;W)D92]&;W)M+G!H<#HQ,C(Y"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C,P(&QI8B](;W)D92]&;W)M+G!H<#HR.3$Y
M(&QI8B](;W)D92]&;W)M+G!H<#HS,3`X"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@W"FUS9VED
M(")3:7IE(@IM<V=S='(@(E-T^')R96QS92(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z.0IM<V=I9"`B4VMI<"!-86EN
M=&5N86YC92(*;7-G<W1R(")(;W!P(&]V97(@=F5D;&EK96AO;&0B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-#,Q('!O+W1R86YS;&%T:6]N+G!H<#HT.#0@
M<&\O=')A;G-L871I;VXN<&AP.C8V-@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.#8P('!O+W1R86YS;&%T:6]N+G!H<#HQ,C`T"FUS9VED(")3:VEP<&5D+BXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-L;W9A:VEA(@IM<V=S
M='(@(DYO<FUA;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-L;W9E;FEA(@IM<V=S
M='(@(DYO<FUA;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-C,*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T<B`B5FES="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C0*(RP@9G5Z>GD*;7-G:60@
M(E-N;W<@4VAO=V5R(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8U"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*
M;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V-PHC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T
M<B`B5FES="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<V"B,L(&9U>GIY
M"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B("`@($5M;F4Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@P"FUS9VED(")3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3
M;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"B,L(&9U>GIY
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(DYO<FUA;"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-0HC+"!F=7IZ>0IM<V=I
M9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4V]R=&5R:6YG<W)E
M:VME9OAL9V4B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3@Q(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,3,*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E-O=7)C
M92!A9&1R97-S(@IM<V=S='(@(D9I<FUA861R97-S92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-O
M=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-@IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW.`IM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B
M4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(:F5L<"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED
M(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,34*(RP@9G5Z>GD*
M;7-G:60@(E-P86-E<B(*;7-G<W1R("),86=R92!S;VTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(RP@9G5Z
M>GD*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B571V:61E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G
M:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*(RP@9G5Z>GD*
M;7-G:60@(E-P86EN(@IM<V=S='(@(E5T=FED97(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.34*(RP@9G5Z>GD*;7-G:60@(E-P86TB"FUS9W-T
M<B`B3&%G<F4@<V]M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS
M9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")3<&5S:6%L
M=&5G;FEN;G1A<W1I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"B,L(&9U>GIY"FUS9VED(")3<&QI="!C
M96QL(@IM<V=S='(@(E9E;&<@86QL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*(RP@9G5Z>GD*;7-G:60@
M(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")696QG(&%L;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"B,L(&9U
M>GIY"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B5F5L9R!A;&QE(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R
M=',B"FUS9W-T<B`B5FEK=&EG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")3<FD@3&%N
M:V$B"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C@@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@HC+"!F=7IZ>0IM
M<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E-T87(@5')E:R(*
M;7-G<W1R(")3=&%R="(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C0T,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU-#@*;7-G:60@(E-T87)T(@IM<V=S='(@(E-T87)T(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(W
M.3@*(RP@9G5Z>GD*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4W1A<G0B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`HC+"!F=7IZ>0IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B4W1A="]&>6QK92`H
M07)B96ED*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4X,R!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HT.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W1A='5S(&9O<B!L
M;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#`T"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R
M(")$:6X@:6YF;W)M87-J;VXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y-@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T
M<B`B1G)A+6%D<F5S<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C(U"B,L(&9U>GIY"FUS9VED
M(")3=')I;F<@;&ES="(*;7-G<W1R(")3=F%R=&5L:7-T92(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#4W"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-3
M72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8F1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B3F]T:7,@
M;'ET=&5R("5S(&EK:V4@9G5N;F5T+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C,U(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<X"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D5M;F4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8V.`HC+"!F=7IZ>0IM<V=I9"`B4W5B:F5C
M="!0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B1&EN(&]F9F5N=&QI9V4@;OAK
M:V5L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,B!L:6(O2&]R9&4O1F]R
M;2]296YD97)E<BYP:'`Z,S$S"FUS9VED(")3=6)M:70B"FUS9W-T<B`B4V5N
M9"(*"B,Z('-I9VYU<"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D("<E<R<@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(E-E;F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3$S(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HS,`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3=6MS97-S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O('1H92!S>7-T96TN(@IM<V=S='(@
M(B5S(&)L92!L86=T('1I;"`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TN(@IM<V=S
M='(@(B5S(&)L92!L86=T('1I;"`E<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C@Q(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D("<E<R<N(@IM<V=S
M='(@(DAE;F1E;'-E;B!B;&4@<VQE='1E="XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(E<R!B
M;&4@;&%G="!T:6P@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M,0HC+"!F=7IZ>0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B2W5N
M;F4@:6MK92!L86=E(%9&4RUB86-K96YD.B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-0HC+"!F
M=7IZ>0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9V4@5D93+6)A8VME;F0Z
M("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")+=6YN92!I:VME
M(&QA9V4@5D93+6)A8VME;F0Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D
M871E9"`G)7,G(@IM<V=S='(@(DEN;G-T:6QL:6YG96YE(&)L92!O<'!D871E
M<G0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!B;&4@;&%G="!T:6P@
M)7,N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-0HC+"!F=7IZ>0IM<V=I9"`B4W5D86XB"FUS9W-T<B`B571V:61E
M<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4U
M.`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")386UM96YD<F%G(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")3=6X@
M4FES92(*;7-G<W1R(")%;6YE(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C<Q"B,L(&9U>GIY"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(D5M;F4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8X"FUS9VED(")3=6YN
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<Y"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D5M;F4B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,38*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@
M(D5M;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<X"B,L
M(&9U>GIY"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B("`@($5M;F4Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#(*(RP@9G5Z>GD*
M;7-G:60@(E-U;G-E="(*;7-G<W1R(")%;6YE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X,0HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B("`@($5M;F4Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-U<&5R<V-R
M:7!T(@IM<V=S='(@(D)E<VMR:79E;'-E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V-0HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R
M("));7!O<G1E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(FYA=FXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC
M+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")N879N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U
M>GIY"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4_AK(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0HC+"!F=7IZ
M>0IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(DQE<W0B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4_AK(@H*(SH@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(E-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5/AM('/X<'!E;&MU<G9E;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*(RP@9G5Z>GD*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B1G)A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,W,`HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,B"FUS
M9W-T<B`B1G)A(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S$*(RP@
M9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E1I='1E;"(*"B,Z(&QI
M8B](;W)D92]522]486)L92YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")486)L
M92(*;7-G<W1R(")4:71T96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<S"B,L(&9U>GIY"FUS9VED(")486)L
M92!0<F]P97)T:65S(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B1F]R
M:.5N9'-V:7-N:6YG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E1A
M:7=A;B(*;7-G<W1R(")3^&LB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T
M<B`B1&%T;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M(")"<G5K97)N879N.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M-C@*;7-G:60@(E1A<VMS(@IM<V=S='(@(D]P<&=A=F5R(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*(RP@9G5Z>GD*;7-G:60@(E1E;&5P
M:&]N92!.=6UB97(B"FUS9W-T<B`B3F%V;B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C@X"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q,@HC+"!F=7IZ>0IM<V=I
M9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*(RP@9G5Z>GD*;7-G:60@
M(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&QI
M8B](;W)D92]496UP;&%T92YP:'`Z,C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP;&%T92`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B5F5D
M;&5G9V5T(&)L92!I:VME(&9U;FYE="XB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B)7,@4$=0(&%D;6EN:7-T<F%S:F]N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0Q"FUS9VED(")496YT
M871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")';V1T82!F;W)E<W#X
M<G-E;"!F;W)E;/AP:6<B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV.#D*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM
M<V=S='(@(D=O9'1A(&9O<F5L^'!I9R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C`S"B,L(&9U>GIY"FUS9VED(")497AT(@IM<V=S='(@(E1E7VMS="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C4*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R(")+=6X@=&5K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED(")4
M97AT(&%L:6=N(@IM<V=S='(@(DYE<W1E('-I9&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"B,L(&9U>GIY"FUS9VED
M(")497AT=&]P(@IM<V=S='(@(E1E7VMS="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")4:&%I("A4
M25,M-C(P*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4:&%I;&%N
M9"(*;7-G<W1R(")3^&LB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.30T"B,L
M(&9U>GIY"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN
M(@IM<V=S='(@(D1U(&AA<B!B;&ET(&QO9V=E="!U="X@/&)R("\^(%1A:VL@
M9F]R(&%T(&1U(&)R=6MT92!S>7-T96UE="XB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@)7,@:&5L<"!F
M:6QE(&9O<B`E<R!D;V5S;B=T('EE="!E>&ES="X@0W)E871I;F<@82!N97<@
M;VYE+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8Y"B,L(&9U
M>GIY"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")$970@97(@:6YG96X@;65L9&EN9V5R(&D@9&5N;F4@<&]S
M=&)O:W-E;BXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"B,L
M(&9U>GIY"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RXB"FUS9W-T<B`B365L9&EN9V5N('-O;2!H87(@8FQI='0@<VMR
M979E="!H87(@8FQI='0@<W1E;F=T+B!!=G-L=71T97(N(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HQ-C`@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ-S$@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ
M.30@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#4@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR,C,*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S4@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HR-S0*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#D*
M;7-G:60@(E1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B
M2V%L96YD97)D871A(&5R('5G>6QD:6<B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C8T"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(D1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK:V4@<W1O='1E="XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4T"B,L(&9U>GIY
M"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")/<'!F^')I;F=E;B!<(B5S
M7"(@8FQE(&QA9W0@=&EL(&%D<F5S<V5B;VME;B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$Q-S$*(RP@9G5Z>GD*;7-G:60@(B(*(E1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI9R!0
M1U`M;OAK:V5L(&5R('#E:W)E=F0@9F]R(.4@=F5R:69I<V5R92!S:6=N97)T
M(&UE;&1I;F<N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8V-@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R(")$96X@9F]R
M97-P=7)T92!O<'!G879E;B!E<B!I:VME('-T;W1T970N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V-PHC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G
M<W1R(")$96X@9F]R97-P=7)T92!O<'!G879E;B!E<B!I:VME('-T;W1T970N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,C<*(RP@9G5Z>GD*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(E/X='1E(&9O<B!P97)S;VYL:6<@4$=0
M(&[X:VME;'!A<B!K<F5V97(@96X@<VEK:V5R('=E8BUT:6QK;V)L:6YG+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<X"B,L
M(&9U>GIY"FUS9VED(")4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U
M<B!C86QE;F1A<BXB"FUS9W-T<B`B2&5N9&5L<V5N(&)L92!L86=T('1I;"!I
M(&1I;B!K86QE;F1E<BXB"@HC.B!L:6(O2&]R9&4N<&AP.C$X,2!L:6(O2&]R
M9&4N<&AP.C4P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,3<T(&QI8B](;W)D92YP:'`Z-#DT"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@
M<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,38T
M"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(V-`IM<V=I
M9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H
M870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@
M97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R
M(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF
M("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L
M>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@U('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!H96QP(&9I;&4@)7,@9&ED
M;B=T('-T87)T('=I=&@@/#]X;6PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.C@X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED
M96YT:71E=&5N(%PB)7-<(B!B;&4@<VQE='1E="XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4
M:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,S8*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-
M1$XN<&AP.C(Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E
M96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#8Q"FUS9VED(")4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C4Y
M"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O4')E9G,N<&AP.C(Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A
M8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S4@;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H
M<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H
M<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HS-2!L
M:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=V5B8W!P+G!H<#HT,`HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<W)C:&EG:&QI=&4N<&AP.C,Y"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]M<V5X8V5L+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*
M;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@7"(E<UPB(&)L
M92!S;&5T=&5T+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@7"(E<UPB
M(&)L92!L86=R970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<
M(B!B;&4@;&%G<F5T+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C(X-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D1E;B!S<&5S:69I<V5R=&4@9FEL96X@96MS
M:7-T97)E<B!I:VME+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D960@
M=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B2&%N9&QI;F=E;B!H87(@8FQI
M='0@;&%G="!T:6P@9&EN(&QI<W1E(&]V97(@:&%N9&QI;F=E<BXB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z,3$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")$96X@<W!E<VEF:7-E<G1E(&9I;&5N(&5K<VES=&5R97(@:6MK
M92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,S$Q"FUS9VED(")4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR
M-3`@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@
M(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T
M<B`B4VEG;F%T=7)E;B!K=6YN92!I:VME(&5R<W1A='1E<RXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HY,PIM<V=I9"`B5&AE
M('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY
M('-T;W)E9"XB"FUS9W-T<B`B0G)U:V5R96YS(&QE9&EG+V]P<'1A='0@:6YF
M;W)M87-J;VX@8FQE(&QA9W)E="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4R"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,#,@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$P-PHC+"!F=7IZ>0IM<V=I9"`B5&AE('=E871H
M97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1E="!E
M<B!I;F=E;B!M96QD:6YG97(@:2!D96YN92!P;W-T8F]K<V5N+B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T
M<B`B5F5D;&5G9V5T(&)L92!I:VME(&9U;FYE="XB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(")$970@97(@:6YG96X@;65L
M9&EN9V5R(&D@9&5N;F4@<&]S=&)O:W-E;BXB"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z,S0P"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B1&5T(&5R(&EN9V5N(&%L=&5R;F%T:79E(&1E;&5R('-O;2!K86X@=FES
M97,@:6YL:6YE+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,SDX"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!D;V5S;B=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F
M;W(@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-34*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG
M("<E<R<@=&\@=&AE('-Y<W1E;2X@)7,N(@IM<V=S='(@(D1E="!O<'!S=&]D
M(&5T('!R;V)L96T@=6YD97(@<VQE='1I;F=E;B!A=B`E<RX@365L9&EN9R!F
M<F$@<V5R=F5R96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M)R5S)R!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")$970@;W!P<W1O9"!E
M="!P<F]B;&5M('5N9&5R('-L971T:6YG96X@878@)7,N($UE;&1I;F<@9G)A
M('-E<G9E<F5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M("(B"B)$970@;W!P<W1O9"!E="!P<F]B;&5M('9E9"!F:F5R;FEN9R!A=B!P
M;W-T8F]K<V5N+B!-96QD:6YG(&9R82!S97)V97)E;B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(D1E="!O<'!S=&]D(&5T('!R;V)L96T@=6YD97(@<VQE='1I
M;F=E;B!A=B`E<RX@365L9&EN9R!F<F$@<V5R=F5R96XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,B"FUS9W-T<B`B1&5T
M(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!O<'!D871E<FEN9R!A=B!H96YD96QS
M96XZ("5S(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T)R;W=S97(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HS.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B
M"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!F;W)S^&L@<.4@
MY2!V:7-E(&1E;FYE(&UE;&1I;F=S9&5L96XB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C0R(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B1&5T(&]P
M<'-T;V0@96X@9F5I;"!V960@:6UP;W)T97)I;F<@878@:&5N9&5L<V5N.B`E
M<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N
M(&9E:6P@=6YD97(@:6UP;W)T97)I;F<@878@:&5N9&5L<V5N.B`E<RXB"@HC
M.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!I;7!O<G1E
M<FEN9R!A=B!H96YD96QS96XZ("5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS
M9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T97)I;F<@878@
M:&5N9&5L<V5N.B`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HY,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I
M;VXZ("5S+B(*;7-G<W1R("(B"B)$970@;W!P<W1O9"!E;B!F96EL('9E9"!I
M;7!O<G1E<FEN9R!A=B!B<G5K97)E;G,@;&5D:6<O;W!P=&%T="UI;F9O<FUA
M<VIO;CH@)2(*(G,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R
M97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U
M;F1E<B!O<'!D871E<FEN9R!A=B!H96YD96QS96XZ("5S(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$P.34@<&\O=')A;G-L871I;VXN<&AP.C$Q,#$@<&\O
M=')A;G-L871I;VXN<&AP.C$R,C8*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS;&%T:6]N
M+G!H<"!W:71H('1H92`B"B)F;&%G("UD('1O('-E92!A;GD@97)R;W(@;65S
M<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V,PHC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@
M;W!P9&%T97)I;F<@878@:&5N9&5L<V5N.B`E<R(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-C4*(RP@9G5Z>GD*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$970@;W!P<W1O
M9"!E;B!F96EL('5N9&5R(&]P<&1A=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<P"B,L(&9U
M>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R(&]P<&1A=&5R:6YG
M(&%V(&AE;F1E;'-E;CH@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,34S"B,L(&9U>GIY"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$
M96YN92!T:F5N97)E;B!S=/AT=&5R(&EK:V4@9&5L:6YG(&%V(&UA<'!E<BXB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HX,@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HY-@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3(*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C`P"FUS9VED(")4
M:&ES(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")$96X@9F]R
M97-P=7)T92!O<'!G879E;B!E<B!I:VME('-T;W1T970N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$X"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,U.0IM<V=I9"`B5&AI<R!A
M8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B1&5N(&9O
M<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!I;7!L96UE;G1E<G0N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3$*(RP@9G5Z>GD*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N(@IM<V=S='(@(B5S('-E<B!I:VME('5T('-O;2!E;B!G>6QD:6<@
M<&]S=&)O:W,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-34*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B5S('-E<B!I:VME('5T('-O
M;2!E;B!G>6QD:6<@<&]S=&)O:W,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,S`*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(E<R!S97(@:6MK92!U
M="!S;VT@96X@9WEL9&EG('!O<W1B;VMS+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3@W"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T
M96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@
M*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX,@IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDW,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`U,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X,0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$Q,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$W-"!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(T.`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(X,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,Y-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,34T-PHC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3DT,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DX.0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`V,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$S,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(P-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,Y,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0S-PHC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T.2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R,@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S8Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S<P,`HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B)7,@:&%R
M(&%V<VSE='0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C`*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#$*;7-G:60@(E1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#@Y"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q.`IM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDX-`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")$971T92!MY2!VYG)E(&5T('1A
M;&PN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C4*;7-G:60@(B(*(E1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C@*;7-G:60@
M(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")$
M971T92!T86QL970@;>4@=N9R92!M:6YS="`Q+B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C@U"B,L(&9U>GIY"FUS9VED(")4:&ES('-C<FEP="!M=7-T
M(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F4N(@IM<V=S='(@(D1E='1E
M('9I;F1U970@;>4@8FQI(.5P;F5T(&9R82`G3GD@;65L9&EN9R<@=FEN9'5E
M="(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT.`HC+"!F=7IZ
M>0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(@IM<V=S='(@(D1E;FYE('1J96YE<F5N('-T^'1T97(@
M:6MK92!D96QI;F<@878@;6%P<&5R+B(*"B,Z(&QI8B](;W)D92]296=I<W1R
M>2YP:'`Z,30W"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,3(V"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM
M<V=S='(@(D1E='1E(&WE(';F<F4@970@=&%L;"XB"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M(@IM<V=S='(@(D1E='1E('9I;F1U970@;>4@8FQI(.5P;F5T(&9R82`G3GD@
M;65L9&EN9R<@=FEN9'5E="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-S$*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(R-0IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q,0HC+"!F=7IZ>0IM<V=I
M9"`B5&EM92(*;7-G<W1R(")4:71T96PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S$Q"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B1F]R;6%T('#E(&YA=FXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C4R,@HC+"!F=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I
M;VXB"FUS9W-T<B`B1FEL=&5R:6YN<W1I;&QI;F=E<B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,R(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED
M(")4:71L92(*;7-G<W1R(")4:71T96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I
M<"DZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C@P"FUS9VED(")4;R(*;7-G<W1R(")4:6PB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C(Y"B,L(&9U>GIY"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L
M:6-K:6YG+B(*;7-G<W1R("(B"B)&;W(@Y2!V96QG92!F;&5R92P@:&]L9"!N
M961E($-O;G1R;VP@*%!#*2!E;&QE<B!#;VUM86YD("A-86,I(&UE;G,@9'4@
M:VQI:VME<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3$*
M(RP@9G5Z>GD*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DUE;&1I;F=S=&5K<W0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X
M"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`HC+"!F
M=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4:6PB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4;VME
M;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3,*(RP@9G5Z>GD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DYY(&UE
M;&1I;F<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Q"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G<W1R(")4:6PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S<*(RP@9G5Z>GD*;7-G:60@(E1O<"(*;7-G<W1R(")4:6PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED
M(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV-3<*(RP@9G5Z>GD*;7-G:60@(E1R86YS;&%T960B"FUS9W-T
M<B`B56)E<W9A<G0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@
M9G5Z>GD*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")/<F=A;FES97)I
M;F<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S<X"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B5'5R:V5Y
M(@IM<V=S='(@(F[X:VME;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X
M"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"B,L
M(&9U>GIY"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B3V)S97)V97(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M3$DN<&AP.C(V,@IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@
M(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(U,B!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS
M9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(E5G
M86YD82(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(E5K
M<F%I;F4B"FUS9W-T<B`B1VIE;F]P<')E='0B"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,V,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R
M=F5R96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,#`*;7-G
M:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N
M('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS
M-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HS,S`@;&EB+U9&4R]M=7-Q;"YP:'`Z-3`R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T
M:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<P-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E
M<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*
M"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,S<U"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")+86X@:6MK92!K
M;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<X
M.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP.C$W-2!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ.3<*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`R(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q,`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME
M(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M,S(P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!K
M;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M.34@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<S(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C(W,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R
M96XN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(V"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK
M92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR,3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V
M97)E;BXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW.2!L:6(O
M2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DML87)T92!I:VME
M(.4@:&5N=&4@:6YF;W)M87-J;VX@;VT@:W9O=&4B"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C(W,"!L:6(O5D93+W-Q;"YP:'`Z,S(S(&QI
M8B]61E,O;75S<6PN<&AP.C,S-0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DMA
M;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<Y(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)R5S)SH@)7,N
M(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-S@@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S@R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE
M('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W-B!L
M:6(O5D93+VUU<W%L+G!H<#HS-#@@;&EB+U9&4R]M=7-Q;"YP:'`Z,S8Q"B,Z
M(&QI8B]61E,O;75S<6PN<&AP.C,V.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-S0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS-#@@;&EB+U9&4R]S<6PN<&AP.C,V
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@
M=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,
M<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-#(@;&EB+U9&4R]S
M<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H<#HQ-S,*(SH@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,3@V(&QI8B]61E,O;75S<6PN<&AP.C$Y,R!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HT,3(*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-#(P"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G
M<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C,S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R
M(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C<U,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R
M;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@<F5G
M:7-T<F5R92!I;G-T:6QL:6YG96YE(&D@^&MT96XN(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,C<*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B4V5T="!I
M;FX@<V5R=&EF:6MA="!H97(B"@HC.B!L:6(O3F5T+TE-4U`N<&AP.C0V,"!L
M:6(O3F5T+TE-4U`O075T:"YP:'`Z,3$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`B)7,@:&%R('-V87)T('#E(&EN=FET87-J;VYE;B!T:6P@)7,N
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,SD@;&EB+U9&4R]F:6QE+G!H<#HQ
M-#0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,38U"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$W,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E
M;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C$Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$R-R!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")+86X@
M:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HW,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,PHC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME
M(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HT-PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")+86X@:6MK92!K;V)L
M92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV,C(*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E
M<F5N+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA
M=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S$V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VME(&MO
M8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C4U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T
M:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(Y-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS
M97)V97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4V,R!L:6(O5D93+VUU
M<W%L+G!H<#HR-#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DMA;B!I:VME
M(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,C0Y(&QI8B]61E,O;75S<6PN<&AP.C(R,B!L:6(O5D93+VUU<W%L+G!H<#HT
M.#4*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`U(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C,R-PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E
M<F5N+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4Q"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T
M<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C8R"FUS9VED(")5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")+86X@
M:6MK92!O=F5R<V5T=&4@9&5T=&4@5V]R9"UD;VMU;65N=&5T(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C$R-R!L:6(O5D93+V9T<"YP:'`Z,3,P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")+;&%R=&4@:6MK92#E(&AE;G1E(&EN9F]R;6%S
M:F]N(&]M(&MV;W1E(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,C`*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(DML87)T92!I:VME(.4@:&5N=&4@:6YF;W)M87-J
M;VX@;VT@:W9O=&4B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R,R!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S4@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30P"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B2VQA<G1E(&EK:V4@Y2!H96YT92!I;F9O<FUA<VIO;B!O;2!K
M=F]T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`*(RP@9G5Z>GD*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")':F5N
M;W!P<F5T="(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")!;F=R92!E;F1R:6YG97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"B,L(&9U
M>GIY"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")'
M:F5N;W!P=&$@<V5S:F]N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(S,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDY
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(V(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-3`*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-R!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDS"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3@*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C0*(RP@
M9G5Z>GD*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B12UP;W-T(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B
M"FUS9W-T<B`B56CE;F1T97)T(&MO;7!O;F5N="!A=B!T>7!E;CH@)7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B56YI8V]D92`H551&
M+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-2!L:6(O0FQO
M8VLO;65T87(N<&AP.C8Y"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,34@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$V"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(E5K
M:F5N="!D871O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#<*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#@*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T
M.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N:VYO=VX@8V]M;6%N
M9#H@)7,B"FUS9W-T<B`B3&%S="!N960@;6%P<&5N*&4I(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@
M(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(E9E;FYL
M:7-T('-K<FEV(&EN;B!B<G5K97)N879N(&]G('!A<W-O<F0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*
M(RP@9G5Z>GD*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM
M<V=S='(@(E-L971T(&[E=N9R96YD92!N^&ML97(B"@HC.B!L:6(O2&]R9&4O
M261E;G1I='DN<&AP.C(Y.`IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")5=&5N
M(&YA=FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(E-E='0@:6YN('-E<G1I9FEK870@:&5R(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,3`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HY-3(*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY-3@*(RP@9G5Z
M>GD*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")5<W5P
M<&]R=&5R="!I;FYH;VQD<RUT>7!E+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HV-3<*(RP@9G5Z>GD*;7-G:60@(E5N=')A;G-L871E9"(*;7-G<W1R(")5
M8F5S=F%R="(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P-B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$Y,0HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E(@IM<V=S='(@(E-I
M<W1E(&]P<&1A=&5R:6YG.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M92`E<R(*;7-G<W1R(")3:7-T92!O<'!D871E<FEN9SHB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#@*;7-G:60@(E5P9&%T
M92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R(")/<'!D871E<B!S=&%T=7,@
M<.4@879S96YD97)E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B
M4VES=&4@;W!P9&%T97)I;F<Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ,S<@
M861M:6XO<&5R;7,O961I="YP:'`Z,C$W('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M)R5S)RXB"FUS9W-T<B`B4F5D:6=E<B`G)7,G(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P.#`@<&\O=')A;G-L871I;VXN<&AP.C$R,3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871I;F<@)7,@:&5L<"!F:6QE(&9O<B`E<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#$*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$X,@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(DQA<W0@;W!P
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`IM<V=I9"`B57!L;V%D
M960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.3(@<&\O=')A;G-L871I;VXN<&AP.CDS"B,L(&9U>GIY"FUS9VED(")5<V%G
M93HB"FUS9W-T<B`B0G)U:V5R;F%V;CHB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(E-L971T(&[E=N9R96YD
M92!N^&ML97(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-34X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C,*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-C4Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#0*(RP@9G5Z>GD*;7-G:60@(E5S97(@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B)7,@4$=0(&%D;6EN:7-T<F%S:F]N
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@
M3W!T:6]N<R(*;7-G<W1R("),86=R92!686QG(@H*(SH@<VEG;G5P+G!H<#HV
M-`HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B
M3&%G<F4@5F%L9R(*"B,Z('-I9VYU<"YP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@
M(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N(@IM<V=S='(@(D9I;'1E<G-T^'1T92!E<B!A=G-LY71T(&D@9&5T
M=&4@<WES=&5M970N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<R(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,C4T"B,L(&9U>GIY"FUS9VED(")5<V5R
M('!E<FUI<W-I;VYS(@IM<V=S='(@(DQA9W)E(%9A;&<B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<S"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-38@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HY-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(P,B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8U('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$Q"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R(")"<G5K97)N879N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HQ,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE("<E
M<R<@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(DUA<'!E;B!<(B5S7"(@9FEN
M;F5S(&%L;&5R961E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B0G)U:V5R;F%V;CHB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED
M(")5<V5R;F%M93H@(@IM<V=S='(@(D)R=6ME<FYA=FXZ(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(E5S97)S(@IM
M<V=S='(@(D)R=6ME<FYA=FXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHT"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$U"B,L(&9U>GIY"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(D1A
M=&\B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$P.2!L:6(O5D93+V9I;&4N<&AP
M.C(P,@HC+"!F=7IZ>0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B1&5N('-P97-I9FES97)T92!F:6QE;B!E:W-I<W1E
M<F5R(&EK:V4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,PHC
M+"!F=7IZ>0IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B3&]K87-J;VXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8Q"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C8R"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C(Q(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8S"FUS9VED(")686QU92!I
M;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(R."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(U,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(Y.`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-PHC
M+"!F=7IZ>0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(DEN9V5N(&UE;&1I;F=E
M<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#DS(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3<P"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"B,L(&9U>GIY"FUS9VED(")687)I
M86)L92(*;7-G<W1R(")4:71T96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")696YE>G5E;&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,C@*;7-G
M:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<R-`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO
M;B(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C`P"B,L(&9U>GIY"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`B4&5R<V]N;&EG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC
M86P@86QI9VXB"FUS9W-T<B`B1F5T8VAM86EL.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"B,L(&9U>GIY"FUS9VED
M(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(D9E=&-H;6%I;#H@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PHC+"!F
M=7IZ>0IM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(D9E=&-H;6%I;#H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W-PHC+"!F=7IZ>0IM
M<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(DCX>2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G
M:60@(E9I970@3F%M(@IM<V=S='(@(DYA=FXB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.3DT"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5FES("5S(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M(&%S("5S(@IM<V=S='(@(E9I<R`E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C<Y"FUS9VED(")6:65W(&5V96YT(@IM<V=S
M='(@(E9I<R!H96YD96QS92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C$P.0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(E9I
M<R!H86YD;&EN9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#<*;7-G:60@
M(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R,0IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#$*;7-G
M:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS.0IM
M<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,Q"FUS9VED(")7
M87)N:6YG(@IM<V=S='(@(D%D=F%R<V5L(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@Q('!O+W1R86YS;&%T:6]N
M+G!H<#HW,3$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<R-2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`T."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`U-PHC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`V-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-2!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`Y-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P,2!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(Q-@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(R-B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3(S,B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,@HC+"!F=7IZ
M>0IM<V=I9"`B5V%R;FEN9SH@(@IM<V=S='(@(D%D=F%R<V5L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B
M5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(U"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#4*;7-G:60@(E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#@W"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.3`*(RP@9G5Z>GD*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8G-I9&4@861R97-S92(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z,S<*;7-G:60@(E=E96ML>2(*;7-G
M<W1R(")5:V5N=&QI9R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(E9E;&MO;6UE
M;B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(E9E;&MO;6UE;B!T:6P@)7,B"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS
M9W-T<B`B5F5L:V]M;65N+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")797-T97)N(%-A:&%R82(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")6:7-N:6YG(&5L
M;&5R('!O<W1B;VMS('-O;2!S:V%L('9I<V5S(&5T=&5R(&EN;FQO9V=I;F<Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(E=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(T"FUS9VED(")7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$*;7-G:60@(E=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@B"FUS9W-T<B`B
M4_AK(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3`*;7-G:60@(E=I9'1H
M(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$P"B,L(&9U>GIY"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@
M(E/X:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`U"B,L(&9U>GIY"FUS9VED(")7:61T:#HB"FUS9W-T<B`B4_AK(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y,`IM<V=I9"`B5VEK:2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<R
M"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(E/X:R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S,*(RP@9G5Z>GD*;7-G:60@(E=I
M;F0@16%R;'DB"FUS9W-T<B`B079S;.5T=#H@(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW.`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-`HC+"!F=7IZ>0IM<V=I
M9"`B5VEN9#HB"FUS9W-T<B`B4_AK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-0HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@
M(D%V<VSE='0Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`HC+"!F
M=7IZ>0IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E/X:R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-S<*(RP@9G5Z>GD*;7-G:60@(E=I<VAL:7-T
M<R(*;7-G<W1R(")"971R;V1D92!A9')E<W-E<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R(*;7-G<W1R(")E
M;&QE<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(W
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38W"FUS9VED(")7
M;W)K($%D9')E<W,B"FUS9W-T<B`B1FER;6%A9')E<W-E(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.34*;7-G:60@(E=O<FL@4&AO
M;F4B"FUS9W-T<B`B1FER;6%T96QE9F]N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$Q-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)I=&EN9R!U<&1A=&5D
M(&AE;'`@9FEL92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3<*;7-G:60@(E@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8Q-@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8Q.`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q.0IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#8*;7-G:60@(E@U
M,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+EY2(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#8@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0R-PHC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G
M<W1R("+EY2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#`R"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z,S4*;7-G:60@(EEE87)L>2(*;7-G<W1R
M("+E<FQI9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(EEE;65N(@IM<V=S='(@(DQE
M<W0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@X
M"FUS9VED(")997,B"FUS9W-T<B`B2F$B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$S,C8*;7-G:60@(EEO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92])9&5N=&ET>2YP:'`Z,S`T"FUS9VED(")9;W4@8V%N(&YO="!H879E
M('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,SD@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$Y-3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R
M(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B5F5N;FQI9W-T(')E
M='0@='9E='ED:6=E(&5L;&5R('5G>6QD:6=E(&%D<F5S<V5R+B(*"B,Z(&QI
M8B](;W)D92]$871A+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDT-`HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")$:6YE
M('9A;&<@:&%R(&)L:71T(&]P<&1A=&5R="(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C4S"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#`*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I=B!I;FX@9&5T(&YY92!N879N970Z
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS.`HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T
M;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=E(%9&4RUB
M86-K96YD.B`E<R(*"B,Z(&QI8B](;W)D92YP:'`Z-#0W"B,L(&9U>GIY"FUS
M9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T
M<B`B2W5N;F4@:6MK92!L86=E(%9&4RUB86-K96YD.B`E<R(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B1'4@;>4@8F5S:W)I=F4@<')O8FQE
M;65T(&;X<B!D=2!K86X@<V5N9&4@96X@<')O8FQE;7)A<'!O<G0N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(D1U(&WE(&AA(&UI;G-T(.EN(&UO
M='1A:V5R+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N(@IM<V=S='(@(D1U(&WE('9E;&=E(&5N(&ED96YT:71E="!S
M;VT@<VMA;"!S;&5T=&5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E<F4@96X@;6]T=&%K
M97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R
M(")$=2!MY2!S<&5S:69I<V5R92!E;B!M;W1T86ME<BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`B1'4@;>4@9OAR<W0@<W!E<VEF:7-E<F4@9FEL
M96X@<V]M('-K86P@;&5G9V5S('9E9"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92XB"FUS9W-T<B`B1'4@;>4@9OAR<W0@<W!E<VEF:7-E
M<F4@9FEL96X@<V]M('-K86P@;&5G9V5S('9E9"XB"@HC.B!L:6(O2&]R9&4O
M0V]M<')E<W,O>FEP+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B1'4@
M;>4@<W!E<VEF:7-E<F4@96X@;6]T=&%K97(N(@H*(SH@;&EB+TAO<F1E+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B1'4@
M;>4@<W!E<VEF:7-E<F4@96X@;6]T=&%K97(N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M1&EN("5S('1I;&MO8FEN9R!H87(@9^5T="!U="X@5F5N;FQI9W-T(&QO9R!I
M;FX@:6=J96XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R
M(")%<&]S=&%D<F5S<V5N(&1I;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM
M<V=S='(@(D5P;W-T861R97-S96X@9&EN.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM
M<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$:6X@:6YF;W)M87-J
M;VXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3,V"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")&=6QL="!N879N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.CD*;7-G:60@(B(*(EEO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D
M9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.CD*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D
M(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDT,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM
M<V=S='(@(DYE='1L97-E<F5N(&1I;B!S=/AT=&5R(&EK:V4@=FES;FEN9R!A
M=B!D96YN92!T>7!E(&)I;&1E<B!I;FQI;F4N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<')I;G0N:G,Z,C<*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT
M<F]L+T]P=&EO;B`K(%`@=&\@(@HB<')I;G0N(@IM<V=S='(@(B(*(DYE='1L
M97-E<F5N(&1I;B!S=/AT=&5R(&EK:V4@9&5N;F4@=71S:VEF='-O<&5R87-J
M;VYE;BX@5')Y:VL@2V]N=')O;&PO(@HB3W!S:F]N("L@4"!F;W(@Y2!S:W)I
M=F4@=70N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T-PIM<V=I9"`B
M66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A
M=6QT(&ED96YT:71Y.B(*;7-G<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3$*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9G5L;"!N86UE.B(*;7-G<W1R(").879N970@9&ET=#HB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,30U"FUS9VED("(B"B)9;W5R(&=E='1E>'0@=F5R
M<VEO;B!I<R!T;V\@;VQD(&%N9"!D;V5S(&YO="!S=7!P;W)T(%!(4"!N871I
M=F5L>2Y<;B(*(DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$U-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G
M<W1R(")$:6YE('9A;&<@:&%R(&)L:71T(&]P<&1A=&5R="(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,34X"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N(@IM<V=S='(@(D1I;F4@=F%L9R!H87(@8FQI='0@
M;W!P9&%T97)T(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E1J
M96YE<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0HC+"!F=7IZ>0IM
M<V=I9"`B6F%I<F4B"FUS9W-T<B`B1G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B6F%M8FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z-38*;7-G:60@(EM0<F]B;&5M(%)E<&]R
M=%TB"FUS9W-T<B`B6U!R;V)L96UR87!P;W)T72(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T
M960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E
M<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4N<&AP.C$Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B6VQI;FIE("5S(&%V("5S72(*"B,Z(&QI
M8B](;W)D92YP:'`Z,30W,B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B)7,@
M4$=0(&%D;6EN:7-T<F%S:F]N(@H*(SH@;&EB+V%P:2YP:'`Z,3,T"FUS9VED
M(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R,@HC+"!F=7IZ
M>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(D1A=&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*(RP@
M9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]3;&5T="(*"B,Z
M(&QI8B]A<&DN<&AP.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B7T=R;W5P<R(*;7-G
M<W1R(")'<G5P<&4B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3@Q"FUS9VED
M(")?2&5L<"(*;7-G<W1R(")(:F5L<"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B1F]R:.5N9'-V:7-N
M:6YG(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C(P,`HC+"!F=7IZ>0IM<V=I
M9"`B7TQO9R!I;B(*;7-G<W1R("),;V=G(&EN;B(*"B,Z(&QI8B](;W)D92]-
M96YU+G!H<#HQ.38*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(DQO9V<@=70B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G
M<W1R(")&:F5R;B!P87(B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<P"FUS
M9VED(")?3W!T:6]N<R(*;7-G<W1R(")686QG(@H*(SH@;&EB+V%P:2YP:'`Z
M,3$X"B,L(&9U>GIY"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R
M<V]N;&EG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`B1FIE<FX@<&%R(@H*(SH@;&EB+V%P:2YP:'`Z,3`V"B,L
M(&9U>GIY"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B5F5L9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC
M+"!F=7IZ>0IM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M1F]R:.5N9'-V:7-N:6YG(@H*(SH@;&EB+V%P:2YP:'`Z,3$P"B,L(&9U>GIY
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B0G)U:V5R;F%V;B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3$Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B061R97-S96)O:R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HW,3$*(RP@9G5Z>GD*;7-G:60@(F%N(&5R<F]R(&AA<R!O8V-U<F5D.B(*
M;7-G<W1R("(\8CY%;B!F871A;"!F96EL(&AA<B!O<'!S=.5T=#H\+V(^(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#,*(RP@9G5Z>GD*;7-G:60@(F-A
M;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-S`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B079B<GET(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P.`IM<V=I9"`B8VQI8VL@:&5R
M92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#0U('!O+W1R
M86YS;&%T:6]N+G!H<#HU-3`@<&\O=')A;G-L871I;VXN<&AP.C8Q,0HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-S0Y('!O+W1R86YS;&%T:6]N+G!H<#HX,3`@
M<&\O=')A;G-L871I;VXN<&AP.C@X-PHC+"!F=7IZ>0IM<V=I9"`B9&]N92(*
M;7-G<W1R(")&97)D:6<B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-34R('!O
M+W1R86YS;&%T:6]N+G!H<#HU.#0@<&\O=')A;G-L871I;VXN<&AP.C8Q,PHC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S<X('!O+W1R86YS;&%T:6]N+G!H<#HX
M,3(@<&\O=')A;G-L871I;VXN<&AP.C@X.0HC+"!F=7IZ>0IM<V=I9"`B9F%I
M;&5D(@IM<V=S='(@(D4M<&]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-S@*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.C@W,`HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*
M;7-G<W1R(")&:6PB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(Y"B,L(&9U
M>GIY"FUS9VED(")F;W5N9#H@(@IM<V=S='(@(D%V<VSE='0Z("(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B5S
M('#E("5S("5S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S,@IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(P.`IM<V=I9"`B:3$X;B(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Y"FUS9VED(")I;6UE9&EA=&4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(FEN;&EN92(*;7-G<W1R
M("));FQI;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B;&EN97-=(@IM<V=S='(@(DEN;&EN
M92(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4T"B,L('!H
M<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C(X."!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`V"FUS9VED
M(")N86UE(@IM<V=S='(@(FYA=FXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,S<X"B,L(&9U>GIY"FUS9VED(")N;W0@8VAA;F=E9"(*;7-G<W1R(")!;F=R
M92!E;F1R:6YG97(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,Q"B,L(&9U
M>GIY"FUS9VED(")N;W0@9F]U;F0B"FUS9W-T<B`B3V)J96MT970@8FQE(&EK
M:V4@9G5N;F5T(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(R"B,L(&9U>GIY
M"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B1F5R9&EG(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C0U"B,L(&9U>GIY"FUS9VED
M(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E
M(&]P<&=A=F5N(&5R(&EK:V4@:6UP;&5M96YT97)T+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.#DU"B,L(&9U>GIY"FUS9VED(")N;W1E<&%D(@IM<V=S
M='(@(DYO=&%T8FQO:VL@9F]R("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`HC+"!F=7IZ>0IM<V=I9"`B
M<&5R8V5N="(*;7-G<W1R(")3:W)I=B!U="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S@P"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B3W)G86YI<V5R
M:6YG(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.`IM<V=I9"`B<VAO
M=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,S"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W
M.0HC+"!F=7IZ>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(D]P<&1A=&5R(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3D*(RP@9G5Z>GD*;7-G:60@(G1A
M<VL@;&ES="(*;7-G<W1R(")3=F%R=&5L:7-T92(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HW,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(G1H92!(
M;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T
M.B(*;7-G<W1R(")$96X@<W!E<VEF:7-E<G1E(&9I;&5N(&5K<VES=&5R97(@
M:6MK92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C(X,@HC+"!F=7IZ>0IM<V=I9"`B='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")6:7,@;6%I;&QI<W1E(&EN
M9F]R;6%S:F]N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(G5N:69I960B"FUS
M9W-T<B`B12UP;W-T(@H*(SH@;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,3<*
M(RP@9G5Z>GD*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B571E;B!N879N(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C,W-0HC+"!F=7IZ>0IM<V=I9"`B=7!D
M871E9"(*;7-G<W1R(")3:7-T92!O<'!D871E<FEN9SHB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(Y"B,L(&9U>GIY"FUS9VED(")U<V5R('-E;&5C
M="(*;7-G<W1R(")I;F=E;B!M87!P92!V86QG="(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,S@*;7-G:60@(G9#87)D(@IM<V=S='(@
M(G9#87)D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-`HC+"!F=7IZ>0IM<V=I9"`B=SHB"FUS9W-T<B`B1G=D.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS"FUS9VED(")W96%T:&5R+F-O
M;2(*;7-G<W1R("(B"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&\O<W9?4T4N<&\`````````````````````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,3$S,3`W-0`Q,#4Q-30S,3`V,P`P,38T,30`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R!(;W)D
M92!3=V5D:7-H('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R+3(P
M,#8@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U
M;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC
M($IO87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/BP@
M,C`P-BX*(R!!;F1R96%S($1A:&SI;B`\86YD<F5A<T!D86AL96XN=W,^+"`R
M,#`U+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!(;W)D92`S+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ
M-2`Q,3HR,2LP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$V
M(#`P.C(V*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F]A<75I;2!(;VUR
M:6=H875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^7&XB"B),86YG=6%G92U4
M96%M.B!3=V5D:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M
M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?
M=&]P+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(@)B,Q-3$[("5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T<B`B(@HB("8C,34Q.R`E<R!K;VUM
M97(@871T('5T9O9R82!D92!U;F1E<FCE;&QS86MT:79I=&5T97)N82!S;VT@
M;6%R:V5R871S(&YE9&%N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R!D86=A<B!S961A
M;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S,C8@;&EB+TAO
M<F1E+G!H<#HQ,S<T"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(@*'-N86)B=&%N9V5N="`E<RDB"@HC.B!T96UP;&%T
M97,O;&EN:W,O;&EN:W,N:6YC.C0*;7-G:60@(B`H4F5A9"!O;FQY*2(*;7-G
M<W1R("(@*%-K<FEV<VMY9&1A9"DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<W(&QI8B](;W)D92]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AO;2`E<R!D86=A
M<BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S<W"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&ED
M86<I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B
M("AI;6]R9V]N*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H>65S=&5R9&%Y*2(*
M;7-G<W1R("(@*&EGY7(I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS
M9W-T<B`B(&ML("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U
M(&QI8B]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B)R5S)R#D<B!I;G1E
M(&5N(&MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,B!L
M:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R#D<B!I
M;G1E(&5T="!G;V1KY&YT('9A;"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C8U-@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C$P,SD@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*
M(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@Y'(@:6YT92!K;VYF:6=U<F5R870@
M:2!(;W)D97)E9VES=')E<G0N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP
M:'`Z,3<Q(&QI8B](;W)D92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")4<N1D:&%N=&5R87)E;B!F]G(@)7,@<V%K;F%S+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!L861E
M<R!T:6QL(&D@9W)U<'!S>7-T96UE="XB"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G
M(&QA9&5S('1I;&P@:2!B96CV<FEG:&5T<W-Y<W1E;65T+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S
M+B(*;7-G<W1R("(G)7,G('-K87!A9&5S(&EN=&4Z("5S+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F
M34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(E
M+C)F34(@86YVY&YT(&%V("4N,F9-0B!T:6QLY71E="`H)3)F)24I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@;V-H("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,C8X"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(D1I='0@;/9S96YO<F0@=7!P:/9R
M(&%T="!GY&QL82!O;2`E9"!D86=A<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F
M;W)E8V%S="(*;7-G<W1R("(E9"UD86=S<')O9VYO<R(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HV."!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T
M:6-E7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC
M92(*;7-G<W1R("(E<R`M($;V<B!KY&YN961O;2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT
M(@IM<V=S='(@(D9I;F=E<G!R:6YT(&;V<B`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S0*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C@T,2!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0S"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y('1E;7!L871E<R]M86EN=&5N86YC
M92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@
M(B5S(%5N9&5R:.5L;'-F=6YK=&EO;B`M($)E:W+D9G1E;'-E(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S
M(%-E='5P(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M,R!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(&%N;>1L86XB"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(E1JY&YS=&5A=G1A;"!F
M]G(@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC
M.B!L:6(O5D93+W-M8BYP:'`Z-#,R(&QI8B]61E,O<VUB+G!H<#HT.30@;&EB
M+U9&4R]F='`N<&AP.C8X,@HC.B!L:6(O5D93+V9T<"YP:'`Z-S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E
M<R!F:6YN<R!R961A;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T
M-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G
M<W1R("(E<R!K;"`E<R`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B5S(&AA<B!A;FYU;&QE<F%T
M("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D
M('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(&AA<B!S=F%R
M870@<.4@96X@8F5GY')A;B!O;2!I;F9O<FUA=&EO;B!A;F?E96YD92!L961I
M9R]U<'!T86=E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4R-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@
M<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RXB"FUS9W-T<B`B)7,@
M:&%R('-V87)A="!PY2!I;F)J=61A;B!T:6QL("5S+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B5S(&AA<B!S:VEC:V%T(&1I9R!I;F9O<FUA=&EO
M;B!O;2!L961I9R]U<'!T86=E;BXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B
M"B(E<R!K;VUM97(@871T('5T9O9R82!D92!U;F1E<FCE;&QS86MT:79I=&5T
M97)N82!S;VT@;6%R:V5R871S(&YE9&%N+B!-87)K97)A("(*(F1E(&%K=&EV
M:71E=&5R('-O;2!D=2!V:6QL('5T9O9R82XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S0P(&QI8B](;W)D92]&;W)M+G!H<#HR,S0T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&MR
MY'9S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&5R(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,R!L:6(O
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@<V%K;F%S+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(E<R!E9G1E<F9RY6=A<B!I;F9O
M<FUA=&EO;B!O;2!NY'(@9'4@Y'(@;&5D:6<O=7!P=&%G96XN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A
M="`E<RXB"FUS9W-T<B`B)7,@969T97)F<N5G87(@9&EN(&[D<G9A<F\@=FED
M("5S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@
M=&EL;"`E<R!A=B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I
M<VAE<R!T;R!A9&0@=&\@)7,N(@IM<V=S='(@(B5S('9I;&P@;.1G9V$@=&EL
M;"!T:6QL("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE
M<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS9W-T<B`B)7,@=FEL;"!G
M]G)A(&1I9R!M961V971E;B!O;2`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!W:7-H97,@=&\@<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T
M:6]N(&%B;W5T("5S+B(*;7-G<W1R("(E<R!V:6QL(&5R:.5L;&$@9&5N('-E
M;F%S=&4@:6YF;W)M871I;VYE;B!O;2`E<RXB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDR,B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")!
M9')E<W-B;VL@9O9R("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,30@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B!F]G(@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-B!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P
M860B"FUS9W-T<B`B06YT96-K;FEN9V%R(&;V<B`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,P(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B
M57!P9VEF=&5R(&;V<B`E<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M
M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@
M;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A
M;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!-961D
M96QA;F1E="!K86YS:V4@:6YT92#D<B!F<N5N(&1E;B!S;VT@9&5T('9E<FMA
M<BX@5F%R(&;V<G-I:W1I9R!M960@(@HB871T(&;V;&IA(&SD;FMA<B!E;&QE
M<B!S:VEC:V$@879SY&YD87)E;B!P97)S;VYL:6<@:6YF;W)M871I;VXN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S
M='(@(BP@<W1O<FUB>6%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@<W1O<FUB>6%R("5S("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:65R
M86YD92!M96QL86X@)7,@;V-H("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HW,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S,*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,S(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.`IM<V=I9"`B+2T@<V5L96-T
M("TM(@IM<V=S='(@(BTM(';D;&H@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R+71I;6UA
M<G-F;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T
M($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+71I;6UA<G-F;W)M870B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B,C0@=&EM;6%R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H
M<#HV.2!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO
M=7,B"FUS9W-T<B`B/$;V<F5GY65N9&4B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")%;B!D871A8F%S:V]P<&QI;F<@
M:W+D=G,@9O9R(&%K='5E;&QT(&)L;V-K+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38P(&QI8B](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")%='0@9F%T86QT(&9E
M;"!H87(@:6YT<N1F9F%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.3(P(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D=G,@9O9R
M(&%T="!K<GEP=&5R82!E='0@;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,30U(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(D5N('!U8FQI
M:R!01U`M;GEC:V5L(&MRY'9S(&;V<B!A='0@=F5R:69I97)A(&5T="!S:6=N
M97)A="!M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P-S<@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(D5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K
M96P@<V%M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T
M("(*(FUE9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.3DU(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*
M;7-G<W1R("(B"B)%;B!P=6)L:6L@;V-H('!R:79A="!01U`M;GEC:V5L('-A
M;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T="!S:6=N97)A(&5T="`B"B)M961D
M96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3`U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@HB16X@<'5B;&EK(&]C:"!P<FEV870@4R]-24U%+6YY
M8VME;"!S86UT(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@9&5K<GEP=&5R82`B
M"B)E='0@;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0S,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S,0IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5N('!U8FQI:R!O8V@@<')I=F%T(%,O
M34E-12UN>6-K96P@<V%M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T('-I9VYE
M<F$@971T("(*(FUE9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS-C0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B16X@<'5B;&EK(%,O34E-12UN
M>6-K96P@:W+D=G,@9O9R(&%T="!K<GEP=&5R82!E='0@;65D9&5L86YD92XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS
M9VED(")!32!#;&]U9',B"FUS9W-T<B`B1O9R;6ED9&%G<VUO;&XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R("),Y'1T(&;V<FUI9&1A9W-R96=N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G
M:60@(D%-(%)A:6XB"FUS9W-T<B`B1O9R;6ED9&%G<W)E9VXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R(")&]G)M:61D86=S<VMU<F%R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")&]G)M:61D86=S<VMU<F%R(&UE9"!S;O8B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB
M"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,#`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P
M"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")/;2!E9&ET;W)N
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T
M+BXN(@IM<V=S='(@(D]M+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@
M(D)O='1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")-:71T96XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T
M,`IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B06-C97!T97)A(&)E
M9^1R86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8X,0IM<V=I9"`B06-C97!T960B"FUS9W-T<B`B06-C97!T97)A
M9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D)E:/9R:6=H970@<V%K;F%S(&%T
M="!S:V%P82!61E,M;6%P<"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3,V(&QI8B]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B0F5H]G)I9VAE
M="!S86MN87,@871T('-K87!A(%9&4RUF:6PN(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B2V]N=&]I;F9O<FUA=&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("),]G-E;F]R
M9"!F]G(@:V]N=&\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")+
M;VYT;W0@9G)Y<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U
M"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(D)U9&=E="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4Q"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C(U"FUS
M9VED(")!8W1I;VYS(@IM<V=S='(@(L5T9^1R9&5R(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ-#@*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS
M9W-T<B`B3.1G9R!T:6QL(@H*(SH@=&5M<&QA=&5S+VQI;FMS+VQI;FMS+FEN
M8SHQ,PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@)7,B"FUS9W-T<B`B3.1G
M9R!T:6QL("5S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O
M=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("),
MY&=G('1I;&P@=6YD97)G<G5P<"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@
M(FSD9V<@=&EL;"!U;F1E<F)E:/9R:6=H970B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(DSD9V<@
M=&EL;"!HY'(Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O
M=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3.1G
M9R!T:6QL(&YY(&=R=7!P(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(DSD9V<@
M=&EL;"!N>2!B96CV<FEG:&5T(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3.1G9R!T:6QL('5N9&5R
M9W)U<'`@=&EL;"`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B
M"FUS9W-T<B`B3.1G9R!T:6QL('5N9&5R8F5H]G)I9VAE="!T:6QL("<E<R<B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z
M(@IM<V=S='(@(DSD9V<@=&EL;"!E;B!N>2!A;G;D;F1A<F4Z(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@
M8V]L=6UN(@IM<V=S='(@(DSD9V<@=&EL;"!K;VQU;6XB"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE
M;6)E<G,B"FUS9W-T<B`B3.1G9R!T:6QL(&YY82!M961L96UM87(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*
M;7-G<W1R("),Y&=G('1I;&P@<&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B3.1G9R!T:6QL(&UE;GEN
M(&;V<B`E<R!S;VT@36]Z:6QL82!3:61E8F%R(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S$*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S<*;7-G:60@(D%D
M9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(DSD9V<@=&EL;"!I(&UI
M;B!K86QE;F1E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HW,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q
M"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("),Y&=G('1I
M;&P@:2!A9')E<W-B;VLZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B
M3.1G9R!T:6QL(&D@;6EN(&%D<F5S<V)O:R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("),Y&=G('1I;&P@86YVY&YD
M87)E(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N
M;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB
M"FUS9W-T<B`B(@HB3&%D92!T:6QL("<E<R<@=&EL;"!S>7-T96UE="P@;65N
M(&MU;F1E(&EN=&4@;.1G9V$@=&EL;"!E>'1R82`@:6YF;W)M871I;VXZ("4B
M"B)S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RXB"FUS9W-T<B`B3&%D92!T:6QL("<E<R<@=&EL;"!S>7-T96UE="X@1'4@
M:V%N(&QO9V=A(&EN(&YU+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(E5P<&SD9V<@878@86YVY&YD87)E(.1R(&EN86MT:79E<F%T+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#0U(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS9VED
M(")!9&1R97-S(@IM<V=S='(@(D%D<F5S<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!
M9')E<W-B;VLB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI
M;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G
M<W1R(")!9&UI;FES=')A=&EO;B`M(&%N9V4@8F5H]G)I9VAE="!F]G(@86YD
M<F$@86YVY&YD87)E(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S
M+W!O<G1A;"]M96YU+G!H<#HQ,3,*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M
M:6YI<W1R871I;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S
M"FUS9VED(")!9',B"FUS9W-T<B`B4F5K;&%M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:65N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!
M;&=E<FEA(@IM<V=S='(@(D%L9V5R:65T(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")*=7-T97)A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I
M9"`B06QI9VYM96YT.B(*;7-G<W1R(")*=7-T97)I;F<Z(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B06QL82(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C`W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(D%L;&$@875T96YT:7-E<F%D92!A;G;D;F1A<F4B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O
M=7!S(@IM<V=S='(@(D%L;&$@9W)U<'!E<B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDQ(&QI8B](
M;W)D92]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S
M:6]N<R(*;7-G<W1R(")!;&QA(&)E:/9R:6=H971E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@
M(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(D%L;&$@9GER82!S:61O<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S4*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G
M<W1R(")4:6QLY70@9FQE<F$@861R97-S97(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/R(*;7-G<W1R(")4:6QLY70@:6YS=.1L;&YI;F<@9O9R('-O
M<G1E<F%D(&QI<W1A/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C4P-"!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*
M;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D9I;FYS(')E9&%N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E
M($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT97)N871I=B!)35-0+6EN;&]G9VYI
M;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E
M<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EV="!L]G-E
M;F]R9"!F]G(@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R
M;F%T:79T(&%N=N1N9&%R;F%M;B!F]G(@24U34"(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D
M<F5S<R(*;7-G<W1R(")!;'1E<FYA=&EV(&4M<&]S="!A9')E<W,B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L
M871E<R(*;7-G<W1R(")!;'1E<FYA=&EV(&UA;&PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!;'1E<FYA=&EV('1E>'0Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")!;65R
M:6MA;G-K82!386UO82(*"B,Z(&9R86UE=V]R:R],:6YK<R],:6YK<RYP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R]296QA=&EO;G-H:7`O4F5L871I;VYS:&EP36%N
M86=E<BYP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(D%N(&5R<F]R(&]C
M8W5R<F5D(&9O;&QO=VEN9R!T:&ES(&QI;FLZ("5S(@IM<V=S='(@(D5T="!F
M96P@=7!P<W1O9"!NY'(@;.1N:V5N("@E<RD@<VMU;&QE(&%N=N1N9&%S(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$Q-0HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D5T="!F96QA
M:W1I9W0@=N1R9&4@86YG879S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R
M960N(@IM<V=S='(@(D5T="!O:^1N="!F96P@:&%R(&EN='+D9F9A="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;GEM('!R
M;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@
M(D%N<W=E<B(*;7-G<W1R(")3=F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T
M:6-A(@IM<V=S='(@(D%N=&%R:W1I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U
M82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&]C:"!"87)B=61A(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z
M,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!L:6(O2&]R
M9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P<&QI
M:V%T:6]N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!
M<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(D%P<&QI:V%T:6]N<VQI<W1A(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I
M;VX@:7,@<F5A9'DN(@IM<V=S='(@(D%P<&QI:V%T:6]N96X@Y'(@:VQA<BXB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P
M;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(E9E<FMS=.1L;"!T:6QL('5N
M9&5R=71D96QN:6YG87(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")';V1KY&YN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,R(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$*;7-G:60@(D%P<')O>&EM871E
M(%-I>F4B"FUS9W-T<B`B56YG96;D<FQI9R!S=&]R;&5K(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$W"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")A
M<')I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!<F%B
M:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A8FES:R`H5VEN9&]W<RTQ
M,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C4Y"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C<X"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")!<FMI=F9I
M;'-T;W)L96LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,"!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D%R:VEV9FEL
M;F%M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS
M9W-T<B`BQ'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!T82!B;W)T(&)E9^1R
M86X@9O9R("5S/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS
M9W-T<B`BQ'(@9&5T('/D:V5R="!A='0@9'4@=FEL;"!R861E<F$@)R5S)R!O
M8V@@979E;G1U96QL82!U;F1E<F=R=7!P97(_(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!
M<FUE;FEA(@IM<V=S='(@(D%R;6%N:65N(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@
M(D%R;65N:7-K("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B2V]N<W0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B07-C96YS:6]N($ES;&%N9"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T
M(@IM<V=S='(@(D%S8VEI(&MO;G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%S:65N+U-T:6QL82!H
M879S<F5G:6]N96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS
M9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B1G+E9V$@969T97(@8F5K<N1F
M=&5L<V4@:6YN86X@=6YD97)HY6QL<V%K=&EV:71E=&5R('5T9O9R<S\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S(&QI8B](;W)D92]&;W)M
M+G!H<#HS,#DY"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B
M5&EL;&1E;&YI;F=S:V]L=6UN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HR-#D*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS,3@*;7-G:60@(D%T=&%C:&5D
M(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@
M<V5N="(*;7-G<W1R(")":69O9V%D(.1R(&5N(&E#86QE;F1E<B!F:6P@;65D
M(&5T="!S=F%R('#E(&5N(&)E9^1R86X@<V]M(&1U('-K:6-K870L(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(D;V<G/V:R!T:6QL(&%T
M="!R861E<F$@96X@9W)U<'`@<V]M(&EN=&4@9FEN;G,N(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1O9R<_9K('1I
M;&P@871T(')A9&5R82!E;B!B96CV<FEG:&5T('-O;2!I;G1E(&9I;FYS+B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1O9R
M<_9K(&%T="#D;F1R82!E;B!B96CV<FEG:&5T('-O;2!I;G1E(&9I;FYS+B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")&]G)S
M]FL@871T(.1N9')A(&5N('5T9&5L;FEN9R!S;VT@:6YT92!F:6YN<RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W
M-PIM<V=I9"`B071T96YD965S(@IM<V=S='(@(D1E;'1A9V%R92(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV.`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@V(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C8T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<Q(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!
M='1R:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(Q"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B875G=7-T
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86QI
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BUG-T97)R:6ME
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V."!L:6(O
M2&]R9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C>7)S<6PZ($E-05`M97AT96YS:6]N('-A:VYA<RXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H
M7V-Y<G-Q;#H@2V]P<&QI;F=E;B!S86MN87(@9G5N:W1I;VYE<B!S;VT@:W+D
M=G,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C>7)U<SH@24U!4"UE>'1E;G-I;VX@<V%K;F%S+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-B!L:6(O2&]R9&4O075T:"]F='`N
M<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(D%U=&A?9G1P.B!&5%`M=&EL;.1G
M9R!S86MN87,N($MO;7!I;&5R82!02%`@;65D('-W:71C:&5N("TM96YA8FQE
M+69T<"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T(&QI
M8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]I;6%P.B!)34%0+65X=&5N<VEO;B!S86MN87,N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HU,2!L:6(O2&]R9&4O075T:"]K<F(U+G!H
M<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@:W)B-2UE>'1E;G-I
M;VX@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`R(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L
M9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($1E="!GY7(@:6YT92!A
M='0@;.1G9V$@=&EL;"!A;G;D;F1A<F4@:2!!8W1I=F4@1&ER96-T;W)Y(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B075T:%]L9&%P.B!$970@9^5R(&EN=&4@871T(')A9&5R82!A
M;G;D;F1A<F4@9G+E;B!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HV,R!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@3$1!4"UT:6QLY&=G
M('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S
M.2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z
M($MA;B!I;G1E(&SD9V=A('1I;&P@86YVY&YD87)E("<E<R<N(%-E<G9E<FX@
M<W9A<F%D93H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M.#4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM
M<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EN=&4@<F%D97)A(&%N=N1N9&%R92`E
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!
M=71H7VQD87`Z($MA;B!I;G1E('5P<&1A=&5R82!A;G;D;F1A<F4@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-2!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B075T:%]L9&%P.B!$970@9^5R(&EN=&4@871T('5P<&1A=&5R
M82!A;G;D;F1A<F4@:2!!8W1I=F4@1&ER96-T;W)Y+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8@;&EB+TAO<F1E+T%U=&@O;6-A;"YP
M:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($U#04PM97AT96YS
M:6]N('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M-C`@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?<VUB875T:#H@<VUB875T:"UE>'1E;G-I;VX@<V%K;F%S
M+B(*"B,Z(&QI8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M075T96YT:7-E<FEN9R!T:6QL($E-05`M<V5R=F5R(&UI<W-L>6-K861E<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")!=71E;G1I
M<V5R:6YG(&UI<W-L>6-K861E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960N("5S(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@;6ES<VQY8VMA
M9&5S+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-S8@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@
M(D%U=&5N=&ES97)I;F<@879V:7-A9&5S(&%V(%)!1$E54RUS97)V97)N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q(&QI8B]61E,O9G1P
M+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG('1I;&P@1E10+7-E<G9E
M<B!M:7-S;'EC:V%D97,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HW,"!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT:7-E
M<FEN9R!T:6QL(%--0BUS97)V97(@;6ES<VQY8VMA9&5S+B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L
M9',Z(@IM<V=S='(@(E1I;&QGY&YG;&EG82!FY&QT.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C$T"FUS9VED(")!
M=V%I=&EN9R!297-P;VYS92(*;7-G<W1R(")6Y&YT87(@<.4@<W9A<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I:F%N(@H*
M(SH@8V]N9FEG+W1H96UE<R]A>G5R+G!H<#HX"FUS9VED(")!>G5R(@IM<V=S
M='(@(D%Z=7)B;.4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G
M:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9(+75R<^1K=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")"86MG<G5N9"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@
M(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0F%K9W)U;F1S9N1R9R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB
M"FUS9W-T<B`B1F5L86MT:6=T(&SV<V5N;W)D(&;V<B!+97)B97)O<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB
M"FUS9W-T<B`B1F5L86MT:6=T(&%N=N1N9&%R;F%M;B!F]G(@2V5R8F5R;W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR86EN(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(D)A;'1I<VL@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*(SH@;&EB
M+T)L;V-K+V)A<G1I;64N<&AP.C0*;7-G:60@(D)A<B!4:6UE(@IM<V=S='(@
M(D)A<G1I9"(*"B,Z(&QI8B]";&]C:R]B87)T:6UE+G!H<#HS-0IM<V=I9"`B
M0F%R('1I;64B"FUS9W-T<B`B4F%D=&ED(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B
M861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z(&-O;F9I9R]T:&5M97,O8F%R
M8FEE+G!H<#HV"FUS9VED(")"87)B:64B"FUS9W-T<B`B0F%R8FEE(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D)A<VMA=&%L;V<@)R5S)R!F]G(@8FEL9&5R(&AI='1A9&5S(&EN
M=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")"87-L:6YJ92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")6:71R>7-S;&%N9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R
M;75D82(*;7-G<W1R(")"97)M=61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1O9D96QS961A
M9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M-3(@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0FQO8VL@)R5S)R!F]G(@87!P;&EK
M871I;VX@)R5S)R!S86MN87,N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")";&]C
M:VEN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B0FQO8VMT>7`B"@HC
M.B!C;VYF:6<O=&AE;65S+V)L=65M;V]N+G!H<#HV"FUS9VED(")";'5E($UO
M;VXB"FUS9W-T<B`B0FSE(&WE;F4B"@HC.B!C;VYF:6<O=&AE;65S+V)L=65W
M:&ET92YP:'`Z-@IM<V=I9"`B0FQU92!A;F0@5VAI=&4B"FUS9W-T<B`B0FSE
M='0@;V-H('9I='0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B1F5T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:6$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T
M<B`B0F]K;>1R:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(E)A
M;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(E)A;6)R961D
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4F%M87(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,@HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S
M;FEE;B!O8V@@2&5R>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B0N5D82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O
M='1O;2(*;7-G<W1R(")";W1T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,SD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)
M<VQA;F0B"FUS9W-T<B`B0F]U=F5T($ES;&%N9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)A>FEL(@IM<V=S='(@(D)R87-I;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I='1I
M<VMA('1E<G)I=&]R:65T(&D@26YD:7-K82!O8V5A;F5N(@H*(SH@8V]N9FEG
M+W1H96UE<R]B<F]W;BYP:'`Z-@IM<V=I9"`B0G)O=VXB"FUS9W-T<B`B0G)U
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B
M0G)U;F5I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QG
M87)I96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E!U;FMT;&ES
M=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K
M:6YA($9A<V\B"@HC.B!C;VYF:6<O=&AE;65S+V)U<FYT;W)A;F=E+G!H<#HY
M"FUS9VED(")"=7)N="!/<F%N9V4B"FUS9W-T<B`B0G+D;F0@3W)A;F=E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T
M<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B
M0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DW(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS
M9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@1&ES
M=')I8G5T:6]N(%!O:6YT<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")#7V5L;"!I;G-TY&QL;FEN9V%R+BXN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@
M:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B0V%C:&5I;FET:65R
M:6YG(.1R(&EN=&4@9G5L;'-TY&YD:6<N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U.0HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#@U(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#0P"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R("),=6=N="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C@*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;V1J82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z
M(&-O;F9I9R]T:&5M97,O8V%M;W5F;&%G92YP:'`Z-@IM<V=I9"`B0V%M;W5F
M;&%G92(*;7-G<W1R(")+86UO=69L86=E(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(DMA;B!I;G1E(&YO;&QS=.1L;&$@;/9S96YO<F0@875T;VUA=&ES
M:W0L(&MO;G1A:W1A(&1I;B!A9&UI;FES=')A=/9R+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,Q."!L:6(O1FEL92]#4U8N<&AP.C,U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(DMA;B!I;G1E('-K<FEV82!T:6QL(&9I;"`G)7,G(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES
M=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(D1E="!G
MY7(@:6YT92!A='0@861M:6YI<W1R97)A(&5X=&5R;F$@<V5S<VEO;G-H86YT
M97)A<F4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(SH@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C>7)S<6PN
M<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT82!)
M34%0+7-E<G9E<FXZ("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#$S(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E
M(/9P<&YA(&9I;"`G)7,G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N
M<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS
M9W-T<B`B079B<GET(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")!
M=F)R>70@<')O8FQE;7)A<'!O<G0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Q."!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA
M;B!I;G1E(')A9&5R82`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&9R86UE=V]R:R]61E-?25-/+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-PHC.B!F<F%M
M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C4S"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6YT92!H:71T82!E
M;B!T96UP<N1R(&UA<'`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HY,2!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(N
M<&AP.CDW"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*
M;7-G<W1R(")+86X@:6YT92!F;W)T<^1T=&$@=71A;B`G;>5L9FEL)RUP87)A
M;65T97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30@;&EB
M+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(')A
M9&5R82!M87!P("<E<R<N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C@P"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X(&QI8B](;W)D
M92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B2V%N
M(&EN=&4@<F%D97)A.R`E9"!B87)N(&5X:7-T97)A<BXB"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@@;&EB+TAO<F1E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G
M<W1R(")+86X@:6YT92!D:7)I9V5R82!M961D96QA;F1E('1I;&P@86YG:79E
M="!N=6UM97(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@
M(DMA<"!697)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B4G5B
M<FEK(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z,3`T(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED
M(")#87)R:65R(@IM<V=S='(@(D]P97)A=/9R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS
M9W-T<B`B2V%T96=O<FEE<B!O8V@@<G5B<FEK97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N($ES;&%N9',B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#
M96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@
M(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")#96QL:6YS=.1L;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T
M"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(D-E;&QU=&9Y;&QN860Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(D-E;&QI
M;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M0V5L;&UE;&QA;G)U;3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C<T(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B
M"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D-E
M;'1I<VL@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G
M<W1R(")#96YT<F5R860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(*;7-G<W1R(")#96YT<F%L869R:6MA;G-K82!R97!U8FQI
M:V5N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D-E;G1R86QE=7)O
M<&5I<VL@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.3D@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B0V5R=&EF:6MA
M=&1E=&%L:F5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,3$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E
M<G1I9FEC871E($]W;F5R(@IM<V=S='(@(D-E<G1I9FEK873D9V%R92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI
M8VEE<R(*;7-G<W1R(")#97)T:69I:V%T<&]L:6-I97,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")#:&%D(@IM<V=S='(@(E1C:&%D(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.38*;7-G:60@(D-H86ER
M(%!E<G-O;B(*;7-G<W1R(")/<F1F]G)A;F1E(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(L1N9')A(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!0
M87-S=V]R9"(*;7-G<W1R("+$;F1R82!D:71T(&SV<V5N;W)D(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-H86YG961E9F%U;'1I9&5N=&ET>2YI;F,Z,3,*;7-G
M:60@(D-H86YG92!D969A=6QT(&ED96YT:71Y(@IM<V=S='(@(L1N9')A(&;V
M<G9A;&0@:61E;G1I=&5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y
M"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*
M(F5M86EL<RXB"FUS9W-T<B`B(@HBQ&YD<F$@;F%M;B!O8V@@861R97-S('-O
M;2!M;W1T86=A<FYA('-E<B!NY'(@9&4@;.1S97(@;V-H('-V87)A<B!PY2!D
M:6YA("(*(FUE9&1E;&%N9&5N+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"B)!='0@8GET82!L]G-E;F]R9"!S=/9D<R!I;G1E(&UE9"!D96X@;G5V87)A
M;F1E(&MO;F9I9W5R871I;VYE;BX@(%9A<B!G;V0@(@HB:V]N=&%K=&$@861M
M:6YI<W1R873V<F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B5&MN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")+;VYT
M<F]L;&5R82!LY&YK+BXN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?=&]P+FEN8SHQ,PIM<V=I9"`B0VAE8VL@=&AE(&)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92XB"FUS9W-T<B`B36%R:V5R82!D92!A:W1I=FET971E<B!D=2!V:6QL('5T
M9O9R82!N=2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R(")+:6YA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R(")+:6YE<VES:W0@9O9R96YK;&%T("A'0C(S
M,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE
M<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(DMI;F5S:7-K="!T<F%D
M:71I;VYE;&QT("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B5N1L:B!A
M<'!L:6MA=&EO;CHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#
M:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")6Y&QJ(&SV<V5N;W)D(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V."!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B
M"FUS9W-T<B`B5N1L:B!A;G;D;F1A<FYA;6XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8R-@IM<V=I9"`B0VAO
M;W-E(&%N(&%C=&EO;CHB"FUS9W-T<B`B5N1L:B#E=&?D<F0Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")6Y&QJ(&AU<B!D871U;2!S:V%L;"!V
M:7-A<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B5N1L:B!L:7-T<W1I;"`H
M9O9R('-O<G1E<F%D92!L:7-T;W(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M
M87,@27-L86YD(@IM<V=S='(@(DIU;/9N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y-"!L:6(O
M5D93+G!H<#HY,30*(SH@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B2VQA<W-D969I;FET:6]N(&;V<B`E<R!S86MN87,N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@
M(D-L96%R(@IM<V=S='(@(E)E;G-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R(")296YS82!-4T]F9FEC92UT86=G87(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R
M(")296YS82!F<N5G82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E
M<R(*;7-G<W1R(")296YS82!A;G;D;F1A<F4Z("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM
M<V=S='(@(E)E;G-A(&%N=N1D;F%R92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`B4F5N<V$@86YVY&YD87)D871A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS
M9W-T<B`B4V5N87)E('5P<&ML87)N86YD92(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]N;W1I8V5?8F]T=&]M+FEN8SHV"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#
M;VYT:6YU92(*;7-G<W1R(")+;&EC:V$@9O9R(&%T="!F;W)T<^1T=&$B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#0*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G
M:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!V
M:6$@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM
M<V=S='(@(E-TY&YG(&;V;G-T97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(DUO;&XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S
M($5A<FQY(@IM<V=S='(@(E1I9&EG82!M;VQN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G
M<W1R(")-;VQN:6YG="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',B"FUS9W-T<B`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL
M87!S92!3:61E8F%R(@IM<V=S='(@(DMO;7!R:6UE<F$@<VED;V;D;'1E="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(DMO;7!R
M:6UE<F%D92!R86UA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T
M<B`B2V]L;VUB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
M1N1R9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#<U(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S$*(SH@;&EB
M+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S,B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R
M(")&Y')G:&%N=&5R87)E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@T-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@S,@IM<V=I9"`B0V]L;W5R('-E
M;&5C=&EO;B(*;7-G<W1R(")&Y')G=F%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S
M='(@(DMO;'5M;F5R.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M;B!T:71L
M97,B"FUS9W-T<B`B2V]L=6UN(')U8G)I:V5R(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(DQU<W1I
M9VAE=&5R(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM
M86YD(@IM<V=S='(@(DMO;6UA;F1O(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DMO;6UA;F1O9O9N
M<W1E<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS
M9W-T<B`B2V]M;65N=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G
M:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(DYA;6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I
M9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F]S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R
M(")&]G)E=&%G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV.3<*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R(")3;'5T
M9O9R9"(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HQ,#$*(SH@9G)A;65W;W)K+U1E>'0O5&5X="]&:6QT97(O96UA
M:6QS+G!H<#HX,@HC.B!F<F%M97=O<FLO5&5X="]497AT+T9I;'1E<B]E;6%I
M;',N<&AP.C@X"B,Z(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+V5M86EL
M<RYP:'`Z.3@*(SH@9G)A;65W;W)K+U1E>'0O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HQ,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]M<&]S92!-97-S86=E
M("@E<RDB"FUS9W-T<B`B4VMR:78@;65D9&5L86YD92`H)7,I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B1&%T;W)E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")6Y&1E<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@
M(E;D9&5R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B2V]N9FEG=7)A=&EO
M;G-S:VEL;&YA9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M
M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B));G-TY&QL;FEN
M9V%R(&;V<B!A='0@<WEN:W)O;FES97)A(&UE9"!H86YD9&%T;W)E<BP@<VUA
M<G1A('1E;&5F;VYE<B!O8V@@(@HB3W5T;&]O:R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N(@IM<V=S='(@(DMO;F9I9W5R871I;VX@8F5H]G9E<B!U<'!D871E
M<F%S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(DMO;F9I9W5R97)A
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM
M<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")"96MRY&9T82!L]G-E
M;F]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O
M9B!T:&4B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P
M.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(D;V<F)I;F1E
M;'-E(&UI<W-L>6-K861E<RXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")&]G)B:6YD96QS
M92!M:7-S;'EC:V%D97,Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<W.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B1O9R8FEN9&5L<V4@;65D('!U8FQI:R!N>6-K96QS97)V97(@
M;F5K861E<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D;V<F)I;F1E;'-E(&UE
M9"!P=6)L:6L@;GEC:V5L<V5R=F5R(&YE:V%D97,Z("5S("@E<RDB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-2!L:6(O5D93+V9T<"YP:'`Z
M.#<V"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(")&]G)B:6YD96QS92!M960@1E10+7-E<G9E<B!M:7-S;'EC:V%D
M97,N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O
M;G1A8W1S(@IM<V=S='(@(DMO;G1A:W1E<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,R!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N
M=&%K=&5R(&QA9&5S('1I;&P@:2!D:6X@861R97-S8F]K+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B26YN96CE;&QS='EP
M(&;V<B!K;VUP<FEM97)A9"!F:6PZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<X(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("));FYE:.5L;"!I("<E<R<B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(D9O
M<G1SY'1T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Q(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M0V]O:R!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS
M9VED(")#;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(DMO<&EE<F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0V."!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")+;W!I97)I;F<@;6ES
M<VQY8VMA9&5S.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@
M(DMO<&EE<F$@;6%R:V5R:6YG(@H*(SH@8V]N9FEG+W1H96UE<R]C;W)N9FQO
M=V5R+G!H<#HV"FUS9VED(")#;W)N9FQO=V5R(@IM<V=S='(@(DUA:G-B;&]M
M;6$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-2!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B2V]S=&YA
M9',M240B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,PHC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S
M=&$@4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R
M(")%;&9E;F)E;G-K=7-T96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-38*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R(")+86X@:6YT92!01U`M:W)Y<'1E<F$@;65D9&5L86YD
M92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B2V%N(&EN
M=&4@4$=0+6MR>7!T97)A(&UE9&1E;&%N9&4Z("(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$P,S,*;7-G:60@(D-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E+B(*;7-G<W1R(")+86X@:6YT92!01U`M<VEG;F5R82!M
M961D96QA;F1E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*
M;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B
M2V%N(&EN=&4@4$=0+7-I9VYE<F$@;65D9&5L86YD93H@(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP
M="!M97-S86=E+B(*;7-G<W1R(")+86X@:6YT92!3+TU)344M:W)Y<'1E<F$@
M;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C0V-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DMA;B!I
M;G1E(%,O34E-12US:6=N97)A(&UE9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DMA;B!I
M;G1E(&SD9V=A('1I;&P@:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.CDV(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!,1$%0('-E<G9E
M<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ-S,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B
M"FUS9W-T<B`B2V%N(&EN=&4@=F5R:69I97)A(&MO;G1O<V%L9&\N("5S(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;F1E(&EN=&4@
M86YS;'5T82!T:6QL($Q$05`M<V5R=F5R+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B
M2V%N(&EN=&4@:V]N=&%K=&$@<V5R=F5R("<E<R<@=FEA($944#H@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R
M,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(&1I<W1R:6)U=&EO
M;G-L:7-T82X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,3`U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS
M9W-T<B`B2V%N(&EN=&4@9&5K<GEP=&5R82!01U`M9&%T82XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DMA;B!I;G1E(&1E:W)Y<'1E<F$@
M4$=0+61A=&$Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3(R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#
M;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B2V%N(&EN
M=&4@9&5K<GEP=&5R82!3+TU)344M9&%T82XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V%N(&EN
M=&4@<F%D97)A(&MO;G1A:W0N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+
M86X@:6YT92!R861E<F$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@=7!P9W)A9&5R:6YG<W-C<FEP
M="!T:6QL.B`E<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S@*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B2V%N(&EN=&4@
M8F5S=.1M;6$@;6]T=&%G87)E;G,@95!O<W0M861R97-S+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMA
M;B!I;G1E(&CD;71A(&MO;7!L971T(&%D<F5S<V)O:RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DMA;B!I;G1E(&CD;71A(&MO;7!L971T(&1I<W1R:6)U=&EO;G-L:7-T82XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0T-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(")+86X@:6YT92!HY&UT82!K;VUP
M;&5T="!L:7-T82#V=F5R(&1I<W1R:6)U=&EO;G-L:7-T;W(N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S
M='(@(DMA;B!I;G1E(&QA9&1A('-T<F%T96=I("<E<R<N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M-CD*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2`G)7,G+B(*;7-G<W1R(")+86X@:6YT92!L861D82!S
M=')A=&5G:2`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6YT92!S:V%P82!M87!P("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,0HC
M.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V1I<F5C="YP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&UK9&ER("<E<R<N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(&UA<'`@
M)R5S)RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,#@@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R
M(")+86X@:6YT92!HY&UT82!P=6)L:6L@;GEC:V5L(&9RY6X@;GEC:V5L<V5R
M=F5R;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DMA;B!I;G1E(/9P<&YA("<E<R<@9O9R('-K<FEV:6YG
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(V,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(DMA;B!I;G1E(/9P<&YA("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@)R5S)R!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N(&EN=&4@
M]G!P;F$@)R5S)R!F]G(@<VMR:79I;F<N(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B2V%N(&EN
M=&4@]G!P;F$@36%I;G1E;F%N8V5?5&%S:R!M;V1U;"`E<R(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT
M92#V<'!N82!M87!P96X@)R5S)R(*"B,Z(&9R86UE=V]R:R]61E-?25-/+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RXB
M"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@;6%P<"`G)7,G(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-CDY"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV
M-38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@
M;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EN=&4@
M:V]N=&%K=&$@3$1!4"!S97)V97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<#HR,S@@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B2V%N
M(&EN=&4@;.1S82`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*(D1E="!G:6-K(&EN=&4@871T(.5T97)S=.1L;&$@
M;/9S96YO<F1E="!F]G(@9&5N(&%N9VEV;F$@86YVY&YD87)E;BX@3N5G;VX@
M(@HB96QL97(@;N5G<F$@878@=7!P9VEF=&5R;F$@Y'(@:6YT92!K;W)R96MT
M82X@1O9R<_9K(&EG96X@96QL97(@:V]N=&%K=&$@(@HB861M:6YI<W1R873V
M<F5N(&]M(&1U(&)E:/9V97(@:&KD;'`N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S`W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!
M0TPB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@04-,(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G
M<W1R(")+86X@:6YT92!HY&UT82!A9')E<W-B;VLN("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A(&1I<W1R:6)U=&EO;G-L:7-T
M82X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0S-PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A
M(&1I<W1R:6)U=&EO;G-L:7-T;W(N("5S(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS
M9W-T<B`B2V%N(&EN=&4@:.1M=&$@9'-E<G9E<F9U;FMT:6]N97(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMA;B!I;G1E(.5T97)S=.1L
M;&$@:V]N9FEG=7)A=&EO;F5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E
M<UPB+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<FUD:7(@)R5S)RXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S
M)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")+86X@:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N(&;V<B`E<RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BXB"FUS9W-T<B`B2V%N(&EN=&4@<W!A<F$@8F%C:W5P+6MO
M;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B2V%N(&EN=&4@<W!A<F$@96X@8F%C
M:W5P+6MO;F9I9W5R871I;VXZ("5S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DMA
M;B!I;G1E('-P87)A('5P<&=R861E<FEN9W-S8W)I<'0@=&EL;#H@)7,N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B2V%N(&EN=&4@<W!A<F$@8F%C:W5P+6MO;F9I
M9W5R871I;VX@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O
M<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R
M("(B"B)+86X@:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N<V9I;&5N("5S+B!$
M=2!K86X@86YT:6YG96X@86YVY&YD82!E;B!A=B`B"B)A;'1E<FYA=&EV96X@
M871T('-P87)A(&MO9&5N('1I;&P@)7,@96QL97(@:V]P:65R82!K;V1E;B!N
M961A;B!T:6QL("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,30S(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U
M;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DMA;B!I
M;G1E('/V:V$@:2!,1$%0+6MA=&%L;V=E;BXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N
M;&EN:R!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`G)7,G+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HX-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=6YL:6YK("<E<R<N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`G)7,G
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C$Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(")+86X@:6YT92!U<'!D871E<F$@:V]N=&%K="X@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,Y-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DMA;B!I;G1E('5P<&1A=&5R82!D:7-T
M<FEB=71I;VYS;&ES=&$N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DMA;B!I;G1A('-P
M87)A(&MO;F9I9W5R871I;VX@9O9R("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB
M"FUS9W-T<B`B2V%N(&EN=&4@:&ET=&$@36]Z:6QL87,@<VED;V;D;'0N(%9E
M<FEF:65R82!A='0@<VED;V;D;'1E="#D<B#V<'!E="XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B2V%N(&EN
M=&4@9V4@86YVY&YD87)E;B`G)7,G(&%N9VEV;F$@<N1T=&EG:&5T97(@=&EL
M;"!M87!P96X@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S"FUS9VED(")#;W5N=&5D
M('1E>'0B"FUS9W-T<B`B4N1K;F%D('1E>'0B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("),86YD(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G
M<W1R(")+=7)S97(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R
M(")3:V%P82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R
M(")3:V%P82!LY&YK(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")3
M:V%P82!N>2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R(")3:V%P82!U;F1E<FUA<'`B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,"!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G
M<W1R(")"96CV<FEG:&5T97(@9O9R(.1G87)A(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(S,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q-@IM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DMR961I=&MO<G1S;G5M
M;65R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.0HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B2W)O871I
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*
M;7-G<W1R(")!:W1U96QL82`T(&9A<V5R(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(D%K='5E
M;&P@<V5S<VEO;B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C
M:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D%K
M='5E;&P@=&ED(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G
M<W1R(")!:W1U96QL(%523"#D<B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")!:W1I=F$@86YVY&YD
M87)E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N
M="!796%T:&5R(@IM<V=S='(@(D%K='5E;&QT(';D9&5R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD
M:71I;VXZ("(*;7-G<W1R(")!:W1U96QL82!V:6QL:V]R.B`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#
M=7)R96YT('-T>6QE(@IM<V=S='(@(D%K='5E;&P@<W1I;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M(")3:W+D9&1A<G-Y(&%K=&EV:71E=&5R('-O;2!K]G)S('9I9"!I;FQO9VYI
M;F<@=&EL;"`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")+;&EP
M<"!U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B2VQI<'`@=7)V
M86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-PHC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#>7!E<FXB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`B2WER:6QL:7-K("A+3TDX+5(I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I(@IM<V=S='(@(DMY<FEL;&ES:R`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52DB"FUS9W-T<B`B2WER:6QL:7-K+U5K<F%I;G-K("A+3TDX
M+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")4
M:F5C:VEE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,C8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T
M<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@P(&QI8B](
M;W)D92]&;W)M+G!H<#HS,C<V"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3D@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&%G;&EG(@H*(SH@861M
M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM
M<V=S='(@(D1A=&%4<F5E(&)LY&1D<F%R92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G:60@
M(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")$871A8F%S=7!P<VQA9R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0P,B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM
M<V=I9"`B1&%T92(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM
M<V=S='(@(D1A='5M(&UO='1A9V5T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B1&%T
M92!S96QE8W1I;VXB"FUS9W-T<B`B1&%T=6UV86PB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")$86<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E]2861E<F$@:V]L=6UN(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(U"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E
M<B(*;7-G<W1R(")D96-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R(")$96-I;6%L97(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X-0IM<V=I9"`B1&5C;&EN
M960B"FUS9W-T<B`B079B]FIT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM
M<V=S='(@(DUI;G-K82!I;F1R86<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")&]G)V
M86QT(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B1O9R=F%L9"!F
MY')G(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,2!L
M:6(O2&]R9&4O261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT
M:71Y(@IM<V=S='(@(D;V<G9A;&0@:61E;G1I=&5T(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@
M(D;V<G9A;'0@<VMA;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM
M<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6YI=&EO;F5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#,*
M;7-G:60@(D1E;&5G871E('!O<VET:6]N(@IM<V=S='(@(D1E;&5G97)A('!O
M<VET:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV.3,*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R(")$96QE9V5R
M860B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z(&9R86UE
M=V]R:R],:6YK<R],:6YK<RYP:'`Z,C8S"B,Z(&9R86UE=V]R:R]296QA=&EO
M;G-H:7`O4F5L871I;VYS:&EP36%N86=E<BYP:'`Z,C4X(&QI8B](;W)D92]0
M97)M<RYP:'`Z,S(V"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE
M=&4B"FUS9W-T<B`B4F%D97)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L
M;"(*;7-G<W1R(")2861E<F$@8V5L;"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B
M"FUS9W-T<B`B4F%D97)A(&=R=7!P(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(E)A9&5R
M82!L;V=G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C<W(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`Q"FUS
M9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")2861E<F$@8F5H]G)I
M9VAE="(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")2861E<F$@;V-H
M(')E;G-A(&UE9&1E;&%N9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB
M"FUS9W-T<B`B4F%D97)A(&-E;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L
M=6UN(@IM<V=S='(@(E)A9&5R82!K;VQU;6XB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R(")2861E<F$@8F5F:6YT;&EG(&%L=&5R;F%T:79M
M86QL(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4T"FUS
M9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B4F%D97)A9&4@;65D9&5L
M86YD96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,2!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")2861E
M<F$@8F5H]G)I9VAE="!F]G(@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(T(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")2861E<F$@
M8F5H]G)I9VAE="!F]G(@)R5S)R!O8V@@=6YD97)B96CV<FEG:&5T97(_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")2861E<F$@<F%D(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I
M9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E)A9&5R82!V
M86QD(&ED96YT:71E="(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(E)A
M9&5R82!U;F1E<FUA<'!A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(*;7-G<W1R(")2861E<F$@86MT=65L;"!K;VQU;6XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T
M<B`B4F%D97)A(&%K='5E;&P@<F%D(@H*(SH@9G)A;65W;W)K+TQI;FMS+TQI
M;FMS+G!H<#HR-C,*(SH@9G)A;65W;W)K+U)E;&%T:6]N<VAI<"]296QA=&EO
M;G-H:7!-86YA9V5R+G!H<#HR-3@*;7-G:60@(D1E;&5T92!T:&ES(&QI;FLB
M"FUS9W-T<B`B4F%D97)A(&1E;B!HY'(@;.1N:V5N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E)A9&5R
M861E('5P<&=R861E<FEN9W-S8W)I<'1E="`G)7,G+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-3,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@
M(DQE=F5R86YS=&ED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@
M(D1A;FUA<FLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C8T,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(D%V
M<VSE(&)E9^1R86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0W,0IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E
M+V)U<WD@:6YF;W)M871I;VXB"FUS9W-T<B`B079S;.4@8F5GY')A;B!O;2!L
M961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE
M;2(*;7-G<W1R(")"97-K<FEV('!R;V)L96UE="(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38U(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDS.`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.30R('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E<VMR:79N:6YG(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34@;&EB+TAO<F1E+G!H<#HQ
M.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB
M"FUS9W-T<B`B1&5T86QJ97(@*&]C:W/E(&D@2&]R9&5S(&QO9V=F:6PI.B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY(&QI8B](;W)D92YP
M:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A;&IE<B!H87(@;&]G9V%T
M<R!F]G(@<WES=&5M861M:6YI<W1R873V<F5N+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@
M(E5T=F5C:VQI;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I
M9"`B1&5W(%!O:6YT(@IM<V=S='(@(D1A9V=P=6YK="(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(D1A9V=P=6YK="!F]G(@<V5N87-T92!T:6UM96XZ("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E
M=R!P;VEN=#H@(@IM<V=S='(@(D1A9V=P=6YK=#H@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B4FEK=&YI;F<@=N1N<W1E<B!T
M:6QL(&CV9V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS
M9W-T<B`B4FEK=&YI;F<@:/9G97(@=&EL;"!VY&YS=&5R(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+
M871A;&]G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B
M1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")6:7-A(#(T+71I;6UA
M<G,@:VQO8VMA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")6:7-N:6YG<VEN<W3D;&QN
M:6YG87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B5FES82!D
M971A;&IE<F%D(&;V<G5T<^1G96QS92(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M5FES82!F]G)U='/D9V5L<V4@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$W(&QI8B](;W)D92]&;W)M+G!H<#HR.#`S"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")6:7-N:6YG<V9O<FUA="(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`@;&EB+TAO<F1E+TU)344O
M341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9&EV:61E<BYP:'`Z-"!L:6(O0FQO
M8VLO9&EV:61E<BYP:'`Z-#4*;7-G:60@(D1I=FED97(B"FUS9W-T<B`B079S
M:VEL:F%R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II
M8F]U=&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T
M92(*;7-G<W1R(")2861E<F$@:6YT92(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`B06YVY&YD(&EN=&4@;6%I;G1E;F%N8V4N
M<&AP(&1I<F5K="(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(DEN;F5HY6QL97(@9O9R<W1A(')A
M9&5N(&;D;'1N86UN96X_($]M("=J82<L(&UA<FME<F$@:.1R.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$
M;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:V%N<VMA(')E<'5B
M;&EK96XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED
M(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(DAA
M<B!D=2!I;F=E="!K;VYT;S\@4F5G:7-T<F5R82!D:6<N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0S(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HX-3(*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(DCD
M;71A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0S
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B2.1M=&$@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")(
MY&UT82!G96YE<F5R860@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP="XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(")$
M<F]P<&QI<W1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED
M(")$<G5G<R(*;7-G<W1R(")$<F]G97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,#(@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(@;&EB+TYE="]335,O
M9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N(@IM<V=S='(@(B(*(D1R:79R=71I;B!F]G(@12UP;W-T('1I;&P@
M4TU3+6)R>6=G83L@9O9R(&]P97)A=/9R97(@<V]M('1I;&QH86YD86CE;&QE
M<B`B"B)D96YN82!T:N1N<W0N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`HC.B!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R(")&14PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B
M"FUS9W-T<B`B16MU861O<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(U(&QI8B](;W)D92]097)M<RYP:'`Z,S(U"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R
M("+$;F1R82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@
M;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*
M;7-G<W1R("+$;F1R82!B;&]C:R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(L1N9')A(&=R=7!P(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BQ&YD<F$@
M8F5H]G)I9VAE="(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ&YD<F$@8F5H]G)I
M9VAE=&5R(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("+$;F1R82!B96CV<FEG:&5T97(@9O9R("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS
M9W-T<B`BQ&YD<F$@:6YS=.1L;&YI;F=A<B!F]G(Z(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(L1N9')A(&)E:/9R:6=H971E<B!F]G(@)R5S
M)R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
MQ&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G)7,G(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B571B:6QD
M;FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=Y<'1E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A
M;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L
M96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-CD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M
M86EL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D
M<F5S<R(*;7-G<W1R(")%+7!O<W1A9')E<W,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.38S(&QI8B](;W)D92]&;W)M+G!H<#HQ.38W"FUS9VED
M(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B12UP;W-T
M861R97-S97(@;>5S=&4@<W3D;6UA(/9V97)R96YS+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y.#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3,*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D4M<&]S
M=&UE9&1E;&%N9&4@;65D(&)E:W+D9G1E;'-E(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$@;&EB+TYE="]335,O9V5N
M97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB
M"FUS9W-T<B`B12UP;W-T('1I;&P@4TU3+6)R>6=G82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.#$*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS
M(@IM<V=S='(@(DOD;G-L;VEK;VYE<B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB
M"FUS9W-T<B`B5&]M="!M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C(T,PHC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#@T
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C<P-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-3`*
M;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B5&]M="!R97-U;'1A="XB
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S(&QI8B](
M;W)D92]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H
M('1E<FUS(@IM<V=S='(@(E1O;70@<_9K:W)I=&5R:6$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F
M(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0T.`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4U
M,PIM<V=I9"`B16YD(@IM<V=S='(@(E-L=70B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(W.3<*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(E-L=70@Y7(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")&]G)S=&]R82!E9&ET;W(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T
M<B`B06YG92!S]FMVY&<@*%523"D@=&EL;"!B:6QD96X@:.1R(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@V,PHC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B4TMR:78@8F]K<W3D=F5R
M;F$@;F5D86XZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R;W(B"FUS9W-T
M<B`B1F5L(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C,@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(D9E;"!V
M:60@<VMA<&%N9&4@878@8FQO8VLZ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L
M971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(D9E;"!V:60@<F%D97)I
M;F<@878@<WEN:W)O;FES97)I;F=S;>1R:V4Z("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(D9E;"!V:60@<F%D
M97)I;F<@878@<WEN:W)O;FES97)I;F=S;&]G9SH@)7,B"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V."!L:6(O2&]R9&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(@IM<V=S='(@(D9E;"!NY'(@:6YN96CE;"!HY&UT861E
M<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C$Y-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C(W.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C,T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S
M96YD:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`B1F5L('5N9&5R('/D;F1N:6YG
M(&%V('-V87)S;65D9&5L86YD93H@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D9E;"!V:60@=7!P9&%T97)I
M;F<@878@;/9S96YO<F0Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB
M+B(*;7-G<W1R(")&96P@=FED('-K<FEV;FEN9R`G)7,G+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R`G
M)7,G+B(*;7-G<W1R(")&96P@=FED('-K<FEV;FEN9R!A=B`G)7,G+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<V"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1L86YD(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&EO<&EE;B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T
M;FES:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@
M(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@
M(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B5F%R(#$U.F4@;6EN=70B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI
M;G5T97,B"FUS9W-T<B`B5F%R86YN86X@;6EN=70B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G
M:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B5F%R(#,P.F4@<V5K=6YD
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B
M5F%R(#4Z92!M:6YU="(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM
M<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B5F%R:F4@:6YL;V=G;FEN9R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R(")687)J92!H86QV=&EM;64B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")687)J92!M:6YU="(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE
M('9A;'5E<SHB"FUS9W-T<B`B17AE;7!E;"!PY2!VY')D96XZ(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(DOV
M<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-2!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT-S4*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G
M<W1R(")%>'!A;F1E<F$B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")%>'!A;F1E
M<F$@<VED;V;D;'0B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B
M17AP96-T960@)RDG(@IM<V=S='(@(D;V<G;D;G1A9&4@)RDG(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-2!L:6(O2&]R9&4O4U%,
M+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B1O9R=N1N=&%D92!E;G-K
M:6QT(&]R9"!E;&QE<B!C:71E<F%T('/V:V)E9W)E<'`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#$@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1O9R
M9F%L;&]D871U;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O
M;&]R(@IM<V=S='(@(D;V<F=R=6YD<V;D<F<B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S
M='(@(DQA9&1A('5P<"!K;VYF:6=U<F%T:6]N('9I82!&5%`N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V(&QI8B](;W)D92]0<F5F
M<R]S<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N(@IM<V=S='(@(DUI<W-L>6-K861E<R!A='0@:.1M=&$@:6YS=.1L
M;&YI;F=A<BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`HC.B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&MO;G1A:W1A($Q$05`@<V5R=F5R
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY."!L:6(O2&]R
M9&4O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+B(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&MO;G1A
M:W1A(%--0B!S97)V97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV.#8@;&EB+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B36ES<VQY
M8VMA9&5S(&%T="!K;W!I97)A(&9RY6X@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C8Y,2!L:6(O5D93+V9T<"YP:'`Z-S(R"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS
M9W-T<B`B36ES<VQY8VMA9&5S(&%T="!K;W!I97)A('1I;&P@)R5S)RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W(&QI8B](;W)D92]!
M=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(DUI<W-L>6-K861E<R!A='0@<VMA
M<&$@;GD@4T%33"UF]G)B:6YD96QS92XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC
M.B!L:6(O5D93+W-M8BYP:'`Z-3`Q(&QI8B]61E,O9G1P+G!H<#HW-34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&9L>71T82!T:6QL("<E<R<N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$@;&EB+U9&4R]S;6(N
M<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(@IM<V=S='(@(DUI<W-L>6-K861E<R!A='0@:.1M=&$Z("5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G
M:60@(D9A:7(B"FUS9W-T<B`B0G)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1S]F%R;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1N1R]F%R
M;F$B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X(&QI8B](;W)D92]#
M3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D9A=&%L
M="!F96PZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$X-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>&%R(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$U"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R(")F96)R=6%R:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(DOD;FYS('-O;2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS
M(&QI:V4Z("(*;7-G<W1R(")+Y&YN<R!S;VTZ("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R
M<R(*;7-G<W1R(")&Y71A;&EG82!S:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")&Y71A;&EG82!S;O9S:W5R87(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.30T(&QI8B](;W)D92]&;W)M+G!H<#HQ.30X
M"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B1N1L=&UA=')I<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,S,CD*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(D9I9VQE
M="!#05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,S,PIM<V=I9"`B1FEG;&5T(&9O;G0B"FUS
M9W-T<B`B1FEG;&5T='EP<VYI='0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS
M9W-T<B`B1FEJ:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6PB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-R!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D%N=&%L(&9I;&5R.B`E
M<R!F:6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV,`HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE
M<R(*;7-G<W1R(")!;G1A;"!F:6QE<CH@)7,@9FEL97(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS
M9W-T<B`B1FEL:&%N=&5R87)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")&
M:6QN86UN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDX,0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS
M9W-T<B`B1FEL=F%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X
M-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30Y,`IM<V=I9"`B1FEL92!U<&QO860B
M"FUS9W-T<B`B1FEL=7!P;&%D9&YI;F<B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-30@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,@IM
M<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D9I
M;'5P<&QA9&1N:6YG('-T]F1S(&EN=&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R(")&]G)S=&$@:&%L=F%N(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T
M(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*
M;7-G<W1R(")&]G)S=&$@:W9A<G1E;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,SD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,30*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM
M<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,#<*(SH@;&EB+U9&4R]S<6PN<&AP.C(S-R!L:6(O5D93+VUU<W%L+G!H<#HQ
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(DUA<'`@)7,@97AI<W1E<F%R(&EN=&4N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B
M1F]N="!#;VQO<B(*;7-G<W1R(")&;VYT9N1R9R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")-870B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S(@IM<V=S='(@(D;V<B!W96)B;.1S87)E('-O;2!I;G1E('-T]F1E
M<B!B:6QD97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I9"`B
M1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')O9VYO<R`H5$%&*2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A
M<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U
M<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)!
M;G1A;"!D86=A<B!F]G(@<')O9VYO<R`H=F%R:F4@9&%G(&)E='ED97(@96X@
M<')O9VYO<R!F]G(@9&%G(&]C:"!E;B!F]G(@(@HB;F%T="DB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@
M<&%S<W=O<F0_(@IM<V=S='(@(D=L]FUT(&1I='0@;/9S96YO<F0_(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS
M9W-T<B`B1F]R;75LY'(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*
M;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B5FES:&5T<V]R9"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S
M='(@(E1Y<"!A=B!V:7-H971S;W)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")6:7-H971S;W)D(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R
M(@IM<V=S='(@(E9I<VAE='-O<F0@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S
M(@IM<V=S='(@(E9I9&%R8F5F;W)D<F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B
M1G(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B4F%M87(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-PHC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N:W)I:V4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@
M(D9R86YK<FEK92P@365T<F]P;VPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-PIM<V=I9"`B1G)E92]"=7-Y($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DQE9&EG+U5P<'1A9V5N(&EN9F]R;6%T:6]N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HT,C<*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R("),961I9R]5
M<'!T86=E;B!S=F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT,C(*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM
M<V=S='(@(DQE9&EG+W5P<'1A9V5N+6;V<F9RY6=A;B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C<R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0Q"FUS9VED
M(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS92(*;7-G<W1R(")3=F%R('#E
M(&QE9&EG+W5P<'1A9V5N+6;V<F9RY6=A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R(")&<F%N<VMA($=U:6%N82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R86YS:V$@4&]L
M>6YE<VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<R(*;7-G<W1R(")&<F%N<VMA('/V9')A('1E<G)I=&]R:65R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I
M9"`B1G)O;2(*;7-G<W1R(")&<N5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R
M;VT@=&AE("(*;7-G<W1R(")&<N5N(&1E;B`B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*
M;7-G<W1R(")&=6QL<W3D;F1I9R!B97-K<FEV;FEN9R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&
M=6QL($UO;VXB"FUS9W-T<B`B1G5L;&WE;F4B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV
M,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D9U;&QS=.1N9&EG="!N86UN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`B1V%L;&5R:2!A='0@=&$@8FEL9"!F<N5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R(")'86QL97)I.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F5R82!K;VYF:6=U<F%T:6]N(&;V
M<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'96YE<F5R860@:V]D
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(E1Y<VML86YD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDQ(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(D;V<FYA
M;6XB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")';&]B86QA
M(&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M-PIM<V=I9"`B1V\B"FUS9W-T<B`B3TLB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P,`HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B
M1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE:V%R=&]R(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G
M<W1R(")';V]G;&5S]FMN:6YG(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B1W+E
M<VMA;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R96MI
M<VL@*$E33RTX.#4Y+3<I(@H*(SH@8V]N9FEG+W1H96UE<R]G<F5E;BYP:'`Z
M-@IM<V=I9"`B1W)E96XB"FUS9W-T<B`B1W+V;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1W)E96YL86YD(@IM<V=S='(@(D=R]FYL86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDU(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M<F5N861A(@IM<V=S='(@(D=R86YA9&$B"@HC.B!C;VYF:6<O=&AE;65S+V=R
M97DN<&AP.C8*;7-G:60@(D=R97DB"FUS9W-T<B`B1W+E(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D=R=7!P861M:6YI<W1R871I;VXB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-CD*(SH@;&EB+TAO<F1E+T=R;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S`W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(D=R;W5P7VQD87`Z($MA;B!I;G1E(&SD9V=A('1I;&P@9W)U<'`@)R5S
M)RX@4V5R=F5R;B!S=F%R861E.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q."!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$X"B,Z(&QI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<#HQ,C0@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($MA;B!I;G1E(')A
M9&5R82!G<G5P<"`G)7,G(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,S@@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P
M7VQD87`Z($MA;B!I;G1E('5P<&1A=&5R82!G<G5P<"`G)7,G(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HS,30*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R
M(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C(V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(D?D<W1B
M96CV<FEG:&5T97(B"@HC.B!T96UP;&%T97,O9W5E<W0O9W5E<W0N:6YC.C$Q
M"FUS9VED(")'=65S="!397)V:6-E<R(*;7-G<W1R(")4:N1N<W1E<B!F]G(@
M9^1S=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(D?D<W1B;VLB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=U:6YE82(*;7-G<W1R(")'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U":7-S874B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P(&QI8B](;W)D92]&;W)M+G!H<#HY-C0*
M;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S
M:7-T82!C96QL96X@:2!E;B!R860N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S
M:7-T82!K;VQU;6YE;B!I(&5N('1A8F5L;"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(';D9W)A<B!A='0@<F%D97)A
M('-I<W1A(')A9&5N(&D@96X@=&%B96QL+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:'1T<"YP:'`Z,34W(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U
M-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(DA45%`@075T96YT:7-E<FEN9R!S86MN87,N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,#(@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")(87-H86QG;W)I
M=&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")$:6UM82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,C,@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,3@*;7-G:60@(DAE861E<B(*;7-G<W1R(")2=6)R:6LB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,Z(&QI8B](
M;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(E)U8G)I:V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D+2!O
M8V@@36-$;VYA;&3V87)N82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(DMR869T:6=A(.5S:W-K=7)A<B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B
M<F5I<VL@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS
M9W-T<B`B2/9J9"(*"B,Z(&QI8B]";&]C:R]B87)T:6UE+G!H<#HR-"!L:6(O
M0FQO8VLO9&EV:61E<BYP:'`Z,C0*;7-G:60@(DAE:6=H="`H:6X@<&EX96QS
M*2(*;7-G<W1R(")(]FID("AP:7AL87(I(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L
M<"YP:'`Z,3@V"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ.#0@;&EB+TAO<F1E
M+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R
M(")(:N1L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(DAJ
MY&QP(&UE9"!E9&ET;W)N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W-0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(DAJY&QP9G5N:W1I;VXB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FY'(B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.B(*;7-G<W1R(")(Y'(@Y'(@8O9R:F%N(&%V(&9I;&5N.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")(:6=H(@IM<V=S='(@(DCV9R(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z
M-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&5?;2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM
M<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#DQ(&QI8B](;W)D
M92YP:'`Z,34S.0IM<V=I9"`B2&]M92(*;7-G<W1R(")(96TB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G
M<W1R(")!9')E<W,L(&AE;2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B2&5M:V%T86QO9R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@
M(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L969O;BP@:&5M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-@HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R
M(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D
M(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($]G:6QT:6=T
M("5S(%A-3"UD871A('#E='+D9F9A9&5S(&D@;65D9&5L86YD92`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@26YG970@;65D9&5L86YD92!M871C:&%R(&]B:F5K=&5T
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86XZ($EN9V5T(&]B:F5K="!A=B!T>7!E
M;B`E<R!H:71T861E<R!I(&UE9&1E;&%N9&5T("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C4P(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!2
M861E<F%D92`E<R`G)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HR,C,@;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E
M9W)A=&EO;G-M;W1O<FX@:W+D=F5R("=D;VUX;6PG+71I;&SD9V=E="!F]G(@
M4$A0(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I;G1E('-K87!A(&YY
M='0@6$U,+71RY&0@9O9R(&]B:F5K="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(T-R!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EN
M=&4@<F%D97)A("5S("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-S0@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!+86X@:6YT92!HY&UT82!-24U$12U)1"!F]G(@9&5L96X@;65D
M('1Y<"`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,R!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6YT92!S>6YK<F]N:7-E
M<F$@)7,@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$S,S8@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EN=&4@<WEN:W)O
M;FES97)A('5T9&5L;FEN9V%R.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,S0P(&QI8B](;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<
M(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@3VOD;F0@=71D96QN:6YG("<E<R<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T
M"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B2&]R:7-O;G1E;&P@
M;&EN:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B2&]R
M:7-O;G1E;&P@=71F>6QL;F%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T
M<B`B2&]R:7-O;G1E;&PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")(=7(@:&%M;F%D
M92!D=2!HY'(_("A687(@9V]D(')A<'!O<G1E<F$@9&5T=&$A*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*
M;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_(@IM<V=S='(@(DAU<B!MY6YG82!K;VQU;6YE<B!V:6QL(&1U('-LY2!I
M:&]P/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B2'5R(&WE;F=A(&;D;'0@*&MO;'5M;F5R*2!F:6YN<R!D970_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`B2'5R(&WE;F=A(')A9&5R('9I;&P@9'4@<VSE('-A;6UA
M;C\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")&
M=6MT:6=H970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X
M"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(D9U:W1I9VAE=#HB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R(")(=6UO<FES=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*
M;7-G<W1R(")5;F=E<FXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC
M.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-K87!A;F1E(&%V
M($E-05`M;6%P<"!M:7-S;'EC:V%D93H@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-0HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C$T(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(E)A9&5R:6YG(&%V($E-05`M;6%P<"!M:7-S;'EC:V%D97,Z("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R(")3:V%P86YD92!A=B!Q=6]T82!F]G(@24U!
M4"UM87!P(&UI<W-L>6-K861E<SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S$V(&QI8B](;W)D92]&;W)M+G!H<#HQ,S(P"FUS9VED("))
M4"!!9&1R97-S(@IM<V=S='(@(DE0+6%D<F5S<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O:7!B87-I
M8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B25`M861R97-S(.1R(&EN=&4@=&EL;&?D;F=L:6<N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.2!L:6(O2&]R9&4O075T
M:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`M861R97-S(.1R(&EN
M=&4@:6YO;2!G;V1KY&YT($-)1%(M8FQO8VLN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W
M;B!V:6]L871I;VXN(@IM<V=S='(@(D;V<G/V:R!A='0@:W)I;F=GY2!)4"UL
MY7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T
M<B`B25]N9F]G82!R860@9O9R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA
M;F0B"FUS9W-T<B`B27-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")%;F)A<G0@:6MO;F5R
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N97(@9O9R("5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(DEK;VYE<B!M960@=&5X="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS
M9W-T<B`B261E;G1I=&5T96YS(&YA;6XZ(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DQ(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+B(*;7-G<W1R(")/;2!D970@:6YT92!V:7-A<R!K;W)R96MT+"`E<R!F
M]G(@871T(/9P<&YA(&D@;GET="!F]FYS=&5R+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2XB"FUS9W-T<B`B(@HB3VT@9'4@:6YT92!S97(@;N5G<F$@:6MO;F5R
M(&[D<B!D=2!A;G;D;F1E<B!);G1E<FYE="!%>'!L;W)E<BP@<^4@:V%N(&1U
M("(*(F)E:/9V82!M87)K97)A(&1E;FYA(')U=&$@9O9R(&%T="!S=.1N9V$@
M878@9V5N;VUS:VEN;&EG82!03D<M8FEL9&9I;&5R+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-3@*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N(@IM<V=S='(@(B(*(D]M(&1U('-E<B!D96YN82!T97AT(&UE
M;B!I;F=E;B!B:6QD+"!SY2!K86X@:6YT92!D:6X@=V5B8FSD<V%R92!V:7-A
M(&1E;B`B"B)B:6QD(&1U(&;V<G/V:V5R(&QA9&1A('5P<"XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(D;V<FAA;F1S9W)A
M;G-K82!B:6QD.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")"
M:6QD861R97-S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S
M='(@(D)I;&1A9')E<W,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDB"FUS9W-T<B`B0FEL9"!F<N5N(&=A;&QE<FDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B0FEL9"!F
M<N5N(&=A;&QE<FDZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D
M(@IM<V=S='(@(DQA9&1A('5P<"!B:6QD(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")":6QD97(B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1E<F$L('-T96<@
M)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B26UP
M;W)T97)A9&4@9N1L=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R
M=&5R861E(&;D;'0Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HW,#$*;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`B
M4.5GY65N9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(DEN7V9O9V$@<F%D(&5F=&5R(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U(&QI8B](;W)D92]#;VUP<F5S<R]Z
M:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+B(*;7-G<W1R(")&96QA:W1I=B!A:W1I=FET971S:V]D('-P96-I9FEC97)A
M9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*
M;7-G<W1R(")&96QA:W1I9W0@86YVY&YD87)N86UN(&]C:"]E;&QE<B!L]G-E
M;F]R9"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I
M9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)/9VEL=&EG
M="!A;G;D;F1A<FYA;6X@96QL97(@86QT97)N871I=B!A9')E<W,N($;V<G/V
M:R!I9V5N(&5L;&5R(&MO;G1A:W1A("(*(F%D;6EN:7-T<F%T]G)E;B!O;2!D
M=2!B96CV=F5R(&AJY&QP+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G
M<W1R("+6:V$@:6YD<F%G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS
M9W-T<B`B26YD:65N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-30@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-30*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B
M"FUS9W-T<B`B26YD:79I9'5E;&QA(&%N=N1N9&%R92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5S:65N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*
M;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I;VXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("));F9O<FUA
M=&EO;B#D<B!I;G1E('1I;&QGY&YG;&EG(&SD;F=R92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G
M:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN9F]G82!K7V]L
M=6UN(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS
M9W-T<B`B26YF;V=A(&)I;&0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T
M<B`B26YF;V=A('1A8F5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G
M<W1R("));F9O9V$@=V5B8FSD;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?
M0V]L=6UN($)E9F]R92(*;7-G<W1R("));F9O9V$@7VMO;'5M;B!F]G)E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("));F9O9V$@;GD@:V]L=6UN(&5F=&5R(&%K
M='5E;&P@:V]L=6UN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YF;V=A(&YY
M(&MO;'5M;B!F]G)E(&%K='5E;&P@:V]L=6UN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("));F9O9V$@<F%D(&5F=&5R(&%K='5E;&P@<F%D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YF;V=A(&YY(')A9"!F]G)E(&5K='5E;&P@<F%D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D92(*;7-G<W1R("));F9O9V$@<&%R86=R868@969T97(@86MT=65L;"!N
M;V0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));F9O9V$@<&%R86=R868@9O9R
M92!A:W1U96QL(&YO9"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS
M9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DEN9F]G
M82!A;'1E<FYA=&EV(&UA;&PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y
M;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B26YF;V=A
M(&-E;&P@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B
M"FUS9W-T<B`B26YF;V=A(&-E;&P@9O9R92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R
M="!C;VQU;6X@869T97(B"FUS9W-T<B`B26YF;V=A(&MO;'5M;B!E9G1E<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN
M9F]G82!K;VQU;6X@9O9R92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDP(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU,`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G
M:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("));F9O9V$@;65D9&5L86YD
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS
M9W-T<B`B26YF;V=A('!A<F%G<F%F(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("));F9O9V$@<&%R86=R
M868@9O9R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`B26YF;V=A(')A9"!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@
M8F5F;W)E(@IM<V=S='(@(DEN9F]G82!R860@9O9R92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B06YG
M92!E<F9O<F1R870@<W9A<B!T:6QL('/D:V5R:&5T<V9RY6=A;CHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED
M("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN9F]G82_$;F1R82!B
M:6QD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DEN9F]G
M82_$;F1R82!LY&YK(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD
M('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3W1I;&QRY&-K
M;&EG(&MR961I="!F]G(@871T('-K:6-K82!T:6QL(&1I<W1R:6)U=&EO;G-L
M:7-T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")/=&EL
M;'+D8VML:6<@:W)E9&ET+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B
M"FUS9W-T<B`B2&5L=&%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$S,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L
M:7-T(@IM<V=S='(@(DAE;'1A;'-L:7-T82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C@S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S4R"FUS9VED("));G9A
M;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S
M='(@(D]G:6QT:6<@Y71GY')D(&;V<B!D96X@:.1R(&MO;7!O;F5N=&5N+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM
M<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T
M<B`B3V=I;'1I9R!51$@@*"=U<V5R(&1A=&$@:&5A9&5R)RDN(@H*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#;VUP<F5S
M<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR
M,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B3V=I;'1I9W0@
M6DE0+6%R:VEV9&%T82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*
M;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(D9E;&%K=&EG
M(&%P<&QI:V%T:6]N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T
M<B`B1F5L86MT:6=T(&)A=&-H+4E$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C,W(&QI8B](;W)D92]&;W)M+G!H<#HR,#DQ"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,38R(&QI8B](;W)D92]&;W)M+G!H<#HR,C,V(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S`S"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R(")&96QA:W1I9R!D871A('-K:6-K860N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(D9E;&%K=&EG(&1E<W1I
M;F%T:6]N<V%D<F5S<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,C(P(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD@;&EB+TAO<F1E+T-O;7!R
M97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM
M<V=S='(@(D9E;&%K=&EG="!F:6QF;W)M870B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y
M+B(*;7-G<W1R(")/9VEL=&EG(&QI8V5N<VYY8VME;"XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")&96QA:W1I9R!O<G0@<W!E8VEF:6-E
M<F%D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B1F5L86MT
M:6<@;65D9&5L86YD95]T>7`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+B(*;7-G<W1R(")&96QA:W1I9R!E;&QE<B!S86MN860@87!I7VED
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S
M='(@(D9E;&%K=&EG="!E;&QE<B!S86MN860@<&%R86UE=&5R+B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1F5L86MT:6<@]G9E<FQI9V=A;F1E
M(&)E:/9R:6=H970N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(")&96QA
M:W1I9W0@<&%R=&YE<BUI9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B1F5L86MT:6<@<')O9'5K=&MO9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C
M;VPN(@IM<V=S='(@(D9E;&%K=&EG="!P<F]T;VMO;&PN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW
M,0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")&
M96QA:W1I9R!M;W1T86=A<F4Z("<E<R<B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`X,"!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@
M(D9E;&%K=&EG="!U=&1E;&YI;F=S;V)J96MT(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O
M=7)C92!A9&1R97-S+B(*;7-G<W1R(")&96QA:W1I9R!A=G/D;F1A<F%D<F5S
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3$*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")&96QA
M:W1I9W0@=6YI8V]D92UD871A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%R:65R
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U
M-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS
M9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DEN=F5R=&5R82!U<G9A
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B27)A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS
M9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T
M<B`B27)L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB
M"FUS9W-T<B`B27-L92!O9B!-86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B
M"FUS9W-T<B`B16YS=&%K82#E<VMS:W5R87(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("))<W)A96PB"FUS9W-T<B`B27-R865L(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,C4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R(")5=&;D<F1A="!A=B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I
M9"`B271A;&EC(@IM<V=S='(@(DMU<G-I=B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DET86QY(@IM<V=S='(@(DET86QI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*
M86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B:F%N=6%R:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&%N(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M
M,C`R,BU*4"DB"FUS9W-T<B`B2F%P86YS:R`H25-/+3(P,C(M2E`I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86YI96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C`*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS
M9W-T<B`B:G5L:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`W(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM
M<V=I9"`B2G5N92(*;7-G<W1R(")J=6YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF
M>2(*;7-G<W1R(")*=7-T97)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N
M=&5R(@IM<V=S='(@(D-E;G1E<FIU<W1E<F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S
M=&EF>2!&=6QL(@IM<V=S='(@(DIU<W1E<F$@:N1M="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED
M(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B5N1N<W1E<FIU<W1E<F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")(]F=E<FIU<W1E<F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#8*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B
M2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2V5N>6$B"FUS9W-T<B`B2V5N>6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@U(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED
M(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DME<F)E<F]S<V5R=F5R;B!A=G9I<V%D92!A=71E;G1I<V5R:6YG
M96XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N
M96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,#`@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B3GEC:V5L('-K87!A9"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,R!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G
M<W1R(")&:6YG97)P<FEN="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0P,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(DME>2!,96YG=&@B"FUS9W-T<B`B3GEC:V5L;.1N9V0B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#`@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(").>6-K96QT>7`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y."!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM
M<V=S='(@(DYY8VME;&%N=N1N9&%N9&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P
M"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(DYY8VME;"!F:6YN<R!R961A;B!PY2!D96X@<'5B
M;&EK82!N>6-K96QS97)V97)N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")"87)N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM
M<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!C;VYF:6<O
M=&AE;65S+VMO;&%B+G!H<#HY"FUS9VED(")+;VQA8B(*;7-G<W1R(")+;VQA
M8B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(DYO<F1K;W)E82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")3>61K;W)E
M82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@
M*$550RU+4BDB"FUS9W-T<B`B2V]R96%N<VL@*$550RU+4BDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5W86ET(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7-T86XB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS
M9W-T<B`B3&%?>6]U="(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<N5K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS
M9W-T<B`B3&%O<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@
M(DQA<W0@2&%L9B(*;7-G<W1R(")3:7-T82!H86QV86XB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E
M(@IM<V=S='(@(DSV<V5N;W)D(.1N9')A9&5S(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1
M=6%R=&5R(@IM<V=S='(@(E-I<W1A(&MV87)T86QE="(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@
M(E-E;F%S="!U<'!D871E<F%D.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q.2!L:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E-E;F%S=&4@:6YL;V=G
M;FEN9SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$@;&EB
M+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E-E;F%S=&4@:6YL;V=G;FEN
M9SH@)7,@9G+E;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q
M-B!L:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.
M979E<B(*;7-G<W1R(")396YA<W1E(&EN;&]G9VYI;F<Z($%L9')I9R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),971T;&%N9"(*"B,Z
M(&-O;F9I9R]T:&5M97,O;&%V96YD97(N<&AP.C8*;7-G:60@(DQA=F5N9&5R
M(@IM<V=S='(@(DQA=F5N9&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0T"FUS9VED("),87<B"FUS9W-T<B`B3&%G(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO
M=70B"FUS9W-T<B`B3&%Y;W5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<B(*;7-G<W1R("),Y&UN82!T;VT@9O9R(&%T="!S=.1N9V$@878@
M:V%N=&QI;FIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R."!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R
M("),:6)A;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(E;D;G-T97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3`U"FUS9VED("),969T(&AE861E<B(*;7-G<W1R(")6Y&YS
M=&5R<G5B<FEK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,0IM<V=I9"`B3&5F="!V86QU97,B"FUS
M9W-T<B`B5N1N<W1E<G;D<F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,CD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B3FEVY2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B
M3&EB>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G
M<W1R("),:65C:'1E;G-T96EN(@H*(SH@8V]N9FEG+W1H96UE<R]L:6=H=&)L
M=64N<&AP.C8*;7-G:60@(DQI9VAT($)L=64B"FUS9W-T<B`B3&IU<V)LY2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS
M9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(D1U9V=R96=N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI
M9VAT(%)A:6XB"FUS9W-T<B`B3.1T="!R96=N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@
M16%R;'DB"FUS9W-T<B`B3.1T="!F]G)M:61D86=S<F5G;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H
M="!286EN($QA=&4B"FUS9W-T<B`B3.1T="!E9G1E<FUI9&1A9W-R96=N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G
M:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DSD='0@<F5G;G-K=7(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM
M<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B3.1T="!R
M96=N(&UE9"#E<VMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B3.1T="!S
M;O8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3.1T="!S;O9S
M:W5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE
M<FEC:R(*;7-G<W1R("),:6UE<FEC:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X,30@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI
M;FLB"FUS9W-T<B`B3.1N:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@
M=&\Z(@IM<V=S='(@(DSD;FME;B!P96MA<B!PY3HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<U(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<Y"FUS
M9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A
M9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(DSD;FMA(&4M<&]S=&%D<F5S
M<V5N('1I;&P@9G5N:W1I;VYE;B!F]G(@871T('-K87!A(&YY='0@;65D9&5L
M86YD92(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T
M97AT+G!H<#HQ.#,*(SH@9G)A;65W;W)K+U1E>'0O5&5X="]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR
M=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("),Y&YK87(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI
M92(*;7-G<W1R(")+86MA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#8@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP
M.C0V"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I
M9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI
M<W1A("T@86YVY&YD87)E(&MA;B!S92!M87!P96XB"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")6
M:7-A(&1A=&%B87-E<B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q
M"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(E9I<V$@:&KD;'#D
M;6YE;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@
M5&%B;&5S(@IM<V=S='(@(DQI<W1A('1A8F5L;&5R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.30@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES
M="U!<F-H:79E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.#D@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),
M:7-T+4AE;'`B"FUS9W-T<B`B3&ES="U(96QP(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.38@;&EB+TAO<F1E+TU)344O2&5A9&5R
M<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI<W0M260B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,B!L:6(O2&]R
M9&4O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS
M9W-T<B`B3&ES="U/=VYE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DS(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,PIM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W0M4&]S="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T
M<B`B3&ES="U3=6)S8W)I8F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,"!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3`*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U5;G-U8G-C
M<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M1&5T(&=I8VL@:6YT92!A='0@;&ES=&$@<V5S<VEO;F5R.B`E<R(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B1&5T(&=I8VL@:6YT92!A
M='0@;&ES=&$@86YVY&YD87)E.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B3&ES=&YI;F<@878@86YVY&YD87)E(&%V86MT:79E
M<F%D+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET
M97)A='5R92(*;7-G<W1R("),:71T97)A='5R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI=&%U96XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM
M<V=S='(@(DQA9&1A<BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("),;VMA;"!T
M:60Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C
M86QE(&%N9"!4:6UE(@IM<V=S='(@(E)E9VEO;F%L="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<P(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<R"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU-R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B4&QA=',B"@HC
M.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]M96YU+G!H<#HQ-C,@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,`HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`@=&5M<&QA=&5S
M+V=U97-T+V=U97-T+FEN8SHS,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(DQO
M9V=A(&EN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS
M9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M96YU+G!H<#HQ-3<@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("),
M;V=G82!U="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B
M3&]G:6XB"FUS9W-T<B`B3&]G:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("),;V=I;F%K=&EV
M:71E=&5R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV(&QI8B](
M;W)D92]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(B(*(DEN;&]G9VYI;F<@;6ES<VQY8VMA9&5S+B!4
M<F]L:6=T=FES('9A<B!A;G;D;F1A<FYA;6X@96QL97(@;/9S96YO<F0@(@HB
M9F5L86MT:6=T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,B!L
M:6(O2&]R9&4O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM
M<V=S='(@(DEN;&]G9VYI;F<@;6ES<VQY8VMA9&5S+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD*
M;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),Y6YG('1E>'0B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B2^1R
M;&5K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C@*;7-G:60@(DQO=R(*;7-G<W1R("),Y6<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),
M;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(D=R96MI<VMA(&=E;65N97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(DQA=&EN<VMA(&=E;65N97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA
M;B!N=6UB97)S(@IM<V=S='(@(E-MY2!R;VUE<G-K82!S:69F<F]R(@H*(SH@
M8V]N9FEG+W1H96UE<R]L=6,N<&AP.C8*;7-G:60@(DQO>6]L82(*;7-G<W1R
M("),;WEO;&$B"@HC.B!C;VYF:6<O=&AE;65S+VQU8V)L=64N<&AP.C8*;7-G
M:60@(DQO>6]L82!";'5E(@IM<V=S='(@(DQO>6]L82!";.4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R9R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S8*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3
M+51.148@8FEL86=A(&EN;F5H]FQL(&EN9V5N(&1A=&$N(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-PHC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-PHC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9B(*;7-G<W1R(")-86-E9&]N:65N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36%D86=A<V-A<B(*;7-G<W1R(")-86=A9V%S:V%R(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I<VLB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB
M"FUS9W-T<B`B12UP;W-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")%+7!O<W1A9&UI;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")3:V%P82!L
MY&YK+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA
M;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA
M;&%Y<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B
M36%L9&EV97)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#$@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B
M36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)5;F1E<FCE;&P@;&ES=&%N(&UE
M9"!K871E9V]R:65R(&1U(&%N=N1N9&5R(&;V<B!A='0@:V%T96=O<FES97)A
M('!O<W1E<B!M960@(@HB;V-H(&;D<F=E<FYA('-O;2!T:6QL:/9R(&1E<W-A
M(&MA=&5G;W)I97(N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q,C4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R-"UK
M87)T82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#4V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,30P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#@W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3<Q
M"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W0M:V%R=&$B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA
M<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`BUG9E<G/D='1N:6YG87(@<W!A<F%D
M92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,38*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(FUA<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T
M<B`B36%R9VEN86PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B1FQA9V=A('-O
M;2!LY'-T+V]LY'-T(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB"FUS9W-T<B`B1FQA9V=A(&UE9"!A;FYA;B!S=&%T=7,@*'0@97@@=FEK
M=&EG="]B97-V87)A="DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL]F%R;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE
M;&1S(@IM<V=S='(@(DUA=&-H86YD92!FY&QT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A;FEE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:71I=7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X('1I;&SE=&5N(&MR
M961I="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G
M<W1R(")'<N1N<R!F]G(@;6%X(&%N=&%L(&1E;&%R(&D@;65D9&5L86YD92#V
M=F5R<VMR:61E;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DCV9W-T82!T
M96UP97)A='5R92!S96YA<W1E(#(T('1I;6UA<FYA.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@-B!T:6UM
M87)N83H@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B36%X:6UA;'0@86YT86P@
M<&]R=&%L8FQO8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,Y(&QI8B](;W)D92]&;W)M+G!H<#HY,#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#,*
M;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DUA>&EM86P@;.1N9V0B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3@*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*
M;7-G<W1R(")M86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-3,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS
M9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM
M<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:6-I;B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,Q"FUS9VED(")-
M965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R(")!=F)O:V$@;?9T92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`S
M"FUS9VED(")-965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(DWV=&5S:6YF
M;W)M871I;VXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4P.0IM<V=I9"`B365E=&EN9R!0<F]P;W-A;"(*;7-G<W1R
M(")-]G1E<V;V<F9RY6=A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-3(U"FUS9VED(")-965T:6YG(%)E<&QY(@IM
M<V=S='(@(DWV=&5S<W9A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-3$T"FUS9VED(")-965T:6YG(%5P9&%T92(*
M;7-G<W1R(")-]G1E<W5P<&1A=&5R:6YG(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3D*;7-G:60@(DUE971I;F<@
M57!D871E(%)E<75E<W0B"FUS9W-T<B`B57!P9&%T97)I;F=S8F5GY')A;B!O
M;2!M]G1E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-961L96UM87(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S
M='(@(DUE;GELY&=E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S
M='(@(E-LY2!I:&]P(&-E;&QE<B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G
M92(*;7-G<W1R(")-961D96QA;F1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR,38@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"B)-961D96QA;F1E="!V97)I9FEE<F%D97,@
M;65N(&1E;B!S:6=N97)A9&5S(&-E<G1I9FEK870@:W5N9&4@:6YT92!V97)I
M9FEE<F%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")-961D
M96QA;F1E(&?D;&QE<B!I;G1E(&SD;F=R92XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(DUE9&1E
M;&%N9&5T>7`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE
M=&%R(%=E871H97(B"FUS9W-T<B`B365T87)VY&1E<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DUE=&%R8FQO8VME="#D<B!I;G1E('1I;&QGY&YG;&ET
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-971A<BUB
M;&]C:R!E:B!T:6QL9^1N9VQI9W0N($1E=&%L:F5R(&AA<B!L;V=G871S(&;V
M<B!S>7-T96UA9&UI;FES=')A=/9R96XN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C
M=&5D+B(*;7-G<W1R(")-971A<D1"(.1R(&EN=&4@86YS;'5T96XN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B365T;V0B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O
M4E!#+W-O87`N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z
M.#$@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-
M971O9&5N("<E<R<@Y'(@:6YT92!D969I;FEE<F%D(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O<F5S="YP:'`Z-C$@;&EB+TAO<F1E+U)00R]R97-T+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A
M;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DUE=&]D96X@:&%R(&EN=&4@9&5F
M:6YE<F%T<RX@06YR;W!A9"!M971O9#H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I
M9"`B365T<FEC(@IM<V=S='(@(DUE=')I<VLB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-97AI8V\B"FUS9W-T<B`B365X:6MO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]N
M97-I96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")-:71T96XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS."!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP
M92(*;7-G<W1R(")-:6UE='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("),
MY&=S=&$@=&5M<&5R871U<B!S96YA<W1E(#(T('1I;6UA<FYA.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B3.1G<W1A('1E;7!E<F%T=7(@<V5N87-T92`V
M('1I;6UA<FYA.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0S.2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM
M=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B
M36EN<W1A(&SV<V5N;W)D<^5L9&5R(&AA<B!I;G1E('5P<&[E='1S(.1N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-PHC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED
M(")-:7)R;W(B"FUS9W-T<B`B4W!E9VQA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(D1I=F5R
M<V4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,"!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C
M:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(D]B;&EG871O<FES:W0@<&%K
M970@<V%K;F%S("A014%2($A45%!?4F5Q=65S="DN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(DMO;F9I
M9W5R871I;VX@<V%K;F%S+B!$=2!MY7-T92!S:V%P82!D96X@;G4@;VT@9'4@
M=FEL;"!A;G;D;F1A(&1E;B!HY'(@(@HB87!P;&EK871I;VYE;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@
M(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B4V%K;F%R(&UE9&1E;&%N
M9&4M240N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3@*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B3V)L:6=A=&]R:7-K="!P86ME="!S86MN87,@
M*%!%05(@36%I;"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDT"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S
M='(@(E-A:VYA<B!S97-S:6]N<RU)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")-
MY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B
M:6QE($UA:6PB"FUS9W-T<B`B36]B:6P@92UP;W-T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DUO9&5R871E
M(@IM<V=S='(@(DUO9&5R97)A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S,@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T
M<B`BQ&YD<F%D(&1A='5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM
M<V=S='(@(L1N9')A(&SD;FLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-`IM
M<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&%V:65N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&EE
M="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U.#@*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@
M(DWE;F%D(&]C:"#E<B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3<@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-Y6YA=&QI9R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]T<V5R<F%T(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R(")-Y6YF87-E<B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR-3,*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O0U-6
M+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M1FQE<B!FY&QT(&AI='1A9&5S('#E(')A9"`E9"#D;B!D970@9O9R=N1N=&%D
M92`E9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA
M<F]C:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(DUE<W1A9&5L<R!K
M;&%R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(DUE<W1A9&5L<R!M
M;VQN:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")-97-T861E;',@
M<V]L:6=T(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P.0HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$
M;W=N(@IM<V=S='(@(D9L>71T82!N960B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HU,3,@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-3$S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B1FQY='1A(';D;G-T97(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$W"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM
M<V=S='(@(D9L>71T82!H]F=E<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4P-2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU
M,#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*
M;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B1FQY='1A('5P<"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.3D*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D
M;W=N(@IM<V=S='(@(D9L>71T82!N960B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DX"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4R-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S='(@(D9L>71T82!U
M<'`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO
MYV%M8FEQ=64B"@HC.B!C;VYF:6<O=&AE;65S+VUO>FEL;&$N<&AP.C8*;7-G
M:60@(DUO>FEL;&$B"FUS9W-T<B`B36]Z:6QL82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#@*;7-G
M:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R(")&;&5R
M;FEVY7-L:7-T82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#(W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#4X"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L
M=&EM87`@4W1O<F)R:71A;FYI96YK87)T82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8*;7-G:60@
M(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")&;&5R=F%L(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*
M;7-G<W1R(")-:71T(&MO;G1O(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DUI
M;B!K;VYT;VEN9F]R;6%T:6]N(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HT-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUI;B!P;W)T86PB
M"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#,*;7-G:60@(DUY(%!O
M<G1A;"!,87EO=70B"FUS9W-T<B`B36EN('!O<G1A;&QA>6]U="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHW"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS
M9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D5*+"!*86<@86-C
M97!T97)A<B!I;G1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#`P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M.#,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").86UN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FEA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U."!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!C;VYF
M:6<O=&AE;65S+TYE6%1G<F5Y+G!H<#HV"FUS9VED(").95A4(@IM<V=S='(@
M(DYE6%0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C<P-@IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S='(@(D)E:/9V
M97(@Y71GY')D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B
M3F5P86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R
M(").961E<FSD;F1E<FYA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S
M($%N=&EL;&5S(@IM<V=S='(@(DYE9&5R;.1N9'-K82!!;G1I;&QE<FYA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@
M55),(@IM<V=S='(@(DYE<V-A<&4@8F%S+5523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-"!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B3F5T<V-A<&4@9O9R;GEE;'-E+5523"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@R(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R
M(").971S8V%P92#E=&5R:V%L;&5L<V4M55),(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G
M<W1R(").971S8V%P92!34TPM<V5R=F5R;F%M;B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M(@IM<V=S='(@(DYE='-A<&4@8V5R=&EF:6MA='-K;VUM96YT87(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,"!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@='EP92(*;7-G<W1R(").971S87!E(&-E<G1I9FEK871S='EP(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*
M;7-G<W1R(").Y'1V97)K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(D%L9')I9R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3GEA($MA;&5D;VYI96XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HU,`HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR
M-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYY(&MA=&5G;W)I(@H*
M(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#$@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S
M86=E('1O("5S(@IM<V=S='(@(DYY='0@;65D9&5L86YD92!T:6QL("5S(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV
M."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G
M<W1R(").>6WE;F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M(").>71T(&%N=N1N9&%R;F%M;B`H=F%L9G)I='0I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3GEA(%IE96QA;F0B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S
M=V]R9"(*;7-G<W1R(").>71T(&SV<V5N;W)D(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C(R-R!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N(@IM<V=S='(@(DYY='0@;/9S96YO<F0@:V]M;65R(&%T="!G
MY2!U="`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*
M;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DSV
M<V5N;W)D(&WE<W1E('9A<F$@<V%M;6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H
M7V)L86YK*2(*;7-G<W1R(").>71T(&;V;G-T97(@*%]B;&%N:RDB"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W
M<R(*;7-G<W1R(").>6AE=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(").>6AE='-G<G5P
M<&5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B3N1S=&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B2V]M;6%N9&4@
M-"!F87-E<B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<T"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,S8V(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<P
M"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B3N1S=&$@:6YS=.1L;&YI
M;F=A<B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S(&QI8B](
M;W)D92]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(").
MY'-T83XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B
M3FEC87)A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B
M3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI
M9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS
M9VED(").:6=H="(*;7-G<W1R(").871T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDS-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").96HB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N(@IM<V=S='(@(D1E="!F:6YN<R!I;F=E="!K;VYF:6=U<F%T:6]N
M<V1A=&$@871T('9I<V$@<VMI;&QN861E<B!F]G(N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*(SH@9G)A;65W;W)K
M+U9&4U])4T\O25-/5W)I=&5R+G!H<#HQ,3$@;&EB+U9&4R])4T]7<FET97(N
M<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B26YG96X@=&EL;&?D;F=L:6<@<W1R
M871E9VD@9O9R(&%T="!S:V%P82!)4T\M:6UA9V4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C
M:"!T96UP;&%T92XB"FUS9W-T<B`B26YT92!E;B!B871C:&UA;&PN(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C(V-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HW.0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-#4@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C8W"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@
M=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")$970@9FEN;G,@:6YG
M970@8FQO8VL@<.4@9&5N(&)E9^1R9&$@<&]S:71I;VYE;B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`@;&EB+TAO<F1E+T%U=&@O;6-A
M;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5T(&MA;&5N9&5R
M;F%M;B!F]G(@34-!3"!A=71E;G1I<V5R:6YG(&%N9VEV970N(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T
M<B`B26YG96X@Y&YD<FEN9RXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$U-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B26YG82!U;F1E<F)E:/9R:6=H971E<B!K86X@;.1G9V%S('1I
M;&P@9&5N(&CD<B!B96CV<FEG:&5T96XN(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT.#(*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S(&QI8B](;W)D92YP:'`Z
M,38Y(&QI8B](;W)D92YP:'`Z-3`X"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("));F=E;B!K;VYF
M:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T(&QI8B]61E,O9G1P+G!H<#HX
M-34*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F5R:6YG
M<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R($944"!61E,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD@;&EB+U9&4R]S<6PN<&AP.C8W,@IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R97)I;F=S:6YF
M;W)M871I;VX@86YG:79E;B!F]G(@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG
M=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B!344PM9FEL(%9&4RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,30*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*
M;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("));F=E;B!K<F5D:70@
M:W9A<BXB"@HC.B!F<F%M97=O<FLO3&EN:W,O3&EN:W,N<&AP.C(U-@HC.B!F
M<F%M97=O<FLO4F5L871I;VYS:&EP+U)E;&%T:6]N<VAI<$UA;F%G97(N<&AP
M.C(U,0IM<V=I9"`B3F\@9&5S8W)I<'1I;VX@9F]U;F0B"FUS9W-T<B`B0F5S
M:W)I=FYI;F<@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+B(*;7-G<W1R("));F=E;B!M;W1T86=A<F4@86YG:79E;BXB"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S(@;&EB+TAO<F1E+T)R;W=S
M97(N<&AP.CDR,`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("))
M;F=E;B!F:6P@=7!P;&%D9&%D(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B26YG82!I:V]N
M97(@:&ET=&%D97,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T
M<B`B26YG96X@;W)T(&%N9VEV96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(DEN9V5N(&]R="!A;F=I=F5N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P
M<&QI960N(@IM<V=S='(@(DEN9V5T(&UE9&1E;&%N9&4@8FEF;V=A9&5S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G
M:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("));F=E="!N86UN(&%N
M9VEV970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S<*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B26YG
M96X@;G5M;65R(&%N9VEV970N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B26YG
M82!O9O9R<VOD;61A('9I<VAE='-O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.CDQ(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B26YG970@;/9S96YO<F0@9O9R($A45%`M875T96YT
M:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z,3`X(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DEN9V5T(&SV<V5N;W)D(&;V<B!)34%0+6%U=&5N=&ES97)I
M;F<@86YG:79E="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C<R(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DEN9V5T(&SV<V5N;W)D(&;V<B!+97)B97)O<RUA=71E;G1I<V5R
M:6YG(&%N9VEV970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O<V%S
M;"YP:'`Z-S<*(SH@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T(&QI8B](
M;W)D92]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@
M;/9S96YO<F0@9O9R($QO9VEN+6%U=&5N=&ES97)I;F<@86YG:79E="XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U(&QI8B](;W)D
M92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E
M="!L]G-E;F]R9"!F]G(@4$%34U=$+6%U=&5N=&ES97)I;F<@86YG:79E="XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0@;&EB+TAO<F1E
M+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@;/9S96YO
M<F0@9O9R(%--0BUA=71E;G1I<V5R:6YG(&%N9VEV970N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM
M<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("));F=A(';D;G1A
M;F1E(')E9VES=')E<FEN9V%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HW-#@*;7-G:60@(DYO('%U;W1A('-E="(*;7-G<W1R("));F=E;B!K=F]T
M82!A;F=I=F5N(@H*(SH@;&EB+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T
M82!S970N(@IM<V=S='(@(DEN9V5N(&MV;W1A(&%N9VEV96XN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM
M<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B26YG82!R96=L97(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D@;&EB+T9I;&4O0U-6+G!H<#HT
M.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DEN
M9V5N(&%V9W+D;G-A<F4@86YG:79E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E
M<R(*;7-G<W1R("));F=A('-I9&]R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU.#,@;&EB+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C
M:"!F:6QE(@IM<V=S='(@(DEN9V5N('/E9&%N(&9I;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B26YG96X@
M=&5M<&]RY')K871A;&]G('1I;&QGY&YG;&EG(&;V<B!C86-H92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,2!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+B(*;7-G<W1R("));F=E="!A;G;D;F1A<FYA;6X@;V-H
M+V5L;&5R(&SV<V5N;W)D('-K:6-K870N(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ-#`@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T
M,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B
M26YG970@9VEL=&EG(%A-3"UD871A(')E='5R;F5R861E<R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-#,*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDU,PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-"!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.34*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("));F=A
M(';D<F1E;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B));F=E;B!V
M97)S:6]N(&AI='1A9&5S(&D@9&5N('5R<W!R=6YG;&EG82!K;VYF:6=U<F%T
M:6]N96XN(,5T97)S:V%P82`B"B)K;VYF:6=U<F%T:6]N96XN(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B26YG96X@=F5R<VEO;B!H:71T861E<R!I(&1I;B!K
M;VYF:6=U<F%T:6]N+B#%=&5R<VMA<&$@:V]N9FEG=7)A=&EO;F5N+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`T
M"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B26-K92UD96QT86=A
M<F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,38*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-C`@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G
M<W1R("));F=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T
M<B`B26YG96X@*&%N=N1N9"!U;F1E<F;V<G-TY61D*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*
M;7-G<W1R(").;W)F;VQK]F%R;F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(DYO<G)A(&AE;6ES9N1R96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B3F]R
M<F$@36%R:6%N8?9A<FYA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM
M<V=S='(@(DYO<F=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@
M(DYO="!!9G1E<B(*;7-G<W1R("));G1E(&5F=&5R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B26YT92!F
M]G)E(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X(&QI8B]6
M1E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B26YT92!E;B!K871A;&]G(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*
M(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+G!H<#HV-PHC.B!F<F%M
M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX-`HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0Y"B,Z(&9R86UE=V]R:R]61E-?
M25-/+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-C`*(SH@;&EB
M+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT
M960N(@IM<V=S='(@(D5J(&EM<&QE;65N=&5R860N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E
M="(*;7-G<W1R(")%:B!A;F=I=F5N(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HV-C4@;&EB+U9&4RYP:'`Z,3DS"B,Z(&QI8B]61E,N<&AP
M.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z,C4R(&QI8B]61E,N
M<&AP.C(V.0HC.B!L:6(O5D93+G!H<#HR.#4@;&EB+U9&4RYP:'`Z,S`Q(&QI
M8B]61E,N<&AP.C,Q-B!L:6(O5D93+G!H<#HS,S,*(SH@;&EB+U9&4RYP:'`Z
M,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU,#4@;&EB+U9&4RYP
M:'`Z-3<T"B,Z(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93+G!H<#HV-CD@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-C`@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G:60@(DYO="!S
M=7!P;W)T960N(@IM<V=S='(@(E-T]F1S(&EN=&4N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-`HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`U.`HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED
M(").;W1E<R(*;7-G<W1R(")!;G1E8VMN:6YG87(B"@HC.B!S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+B(*;7-G<W1R("));F=E;G1I;F<@871T('9I<V$L(&?E('1I
M;&QB86MA+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O
M<"YI;F,Z,3`*;7-G:60@(DYO=&EC92(*;7-G<W1R(")/0E,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C0*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S
M='(@(FYO=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T
M-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(DYU;6UE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R
M86-T97)S(@IM<V=S='(@(D%N=&%L('1E8VME;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S<S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(W(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*
M;7-G<W1R(")!;G1A;"!K;VQU;6YE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,S<Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(")!
M;G1A;"!R861E<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYU;6UE<B!I
M;G1E('-P96-I9FEC97)A9&4@9O9R(&%T="!U<'!D871E<F$@:2!D:7-T<FEB
M=71I;VYS;&ES=&%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#@S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C8S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#0V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@
M(D]B:F5C="(*;7-G<W1R(")/8FIE:W0B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B
M3V)J96MT<VMA<&%R92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,#0@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S
M='(@(D]K=&%L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#(S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS
M9VED(")/8W1O8F5R(@IM<V=S='(@(F]K=&]B97(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(D9I;'1E<B!F]G(@;V;V<G-KY&UD:&5T97(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2V]N=&]R
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S
M='(@(D=A;6UA;'0@;V-H(&YY='0@;/9S96YO<F0@9N5R(&EN=&4@=F%R82!S
M86UM82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G
M:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")'86UM86QT(&SV<V5N;W)D(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@
M<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(D=A;6UA;'0@;/9S
M96YO<F0@Y'(@9F5L86MT:6=T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R(")/;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z-S,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R(")$96QA9&4@;6%P<&%R('-T]F1S(&5N8F%R="!A=B!)
M34%0+7-E<G9R87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(D5N8F%R="!O
M9O9R<VOD;61A('9I<VAE='-O<F0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S4*
M;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T
M<B`B16YD87-T(&5N(&4M<&]S=&%D<F5S<R!T:6QLY71E;BXB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W
M;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S
M:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S
M='(@(B(*(D5N9&%S="#D9V%R92!E;&QE<B!S>7-T96UA9&UI;FES=')A=/9R
M(&MA;B#D;F1R82#D9V%R92!E;&QE<B!B96CV<FEG:&5T97(@<.4@(@HB96X@
M=71D96QN:6YG(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(M9P<&YA(&D@;GET="!F]FYS=&5R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@
M(B(*(D]P96Y34TPM9F5L.B!$970@9VEC:R!I;G1E(&%T="!E>'1R86AE<F$@
M9&%T82!F<N5N('-I9VYE<F%D(%,O34E-12UD96PN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED
M(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(M9P
M<&YA(&SD;FL@:2!N>71T(&;V;G-T97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E
M<F%T:79S>7-T96TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8P,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B
M"FUS9W-T<B`B26-K92!O8FQI9V%T;W)I<VMA(&1E;'1A9V%R92(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M96YU+G!H<#HQ-3`@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("));G-TY&QL
M;FEN9V%R(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@
M9F]R("5S(@IM<V=S='(@(DEN<W3D;&QN:6YG87(@9O9R("5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B
M3W)D97)E9"!,:7-T(@IM<V=S='(@(E-O<G1E<F%D(&QI<W1A(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M(")/<F=A;FES871I;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V."!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I
M9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")/<F=A;FES871I;VYS
M96YH970B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED
M(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7-E<F$B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4B"FUS9W-T<B`B57)S<')U;F=L:6<@87!P;&EK871I;VYS;6%L
M;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*
M;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B57)S
M<')U;F=L:6=A(&UA;&QA<B!I("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M06YN86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/
M=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")!;F1R82!I;G-TY&QL;FEN9V%R
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N
M97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ&=A<F)E:/9R:6=H971E<B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.2!L:6(O2&]R9&4O075T
M:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B4$%-+4%U=&5N=&ES97)I;F<@Y'(@:6YT
M92!T:6QL9^1N9VQI9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HQ,#4@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H
M<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2
M.CI-86EL+6MO<'!L:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3(U,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED
M(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0($1I9VET86P@
M4VEG;F%T=7)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3(Y.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@
M16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0($5N8W)Y<'1E9"!$871A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,2!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*
M;7-G<W1R(")0=6)L:6L@4$=0+6YY8VME;"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S,S,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R
M(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")02%`M:V]D(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS
M9W-T<B`B4$A0+7-K86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("),
MY'1T(&;V<FUI9&1A9W-R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B1O9R
M;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")%9G1E<FUI
M9&1A9W-S:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")%9G1E<FUI9&1A
M9W-S;O8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,0IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D5F=&5R;6ED
M9&%G<W-K=7)A<B!M960@<V[V(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")%9G1E
M<FUI9&1A9W-S;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`BQ7-K<VMU
M<F%R('#E(&5F=&5R;6ED9&%G96XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R(")03U-)6"UT:6QLY&=G('-A:VYA<R(*"B,Z(&QI8B]A<&DN<&AP.C$T
M.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")07TA0+7-K86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V
M"FUS9VED(")0861D:6YG(@IM<V=S='(@(E5T9GEL;&YA9#HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-PHC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-`HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M"FUS9W-T<B`B4&%L97-T:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA
M(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE
M=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$M3GEA($=U:6YE82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B
M4&%R=&QY($-L;W5D>2(*;7-G<W1R(")$96QV:7,@;6]L;FEG="(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P,C(@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.2!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT
M,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S
M=V]R9"(*;7-G<W1R("),]G-E;F]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(DSV<V5N;W)D(.1N9')A9&5S+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*
M;7-G<W1R("),]G-E;F]R9"!F96QA:W1I9W0B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W)A9&EU<RYP:'`Z,34R(&QI8B](;W)D92]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("),]G-E;F]R9"!K<N1V<R!F]G(@4D%$
M2553(&%U=&5N=&ES97)I;F<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`U,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U-PIM<V=I9"`B4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B3/9S96YO<F0@;65D(&)E
M:W+D9G1E;'-E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP
M"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B3/9S96YO<F0Z(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B
M"FUS9W-T<B`B3/9S96YO<F0Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#,X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("),]G-E;F]R
M9"!MY7-T92!V87)A(&QI:V$N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q
M.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(DML:7-T<F$@:6XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED
M(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")+;&ES=')A(&EN(&9R
MY6X@=7)K;&EP<'-H86YT97)A<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")3
M]FMVY&<B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")6Y&YT86YD92!R96=I<W1R
M97)I;F=A<CHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@
M(E!E;W!L92(*;7-G<W1R(")-Y&YN:7-K;W(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*
M;7-G<W1R(")0<F]C96YT(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?8F]T=&]M+FEN8SHV"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,B"FUS9W-T<B`B571F]G(@=6YD97)HY6QL<V9U;FMT:6]N
M97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@
M(E5T9O9R('5N9&5R:.5L;'-A:W1I=FET971E<B!V:60@:6YL;V=G;FEN9S\B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R
M(")"96CV<FEG:&5T(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L
M971E9"XB"FUS9W-T<B`B0F5H]G)I9VAE="`G)7,G(')A9&5R861E<R!I;G1E
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V(&QI8B]61E,O
M<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@
M(L5T:V]M<W0@;F5K860B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B8F5H]G)I9VAE
M=&5R(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B0F5H]G)I9VAE='-A9&UI;FES=')A
M=&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R
M<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B4&5R<V]N;&EG(&EN9F]R;6%T
M:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#,*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S
M='(@(DAU<V1J=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*
M;7-G<W1R(")&:6QI<'!I;F5R;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DV"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO
M=&]S(@IM<V=S='(@(D9O=&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C
M86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T
M<B`B4&EX;&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED
M(")0;&%T:71U9&5S(@IM<V=S='(@(DML:6-HZ65R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(E9A<B!G;V0@
M:VQI8VMA(&D@96X@8V5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R(")"96MRY&9T82!A='0@9'4@=FEL;"!R861E<F$@=F%L9"!P;W-T/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
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M:65W97(O:6-A;&5N9&%R+G!H<#HU-#`*;7-G:60@(B(*(E!L96%S92!R979I
M97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T
M(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B
M"B)+;VYT<F]L;&5R82!F]FQJ86YD92!I;F9O<FUA=&EO;B!O8V@@=N1L:B!S
M961A;B!E;B!H86YD;&EN9R!I(&UE;GEN7&XB"B)N961A;BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0S-0IM<V=I
M9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO
M=RXB"FUS9W-T<B`B5N1L:B!E;B!H86YD;&EN9R!F<N5N(&UE;GEN(&YE9&%N
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<P"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z
M(@IM<V=S='(@(D%N9V4@;GET="!K871E9V]R:6YA;6XZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&5N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI
M=&EK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B
M4&]L;',B"FUS9W-T<B`B56YD97)S]FMN:6YG87(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E!O
M<VET:6]N97)I;F<@878@8FEL9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:71I;VYE<FEN9R!A=B!T86)E;&QE
M;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")3:W)I
M=B!T:6QL(&1E;B!HY'(@;6%P<&5N("AE:B!T=FEN9V%T(&%V($E-05`I(@H*
M(SH@8V]N9FEG+W1H96UE<R]P;W-T;G5K92YP:'`Z-@IM<V=I9"`B4&]S=&YU
M:V4B"FUS9W-T<B`B4&]S=&YU:V4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W,R!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G
M<W1R(").961E<F+V<F0@9&4@<V5N87-T92`E<R!T:6UM87)N83H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP
M:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")#:&%N<R!T:6QL/&)R+SYN
M961E<F+V<F0B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z
M.3@@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?;&1A<#H@3$1!4"UT:6QLY&=G('-A:VYA<RXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,@;&EB+TAO<F1E+U!R
M969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R
M969S7W-E<W-I;VXZ($]B;&EG871O<FES:W0@<V5S<VEO;G-T:6QLY&=G(&AI
M='1A9&5S(&EN=&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(E1R>6-K(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(DQU9G1T<GEC:R!V:60@:&%V970Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T
M<B`B3'5F='1R>6-K.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3@X"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@
M(D;V<FAA;F1S=FES;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D;V<FAA;F1S9W)A
M;G-K82!B:6QD(&D@;GET="!F]FYS=&5R(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-C`@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-C0*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-38@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS
M9W-T<B`B1O9R96?E96YD92!I;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@
M9&]C=6UE;G0B"FUS9W-T<B`B4VMR:78@=70@9&]K=6UE;G0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")0<FEV
M871A(&YY8VME;"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-CD@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*
M;7-G<W1R(")0<F]B;&5M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W
M"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)L96UB
M97-K<FEV;FEN9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*
M;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:W0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$Q-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S(X,`IM<V=I9"`B4')O;7!T('1E>'0B"FUS
M9W-T<B`B5&5X="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI
M8R!+97DB"FUS9W-T<B`B4'5B;&EK(&YY8VME;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R
M(")0=6)L:6L@;GEC:V5L86QG;W)I=&TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(E!U8FQI:R!N
M>6-K96QI;F9O<FUA=&EO;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(S,"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(D9E;"!V:60@9V5N97)E<FEN9R!A=B!P=6)L:6MT
M+W!R:79A="!N>6-K96QP87(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R
M=&\@4FEC;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B
M"FUS9W-T<B`B4F5N<V$@;65D9&5L86YD96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E%A=&%R(@IM<V=S='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")&<N5G82(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B2W9O
M=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")0=6)L:6L@
M4E-!+6YY8VME;"`H)60@8FET87(I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V.`IM<V=I9"`B4F%D
M:6\@<V5L96-T:6]N(@IM<V=S='(@(D5N<VMI;'0@=F%L(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6XB
M"FUS9W-T<B`B4F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0U"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(E1I9&EG
M="!R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#8*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")396YT(')E9VXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I
M9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B4F5G;G-K=7)A<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(E)E9VX@;V-H('-N]B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN('1O
M(%-N;W<B"FUS9W-T<B`B4F5G;B!T:6QL('-N]B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")3
M;'5M<&WD<W-I9W0@=FES:&5T<V]R9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B
M4F%T:6\B"FUS9W-T<B`B1O9R:.5L;&%N9&4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),Y',B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-#<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DSD<R!M961D
M96QA;F1E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")3Y&ME<G0@
M871T(&1U('9I;&P@<F%D97)A("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N
M9W)A<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`B(@HB4^1K97)T(&%T="!D=2!V:6QL(')A9&5R82!A;G;D;F1A
M<F1A=&$@9O9R("5S/R!2861E<FEN9V5N(&MA;B!I;G1E(.5N9W)A<RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS
M9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")']G(@;VT@
M9&EN('-E;F%S=&4@:6YM871N:6YG(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E
M<V@B"FUS9W-T<B`B57!P9&%T97)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(E5P<&1A=&5R82!D>6YA;6ES:V$@;65N>65L96UE;G0Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0
M;W)T86P@5FEE=SHB"FUS9W-T<B`B57!P9&%T97)A('!O<G1A;'9Y.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q
M-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS
M9W-T<B`B4F5G97@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y
M(&QI8B](;W)D92]&;W)M+G!H<#HS,C,U"FUS9VED(")296QA=&EO;G-H:7`@
M0G)O=W-E<B(*;7-G<W1R(")6:7-A(&;V<FCE;&QA;F1E;B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("),861D82!O;2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM
M<V=S='(@(DMO;6UE;G1A<F5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-3<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S8*;7-G:60@(E)E;65M8F5R('1H
M92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(DMO;2!I:.5G(&EN
M9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@
M(D9JY')R<V5R=G)A<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@IM<V=S='(@(E523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED
M(")296UO=F4B"FUS9W-T<B`B5&$@8F]R="(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@
M(E1A(&)O<G0@8FQO8VLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3,R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B5&$@
M8F]R="!K;VQU;6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R
M(")482!B;W)T(&9O<FUA=&5R:6YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3@*;7-G:60@(E)E;6]V92!F<F]M
M(&UY(&-A;&5N9&%R(@IM<V=S='(@(E1A(&)O<G0@9G+E;B!M:6X@:V%L96YD
M97(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B
M4F5M;W9E('!A:7(B"FUS9W-T<B`B5&$@8F]R="!P87(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M4F%D97)A('-P87)A="!S:W)I<'0@9G+E;B!S97)V97)N<R!T96UP;W+D<FMA
M=&%L;V<N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E1A
M(&)O<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0B"FUS9W-T<B`B4F%D97)A(&1E;FYA(&YO9"!F<N5N(&1O
M:W5M96YT970B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")482!B;W)T(&%N=N1N
M9&%R92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B
M5&$@8F]R="!A;G;D;F1A<F4Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#`*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#D*;7-G:60@(E)E<&QY
M(%-E;G0N(@IM<V=S='(@(E-V87(@<VMI8VMA="XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U.0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V.`HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0W.`IM<V=I
M9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B
M4W9A<F$@871T(&)E9^1R86X@:6YT92!S=/9D<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8V"FUS9VED(")297!L
M>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`B
M4W9A<F$@;65D(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A9V5N(&;V<B!K
M;VUM86YD92!T=N4@;>5N861E<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-0IM<V=I9"`B4F5P;'D@=VET:"!R
M97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R(")3=F%R
M82!M960@9&5N(&)E9^1R9&$@;&5D:6<O=7!P=&%G96XM:6YF;W)M871I;VYE
M;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C$X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")297!L>3H@)7,B"FUS9W-T
M<B`B4W9A<CH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$S."!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U
M97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z
M("(*;7-G<W1R(")"96?D<F%N(&MU;F1E(&EN=&4@8F5S=F%R87,N(%)E='5R
M;F5R860@9F5L:V]D.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@
M9F]U;F0N(@IM<V=S='(@(D1E;B!E9G1E<F9RY6=A9&4@=&KD;G-T96X@:W5N
M9&4@:6YT92!H:71T87,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT.3(*(SH@;&EB+TAO
M<F1E+G!H<#HQ-S8@;&EB+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B17)F;V1R860@)R5S)R#D<B!I;G1E(&%N
M9VEV96X@:2!K;VYF:6=U<F%T:6]N96X@878@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,R!L
M:6(O5D93+W-Q;"YP:'`Z-C<X(&QI8B]61E,O9G1P+G!H<#HX-C$*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I
M(&MO;F9I9W5R97)I;F=E;B!A=B!61E,N(@H*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S@Q(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B17)F;V1R860@)R5S)R#D<B!I;G1E
M(&%N9VEV96X@:2!K;VYF:6=U<F5R:6YG96XN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U(&QI8B](;W)D92]&;W)M+U)E;F1E
M<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(D]B
M;&EG871O<FES:W1T(&;D;'0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4Y,@IM<V=I9"`B4F5Q=6ER960@4&%R=&EC
M:7!A;G0B"FUS9W-T<B`B3V)L:6=A=&]R:7-K(&1E;'1A9V%R92(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,T,PHC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP
M:'`Z,S(P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R
M("+%=&5R<W3D;&PB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BQ71E<G-TY&QL(&SV
M<V5N;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G
M:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BQ71E<G-TY&QL(&SV
M<V5N;W)D(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S
M=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(L5S=&5R=.1L;"!S96YA<W1E(&9R
MY6=A;B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S
M(@IM<V=S='(@(E)E<W5L=&%T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+%=&5R=N1N9"!T:6QL(&EN<W3D
M;&QN:6YG87(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*
M;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B06YG92!N>71T
M(&SV<V5N;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(E+I=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(L5T97)S=.1L;"!K;VYF:6=U<F%T:6]N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS(@IM<V=S='(@(DEN<W3D;&QN:6YG87(@9O9R(%)I8V@@
M5&5X="!%9&ET;W(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G
M:60@(E)I9&1L97,B"FUS9W-T<B`B1^5T;W(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT
M(@IM<V=S='(@(DCV9V5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM<V=I9"`B4FEG:'0@:&5A
M9&5R(@IM<V=S='(@(DCV9V5R<G5B<FEK(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,PIM<V=I9"`B
M4FEG:'0@=F%L=65S(@IM<V=S='(@(DCV9V5R=N1R9&5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS
M9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4F%?9&EN<W3D;&QN
M:6YG87(N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-3@S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E)O;&PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4G5MY&YI96XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`X"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C8*;7-G:60@(E)O=&%T
M92`Q.#`B"FUS9W-T<B`B4F]T97)A(#$X,"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`B4F]T97)A(';D;G-T97(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C$Q"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M(")2;W1E<F$@:/9G97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*
M;7-G<W1R(")2861I;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R
M;W!E<G1I97,B"FUS9W-T<B`B4F%D:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2
M;W=S.B(*;7-G<W1R(")2861E<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G
M<W1R("),:6YJ97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(DQI;FIE<B!V
M:7-A<R!M96QL86X@86QL82!R861E<B!O8V@@:V]L=6UN97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*
M;7-G<W1R("),:6YJ97(@=FES87,@96YB87)T(&UE;&QA;B!K;VQU;6YE<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY(@IM<V=S='(@(DQI;FIE<B!V:7-A<R!E;F)A<G0@;65L;&%N(')A9&5R
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S
M='(@(DOV<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T
M:6]N(@IM<V=S='(@(E)Y<W-L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR.#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR
M.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G
M<W1R(")3+TU)344@<VEG;F%T=7(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,R,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R
M,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E,O
M34E-12UK<GEP=&5R870@;65D9&5L86YD92(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<V%S;"YP:'`Z.#$@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*
M;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B4T%33"UA=71E;G1I<V5R:6YG(.1R(&EN=&4@=&EL;&?D;F=L
M:6<N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B
M4TU3($UE<W-A9VEN9R(*;7-G<W1R(")335,@;65D9&5L86YD96XB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R
M(")344PM<VMA;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S@*;7-G:60@(E-13"!S=&%T96UE;G0@
M9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,+7-E:W9E;G,@9O9R('5P
M<'-L86<@878@=N1R9&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S4*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(DQ90TM!5"(*"B,Z(&QI
M8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")37U%,
M+7-K86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("),]B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A:6YT($AE;&5N82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R
M(")386EN="!+:71T<R!O8V@@3F5V:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DQ(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED(")3
M86EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DR(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")3
M86EN="U0:65R<F4@;V-H($UI<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED
M(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")3
M86EN="!6:6YC96YT(&]C:"!'<F5N861I;F5R;F$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`B4V%M;6$@<F%M("A?<V5L9BDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*
M;7-G<W1R(")386\@5&]M92!O8V@@4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A='1E
M;&ET;&5V97)A;G3V<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A
M8FEA(@IM<V=S='(@(E-A=61I87)A8FEE;B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")3<&%R82(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4W!A<F$@)R5S
M)R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4W!A<F$@)7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`B4W!A<F$@:6YS=.1L;&YI;F=A<B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB4W!A<F$@9V5N97)E
M<F%D(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I<'0@=&EL;"!D:6X@<V5R
M=F5R<R`@=&5M<"UK871A;&]G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(E-P87)A9&4@:V]N9FEG=7)A=&EO;B!F]G(@)7,N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B4W!A<F%D92!U<'!G<F%D97)I;F=S<V-R:7!T('1I;&PZ
M("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4P"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B4W!R:61D
M82#E<VMS:W5R87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G
M:60@(E-C:65N8V4B"FUS9W-T<B`B5F5T96YS:V%P(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3]FLB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R(")3]FMM;W1O<F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDW,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDU.0IM<V=I9"`B
M4V5L96-T($9I;&5S(@IM<V=S='(@(E;D;&H@9FEL97(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Y"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A
M(&1A=&4B"FUS9W-T<B`B5N1L:B!E='0@9&%T=6TB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@
M861D(@IM<V=S='(@(E;D;&H@9W)U<'`@871T(&SD9V=A('1I;&PB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N
M97<@;W=N97(B"FUS9W-T<B`B5N1L:B!N>2#D9V%R92(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R
M(@IM<V=S='(@(E;D;&H@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(E;D;&H@86YVY&YD87)E(&%T="!LY&=G82!T:6QL(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(E;D;&H@86QL82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C,@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#<*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")6Y&QJ(&1A='5M
M:V]M<&]N96YT97(N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@T-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E;D
M;&H@971T(&]B:F5K="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-3,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B5N1L:B!I
M;F=E;B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(D%N9V4@9&4@=&5C:V5N
M(&1U(&)E:/9V97(@:2!R=71O<FYA(&YE9&%N+B!$=2!K86X@<V5D86X@:V]P
M:65R82!O8V@@:VQI<W1R82`B"B)I;B!D96T@:2!T97AT87)U=&%N+B(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")6Y&QJ(&%V9W+D;G-A<F4@9O9R
M(&1A='5M.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")6Y&QJ(&1A='5M
M9F]R;6%T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.B(*;7-G<W1R(")6Y&QJ(&ED96YT:71E="!D=2!V:6QL(.1N9')A
M.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")6Y&QJ(&%V9W+D;G-A
M<F4@9O9R('1I9#HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5N1L:B!T
M:61S9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*
M;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")6
MY&QJ('1VY2!M871C:&%N9&4@9N1L=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM
M<V=S='(@(E;D;&H@9&ET="!FY')G<V-H96UA+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`B06YG92!D:71T(&;V<G9A;&1A('-P<N5K.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-C4S"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")3
M:VEC:V$@<V5N87-T92!I;F9O<FUA=&EO;F5N(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O
M<G0B"FUS9W-T<B`B4VMI8VMA('!R;V)L96UR87!P;W)T(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3$*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E;F0@
M4TU3(@IM<V=S='(@(E-K:6-K82!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS;W(Z("(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M
M8F5R(@IM<V=S='(@(G-E<'1E;6)E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3
M97)B:65N(&]C:"!-;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4V5R:65N=6UM97(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")3
M97)V97)I;G-TY&QL;FEN9V%R(&9E;&%K=&EG82!E;&QE<B!I;F%K=&EV('-E
M<G9E<BXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I
M;VX@061M:6XB"FUS9W-T<B`B4V5S<VEO;G-A9&UI;FES=')A=&EO;B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I
M9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")397-S:6]N<RU)1"!H
M87(@9^5T="!U="XB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I
M;VYS(@IM<V=S='(@(E-E<W-I;VYE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S,30@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,3@*;7-G:60@(E-E
M="(*;7-G<W1R(")3Y'1T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y
M"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*
M(DMO;F9I9W5R97)A(&%L=&5R;F%T:78@<V]M(&WV:FQI9V?V<B#E=&5R<W3D
M;&QN:6YG(&%V(&)O<G1G;/9M="!L]G-E;F]R9"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@
M=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS
M9W-T<B`B2V]N9FEG=7)E<F$@9FKD<G)S97)V<F%R('-O;2!D=2!V:6QL(&MO
M;6UA(.5T(&9RY6X@9&EN('!O<G1A;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B06YG92!D:71T
M(&;V<G9A;&1A('-P<N5K+"!T:61S>F]N(&-O:"!D871U;6EN<W3D;&QN:6YG
M87(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(B(*(E/D='0@9&ET="!I;FET:6%L82!A<'!L:6MA=&EO;BP@
M9N1R9W-C:&5M82P@<VED=7!P9&%T97)I;F<@;V-H(&%N9')A("(*(G9I<VYI
M;F=S:6YS=.1L;&YI;F=A<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")3971U<"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R
M861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(DMO;F9I9W5R871I;VYS
M=7!P9W)A9&5R:6YG<W-K<FEP="!F:6YN<R!T:6QL9^1N9VQI9V$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L
M(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G
M<W1R(")$970@9FEN;G,@9FQE<F$@;W)T97(@;65D('!A<F%M971E<FXZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H
M96QL97)N82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G
M:60@(E-H;W!P:6YG(@IM<V=S='(@(DAA;F1E;"(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM
M<V=S='(@(DMO<G0@<W5M;65R:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(E-K86QL(&=E;G;D9W-T86YG96YT
M97(@9&5F:6YE<F%S(&;V<B!D92!F;&5S=&$@;.1N:V%R/R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(S(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDP('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E9I<V$B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E9I<V$@<VMI
M;&QN861E<B!M96QL86X@9&5N(&%K='5E;&QA(&]C:"!D96X@;GEL:6=E;B!S
M:V%P861E(&MO;F9I9W5R871I;VYE;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO
M9V=I;F<@:6X_(@IM<V=S='(@(E9I<V$@<V5N87-T92!I;FQO9V=N:6YG<W1I
M9"!V:60@:6YL;V=G;FEN9S\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S8U(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(E9I<V$@:6YS=.1L;&YI
M;F<@9O9R(&%T="!B96CE;&QA(&]R:6=I;F%L(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.0IM<V=I
M9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B5FES82!P86QE='0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E9I<V$@)W1A8F5L;&%K=&EV:71E
M=&5R)R!I(&UE;GEN/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\B"FUS9W-T<B`B5FES82!M96YY(&;V<B`E<R!T:6QL(';D;G-T97(_
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(E1A8F5L;&-E;&QI;G-TY&QL;FEN9V%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R(")486)E;&QI;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED
M(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B5&%B96QL:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5FES82!D:6%L
M;V=R=71A(&;V<B!B:6QD96=E;G-K87!E<B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C<*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(E9I<V$@=7!P;&%D9&YI;F<B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4VAO=V5R<R(*;7-G<W1R(")3:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!%87)L>2(*
M;7-G<W1R(")4:61I9V$@<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G
M<W1R(")396YA('-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET
M>2(*;7-G<W1R(")3:W5R87(@:2!NY')H971E;B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C0X,"!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HT.#`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")&]G)M:6YS:V$B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q
M,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW-S0@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z.#,V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.CDR,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HQ,#@W"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q
M,38@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@
M(DMR>6UP(&5L;&5R(&9L>71T82!B;W)T(&[D<FQI9V=A;F1E(&)L;V-K(&;V
M<G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T
M<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V-2!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I
M9"`B4VEG;B!U<"(*;7-G<W1R(")296=I<W1R97)A(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")3:6=N871U
M<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@
M06QG;W)I=&AM(@IM<V=S='(@(E-I9VYA='5R86QG;W)I=&TB"@HC.B!C;VYF
M:6<O=&AE;65S+W-I;7!L97@N<&AP.C8*;7-G:60@(E-I;7!L97@B"FUS9W-T
M<B`B4VEM<&QE>"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM
M<V=S='(@(E-I;F=A<&]R92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C,@;&EB+TAO<F1E+T9O<FTN<&AP.CDP,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(Q.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$P.2!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`IM<V=I9"`B4VEZ92(*
M;7-G<W1R(")3=&]R;&5K(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?8F]T=&]M+FEN8SHY"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM
M<V=S='(@(D%V8G)Y="!U;F1E<FCE;&PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9A:VEE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=F5N:65N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<B
M"FUS9W-T<B`B4V[V(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(E-N]G-K
M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PIM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N]G-K=7)A<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B5&ED:6=A('-N]G-K=7)A
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y
M"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")396YA('-N]G-K
M=7)A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED(")3;F]W
M(&1E<'1H.B`B"FUS9W-T<B`B4V[V9&IU<#H@(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#D*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M(@IM<V=S='(@(DUO='-V87)A;F1E('-N]B!I('9A='1E;CH@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B4V%L;VUO
M;O9A<FYA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@
M(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B4^5N9V5R(&]C:"!D:6MT97(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3$R"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R
M(")3;W)T97)I;F=S:6]R9&YI;F=S=F%L(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.2!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.#D@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-#<@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G
M<W1R(")KY&QL861R97-S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B4WED869R:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3]F1R82!'
M96]R9VEA(&]C:"!3>7-S86YD=VEC:/9A<FYA(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE
M<FX@2&5M:7-P:&5R92(*;7-G<W1R(")3Y&1R82!H96UI<V;D<F5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G
M:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B571R
M>6UM92!M96QL86X@:6YT:6QL:6=G86YD92!C96QL97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R
M(")5=')Y;6UE(&UE;&QA;B!I;FYE:.5L;"!O8V@@:V%N=&5N(&D@8V5L;&5N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U(&QI8B](;W)D92]&
M;W)M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R(")-96QL86YR=6TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B365L;&%N<G5M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")-96QL86YR
M=6T@;V-H('5T:N1M;FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G
M<W1R(")3<&%N:65N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P
M,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R("));FUA=&YI;F<@878@<W!E8VEE;&QA('1E8VME;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*
M;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B1&5L82!C96QL(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM
M<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(D1E;&$@:V]L=6UN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(D1E;&$@<F%D(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B
M4W!O<G1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R
M(")3<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS
M9W-T<B`B4W1A;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*
M;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0T,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T.`IM
M<V=I9"`B4W1A<G0B"FUS9W-T<B`B4W1A<G0B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(W.34*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4W1A<G3E<B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC
M92(*;7-G<W1R(")3=&%T(&5L;&5R(')E9VEO;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,0IM<V=I9"`B4W1O<F%G92!F;W)M
M870B"FUS9W-T<B`B3&%G<FEN9W-F;W)M870B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B1V%T=6%D
M<F5S<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B1V5N;VUS=')U
M:V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B
M4W1RY&YG;&ES=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")482!B;W)T(&1O;>1N(&9RY6X@
M861R97-S96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")3
M=&EL(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B4_8B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DMA;B!I;G1E(&AI
M='1A('5N9&5R:V%T86QO9R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BQ')E
M;F1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PHC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")3:VEC:V$B"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@
M=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G
M<W1R("(B"B)$:6X@8F5GY')A;B!A='0@;.1G9V$@=&EL;"!<(B5S7"(@=&EL
M;"!S>7-T96UE="!H87(@<VMI8VMA=',N($1U(&MA;B!I;G1E("(*(FQO9V=A
M(&EN(&EN;F%N(&1I;B!B96?D<F%N(&AA<B!A8V-E<'1E<F%T<RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED
M(")3=6)S8W)I<'0B"FUS9W-T<B`B3F5D<^1N:W0B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C
M97-S(@IM<V=S='(@(DQY8VMA="(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!L861E<R!T:6QL(&D@<WES
M=&5M970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4F%D97)A9&4@:6YF;W)M
M871I;VX@;VT@86YVY&YD87)E("<E<R<N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B
M)R5S)R!R861E<F%D97,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@=&]G<R!B;W)T(&9RY6X@
M<WES=&5M970N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A=&EO;F5N
M(&AA<B#E=&5R<W3D;&QT<RX@3&%D9&$@;VT@<VED86X@9O9R(&%T="!S92!F
M]G+D;F1R:6YG87(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E-P87)A9&4@
M8F%C:W5P:V]N9FEG=7)A=&EO;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B
M4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N("5S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S)R!U<'!D871E<F%D97,N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R
M;W1E("5S(@IM<V=S='(@(E-K<F5V("5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3=61A;B(*;7-G<W1R(")3=61A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34X"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U
M;6UA<GDB"FUS9W-T<B`B4V%M;6%N<W3D;&QN:6YG(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")3;VQU
M<'!GY6YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(E-O;&YE9&?E;F<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B4W5N;GDB"FUS9W-T
M<B`B4V]L:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")3;VQU<'!GY6YG(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V
M"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")3;VQU<'!GY6YG+VYE
M9&?E;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS
M9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B4V]L=7!P9^5N9SH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM
M<V=S='(@(E-O;&YE9&?E;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")3;VQN961GY6YG
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")5<'!H]FID(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*
M;7-G<W1R(")3=7!P;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M
M92(*;7-G<W1R(")3=7)I;F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")3=7)N86UE(@IM<V=S='(@(D5F=&5R;F%M;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P.0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3
M=F%L8F%R9"!O8V@@2F%N($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3
M=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")3=V5D96XB"FUS9W-T<B`B4W9E<FEG92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")3=VET>F5R;&%N9"(*;7-G<W1R(")38VAW96EZ(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B
M"FUS9W-T<B`B4WEK<F]N:7-E<FEN9W-L;V=G(')A9&5R860B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B
M4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW
M(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(E-Y;G1A>&9E;"!I('/V
M:VMR:71E<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!2
M97!U8FQI8R(*;7-G<W1R(")3>7)I96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R
M("+%<VMS:W5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(L5S
M:W-K=7)A<B!O8V@@8FSE<VEG="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("+%
M<VMS:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B5&ED:6=A
M(.5S:W-K=7)A<B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ
M-C8@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE
M(@IM<V=S='(@(E135BUF:6PB"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N
M<&AP.C$S-"!L:6(O2&]R9&4O54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B
M;&4B"FUS9W-T<B`B5&%B96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R(")486)E;&QI;G-TY&QL;FEN9V%R(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC.B!L:6(O2&]R
M9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T
M(@IM<V=S='(@(E1A8F5L;'5P<'/D='1N:6YG(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B
M;&4@<')O<&5R=&EE<R(*;7-G<W1R(")486)E;&QI;G-TY&QL;FEN9V%R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N
M(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*
M;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%I
M=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@
M(E1A:FEK:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>F%N:6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")4
M87)G970Z(@IM<V=S='(@(DWE;#HB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`T.2!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")4
M87-K<R(*;7-G<W1R(")5<'!G:69T97(B"@HC.B!C;VYF:6<O=&AE;65S+V=E
M;FYE=FEL;&EE<G,N<&AP.C$T"FUS9VED(")496%L(@IM<V=S='(@(E1E86PB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,R!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU
M;6)E<B(*;7-G<W1R(")496QE9F]N;G5M;65R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(DCV9W-T82!T96UP97)A='5R('-E;F%S=&4@=&EM;65N.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B5&5M<&5R871U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R
M871U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O
M)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E;7!E<F%T=7(\8G(@+SXH)7--
M87@E<R\E<TUI;B5S*2`F9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HV.#<@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B2V%N(&EN=&4@:&ET=&$@;6%L;"`E<RXB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B06YVY&YD87)A9&UI;FES=')A=&EO;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0Q"FUS
M9VED(")496YT871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R(")';V1K
MY&YN(&)E9^1R86X@<')E;&EM:6[D<G0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X.0IM<V=I9"`B5&5N=&%T:79E
M;'D@06-C97!T960B"FUS9W-T<B`B4')E;&EM:6[D<G0@86-C97!T97)A="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,S,0IM<V=I9"`B5&5X="(*;7-G<W1R(")4
M97AT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X
M="!/;FQY(@IM<V=S='(@(D5N8F%R="!T97AT(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X
M="!A;&EG;B(*;7-G<W1R(")497AT:G5S=&5R:6YG(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O
M<"(*;7-G<W1R(")497AT=&]P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B5&\B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R
M,"DB"FUS9W-T<B`B5&AA:2`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EL86YD(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG
M('1H92!S>7-T96TN(@IM<V=S='(@(E1A8VL@9O9R(&%T="!D=2!A;G;D;F1E
M<B!S>7-T96UE="XB"@HC.B!S97)V:6-E<R]L:6YK<R]D96QE=&4N<&AP.C,T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92`E<R!L:6YK('1O("5S(&AA<R!B
M965N(')E;6]V960N(@IM<V=S='(@(DSD;FME;B`E<R!T:6QL("5S(&AA<B!R
M861E<F%T<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,"!L
M:6(O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")&5%`M=&EL;.1G9V5T(.1R(&EN
M=&4@=&EL;&?D;F=L:6=T+B(*"B,Z(&QI8B](;W)D92](:7-T;W)Y+G!H<#HU
M-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R(")(:7-T;W)I:W-Y<W1E;65T(.1R(&%V86MT:79E<F%T+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3,X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(M:6YT96=R871I;VYS9W+D;G-S;FET=&5T('-T
M]F1E<B!I;G1E(%PB)7-<(B(*"B,Z(&QI8B].970O24U34"]";V]K+G!H<#HQ
M,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+B(*;7-G<W1R("))35-0+6QO9V=E;B!K=6YD92!I;G1E(&EN:71I97)A
M<RXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'DB"FUS9W-T<B`B2VQA<W-E;B!-86EN=&5N86YC93HZ(&MU;F1E(&EN=&4@
M;&%D9&%S(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR
M.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(DEN<W3D;&QN:6YG<V;V;G-T<F5T(&AA<B!S=.1N9W1S
M+B!!=G-L=71A<BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X
M.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PHC.B!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P
M,"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C(R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G
M<W1R("(B"B)!9&UI;FES=')A=/9R96X@;>5S=&4@:V]N9FEG=7)E<F$@96X@
M<&5R;6%N96YT($)E:/9R:6=H971S+6MO<'!L:6YG(&]M(&1U("(*(G9I;&P@
M86YVY&YD82!"96CV<FEG:&5T97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O
M;2!S:61E(&]N;'DB"FUS9W-T<B`B16YB87)T(&YE9')E('-I9&%N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT.0IM
M<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R(")+
M86QE;F1E<FEN9F]R;6%T:6]N96X@Y'(@9F5L86MT:6<B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@
M8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S
M='(@(DMO;G1A:W1E;G,@240@86YG879S(&EN=&4@96QL97(@:W5N9&4@:6YT
M92!H:71T87,@:2!D871A8F%S96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4Q(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A
M:W1E;B!L861E<R!T:6QL(&D@861R97-S8F]K96XN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$T.2!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"B)$96X@;/9S9VIO<F1A(%!'4"US:6=N871U<F5N
M(&MRY'9S(&;V<B!A='0@=F5R:69I97)A(&1E="!S:6=N97)A9&4@(@HB;65D
M9&5L86YD970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#$*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)$:7-T<FEB=71I
M;VYS;&ES=&%N<R!)1"!A;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI
M='1A<R!I(&1A=&%B87-E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(D1I<W1R:6)U=&EO;G-L:7-T
M86X@:&%R(&EN=&4@86YG:79I=',N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+G!H<#HQ,3,@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(DMR>7!T97)I;F=S9G5N:W1I;VYE<FYA(&MR
MY'9E<B!E;B!SY&ME<B!W96)F]G)B:6YD96QS92`H2%144%,I+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S@*;7-G
M:60@(E1H92!E=F5N="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R
M+B(*;7-G<W1R(")(Y&YD96QS96X@;&%D97,@=&EL;"!I(&MA;&5N9&5R;BXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C0Y,PHC.B!L:6(O2&]R9&4N<&AP.C$W-R!L:6(O
M2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D9I;&5N
M("5S('-K86QL(&EN;F5HY6QL82!E;B!I;G-TY&QL;FEN9R!F]G(@)7,N(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HT.#,*(SH@;&EB+TAO<F1E+G!H<#HQ-S`@;&EB+TAO
M<F1E+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B1FEL
M96X@)7,@<VMA;&P@:6YN96CE;&QA(&EN<W3D;&QN:6YG87(@9O9R("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@
M(D9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@<VEG('-JY&QV+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN;W0@
M8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")&:6QE;B!K86X@:6YT
M92!K;W!I97)A<R!T:6QL('-I9R!S:N1L=BXB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.#`@;&EB+TAO<F1E+T1A=&$N<&AP.C(X,`IM<V=I9"`B
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D9I;&5N(&EN
M;F5H]FQL(&EN9V5N(&EN9F]R;6%T:6]N+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M(@IM<V=S='(@(DAU=G5D9N1L="!F]G(@9&5T=&$@;65D9&5L86YD92]R9F,X
M,C)M961D96QA;F1E(&;V;&IE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W
M97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE
M;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E
M;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED96YT
M:71E=&5N("<E<R<@<F%D97)A9&5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(D)A<F$@=N1N<W1E<B!S:61A(@H*
M(SH@<V5R=FEC97,O;&EN:W,O9&5L971E+G!H<#HS-PIM<V=I9"`B5&AE(&QI
M;FL@:&%S(&)E96X@<F5M;W9E9"(*;7-G<W1R("),Y&YK96X@:&%R('1A9VET
M<R!B;W)T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,30V
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*(E/V:W;D9V5N('1I
M;&P@1VYU4$<M<')O9W)A;6UE="!MY7-T92!V87)A(&%N9VEV96X@=&EL;"!K
M;&%S<V5N($-R>7!T7W!G<#HZ+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M341.+G!H<#HR,#$@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E
M<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*
M(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)-961D96QA;F1E
M="!S:VEC:V%T("5S('1I;&P@)7,@;65D(.1R96YD92!<(B5S7"(@:&%R('9I
M<V%T<RY<;B(*(D1E='1A(.1R(&EN9V5N(&=A<F%N=&D@9O9R(&%T="!M961D
M96QA;F1E="!H87(@;.1S=',N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM
M<V=S='(@(DYA;6YE="!S;VT@<VMA;&P@86YVY&YD87,@9O9R(&%T="!LY&YK
M82!T:6QL('-K87!A+7-I9&%N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#0Q(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(D%N=&%L
M(&;D;'0@;>5S=&4@=F%R82!E='0@;G5M97)I<VMT(';D<F1E+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,2!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L
M92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA
M<W,N(@IM<V=S='(@(DUO9'5L96X@;W!E;G-S;"!K<N1V<R!A=B!K;&%S<V5N
M($AO<F1E7T-R>7!T7W-M:6UE.CHN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+G!H<#HR.3`@;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(DEN<W3D;&QN:6YG
M96X@7"(E<UPB(&MU;F1E(&EN=&4@<W!A<F%S('#E(&=R=6YD(&%V(&%T="!D
M871A;>1N9V1E;B`B"B+V=F5R<VMR:79E<B!D96X@;6%X:6UA;'0@=&EL;.5T
M;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H
M<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET
M92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP
M.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB4')O9W)A;6UE="!S;VT@86YVY&YD
M<R!F]G(@871T('9I<V$@9&5N(&CD<B!M961D96QA;F1E='EP96X@*"5S*2!S
M86MN87,@<.4@(@HB<WES=&5M970N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#4T(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@
M<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(E1E8VMN970@9O9R(&-I=&5R:6YG(&WE<W1E('9A<F$@971T
M('1E8VME;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R(")"87)A(&CV9V5R(&]C:"!VY&YS=&5R('-I9&]R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S
M='(@(D)A<F$@:/9G97(@<VED82(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T-B!L:6(O1FEL92]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E
M<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R
M(")397!A<F%T;W)N(&WE<W1E('9A<F$@971T('1E8VME;BXB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")397)V97(@)R5S)R!R861E<F%D97,N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(E-E<G9E<B`G)7,G
M('-P87)A9&5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N(@IM<V=S='(@(E!R96YU;65R871I;VYS8F5GY')A;B!F]G(@
M)7,@:&%R('1A9VET<R!B;W)T+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D%N
M9VEV96X@<F%D("@E9"D@9FEN;G,@:6YT92XB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B06YG:79E;B!R860@97AI<W1E<F%R(&EN=&4N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ
M,#@*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S
M:VQI<W0N(@IM<V=S='(@(E5P<&=I9G1E;B!H87(@;&%G=',@=&EL;"!I(&1I
M;B!U<'!G:69T<VQI<W1A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,3<W(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B5&5M<&]RY'(@9FEL("<E<R<@9FEN;G,@:6YT92XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$P(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S`V"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA
M=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(E1E>'1E;B!D
M=2!M871A="!I;B!S=.1M;65R(&EN=&4@]G9E<F5N<R!M960@=&5X=&5N('#E
M('-KY')M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>2(*;7-G<W1R(")"87)A('1O<'`@;V-H(&)O='1E;B!S:61A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B0F%R82!T
M;W!P<VED82(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-R!L:6(O
M2&]R9&4O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B57!P
M;&%D9&%T(&1A=&$@9O9R<W9A;FX@<V5D86X@9O9R96?E96YD92!S=&5G+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K
M+T1A=&$O1&%T82]T<W8N<&AP.C$W,@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N
M<&AP.C(V,B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")$
M96X@=7!P;&%D9&%D92!F:6QE;B!K=6YD92!I;G1E('-P87)A<RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.CDS"FUS
M9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C
M97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R("),961I9R]U<'!T86=E;BUI;F9O
M<FUA=&EO;B!F]G(@86YVY&YD87)E;B!H87(@<W!A<F%T<RXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E=E871H97(N8V]M+6)L;V-K970@
MY'(@:6YT92!T:6QL9^1N9VQI9W0N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B5&5M86MA=&%L;V<@)R5S)R!F
M:6YN<R!I;G1E+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3<X(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9V$@:6YS=.1L
M;&YI;F=A<B!T:6QL9^1N9VQI9V$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z,S0Q(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HS-#D*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$970@9FEN;G,@:6YG82!A;'1E
M<FYA=&EV82!D96QA<B!S;VT@:V%N('9I<V%S(&EN;&EN92XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#`U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"B)&]G(@;>5N9V$@=&5C:V5N(&D@9N1L=&5T+B!$=2!H
M87(@86YG971T("5S('1E8VME;CL@;6%X:6UA;'0@86YT86P@=&5C:V5N(.1R
M("(*(B5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(E!R;V)L96T@
M;65D(&%T="!LY&=G82!T:6QL("<E<R<@=&EL;"!S>7-T96UE=#H@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")0<F]B;&5M(&UE9"!A='0@
M<F5N<V$@:6YF;W)M871I;VX@;VT@86YVY&YD87)E("<E<R<@9G+E;B!S>7-T
M96UE=#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E!R;V)L96T@;65D(&%T="!T82!B
M;W)T("<E<R<@9G+E;B!S>7-T96UE=#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")0<F]B;&5M('9I9"!U<'!D
M871E<FEN9R!A=B`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@W.2!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B4')O
M8FQE;2!V:60@=7!P;&%D9&YI;F<@878@9FEL96XN($EN9V$@)7,@;&%D9&%D
M97,@=7!P+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M-"!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D1E="!U<'!S=&]D
M('!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N.B`E<R#D<B!S=/9R
M<F4@Y&X@;6%X:6UA;'0@(@HB=&EL;.5T96X@<W1O<FQE:R`H)60@8GET97,I
M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*
M(D1E="!U<'!S=&]D('!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N
M.B`E<R!L861D861E<R!E;F)A<G0@=7!P(&1E;'9I<RXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R
M(")$970@=7!P<W1O9"!E='0@9F5L('9I9"!V:7-N:6YG(&%V(&UE9&1E;&%N
M9&5D96QE;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C0X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R(")&96P@=FED(&EM<&]R="!A=B!K;VYT86MT9&%T82XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B1F5L('9I9"!I;7!O<G0@878@
M:.1N9&5L<V5N.B`E<RXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP
M:'`Z,S$@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM
M<V=S='(@(D9E;"!V:60@:6UP;W)T(&%V(&E#86QE;F1A<B!D871A+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R(")&96P@=FED(&EM<&]R="!A
M=B!U<'!G:69T96XZ("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`B1F5L('9I9"!I;7!O<G0@878@:6YF
M;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96XZ("5S+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)%='0@9F5L
M('#E='+D9F9A9&5S(&D@9F]R;75LY')E="X@2V]N=')O;&QE<F$@871T(&1U
M(&EN=&4@9VSV;70@9GEL;&$@:2!E='0@(@HB;V)L:6=A=&]R:7-K="!FY&QT
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,X"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)$970@9VEC:R!I;G1E(&%T="!U
M=&;V<F$@9&5N(&)E9^1R9&$@861R97-S8F]K<V9U;FMT:6]N96XN(%9A<B!G
M;V0@9O9R<_9K("(*(G-E;F%R92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B1F5L('9I9"!U<'!D871E<FEN9R!A=B!K
M;VYT86MT=7!P9VEF=&5R+B!&]G)S]FL@:6=E;B!S96YA<F4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R(")&96P@=FED('5P<&1A=&5R:6YG(&%V(&1I
M<W1R:6)U=&EO;G-L:7-T86XN($;V<G/V:R!I9V5N('-E;F%R92XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS
M9W-T<B`B1&EN($E-05`M<V5R=F5R('-T]F1E<B!I;G1E(&1E;&%D92!M87!P
M87(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.CDV"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,3$R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,C`P"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(")$96YN82!H86YD;&EN9R!S=/9D<R!I;G1E+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M,3$X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z,S4Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N
M=&5D+B(*;7-G<W1R(")$96YN82!F=6YK=&EO;B#D<B!I;G1E(&EM<&QE;65N
M=&5R860@Y&XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HT."!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92XB"FUS9W-T<B`B1FEL96X@=F5R:V%R(&EN=&4@=F%R82!E='0@9VEL
M=&EG="!205(M87)K:78N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HU,B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU
M,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z
M:7`@9FEL92XB"FUS9W-T<B`B1FEL96X@=F5R:V%R(&EN=&4@=F%R82!E='0@
M9VEL=&EG="!:25`M87)K:78N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$T-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S,0IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(D9E;&%K=&EG="!K;W)T;G5M;65R+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&5N;F$@9')I=G)U=&EN
M(&?V<B!D970@;?9J;&EG="!A='0@<VMI8VMA(&UE9&1E;&%N9&5N('9I82!#
M;&EC:V%T96QL+2(*(F)R>6=G86X@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V5N;VT@871T(&%N=N1N9&$@2%144"!!4$DZ="XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-"!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@HB1&5N;F$@9')I=G)U=&EN(&?V<B!D970@;?9J;&EG="!A='0@<VMI
M8VMA(&UE9&1E;&%N9&5N('9I82!724XM8G)Y9V=A;B`B"B(H:'1T<#HO+W=I
M;G!L8RYC;VTI(&=E;F]M(&%T="!A;G;D;F1A($A45%`@05!).G0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&5N;F$@
M9')I=G)U=&EN(&?V<B!D970@;?9J;&EG="!A='0@<VMI8VMA(&UE9&1E;&%N
M9&5N('9I82!S;7,R96UA:6PM8G)Y9V=A;B`B"B(H:'1T<#HO+W-M<S)E;6%I
M;"YC;VTI(&=E;F]M(&%T="!A;G;D;F1A($A45%`@05!).G0B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)$96YN82!D<FEV<G5T:6X@9_9R(&1E
M="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA(%--5%`@9V5N
M;VT@(@HB5F]D869O;F4@271A;&EE;BUB<GEG9V%N("AE;F)A<G0@=&EL;"!6
M;V1A9F]N;G5M;65R*2X@1')I=G)U=&EN96X@:W+D=F5R(&5T="`B"B)E+7!O
M<W1K;VYT;R!H;W,@5F]D869O;F4@271A;&EE;B`H:'1T<#HO+W=W=RXQ.3`N
M:70I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P
M-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDX,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3`V,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y
M,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3$X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V,`HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,34V,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@T,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3DV,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P
M.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U,PHC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0U-`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R
M,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S@P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@Q-PIM<V=I9"`B5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B1N1L=&5T(&WE<W1E('9A<F$@
M:69Y;&QT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B1N1L=&5T(&;E<B!E;F)A
M<G0@:6YN96CE;&QA(&AE;'1A;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#$X(&QI8B](;W)D92]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R(")&Y&QT970@9N5R(&5N8F%R="!I;FYE:.5L;&$@<VEF9G)O
M<B!O8V@@:V]L;VXN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B1N1L=&5T
M(&;E<B!E;F)A<G0@:6YN96CE;&QA(&]K=&%L82!T86PN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R
M-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB1N1L=&5T
M('-K86QL('9A<F$@96X@:V]M;6$M(&5L;&5R(&UE;&QA;G-L86=S<V5P87)A
M<F%D(&QI<W1A(&UE9"!H96QT86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY.#D@;&EB+TAO<F1E+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F
M:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")&Y&QT970@
M;>5S=&4@=F%R82!E='0@9V]D:^1N="!T86PN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@S-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R,@IM<V=I
M9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G
M+B(*;7-G<W1R("(B"B)$971T82!FY&QT(&WE<W1E(&EN;F5HY6QL82!E;B!2
M1T(M9N1R9VMO9"!I(&AE>&%D96-I;6%L="!F;W)M870L('0@97@@(@HB)R,Q
M,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D1E='1A(&9O<FUU;.1R(&AA
M<B!R961A;B!B96%R8F5T871S+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T
M+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S
M='(@(D1E="!HY'(@Y'(@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-3D@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B
M"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E
M(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@
M<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,"!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+B(*;7-G<W1R(")-961D96QA;F1E="!S:W)E=G,@:2!E;B!A
M;FYA;B!T96-K96YU<'!SY'1T;FEN9R`H)7,I(.1N(&1I;B!E9V5N+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B1&5T(&CD<B!N=6UR970@;>5S=&4@=F%R
M82!M:6YS="!E='0N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V=Z:7`N<&AP.C0U(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N(@IM<V=S='(@(E-E<G9E<FX@:V%N(&EN=&4@<&%C:V$@=7!P
M('II<"!O8V@@9WII<"!F:6QE<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X-B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X
M.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+B(*;7-G<W1R(")3>7-T96UE="#D<B!F]G(@=&EL;&;D;&QE="!A=F%K=&EV
M97)A="XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-"!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")$970@:.1R(';D<F1E="!MY7-T
M92!V87)A(&YU;65R:7-K="XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(D1E='1A(&;V;G-T
M97(@;>5S=&4@86YR;W!A<R!F<N5N(&5T="!K;VYF:6=U<F%T:6]N<V;V;G-T
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("+%<VMA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("+$
M<F5N9&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0R.0HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B5&ED(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*
M;7-G<W1R(")4:61S<F5D;W9I<VYI;F<B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(E1I9'-F;W)M870B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3,U"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")4
M:61S=F%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G
M<W1R("+6<W1T:6UO<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE
M(@IM<V=S='(@(E)U8G)I:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS
M9W-T<B`B4G5B<FEK("AT;V]L=&EP*3HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")4:6QL(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R.0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L
M:6-K:6YG+B(*;7-G<W1R("(B"B)&]G(@871T(&UA<FME<F$@9FQE<F$@=F%L
M+"!HY6QL(&YE9"!#=')L("A00RD@96QL97(@0V]M;6%N9"`H36%C*2!T86YG
M96YT96X@(@HB;N1R(&1U(&ML:6-K87(N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B261A9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*
M;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")6:7-A($A434PM
M:^1L;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME
M;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I
M9"`B5&]M;W)R;W<B"FUS9W-T<B`B26UO<F=O;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*
M;7-G<W1R(")4;W`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@
M(E1O<"!F<F%M92`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("+6=F5R<^1T=&YI;F=A
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*
M;7-G<W1R(")4<FEN:61A9"!O8V@@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I
M9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")386YT(&5L;&5R(&9A;'-K="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*
M;7-G:60@(E1U(@IM<V=S='(@(E1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=6YI<VEA(@IM<V=S='(@(E1U;FES:65N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4=7)K97DB"FUS9W-T<B`B5'5R:VEE="(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R
M(")4=7)K:7-K("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@
M(E1U<FMS+2!O8V@@0V%I8V]S]F%R;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(D%N9V4@9&ET="!V86PZ("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD
M97@Z("(*;7-G<W1R(")55BUI;F1E>#H@(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@9O9R(&1I
M='0@;&5V97)A;G-R87!P;W)T97)I;F=S<VMR:7!T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*
M;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS
M9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM
M<V=S='(@(E5K<F%I;F$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,3(@;&EB+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A
M8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EN=&4@;.1S82!6
M1E,M;6%P<"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M.38@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE
M('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U
M<"XB"FUS9W-T<B`B(@HB1&5T(&=I8VL@:6YT92!A='0@;.1G9V$@=&EL;"!U
M=/9K860@86YVY&YD87)I;F9O<FUA=&EO;B!V:60@<F5G:7-T97)I;F<N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@@;&EB+U9&4R]F='`N
M<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N
M(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@5D93+69I;"`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C0V.`HC.B!L:6(O5D93+V9I;&4N<&AP.C,Y,B!L:6(O
M5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B2V%N(&EN=&4@Y&YD<F$@8F5H]G)I9VAE="!F]G(@5D93+69I;"`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-2!L:6(O
M5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DMA;B!I;G1E(.1N9')A('1I;&P@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@)7,O
M)7,B"FUS9W-T<B`B2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL<W1O<FQE:R`E
M<R\E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R(&QI8B]6
M1E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E
M(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@<.4@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HQ,#$V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HX,S0*(SH@;&EB+U9&4R]F:6QE+G!H<#HV.34@;&EB+U9&4R]S
M<6PN<&AP.C$P,C@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(*;7-G<W1R(")+86X@:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R
M;&5K('#E("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H
M<#HT,S4@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DMA;B!I;G1E
M(&MO;G1A:W1A(%-13"US97)V97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,SD@;&EB+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DMA;B!I;G1E(&MO;G1A
M:W1A('9I82!34TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(P.2!L:6(O5D93+V9I;&4N<&AP.C(S,@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C(S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#0@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Y"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM
M<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I
M;G1E(&MO<&EE<F$@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,V-2!L:6(O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(%9&4RUM87!P("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR-38@;&EB+U9&4R]F:6QE+G!H<#HS-C$*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6YT
M92!S:V%P82!61E,M;6%P<"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3(T(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@<VMA<&$@
M5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-B!L
M:6(O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I
M;G1E('-K87!A(%9&4RUM87!P("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C8U(&QI8B]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@
M:6YT92!S:V%P82!T;VT@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-SD@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP
M:'`Z-S8*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")+86X@:6YT
M92!P86-K82!U<'`@9&%T82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC.B!L:6(O
M5D93+W-M8BYP:'`Z,C(X(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@
M)7,L(&UA<'!E;B#D<B!I;G1E('1O;2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")+
M86X@:6YT92!R861E<F$@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,S,X(&QI8B]61E,O<W%L+G!H<#HS.34@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2(*;7-G<W1R(")+86X@:6YT92!R861E<F$@)7,L(&UA<'!E;B#D
M<B!I;G1E('1O;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*(SH@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@5D93+6UA<'`@
M<F5K=7)S:79T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S
M-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0T(&QI8B]61E,O9FEL92YP:'`Z,S0T"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,S0S"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6YT92!R
M861E<F$@5D93+6UA<'`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(SH@;&EB+U9&
M4R]S<6PN<&AP.C0R,"!L:6(O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!61E,M;6%P<#H@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<@;&EB+U9&4R]F='`N<&AP
M.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(%9&4RUF
M:6P@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y,2!L:6(O5D93+V9I;&4N<&AP.C,Q,"!L
M:6(O5D93+W-Q;"YP:'`Z,CDQ"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$V-R!L
M:6(O5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@W"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y,2!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S
M='(@(DMA;B!I;G1E(')A9&5R82!61E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C0T(&QI8B]61E,O<VUB+G!H<#HR-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P("<E<R<N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8@;&EB+U9&4R]S
M<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DMA;B!I;G1E(')A
M9&5R82!61E,@<F5K=7)S:79T.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@P,R!L:6(O5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(")+
M86X@:6YT92!A=F?V<F$@86MT=65L;"!M87!P+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS(@IM<V=S='(@(DMA;B!I;G1E(&5X=')A:&5R82!#97)T:69I
M:V%T<V1E=&%L:F5R(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP
M.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(SH@
M;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B2V%N(&EN=&4@;&%D9&$@9&5F:6YI
M=&EO;F5N(&%V("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3<Q"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`S(&QI
M8B]61E,O9FEL92YP:'`Z,C`X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W-`HC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6YT92!F;'ET=&$@5D93+69I
M;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(SH@;&EB
M+U9&4R]S;6(N<&AP.CDS(&QI8B]61E,O<VUB+G!H<#HQ,#8@;&EB+U9&4R]S
M;6(N<&AP.C8U,@HC.B!L:6(O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")+86X@:6YT92#V<'!N82!61E,M9FEL("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S,@;&EB+U9&4R]F:6QE+G!H<#HR.#0*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DMA
M;B!I;G1E(/9P<&YA(%9&4RUF:6P@9O9R('-K<FEV;FEN9RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<R(&QI8B]61E,O9FEL92YP:'`Z.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S<*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6YT92#V<'!N82!61E,M9FEL
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B2V%N(&EN
M=&4@]G!P;F$@:V]M<')I;65R870@87)K:78N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@S-B!L:6(O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(DMA;B!I;G1E(&SD<V$@5D93+69I;"`H9FEL97-I>F4H*2!M:7-S;'EC:V%D
M97,I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C<@;&EB+U9&4RYP
M:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*;7-G<W1R(")+86X@:6YT92!LY'-A(%9&4RUF
M:6P@*&=E=$9I;&53:7IE*"D@;6ES<VQY8VMA9&5S*2XB"@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*
M(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B2V%N(&EN=&4@;.1S
M82!F:6PZ("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.2!L
M:6(O5D93+V9I;&4N<&AP.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6YT92!LY'-A(&MA
M=&%L;V=E;B!F]G(@)W9F<W)O;W0G+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$P-2!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q,#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DMA;B!I
M;G1E(&)Y=&$@;F%M;B!PY2`E<R!T:6QL("5S.B!D97-T:6YA=&EO;G-M87!P
M(&9I;FYS(')E9&%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EN=&4@
M8GET82!N86UN('#E(%9&4RUM87!P+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S(Y(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUM87!P.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,T,PHC.B!L:6(O5D93+W-M8BYP:'`Z,C<Q(&QI
M8B]61E,O9G1P+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E
M(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C(Y"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$W(&QI8B]61E,O;75S<6PN<&AP
M.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6YT92!B>71A(&YA;6X@<.4@
M5D93+69I;"`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S`Q(&QI8B]61E,O<W%L+G!H<#HS,C8*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR.3,*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6YT
M92!B>71A(&YA;6X@<.4@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(SH@9G)A;65W;W)K
M+U9&4U])4T\O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4Q(&QI8B]61E,O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M
M:VES;V9S)RXB"FUS9W-T<B`B2V%N(&EN=&4@:_9R82`G;6MI<V]F<R<N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`B2V%N(&EN=&4@]G9E<G/D='1A(%=O<F1D;VMU;65N=&5T(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-3(*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L:6(O5D93+V9T
M<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E('-K<FEV82!T
M:6QL(%9&4RUF:6P@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3<Y(&QI8B]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")+86X@
M:6YT92!S:W)I=F$@=&EL;"!61E,M9FEL("AC;W!Y*"D@;6ES<VQY8VMA9&5S
M*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,30S(&QI8B]61E,O9FEL92YP:'`Z,C@X"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T-B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*
M;7-G<W1R(")+86X@:6YT92!S:W)I=F$@9&%T82!T:6QL(%9&4RUF:6PN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,B!L:6(O5D93+G!H<#HX-C(*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`B2V%N(&EN=&4@<VMR:79A('1I;&P@5D93
M+69I;"P@:W9O=&$@<VMU;&QE(/9V97)S:W)I9&%S+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R
M;&EN92(*;7-G<W1R(")5;F1E<G-T<G5K96XB"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`BQ6YG
M<F$@Y&YD<FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB
M"FUS9W-T<B`BQ6YG<F%R(&1I;B!S96YA<W1E(.5T9^1R9"(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")/=N1N=&%T('-V
M87(@9G+E;B!S97)V97(@<.4@9O9R8FEN9&5L<V4Z("(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-"!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,SD@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B
M3W;D;G1A="!S=F%R(&9RY6X@<V5R=F5R('1I;&PZ("(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z(&QI8B](
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I
M;&5D(@IM<V=S='(@(D5J(&MA=&5G;W)I<V5R860B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM
M<V=S='(@(DEC:V4@:&%N=&5R860@:V]M<&]N96YT(&%V('1Y<#H@)7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&
M+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")&]G)E;F%D92!!<F%B
M96UI<F%T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*
M;7-G<W1R(")3=&]R8G)I=&%N;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R(*;7-G<W1R(")&]G)E;G1A(%-T871E<FYA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',B"FUS9W-T<B`B06UE<FEK86YS:V$@4W1I;&QA:&%V<_9A<FYA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N:71S(@IM<V=S='(@(D5N:&5T97(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3@@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Y"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0R.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B3VOD;F0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"FUS9W-T<B`B3VOD;G0@9W+D;G-S;FET='-M961D
M96QA;F1E:60@*&%P:6US9VED*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B3VOD;G0@:VQI96YT;65D
M9&5L86YD96ED("AC;&EM<V=I9"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B3VOD;F0@;W)T('-P96-I9FEC97)A9"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N
M:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(D]KY&YT(&%N
M=N1N9&%R;F%M;B!E;&QE<B!L]G-E;F]R9"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(E1A(&)O<G0@;.1N
M:V5N(&9RY6X@;G5V<F%N9&4@96QE;65N="(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z,CDV(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z
M,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(DYA;6YL]G,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B
M"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(DEC:V4M
M<')I=FEL:6=E<F%D92!S:W)I<'0@:V%N(&EN=&4@:V]M;6$@Y70@2VQI<'`@
M=70O2V]P:65R82]+;&ES=')A+2(*(F9U;FMT:6]N97)N82!A=B!SY&ME<FAE
M='-S:^1L+B!+;&EC:V$@3TL@9O9R(&%T="!S92!E;B!T96MN:7-K(&)E<VMR
M:79N:6YG("(*(F9RY6X@;6]Z:6QL82YO<F<@;VT@:'5R(&1U(&MA;B!T:6QL
MY71A(&%T="!S:W)I<'0@:V]M;65R(.5T('5R:VQI<'`N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I
M9"`B56YS970@8V]L;W(B"FUS9W-T<B`B5&$@8F]R="!FY')G(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,S(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M.#<*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C<@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N
M<VEO;B(*;7-G<W1R(")4:6QLY&=G970@<W3V9',@:6YT92(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,3DW"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S
M"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B57!P9&%T97)A(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B57!P9&%T97)A("5S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#@*;7-G
M:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R(")5<'!D871E
M<F$@<W1A='5S('#E('-V87)A;F1E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B
M57!P9&%T97)A(&%N=N1N9&%R92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB
M+B(*;7-G<W1R(")5<'!D871E<F%D92`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D
M+B(*;7-G<W1R(")5<'!D871E<FEN9W-S8W)I<'0@<F%D97)A="XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(DQA9&1A
M('5P<"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+B(*;7-G<W1R("),861D861E('5P<"!A;&QA(&MO;F9I9W5R871I;VYS
M9FEL97(@=&EL;"!S97)V97)N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B5F5R<V%L97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED
M(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(E)O;65R<VMA('-I9F9R
M;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U
M9W5A>2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C0U"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*
M;7-G<W1R(")!;G;D;F0@86MT=65L;#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(D%N=N1N9"!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W
M"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+B(*;7-G<W1R(")!;G;D;F0@;VT@;F%M;B]L]G-E;F]R
M9"#D<B!A;FYO<FQU;F1A(&;V<B!)35-0+7-E<G9E<BXB"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S
M='(@(D%N=N1N9&%R92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S(P(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-S<T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R(")!;G;D;F1A<F4@)7,@Y'(@:6YT92!B96CV<FEG(&;V
M<B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B06YVY&YD87)A9&UI;FES=')A=&EO;B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4P(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T
M<B`B06YVY&YD87)I;G-TY&QL;FEN9V%R(@H*(SH@<VEG;G5P+G!H<#HV,@IM
M<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B06YVY&YD87)R96=I
M<W1R97)I;F<B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G
M<W1R(")!;G;D;F1A<G)E9VES=')E<FEN9R!H87(@879A:W1I=F5R871S+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C
M;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B06YVY&YD87)K;VYT;W0@:&ET=&%D
M97,@:6YT92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34P(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S8*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HY."!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@
M(E5S97)N86UE(@IM<V=S='(@(D%N=N1N9&%R;F%M;B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")!;G;D;F1A<FYA;6X@)7,@
M9FEN;G,@<F5D86XN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B06YVY&YD87)N86UN.B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N
M86UE.B`B"FUS9W-T<B`B06YVY&YD87)N86UN.B`B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES
M=&5M.B(*;7-G<W1R(")!;G;D;F1A<F4@:2!S>7-T96UE=#HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$T(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI<W1A;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-34*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@
M;&EB+U9&4R]F:6QE+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4RUM87!P(&5X:7-T97)A<B!I;G1E
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A
M8V%T:6]N(@IM<V=S='(@(E-E;65S=&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8V(&QI8B](;W)D92]&;W)M+G!H<#HX-S`*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B1VEL=&EG
M82!P;&%T<V5R('-O;2!H:71T861E<R!I;FML=61E<F%R.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S."!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B1VEL
M=&EG:&5T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4U"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(DUI
M;G5T97(@9G+E;B!N=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HX-C`@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@
M;V8@)7,N(@IM<V=S='(@(E;D<F1E="#V=F5R<W1I9V5R(&1E="!H]F=S=&$@
M=&EL;.5T;F$@*"5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T.`HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(W,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,R,"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDQ-`HC.B!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E;D<F1E;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$X-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$Y,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM
M<V=S='(@(E;D<F1E;B!A='0@=N1L:F$@9G+E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM
M<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU=&%U(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T
M<B`B5F%R:6%B96PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q."!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM
M<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@
M:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(E9E<FEF:65R:6YG
M(&UI<W-L>6-K861E<R`M(&UE9&1E;&%N9&5T(&MA;B!H82!M86YI<'5L97)A
M=',N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB
M"FUS9W-T<B`B5F5R<VEO;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")697)S:6]N
M:&%N=&5R:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T
M<B`B5F5R=&EK86P@:G5S=&5R:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN
M9R(*;7-G<W1R(")697)T:6MA;"!U=&9Y;&QN860B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;#HB"FUS9W-T<B`B5F5R=&EK86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R
M(")6Y&QD:6=T(&CV9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW
M"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I971N86UE
M<VES:R`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV,2!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.3<P"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5FES82`E<R(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT
M97)N86P@=V5B('!A9V4B"FUS9W-T<B`B5FES82!E;B!E>'1E<FX@=V5B8G-I
M9&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C`@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9I<V$@<V]M("5S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.0IM
M<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R(")6:7-A(&CD;F1E;'-E(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,#D*
M;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R(")6:7-A('5P<&=I9G0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S
M='(@(DIU;F=F<G7V87)N82P@0G)I='1I<VMA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")*=6YG9G)U]F%R
M;F$L($%M97)I:V%N<VMA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*
M;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B4VEK="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R(")3:6MT.B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@T"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!3
M3510(@IM<V=S='(@(E9O9&%F;VYE($ET86QI96X@=FEA(%--5%`B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")605).(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N(@IM<V=S='(@(E9!4DY)3D<A(2$@4D%$15)!(%-+4DE05$54($U!3E5%
M3$Q4($92Q4X@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I
M9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!V:6$@2%144"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,`HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L
M;&ES(&]C:"!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5F%R;FEN9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G
M:60@(E=E(@IM<V=S='(@(D]N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(E;D
M9&5R<')O9VYO<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")6
MY&1E<F1A=&$@9G+E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M,B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R(")W96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B8B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=E
M8F)P;&%T<R(*"B,Z(&-O;F9I9R]T:&5M97,O=V5B8G!L871S96XM<V]B97(N
M<&AP.C$V"FUS9VED(")796)B<&QA='-E;B`M(%-O8F5R(@IM<V=S='(@(E=E
M8F)P;&%T<V5N("T@4V]B97(B"@HC.B!C;VYF:6<O=&AE;65S+W=E8F)P;&%T
M<V5N+7-O8F5R7VYE=RYP:'`Z-@IM<V=I9"`B5V5B8G!L871S96X@+2!3;V)E
M<B!.15<B"FUS9W-T<B`B5V5B8G!L871S96X@+2!3;V)E<B!.62(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@@;&EB+TAO
M<F1E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@
M(E9E8VMO=FES(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*
M;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5N1L:V]M;65N(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS
M9W-T<B`B5N1L:V]M;65N('1I;&P@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5N1L:V]M
M;65N+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")6Y'-T97)LY&YD<VL@*$E3
M3RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@
M(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")6Y'-T97)LY&YD<VL@
M*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R
M82(*;7-G<W1R(")6Y'-T<F$@4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")6
M:6QK96X@87!P;&EK871I;VX@<VMA;&P@)7,@=FES82!E9G1E<B!I;FQO9V=N
M:6YG/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED
M(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")6
M:6QK96X@Y'(@879G<N1N<VYI;F=S=&5C:VYE=#\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/R(*;7-G<W1R(")6:6QK970@Y'(@=&5C:VYE="!F]G(@8VET
M97)A9"!T97AT/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#,S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#8T"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T
M<B`B5VAE<F5I<R!!=7-T<F%L:65N:V%R=&$B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")6:6QK82!F
M87-E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BXB"FUS9W-T<B`B5FEL:V$@<&QU9VEN('-K86QL(&%K=&EV97)A<R!F]G(@
M4FEC:"!497AT(&5D:71O<FXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`B0G)E9&0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3$Q"FUS9VED(")7:61T:"!I;B!#4U,@=6YI
M=',B"FUS9W-T<B`B0G)E9&0@:2!#4U,M=6YI=',B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.B(*;7-G<W1R(")"<F5D9"!PY2!M96YY;B!F]G(@)R5S)R!T
M:6QL(';D;G-T97(@*&?D;&QE<B!F<N5N(&[D<W1A(&EN;&]G9VYI;F<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM
M<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(E1A8F5L;&)R961D
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B0G)E9&1E;FAE="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`B0G)E9&0Z(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"(*;7-G
M<W1R(")6:6YD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5&ED:6<@=FEN
M9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E
M960@:6X@:VYO=',B"FUS9W-T<B`B5FEN9&AA<W1I9VAE="!I(&MN;W`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B5VEN9#HB"FUS9W-T
M<B`B5FEN9#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q
M"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5FEN9#H@(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B5FES9&]M
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES
M:&QI<W0B"FUS9W-T<B`BUFYS:V5L:7-T82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")!<F)E=&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*
M;7-G<W1R(")!9')E<W,L(&%R8F5T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
M5&5L969O;BP@87)B971E(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C$Y,R!L:6(O1FEL92]#4U8N<&AP.C(Y-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B1F5L(&%N=&%L
M(&;D;'0@<.4@<F%D("5D+B!&]G)VY&YT861E("5D+"!H:71T861E("5D+B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,"!L:6(O1FEL92]#
M4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D9E
M;"!A;G1A;"!FY&QT+B!&]G)VY&YT861E("5D+"!H:71T861E("5D+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-"!L:6(O5D93+V9I;&4N
M<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")&96P@<&]S:71I
M;VX@)60@=FED(&SD<VYI;F<@878@5D93+69I;"XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E
M9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S
M:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T
M<B`B6#4P.58S(%5T]FMA9"!N>6-K96QA;G;D;F1N:6YG(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.34@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT
M96YS:6]N<R(*;7-G<W1R(")8-3`Y5C,M=&EL;.1G9R(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")962(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#D*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S,`HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`B
M65E962(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#@P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2!M87`B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G
M<W1R("+%<FQI9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T
M<B`B665M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3,U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")*82(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHV"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L
M($D@06=R964B"FUS9W-T<B`B2F$L(&IA9R!S86UT>6-K97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B1'4@:&%R(&%K=&EV
M97)A="!T97AT;.1G92X@06YVY&YD(%L\/ET@9O9R(&%T="#E=&5R9^4@=&EL
M;"!765-)5UE'+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@
M(D1U(&AA<B!I;G1E(&)E:/9R:6=H970@<VMA<&$@9FQE<B#D;B`E9"!B;&]C
M:RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-C<@;&EB+TAO
M<F1E+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+B(*;7-G<W1R(")$=2#D<B!I;G1E(&%U=&5N=&ES97)A9"XB"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(D1U(&MA;B!I;G1E(&%N=N1N9&$@)UQ<)R!I(&1I='0@
M;F%M;B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9
M;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+B(*;7-G<W1R(")$=2!K86X@:6YT92!A;G;D;F1A("=<7"<@:2!D
M:71T(&YA;6XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-SD*;7-G:60@(EEO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M1'4@86YG878@:6YT92!E;B!G;V1KY&YD(&4M<&]S=&%D<F5S<RXB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`@;&EB+TAO<F1E+T1A=&$N<&AP
M.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#@@;&EB+TAO<F1E+T%U=&@N<&AP.CDX
M-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")$
M=2#D<B!U=&QO9V=A9"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O
M;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB1'4@;>5S=&4@86YG
M92!E='0@9VEL=&EG="!M;V)I;&YU;6UE<CL@96YB87)T('-I9F9R;W(@;V-H
M(&5T="`G*R<@9O9R92`B"B)I;G1E<FYA=&EO;F5L;'0@<')E9FEX+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N(@IM<V=S='(@(D1U(&%N9V%V(&EN=&4@971T(&=O9&OD;G0@=N1R9&4N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S
M='(@(B(*(D1U(&WE<W1E(&MO;F9I9W5R97)A(&5N($1A=&%4<N1D<RUK;W!P
M;&EN9R!F]G(@871T(&%N=N1N9&$@<F5G:7-T<F5R:6YG(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HT,S8@;&EB+TAO<F1E+G!H<#HT-C(*;7-G
M:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R
M(")$=2!MY7-T92!K;VYF:6=U<F5R82!E;B!61E,M:V]P<&QI;F<B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D1U(&WE<W1E(&)E<VMR:79A
M('!R;V)L96UE;BP@:6YN86X@9'4@:V%N(')A<'!O<G1E<F$@971T('!R;V)L
M96TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@96X@55),
M('-O;2!LY&YK96X@<&5K87(@<.4B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+B(*;7-G<W1R(")$=2!MY7-T92!A;F=E(&5N('-E<G9E
M<B!S;VT@<VMA;&P@<F%D97)A<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O
M=70N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S
M;VT@<VMA;&P@<F5N<V%S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS
M9W-T<B`B1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L
M;"!R861E<F%S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")$=2!MY7-T92!A;F=E
M(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(&SD9V=A<R!T:6QL+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")$=2!MY7-T92!A;F=E
M(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL('5P<&1A=&5R87,N(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X(&QI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")$=2!MY7-T
M92!A;F=E(&5N(.5T9^1R9"!S;VT@<VMA;&P@=71F]G)A<RXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC.B!L
M:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")$
M=2!MY7-T92!A;F=E(&5T="!N>71T(&MA=&5G;W)I;F%M;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PHC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED
M(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T(&ET86QI96YS:W0@=&5L969O
M;FYU;6UE<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-B!L:6(O
M2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*
M;7-G<W1R(")$:6X@)7,@<V5S<VEO;B!H87(@=7!P:/9R="X@5F%R(&=O9"!L
M;V=G82!I;B!I9V5N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B1&EN
M(&4M<&]S=&%D<F5S<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*
M;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B1&EN($9RY6XZ
M(&%D<F5S<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M
M871I;VXB"FUS9W-T<B`B1&EN(&EN9F]R;6%T:6]N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@P(&QI8B](;W)D92]!=71H+G!H<#HY-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B)$:6X@:6YT97)N971A9')E<W,@:&%R
M(.1N9')A=',@969T97(@871T(&1U(&QO9V=A="!I;B!T:6QL("<E<R<N($;V
M<B!A='0@(@HB<VMY9&1A(&1I9RP@;>5S=&4@9'4@;&]G9V$@:6X@:6=E;BXB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(D1I='0@;F%M;B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H
M96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)$:6X@875T96YT:7-E
M<FEN9W-K;W!P;&EN9R!S=/9D97(@:6YT92!U<'!LY&=G(&%V(&%N=N1N9&%R
M92X@3VT@9'4@=FEL;"`B"B)A;G;D;F1A($AO<F1E(&;V<B!A='0@861M:6YI
M<W1R97)A(&%N=N1N9&%R92!SY2!MY7-T92!D=2!A;G;D;F1A(&5N(&%N;F%N
M("(*(F%U=&5N=&ES97)I;F=S:V]P<&QI;F<N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S
M+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M
M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(D1I='0@875T96YT:7-E<FEN
M9W-K;W!P;&EN9R!S=/9D97(@:6YT92!L:7-T;FEN9R!A=B!A;G;D;F1A<F4L
M(&5L;&5R('/E(.1R("(*(F9U;FMT:6]N96X@879S=.1N9V0N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T(&QI8B](;W)D92]!=71H+G!H<#HY
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)$:6X@=V5B8FSD<V%R
M92]I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E<B!A='0@9'4@;&]G
M9V%T(&EN('1I;&P@)R5S)RX@(@HB1O9R(&%T="!S:WED9&$@9&EG+"!MY7-T
M92!D=2!L;V=G82!I;B!I9V5N+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C4U"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N(@IM<V=S='(@(D1I;B!W96)B;.1S87)E('-T]F1E<B!I;G1E
M(&1E;B!HY'(@9G5N:W1I;VYE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M
M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(D1I;B!W96)B;.1S
M87)E('-T]F1E<B!I;G1E('5T<VMR:69T<V9U;FMT:6]N96XN(%1R>6-K($-T
M<FPO3W!T:6]N("L@4"!F]G(@(@HB871T('-K<FEV82!U="XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.B(*;7-G<W1R(")$:6X@86MT=65L;&$@=&ED<WIO;CHB"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B1&EN(&;V<G9A;&1A
M(&ED96YT:71E="!H87(@Y&YD<F%T<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S
M='(@(D1I;B!F]G)V86QD82!I9&5N=&ET970Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@
M(D1I='0@9G5L;'-TY&YD:6=A(&YA;6XZ(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z,3`P,"!L:6(O2&]R9&4O075T:"YP:'`Z.3DY"FUS9VED(")9
M;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")$:6X@:6YL;V=G;FEN
M9R!H87(@9^5T="!U="XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F
M;W(@)7,@:7,Z("5S(@IM<V=S='(@(D1I='0@;GEA(&SV<V5N;W)D(&;V<B`E
M<R#D<CH@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U
M-"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+B(*;7-G<W1R(")$:6YA(&EN<W3D;&QN:6YG87(@:&%R('5P
M<&1A=&5R871S(&;V<B!D96X@:.1R('-E<W-I;VYE;BXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+B(*;7-G<W1R(")$:6YA(&EN<W3D;&QN:6YG87(@:&%R('5P<&1A=&5R871S
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(D1I='0@;/9S
M96YO<F0@:&%R(&)L:79I="#E=&5R<W3D;&QT(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)$:71T(&SV<VYO
M<F0@:&%R(.5T97)S=.1L;'1S+"!K;VYT<F]L;&5R82!D:6X@92UP;W-T(&]C
M:"!L;V=G82!I;B!M960@9&ET="`B"B)N>6$@;/9S96YO<F0N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R(&QI8B](;W)D92]!=71H+G!H<#HW
M,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@
M(D1I='0@;/9S96YO<F0@:&%R(&?E='0@=70N(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S
M.B(*;7-G<W1R(")$:6YA(&9JY')R<V5R=G)A<CHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(DIU9V]S;&%V:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E
M(@IM<V=S='(@(EIA:7)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B
M"FUS9W-T<B`B6F%M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W
M92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R
M"B,Z(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@
M(EM']FT@8VET97)A9"!T97AT72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM&96QR87!P
M;W)T72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM6:7-A
M(&-I=&5R860@=&5X="`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO5&5X
M="]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$V.0HC.B!L:6(O
M2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B6U9I<V$@8VET97)A9"!T97AT("T@)7,@<F%D97)=(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,@;&EB+TAO<F1E+G!H
M<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM
M<V=S='(@(EMR860@)7,@878@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-#DW(&QI8B](;W)D92YP:'`Z,34T-0HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B7T%D;6EN:7-T<F%T:6]N(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851RY&0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]2861E<F$@<F%D(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P
M<&5R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-2!L
M:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?
M2&KD;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E]":6QD:6YS=.1L;&YI;F=A<BXN+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.30@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y
M-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?3&]G9V$@:6XB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP(&QI8B](;W)D92]-96YU
M+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E],;V=G82!U="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(L1?;F1R
M82!LY&YK+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$V-"!L:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R(")?26YS=.1L;&YI;F=A<B(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM
M<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]"96CV<FEG:&5T97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?5&$@8F]R
M="!LY&YK+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B
M"FUS9W-T<B`B7U-E='5P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")?5&%B96QL:6YS=.1L;&YI;F=A<BXN+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]!;G;D
M;F1A<F4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,2!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S
M='(@(F%D<F5S<V)O:R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B;VOD;F0@
M;6]T=&%G87)E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S
M='(@(FMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-C4*;7-G:60@(F-A;&TB"FUS9W-T<B`B;'5G
M;G0B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@
M(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B:V%N(&EN=&4@
M<VMA<&$@=71F:6PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(FMA;B!I;G1E
M(/9P<&YA(&EN9&%T82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,2!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FML:6-K82!HY'(B"@HC.B!L:6(O
M0FQO8VLO8F%R=&EM92YP:'`Z-38*;7-G:60@(F-L;V-K(@IM<V=S='(@(FML
M;V-K82(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(FMO;6UA;F1O
M<F%D<V9E;"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM
M<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")K;VYF:6=U<F%T
M:6]N<V9E;"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM
M<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")K
M<FET:7-K('-Y<W1E;69I;"!S86MN87,B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S
M='(@(F1A=&%F;W)M871F96PB"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N
M:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(N1N9')A(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U
M;F0B"FUS9W-T<B`B<&]S=&5N(&MU;F1E(&EN=&4@:&ET=&%S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(F9A
M;&QI;F<B"FUS9W-T<B`B9F%L;&%N9&4B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-3`@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@Y.`IM
M<V=I9"`B9FEL92(*;7-G<W1R(")F:6PB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S(@IM<V=S='(@(F9RY6X@9&5N("5S("@E<RD@:VP@)7,@
M)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED
M(")G=7-T:6YG(@IM<V=S='(@(G-T;W)M8GEA<B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B
M:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S,T"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-3D*
M;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R
M(")O:^1N9"!VY')D9&%T;W(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(F=E;F%S="(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B:6YL:6YE(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P
M=70@97)R;W(B"FUS9W-T<B`B8F5A<F)E=&YI;F=S9F5L(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<B(*;7-G<W1R("));G1E<FYT(&%P<&QI:V%T:6]N<V9E;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B<F%D97)=(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,Z(&9R86UE
M=V]R:R]61E-?25-/+TE33U=R:71E<B]M:VES;V9S+G!H<#HU-"!L:6(O5D93
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS
M9W-T<B`B9F5L:V]D("5D(&9RY6X@;6MI<V]F<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-#4*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B
M;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,"!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C(X-0HC.B!S97)V:6-E<R]P;W)T86PO;65N
M=2YP:'`Z,C$R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*
M;7-G<W1R(")N86UN(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,2!L
M:6(O2&]R9&4O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*
M;7-G<W1R(")I;G1E(&EM<&QE;65N=&5R860B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(FEN=&4@:6UP;&5M96YT97)A9"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`U(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E
M<&%D(@IM<V=S='(@(F%N=&5C:VYI;F=S8FQO8VLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P
M97)C96YT(@IM<V=S='(@(G!R;V-E;G0B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S
M='(@(N5T:V]M<W0@;F5K860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T
M<B`B<&EX;&%R(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<P
M"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B<')O
M=&]K;VQL9F5L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S0*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")S=&EG86YD92(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC
M92!U;F%V86EL86)L92(*;7-G<W1R(")4:N1N<W1E;B#D<B!E:B!T:6QL9^1N
M9VQI9R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q"FUS9VED(")S
M:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(G9I<V$@<VMI;&QN861E<B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@
M(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@=FEA($A4
M5%`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S8Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*
M;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G-T96%D>2(*;7-G<W1R(")S
M=&%D:6=T(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34P"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B<WES=&5M9F5L(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")U<'!G:69T<VQI<W1A
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T
M96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R(")T:6QL9N1L;&EG="!F96PB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8Y"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS
M9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S
M='(@(F%N9V4@;/9S96YO<F1E="!T=N4@9^5N9V5R(&;V<B!A='0@8F5K<N1F
M=&$B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")E;F%D(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-R!L:6(O2&]R9&4O34E-
M12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")N86UN;/9S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(G5S97(@<V5L96-T(@IM<V=S='(@(F%N=N1N9&%R=F%L(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@
M(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C0R"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W
M96%T:&5R+F-O;2(*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O=')?
M5%(N<&\`````````````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#<R,#(W-``Q,#4Q-30S,3`V,P`P,38T,S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!4=7)K:7-H('1R86YS
M;&%T:6]N<R!F;W(@2&]R9&4@<&%C:V%G90HC($AO<F1E('!A:V5T:2!IYVEN
M(%3\<FOG92#'979I<FEL97(N"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!'96YE<F%T
M960@8GD*(R!397)V970@1_QN97D@/'-G=6YE>4!M971U+F5D=2YT<CX*(R!!
M:&UE="#6>G3\<FL@/&]A:&UE=$!M971U+F5D=2YT<CX*(PIM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&5V,RXP+C1<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`U+3`V+3(X(#$T.C0X*S`S,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@075T;VUA=&EC86QL>2!G96YE<F%T961<;B(*
M(DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/4E33RTX.#4Y+3E<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],3L@<&QU<F%L
M/3`[7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@
M9_QN(/9N8V4I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R
M("(H17)I_FEM($%N86AT87+]("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES
M*2(*;7-G<W1R("(@*"5S(&?\;F1E*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H8G5G_&XI
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT
M;VUO<G)O=RDB"FUS9W-T<B`B("AY87+];BDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B
M("AD_&XI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(&1E
M*&1A*2`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B1&EZ:6X@9&7P:6PB"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(&ES(&=E
MYV5R;&D@8FER('-EYV5N96L@9&7P:6PN(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R("(G)7,G($AO<F1E($MA>?UT;&%R_6YD82!Y87#]
M;&%N9/UR_6QM86W]_BXB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ
M-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E
M;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B)R5S)R!A\&'G(.=E=FER:6-I
M<VD@8G5L=6YA;6%D_2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H
M92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(&=R=7`@<VES=&5M:6YE
M(&5K;&5N9&DN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@:7II;B!S
M:7-T96UI;F4@96ML96YD:2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@
M(B<E<R=Y87)A=/UL86UA9/TZ("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S('9E("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO
M=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M9_QN;/QK(&AA=F$@=&%H;6EN
M:2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($)I;&1I<FEM
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@
M4&%R;6%K(-UZ:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(E<R!"86O];2#=_FQE;6QE<FD@+2!/;F%Y;&%M82(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R
M("(E<R!!>6%R;&%R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S
M='(@(B5S($=I<FG^(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*
M;7-G<W1R("(E<R!!;FQA_FUA($MO_G5L;&%R_2(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!Z871E;B!V87(N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@9&4@)7,@)7,B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB1V5RYVME_G1I<FEL;65S
M:6YI(&ES=&5D:?!I;FEZ(&G^;&5M;&5R(&GG:6X@;VYA>2!K=71U;&%R_6[]
M(&G^87)E=&QE>6EN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T
M<B`B)7,@:7-T96YM96MT961I<BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(B5S(&1A:VEK82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("(E<R!B=6QU;F%M863]+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B)7,@+2`E<R`O("5S("(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S($%D<F5S($1E9G1E<FDB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S(%1A:W9I;2(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R!.;W0@1&5F=&5R:2(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,@1_9R978@3&ES
M=&5S:2(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L
M86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0Q,`HC+"!F=7IZ>0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L
M(&;]<G3];F%L_2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&;]<G3];F%L_2`E<R`E<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L(&1E\&G^
M:6T@)7,@+3X@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(%-EYR`M
M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B,3(@4V%A=&QI:R!:86UA;B!":>=I;6DB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM
M<V=S='(@(C(T(%-A871L:6L@6F%M86X@0FGG:6UI(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T
M('-A870B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L(&9U
M>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`BUFYC96MI(%-A>69A(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B
M0G4@]F)E:R!IYVEN('9E<FET86)A;OT@<V]N('5Z86YT_7/](&=E<F5K;65K
M=&5D:7(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G
M:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D]N=6QM
M87H@8FER(&AA=&$@;VQU_G1U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+=;&5T:7EI(/YI
M9G)E;&5Y96)I;&UE:R!IYVEN(%!'4"!AY_UK(&%N86AT87+](&=E<F5K;65K
M=&5D:7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HBW6UZ86QA;FW]_B!I
M;&5T:7EI(&1O\')U;'7P=6YU('-A\&QA;6%K(&GG:6X@4$=0(&'G_6L@86YA
M:'1A<OT@9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HBW6QE=&EN:6X@
M_FEF<F5S:6YI(.?V>FUE:R!IYVEN(&'G_6L@4$=0(&%N86AT87+]+/9Z96P@
M4$=0(&%N86AT87+]('9E(&=EYVG^("(*(G3\;6-E8VGP:2!G97)E:VUE:W1E
M9&ER+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"B+=;&5T:7EI(&EM>F%L86UA:R!IYVEN(&'G_6L@
M4$=0(&%N86AT87+]+/9Z96P@4$=0(&%N86AT87+]('9E(&=EYVG^("(*(G3\
M;6-E8VGP:2!G97)E:VUE:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB
MW6QE=&EN:6X@_FEF<F5S:6YI(.?V>FUE:R!IYVEN(&'G_6L@4R]-24U%(&%N
M86AT87+]+"#V>F5L(%,O34E-12!A;F%H=&%R_2!V92`B"B)G9>=I_B!T_&UC
M96-I\&D@9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(MUL971I
M>6D@:6UZ86QA;6%K(&GG:6X@8>?]:R!3+TU)344@86YA:'1A<OTL(/9Z96P@
M4R]-24U%(&%N86AT87+]('9E(&=EYVG^("(*(G3\;6-E8VGP:2!G97)E:VUE
M:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(MUL971I>6D@_FEF<F5L97EE
M8FEL;65K(&GG:6X@8>?]:R!334E-12!A;F%H=&%R_2!G97)E:VUE:W1E9&ER
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*
M(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")"=6QU=&QA<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"B,L
M(&9U>GIY"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(M93($AA9FEF
M(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(M;6(%EA\&UU<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED
M(")!32!3:&]W97)S(@IM<V=S='(@(M;6(%-A\&YA:R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`BUM8@2&%F:68@2V%R(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(M;6+]93
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B
M06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B1/QZ96YL97EI8VD@:&%K:_UN
M9&$B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O
M=70N+BXB"FUS9W-T<B`B2&%K:_UN9&$N+BXN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M
M(@IM<V=S='(@(D5N86QT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(D]R
M=&%Y82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B5D93(&1I>FEN:2!Y87)A=/UR:V5N(&5R:?YI;2!E;F=E;&QE;F1I
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E9&
M4R!D:7II;FD@>6%R873];/UR:V5N(&5R:?YI;2!E;F=E;&QE;F1I+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O
M=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D)I;&=I;&5R:6YI>B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N="!087-S=V]R
M9"(*;7-G<W1R(")(97-A<"!087)A;&]S_2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(DAE<V%P($1O;F1U<G5L9'4N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*
M;7-G<W1R(")(97-A<&QA;OUY;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@
M(D%D9"(*;7-G<W1R(")%:VQE(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@
M861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*
M;7-G<W1R(")!;'0@1W)U<"!%2VQE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY
M"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")!;'0@W7II
M;B!%2VQE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@
M(D%D9"!(97)E.B(*;7-G<W1R(")"=7)A>6$@16ML93HB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D
M($YE=R!'<F]U<"(*;7-G<W1R(")996YI($=R=7`@16ML92(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S
M='(@(EEE;FD@W7II;B!%:VQE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D%L="!G<G5B
M=2`G)7,G(&GG:6YE(&5K;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B)R5S)R#\>F5R
M:6YD92!A;'0@:7II;B!E:VQE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G
M:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")996YI(&MU;&QA;OUC_2!E
M:VQE.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B2V]L;VX@16ML92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@
M(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")996YI(/QY92!E:VQE(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B
M"FUS9W-T<B`BW6MI;&D@16ML92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S
M(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B5S($UE;OQS_&[\($UO>FEL
M;&$@2V5N87(@QW5B=?!U($]L87)A:R!%:VQE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D
M<F5S<R!B;V]K.B(*;7-G<W1R(")!9')E<R!D969T97)I;F4@96ML93HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G
M:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B061R97,@9&5F
M=&5R:6UE(&5K;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D
M('5S97(B"FUS9W-T<B`B2W5L;&%N_6/]($5K;&4B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@
M7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET
M:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B)R5S
M)R!S:7-T96UE(&5K;&5N9&DL(&%M82!H97)H86YG:2!E:R!B:7(@9VER:?X@
M8FEL9VES:2!E:VQE;F5M961I.B`E<R(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B<E<R<@<VES
M=&5M92!E:VQE;F1I+B#>:6UD:2!G:7)I_B!Y87!A8FEL:7)S:6YI>BXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")+=6QL86[]8_T@96ML
M96UE('-EYVEL96UE>B!K_6S];F3]+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(D%D<F5S($1E9G1E<FDB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E
M="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B6?9N971I
M;2TM1&GP97(@:W5L;&%N_6QA<B!IYVEN(&EZ:6YL97)I(&)E;&ER;&5Y:6XB
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B6?9N
M971I;2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@
M(D%D<R(*;7-G<W1R(")!9',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI
M<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M06QB86YI82(*;7-G<W1R(")!<FYA=G5T;'5K(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B06QG97)I82(*;7-G<W1R(")#97IA>6ER(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS
M9W-T<B`BUG1E:VD@860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")(
M:7IA;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(DAI>F%L86UA:SHB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G
M<W1R(")4_&W\(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U
M=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5/QM($1O\')U;&%N;?W^($MU
M;&QA;OUC_6QA<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O
M=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5/QM($=R
M=7!L87(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R
M86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L
M;"!097)M:7-S:6]N<R(*;7-G<W1R(")4_&T@W7II;FQE<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G
M:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E3\;2!D]G)T('G\>B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("+';VML=2!A9')E<VQE<F4@:7II
M;B!V97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")3
M_7)A;&%N;?W^(&QI<W1E('3\<OQN_"!A>6%R;&%M87EA(&EZ:6X@=F5R:6QS
M:6X@;6D_(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("):871E;B!V
M87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E
M<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("+6=&5K:2!)35-0($=I<FG^:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(M9T96MI($E-4U`@4&%R;VQA<_TB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA
M=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("+6=&5K:2!)35-0($MU;&QA;OUC
M_2!!9/TB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I
M9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BUG1E:VD@96QE
M:W1R;VYI:R!P;W-T82!A9')E<VDB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("+6=&5K
M:2!T87-L86ML87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT
M.B(*;7-G<W1R("+6=&5K:2!M971I;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;65R:6-A;B!386UO82(*;7-G<W1R(")!;65R:6MA;B!386UO82(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`B1V7G97)S:7H@9&7P97(@8F5L:7)T:6QD
M:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U
M>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G
M<W1R(")B:7(@:&%T82!O;'7^='4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD
M;W)R82(*;7-G<W1R(")!;F1O<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL
M;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B
M06YO;FEM(%!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")#979A<"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)T:6MA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I
M9W5A('9E($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*
M;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(E5Y9W5L86UA(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T
M(@IM<V=S='(@(E5Y9W5L86UA($QI<W1E<VDB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B57EG=6QA;6$@2&%Z_7(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S
M='(@(D%L="!P87EL8?[];6QA<F$@=7EG=6QA(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B3VYA>6QA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(EEA:VQA
M_OUK($)O>75T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(DYI<V%N(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ
M,C4V*2(*;7-G<W1R(")!<F%PYV$@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I
M>F4B"FUS9W-T<B`B0F5L9V5L:6L@1&]S>6$@0G5Y=71U(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G
M<W1R(")"96QG96QI:R!!9/TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_(@IM<V=S='(@(B5S(&GG:6X@9VER:?X@:7-T9?!I;FD@:V%L
M9/UR;6%K(&ES=&5D:?!I;GIE(&5M:6X@;6ES:6YI>C\B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(G)7,G('9E('3\
M;2!A;'0@9W)U<&QA<OUN_2!S:6QM96L@:7-T:7EO<B!M=7-U;G5Z/R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<FIA;G1I;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B17)M96YI<W1A
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA
M;B`H05)-4T-)22TX*2(*;7-G<W1R(")%<FUE;FEC92`H05)-4T-)22TX*2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S
M='(@(E-A;F%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B
M07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED
M(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(D%S8V5N<VEO;B!!9&%L87+]
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!
M<G0B"FUS9W-T<B`B07-C:6D@4V%N873](@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM
M<V=S='(@(D%S>6$O4&%S:69I:R!"]FQG97-I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(D)A
M:_UM(&G^;&5M;&5R:6YD96X@]FYC92!D;_!R=6QA;6$@<V]R=6QS=6X@;74_
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D%T86UA($MO;&]N;&%R_2(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")687(@;VQM87EA;B!B
M:7(@9W)U8G4@<VEL;64@9VER:?YI;6DN(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B5F%R(&]L;6%Y86X@8FER(&EZ
M;FD@<VEL;64@9VER:?YI;6DN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R(")687(@;VQM87EA;B!B:7(@9W)U8G4@9/QZ96YL
M96UE(&=I<FG^:6UI+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU
M,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+B(*;7-G<W1R(")687(@;VQM87EA;B!B:7(@<&%Y;&'^_6W](&3\>F5N;&5M
M92!G:7)I_FEM:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM
M<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("+6>FYI=&5L:6ML97(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(D'P=7-T;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B079U<W1U<F%L>6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!=7-T<FEA(@IM<V=S='(@(D%V=7-T=7)Y82(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?8WER<W%L.B#=<W1E;F5N(&EM87`@=7IA=&%T_7/](&)U;'5N86UA
M9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z(-US=&5N96X@
M>65T96YE:VQE<F4@<V%H:7`@9&7P:6PN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER
M=7,Z(-US=&5N96X@:6UA<"!U>F%N=/US_2!B=6QU;F%M863]+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F
M='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE
M(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R
M("(B"B)!=71H7V9T<#H@W7-T96YE;B!&5%`@=7IA;G3]<_T@8G5L=6YA;6%D
M_2X@4$A0)WEI("TM96YA8FQE+69T<"!S=VET8V@@(@HB9&7P:?YT:7)G97-I
M>6QE(&1E<FQE>6EN+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP
M:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z(-US=&5N96X@24U!
M4"!U>F%N=/US_2!B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B
M-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z(-US
M=&5N96X@:W)B-2!U>F%N=/US_2!B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?;&1A<#H@W7-T96YE;B!,1$%0('5Z86YT_7/](&)U;'5N
M86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R(")!=71H7VEM87`Z("5S(&MU;&QA;OUC_7/](&5K;&5N96UE9&DN(%-U
M;G5C=3H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B`E<R!K=6QL86[]8_US
M_2!S:6QI;F5M961I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B`E<R!K=6QL
M86[]8_US_2!G_&YC96QL96YE;65D:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*
M;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(-US=&5N96X@34-!3"!U>F%N
M=/US_2!B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@
MW7-T96YE;B!S;6)A=71H('5Z86YT_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B1&_P<G5L86UA
M(&)A_F%R_7/]>B!O;&1U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B1&_P<G5L86UA
M(&)A_F%R_7/]>B!O;&1U+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D1O\')U;&%M82!2041)55,@
M<W5N=6-U<W4@=&%R86;];F1A;B!G97)I(.=E=G)I;&1I+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1E10('-U;G5C=7-U
M;F$@9&_P<G5L86UA(&)A_F%R_7/]>B!O;&1U+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1E10('-U
M;G5C=7-U;F$@9&_P<G5L86UA(&)A_F%R_7/]>B!O;&1U+B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L
M9',Z(@IM<V=S='(@(DMU;&QA;OUL_7(@86QA;FQA<CHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B87EC86XB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*
M;7-G<W1R(")"3T9(($'G_6ML86UA;&%R_2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG
M<F]U;F0B"FUS9W-T<B`B07)T86QA;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L
M;W(B"FUS9W-T<B`B07)T86QA;B!296YG:2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R
M9"XB"FUS9W-T<B`B2_9T_"!K97)B97)O<R!P87)O;&%S_2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R
M;W,@=7-E<FYA;64N(@IM<V=S='(@(DOV=/P@:V5R8F5R;W,@:W5L;&%N_6/]
M(&%D_2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A
M:&%M86QA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B
M0F%H<F5Y;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"
M86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT_6L@*$E33RTX.#4Y
M+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B
M0F%N9VQA9&7^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E1A8F%N(&=R869I:R!D
M:7II;FD@)R5S)R!B=6QU;F%M863]+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B
M"FUS9W-T<B`B5&%B86X@YVEZ9VES:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&%R=7,B"FUS9W-T<B`B0F5Y87H@4G5S>6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"96QG:75M(@IM<V=S='(@(D)E;.=I:V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M
M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B
M1&_P=6UG_&[\(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B57EG
M=6QA;6$@7"(E<UPB('-A:&EP(&]L9'7P=2!<(B5S7"(@]F)E\&D@8G5L=6YA
M;6%D_2XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G
M:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(M9B96L@07EA<FQA<OTB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K
M(%1Y<&4B"FUS9W-T<B`BUF)E:R!4_'+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@
M(DMO>74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O
M;&EV>6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED
M(")";V]K;6%R:W,B"FUS9W-T<B`B665R(-UM;&5R:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@
M(D)O<F1E<B(*;7-G<W1R(")3_6[]<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(E/];OUR($MA;/UN;/WP_3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")"
M;W)D97)S(@IM<V=S='(@(E/];OUR;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N82!(97)S96LB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS
M9W-T<B`B2&5R($EK:7-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B
M"FUS9W-T<B`B0F]T<W9A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R
M(")!;'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(D)O=79E="!!9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL
M(@IM<V=S='(@(D)R97II;'EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET86YY82!(
M:6YT($]K>6%N=7-U($+V;&=E<VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=6QG87)I82(*;7-G<W1R(")"=6QG87)I<W1A;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U
M;&QE=&5D($QI<W0B"FUS9W-T<B`B36%D9&4@W6UL:2!,:7-T92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A
M<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N
M9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#
M35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-24R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@1&'P_73];2!.;VMT
M86QA<OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B7TC\8W)E(-9Z96QL:6ML97)I+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PHC+"!F=7IZ>0IM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B1&'P_73];2!L:7-T97-I
M(&)E;&ER;&5N96UE9&DN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R
M(@IM<V=S='(@(E1A:W9I;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B1'5R9W5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)OYWEA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)087)O;&$@]GID979I;FEM;&D@
M;VQA<F%K('/]9OUR;&%N86UA;6%K=&%D_7(L(&S\=&9E;B!Y]FYE=&EC:6YI
M>FQE(&?V<OS^_&XN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E
M('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!D;W-Y87/]('-I;&EN
M96UE9&DN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(DE-05`@<W5N=6-U<W5N82!B8?!L86[];&%D_3H@)7,B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(EPB)7-<(B!D;W-Y87/]('-I;&EN96UE9&DN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(MUP=&%L(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R(")3;W)U;B!287!O<G5N=2#=<'1A;"!%="(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(EPB)7-<
M(B!D;W-Y87/]('-I;&EN96UE9&DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B1V7G:6-I(&1I>FEN(&)U
M;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(G=&%R9V5T1FEL92<@9&7P
M:?YT:7)G97-I(&]L;6%D86X@9&5V86T@961I;&5M97HN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@9&EZ:6YI(&MA;&3]<OUL86UA9/TN(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")+86QD_7+];&%M
M863]("PE9"!A;'0@>6%P_2!V87(N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E
M<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E
M<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB665N
M:61E;B!D_'IE;FQE;65D:2P@>65N:61E;B!D_'IE;FQE;64@:>=I;B!S8?!L
M86YA;B!K87G]=&QA<OUN('-A>?US_2!I;&4@(@HB9&5P;VQA;FW]_B!O;&%N
M;&%R_6X@<V%Y_7/](&7^;&7^;65M96MT961I<BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S
M='(@(D)E;&ER=&EL;6G^(&YU;6%R87EA(&EL971I('GV;FQE;F1I<FEL96UE
M9&DN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")#
M87!E(%9E<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")"8?YL
M_6LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B
M"FUS9W-T<B`B2V%T96=O<FEL97(@=F4@171I:V5T;&5R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA;B!!9&%L
M87+](@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")#97`@5&5L969O;G4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B2/QC<F4@
MUGIE;&QI:VQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")(
M_&-R92!Y87-T_6ML86UA<_TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T
M:65S(@IM<V=S='(@(DC\8W)E(-9Z96QL:6ML97)I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@
M<W!A8VEN9SHB"FUS9W-T<B`B2/QC<F4@0F_^;'5K;&%R_3HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS
M9W-T<B`B0V5P(%1E;&5F;VYU(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1I
M:R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@
M(D]R=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`B3W)T82!!9G)I:V$@0W5M:'5R:7EE=&DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A
M;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B3W)T82!!=G)U<&$@*$E33RTX.#4Y
M+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B3VYA>2!"96QG
M97-I($%Y<OUN=/UL87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,3$*(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R
M(@IM<V=S='(@(D]N87D@0F5L9V5S:2!!>7+];G3];&%R_2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I
M8V%T92!0;VQI8VEE<R(*;7-G<W1R(")/;F%Y($)E;&=E<VD@2W5R86QL87+]
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(L=A9"(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")$9?!I
M_G1I<B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F
M=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4&%R
M;VQA;OUZ_2!S_6;]<FQA>?UN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M("(*(F5M86EL<RXB"FUS9W-T<B`B(@HBW6YS86YL87+];B!S:7ID96X@9V5L
M96X@96QE:W1R;VYI:R!P;W-T86QA<OT@;VMU<FME;B!V92!C979A<&QA<FME
M;B`B"B)G]G)D_&ML97)I(&%D('9E(&%D<F5S:6YI>FD@9&7P:?YT:7)I;BXB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*
M(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H
M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*
M;7-G<W1R(")+87)A:W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN
M+BXB"FUS9W-T<B`B0F'P;&%N=/UY_2!$95]N971L92XN+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(MYI;&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EN82(*;7-G<W1R("+':6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM
M<V=S='(@(D)A<VET;&7^=&ER:6QM:?X@QVEN8V4@*$=",C,Q,BDB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2DB"FUS9W-T<B`B1V5L96YE:W-E;"#':6YC92`H0FEG-2DB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")087)O;&$@<V7G:6XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#
M:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")+=6QL86[]8_T@863]('-EYVEN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")487)I:&QE<FEN(&YA
M<_UL(&?V<W1E<FEL96-E\&EN:2!S9>=I;CHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS
M9W-T<B`B3&ES=&4@0FGG96T@5/QR_&[\(%-EYVEN("AS_7)A;&%N;?W^(&QI
M<W1E;&5R(&GG:6XI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES
M;&%N9"(*;7-G<W1R(")#:')I<W1M87,@061A;&%S_2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E
M<R!N;W0@9F]U;F0N(@IM<V=S='(@(E/];OUF('1A;OUM_2!B=6QU;F%M863]
M.B5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,30*;7-G:60@(D-L96%R(@IM<V=S='(@(E1E;6EZ;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A
M<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DU33V9F:6-E(&)IYVEM(&EM;&5R
M:6YI('1E;6EZ;&4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"B,L(&9U
M>GIY"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")+=6QL86[]8_T@=&5M
M:7IL92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R
M(")+=6QL86[]8_UY_2!T96UI>FQE.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R
M(")+=6QL86[]8_T@=&5M:7IL92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B
M2W5L;&%N_6/]('9E<FES:2!T96UI>FQE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M:6YG($QA=&4B"FUS9W-T<B`B1V7G(%-A871L97)D92!98?!M=7(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I
M9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B1&5V86T@971M96L@:>=I
M;B!T_6ML87G];B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*
M;7-G<W1R(")(5%10('EO;'5Y;&$@0VQI8VMA=&5L;"(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E!E;F-E<F5Y:2!+87!A
M="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B
M"FUS9W-T<B`B0G5L=71L87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY
M(@IM<V=S='(@(D)U;'5T;'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D)U;'5T
M;'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD
M<R(*;7-G<W1R(")#;V-O<R!!9&%L87+](@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G
M<W1R(")+96YA<B#'=6)U\'5N=2!$87)A;'0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL
M87!S960@8F]R9&5R<R(*;7-G<W1R(")$87)A;'3];&W]_B!3_6[]<FQA<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;&]M8FEY
M82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R
M+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")296YK(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC
M:V5R(@IM<V=S='(@(E)E;FL@4V7G:6-I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R
M(")296YK(%-EYVEM:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")+;VQO;FQA
M<CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#
M;VQU;6X@=&ET;&5S(@IM<V=S='(@(DMO;&]N($)A_FS]:VQA<OTB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS
M9W-T<B`B2V]M:6LB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@
M(D-O;6UA;F0B"FUS9W-T<B`B2V]M=70B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B2V]M=70@2V%B
M=?!U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")#;VUM96YT(@IM<V=S='(@(D'G_6ML86UA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE
M(@IM<V=S='(@(D]R=&%K($%D_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO
M<F]S(@IM<V=S='(@(D-O;6]R;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@
M(MYI<FME="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B
M0V]M<'5T97)S(@IM<V=S='(@(D)I;&=I<V%Y87)L87(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD
M:71I;VXB"FUS9W-T<B`B2V_^=6QL87(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")+;_YU;&QA<B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(EEA</UL86YD_7)M82!&87)K;&%R
M_2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I
M9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A
M;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92XB"FUS9W-T<B`B66%P_6QA;F3]<FUA;OUN(&?\;F-E;&QE;FUE
M<VD@9V5R96MM96MT961I<BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R
M(")987#];&%N9/UR.B5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")0
M87)A;&]Y_2!$;_!R=6QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D1E;6]K<F%T:6L@
M2V]N9V\@0W5M:'5R:7EE=&DB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B0F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960Z("(*;7-G<W1R(")"8?!L86YT_2!B8?YA<OUS_7H@;VQD=3HB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B0>?]:R!A;F%H=&%R('-U;G5C=7-U;F$@8F'P;&%N=/T@<F5D
M9&5D:6QD:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T
M<B`B0>?]:R!A;F%H=&%R('-U;G5C=7-U;F$@8F'P;&%N=/T@<F5D9&5D:6QD
M:2X@4V5B96(Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@T-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B1E10('-U;G5C=6YA(&)A\&QA;G3](&)A_F%R_7/]>B!O
M;&1U+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#
M;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("+=
M;&5T:?YI;2!N;VMT86QA<OT@8F'^87+]>6QA(&%D<F5S(&1E9G1E<FEN:7IE
M(&5K;&5N9&DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*
M;7-G<W1R("+=YV5R:6LZ("<E<R<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G
M:60@(D-O;G1I;G5E(@IM<V=S='(@(D1E=F%M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VL@061A;&%R_2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@
M(L=E<F5Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<'EA;&$B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(D)A
M\&QA;G3](&)A_F%R_7/]>B!O;&1U.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N
M(@IM<V=S='(@(E-EYVEM:2!+;W!Y86QA(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")+;W-T
M82!2:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G
M<W1R(")#;W1E(&0G279O:7)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`BW6QE=&D@4$=0(&EL92#^:69R96QE;F5M961I+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@
M(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("+=;&5T:2!0
M1U`@:6QE(&EM>F%L86YA;6%D_2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R
M>7!T(&UE<W-A9V4N(@IM<V=S='(@(MUL971I(%,O34E-12!I;&4@<VEF<F5L
M96YE;65D:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(MUL971I(%,O34E-12!I;&4@:6UZ86QA;F%M863]+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S_2!E:VQE;F5M961I+B`E<R(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@<W5N=6-U<W5N82!B8?!L
M86[];&%M863]+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(DQ$05`@<W5N=6-U<W5N82!B8?!L86[];&%M863]+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC
M92X@)7,B"FUS9W-T<B`B0F%K:7EE(&1E;F5T;&5N96UE9&DN("5S(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B4TU"('-U
M;G5C=7-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(B<E<R<@<W5N=6-U;F$@1E10('EO;'5Y;&$@8F'P;&%N_6QA
M;6%D_3H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")$8?#]=/UM
M(&QI<W1E<VD@>6%R873];&%M863]+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+B(*;7-G<W1R(")01U`@=F5R:7-I;FEN(/YI9G)E<VD@Y_9Z
M_&QE;65D:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM
M<V=S='(@(E,O34E-12!V97)I<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S_2!S:6QI;F5M961I
M+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D1A\/UT_6T@;&ES
M=&5S:2!S:6QI;F5M961I+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M07EA<B!G_&YC96QL96UE(&)E=&GP:2`G)7,G('-I;&EN96UE9&DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R
M(")!;/UC_6[];B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!B96QI<FQE;F5M
M961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D
M<F5S<R!B;V]K+B(*;7-G<W1R(")!9')E<R!D969T97)I('1A;6%M96X@9V5T
M:7)I;&5M961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S
M:2!T86UA;65N(&=E=&ER:6QE;65D:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RXB"FUS9W-T<B`B1&'P_73];2!L:7-T96QE<FEN:6X@;&ES=&5S:2!T86UA
M;65N(&=E=&ER;&5M961I+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B4W1R871E:FD@)R5S
M)R!Y_&ML96YE;65D:2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B;6MD:7(@)R5S
M)R!B8?YA<OUS_7H@;VQD=2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(D%N86AT87(@<W5N=6-U
M<W5N9&%N(&'G_6L@86YA:'1A<B!E9&EN:6QE;65D:2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(B<E<R<@
M>6%Z_6QM86L@:>=I;B!AY_UL86UA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(E<R!AY_UL86UA
M9/TN(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B36%I;G1E;F%N8V5?
M5&%S:R!B:7)I;6D@)7,@8>?];&%M863]+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!D:7II;FD@8>?]
M;&%M863]+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M3$1!4"!S=6YU8W5S=2!A<F%N86UA9/TN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E860@)7,N(@IM<V=S='(@(B5S(&]K=6YA;6%D_2XB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T
M(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3
M;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(MUS=&5N96X@
M:W5L;&%N8_T@:>=I;B!P87)O;&$@<_UF_7)L86YA;6%D_2X@0F%Z_2!Y861A
M('3\;2!A>7+];G3];&%R(&1O\')U("(*(F1E\&EL+B!996YI9&5N(&1E;F5Y
M:6X@>6%D82!D86AA(&9A>FQA('EA<F3];2!IYVEN('-I<W1E;2!Y]FYE=&EN
M:7IL92`B"B)G]G+\_OQN+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T
M<B`B04-,(&5R:?YI;&5M961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@
M(D%D<F5S(&1E9G1E<FEN92!E<FG^:6QE;65D:2X@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S:6YE(&5R:?YI;&5M
M961I+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(D1A\/UT
M_6T@;&ES=&5L97)I;F4@97)I_FEL96UE9&DN("5S(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B4W5N=6-U
M;G5N('EE=&5N96ML97)I;F4@97)I_FEL96UE9&DN(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")987#];&%N9/UR;6$@9V5R:2!D]FYD_'+\
M;&5M961I+BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S
M='(@(G)M9&ER("5S(.=A;/W^=/UR_6QA;6%D_2XB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!Y87#];&%N
M9/UR;6$@:V%Y9&5D:6QE;65D:2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B665D
M96L@8FER('EA</UL86YD_7)M82!K87ED961I;&5M961I+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@
M(EEE9&5K(&)I<B!Y87#];&%N9/UR;6$@:V%Y9&5D:6QE;65D:3H@)7,B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B07EA<B!G_&YC96QL96UE(&)E=&GP
M:2!K87ED961I;&5M961I.B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(EEE
M9&5K('EA</UL86YD_7)M82!D;W-Y87/]("5S(&MA>61E9&EL96UE9&DN(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS
M('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY
M('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B)987#];&%N9/UR
M;6$@9&]S>6%S_2`E<R!K87ED961I;&5M961I+B!"=2!D=7)U;61A+"!K;V1U
M('1E:W)A<B`E<R!IYVEN92`B"B)K87ED971M96L@>6%D82!T86MI<"!E9&5N
M(&MO9'4@96P@:6QE("5S(&GG:6YE(&MO<'EA;&%M86LL('-EYV5N96ML97)I
M;FD@(@HB:W5L;&%N86)I;&ER<VEN:7HN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+B(*;7-G<W1R("),1$%0('-U;G5C=7-U(&%R86YA;6%D
M_2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")"
M8?`@Y_9Z_&QE;65D:3H@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(MUL971I
M_FEM(&YO:W1A<_T@9_QN8V5L;&5N96UE9&DN("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B1&'P_73];2!L:7-T97-I(&?\;F-E;&QE;F5M961I
M+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I
M;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B)R5S)R!IYVEN('EA</UL86YD
M_7)M82!Y87K];&%M863].B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*
M(DUO>FEL;&$@:V5N87(@YW5B=?!U(&)U;'5N86UA9/TN($ME;F%R(.=U8G7P
M=6YU;B!AY_UK(&]L9'7P=6YD86X@96UI;B!O;'5N+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B<E<R<@9&EZ:6YI(&GG:6X@)R5S)R!K=6QL86[]8_US_2!T
M86MI<"!E9&5N(&AA:VQA<OT@=F5R96UE9&DZ("5S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S
M='(@(E-A>?UL;?W^(&UE=&EN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`BW&QK92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B1&5R<VQE<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E
M(@IM<V=S='(@(EEA<F%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK
M(@IM<V=S='(@(D)A\&QA;G3]('EA<F%T(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N
M92(*;7-G<W1R(")996YI(%EA<F%T(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R
M<R(*;7-G<W1R(")!;'0@9&EZ:6X@>6%R870B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N
M<R(*;7-G<W1R(")987)A=/UC_2#=>FEN;&5R:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*
M;7-G<W1R(")+<F5D:2!K87)T(&YU;6%R87/](@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(D-R;V%T:6$B"FUS9W-T<B`B2/UR=F%T:7-T86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#=6)A(@IM<V=S='(@(DO\8F$B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`BWG4@06YD86MI($5V<F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B
M66%R873]8_T@W7II;FQE<FDB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L
M:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G
M<W1R("+>=2!!;F1A:VD@6F%M86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@
M55),(&ES(@IM<V=S='(@(MYU(&%N9&%K:2!54DPB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS
M9W-T<B`BWG4@06YD86MI($5V<F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`BWG4@06YD86MI
M($AA=F$@1'5R=6UU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("+>=2!!
M;F1A:VD@WF%R=&QA<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@
M(EG\<OQR;/QK=&5K:2!S:71I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(E<R!E(&=I<FG^=&4@
MYV%L_?YA8V%K(&?V<F5V;&5R:2!K:?YI<V5L;&7^=&ER:6XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*
M;7-G:60@(D-U="(*;7-G<W1R(")+97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N
M(@IM<V=S='(@(MYEYVEL:2!O;&%N;&%R_2!K97,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B2_UB<OUS(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(DMI<FEL("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*
M;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMI<FEL
M("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")+
M:7)I;"]5:W)A>6YA("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`BQV5K($-U;6AU<FEY971I(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1T<B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY
M(@IM<V=S='(@(D?\;FS\:R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM
M<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")697)I($'P86/](%1A
M<F%Y_6/]<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS
M9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(E1A<FEH(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1V5L:?X@5&%R:6AI(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I
M;VXB"FUS9W-T<B`B5&%R:6@@4V7G:6UI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S(R"FUS9VED(")$87DB"FUS9W-T<B`B1_QN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R(")+7V]L;VYU(%-I;"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E
M;6)E<B(*;7-G<W1R(")!<F%L_6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`B3VYD86S]:R!S87G];&%R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(D=I<FEN=&EY:2!!>F%L="(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z
M,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(M9N('1A;OUM;/TB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I
M9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("+6;B!486[];6S](%)E;FLB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$
M969A=6QT($ED96YT:71Y(@IM<V=S='(@(M9N(%1A;OUM;/T@2VEM;&EK(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$
M969A=6QT(%-H96QL(@IM<V=S='(@(M9N('1A;OUM;/TB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@
M(E1A;OUM;&%R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-I;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B2/QC<F4@4VEL
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR
M,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")'<G5P(%-I;"(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E($QO9R(*;7-G<W1R(")3873]<OT@<VEL(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T
M<B`BW7II;B!3:6PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*
M;7-G<W1R("+=;&5T:6QE<FD@<VEL('9E('1E;6EZ;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED
M(")$96QE=&4@8V5L;"(*;7-G<W1R(")(_&-R92!3:6PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED
M(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(DMO;&]N(%-I;"(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(E9A<F]L86X@]G1E:VD@=&%S;&'P
M_2!S:6PB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(B"FUS9W-T<B`B)R5S)R!IYVEN(&EZ:6YL97)I('-I;"(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B)R5S)R!I
MYVEN(&EZ:6YL97(@=F4@86QT(&EZ:6YL97(@<VEL:6YS:6X@;6D_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3873]<OT@<VEL(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E-EYVEL;6G^(&MI
M;6QI\&D@<VEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN(@IM<V=S='(@(MYU(&%N9&%K:2!K;VQO;G4@<VEL(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(MYU(&%N
M9&%K:2!S873]<OT@<VEL(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")+=7)U;'5M(&?\;F-E
M;&QE;64@8F5T:?!I("<E<R<@<VEL:6YD:2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS
M9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(E1E<VQI;2!Z86UA;OTB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1A;FEM87)K82(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$
M97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")3;W)U;G4@5&%N_6UL87G]
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$
M97-C<FEP=&EO;B(*;7-G<W1R(")!Y_UK;&%M82(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(D%Y<OUN=/UL87(@*$%Y;OT@>F%M
M86YD82!(;W)D92=U;B!G_&YL_&L@9&]S>6%S_6[];B!IYVEN9&4I.B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R(")!>7+];G3];&%R('GV;F5T:6-I(&GG:6X@9_QN;/QK(&]L87)A:R!K
M87ED961I;&1I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*
M;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D=E;&G^:6TB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@
M(DYE;2!-:6MT87+](@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G
M:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4V]N('-A
M871T96MI(&YE;2!M:6MT87+].B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(").96T@
M;6EK=&%R_3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS
M9W-T<B`B4V]L9&%N('-A\&$@>?9N;/PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F="(*;7-G<W1R(")38?!D86X@<V]L82!Y]FYL_"(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`B1&EZ:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED
M(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(C(T('-A871L:6L@
M>F%M86X@;?T@9_9S=&5R:6QS:6X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B1_9R_&YT
M_&QE;64@4V7G96YE:VQE<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R
M96-A<W0B"FUS9W-T<B`B2&%V82!T86AM:6YI;FD@9_9R_&YT_&QE("A4048I
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F
M;W)E8V%S="`H5$%&*2(*;7-G<W1R(")(879A('1A:&UI;FEN:2!G]G+\;G3\
M;&4@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS
M9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")']G+\;G3\;&5M92!":>=I
M;6DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B1/QZ96X@0FEL
M9&ER:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B
M0VEB=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*
M;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B4VEL;65Y:6XB"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(FUA:6YT96YA
M;F-E+G!H<"!D;W-Y87/];F$@9&_P<G5D86X@97)I_FUE>6EN+B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM
M<V=S='(@(MUL:R!S873]<B!A;&%N(&%D;&%R_6[](&GG97)I>6]R(&UU/R!%
M=F5T(&ES92!B=2!K=71U>74@<V7G:6XZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI:R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEK($-U;6AU<FEY
M971I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@
M(D1O=VYL;V%D(@IM<V=S='(@(MUN9&ER(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O
M=VYL;V%D("5S(@IM<V=S='(@(B5S(-UN9&ER(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B3VQU_G1U<G5L86X@
M>6%P_6QA;F3]<FUA>?T@4$A0(&)E=&GP:2!O;&%R86L@:6YD:7(N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N
M(&QI<W0B"FUS9W-T<B`B0?YA\/T@8>?];/UR(&QI<W1E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("+=;&'G
M;&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")%+4UA:6PB"FUS9W-T<B`B12U0;W-T82(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5C=6%D;W(B"FUS9W-T<B`B16MV871O<B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET(@IM<V=S='(@(D3\>F5N;&4B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*
M;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B0FQO:R!$_'IE;FQE(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G
M:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B1W)U<"!$_'IE;FQE(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S
M='(@(MUZ:6X@1/QZ96YL92(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`BW7II;FQE
M<FD@1/QZ96YL92(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B)7,@W>=I;B#=>FEN;&5R:2!$_'IE;FQE(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB
M"FUS9W-T<B`B4V7G96YE:VQE<FD@9/QZ96YL93HB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B5S
M(&GG:6X@:7II;FQE<FD@9/QZ96YL92(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@:>=I;B!I>FEN;&5R:2!D_'IE;FQE
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I
M;VXB"FUS9W-T<B`B1?!I=&EM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B
M"FUS9W-T<B`B3?US_7(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H
M96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS
M9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB
M"FUS9W-T<B`BUO!E+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R
M(")%;&5K=')O;FEK(%!O<W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S=&$@
M061R97-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I
M9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D5L96MT
M<F]N:6L@<&]S=&$@87-R97-L97)I(&7^;&7^;65L:2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I
M<FUA=&EO;B(*;7-G<W1R(")/;F%Y;/T@96QE:W1R;VYI:R!P;W-T82(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS
M9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED(")%
M;6]T:6-O;G,B"FUS9W-T<B`B1'5Y9W4@<VEM9V5R;&5R:2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I
M9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B0F_^(&EL971I+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G
M:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B0F_^('-O;G7G+B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y
M('-E87)C:"!T97)M<R(*;7-G<W1R(")";_X@87)A;6$@=&5R:6UL97)I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\B"FUS9W-T<B`B(@HB1F]T;_!R868@1V%L97)I<VEN9&5N(&UE=&EN;&5R
M:6X@:>=E<FES:6YE(&?V<OQN=/P@96ML96UE(&5T:VEN;&7^=&ER:6QS:6X@
M(@HB;6D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B4V'P
M('3]:R!IYV5R:6L@;65N_'/\(&5T:VEN;&7^=&ER:6QS:6X@;6D_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")":71I_B!Y
M_6S](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B1/QZ96YL97EI
M8VEY:2!'96YI_FQE="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*
M;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U
M('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.B(*;7-G<W1R("(B"B)087)O;&%N_7K]('/]9OUR;&%M86L@:7-T961I\&EN
M:7ID92!S;W)U;&UA:R#\>F5R92!B:7(@9_QV96YL:6L@<V]R=7-U("(*(F=I
M<FEN+"#6<BX@)T5V8VEL(&AA>79A;OUN_7K];B!A9/T@;F5D:7(_)SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G
M<W1R(")']G+\;G3\(&%D<F5S:6YI(&)U<F%Y82!G:7)I;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N
M=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")%:W9A=&]R($=I
M;F5S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I
M=')E(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B2&%T82(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T
M<B`B66%N_73](&?V;F1E<FUE9&4@:&%T83H@)7,N(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T
M<B`B66%N_73](&?V;F1E<FUE9&4@:&%T83H@)7,N(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B
M66%N_73](&?V;F1E<FUE9&4@:&%T83H@)7,N(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B66%N_73]
M(&?V;F1E<FUE9&4@:&%T83H@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H
M(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D5L971R;VYI:R!P;W-T82!D]FYD
M97)M961E(&AA=&$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM
M<V=S='(@(B<E<R<@>6%Z87)K96X@:&%T82XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N>6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R(")%=&EY;W!Y82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FEK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O
M<&4B"FUS9W-T<B`B079R=7!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")(97(@,34@
M9&%K:6MA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B
M179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(DAE<B`R(&1A:VEK82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")(97(@,S`@
M<V%N:7EE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS
M9W-T<B`B2&5R(#4@9&%K:6MA(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`B2&5R($=I<FG^=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P
M"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B2&5R('EA<OUM('-A
M870B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")(
M97(@9&%K:6MA(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*
M;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("+6<FYE:R!D9?!E<FQE
M<CHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN
M<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B
M"FUS9W-T<B`BQV%L_?YT_7(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")'96YI_FQE
M="(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@
M(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(DME;F%R(,=U8G7P=6YU($=E;FG^
M;&5T(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM
M<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B<I)R!"96ML96YI>6]R(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G
M<W1R(")3861E(&ME;&EM92!V97EA(&%L_6YT_2!A<F%M82!T97)I;6D@8F5K
M;&5N:7EO<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D=EYV5R;&EL:6L@
M4V]N(%1A<FEH:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("+<<W0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS
M9VED(")&1R!#;VQO<B(*;7-G<W1R("+6;B!!;&%N(%)E;F=I(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R(")!>6%R;&%R(&GG:6X@1E10('G\:VQE;65S:2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(E1E<F-I:&QE
M<FEN(&=E=&EL;65S:2!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("),1$%0('-U;G5C=7-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B4TU"
M('-U;G5C=7-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@:V]N
M=6UU;F1A;B!K;W!Y86QA;6$@8F'^87+]<_UZ+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YA
M(&MO<'EA;&%M82!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+B(*;7-G<W1R(")996YI(%-!4TP@8F'P;&%N=/US_2!O
M;'7^='5R=6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@
M(EPB)7-<(B!K;VYU;75N82!T8?[];6$@8F'^87+]<_UZ+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(EPB)7-<
M(B!K;VYU;75N82!T8?[];6$@8F'^87+]<_UZ+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S
M='(@(E5Y9W5N($AA=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)
M<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F0@061A;&%R_2`H
M36%L=FEN82DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM
M<V=S='(@(D9A<F]E($%D86QA<OTB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B3VYU;&UA>B!(
M871A.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS
M9W-T<B`B1F%K<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("+>=6)A="(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM
M<V=S='(@(DAI<W-E9&EL:7EO<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")(:7-S
M961I;&EY;W(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")(869I9B!3
M8?!A;F%K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B2&%F:68@
M2V%R(%-A\&%N8?#](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(D%L86X@;6%T<FES:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE
M="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*
M;7-G<W1R(")D;W-Y82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS
M9W-T<B`B1&]S>6$@4V%Y_7/].B`E<R!D;W-Y82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&5S(@IM<V=S='(@(D1O<WEA(%-A>?US_3H@)7,@9&]S>6$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B1&]S>6$@6?9N971I8VES:2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&:6QE($YA;64B"FUS9W-T
M<B`B1&]S>6$@063](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY
M-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B1&]S>6$@<V7G:6UI
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL
M92!U<&QO860B"FUS9W-T<B`B1&]S>6$@>?QK;&5M92(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S
M(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D1O<WEA('G\:VQE;64@9&5S=&5K
M;&5N;6EY;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS
M9VED(")&:6QT97)S(@IM<V=S='(@(E/\>F=EYVQE<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N9&EY82(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
MW6QK(%EA<OTB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(MUL
M:R#'97ER96LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B3W)A;OT@<V%B
M:71L92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`BQV5V:7(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED
M(")&;&]A="(*;7-G<W1R(")+87EA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B4VES
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B)7,@9&EZ:6YI('EO
M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B66%Z_2!296YG:2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M(")996UE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B1_9R_&YT_&QE<FD@9&5S
M=&5K;&5M97EE;B!T87)A>?UC_6QA<B!IYVEN(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(E1A
M:&UI;B`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW
M.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B
M"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*2(*;7-G<W1R("(B"B)486AM:6X@1_QN;&5R:2`H3F]T.B!'97)I(&3V
M;OQL96-E:VQE<B!H96T@9_QN(&AE;2!G96-E(&]L87)A:R!D]F[\;&5C96L[
M("DB"B)B_'G\:R!B:7(@<V%Y_2!G96YI_B!B:7(@]F)E:VQE('-O;G7G;&%N
M86-A:W3]<BDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM
M<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(E!A<F]L86[]
M>OT@;?T@=6YT='5N=7H_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;6QA<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")$
M97EI_B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R
M='5N92!T>7!E(@IM<V=S='(@(D1E>6G^('3\<OPB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D1E>6G^
M;&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T
M=6YE<R`R(@IM<V=S='(@(D1E>6G^;&5R(#(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R=6UL
M87(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R(")9]FYL96YD:7)M96QE<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM
M<V=S='(@(D-U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(L=E<N=E
M=F5L97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A
M;G-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N<V$L($UE<G1O
M<&]L:71A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS
M9W-T<B`B1G)A;G/]>B!'=7EA;F%S_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&
M<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R86YS_7H@4&]L:6YE>GEA<_TB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<R(*;7-G<W1R(")&<F%N<_UZ($?\;F5Y($+V;&=E<VDB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&
M<F]M(@IM<V=S='(@(DMI;61E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B2VEM9&5N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B5&%M($)E=&EM;&5M92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T
M<B`B1&]L=6YA>2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA
M;64B"FUS9W-T<B`B0>?]:R!!9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N
M(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")']G+\;G3\;&5R:6X@86S];F%C
M8?#](&=A;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T
M<B`B1V%L97)I.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R
M(")'86UB:7EA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(B5S(%EA</UL86YD_7)M87/];OT@3VQU_G1U<B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T
M960@0V]D92(*;7-G<W1R(")/;'7^='5R=6QA;B!+;V0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D?\<F-I<W1A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B06QM86YY82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=A;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B0V5B96QI=&%R_6LB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R(")697)I;&5N($%D(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(D=I="(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O
M961E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")'
M;V]G;&4@07)A;6$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS
M9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92!!<F%M82(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G
M:60@(D=R87ES8V%L92(*;7-G<W1R(")3:7EA:"!"97EA>B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B675N86YI<W1A;B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM
M-RDB"FUS9W-T<B`B675N86YC82`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W+V;FQA;F0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B1W)U<"!9]FYE=&EM:2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V
M.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T
M<B`B1W)U<"!I<VEM;&5R:2!D;VQU(&]L;6%L_63]<B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H
M7VEM87`Z("5S(&MU;&QA;OUC_7/](&5K;&5N96UE9&DN(%-U;G5C=3H@(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.B`E<R!K=6QL86[]8_US_2!G_&YC96QL96YE;65D
M:2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G
M<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/](&?\
M;F-E;&QE;F5M961I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P
M;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'
M=6%D86QU<"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U
M86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U
M871E;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G
M:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B2V]N
M=6L@W7II;FQE<FDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P
M"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B2V]N=6L@1&5F=&5R:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")':6YE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE($)I
M<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U
M>6%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B
M2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M(@IM<V=S='(@(DA434Q!<F5A('-A=/UR9&%K:2!S;VX@:/QC<F5Y:2!S:6QM
M97EI(')E9&1E9&EY;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE
M+B(*;7-G<W1R(")(5$U,07)E82#G:7IE;&=E9&5K:2!S;VX@:V]L;VYU('-I
M;&UE>6D@<F5D9&5D:7EO<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M(@IM<V=S='(@(DA434Q!<F5A(.=I>F5L9V5D96MI('-O;B!S873]<OT@<VEL
M;65Y:2!R961D961I>6]R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T
M<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B2%144"!+:6UL:6L@1&5N971I;6D@8G5L86YA;6%D_2XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(
M87-H+4%L9V]R:71H;2(*;7-G<W1R(")(87-H($%L9V]R:71M87/](@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@
M(DAA>F4B"FUS9W-T<B`B2&%F:68@4VES(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G
M:60@(DAE861E<B(*;7-G<W1R(")"8?YL_6LB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(
M96%D97)S(@IM<V=S='(@(D)A_FS]:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE
M87)D($%D87/]('9E($UC1&]N86QD($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PHC+"!F=7IZ>0IM<V=I9"`B
M2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")']FL@9_QR_&QT_&S\(&;]<G3];F$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)
M4T\M.#@U.2TX+4DI(@IM<V=S='(@(MUB<F%N:6-E("A)4T\M.#@U.2TX+4DI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(EG\:W-E:VQI:R(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B
M2&5L<"(*;7-G<W1R(")987)D_6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O
M<B(*;7-G<W1R(")$_'IE;FQE>6EC:2!K=6QL87)A:R!Y87)D_6TB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS
M9W-T<B`B66%R9/UM8_TB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G
M:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B66%R_6O\<F4B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.B(*;7-G<W1R(")$;W-Y86[];B!B8?YL86YG_6/].B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG
M:"(*;7-G<W1R(")9_&MS96LB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G
M:60@(DAO7VUE(@IM<V=S='(@(E]!;F%S87EF82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@
M(E9A=&EK86XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*
M;7-G:60@(DAO;64B"FUS9W-T<B`B06YA<V%Y9F$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R(")%=B!!9')E<VDB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S
M='(@(D1I>FEN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")%=B!496QE
M9F]N=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B
M2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G
M<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@0G4@;65S86H@
M:>=I;F1E(&=EYV5R<VEZ("5S(%A-3"!V97)I<VD@:6QE(&MA<O[];&'^_6QD
M_3H@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R
M97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S
M(&YE<VYE<VD@:6QE(&EL9VEL:2!B:7(@:6QE=&D@8G5L=6YA;6%D_2(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!T_'+\
M;F1E(&AIYR!B:7(@;F5S;F4@)7,@;65S86K](&GG:6YD92!Y;VLN(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S(%PB)7-<(B!B8?YA<OT@
M:6QE('-I;&EN9&DB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R
M,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B
M(@HB2&]R9&4O2V]L86(Z($+\=/QN;&5M92!M;W1O<G4@)V1O;7AM;"<@4$A0
M('5Z86YT_7/];F$@:6AT:7EAYR!D=7EM86MT863]<B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@
M;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!N97-N97-I(&GG
M:6X@>65N:2!834P@8?!A8_T@;VQU_G1U<G5L86W]>6]R(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%-I;&EN96UE9&D@)7,@7"(E<UPB.B`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@)7,@=/QR_&YD96MI(&O]<_UM(&GG:6X@34E-12!)1"!B=6QU
M;F%M863](@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M1?YL96YE;65D:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M(")087EL8?[];6QA<B!E_FQE;F5M961I.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")":6QI;FUE
M>65N('!A>6QA_OUM(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*
M;7-G<W1R(")9871A>2#':7IG:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN
M9R(*;7-G<W1R(")9871A>2!Y87-T_6ML86UA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A
M;#HB"FUS9W-T<B`B66%T87DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")"=7)A>6$@
M;F%S_6P@9V5L9&EN:7H_("A,_'1F96X@<F%P;W(@961I;B$I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM
M<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`B2V'G(&%D970@:V]L;VYU(&)I<FQE_G1I<FUE:R!I<W1I
M>6]R<W5N=7H_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*
M;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*
M;7-G<W1R(")+8><@86QA;B`H:V]L;VXI('9A<C\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M(")+8><@861E="!S873]<OT@8FER;&7^=&ER;65K(&ES=&EY;W)S=6YU>C\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(").96TB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(
M=6UI9&ET>3H@(@IM<V=S='(@(DYE;3H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B36EZ86CG_6QA
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")-86-A
M<FES=&%N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B24U!4"!P;W-T82!K=71U<W4@;VQU_G1U<G5L86UA9/TZ("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B24U!4"!P;W-T82!K=71U<W4@<VEL:6YE;65D:3H@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))
M34%0('!O<W1A(&MU='5S=2!K;W1A<_T@;VQU_G1U<G5L86UA9/TZ("5S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R("))4"!!9')E<VDB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(DE0(&%D<F5S:2!M979C=70@9&7P:6PN("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(DE0($%D<F5S:2!I>FEN('9E<FEL96X@0TE$4B!B;&_P=2!IYVEN9&4@
M9&7P:6PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM
M<V=S='(@(DE0(&MI;&ET;&5M92!I:&QA;&DN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))
M7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`BUFY?8V5Y92!3873]<B!997)L
M9?YT:7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
MW7IL86YD82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@
M(DEC;VYS($]N;'DB"FUS9W-T<B`B4V%D96-E(%-I;6=E;&5R(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC
M;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!IYVEN('-I;6=E;&5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT
M(@IM<V=S='(@(DUE=&EN(&EL92!B:7)L:6MT92!S:6UG96QE<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M
M93HB"FUS9W-T<B`B2VEM;&GP:6X@863].B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(D7P97(@9&_P<G4@9_9R_&YT
M_&QE;F5M:7EO<G-A+"!Y96YI('!E;F-E<F5D92!AYVUA:R!IYVEN('3]:VQA
M>?UN("5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@
M(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T
M($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB1?!E
M<B!);G1E<FYE="!%>'!L;W)E<B!I;&4@<VEM9V5L97)I(&?V<F5M:7EO<G-A
M;OUZ(&)U(&MU='5Y=2!S9>=E<F5K(%!.1R`B"B)S87ED86UL_?#];OT@:V%P
M871M86[]>B!G97)E:VER+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*
M;7-G<W1R("(B"B)']G+\;G3\;&5R:2!G]G)E;6EY;W(@9F%K870@8G4@;65S
M86K](&?V<F5B:6QI<GEO<G-A;OUZ+"!Y_&ML96UE:R`B"B)I<W1E9&GP:6YI
M>B!G]G+\;G3\('1A<F%Y_6/];OUZ('1A<F%F_6YD86X@9_9S=&5R:6QE;65M
M96MT961I<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM
M<V=S='(@(D?V<OQN=/P@UFYI>FQE;64B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!5
M4DPB"FUS9W-T<B`B1_9R_&YT_"!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B1_9R_&YT_"!54DPZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B4V5R9VED96X@9_9R
M_&YT_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*
M;7-G<W1R(")397)G:61E;B!G]G+\;G3\.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")'
M]G+\;G3\('G\:VQE;65K(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*
M;7-G:60@(DEM86=E<R(*;7-G<W1R(")']G+\;G3\;&5R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`BW>=E<FD@06MT87(L($%D_6T@)60B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BW>=E<FD@
M86MT87+];&%N(&%L86XZ("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("+=YV5R
M:2!A:W1A<OUL86X@86QA;FQA<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@
M4F]W($%F=&5R(@IM<V=S='(@(E-O;E]R87EA(%-A=/UR($5K;&4B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@
M(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B66%N;/W^
M(&5Y;&5M(&MO9'4@9VER:6QD:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B66%N;/W^(&MU;&QA
M;OUC_2!A9/T@=F4O=F5Y82!P87)O;&$N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@HB66%N;/W^(&MU;&QA;OUC_2!A9/T@=F5Y82#V=&5K:2!A
M9')E<RY996YI9&5N(&1E;F5Y:6X@=F5Y82!D86AA(&9A>FQA('EA<F3];2`B
M"B)IYVEN('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S
M92!);F1E;G0B"FUS9W-T<B`B1VER:6YT:7EI($%R='3]<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B2&EN9&ES=&%N(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T
M<B`B0FER97ES96P@2W5L;&%N_6/];&%R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("));F1O;F5S:6$B"FUS9W-T<B`B16YD;VYE>GEA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*
M;7-G<W1R(")":6QG:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3<*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(D)I;&=I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`HC+"!F=7IZ>0IM<V=I9"`B
M26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B2&GG
M8FER('-EYV5N96L@;65V8W5T(&1E\&EL+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS
M97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B4V]N<F%Y82!+;U]L;VX@16ML
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(D?V
M<OQN=/P@665R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@
M(L=I>F5L9V4@665R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM
M<V=S='(@(E=E8B!"8?!L86YT_7/](%EE<FQE_G1I<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I
M9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(M9N8V5Y92!+;VQO
M7VX@16ML92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B665N:2!K;VQO;G4@_G4@
M86YD86MI(&MO;&]N9&%N('-O;G)A('EE<FQE_G1I<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(EEE;FD@:V]L;VYU(/YU(&%N9&%K:2!K;VQO;F1A;B#V;F-E
M>64@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")996YI('-A=/UR_2#^
M=2!A;F1A:VD@<V%T_7)D86X@<V]N<F%Y82!Y97)L9?YT:7(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R(")996YI('-A=/UR_2#^=2!A;F1A:VD@<V%T_7)D86X@]FYC
M97EE('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B665N:2!P87)A
M9W)A9OT@_G4@86YD86MI(&3\\/QM9&5N('-O;G)A>6$@>65R;&7^=&ER(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B665N:2!P87)A9W)A9OT@_G4@86YD86MI
M(&3\\/QM9&5N(/9N8V5Y92!Y97)L9?YT:7(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("+6=&5K:2!T87-L86L@>65R;&7^=&ER(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E
M<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z
M(@IM<V=S='(@(EEE;FD@8FER('!A<F%L;WG](&%L86)I;&5C9?!I;FEZ(&)I
M<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G:7)I;CHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED
M("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")(_&-R97EI('-O;G)A<_UN
M82!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B
M"FUS9W-T<B`B2/QC<F5Y:2#V;F-E<VEN92!Y97)L9?YT:7(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS
M9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DMO;&]N=2!S;VYR
M87/];F$@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B
M969O<F4B"FUS9W-T<B`B2V]L;VYU(/9N8V5S:6YE('EE<FQE_G1I<B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED
M("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B365S86H@9VER(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(E!A<F%G
M<F%F_2!S;VYR87/];F$@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R(")087)A9W)A9OT@]FYC97-I
M;F4@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*
M;7-G<W1R(")3873]<OT@<V]N<F%S_6YA('EE<FQE_G1I<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G
M:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(E-A=/UR_2#V;F-E<VEN
M92!Y97)L9?YT:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS
M9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ(@IM<V=S='(@(D?\=F5N;&EK('-O<G5S=6YU;B!C979A
M8OTZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R(")']G+\
M;G3\>?P@665R;&7^=&ER+T1E\&G^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF
M>2!,:6YK(@IM<V=S='(@(D)A\&QA;G3](%EE<FQE_G1I<B]$9?!I_G1I<B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VD@
M9_9N9&5R;65K(&GG:6X@>65T97)S:7H@:W)E9&DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(EEE=&5R<VEZ(&MR961I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R(")486US87G](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(E1A;7-A>?T@
M;&ES=&5S:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2XB"FUS9W-T<B`B1V7G97)S:7H@541(+B`H2W5L;&%N_6/](%9E
M<FD@0F'^;/UK($)I;&=I<VDI(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A
M=&$B"FUS9W-T<B`B1V7G97)S:7H@=6YI8V]D92!V97)I<VDN(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B1V7G97)S:7H@=7EG=6QA;6$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")'9>=E<G-I>B!Y_?#];B!K
M:6UL:?!I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B1V7G97)S:7H@
M=F5R:2!G]FYD97)I;&1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+B(*;7-G<W1R(")'9>=E<G-I>B!T97-L:6T@861R97-I
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I
M9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")'9>=E<G-I>B!D;W-Y
M82!B:>=I;6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R
M(")'9>=E<G-I>B!U>6=U;&%M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R(")'9>=E<G-I>B!U>6=U;&%M82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(D=EYV5R<VEZ(&US
M9U]T>7!E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED
M+B(*;7-G<W1R(")'9>=E<G-I>B!Y861A(&%T;&%N;?W^(&%P:5]I9"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S
M='(@(D=EYV5R<VEZ('EA9&$@871L86YM_?X@9&7P:?YT:7)G96QE<B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1V7G97)S:7H@_'-T(&EZ:6XN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(")'9>=E<G-I
M>B#\<W0@:7II;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<U"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS
M9W-T<B`B1V7G97)S:7H@:6QE=&G^:6T@:W5R86QL87+](@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED
M("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")'9>=E<G-I>B!I;&5T:?YI
M;2!K=7)A;&QA<OTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I
M<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")'9>=E<G-I>B!A;/UC_3H@)R5S)R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J
M96-T(@IM<V=S='(@(D=EYV5R<VEZ('!A>6QA_OUL86X@;F5S;F4B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*
M;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D=EYV5R
M<VEZ(&MA>6YA:R!A9')E<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O
M9&4@9&%T82XB"FUS9W-T<B`B1V7G97)S:7H@=6YI8V]D92!V97)I<VDN(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(E-T;VLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U>GIY"FUS9VED("));G9E<G0@<V5L
M96-T:6]N(@IM<V=S='(@(MYEYVEL:2!O;&%N;&%R_2!K97,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`BW7)A;B#=<VQA;2!#=6UH=7)I>65T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M<F5L86YD(@IM<V=S='(@(MUR;&%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B36%N
M($%D82!$979L971I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@
M(EEA;/UT_6QM_?X@9_9K(&?\<OQL=/QL_"!F_7)T_6YA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`BW7-R86EL(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*
M;7-G<W1R("+'_6MA<F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`BW71A;&EK
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("+==&%L>6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EK
M82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U
M"FUS9VED(")*86YU87)Y(@IM<V=S='(@(D]C86LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N>6$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*
M;7-G<W1R(")*87!O;F-A("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@
M8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M
M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R
M<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R
M9&%N(@IM<V=S='(@(MQR9/QN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B5&5M;75Z
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*
M;7-G:60@(DIU;F4B"FUS9W-T<B`B2&%Z:7)A;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`B66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#
M96YT97(B"FUS9W-T<B`B3W)T87EA(%EA<VQA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU
M<W1I9GD@1G5L;"(*;7-G<W1R(")486UA;65N(%EA<VQA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")3;VQA(%EA<VQA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*
M;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B4V'P82!987-L82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:VES
M=&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`BUGIG_&X@;VQA
M;B!S86ML86YS_6X@;?T_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R(")+96YY82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@<W5N=6-U(&1O\')U;&%M87G]
M(')E9&1E='1I+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I
M9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`BQV5K:7)D96L@06-E;6EL97)I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@0W)E871I;VXB"FUS9W-T<B`B06YA:'1A<B!987)A="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(D%N86AT87(@4&%R;6%K:7II(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N
M9W1H(@IM<V=S='(@(D%N86AT87(@57IU;FQU\'4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S
M='(@(D%N86AT87(@5&EP:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DX"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B06YA:'1A
M<B!+=6QL86[];?TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B0>?]:R!A;F%H=&%R('-U;G5C=7-U;F1A
M(&%N86AT87(@>F%T96X@=F%R+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("+';V-U:VQA<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DMU>F5Y($MO<F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")'_&YE>2!+;W)E
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H
M155#+4M2*2(*;7-G<W1R(")+;W)E8V4@*&5U8RU+4BDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=79E>70B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2_UR9_UZ:7-T86XB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B
M"FUS9W-T<B`B4V%Y9F$@7T3\>F5N:2(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(D1I;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,B"FUS9W-T<B`B3&%O($1E;6]K<F%T:6,@2&%L:R!#=6UH=7)I>65T
M:2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L
M9B(*;7-G<W1R(")3;VX@1/9R9/QN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*
M;7-G<W1R(")087)O;&%Y_2!S_6;]<FQA(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(MYI_FMI;B!!>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E-O;B!'_&YC
M96QL96UE.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")3;VX@
M1VER:?XZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS
M9W-T<B`B4V]N($=I<FG^.B`E<R#\>F5R:6YD96X@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R
M(@IM<V=S='(@(E-O;B!':7)I_CH@07-L82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&%T=FEA(@IM<V=S='(@(DQE=&]N>6$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R(")987-A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS
M9VED("),87EO=70B"FUS9W-T<B`B1/QZ96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(DAIYV)I<B!S_6[]<B!IYVEN(&)O
M_B!B_7)A:VUA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S
M='(@(DS\8FYA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")3;VPB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R(")3;VP@8F'^;/UK(&)I;&=I<VDB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A;'5E<R(*;7-G
M<W1R(")3;VQD86MI(&1E\&5R;&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@
M(D'^:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),
M:6)E<GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA
M:&ER:7EA(@IM<V=S='(@(DQI8GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG
M:'0@1')I>GIL92(*;7-G<W1R("+':7-E;&EY;W(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I
M;B(*;7-G<W1R(")(869I9B!98?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L
M>2(*;7-G<W1R(")%<FME;B!386%T;&5R9&4@2&%F:68@66'P;75R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@
M(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")'9><@4V%A=&QE<F1E($AA9FEF
M(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")(869I
M9B!98?!M=7(@4V'P86YA\/TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(B"FUS9W-T<B`B1_9K(&?\<OQL=/QL_"!H869I9B!Y8?!M=7(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B
M3&EG:'0@4VYO=R(*;7-G<W1R(")(869I9B!+87(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO
M=R!3:&]W97(B"FUS9W-T<B`B2&%F:68@2V%R(%-A\&%N8?#](@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R
M(")._&MT96QI(-YI:7(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#$T"FUS9VED("),:6YK(@IM<V=S='(@(D)A\&QA;G3](@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS
M9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B0F'P;&%N=/T@;F]K=&%S
M_3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),
M:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE
M;B!D:7-P;&%Y:6YG(@IM<V=S='(@(D?V<OQN=/QL97)K96X@96QE:W1R;VYI
M:R!P;W-T82!A9')E<VEN:2!O;'7^='5R;6$@<V%Y9F%S_6YA(&)A\&QA(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B0F'P;&%N=/UL87(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("),:6YU>"#'97)E>FDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W1E;&4@+2!K=6QL86[]8_T@9&EZ
M:6YI(&?V<F5B:6QI<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G
M:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(E9E<FD@5&%B86YL87+];OT@
M3&ES=&5L92(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED
M("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(EEA<F3];2!+;VYU;&%R_6[]
M($QI<W1E;&4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),
M:7-T(%1A8FQE<R(*;7-G<W1R("+':7IE;&=E;&5R:2!,:7-T96QE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI
M<W0M07)C:&EV92(*;7-G<W1R("),:7-T96QE+4%R_FEV(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L
M<"(*;7-G<W1R("),:7-T96QE+5EA<F3];2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@
M(DQI<W1E;&4M260B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T96QE+5-A
M:&EP(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*
M;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:7-T96QE+4?V;F1E<FEL;6G^
M(-;P96QE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T96QE+5/\
M<F3\<OQM8_QL97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T
M96QE+5/\<F3\<OQM8_P@3VQM87EA;FQA<B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S
M97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(DMU;&QA;OUC_2!L:7-T96QE
M;64@<V7G:6QE;65Z(&O];/UN9/TN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B2W5L;&%N_6/](&QI<W1E;&5M92!S9>=I
M;&5M97H@:_UL_6YD_2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(DMU;&QA;OUC_2!L:7-T96QE;64@<V7G:6QE;65Z(&O];/UN9/TN
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T
M=7)E(@IM<V=S='(@(D5D96)I>6%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:71H=6%N:6$B"FUS9W-T<B`B3&ET=F%N>6$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN
M(@IM<V=S='(@(EG\:VQE;FEY;W(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B
M665R96P@>F%M86XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS
M9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B665R('9E(%IA;6%N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R(")997(B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B
M1VER:?XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G
M:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R("+'_6O]_B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B1VER:?XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K
M<R(*;7-G<W1R(")':7)I_B!']G)E=FQE<FDB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO
M=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T
M;'DN(@IM<V=S='(@(DMU;&QA;OUC_2!A9/T@=F5Y82!P;W)O;&$@9&_P<G4@
M;VQM863]\/T@:>=I;B!G:7)I_B!B8?YA<OUS_7H@;VQD=2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`B1VER:?X@8F'^87+]<_UZ(&]L9'4N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@
M(E5Z=6X@;65T:6XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G
M:60@(DQO=F4B"FUS9W-T<B`B0?YK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R(")$_/[\
M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T
M<B`B2_SG_&L@>75N86X@:&%R9FQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E
M<B!L871I;B!L971T97)S(@IM<V=S='(@(DO\Y_QK(&QA=&EN(&AA<F9L97)I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M(")+_.?\:R!R;VUA(')A:V%M;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("),_&MS96UB=7)G(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")!02(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]4
M1"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V
M"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(DU3+51.148@16MI('9E<FD@:>=E<FUE;65K=&5D:7(N(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86ME9&]N>6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T
M<B`B0OQY_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I
M9"`B36%I;"(*;7-G<W1R(")0;W-T82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B4&]S=&$@
M6?9N971I8VES:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G
M<W1R(")"8?!L85]N=/T@66%R870N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;&%W:2(*;7-G<W1R(")-86QA=FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&5Z>6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=FQE<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T
M<B`B(@HBUO!E;&5R:2!E=&EK971L97EE8V7P:6YI>B!K871E9V]R:2!L:7-T
M97-I;FD@=F4@:V%T96=O<FEL97)I("(*(FEL:?YK:6QE;F1I<F5C9?!I;FEZ
M(')E;FML97)I('GV;F5T:6XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M(")-87`R-"!H87)I=&%S_2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T
M<B`B36%P475E<W0@:&%R:71A<_TB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*
M;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<G0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G
M:6XB"FUS9W-T<B`B2V5N87(@8F_^;'7P=2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B3VMU;FUU_B]/:W5N;6%M_?X@;VQA
M<F%K(&G^87)E=&QE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG
M+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(D1I\&5R(&EL971I(&G^
M87)E=&QE<FEY;&4@:?YA<F5T;&4@*/9R;F5K.B#6;F5M;&DO0V5V87!L86YM
M_?XI("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*
M;7-G<W1R(")-87)S:&%L;"!!9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEK(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*
M;7-G<W1R(")%_FQE;&5N(&%L86YL87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DUA=7)I=&%N:6$B"FUS9W-T<B`B36]R:71A;GEA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET=7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G
M:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`BW7II;B!V97)I;&5N
M(&5N('G\:W-E:R!K<F5D:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A
M<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")%;B!Y_&MS96L@;65S86H@<&%RYV%S
M_2!S87G]<_T@8?[];&3]+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V
M"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B4V]N
M(#(T('-A871T96MI(&5N('G\:W-E:R!S_6-A:VS]:SH@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(E-O;B`V('-A871T96MI(&5N('G\:W-E:R!S_6-A:VS]
M:SH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU
M;2!L96YG=&@B"FUS9W-T<B`B16X@>?QK<V5K('5Z=6YL=6LB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y
M(@IM<V=S='(@(DUA>?US(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T
M92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")4_7`B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM
M<V=S='(@(MQY96QE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*
M;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N_"!+:7!I.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*
M;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(DC\8W)E;&5R:2!B:7)L9?YT
M:7(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+=;&5T:2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B
M"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS
M9W-T<B`B(@HBW6QE<FD@8F'^87+]>6QA(&1O\')U;&%N9/T@86UA(&EM>F%L
M87G]8_UN_6X@;VYA>2!B96QG97-I(&1O\')U;&%N86UA9/TN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS
M9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE<V%J_6X@<_QR97-I
M(&)I='1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*
M;7-G<W1R(")-97-A:B!T:7!I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(DAA=F$@4F%P;W)U(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B2&%V82!R87!O<G4@]F)E\&D@:W5L
M;&%N_6QA8FEL:7(@9&7P:6PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*(DAA=F$@<F%P;W)U(/9B9?!I(&MU;&QA;OUL86)I;&ER(&1E
M\&EL+B!!>7+];G3];&%R('GV;F5T:6-I(&GG:6X@9_QN;/QK;&5N9&DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A
M<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@
M(EGV;G1E;2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@
M9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(EGV;G1E;2`G)7,G('1A;OUM;&%N;6%M_?XB"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FEK
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B365K<VEK
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O;F5S>6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI
M9&1L92(*;7-G<W1R(")/<G1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-
M:6UE(%3\<OPB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E-O;B`R-"!S86%T
M=&5K:2!E;B!D_/[\:R!S_6-A:VS]:SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S
M='(@(E-O;B`V('-A871T96MI(&5N(&3\_OQK('/]8V%K;/UK.B`B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T
M"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B66%N<_TB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M375H=&5L:68B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B0G5L=6YA;6%Y86X@4$5!4B!P86ME=&DZ
M($A45%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U
M"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB071L86YM_?X@>6%P_6QA;F3]<FUA
M+B!"=2!U>6=U;&%M87G](&MU;&QA;FUA:R!I<W1I>6]R<V%N_7H@>6%P_6QA
M;F3]<FUA>?T@(@HB_')E=&UE:R!Z;W)U;F1A<_UN_7HN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED
M(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(D%T;&%N;?W^(&UE<V%J
M($E$+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C
M:V%G92!-86EL+B(*;7-G<W1R(")!=&QA;FW]_B!O;&%N(&=E<F5K;&D@4$5!
M4B!P86ME=&D@36%I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)
M1"XB"FUS9W-T<B`B071L86YM_?X@;W1U<G5M82!A:70@240N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B
M36\B"FUS9W-T<B`B4'IT(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")'97II8VD@4&]S=&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B4V%K:6XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M(")$9?!I_FEM(%1A<FEH:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*
M;7-G<W1R(")$9?!I_G1I<CI54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V0@
M5&%B86[](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI
M8R!O9B(*;7-G<W1R(")-;VQD;W9Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]N86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36]N9V]L:6$B"FUS9W-T<B`B36_P;VQI<W1A;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S
M='(@(D%Y('9E('G];"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B07EL_6LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N
M='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B07D@179R
M96QE<FDB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R(")&87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@
M(D=E;F5L;&EK;&4@0>?]:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@
M(D=E;F5L;&EK;&4@0G5L=71L=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T
M<B`B1V5N96QL:6ML92!'_&YE_FQI(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B
M0?YA\/T@5&'^_2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(E-O;&$@5&'^_2(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I
M9"`B36]V92!2:6=H="(*;7-G<W1R(")38?!A(%1A_OTB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B
M"FUS9W-T<B`B675K87+](%1A_OTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T
M<B`B0?YA\/T@=&'^_2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")9=6MA<OT@
M=&'^_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R
M(")-;WIA;6)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*
M;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("+'
M;VML=2!D_'IE>2!A_F'P_2!AY_UL_7(@;&ES=&5L97(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L
M=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R
M("+';VML=2!39>=I;2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B2&5S86+];2(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")":6QG:6QE<FEN:7HB"@HC.B!S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB
M"FUS9W-T<B`B4&]R=&%L_6TB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP
M:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(E!O<G1A
M;"!$_'IE;FEM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(DUY86YM87(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S
M='(@(DMA8G5L($5434E93U)532(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N
M<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(D%D(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB>6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B2&]L;&%N9&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B2&]L
M;&%N9&$@06YT:6QL97)I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@
M(DYE='-C87!E(%1A8F%N(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N
M(%523"(*;7-G<W1R(").971S8V%P92!#02#=<'1A;"!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S8V%P92!#02!K=7)A;"!5
M4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM
M<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T<V-A<&4@
M665N:6QE;64@4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B3F5T<V-A<&4@W7!T86P@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@
M;F%M92(*;7-G<W1R(").971S8V%P92!34TP@<W5N=6-U(&%D_2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E(&]N
M87D@8F5L9V5S:2!AY_UK;&%M87/](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@;VYA>2!B96QG97-I('3\<OPB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K
M(@IM<V=S='(@(D'P(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B07-L82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(")9
M96YI($MA;&5D;VYY82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T
M<B`B665N:2!+871E9V]R:2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(MUL971I($]L=?YT
M=7(@*"5S*2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W
M($UO;VXB"FUS9W-T<B`B665N:2!!>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N
M86PI(@IM<V=S='(@(EEE;FD@2W5L;&%N_6/]($%D_2`H4V7G:6UL:2DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(EEE;FD@
M6F5L;&%N9&$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(")087)O;&$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R
M"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R(")087)O;&%L87(@9?YL9?YM96L@>F]R=6YD863]<BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED
M(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(EEE;FD@4&5N8V5R92`H
M7V)O_BDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M.0IM<V=I9"`B3F5W<R(*;7-G<W1R(")(86)E<FQE<B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T
M<B`B2&%B97(@1W)U<&QA<OTB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")3;VYR86MI(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@
M4&AA<V5S(@IM<V=S='(@(E-O;G)A:VD@179R92(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B4V]N<F%K
M:2!39>=E;F5K;&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ
M,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@(E-O;G)A:VDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G
M=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI:F5R
M>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEJ
M97)Y82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G
M:60@(DYI9VAT(@IM<V=S='(@(D=E8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(DAA>?UR
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED
M(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+B(*;7-G<W1R(")&87)K;&%R_6X@9_9S=&5R:6QE8FEL
M96-E\&D@:W5L;&%N_6QA8FEL:7(@>6%P_6QA;F3]<FUA('9E<FES:2!Y;VLN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ
M,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N(@IM<V=S='(@(DE33R!I;6%J;&%R_2!O=?YT=7)M86L@:>=I
M;B!K=6QL86[];&%B:6QI<B!B:7(@>?9N=&5M('EO:RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@
M(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")9_?#];B!T87-L8?#]('EO
M:RXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("+=
M<W1E;F5N(&MO;G5M9&$@:&GG8FER(/9B96L@8G5L=6YM86UA:W1A9/UR(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B34-!3"!D;_!R=6QA;6%S_2!IYVEN(&AIYV)I<B!T86MV
M:6T@863]('-A\&QA;FUA;?W^=/UR+B`B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")$9?!I_FEK;&EK
M(%EO:R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+B(*;7-G<W1R(")"=2!I>FYE(&AIYV)I<B!A;'0@:7II;B!E:VQE;F5M
M97EE8V5K=&ER+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S
M='(@(B5S(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER
M=&EL;65D:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N(@IM<V=S='(@(D944"!61E,@:>=I;B!H:>=B:7(@>6%P
M_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B
M4U%,(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES:2!B96QI
M<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B4U%,+49I;&4@5D93
M(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER=&EL;65D
M:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")+<F5D
M:2!Y;VLN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*
M;7-G<W1R(")(:>=B:7(@=&5S;&EM(&YO:W1A<_T@8F5L:7)T:6QM96UI_G1I
M<BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G
M:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B2&GG8FER(&1O<WEA('G\
M:VQE;F5M961I(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED
M(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B2&GG8FER('-I;6=E(&)U;'5N
M86UA9/TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B2&GG
M8FER('EE<B!B96QI<G1I;&UE9&DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(DAIYV)I<B!Y97(@8F5L:7)T:6QM961I+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S
M"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")(:>=B:7(@
M;65S86H@<V'P;&%N;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I
M960N(@IM<V=S='(@(D%D(&)E;&ER=&EL;65D:2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@
M;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3G5M87)A(&)E;&ER=&EL;65D
M:2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")386QD_7)G86X@9&5Y:?X@:W5L
M;&%N;6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B2%144"!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G
M:7)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ
M,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("))34%0(&1O\')U;&%M87/](&GG:6X@<&%R
M;VQA(&=I<FEL;65D:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S(&1O\')U;&%M
M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN
M<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("),;V=I;B!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G
M:7)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP
M.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4$%34U=$(&1O\')U;&%M87/](&GG
M:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E--0B!D;_!R=6QA;6%S_2!I
MYVEN('!A<F]L82!G:7)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G
M<W1R("(B"B)/<&5N4U-,(&EK:6QI<VEN92!H:>=B:7(@>6]L(&)U;'5N86UA
M9/TN3W!E;E-33"!I:VEL:7-I(%!+0U,@,3(@=F5R:7-I>6QE("(*(F-A;/W^
M;6%K(&GG:6X@9V5R96ML:2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S
M='(@(MQY92!O;&UA:R!IYVEN(&)E:VQE>65N('EO:RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-S4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(").;R!Q=6]T82!S970N(@IM<V=S='(@(D)E;&ER=&EL;65M:?XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S
M"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")+=7)A;"!Y;VLB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(DYO
M('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYU;6%R82!B96QI<G1I
M;&UE9&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B66%N('EO
M:R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"B,L(&9U>GIY
M"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B66%N('EO:R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B
MUFYB96QL96L@:>=I;B!G9>=I8VD@9&EZ:6X@8G5L=6YA;6%D_2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I
M9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@
M(DMU;&QA;OUC_2!A9/T@=F4O=F5Y82!P87)O;&$@9_9N9&5R:6QM961I+B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").
M;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(")'9>=E<FQI(%A-
M3"!V97)I<VD@9V5R:2!D]FYM961I+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T
M<B`B1&7P97(@>6]K(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(M9Z9_QN
M('EA</UL86YD_7)M861A('/\<OQM(&)U;'5N86UA9/TN66%P_6QA;F3]<FUA
M>?T@=&5K<F%R(/QR971I;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+6>F?\
M;B!Y87#];&%N9/UR;6%N_7ID82!S_'+\;2!B=6QU;F%M863]+EEA</UL86YD
M_7)M87G]('1E:W)A<B#\<F5T:6XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R(")(:>=B:7)I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")(:>=B:7)I
M("C6<G3\;/P@:W5L;&%N_6XI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(DMU>F5Y
M($%V<G5P86S]("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&L@061A<_TB"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS
M9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DMU>F5Y(%EA<OUM
M:_QR92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S(@IM<V=S='(@(DMU>F5Y($UA<FEA;F$@061A;&%R_2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G9EYR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@
M069T97(B"FUS9W-T<B`B4V]N<F%S_6YD82!$9?!I;"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E
M(@IM<V=S='(@(M9N8V5S:6YD92!$9?!I;"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(D1I>FEN(&1E\&EL(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G
M:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B1V5RYV5K;&7^=&ER:6QM
M96UI_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B0F5L:7)T:6QM96UI_B(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")$97-T96ML96YM:7EO<BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&QA<B(*"B,Z('-E
M<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(D?V>B!A=/UL86-A:R!B:7+^
M97D@>6]K+"!G97)I(&3V;OQN+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(")+
M87/];2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*;7-G:60@
M(DYU;6)E<B(*;7-G<W1R(")387G](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T
M<B`B2V%R86MT97(@<V%Y_7/](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS
M(@IM<V=S='(@(DMO;&]N('-A>?US_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W
M<R(*;7-G<W1R(")3873]<B!S87G]<_TB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N
M;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B1&'P_73];2!L:7-T96QE<FEN:6X@9_QN8V5L;&5N;65S
M:2!IYVEN(&YU;6%R86QA<B!B96QI<G1I;&UE;6G^+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS
M9W-T<B`B179E="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(").97-N92(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@
M0W)E871O<B(*;7-G<W1R(").97-N92!987)A=/UC_7/](@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
M4V5K:7IL:6L@4VES=&5M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B16MI;2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F
M:6QT97(B"FUS9W-T<B`B4V%L9/UR9V%N;/UK('/\>F=E8VDB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`B3V9I<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM
M<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")087)O
M;&$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z
M>GD*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T
M<B`B66%N;/W^('!A<F]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R(")5;6UA;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")3861E8V4@24U!4"!S=6YU8W5L
M87+]('!A>6QA_OUL86X@9&EZ:6YL97)I(&1E<W1E:VQE;65K=&5D:7(N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R(")3861E8V4@<V%L9/UR9V%N(&1E>6G^
M;&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A
M9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E-A9&5C92!B:7(@96QE:W1R;VYI
M:R!P;W-T82!A9')E<VEN92!I>FEN('9E<FEL;65K=&5D:7(N(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O
M=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R
M<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G
M<W1R("(B"B)":7(@<&%Y;&'^_6W];B!S86AI<&QI\&EN:2!V97EA('-A:&EB
M:6YI('-A9&5C92!S:7-Y96T@>?9N971I8VES:2!V97EA("(*(G-A:&EB:2!D
M9?!I_G1I<F5B:6QI<BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM
M<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B665N:2!P96YC
M97)E9&4@8><B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@
M9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B3W!E;E-3
M3"!H871A<_TZW6UZ86QA;FW]_B!3+TU)344@<&%RYV%S_6YD86X@=F5R:2!S
M9>=I<"#G_6MA=/UL86UA9/TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D)U(&)A\&QA;G3]>?T@
M>65N:2!P96YC97)E9&4@8><B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`BW?YL971I;2!3
M:7-T96UI(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM
M<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")39>=E;F5K;&5R(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(B5S
M(&GG:6X@<V7G96YE:VQE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R
M(")3_7)A;&%N;?W^($QI<W1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")+
M=7)U;'7^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B2W5R=6US
M86P@0FER:6TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS
M9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D3\>F5N;&5M92(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T92(*;7-G<W1R("+6>F?\;B!U>6=U;&%M82!T87-L8?#](@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(E<R!IYVEN
M9&5K:2#V>F?\;B!T87-L86ML87(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(D1I\&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B1&GP
M97(@0FEL9VEL97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q
M"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")386AI<"!I>FEN
M;&5R:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I
M9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(E!!32!D;_!R=6QA;6%S_2!M979C=70@9&7P:6PN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")0
M14%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG
M;F%T=7)E(@IM<V=S='(@(E!'4"!387G]<V%L(-UM>F$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B4$=0(-YI9G)E;&5N;6G^(%9E<FDB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@
M4'5B;&EC($ME>2(*;7-G<W1R(")01U`@0>?]:R!!;F%H=&%R_2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0(&EL92#=;7IA;&%N
M;?W^+]YI9G)E;&5N;6G^(%9E<FDB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!+;V1U(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B
M4$A0($MA8G7P=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(M93($AA
M9FEF(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(M93(%-A\&%N
M86ML87+](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`BUE,@2V%R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R("+64R!+87(@4V'P86YA:VQA<OTB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0HC+"!F
M=7IZ>0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(M93($MA<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4
M+5-T;W)M<R(*;7-G<W1R("+64R!']FL@9_QR_&QT_&S\(&;]<G3];F$B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4%](4"!+86)U\'4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(EEA<W3]:VQA;6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D(@IM<V=S='(@(MW^9V%L($5D:6QM:?X@1FEL:7-T:6X@0O9L9V5S
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G
M<W1R(")087!U82!996YI($=I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y
M(@IM<V=S='(@(DO]<VUE;B!"=6QU=&QU(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS
M9W-T<B`B4&%R;VQA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,S(R"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B66%N;/W^
M('!A<F]L82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(E)!1$E54R!D;_!R=6QA;6%S_2!IYVEN('!A
M<F]L82!G97)E:VUE:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(D]N87EL_2!087)O;&$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")087)O;&$Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`B4&%R;VQA.B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")087)O;&%L87(@9?YL9?YM96L@>F]R=6YD
M863]<BXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B
M4&%S=&4B"FUS9W-T<B`B66%P_?YT_7(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L
M:7!B;V%R9"(*;7-G<W1R(")086YO9&%N('EA</W^=/UR(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T
M:"(*;7-G<W1R(")9;VPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")"96ML97EE
M;B#<>65L:6ML97(Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS
M9VED(")096]P;&4B"FUS9W-T<B`BW6YS86YL87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N
M="(*;7-G<W1R(")9_'ID92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,B"FUS9W-T<B`B0F%K_6T@W?YL96UL97)I;FD@1V5RYV5K
M;&7^=&ER(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G
M<W1R(")"86O];2!I_FQE;6QE<FD@9VER:?YT92!G97+G96ML9?YT:7)I;'-I
M;B!M:3\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM
M<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+=>FEN(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(MUZ:6X@
M)R5S)R!S:6QI;F5M961I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3@V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G
M<W1R("+=>FEN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E](86ML87(B"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("+=>FEN(%GV;F5T:6UI(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R
M(")+:?YI<V5L($)I;&=I;&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U
M(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M;7-G:60@(E!E=',B"FUS9W-T<B`B179C:6P@2&%Y=F%N;&%R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<&EN;&5R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&
M;W1O\')A9FQA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM
M<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")297-I
M;2!":7)I;6DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@
M(E!L871I='5D97,B"FUS9W-T<B`B0F5Y;&EK(%/V>FQE<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G
M:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("),_'1F
M96X@8FER:V'G(&C\8W)E>64@=/UK;&%Y_6XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#HB"FUS9W-T<B`B3/QT9F5N(&)U(/;P97EI(.?]:V%R;6%K(&ES=&5D
M:?!I;FEZ:2!D;_!R=6QA>?UN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*
M;7-G<W1R("),_'1F96X@8G4@]O!E;FEN(&)A\/UN_2#G]GIM96L@:7-T961I
M\&EN:7H@9&_P<G5L87G];BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+B(*;7-G<W1R("),_'1F96X@8FER(&%Y('9E(&)I<B!Y_6P@9VER:6XN(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(@IM<V=S='(@(DS\=&9E;B!Y96YI(&MA=&5G;W)I;FEN(&%D_6[](&=I
M<FEN.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(DS\
M=&9E;B!G9>=E<FQI(&)I<B!)4"!A9')E<VD@9VER:6XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B3/QT9F5N(&=EYV5R;&D@8FER(&?\;B!G:7)I;BP@
M87ED86MI(&?\;B!S87G]<_UN_2!K;VYT<F]L(&5D:6XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92XB"FUS9W-T<B`B3/QT9F5N(&=EYV5R;&D@8FER('IA;6%N
M(&=I<FEN+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*
M;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2XB"FUS9W-T<B`B3/QT9F5N('-O<G5N=6X@8FER(/9Z971I;FD@>6%P_6XN
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("),_'1F96X@:W5L;&%N
M_6/](&%D_2!V92!P87)O;&%N_7K](&=I<FEN(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B),_'1F
M96X@;65T;FD@;VMU>75N+B!3:7-T96UI(&MU;&QA;F%B:6QM96L@:>=I;B!K
M=6QL86[];2!K;_YU;&QA<OUN_2!+04)53"`B"B)E=&UE:R!Z;W)U;F1A<_UN
M_7HN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`B3/QT9F5N('EE;FD@:V%T96=O<FEN:2!A9/T@9VER
M:6XZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L
M;VYY82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B4&]L:71I:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R(")/>6QA;6%L87(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T
M96MI>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R(")']G+\;G3\(&MO;G5M;&%N9/UR_6S]>6]R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BQVEZ96QG
M92!K;VYU;6QA;F3]<OUL_7EO<B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B0G4@9&EZ:6YE(&?V
M;F1E<B`H24U!4"!T87)A9OUN9&%N('IO<FQA;FUA;6%K=&%D_7(I(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4V]N("5S('-A871T92!D_/YE;B!Y
M8?!M=7(@=F4@:V%R(&UI:W1A<OTZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP
M:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@W7-T96YE;B!,
M1$%0('5Z86YT_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!R969S7W-E<W-I;VXZ(-US=&5N96X@;W1U<G5M('5Z86YT_7/](&)U;'5N
M86UA9/TN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R
M97-S=7)E(@IM<V=S='(@(D)A<_UNYR(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R
M(")$96YI>B!S979I>65S:6YD96MI(&)A<_UNYSHB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S
M='(@(D)A<_UNYSHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R
M("+6;FEZ;&5M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D?V<OQN=/QY_"!Y96YI('!E
M;F-E<F5D92#V;FEZ;&4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@IM<V=I
M9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("+6;F-E:VD@<V7G96YE:VQE
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(D)E;&=E>6D@>6%Z
M9/UR(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0<FEV871E($ME>2(*;7-G<W1R("+6>F5L($%N86AT87(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B
M;&5M(@IM<V=S='(@(E-O<G5N(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E-O<G5N
M(%1A;OUM;&%M87/](@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V
M.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5L97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I
M9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B365T:6X@8FEL9VD@:7-T96UI(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(D'G_6L@06YA:'1A<B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y
M($%L9V]R:71H;2(*;7-G<W1R(")!Y_UK($%N86AT87(@86QG;W)I=&UA<_TB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`HC+"!F
M=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(D'G_6L@06YA
M:'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM
M<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B0>?]:R_6>F5L(&%N86AT87(@:6MI;&ES
M:2!B8?YA<OUY;&$@>6%R873];&%M863]+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!O<G1O(%)I:V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")+871A<B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B4V]R9W4B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@
M(E%U;W1A(@IM<V=S='(@(DMA=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!($'G_6L@06YA:'1A<OT@
M*"5D(&)I="DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS
M9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4F%D>6\@4V7G:6UI(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G
M:60@(E)A:6XB"FUS9W-T<B`B66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS
M9W-T<B`B17)K96X@4V%A=&QE<F1E(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B
M"FUS9W-T<B`B1V7G(%-A871L97)D92!98?!M=7(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W
M97(B"FUS9W-T<B`B4V'P86YA:R!98?#]_B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W
M(@IM<V=S='(@(EEA\&UU<B!V92!+87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM
M<V=S='(@(DMA<F$@9/9N_/YE8V5K('EA\&UU<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")2
M87-T9V5L92!$97EI_B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B3W)A;B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S
M='(@(D]K=6UA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`BW6QE=&EL
M97)I($]K=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)3:6QM
M96L@:7-T961I\&EN:7IE(&=E<N=E:W1E;B!E;6EN(&UI<VEN:7H_*$)U(&G^
M;&5M(&=E<FD@YV5V<FEL96UE>BDZ)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB2W5L;&%N_6/]("5S(&4@
M86ET(&MU;&QA;OUC_2!V97)I;&5R:6YI('-I;&UE:R!I<W1E9&GP:6YI>F4@
M96UI;B!M:7-I;FEZ+B!"=2`B"B)I_FQE;2!G97)I(.=E=G)I;&5M97HN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM
M<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B4V]N(&5Y
M;&5M:2!T96MR87)L82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")$979I;F=E
M;B!-96[\(-;P96QE<FEN:2!487IE;&4Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T
M<B`B4&]R=&%L($?V<OQN_&W\;OP@5&%Z96QE.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X
M(@IM<V=S='(@(D3\>F5N;&D@W69A9&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G
M<W1R("+=;&G^:VD@5&%R87G]8_TB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L
M(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`B3VMU;6$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")!
MY_UK;&%M86QA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G
M:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E5Z86MT86MI(%-U;G5C=6QA
M<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(E5Z86MT86MI(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")2
M96UO=F4B"FUS9W-T<B`B4VEL(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`BUF)E\&D@
M4VEL(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")+;VQO;G4@4VEL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B0FGG:6UL96UE
M>6D@4VEL(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G
M:60@(E)E;6]V92!P86ER(@IM<V=S='(@(DEK:6QI>6D@4VEL(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA>61E9&EL;6G^(&)E=&GP:2!S=6YU8W5N=2!G9>=I8VD@9&EZ:6YI
M;F1E;B!S:6PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@
M(E-I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N="(*;7-G<W1R(")"=2!P87+G87G](&)E;&=E9&5N(.?]:V%R
M="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G
M:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(DMU;&QA;OUC_2!3:6PB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(DMU;&QA;OUC_7G]
M('-I;#H@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S
M.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B`B"FUS9W-T<B`BW7-T96L@8V5V87!L86YA;6%D_2Y$
M]F[\;&5N(&AA=&$@:V]D=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@
M8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")9_&ML96YE;B!D;W-Y82!K
M87ED961I;&5M961I+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")'97)E:V5N("<E<R<@
M)7,@>6%P_6QA;F3]<FUA<_UN9&$@8F5L:7)T:6QM96UI_BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B1V5R96ME;B`G)7,G(%9&4R!Y87#];&%N9/UR;6%S_6YD82!B96QI<G1I
M;&UE;6G^+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1V5R96ME;B`G
M)7,G('EA</UL86YD_7)M861A(&)E;&ER=&EL;65M:?XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E
M9"!&:65L9"(*;7-G<W1R(")'97)E:V5N($%L86XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B5&5M:7IL92(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!0
M87-S=V]R9"(*;7-G<W1R(")087)O;&%Y_2!S_6;]<FQA(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`B4&%R;VQA;OUZ_2!S_6;]<FQA>?UN(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,
M87-T(%%U97)Y(@IM<V=S='(@(MYI_FMI;B!!>2(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE
M;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(E-O;G7G;&%R(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R(")39>=E;F5K;&5R92!$]F[\;B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T>7!E(&YE=R!P87-S
M=V]R9"(*;7-G<W1R(")087)O;&%Y_2!S_6;]<FQA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X
M"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")987#];&%N
M9/UR;6%Y_2!'97)I($3V;F3\<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R
M("):96YG:6X@365T:6X@1/QZ96YL97EI8VES:2!39>=E;F5K;&5R:2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G
M<W1R(")":6QM96-E;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")3
M8?`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2
M:6=H="!H96%D97(B"FUS9W-T<B`B4V'P(&)A_FS]:R!B:6QG:7-I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L
M=65S(@IM<V=S='(@(D1O\')U(&1E\&5R;&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2
M;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4V%?=/UR(-9Z96QL:6ML97)I
M+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")']G)E=B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]M86YY82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O
M=&%T92`Q.#`B"FUS9W-T<B`B,3@P(&1E<F5C92!D]FYD_'(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2
M;W1A=&4@3&5F="(*;7-G<W1R(")3;VQA($3V;F3\<B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R(")38?!A($3V;F3\<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O
M=R!0<F]P97)T:65S(@IM<V=S='(@(E-A=/UR(-9Z96QL:6ML97)I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4V%T_7(@]GIE;&QI
M:VQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B4V%T_7)L87(Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`BQVEZ9VEL97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS(@IM<V=S='(@(L=I>F=I;&5R('3\;2!S873]<B!V92!K;VQO;FQA<B!A
M<F%S_6YD82!B96QI<F5C96MT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("+':7IG:6QE
M<B!S861E8V4@:V]L;VYL87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`BQVEZ9VEL97(@<V%D96-E('-A=/UR;&%R(&%R87/];F1A(&)E
M;&ER96-E:W1I<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@
M(E)U;B(*;7-G<W1R("+'86S]_G3]<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-Y82!&961E<F%S>6]N
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N
M9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM
M<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@
M(E,O34E-12#>:69R96QE;64@W6UZ87/](@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@
M365S<V%G92(*;7-G<W1R(")3+TU)344@:6QE(-YI9G)E;&5N;6G^(-UL971I
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")305-,(&1O\')U;&%M87/](&UE=F-U="!D9?!I;"XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")335,@365S<V%G:6YG(@IM
M<V=S='(@(E--4R!-97-A:FQA_FUA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,($MA8G7P=2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T
M96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(E-3
M2"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B
M0D'>05))3$DB"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE
M;&PB"FUS9W-T<B`B4U]13"!+86)U\'4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")#
M=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T
M<B`B4V%I;G0@2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+
M:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I;G0@2VET=',@=F4@3F5V:7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A
M:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@=F4@36EQ=65L
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")386EN="!6:6YC96YT('9E($=R96YA
M9&EN97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B07EN
M_2#G97+G979E("AK96Y?9&ES:2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")3
M86UO82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A
M;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M
M92!V92!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")5>61U
M(%-A\&QA>?UC_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I
M82(*;7-G<W1R(")3=75D:2!!<F%B:7-T86XB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B2V%Y9&5T
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B
M2V%Y9&5T("5S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")+87ED970@
M)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E
M($]P=&EO;G,B"FUS9W-T<B`B4V7G96YE:VQE<FD@2V%Y9&5T(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V
M97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)/;'7^
M='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!02%`@8F5T:?!I(&]L87)A:R!S=6YU
M8W5N=6X@9V7G:6-I(&1I>FEN:6YE("(*(FMA>61E="XB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!Y87#];&%N9/UR;6%S
M_2!K87ED961I;&1I+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")!>6%R(&?\;F-E;&QE
M;64@8F5T:?!I(&MA>61E9&EL9&DZ("<E<R<N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E-C
M871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")986S]=/UL;?W^(&?V:R!G_'+\
M;'3\;/P@9OUR=/UN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM
M<V=I9"`B4V-I96YC92(*;7-G<W1R(")":6QI;2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B07)A;6$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R(")!<F%M82!-;W1O<FQA<OTB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T
M<B`B1&]S>6%L87+](%-EYR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T
M<B`B0FER('1A<FEH('-EYVEN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R
M(")%:VQE;65K(&GG:6X@8FER(&=R=7`@<V7G:6XB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B
M"FUS9W-T<B`B665N:2!S86AI8FD@<V7G:6XB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G
M<W1R(")":7(@<W5N=6-U('-EYVEN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(D5K;&5M96L@:>=I;B!B:7(@:W5L;&%N_6/]('-EYVEN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")$;W-Y86QA<OT@4V7G(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T
M(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(D+\=/QN('1A<FEH(&)I
M;&7^96YL97)I;FD@<V7G:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM
M<V=S='(@(D)I<B!N97-N92!S9>=I;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(EEE;FD@<V%H:6)I('-EYVEN(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82XB"FUS9W-T<B`B(@HBW7-T961I\&YI>B!K87)A:W1E<FQE<FD@8?YA\/UD
M86MI(&MU='5L87)D86X@<V7G:6XN($1A:&$@<V]N<F$@;65T:6X@(@HB86QA
M;OUN9&%N(&MO<'EA;&%Y_7`@>6%P_?YT_7)A8FEL:7)S:6YI>BXB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5&%R:6@@<_UN_7)L87G]8_US_6[]
M('-EY_UN.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")487)I:"!B:>=I
M;6EN:2!S9>=I;CHB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93HB"FUS9W-T<B`B1&7P:?YT:7)M96L@:7-T961I\&EN:7H@
M:VEM;&GP:2!S9>=I;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ
M-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B
M4V%A="!S_6[]<FQA>?UC_7/];OT@<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(E-A870@8FGG:6UI;FD@<V7G:6XZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N(@IM<V=S='(@(D7^;&7^96X@:6MI(&%L86[]('-EYVEN+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y
M;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4F5N:R!D_'IE;FEN:7II('-E
MYVEN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B5&5R8VEH
M(&5T=&GP:6YI>B!D:6QI('-EYVEN.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(E-O<G5N(%)A<&]R=2!']FYD97(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B
M"FUS9W-T<B`B4TU3($?V;F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")!;&?];&%Y_6/].B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS
M9VED(")397!T96UB97(B"FUS9W-T<B`B17EL_&PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(E/]<F)I<W1A;B!V92!-;VYT96YE9W)O(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@
M(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4V5R:2!.=6UA<F%S_2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@
M(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DAA=F$@<F%P;W)U(/9B9?!I(&MU;&QA;OUL86)I;&ER(&1E\&EL+B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO
M;B!!9&UI;B(*;7-G<W1R("+=>FEN(%GV;F5T:6UI(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")3
M97-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(D]T=7)U;2!K:6UL:?!I;FEN
M('/\<F5S:2!D;VQD=2XB"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*
M;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E](86ML87(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B0F5L
M:7)T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(E!A<F]L86[]>OUN
M_2!U;G5T=7)S86[]>B!S_6;]<FQA;6%N_7IA(&EZ:6X@=F5R96-E:R!S9>=E
M;F5K;&5R:2!B96QI<G1I;BX@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(E5L8?YM
M86L@:7-T9?!I;FEZ('5Z86MT86MI('-U;G5C=6QA<OT@8F5L:7)L97EI;BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B5&5R8VEH(&5T=&GP:6YI>B!D:6PL('-A870@9&EL:6UI
M('9E('1A<FEH('-EYV5N96ML97)I;FD@8F5L:7)L97EI;BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)"
M8?YL86YG_><@=7EG=6QA;6%N_7K]+"!R96YK(&3\>F5N:6YI>FDL('-A>69A
M('1A>F5L96UE+"!V92!D:?!E<B!G]G+\;G3\("(*(G-EYV5N96ML97)I;FD@
M8F5L:7)L97EI;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS
M9VED(")3971U<"(*;7-G<W1R(")!>6%R;&%R(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B2W5R=6QU;2!G_&YC96QL96UE
M(&)E=&EK;&5R:2!K=6QL86[];&%B:6QI<B!D=7)U;61A+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@
M(D1E\&G^=&ER9V4@:6QE(&)I<F1E;B!F87IL82!Y97(@;?QM:_QN.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>?YE
M;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H
M;W!P:6YG(@IM<V=S='(@(D%L_?X@=F5R:?XB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R(")+_7-A(-9Z970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V
M"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\B"FUS9W-T<B`BQV_P=2!B8?!L86YT_2!IYVEN(&5R:?YI;2!A
M;F%H=&%R_2!T86[];6QA;G/];B!M_3\B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")']G-T
M97(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*(DAA;&5N(&MA>?UT;/T@;VQA;B!Y87#];&%N9/UR;6$@:6QE('EE;FD@
M>6%R873];&%N('EA</UL86YD_7)M82!A<F%S_6YD86MI("(*(F9A<FML87+]
M(&?V<W1E<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(D=I<FG^=&4@96X@<V]N(&=I<FG^('1A<FEH:2!G]G-T97)I;'-I;B!M
M:3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(M9Z9_QN(&]L
M86[]('-A:VQA;6$@<V7G96YE\&EN:2!G]G-T97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R
M(")39>=I8VEY:2!G]G-T97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM
M<V=S='(@(L=I>F5L9V4@:?YL96UL97)I(&UE;OP@YW5B=?!U;F1A(&?V<W1E
M<FEL<VEN(&UI/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\B"FUS9W-T<B`B)7,@365N_'/\('-O;&1A(&?V<W1E<FEL<VEN(&UI/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R(")486)L;R!(_&-R92#6>F5L;&EK;&5R:2!+=71U
M<W5N=2!G]G-T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8FQO(-9Z96QL:6ML97)I($MU
M='5S=6YU(&?V<W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8FQO(%-A=/UR(-9Z
M96QL:6ML97)I($MU='5S=6YU(&?V<W1E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO
M=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1_9R_&YT
M_"#V>F5L;&EK;&5R:2!K=71U<W5N=2!G]G-T97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R
M(")9_&ML96UE>6D@9_9S=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B4V'P
M86YA:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(D5R:V5N(%-A871L
M97)D92!38?!A;F%K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")'9><@
M4V%A=&QE<F1E(%-A\&%N86LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI
M='DB"FUS9W-T<B`BQV5V<F5D92!38?!A;F%K(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T
M<B`B2_SG_&QT(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("+=;&L@;VQA
M<F%K(&MO;?YU(/;P96QE<B!K_.?\;'1S_&X@>6%D82!T8?[];G/];B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R
M<F$@3&5O;F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(MQY92!O;"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U
M<F4B"FUS9W-T<B`BW6UZ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S
M='(@(MUM>F$@06QG;W)I=&UA<_TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P=7(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(D)O>75T(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*
M;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B0F%K_6W]($%T;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]V
M86MY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@
M(E-L;W9E;GEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B2V%R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@
M4VAO=V5R(@IM<V=S='(@(DMA<B!38?!A;F'P_2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B2V%R(%-A\&%N86ML87+](@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R
M<R!%87)L>2(*;7-G<W1R(")%<FME;B!386%T;&5R9&4@2V%R(%-A\&%N86ML
M87+](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(D=EYR!386%T
M;&5R9&4@2V%R(%-A\&%N86ML87+](@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")+87(@1&5R:6YL
M:?!I.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B66'P86X@:V%R_6X@
M<W4@9?YI=&DZ("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L
M86YD<R(*;7-G<W1R(")3;VQO;6]N($%D86QA<OTB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R
M("+>87)K_6QA<B`F(-YI:7)L97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R
M(")3_7)A;&%M82!D_'IE;FD@<V7G:6UI(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U
M<F-E(&%D9')E<W,B"FUS9W-T<B`B2V%Y;F%K(&%D<F5S:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")'_&YE>2!!9G)I
M:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(D?\;F5Y($%V<G5P82`H
M25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G
M:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D?\
M;F5Y($=E;W)G:6$@=F4@1_QN97D@4V%N9'=I8V@@061A;&%R_2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G
M:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B1_QN97D@66%R_6UK
M_')E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS
M9W-T<B`B0FET:?YI:R!H_&-R96QE<B!A<F%S_6YD86MI(&)O_FQU:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS
M9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M(@IM<V=S='(@(DC\8W)E9&5K:2!S_6[]<B!V92!IYV5R:6L@87)A<_UN9&%K
M:2!B;_YL=6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G
M:60@(E-P86-E<B(*;7-G<W1R(")";_YL=6L@07EA<FQA>?UC_2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM
M<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")!<F%L_6L@8OUR86MM82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*
M;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B07)A;/UK(&+]
M<F%K;6$@=F4@>6%S=/UK;&%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I
M;B(*;7-G<W1R("+=<W!A;GEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(MUS=&5N;65Y96X@W6QE=&DB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(M9Z96P@2V%R86MT97(@1VER:?YI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")(_&-R97EI(&+V
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")+;VQO;G4@
M8O9L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(E-A=/UR_2!B
M]FPB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R(")3<&]R;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@
M3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G:60@
M(E-T86YD87)D(@IM<V=S='(@(E-T86YD87)T(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B57IA>2!9
M;VQU(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S
M='(@(D)A_FQA;F?]YR!Y_6S](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S
M='(@(D5Y86QE="!V97EA(-UL(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")$=7)U;2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A
M9V4@9F]R;6%T(@IM<V=S='(@(D1E<&]L86UA(&)IYVEM:2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"FUS9VED(")3=')E970@
M061D<F5S<R(*;7-G<W1R(")3;VMA:R!!9')E<VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T
M:')O=6=H(@IM<V=S='(@(MQS=/P@YVEZ9VEL:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@
M(D1I>F=I(&QI<W1E<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G
M<W1R(")!9')E<W1E;B!A;&%N(&%D_6[](.?]:V%R="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@
M(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-I=&EL(%M#4U-=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B
M"FUS9W-T<B`B4'IR(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B06QT9&EZ:6X@)R5S)R!B=6QU;F%M863]
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B2V]N=2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R(")']FYD97(B"@HC
M.B!S:6=N=7`N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(B<E<R<@:6X@<VES=&5M
M92!E:VQE;FUE<VD@:7-T9?!I;FEZ(&?V;F1E<FEL9&DN(-US=&7P:6YI>B!O
M;F%Y;&%N82!K861A<B`B"B)G:7)I_B!Y87!A;6%Z<_UN_7HN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B
M4W5B<V-R:7!T(@IM<V=S='(@(D%L='-I;6=E(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM
M<V=S='(@(D)A_F%R_2(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB
M('1O('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@8F'^87+]>6QA('-I<W1E
M;64@96ML96YD:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S
M)R!IYVEN(&]L86X@=F5R:2!B8?YA<OUY;&$@<VES=&5M9&5N('1E;6EZ;&5N
M;6G^=&ER+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")"8?YA<OUY;&$@
M<VEL:6YD:2`G)7,G+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4VES=&5M9&5N(&)A_F%R
M_7EL82!S:6QI;F1I("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB66%P_6QA
M;F3]<FUA(&)A_F%R_7EL82!G97)I(&3V;F3\<OQL9/PN($1E\&G^:6ML:6ML
M97)I(&?V<FUE:R!IYVEN('EE;FED96X@(@HB>?QK;&5Y:6XN(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(EEE9&5K('EA</UL86YD_7)M82!B8?YA<OUY;&$@
M:V%Y9&5D:6QD:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B665D96L@>6%P
M_6QA;F3]<FUA(&1O<WEA<_T@)7,@8F'^87+]>6QA(&MA>61E9&EL9&DN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S
M)R!B8?YA<OUY;&$@9_QN8V5L;&5N9&DB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@
M8F'^87+]>6QA('EA>OUL9/TN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D
M86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S
M='(@(M9Z970B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@
M(E-U;B!2:7-E(@IM<V=S='(@(D?\;B!$;_!U;74B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B1_QN(&)A
M=/UM_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R(")'_&YE_FQI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R(")'_&X@9&_P=6UU(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E
M="(*;7-G<W1R(")'_&X@9&_P=6UU+T?\;B!B873];?TB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS
M9W-T<B`B1_QN(&1O\'5M=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(D?\;B!B873];?TB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3
M=6YS970Z("(*;7-G<W1R(")'_&X@8F%T_6W].B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C
M<FEP="(*;7-G<W1R("+<<W1S:6UG92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B1&5S=&5K(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA
M;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS
M9VED(")3=7)N86UE(@IM<V=S='(@(E-O>6%D_2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A
M<F0@=F4@2F%N($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL
M86YD(@IM<V=S='(@(E-V87II;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-W961E;B(*;7-G<W1R("+=<W9EYR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3
M=VET>F5R;&%N9"(*;7-G<W1R("+=<W9IYW)E(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(E-Y;F,@;&]G(&1E
M;&5T960B"FUS9W-T<B`B4VEL;65Y:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D%R86UA('1E<FEM;&5R:6YD
M92!S]GID:7II;2!H871A<_TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I
M86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3=7)I>64B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R
M;2(*;7-G<W1R(")']FL@9_QR_&QT_&S\(&;]<G3];F$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@
M(D?V:R!G_'+\;'3\;/P@9OUR=/UN86QA<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4+5-T
M;W)M<R!%87)L>2(*;7-G<W1R(")%<FME;B!386%T;&5R9&4@4V'P86YA:R(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E13
M5B!F:6QE(@IM<V=S='(@(E135B!D;W-Y87/](@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(L=I>F5L
M9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(L=)
M>F5L9V4@UGIE;&QI:VQE<FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")486)L92!3970B
M"FUS9W-T<B`BQVEZ96QG92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I
M97,B"FUS9W-T<B`BQVEZ96QG92#V>F5L;&EK;&5R:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")487EV86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I
M=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")487EV86XL(,=I;B!E
M>6%L971I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R(")486-I:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ86YY82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G
M:60@(E1A<F=E=#HB"FUS9W-T<B`B2&5D968Z(@H*(SH@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS
M9VED(")487-K<R(*;7-G<W1R(")']G)E=FQE<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M
M8F5R(@IM<V=S='(@(E1E;&5F;VX@3G5M87)A<_TB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B4V]N('-A870@:>=I;B!S_6-A:VS]:SH@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E/]
M8V%K;/UK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")3_6-A:VS]:SH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T
M92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(G)7,G('1A<VQA\/T@8G5L
M=6YA;6%D_2XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B
M5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5&%S;&%K(%GV;F5T
M:6UI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(DUE
M=&EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X
M="!/;FQY(@IM<V=S='(@(E-A9&5C92!-971I;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E
M>'0@86QI9VXB"FUS9W-T<B`B365T:6X@:&EZ86QA;6%S_2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E
M>'1T;W`B"FUS9W-T<B`B365T;FEN(-QS=/PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R
M(")0<OXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B5&%I("A425,M-C(P*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A>6QA;F0B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F
M;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4VES=&5M:2!K=6QL86[]
M9/WP_6[]>B!IYVEN('1E_F5K:_QR(&5D97)I>BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1E10('5Z86YT_7/](&MU;&QA
M;OUL86)I;&ER(&1U<G5M9&$@9&7P:6PN(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8B!B_'3\;FQE_G1I<FUE(&UO=&]R
M=2!D97-T96ML96UE;65K=&5D:7(Z(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*(RP@9G5Z>GD*;7-G:60@(E1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@
M(EG\:VQE;F5N(&1O<WEA(&MA>61E9&EL96UE9&DN(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(D)A:_UM
M.CH@<_UN_68@8F'^87+]>6QA('G\:VQE;F5M961I+B(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("+>9>=E;F5K
M;&5R('!E;F-E<F5S:2!K87!A;F3]+L?]:_W^('EA</UL_7EO<BXB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+B(*;7-G<W1R("(B"B)%\&5R(&EZ:6YL97)I(&MU;&QA;FUA:R!I<W1I>6]R
M<V%N_7H@>?9N971I8VEN:7II;B#=>FEN('-I<W1E;6EN:2`B"B)Y87#];&%N
M9/UR;6%S_2!G97)E:VUE:W1E9&ER+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T
M;VT@<VED92!O;FQY(@IM<V=S='(@(E-A9&5C92!A;'0@=&%R868B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM
M<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A
M=&%B87-E+B(*;7-G<W1R("(B"B+=;&5T:?YI;2!N;VMT87/];OUN($E$)W-I
M(&)E;&ER;&5N96UE9&DL(&)O_B!B_7)A:_UL;?W^('9E>6$@=F5R:2!T86)A
M;OUN9&$@(@HB8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(MUL971I_FEM(&YO:W1A<_T@8F'^87+]>6QA(&%D<F5S(&1E9G1E<FEN
M:7IE(&5K;&5N9&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92XB"FUS9W-T<B`B(@HBQ_UK87)T_6QM_?X@4$=0(&EM>F$@]F)E\&D@:6UZ
M86QA;FW]_B!I;&5T:6YI;B!D;_!R=6QU\'5N=6X@<V'P;&%N;6%S_2!IYVEN
M("(*(F=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T
M<B`B(@HB1&'P_73];2!L:7-T97-I($E$)W-I(&)E;&ER;&5N96UE9&DL(&)O
M_B!B_7)A:_UL;?W^('9E>6$@=F5R:2!T86)A;OUN9&$@(@HB8G5L=6YA;6%D
M_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+B(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VD@8F5L:7)L96YE
M;65D:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I
M9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BWFEF<F5L96UE(/9Z96QL:6ML97)I
M(&?\=F5N;&D@8FER('=E8B!B8?!L86YT_7/](&=E<F5K=&ER;65K=&5D:7(N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R
M("(E<R!D;W-Y87/]("5S(&%Y87+](&GG97)M96QI9&ER+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B5S(&1O
M<WEA<_T@)7,@87EA<FQA<OT@:>=E<FUE;&ED:7(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1&]S>6$@:V5N9&D@
M_'IE<FEN92!K;W!Y86QA;F%M87HN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB
M"FUS9W-T<B`B1&]S>6$@=F5R:2!IYV5R;6EY;W(N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92XB"FUS9W-T<B`B5&%K:7`@961E;FQE<B!B=2!I;&5T:2]R
M9F,X,C(@:6QE=&ES:2!IYVEN(&)A_FS]:R!B:6QG:6QE<FED:7(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I
M9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*
M;7-G<W1R("(B"B)!_F%M863]\/UM_7H@=&%R87G]8_T@:&%T86QA<OT@<V5B
M96)I>6QE('1A;2!E:W)A;B!K:7!I;FEN($EN=&5R;F5T("(*(D5X<&QO<F5R
M)VQA(&)I<FQI:W1E('-O<G5N(.?]:V%R9/WP_2!B:6QI;FUE:W1E9&ER+B!!
M;FQA;7/]>B!G]G+\;G3\;&5R;&4L("(*(N=A;/W^;6%Y86X@;65T:6X@9/QZ
M96YL97EI8VD@:?YL97)I>6QE('9E+W9E>6$@=&%R87G]8_UN_6X@<F%S=&=E
M;&4@(@HBY_9K;65S:7EL92!K87+^_6QA_F%B:6QI<G-I;FEZ+B!%\&5R('-I
M<W1E;6EN:7H@5VEN9&]W<R`Y>"!I<V4@>?QK<V5K("(*(FEH=&EM86P@)T=E
M;F5R86P@4')O=&5C=&EO;B!&875L="<@:&%T87/](&%L_7`@<VES=&5M:2!Y
M96YI9&5N(&)A_FQA=&UA;OUZ("(*(F=E<F5K96-E:RY<7&Y<7&Y"=2!B:7(@
M=7EA<OUY9/TN($7P97(@:&%L82!T86T@96MR86X@;65T:6X@9/QZ96YL97EI
M8VES:6YI("(*(F1E;F5M96L@:7-T:7EO<G-A;OUZ($5V970G:2!T_6ML87G]
M;BXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R(")+:6UL:6L@7"(E<UPB('-I;&EN9&DN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4V%D96-E('-O;"!T
M87)A9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM
M<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S
M="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@
M(D-R>7!T7W!G<#HZ('/];OUF_6YA($=N=5!'(&EK:6QI<VEN:6X@:V]N=6UU
M('9E<FEL;65K('IO<G5N9&%D_7(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S
M(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM
M<V=S='(@(B(*(B5S('1A<FEH:6YD92`E<R!E(&?V;F1E<FEL96X@7"(E<UPB
M(&MO;G5L=2!I;&5T:2!G]G+\;G3\;&5N9&DN7&XB"B)"=2!I;&5T:6YI;B!O
M:W5N9'7P=2!V97EA(&%N;&'^_6QD_?#];OT@9V%R86YT:6QE;65M96MT961I
M<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4
M:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A
M9V4B"FUS9W-T<B`B3VQU_G1U<B!P96YC97)E<VEN92!B8?!L86[]<FME;B!K
M=6QL86[];&%C86L@:7-I;2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@
M;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")"=2!A;&%N(&=EYV5R;&D@8FER
M(&YU;6%R82!O;&UA;/UD_7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@
M<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*
M;7-G<W1R(")(;W)D95]#<GEP=%]S:6UE.CH@<_UN_6;](&]P96YS<VP@8FER
M:6UI(&GG:6X@9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E
M9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S
M(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B
M"FUS9W-T<B`B(@HB7"(E<UPB('1E<F-I:&D@=F5R:7-I(&EZ:6X@=F5R:6QE
M;B!E;B!Y_&MS96L@8F]Y=71U(&=EYW1I\&D@:>=I;B`B"B)K87ED961I;&5M
M96UE:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E
M8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I
M<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W
M97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P
M<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G
M<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@
M9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB0G4@=F5R:2!Y87!S
M_6[]*"5S*2!G]G-T97)M96L@:>=I;B!K=6QL86[];&%N('!R;V=R86T@<VES
M=&5M9&4@(@HB8G5L=6YM86UA:W1A9/UR+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W
M"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R
M(")3861E8V4@<V]L('9E('-A\"!T87)A9FQA<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")3861E8V4@<V'P('1A
M<F%F(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED
M(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(EPB)7-<(B!S=6YU8W5S=2!S:6QI;F1I
M+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R(")<(B5S7"(@<W5N=6-U<W4@:V%Y9&5D:6QD:2XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R
M("(E<R!IYVEN(&]L86X@_'EE;&EK(&ES=&7P:2!S:6QI;F1I+B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE
M('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D)E;&ER
M=&EL96X@<V%T_7(@8G5L=6YM86UA:W1A9/UR+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(D=EYVEC:2!D;W-Y82!<(B5S7"(@8G5L=6YM86UA:W1A9/UR+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO
M=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E
M;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'DB"FUS9W-T<B`B4V%D96-E(/QS="!V92!A;'0@=&%R869L
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")3
M861E8V4@_'-T('1A<F%F(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B0FER(/9N8V5K:2!A9/UM('/]
M<F%S_6YD82!Y_&ML96YE;B!V97)I(&MA>6)E9&EL9&DN(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A
M+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N(@IM<V=S='(@(EG\:VQE;F5N(&1O<WEA(&MA>61E9&EL
M96UE9&DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")W96%T:&5R+F-O;2!K=6QL86[];&%B:6QI<B!D
M9?!I;"XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B5&5M82!D:7II;FD@)R5S)R!B=6QU;F%M863]
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED
M(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DAI
MYV)I<B!S9>=E;F5K(&UE=F-U="!D9?!I;"XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")-
M971N92!G]FW\;/P@;VQA<F%K(&?V<W1E<FEL96)I;&5C96L@:_US_6T@>6]K
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB
M0G4@86QA;F1A(.=O:R!F87IL82!K87)A:W1E<B!V87(N)7,@=&%N92!K87)A
M:W1E<B!G:7)D:6YI>CL@)7,@=&%N961E;B!A>B`B"B)G:7)M96YI>B!G97)E
M:VER9&DN(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B<E
M<R<@<VES=&5M92!E:VQE;FER:V5N(&)I<B!S;W)U;B!O;'7^='4Z("5S(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B<E<R<@:W5L
M;&%N_6/];OUN('9E<FEL97)I;FEN('-I<W1E;61E;B!S:6QI;FUE<VEN9&4@
M<V]R=6X@=F%R.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B<E<R<@:W5L
M;&%N_6/]<_UN_2!S:7-T96UD96X@Y_UK87)T_6QM87/];F1A('-O<G5N('9A
M<CH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B)R5S)R!G_&YC96QL96YI<FME;B!S;W)U;B!O;'7^
M='4Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T
M<B`B1&]S>6$@*&MA<O[]9&%N*2!Y_&ML96YM97-I;F1E('-O<G5N('9A<CH@
M)7,@>?QK;&5N96UE9&DN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN(@IM<V=S='(@(B(*(D1O<WEA('G\:VQE;FER:V5N(&)I<B!S;W)U;B!O
M;'7^='4Z("5S(&5N(&+\>?QK(&EZ:6X@=F5R:6QE;B!B;WEU='1A;B`H)60@
M(@HB8GET92D@9&%H82!B_'G\:RXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B1&]S>6$@>?QK
M;&5N:7)K96X@8FER('-O<G5N(&]L=?YT=3H@)7,@<V%D96-E(&O]<VUI(&]L
M87)A:R!Y_&ML96YD:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("));&5T:6YI;B!B
M=2!K_7-M_6[](&?V<OQN=/QL96YM97-I;F1E(&AA=&$@;VQU_G1U+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82XB"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S_6[];B!V97)I;&5R:2`H:>=E
M<FDI(&%K=&%R_6S]<FME;B!H871A(&]L=?YT=2XB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")I0V%L
M96YD87(@=F5R:7-I("AIYV5R:2D@86MT87+];/UR:V5N(&AA=&$@;VQU_G1U
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G
M<W1R("(B"B)987#];&%N9/UR;6$@9F]R;75N9&$@8FER(&AA=&$@=F%R+B!'
M97)E:VQI(&)I<B!A;&%N_2!D;VQD=7)M86W]_B`B"B)O;&%B:6QI<G-I;FEZ
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN
M9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E
M("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB0F5L:7)T:6QE;B!A
M9')E<R!D969T97)I(&G^;&5V:6YI;B!G97+G96ML9?YT:7)I;&UE<VD@<_UR
M87/];F1A('-O<G5N("(*(F]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K
M<F%R(&1E;F5Y:6XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"B+=;&5T:?YI;2!N;VMT87/];OUN(&%Y
M<OUN=/UL87+];OT@9_QN8V5L;&5R:V5N(&AA=&$@;VQU_G1U+B!,_'1F96X@
M9&%H82`B"B)S;VYR82!T96MR87(@9&5N97EI;BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB1&'P_73]
M;2!L:7-T97-I;FD@9_QN8V5L;&5R:V5N(&)I<B!H871A(&]L=?YT=2X@3/QT
M9F5N(&1A:&$@<V]N<F$@=&5K<F%R("(*(F1E;F5Y:6XN(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+B(*;7-G<W1R(")"=2!)34%0('-U;G5C=7-U('!A>6QA_OUL86X@9&EZ:6YL
M97)I(&1E<W1E:VQE;6EY;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B0G4@9V7G97)L
M:2!B:7(@<F%R(&%R_FEV:2!D9?!I;"XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")"=2!G9>=E
M<FQI(&)I<B!Z:7`@9&]S>6%S_2!D9?!I;"XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B0G4@9V7G97)L:2!B
M:7(@:V%R="!N=6UA<F%S_2!D9?!I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D)U('/\<OQC_"!#
M;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&'P(&=EYVED:2#\
M>F5R:6YD96X@2%144"!!4$D@(@HB:W5L;&%N87)A:R!M97-A:B!A=&UA;OUZ
M82!I>FEN('9E<FER+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@HB0G4@<_QR_&/\('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"D@8?`@9V7G:61I(/QZ97)I;F1E;B!(5%10($%022`B"B)K=6QL
M86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)"=2!S
M_'+\8_P@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL*2!A\"!G9>=I9&D@
M_'IE<FEN9&5N($A45%`@05!)("(*(FMU;&QA;F%R86L@;65S86H@871M86[]
M>F$@:7II;B!V97)I<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T
M:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T
M<B`B(@HB0G4@<_QR_&/\(%--5%`@>6]L=7EL82!6;V1A9F]N92!)=&%L>2!A
M\"!G9>=I9&D@_'IE<FEN9&5N+"!S861E8V4@5F]D969O;F4@(@HB;G5M87)A
M;&%R_6YA(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N(%9O9&5F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="D@(@HB96QE:W1R;VYI:R!P;W-T82!A
M9')E<VD@9V5R96MT:7)M96MT961I<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")"=2!G97)E:VQI(&)I
M<B!A;&%N9/UR+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`B0G4@86QA;B!S861E8V4@<V%Y_2!IYV5R;65L:61I<BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*
M;7-G<W1R(")"=2!A;&%N('-A9&5C92!S87G]('9E(&EK:2!N;VMT82#\<W3\
M<W1E(&G^87)E=&D@:>=E<F5B:6QI<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")"=2!A;&%N('-A9&5C92!S96MI
M>FQI:R!S87G]('-I<W1E;6EN9&5N(&1E\&5R;&4@:>=E<F5B:6QI<BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R(")"=2!A;&%N('9I<F?\;"!V97EA(&)O_FQU
M:VQA(&%Y<OUL;?W^('-A>?T@;&ES=&4@;VQM86S]9/UR+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")"=2!A;&%N(&=EYV5R;&D@
M8FER(&YU;6%R82!O;&UA;/UD_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R(")"=2!A;&%N(%)'0B!(97@@8FGG
M:6UI;F1E(&)I<B!R96YK(&MO9'4@:>=E<FUE;&ED:7(L(/9R;F5K.B`G(S$R
M,S1A9B<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@
M(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T
M<B`B0G4@9F]R;2!Z871E;B!I_FQE;F1I+B(*"B,Z('1E;7!L871E<R]H96QP
M+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N
M(@IM<V=S='(@(D)U("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B
M"B)"=2!B:7(@2V]L86(@1W)O=7!W87)E(&YE<VYE<VED:7(N($)U(&YE<VYE
M>6D@9_9R96)I;&UE:R!IYVEN($MO;&%B("(*(D=R;W5P=V%R92!B:>=I;6EN
M:2!A;FQA>6%B:6QE;B!B:7(@96QE:W1R;VYI:R!P;W-T82!I<W1E;6-I<VEN
M92!G97)E:R!V87(N0G4@(@HB96QE:W1R;VYI:R!I<W1E;6-I(&QI<W1E<VD@
M:>=I;B`E<R!A9')E<VEN92!U\')A>?UN+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E
M<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B0G4@:6QE=&D@<VEZ
M:6X@:V%R86MT97(@:_QM96YI>F1E;B!F87)K;/T@;VQA<F%K*"5S*2!Y87K]
M;&W]_G3]<BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM
M<V=S='(@(D)U(&YU;6%R82!E;B!A>OUN9&%N(&)I<B!O;&UA;/UD_7(N(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS
M9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII
M<"!F:6QE<RXB"FUS9W-T<B`B0G4@<W5N=6-U('II<"!V92!G>FEP(&1O<WEA
M;&%R_6[](&'G86UA;6%K=&%D_7(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B4VES=&5M:6X@971K:6YL
M:?!I(&MA;&3]<OUL;?W^=/UR+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N(@IM<V=S='(@(D)U(&1E\&5R(&)I<B!S87G](&]L;6%L_63]<BXB"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W(@IM<V=S='(@(D)U('!E;F-E<F4@4V7G96YE:VQE<B!P96YC97)E<VEN
M9&5N(.=A\'+];&UA;/UD_7(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B1_9K
M(&?\<OQL=/QS_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*
M;7-G:60@(E1I8VME=',B"FUS9W-T<B`B0FEL971L97(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("):86UA;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B
M"FUS9W-T<B`B6F%M86X@W7IL96UE(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("):86UA;B!":>=I;6DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE
M('-E;&5C=&EO;B(*;7-G<W1R("):86UA;B!39>=I;6DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(D)A_FS]:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B0F'^
M;/UK("AAY_UK;&%M82DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B2VEM92(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G
M:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@
M8VQI8VMI;F<N(@IM<V=S='(@(B(*(L=O:VQU(/;P92!S9>=I;6D@:>=I;BP@
M=/UK;&%R:V5N($-O;G1R;VP@*%!#*2!V97EA($-O;6UA;F0@*$UA8RD@='7^
M=6YA("(*(F)A<_UN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D)U9_QN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G
M9VQE($A434P@4V]U<F-E(@IM<V=S='(@(DA434P@2V%Y;F'P_6YA($=EYVEN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B66%R_6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S
M='(@(MQS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`BW'-T
M(,=E<N=E=F4@*-Q?<W0I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`BQV5V:7)I;&5R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R
M(")4<FEN:61A9"!V92!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(D1O\')U
M('9E>6$@66%N;/W^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B4V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;G5S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E3\<FMI>64B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X
M-3DM.2DB"FUS9W-T<B`B5/QR:^=E("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4_')K;65N:7-T
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',B"FUS9W-T<B`B5'5R:W,@=F4@0V%I8V]S($%D86QA<OTB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H
M;VEC93H@(@IM<V=S='(@(E-EYVEM:6YI>FD@9VER:6XZ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@
M(@IM<V=S='(@(E4N5BX@96YD96MS.B`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R
M(")"971I:VQE<FEN(&1U<G5M(')A<&]R;&%R_6[];B!T97-L:6T@961I;&5C
M9?!I(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E5K<F%Y;F$B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&1I>FEN:6YE
M(&5R:?YI;&5M96UI>6]R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`BW'EE(&]L=7)K
M96X@96L@:W5L;&%N_6/](&)I;&=I<VD@96ML96YE;6EY;W(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!61E,@9&]S>6%S_6[];B!I>FEN;&5R
M:2!D9?!I_G1I<FEL96UI>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B5S+R5S(%9&4R!D;W-Y
M87/];OUN(&EZ:6YL97)I(&1E\&G^=&ER:6QE;6EY;W(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B)7,@9&7P:?YT:7)I
M;&5M961I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B5D93(&1O<WEA<_T@7"(E<UPB
M(&'G_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O
M)7-<(BXB"FUS9W-T<B`B)7,O)7,@5D93(&1O<WEA<_T@>65N:61E;B!A9&QA
M;F3]<OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H
M<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M(@IM<V=S='(@(E-13"!S=6YU8W5S=6YA(&)A\&QA;OUL86W]>6]R+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B4U-,(&EL92!B8?!L86[]
M;&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`Y"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T
M<B`B5D93(&1O<WEA<_T@:V]P>6%L86YA;?UY;W(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M7"(E<UPB(%9&4R!D:7II;FD@>6%R873];&%M_7EO<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(E9&4R!D:7II;FD@>6%R873];&%M_7EO<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!Y87)A=/UL86W]
M>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@>65N
M:61E;B!A9&QA;F3]<OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92XB"FUS9W-T<B`B0F_^(%9&4R!D;W-Y87/]('EA<F%T_6QA;?UY
M;W(N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z
M-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")6
M97)I('/]:_W^=/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"(@9&EZ
M:6YI('-I;&EN96UI>6]R+"!D:7II;B!B;_X@9&7P:6PN(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(CH@)7,N(@IM<V=S='(@(B<E<R<@<VEL:6YE;6EY;W(Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B)7,@<VEL:6YE;6EY;W(L(&1I
M>FEN(&)O_B!D9?!I;"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+B(*;7-G<W1R(")61E,@9&EZ:6YI(/9Z>6EN96QI(&]L87)A:R!S:6QI
M;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(")61E,@9&EZ:6YI('-I;&EN96UI>6]R+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(E9&4R!D:7II;FD@<VEL:6YE;6EY
M;W(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@<VEL:6YE;6EY
M;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`B5D93(&1O<WEA<_T@<VEL:6YE;6EY;W(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(E9&4R!D;W-Y87/](%PB)7-<(B!S:6QI;F5M:7EO
M<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L
M>3H@)7,N(@IM<V=S='(@(E9&4R#V>GEI;F5L:2!O;&%R86L@<VEL:6YE;6EY
M;W(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R(")9_'+\<FS\:W1E:VD@9&EZ:6YE(&MA<F%R('9E<FEL96UI>6]R
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS
M9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM
M<V=S='(@(D]N87D@8F5L9V5S:2!A>7+];G3];&%R_2#G_6MA<G3];&%M_7EO
M<B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R(")486[];?T@>?QK;&5N96UI>6]R.B`E<R(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V
M-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1O<WEA<_T@
M=&'^_6YA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY
M,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(&1O<WEA<_T@7"(E<UPB(&'G_6QA
M;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(E9&4R!D;W-Y87/]
M('EA;6%K(&GG:6X@8>?];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1O<WEA<_T@
M8>?];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N(@IM<V=S='(@(E/]:_W^=/UL_6W]_B!A<OYI=B!AY_UL86W]>6]R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(E9&4R!D;W-Y87/]('EA>OUL86W]>6]R("AC;W!Y*"D@
M8F'^87+]<_UZ(&]L9'4I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R!D;W-Y87/]('EA
M>OUL86W]>6]R("AC;W!Y*"D@8F'^87+]<_UZ(&]L9'4I+B(*"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS
M.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S
M='(@(E9&4R!D;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B5F9S
M<F]O="!D:7II;FD@;VMU;F%M_7EO<BXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B5S+3XE<R!O;&%R86L@>65N:61E;B!A9&QA;F3]
M<OUL86W]>6]R.B!H961E9B!D:7II;B!Z871E;B!V87(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@9&EZ:6YI('EE
M;FED96X@861L86YD_7+];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")61E,@9&EZ:6YI
M('EE;FED96X@861L86YD_7+];&%M_7EO<CH@)7,B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(&1O<WEA<_T@7"(E<UPB('EE
M;FED96X@861L86YD_7+];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R("(E<R\E<R!61E,@9&]S>6%S_2!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92XB"FUS9W-T<B`B5D93(&1O<WEA<_T@>65N:61E;B!A9&QA;F3]<OUL86W]
M>6]R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M
M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M(@IM<V=S='(@(B=M:VES;V9S)R#G86S]_G3]<OUL86W]>6]R+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@
M(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S
M='(@(D)U(%=O<F0@8F5L9V5S:2#G979I<FEL:6QE;6EY;W(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(&1O<WEA<_T@7"(E
M<UPB('EA>OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93(&1O<WEA<_T@>6%Z_6QA;?UY;W(@
M*&-O<'DH*2!B8?YA<OUS_7H@;VQD=2DN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@
M(E9&4R!D;W-Y82!V97)I<VD@>6%Z_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@T,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M(")61E,@9&]S>6%S_2!Y87K];&%M_7EO<B`H8V]P>2@I(&)A_F%R_7/]>B!O
M;&1U*2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B06QT_6[](.=I>B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA
M;F=E<R(*;7-G<W1R(")$9?!I_FEK;&EK;&5R:2!'97)I($%L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B
M56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B4V]N(&5Y;&5M:2!G
M97)I(&%L(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O
M;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B0F'P;&%N=/UD82!S=6YU8W5D86X@
M8F5K;&5N;65Y96X@>6%N_70Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@(@IM<V=S='(@(E-U;G5C=61A;B!B96ML96YM97EE;B!Y
M86[]=#H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B1&]L9'5R=6QM
M86W]_B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(D)I
M<FQE_FEK($%R87`@16UI<FQI:VQE<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(D)I<FQE_FEK($MR86QL_6LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(D%M
M97)I:V$@0FER;&7^:6L@1&5V;&5T;&5R:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G
M<W1R(")!;65R:6MA($)I<FQE_FEK($1E=FQE=&QE<FEN:6X@2_SG_&L@57IA
M:R!!9&%L87+](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@
M(D)I<FEM;&5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B
M56YK;F]W;B(*;7-G<W1R(")":6QI;FUE>65N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(D)I;&EN
M;65Y96X@87!I;7-G:60@*$%022!-97-A:B!)1"DB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N
M:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B
M0FEL:6YM97EE;B!C;&EM<V=I9"`HW7-T96UC:2!M97-A:B!)1"DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED
M(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")(:>=B:7(@
M>65R(&)E;&ER=&EL;65D:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA
M;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(D)I;&EN;65Y96X@:W5L;&%N_6/]
M(&%D_2!V97EA('!A<F]L82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(MYU(&%N:VD@]O!E;FEN(&)A\/UN
M_2#G]GHB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y
M-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+=<VEM<VEZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)!>7+]8V%L
M_6MS_7H@8F5T:6ML97(@<')O9W)A;7-A;"!O;&%R86L@2V5S+TMO<'EA;&$O
M66%P_?YT_7(G82!G_'9E;FQI:R`B"B)N961E;FEY;&4@97)I_F5M97IL97(N
M($)E=&EK;&5R:6X@<&%N;WEA(&YA<_UL('5L8?YA8V'P_6[](&?V<W1E<F5N
M(&UO>FEL;&$N(@HB;W)G('1E:VYI:R!N;W1U;G4@9_9R;65K(&GG:6X@159%
M5"!I('3]:VQA>?UN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S
M='(@(D)E;&ER=&EL;6G^(')E;FMT96X@=F%Z9V7G(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G
M<W1R(")$97-T96ML96YM97EE;B!5>F%N=/TB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D?\;F-E;&QE(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B1_QN8V5L;&4Z("5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B
M57!D871E('5S97(B"FUS9W-T<B`B2W5L;&%N_6/]>?T@9_QN8V5L;&4B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(D?\;F-E
M;&QE;F1I.B`G)7,G(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*
M;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(EG\:W-E
M;'1M92!B971I\&D@<VEL:6QN9&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B6?QK;&4B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B0OQT
M_&X@=7EG=6QA;6%L87+];B!A>6%R(&1O<WEA;&%R_2!S=6YU8W5Y82!Y_&ML
M96YD:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(D+\>?QK(&QA=&EN(&AA<F9L97)I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B
M57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")"_'G\:R!R;VUA(')A:V%M
M;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M57)U9W5A>2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT
M.B`E<R(*;7-G<W1R(")+=6QL86XZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB
M"FUS9W-T<B`B4U-,(&MU;&QA;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(DMU;&QA;OUC_2!A9/UN_7HO
M<&%R;VQA;OUZ($E-4U`@<W5N=6-U(&GG:6X@9F%R:VS](&ES92!K=6QL86[]
M;BXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L
M(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(DMU;&QA;OUC_6QA<B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R("(E<R!K=6QL86[]8_US_2`E<R!IYVEN(&1O\')U;&%N
M86UA9/TN(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(DMU;&QA;OUC_2!9]FYE=&EM:2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`B2W5L;&%N_6/](%-EYV5N96ML97)I(@H*(SH@
M<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T
M<B`B2W5L;&%N_6/]($MA>?UT(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92XB"FUS9W-T<B`B0G4@<VET92!IYVEN(&MU;&QA;OUC_2!K87ED_2!S
M9>=I;&UE>B!K_6S];FW]_G3]<BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD
M(@IM<V=S='(@(B5S(&)U;'5N86UA9/TN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B2W5L;&%N_6/]($%D_2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X
M:7-T<RXB"FUS9W-T<B`B2W5L;&%N_6/]("<E<R<@>F%T96X@=F%R+B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA
M;64Z(@IM<V=S='(@(DMU;&QA;OUC_2!!9/TZ(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")+
M=6QL86[]8_T@863].B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")3
M:7-T96UD96MI(&MU;&QA;OUC_6QA<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")5>F)E:VES=&%N(@IM<V=S='(@(M9Z8F5K:7-T86XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R(")61E,@9&EZ:6YI('EO:RXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")4871I
M;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L
M:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")'9>=E<FQI
M(&MO;G5M;&%R_6X@:>=E<F1I:VQE<FDZ(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@
M(D=EYV5R;&EL:6LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(MYU(&%N9&%N(&ET:6)A<F5N(&1A:VEK82!D
M9?!E<FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6
M86QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")6
M86QU97,B"FUS9W-T<B`B1&7P97)L97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G
M:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")$9?!E<FQE<FEN
M('-EYVEL96-E\&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM
M<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R(")$9?!I_FME;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E
M;&QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*
M;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")$;_!R=6QA;6$@
M8F'^87+]<_UZ(&]L9'4@+2!B=2!I;&5T:2!K=7)C86QA;FW]_B!O;&%B:6QI
M<BX@("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P
M"FUS9VED(")697)S:6]N(@IM<V=S='(@(E/\<OQM(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM
M<V=S='(@(E/\<OQM($MO;G1O;/PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A
M;&EG;B(*;7-G<W1R(")$_/YE>2!(:7IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D
M9&EN9R(*;7-G<W1R(")$_/YE>2!Y87-T_6ML86UA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC
M86PZ(@IM<V=S='(@(D3\_F5Y.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B
MQV]K(%G\:W-E:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM
M<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM
M<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M8V$@
M*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")'
M]G+\;G3\;&4@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED
M(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(D)I<B!D_?X@
M=V5B('-A>69A<_T@9_9R_&YT_&QE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M87,@)7,B"FUS9W-T<B`B)7,@;VQA<F%K(&?V<OQN=/QL92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@
M(D)R:71A;GEA)WEA(&%I="!6:7)G:6X@061A;&%R_2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(D%M97)I
M:V$@0FER;&5R_FEK($1E=FQE=&QE<FDG;F4@86ET(%9I<F=I;B!!9&%L87+]
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B1_9R_/XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B1_9R_/XZ
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S
M='(@(E--5%`@>6]L=7EL82!6;V1A9F]N92#==&%L>6$B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(E=!4DXB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T
M<B`B55E!4DDA(2$E<R#=Q]U.1$5.($)%5-W0W2!%3"#=3$4@QTE+05)424XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*
M(RP@9G5Z>GD*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")(5%10('EO
M;'5Y;&$@<VUS,F5M86EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES
M(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES('9E($9U='5N82(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R(")5>6%R_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(L=R_B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A
M=&AE<B!&;W)E8V%S="(*;7-G<W1R(")(879A(%1A:&UI;FDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A
M=&$@<')O=FED960@8GDB"FUS9W-T<B`B2&%V82!V97)I<VD@<V'P;&%Y_6/]
M<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E
M871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*
M;7-G<W1R(")796(@4VET97-I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(DAA
M9G1A;/UK(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`B2&_^9V5L9&EN:7HB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G
M<W1R("(E<R!(;_YG96QD:6YI>B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")(;_YG96QD:6YI
M>BP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B0F%T_2`H25-/+3@X-3DM,2DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,34I(@IM<V=S='(@(D)A=/T@*$E33RTX.#4Y+3$U*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R(")"873]
M(%-A:')A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(E<R!G:7)I_G1E;B!S;VYR82!H
M86YG:2!U>6=U;&%M87G](&?V<OQN=/QL97-I;C\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B4_UN_7)L87G]8_T@:V%R86MT97(@
M;F5D:7(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G
M:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B06MT
M87+];2!K87)A:W1E<FD@;F5D:7(_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*(RP@9G5Z>GD*;7-G:60@(E=H97)E
M:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")!=G5S='5R86QY82(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S
M='(@(DAA;F=I($5V<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S
M"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*(EIE;F=I;B!-971I;B!D_'IE;FQE
M>6EC:7-I(&GG:6X@:&%N9VD@=7EU;6QU(&5K;&5R('-EYVEL96)I;&ER(&O]
M;/UN<_UN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(D=E;FG^;&EK
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(D-34R!B:7)I;6EY;&4@9V5N:?YL
M:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M
M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R(")3;VQD86MI
M("5S(&UE;OQS_&[\;B!G96YI_FQI\&D@*&)I<B!S;VYR86MI(&=I<FG^=&4@
M971K:6X@;VQA8V%K*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM
M<V=S='(@(L=I>F5L9V5N:6X@9V5N:?YL:?!I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N
M:70B"FUS9W-T<B`B1V5N:?YL:6L@8FER:6UI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*
M;7-G<W1R(")'96YI_FQI:SHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(E+\>F=A
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V
M"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(D5R:V5N(%-A871L97)D92!2
M_'IG87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD
M('-P965D(&EN(&MN;W1S(@IM<V=S='(@(DMN;W0@8FER:6UI;F1E('+\>F=A
M<B!H_7K](@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I
M;F0Z(@IM<V=S='(@(E+\>F=A<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B4OQZ9V%R.B`B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*
M;7-G<W1R(")":6QG96QI:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.38*(RP@9G5Z>GD*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(MUS=&5K
M($QI<W1E<VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@
M(E=O<FLB"FUS9W-T<B`BW?XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R
M("+=_B!!9')E<VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(MW^(%1E
M;&5F;VYU(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&EZ:6YI('EA
M<F%T_6S]<FME;B!E<FG^:6T@96YG96QL96YD:2XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E
M9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS
M9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S
M(%1E;65L($O]<_UT;&%M86QA<OTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G92(*;7-G<W1R(")8-3`Y=C,@1V5N:?YL971I;&UI_B!!;F%H=&%R($MU
M;&QA;OUM_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM
M<V=S='(@(E@U,#EV,R#6=&5K:2!+;VYU($%D_2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@2V]N=2!!;F%H=&%R
M(%1A;OUT_6/]<_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P
M.78S('5Z86YT_6QA<OTB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B65DB"FUS9W-T<B`B65DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-34*;7-G:60@(EE965DB"FUS9W-T<B`B65E962(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X
M"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2!H87)I=&%S_2(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*
M;7-G:60@(EEE87)L>2(*;7-G<W1R(")9_6QL_6LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")996UE;B(*;7-G<W1R(")996UE;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G
M<W1R(")%=F5T(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")%=F5T
M+"!+86)U;"!%9&EY;W)U;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%
M+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)
M5UE'+B(*;7-G<W1R("(B"B)-153=3B!-3T153D1!4TE.25HN(%L\/ET@9/SP
M;65L97)I;FD@:W5L;&%N87)A:R!765-)5UE'(&?V<OQN_&W\;F4@9/9N_&XN
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"XB"FUS9W-T<B`B1&_P<G5L86YA;6%D_6[]>BXB"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N
M;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M(@IM<V=S='(@(B=<7"<@:V%R86MT97)I('1A;2!A9/UN_7ID82!B=6QU;F%M
M87HN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(D=EYV5R;&D@8FER
M(&5L96MT<F]N:6L@<&]S=&$@861R97-I(&=I<FUE9&EN:7HN(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T
M960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N
M(@IM<V=S='(@(B(*(B5S(&GG:6YD92!K87+^_6S]:R!G96QE;B!A;&%N;&%R
M;&$@*&GG97)I*2!A:W1A<OUL86X@9&]S>6%D86MI(&%L86YL87+]("(*(F7^
M;&7^=&ER;65D:6YI>BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B
MQ_UK_?X@>6%P;6%D_6[]>BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E
M;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@
M)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB
M"FUS9W-T<B`B(@HB1V7G97)L:2!B:7(@8V5P('1E;&5F;VYU(&YU;6%R87/]
M(&=I<FUE;&ES:6YI>BP@<V%Y_6QA<B!V92!S9>=E;F5K;&D@;VQA<F%K("(*
M(G5L=7-L87)A<F%S_2!A<F%M82#V;F5K:2`G*R<@(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!V86QU92XB"FUS9W-T<B`B1V7G97)L:2!B:7(@9&7P97(@9VER
M;65L:7-I;FEZ+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`BW'EE(&MA>63]('EA<&%B
M:6QM96L@:>=I;B!B:7(@5F5R:4'P86/]('EA</UL86YD_7)M86S]<_UN_7HN
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")61E,@
M<V]N(&'^86UA<_UN_2!Y87#];&%N9/UR;6%L_7/];OUZ+B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B4')O8FQE;2!R87!O<G4@9_9N9&5R
M;65D96X@]FYC92!S;W)U;G4@=&%R9FD@971M96QI<VEN:7HN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O(@IM<V=S='(@(D)U(&)A\&QA;G3];OUN(&?V<W1E<F1I\&D@8FER(%52
M3"!G:7)M96QI<VEN:7HB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R(")3:6QI;FUE<VD@:>=I;B!B:7(@<W5N=6-U('-E
MYVUE;&ES:6YI>BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S
M='(@(E1E;6EZ;&5N;65S:6X@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI
M<G1M96QI<VEN:7HN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R
M(")3:6QI;FUE<VD@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI<G1M96QI
M<VEN:7HN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(D5K;&5N;65S:2!IYVEN(&)I
M<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92XB"FUS9W-T<B`B1_QN8V5L;&5N;65S:2!IYVEN(&)I
M<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B
M1V5RYV5K;&7^=&ER:6QE8V5K(&)I<B!E>6QE;2!B96QI<G1M96QI<VEN:7HN
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M
M92XB"FUS9W-T<B`B665N:2!K871E9V]R>2!A9/T@9VER;65L:7-I;FEZ+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M)7,@;W1U<G5M=6YU;B!S_')E<VD@9&]L9'4N($S\=&9E;B!T96MR87(@9VER
M:?X@>6%P_6XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")%;&5K=')O
M;FEK(%!O<W1A($%D<F5S:6YI>B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B2VEM
M9&5N.B!A9')E<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF
M;W)M871I;VXB"FUS9W-T<B`B0FEL9VEL97)I;FEZ(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB
M)7,@;W1U<G5M=6YU>G5N(&)A_FQA;F?]8_UN9&$@W6YT97)N970@061R97-I
M;FEN:7H@9&7P:?YT:2X@1_QV96YL:?!I;FEZ:2`B"B)K;W)U;6%K(&GG:6XL
M('EE;FED96X@9VER:?X@>6%P;6%L_7/];OUZ+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B063];OUZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC
M.C4*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I
M<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT
M<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0N(@IM<V=S='(@(B(*(DMI;6QI:R!D96YE=&EM:6YI>B!K=6QL
M86[]8_T@96ML96UE>6D@9&5S=&5K;&5M96UE:W1E9&ER+"!V97EA(&)U(/9Z
M96QL:6L@(@HB8FER(&YE9&5N('G\>OQN9&5N('-EYVEL96UE>B!K_6S];FW]
M_G3]<BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*
M;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T
M<B`B(@HB2VEM;&EK(&1E;F5T:6UI;FEZ(&MU;&QA;OUC_2!L:7-T96QE;65Y
M:2!D97-T96ML96UE;65K=&5D:7(@=F5Y82!B=2#V>F5L;&EK("(*(F)I<B!N
M961E;B!Y_'K\;F1E;B!S9>=I;&5M97H@:_UL_6YM_?YT_7(N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@HB)7,@;W1U<G5M=6YU>G5N(&)A_FQA;F?]8_UN9&$@=&%R87G]
M8_UN_7H@9&7P:?YT:2X@1_QV96YL:?!I;FEZ:2!K;W)U;6%K("(*(FGG:6XL
M('EE;FED96X@9VER:?X@>6%P;6%L_7/];OUZ+B(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E1A<F%Y_6/];OUZ(&)U(/9Z
M96QL:?!I(&1E<W1E:VQE;65M96MT961I<BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@
M(B(*(E1A<F%Y_6/];OUZ(&)U('EA>F3]<FUA('1E<F-I:&EN:2!D97-T96ML
M96UE;65K=&5D:7(N66%Z9/UR;6%K(&GG:6X@0V]N=')O;"\B"B)/<'1I;VX@
M*R!0('1U_FQA<OUN82!B87/];BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M("):86UA;B!$:6QI;6EN:7HZ(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"XB"FUS9W-T<B`BUFX@=&%N_6UL_2!K:6UL:?!I;FEZ.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`BUFX@=&%N_6UL_2!K:6UL:?!I;FEZ
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*;7-G:60@(EEO=7(@
M9G5L;"!N86UE.B(*;7-G<W1R(")486T@063];OUZ.B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G
M:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(E-EYV5N96ML97)I;FEZ(&?\;F-E
M;&QE;F1I+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,B"FUS9W-T<B`B)7,@:>=I;B!Y96YI('!A<F]L86[]>CH@)7,B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")39>=E;F5K;&5R:6YI>B!B=2!O
M='5R=6UU;B!S_')E<VD@:>=I;F1E(&?\;F-E;&QE;F1I+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E-EYV5N96ML97)I;FEZ
M(&?\;F-E;&QE;F1I+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S
M='(@(E!A<F]L86[]>B!S_6;]<FQA;F3]+B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB4&%R;VQA;OUZ('/]
M9OUR;&%N9/TL(&5L96MT<F]N:6L@<&]S=&%N_7K](&MO;G1O;"!E9&EN('9E
M('EE;FD@<&%R;VQA;OUZ;&$@(@HB9VER:?X@>6%P_6XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,R"B,L(&9U>GIY"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")087)O;&%N_7H@<_UF_7)L
M86YD_2XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E5Z86MT86MI('-U
M;G5C=6QA<OUN_7HZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G
M;W-L879I82(*;7-G<W1R(")9=6=O<VQA=GEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I
M<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M
M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B
M6FEM8F%B=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@
M(EII<'!Y(@IM<V=S='(@(DC]>FS](@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@
M475O=&5D(%1E>'1=(@IM<V=S='(@(EM!;/UN=/T@365T;FD@4V%K;&%=(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E
M<&]R=%TB"FUS9W-T<B`B6U!R;V)L96T@4F%P;W)U72(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M(@IM<V=S='(@(EM!;/UN=/T@365T;FD@1_9S=&5R("TB
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM!;/UN=/T@365T;FD@1_9S
M=&5R("T@)7,@<V%T_7)=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM
M<V=S='(@(B5S+R5S('-A=/UR(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@
M(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?6?9N971I;2(*"B,Z(&QI8B]A
M<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB
M+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B7U9E<FE!
M\&%C_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B4V%T
M_7+](%]3:6PB"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B
M"FUS9W-T<B`B7T=R=7!L87(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")987)?9/UM(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")'
M]G+\;G3\(-9?>F5L;&EK;&5R:2XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B1VE?
M<FG^(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM
M<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BQ_U?:_W^(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED
M(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7T)A\&QA;G3]>?T@1&7P:?YT
M:7(N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T
M"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?4V7G96YE:VQE<B(*"B,Z(&QI
M8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E](
M86ML87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R
M(")"8?!L85]N=/UY_2!3:6PN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G
M:60@(E]3971U<"(*;7-G<W1R(")?07EA<FQA<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B
M7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BQVEZ95]L9V4@UGIE;&QI
M:VQE<FDN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*
M;7-G<W1R(")+7W5L;&%N_6/];&%R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C$*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")A9')E
M<R!D969T97)I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S
M='(@(F%D<F5S(&1E9G1E<FDB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B=&%K=FEM(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("+];/UM;/TB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I
M9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N
M;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S
M='(@(F)U<F%Y82!T_6ML87G];B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B
M"FUS9W-T<B`B66%P_6QA;F3]<FUA($9A<FML87+](@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS
M9W-T<B`B8G5L=6YA;6%D_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(F3\_OQY
M;W(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*;7-G
M:60@(F9I;&4B"FUS9W-T<B`B9&]S>6$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S(@IM<V=S='(@(B5S("@E<RD@9&5N("5S("5S(&1E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM
M<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(L(&;]<G3];F%L_2`E<R`E<R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G
M:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO
M<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM
M961I871E(@IM<V=S='(@(D%C:6PB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM
M<V=S='(@(DUE=&YE(&?V;?QL_"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B<V%T_7)L87)=(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+B(*;7-G<W1R(")M:VES;V9S($E33R!Y87!A<FME;B!H871A
M(&MO9'4Z)60N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R
M"FUS9VED(")N86UE(@IM<V=S='(@(F%D(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(F=E
M<N=E:VQE_G1I<FEL;65D:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G
M<W1R(")H96[\>B!G97+G96ML9?YT:7)I;&UE9&DB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")N
M;W0@9&5F=&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B>?QZ
M9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`BW7II
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")R97-I;2!B:7)I;6DB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R
M:7-I;F<B"FUS9W-T<B`B>?QK<V5L:7EO<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")S97)V:6-E
M('5N879A:6QA8FQE(@IM<V=S='(@(DAA=F$@<F%P;W)U(/9B9?!I(&MU;&QA
M;OUL86)I;&ER(&1E\&EL+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B9F%R:VQA<OT@
M9_9S=&5R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R
M(")(5%10('EO;'5Y;&$@<VUS,F5M86EL(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*
M;7-G:60@(G-T96%D>2(*;7-G<W1R(")S86)I="(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I
M<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(F?V<F5V(&QI<W1E<VDB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*
M(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R(")(97(@1VER:?YT
M92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FTB"FUS9W-T<B`B<&%R;VQA>?T@9&_P<G5L86UA:R!IYVEN
M(&EK:2!D969A(&=I<FEN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B8FER;&7^=&ER:6QM:?XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A
M<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(F%D;&%N9/UR_6QM
M86W]_B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B:W5L
M;&%N_6/]('-EYVEM:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS
M9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R
M+F-O;2(*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]E
M;%]'4BYP;P``````````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P-38P-C<Q`#$P-3$U-#,Q,#8S`#`Q-C,W-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````C($AO<F1E($=R965K
M('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,B!3=&5F86YO<R!)
M+B!$:6UI=')I;W4N"B,@4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS=7!P;W)T
M7W=E8FUA:6Q`=&5I871H+F=R/BP@,C`P,BX*(R!3:6QL:6=A<F1O<R!8<FES
M=&]F;W)O<RP@,C`P,BX*(R!!;F%G;F]S=&]P;W5L;W,@07!O<W1O;&ES+"`R
M,#`R+@HC($UI;&]S:7,@0RX@2V]N<W1A;G1I;F]S+"`R,#`U+@HC"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D93H@,RXP
M+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`R+3$Q+3`W(#$R.C`V
M*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#0M,C8@,3$Z,3,K
M,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!+;VYS=&%N=&EN;W,@0RX@36EL
M;W-I<R`\:VUI;&]S:7-`>6%H;V\N8V]M/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M1W)E96L@/&1E=D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ
M(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES
M;RTX.#4Y+3=<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET
M7&XB"@HC+"!C+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N(@IM<V=S='(@(B(*(B`F(S$U,3L@)7,@Q=_MX>D@YR#S].GC
M[-X@[>$@X]_M[_7M(._I(.OEZ?3O]?'CW^7R(//U[?3>\>?SY_(@\._U(.7?
M[>'I("(*(N7PZ>OEX^S=[>7R(/#A\>'JW/3Y+B(*"FUS9VED("(@(%1H92!M
M86EL8F]X('1R87-H(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(B`@QR#C
M\>'L[.'T[^CU\=_DX2`GZMSD[_(G(.7?[>'I(-[DYR#<Y.7IX2XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S4Q"FUS9VED("(@*"5S(&1A>7,@
M86=O*2(*;7-G<W1R("(@*/#QZ>T@X?#\("5S(.?LW?'E\BDB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$R-S<*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(@*,KKY>GDWR#P\?SSXN'SY_(@)7,I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,U.0IM<V=I9"`B("AI;B`E<R!D87ES
M*2(*;7-G<W1R("(@*//E("5S(.?LW?'E\BDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S4U"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*//>
M[.7QX2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S4W"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*.']\>GO*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-3,*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G
M<W1R("(@*/?HY?(I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P,`IM<V=I9"`B(&%T("(*;7-G<W1R("(@\_3I\B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED("(E9"`E<R!A;F0@)7,B
M"FUS9W-T<B`B)60@)7,@ZN'I("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R-PIM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@
M(B5D+>SE\><@\/'\XNOE^.<B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;F]T:6-E7W1O<"YI;F,Z-`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B
M)7,@+2#3Y^SEW_GSYR(*"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8SHR.0IM<V=I9"`B)7,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M)7,MQ.GA]^7?\>GSYR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S(X"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R#$
MX>KT]>OIZOP@X?#O]/WP^>SA(@H*(RP@8RUF;W)M870*;7-G:60@(B5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B
M)7,@R^7I]._U\>/?Y?(@T_7M]-[QY_/G\B`M(,7PZ>+EXN'?^?/G(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C`Y"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<RW0X?'A[.7T\>_P
M[]_G\^<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<V
M"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(,7CX_'A]MXB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z-`IM<V=I
M9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(,_Q[^D@]_'>
M\^?R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HU.38@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HV-C8*;7-G:60@(B5S(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R("(E<R#>Y.<@]?#<\??EZ2XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$U-R!L:6(O0FQO8VLO;65T87(N<&AP.C$V,R!L:6(O0FQO
M8VLO;65T87(N<&AP.C(S-PHC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,R!L
M:6(O0FQO8VLO;65T87(N<&AP.C,T.0IM<V=I9"`B)7,@870@)7,@)7,B"FUS
M9W-T<B`B)7,@\^4@)7,@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4S,`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE
M9"`E<RXB"FUS9W-T<B`B)7,@X>KU\?[HY^KE("5S+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(V"FUS9VED("(E
M<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R
M("(E<R#A\-SM].?SY2#SY2#E\?[TY^SA(.3IX>CE\^GL_/3G].'R+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(T
M"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E
M<RXB"FUS9W-T<B`B)7,@X?#<[?3G\^4@\_3G[2#P\?SSZNOG\^<@X^GA("5S
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#$V"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(E<R#SX?(@W?/TY>GKY2#PZ^?Q[_;O\=_E\B#D
MZ>'HY?/I[/STY_3A\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S(Q"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R#EW^WAZ2#A
M\.'I]._][.7M[R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@T"FUS9VED
M("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(.OE\/3<(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C$*;7-G:60@(B5S
M(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(E<R#SX?(@YM[TY_/E(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3`X"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*
M;7-G<W1R("(E<R#FWO3G\^4@].?M(/#A\>_U\]_A(//A\B#S].GR("5S+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C8*;7-G:60@(B5S
M('1O("5S(&]F("5S(@IM<V=S='(@(B5S(/GR("5S(.'P_"`E<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$S"FUS
M9VED("(E<R!W:7-H97,@=&\@861D('1O("5S+B(*;7-G<W1R("(E<R#E\.GH
M]>SEWR#TY^T@\/'O\^C>ZN<@\_3O("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`R"FUS9VED("(E<R!W:7-H
M97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B5S(.7PZ>CU
M[.7?(.WA(//A\B#E[>?LY?'^\^7I(./IX2`E<RXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q.`IM<V=I9"`B)7,@
M=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U
M="`E<RXB"FUS9W-T<B`B)7,@Y?#IZ/7LY=\@[>$@Z]SBY>D@].GR(/3EZ^7U
M].'?Y?(@\.OG\>_V[_'?Y?(@X^GA("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$R"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G
M<W1R("(E<R=S(,3IY?7H]>WSZ>_C\=SV[_(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDP-`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M("(E<R=S(,?LY?'OZ_SCZ>\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C@Y-@IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S<R#3Y^SE
MZ?GLX?3<\>GO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C`*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7-S(,O?\_3A(,7QX^'S
MZ?[M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,`IM<V=I9"`B)R5S
M)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@Y.7M(.7?
M[>'I(-WCZO7QYR#E\.GK[^/>+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-3@R"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z.3@R"FUS9VED("(G)7,G(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R#DY>T@W??E
MZ2#Q]>CLZ?/TY=\@\_3O(')E9VES=')Y(/3G\B#E]N'Q[._CWO(@2&]R9&4B
M"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-C`*;7-G:60@(B<E<R<@
M=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(.'MX?#A\>'S
M]-STY_(@Y.7MY/'IZM[R(.3O[-[R(.3E[2#B\=WHY^KE+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-3<*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(/#Q[_/TW>CGZN4@\_3I\B#O
M[-SDY?(@\_7S]-[LX?3O\BXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z.#4*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@\/'O\_3=Z.?JY2#S].GR(-SDY>GE
M\B#T[_4@\_7S]-[LX?3O\BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HX,PIM<V=I9"`B)R5S)R!W87,@;F]T
M(&-R96%T960Z("5S+B(*;7-G<W1R("(G)7,G(.3E[2#DY^SI[_7QX][HY^KE
M.B`E<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X-B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Y,0IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@
M(BP@9W5S=&EN9R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DY
M"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"#L
MY?3AXNOG]-X@X?#\("5S(//E("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`U,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV.3$*;7-G:60@
M(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2#E\.GK[^/>("TM(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G
M<W1R("(Q,OGQYR#L[_'VWB(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM
M<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C3Y\><@[._Q]MXB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B
M"FUS9W-T<B`B,C0@_O'E\B(*"FUS9VED("(\8CY!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9#H\+V(^(@IM<V=S='(@(CQB/M#A\>_U\^G<\_3GZN4@W>WA
M(//OXN'Q_"#KW.CO\CH\+V(^(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-C8*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM
M<V=S='(@(M#A\>_U\^G<\^CGZN4@ZO'?\^GL[R#KW.CO\B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDT,0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`BP?#AZ?3EW_3AZ2#DY^S\\^GO(.KKY>GDWR!01U`@X^GA(/3G[2#J
M\?7P]._C\=SVY_/G(.7M_/(@[.?M_>SA]._R+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-C<*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(L'PX>GTY=_TX>D@Y.?L_//I[R#JZ^7IY-\@4$=0(./IX2#E
M\.GBY>+AW_GSYR#E[?SR(/7P[^/EX_'A[.S=[>_U(.SG[?WLX?3O\BXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DX"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@HBP?#AZ?3EW_3AZ2#DY^S\\^GO+"#P\>_S^?#IZOP@4$=0
M(.KKY>GDWR#JX>D@Z]WNYRWJ^>3IZOSR(./IX2#MX2`B"B+A\._J\?7P]._C
M\>'VWO/E].4@W>WA(.S>[?7LX2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,#$W"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HBP?#AZ?3EW_3AZ2#D
MY^S\\^GO+"#P\>_S^?#IZOP@4$=0(.KKY>GDWR#JX>D@Z]WNYRWJ^>3IZOSR
M(./IX2#MX2#U\._C\=SXY?3E("(*(OCG]NGAZMP@W>WA(.S>[?7LX2XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(L'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GP
MZ>K\(%,O34E-12#JZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@(@HB
MX?#OZO'U\/3OX_'A]M[SY?3E(-WMX2#LWNWU[.$N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-#D*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R
M("(B"B+!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!3+TU)344@ZNOE
MZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA("(*(O7P[^/QW/CE].4@^.?V
MZ>'JW"#=[>$@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S@R"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(L'PX>GTY=_T
MX>D@Y.?L_//I[R#JZ^7IY-\@4R]-24U%(./IX2#TY^T@ZO'U\/3OX_'<]N?S
MYR#E[?SR(.SG[?WLX?3O\BXB"@IM<V=I9"`B04TO4$TB"FUS9W-T<B`B\.PO
M[.PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("+0Y?'?(.'U
M]._](/3O]2#*Y>GLY>WOX_'<]N_U(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(M#E\=\N+BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS
M9VED(")!8G-B;W1T;VTB"FUS9W-T<B`BP?#\Z_7T[R#TW>OO\B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@
M(D%B<VUI9&1L92(*;7-G<W1R("+!\/SK]?3G(,S=\^<B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,`IM<V=I9"`B
M06-C97!T(')E<75E<W0B"FUS9W-T<B`BP?#OY._WWB#AZ?3>[.'T[_(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X
M,0IM<V=I9"`B06-C97!T960B"FUS9W-T<B`BQ>/I[>4@X?#OY.7J]/PB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C@U"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L<@
M\/'\\^+A\^<@X?#O\?'?]NCGZN4@ZN'TW"#TYR#DY^SI[_7QX]_A(%9&4R#J
MX?3AZ_SC[_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S
M.`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS
M9W-T<B`BQR#P\?SSXN'SYR#A\._Q\=_VZ.?JY2#JX?3<(/3G(.3G[.GO]?'C
MW^$@5D93(.'Q]^7?[_4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U
M"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(LKYY.GJ_/(@R^_C
MX?'IX?/L[_TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R
M("+/(.OOX^'QZ>'S[/SR(/#<X_GSY2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(P"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(LKA].'C
M\>'VWB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#4Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C(U"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(L7MW?'CY>GE
M\B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU-"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$S-@HC.B!T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z
M,38*;7-G:60@(D%D9"(*;7-G<W1R("+0\>_SZ-[JYR(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"FUS9VED(")!9&0@
M0VAI;&0@1W)O=7`B"FUS9W-T<B`BT/'O\^C>ZN<@]?#O[^S<Y.'R(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@R"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO
M;B(*;7-G<W1R("+0\>_SZ-[JYR#<Y.7IX?(@]?#O[^S<Y.'R("AC:&EL9"!P
M97)M:7-S:6]N*2(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`BT/'O\^C>ZN<@Y>3^.B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C`X(&%D;6EN+V=R;W5P<RYP:'`Z,C`Y"FUS9VED
M(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(M#Q[_/HWNKG(,W=X?(@S^S<Y.'R
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW,"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<Q"FUS9VED(")!9&0@3F5W(%!E<FUI
M<W-I;VXB"FUS9W-T<B`BT/'O\^C>ZN<@[=WA\B#<Y.7IX?(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHY"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R`G)7,G(@IM<V=S='(@(M#Q[_/HWNKG(/7P[^_L
MW.3A\B#S].\@)R5S)R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M,R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$S-0IM<V=I9"`B061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G(@IM<V=S='(@(M#Q[_/HWNKG
M(-SDY>GA\B`H<&5R;6ES<VEO;BD@]?#O[^S<Y.'R(//T[R`G)7,G(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G
M<W1R("+0\>_SZ-[JYR#MW>_U(/?QWO/TYSHB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(Y"FUS9VED(")!9&0@8V]L=6UN
M(@IM<V=S='(@(M#Q[_/HWNKG(//TWNOG\B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,S4*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*
M;7-G<W1R("+0\>_SZ-[JYR#MW>_U(.S=Z^_U\B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("+0
M\>_SZ-[JYR#FY?WC[_7R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M,0IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M(@IM<V=S='(@(M#Q[_/HWNKG(/3O]2`E<R#S].\@[.7M[_T@]._U($UO>FEL
M;&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C8S,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8S-PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD87(B"FUS
M9W-T<B`BT/'O\^C>ZN<@X?7T[_T@\_3O(.?LY?'OZ_SCZ?P@[._U(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<T"FUS9VED
M(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("+0\>_SZ-[JYR#S].\@
MQ.GE]>CU[?/I[^/QW/;O.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HX,0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O
M:R(*;7-G<W1R("+0\>_SZ-[JYR#S].\@Q.GE]>CU[?/I[^/QW/;O(.SO]2(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R
M("+0\>_SZ-[JYR#W\=[S].<B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0IM<V=I
M9"`B(@HB061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T
M(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)2(*(G,N(@IM
M<V=S='(@(B(*(M#Q[_/TW>CGZN4@)R5S)R#S].\@\_WS].?LX2P@X>OKW"#D
MY>T@[/#\\>7SX2#MX2#P\>_SZ-WS^2#S]>SPZ^?Q^>SA].GJW?(@(@HB\.OG
M\>_V[_'?Y?(B"@HC.B!S:6=N=7`N<&AP.C0V"FUS9VED(")!9&1E9"`G)7,G
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B
MT/'O\_3=Z.?JY2`G)7,G(//T[R#S_?/TY^SA+B#,\._QY=_TY2#MX2#S]>WD
MY>CEW_3E(/3^\>$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C0*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`BQR#P\>_SZ-[JYR#W\>?S]/[M(-WWY>D@X?#E[>7QX^_P[^GGZ.7?+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,CD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,W"FUS9VED(")!9&1R97-S(@IM
M<V=S='(@(L3IY?WH]>WSYR(*"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`BQ.GE]>CU[?/I[^/QW/;O\B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDW"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("+$Z>'WY=_QZ?/G
M("T@Q/[S].4@Y.GJX>G^[.'TX2#SY2#<Z^OO]?(@]_'>\_3E\B(*"B,Z(&%D
M;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("+$Z>'WY=_QZ?/G
M(@H*;7-G:60@(D%K=&EO;B!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R
M(,'J]-_O]2(*"FUS9VED(")!;&5X86YD<F]U<&]L:2!!:7)P;W)T(@IM<V=S
M='(@(L'E\>_KZ>S>[2#!Z^7NX>WD\>_]\._KY_(B"@IM<V=I9"`B06QI87,B
M"FUS9W-T<B`BV.7UY/[M]>SO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T
M<B`BQ?7H]>/QW.SLZ?/E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("+%
M]>CUX_'<[.SI\^<Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS
M9VED(")!;&PB"FUS9W-T<B`BS^OA(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3$X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S$*;7-G:60@(D%L
M;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(L_K[^D@[^D@W>/J]?'O
MZ2#W\=[S].7R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(Q,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("+/Z^7R(._I
M(,_LW.3E\B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HS."!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<T"FUS9VED(")!;&P@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BS^OA(/3A(.3IZN'I_NSA].$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED
M(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("+*X>D@[^D@]-WS\^7QZ?(@*#0I
M(/#KY?7QW?(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4T"FUS
M9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`BS>$@Y?#I
M]/'=\._M].'I(/#OZ^OA\.O=\B#DZ>7UZ/WM\^7I\B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,3<*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D
M97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(LWA(.7PZ?3QW?#O[?3AZ2#Q]>CL
MW_/EZ?(@].'NZ>WO[.GLW>WY[2#KZ?/T_NT[(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-#`Q"FUS9VED(")!;')E861Y(&5X
M:7-T<R(*;7-G<W1R("+'Y.<@]?#<\??EZ2(*"FUS9VED(")!;'1E<FYA=&4@
M24U34"!,;V=I;B(*;7-G<W1R("+%[>'KZ^'J].GJWB!)35-0(,7?\^_D[_(B
M"@IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`BQ>WA
MZ^OAZO3IZOSR($E-4U`@ROGDZ>K\\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.#(*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(L7MX>OKX>KTZ>K\($E-4U`@O.WO[.$@U_'>\_3G(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I
M;"!A9&1R97-S(@IM<V=S='(@(L7MX>OKX>KTZ>K>(.3IY?WH]>WSYR!E;6%I
M;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(L7MX>OKX>KTZ>K<(/#Q_/3U\.$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("+%[>'K
MZ^'J].GJ_"#JY=_LY>WO.B(*"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N(@IM<V=S='(@(L_QW_/TY^KE(.S?X2#LYR#E\.GT\>7P
M_.SE[><@].GLWBXB"@IM<V=I9"`B06YC:&EA;&]S($%I<G!O<G0B"FUS9W-T
M<B`BP>7Q[^OI[-WMX?(@P>/WW^'K[_4N(@H*;7-G:60@(D%N9')A=FED82!!
M:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,'MY/'AXM_DX?(N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$R,`IM<V=I9"`B06YO;GEM
M;W5S(%!R;WAY(@IM<V=S='(@(L'M_NWU[._R(,3IX>SLY?/OZ^'BY_3>\B`H
M4')O>'DI(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G
M:60@(D%N<W=E<B(*;7-G<W1R("+!\-SM].?SYR(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,P"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3D@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`BQ?;A
M\>SOX]XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P
M<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BR]_S].$@Q?;A\>SOX][R(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$S,`IM<V=I9"`B07!P;&EC871I;VX@
M:7,@<F5A9'DN(@IM<V=S='(@(L<@Y?;A\>SOX]X@Y=_MX>D@W?3OZ>SG+B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C(T"FUS9VED(")!<'!L
M>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`BQ?;A\>SOX]X@ZN'I(//TX2#E
M[N'Q]/[LY>WA(.KOZ>W\]_'G\_3A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,S,*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`BQ>/J
M\=_M^2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-S<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("+!\/'?Z^GO\B(*"FUS9VED(")!
M<F%X;W,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#!\=SN[_4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8R(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`BS-WCY>CO\B#A\??EW^_U(.'Q]^7I[^C=].?S
MY_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8Q
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C
M:&EV92!.86UE(@IM<V=S='(@(L_M[^SA(.'Q]^7?[_4@X?'WY>GHW?3G\^?R
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHY
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("+%W_/TY2#SW^/O]?'G
M(./IX2#TYR#DZ>'C\>'VWB#TY_(@X=_TY_/G\B#U\._C\>'VWO(@X^GA("5S
M(#\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z.0IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N
M9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`BQ=_S].4@\]_C[_7Q[^D@_/3I
M(.C=Z^7TY2#MX2#DZ>'C\=SXY?3E("<E<R<@ZN'I(/SKY?(@].GR(/7P[^_L
MW.3E\C\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R
M="(*;7-G<W1R("+4W??MYR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%30TE)(-3=]^WG(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P.0IM<V=I9"`B07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M(@IM<V=S='(@(LWA(.;G].7?].4@Y?#IXN7BX=_Y\^<@\/'?[2#A\/P@ZMSH
MY2#E[=WQX^7IX2#DZ>'WY=_QZ?/G\CLB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,#DW"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T
M<B`BP>W<Z.7SYR#S].?K_NTB"@IM<V=I9"`B071H:6YA:2!!:7)P;W)T(@IM
M<V=S='(@(L'E\>_KZ>S=[>'R(,'HY^W^[2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,38V"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C0Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S$X"FUS9VED(")!
M='1A8VAE9"!I<R!A;B!I0V%L96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E
M<W0@>6]U('-E;G0B"FUS9W-T<B`BU.\@\_7MY^SLW>WO(.7?[>'I(-WMX2#A
M\??EW^\@Y^SE\>_K[^/?[_4@\^4@X?#<[?3G\^<@X>GTWNSA]/SR(//A\B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S4*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("+0\>_S\-SHY>GA
M(.3IX>/QX?;>\B#LYR#U\.'QZO3>\B#O[-SDX?(N(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HS.`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BT/'O\_#<Z.7IX2#D
MZ>'C\>'VWO(@[.<@]?#A\>KT[_T@Y.GJX>G^[.'T[_(N(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z.3@*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+0\>_S\-SHY>GA(.7P
MY>[E\>/A\]_A\B#LYR#U\.'QZO3O_2#DZ>KAZ?[LX?3O\BXB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`BT/'O\_#<Z.7IX2#E
M\.7NY?'CX?/?X?(@[.<@]?#A\>KT[_T@Y.GA[._I\>'S[-WM[_4N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-S<*
M;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R("+0X?'E]?'I\^K\[.7M[^DB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E
M<R(*;7-G<W1R("+)Y.G\].?TY?(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@Q"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(L']
MX^_U\_3O\B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.0IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM
M<V=S='(@(L<@X?7HY>WTZ>KO\._?Y_/G(.'PW?3U]^4B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW.`IM<V=I
M9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+'(.'UZ.7M
M].GJ[_#OW^?SYR#A\-WT]??E+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ.#$*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C
M=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(L<@X?7HY>WTZ>KO\._?
MY_/G(.'P[_'QW_;HY^KE(.'P_"#T[^T@4D%$2553('-E<G9E<BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(L<@X?7HY>WT
MZ>KO\._?Y_/G(//T[^T@1E10+5-E<G9E<B#A\-WT]??E+B(*"FUS9VED(")!
M=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("+$Z>'HW?/I[.$@T.7DW^$Z(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV
M,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@(L'MX>S=[>_M
M].'R(.'PW.WTY_/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R
M("+5\/SBX>CQ[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B
MU_'^[.$@]?#\XN'H\>_U(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R
M("++W.CO\B!+97)B97)O<RWJ^>3IZOSR+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`BR]SH[_(@2V5R8F5R;W,MO.WO[.$@U_'>\_3G+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3(*;7-G:60@(D)A<F4B"FUS
M9W-T<B`BP>3EZ>\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*;7-G
M:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*
M;7-G<W1R("+/(.K]\>GO\B#JX?3<Z^_C[_(@X_'A]NGJ_NT@)R5S)R#DY>T@
MXO'=Z.?JY2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(L+A\^GJ
MWB#C\>'L[-XB"@IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BP^7MW>CKZ>$B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L
M;V-K(%-E='1I;F=S(@IM<V=S='(@(M'UZ.S?\^7I\B#T[-[LX?3O\B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@
M5'EP92(*;7-G<W1R("+4_?#O\B#T[-[LX?3O\B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*;7-G:60@(D)L;V-K(%PB
M)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("+4[R#T[-[LX2!<(B5S7"(@].?R(.7VX?'L[^/>\B!<(B5S7"(@Y.7M(.+Q
MW>CGZN4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(KCM]._MX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G
M:60@(D)O<F1E<G,B"FUS9W-T<B`BO/'IX2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("+*X>D@].$@Y/WO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`BRN'T_O3A].\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(LO?\_3A(.SE(/3EZ^7?Y?(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R,0IM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`BT^?LY=_A(.3IX>WO[-[R
M($-23"(*"FUS9VED(")#5E,B"FUS9W-T<B`BP?'WY=_O(.KEZ>S=[>_U(/?Y
M\>GS[-WM[R#LY2#J_.SLX2`H0U93*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("+)Y.G\].?TY?(@RN7KZ?[M+BXN(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30S"FUS9VED(")#86QE;F1A<B(*
M;7-G<W1R("+'[.7Q[^O\X^GO(@H*;7-G:60@(D-A;&5N9&%R.B(*;7-G<W1R
M("+'[.7Q[^O\X^GO.B(*"FUS9VED(")#86QE;F1A<B!3=6UM87)Y(@IM<V=S
M='(@(M#E\=_KY_CG(,?LY?'OZ_SCZ>_U(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Y-0IM<V=I9"`B0V%L;2(*;7-G<W1R("+'\>7LW^$B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBP>3][>'TYR#G(.'Q]^GJ
M[_#OW^?SYR#T[_4@ZOGDZ>KO_2#A]?3\[.'TX2P@Y?#IZN_I[?GMWO/TY2#L
MY2#T[R#DZ>'WY>GQZ?/TWB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(T,2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$R
M"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G
M<W1R("+!Y/WMX?3G(.<@\_WMY.7SYR#LY2#T[^T@24U!4"U397)V97(Z("5S
M(@H*;7-G:60@(D-A;F-E;"(*;7-G<W1R("+!ZOWQ^?/G(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("+!ZOWQ^?/G(,'MX?;O\=SR(-#Q[^+KWNSA
M]._R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR-CD*;7-G:60@
M(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(L'D_>WA].<@
MYR#DZ>'C\>'VWB#T[_4@X?'WY=_O]2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0W"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3,*;7-G:60@(D-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`BQ.4@XO'?
M\^KY(/#Q[_/Y\>GM_"#VW.KEZ^\@*'1E;7`@9&ER*2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDW"FUS9VED(")#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM
M<V=S='(@(L'D_>WA].<@YR#S]>W=]^7IX2#W^?'?\B#TY^T@\.'QW.SE]/'O
M(%PB=&%R9V5T1FEL95PB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C8U"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@]N'JW>OO]2!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,3(@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3<V"FUS9VED
M(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B
MP>3][>'TYR#G(.3IX>/QX?;>+"`E9"#U\/;<ZN7K[_(@]?#<\??EZ2XB"@HC
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#(*;7-G
M:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O
M<F5D+B(*;7-G<W1R("(B"B+!Y/WMX?3G(.<@Y?#A[>'TX>[I[?SLY_/G+"#O
M(.'QZ>CL_/(@]/GM(.7CX_'A]O[M(/#O]2#D_O/A].4@X^GA("(*(N7PX>WA
M].'NZ>W\[.?SYRP@Y.7M(/3AZ?'IW.;EZ2#LY2#T[^T@X?'IZ.S\(/3Y[2#A
M\._HY^KE]>S=[?GM+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q.`IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A
M9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@
MY/'O[._K[^/>\_D@[-[M]>SA(//T[^T@X?'IZ.S\(/#O]2#O\=_SX?3E+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BQ?#IZN7VX>O?Y.$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@
M86YD($QA8F5L<R(*;7-G<W1R("+*X?3GX^_QW^7R(.KAZ2#%].GJW?3E\B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3<*
M;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`BRNGMY_3\(-3GZ]WV^>WO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(LGDZ?STY_3E
M\B#*Y>OI[_TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("+#W>SI
M\^SA(,KEZ^GO_3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS
M9W-T<B`BR>3I_/3G].7R(,KEZ^GO_2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z
M(@IM<V=S='(@(L3IW.KE[>\@RN7KZ?[M.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-C4*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("+*Z>WG
M]/P@U.?KW?;Y[>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`BRMWM
M]/'O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,C,*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`BR^7P]._LW?'E
MZ>7R(-#I\_3O\._IY_3IZN_](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,C`*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(M#OZ^GTZ>K>(-#I\_3O\._IY_3IZN_](@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.38@/S\_"FUS9VED
M(")#:&%I<B!097)S;VXB"FUS9W-T<B`BT/'\Y>3Q[_(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDW"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BP>OKX>/>(@H*;7-G
M:60@(D-H86YG92!087-S=V]R9"(*;7-G<W1R("+!Z^OAX]X@ZOGDZ>KO_2(*
M"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*
M(F5M86EL<RXB"FUS9W-T<B`B(@HBP>OKW.[TY2#T[R#\[>_LX2#JX>D@].<@
MY.GE_>CU[?/G(/#O]2#HX2#BZ]WP[_7M(/STX>T@Y.GAXMSF[_7M(-X@X?#A
M[?3O_>T@(@HB\^4@[.?M_>SA]-P@\^'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*
M;7-G<W1R("+7X?'AZO3>\>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN
M:RXN+B(*;7-G<W1R("*XZ^7C]^_R(//][>3E\^?R+BXN(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,PIM<V=I9"`B0VAE
M8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HBT^?LY>G^\_3E(/3O
M(/3E]/'AX_GMW^3I[R#CZ>$@[_#OZ>'DWO#O].4@Y?'CX?/?X2CE\BD@Z-WK
MY?3E(.WA(.7J].7KY?/T[_WM("(*(N'U]-X@].<@\_3IX^S>+B(*"FUS9VED
M(")#:&EO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-??[_4B"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P
M;&EC871I;VXZ(@IM<V=S='(@(L7PZ>O=[O3E(,7VX?'L[^/>.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR.#(*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(L7PZ>O=[O3E(.KYY.GJ_"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR.#$*;7-G:60@(D-H;V]S
M92!A('5S97)N86UE(@IM<V=S='(@(L7PZ>O=[O3E(/SM[^SA(/?QWO/TYR(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-#4R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C(V"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*;7-G<W1R("+%\.GK
MW>[TY2#LZ>$@Y>W=\>/EZ>$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(X,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G
M<W1R("+%\.GKW>[TY2#P^?(@Z.$@Y>SVX>W?YN_M].'I(._I(.?LY?'O[.?M
MW^7R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("+%\.GKW>[TY2#T_?#O(.O?
M\_3A\B`HX^GA(/3A[NGM[^SG[-WMY?(@Z]_S].7R*2(*"FUS9VED(")#:')Y
M<V]U<&]L:2!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-?Q]?/O_?#O
MZ^?R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HS,3$@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C8U-0IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(L3E[2#B\=WHY^KE(._QZ?/L_/(@
MZNO<\^?R(/3O]2`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$T"FUS9VED(")#;&5A<B(*;7-G<W1R("+*X>C<\>GSY2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@
M(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`BRN'HX?'I\^S\\B#E].GJ
MY?3^[2`H=&%G<RD@35,M3V9F:6-E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C<*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G
M<W1R("(GP>3EZ>'S[.$G(-?QWO/TYSH@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,38*;7-G:60@(D-L96%R('5S97(B"FUS9W-T
M<B`BRN'HX?'I\^S\\B#7\=[S].<B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS-PIM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@
M(LKAZ.'QZ?/L_/(@Y.7D[^S=[?GM(/?QWO/TYR(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]N;W1I8V5?8F]T=&]M+FEN8SHV"FUS9VED(")#;&EC:R!T
M;R!#;VYT:6YU92(*;7-G<W1R("+*W.WTY2#JZ^GJ(./IX2#S]>W=]^7IX2(*
M"FUS9VED(")#;&]S92!(96QP(%=I;F1O=R(*;7-G<W1R("+*Z^7?\^GL[R#0
MX?'<Z/7Q[_4@PN_>Z.7IX?(B"@IM<V=I9"`B0VQO<V4@2&5L<"(*;7-G<W1R
M("+*Z^7?\^GL[R#"[][HY>GA\B(*"FUS9VED(")#;&]S92!7:6YD;W<B"FUS
M9W-T<B`BRNOEW_/I[.\@T.'QW.CU\>_U(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHT"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S
M='(@(L'MX>3?\.OY\^<@T.OE]?'IZM[R(,SPW/'A\B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@
M(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(L'MX>3I\.OY[-WMX2#0Y?'I
MZ/[QZ>$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`BU_'^[.$B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDW
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HR.3@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0W,B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4Q"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4R"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8X"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Y"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@V"FUS9VED(")#;VQO
M<B!0:6-K97(B"FUS9W-T<B`BQ?#IZ]WJ].?R(-?Q_NSA]._R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-`IM<V=I9"`B0V]L;W5R('-E;&5C
M=&EO;B(*;7-G<W1R("+%\.GK[^/>(-?Q_NSA]._R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z
M(@IM<V=S='(@(M/TWNOE\CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3(Y"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(M3?].OOZ2#3
M].?K_NTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED
M(")#;VUI8W,B"FUS9W-T<B`B0V]M:6-S(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(L7M]._KWB(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G
M<W1R("+*W>OU]N_R(,7M]._K_NTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HS.3D*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`BT_?\Z^GO
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3`*;7-G
M:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(LKOZ>W\(+SM[^SA(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T,@IM<V=I9"`B
M0V]M<&%N>2(*;7-G<W1R("+%].'I\>7?X2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-CDW"FUS9VED(")#;VUP;&5T
M960B"FUS9W-T<B`BS^OOZNOG\?[HY^KE(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0IM<V=I9"`B0V]M<&]S
M92!-97-S86=E("@E<RDB"FUS9W-T<B`BT_WMZ.7SYR#,Y^W][.'T[_(@*"5S
M*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T
M97)S(@IM<V=S='(@(M7P[^OOX^GS]-WR(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-#<*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`BT_7MZ-[JY?(B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HX.0IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("+$Z>'V[_'=\B#0X?'A[.7T\>_P
M[]_G\^?R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("+%\.GK[^/=\B#CZ>$@\_7C]_'O
M[>GS[/P@[.4@4$1!<RP@W>[U\.WA(-3GZ]WV^>WA(.KAZ2!/=71L;V]K+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(D1I92!+;VYF:6=U<F%T
M:6]N(&UU<W,@86MT=6%L:7-I97)T('=E<F1E;BXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3(U"FUS9VED(")#;VYF:6=U<F%T:6]N(&YE961S('5P
M9&%T:6YG+B(*;7-G<W1R("+'(/#A\>'LY?3Q[_#OW^?SYR#W\>7IW.;E].'I
M(.7MY^S=\?GSYRXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*;7-G
M:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("+0X?'A[.7T\>_P[]_G\^<@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,W"FUS9VED
M(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(L7PZ>+EXN'?^?/G(,KYY.GJ
M[_TB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$Y
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BQR#S_>WDY?/G
M(.'PW?3U]^4N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C`V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q.0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("+'
M(//][>3E\^<@X?#=]/7WY3H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDS"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(L'Q[>?SYR#S_>WDY?/G\B#A
M\/P@].\@Y.?L_//I[R#E[O7PY_'E].?TWB#JZ^7IY.G^[2XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.34*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I(@IM<V=S='(@(L'Q[>?SYR#S_>WDY?/G\B#A\/P@].\@Y.?L_//I
M[R#E[O7PY_'E].?TWB#JZ^7IY.G^[2X@R_SC[_(@.B`E<R`H)7,I(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.30*;7-G:60@(D-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(L<@\_WMY.7SYR#L
MY2#T[R!&5%`M4V5R=F5R(.'PW?3U]^4N(@H*;7-G:60@(D-O;G1A8W0@4V5A
M<F-H(@IM<V=S='(@(L'MX>;>].?SYR#%\.'VWO(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-38*;7-G:60@(D-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("+/Z2#E\.'VW?(@\/'O\_3=Z.?JX>T@Y?#I]/7W_O(@\_3O
M(,3IY?7H]>WSZ>_C\=SV[R#SX?(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S@*;7-G:60@(D-O;G1E;G1S(&]F("<E<R<B"FUS9W-T<B`BT.7Q
MZ>7W_.SE[>$@]._U("<E<R<B"@IM<V=I9"`B0V]N=&5N=',@;V8@=&AE(%)!
M4B!A<F-H:79E(@IM<V=S='(@(M#E\>GE]_SLY>WA(/3Y[2#A\??EW_GM(%)!
M4B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#
M;VYT:6YU92(*;7-G<W1R("+3]>W=]^7IX2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P
M>2(*;7-G<W1R("+![?3IX_'A]MXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*
M;7-G<W1R("+![?3IX_'A]MX@Q?#IZ^_CWO(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E+B(*;7-G<W1R("+!Y/WMX?3G(.<@ZO'U\/3OX_'<]N?S
MYR#T[_4@[.?M_>SA]._R(.SE(%!'4"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G92XB"FUS9W-T<B`BP>3][>'TYR#G(/7P[^/QX?;>(/3O]2#LY^W]
M[.'T[_(@[.4@4$=0+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#$Q"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`BP>3][>'TYR#G(.KQ]?#T[^/QW/;G\^<@]._U(.SG
M[?WLX?3O\B#LY2!3+TU)344N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT.#4*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R("+!Y/WMX?3G(.<@]?#OX_'A]MX@]._U(.SG[?WL
MX?3O\B#LY2!3+TU)344N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,B"FUS9W-T<B`BQ.7M(.SP_/'E\^$@[>$@\/'O\^C=\_D@].?M
M(.7PX?;>+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,3$S"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`BP>3][>'TYR#G(//][>3E\^<@[.4@].\@3$1!4"U397)V97(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M-30*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`BP>3][>'T[_(@[R#=Z^7C[_(@]?#OZ^_?\._U+B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HT.`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E<R(*;7-G<W1R("+!Y/WM
MX?3G(.<@\_WMY.7SYR#S]._M(.7N]?#G\>7TY_3>("<E<R<@]_'G\^GL\._I
M_NWTX?(@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S(Y"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+!Y/WMX?3G(.<@Y.?LZ>_U
M\>/?X2#KW_/TX?,@Y.GA[>_LWO(N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$R-@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N(@IM<V=S='(@(L'D_>WA].<@YR#A\._J\?7P]._C\=SVY_/G
M(%!'4"#DY>3O[-WM^>TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-#`*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+B(*;7-G<W1R("+!Y/WMX?3G(.<@X?#OZO'U\/3OX_'<]N?SYR!3+TU)
M344@Y.7D[^S=[?GM+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C4P"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O
M;G1A8W0N("5S(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#E\.'VWO(N
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS-C4*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#KW_/TX?(@
MY.GA[>_LWO(N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S<*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M)R5S)RXB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>('-E='5P('5P9W)A
M9&4@<V-R:7!T("<E<R<@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,SDY(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU
M.0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(L3E(.SP[_'^(.WA(.3IY?7J\>GM
MWO/Y(/3G(.3IY?WH]>WSYR#T[_4@\.'QX>O>\/3G+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@X"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("+!Y/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G(/3O]2#$Z>7UZ/7M\^GOX_'<
M]N_U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$P"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(L'D_>WA].<@YR#PZ][QY_(@\/'\
M\^+A\^<@].?R(.O?\_3A\B#DZ>'M[^S>\BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0V,0IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<RXB"FUS9W-T<B`BP>3][>'TYR#G(/#KWO'G\B#P\?SSXN'SYR#KW_/T
MX?(@X?#\(.O?\_3E\B#DZ>'M[^S>\BXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.0HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C@U"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2`G)7,G+B(*;7-G<W1R("+!Y/WMX?3O(/3O(/;\\?3Y[.$@\_3QX?3GX^GJ
MWO(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3$*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]D:7)E8W0N<&AP.C,Q"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB
M"FUS9W-T<B`BP>3][>'TYR#G(.3G[.GO]?'CW^$@]N'JW>OO]2!<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S(P"FUS9VED
M(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+B(*;7-G<W1R("+!Y/WMX?3G(.<@X>W<ZO3G\^<@Y.?L_//I[_4@ZNOE
MZ>3I[_T@X?#\(/3O[2#E[O7PY_'E].?TWB#$Y^PNRNOEZ>3I_NTN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HW,#(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S4T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BP>3][>'T
M[R#T[R#<[>_IX^SA("5S+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#`*;7-G
M:60@(D-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R:71I;F<N(@IM<V=S='(@
M(L'D_>WA].\@].\@W.WOZ>/LX2!<(B5S7"(@X^GA(.7CX_'A]MXN(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,34@8RUF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S(@IM<V=S='(@(L'D_>WA].\@].\@W.WOZ>/LX2#T[_4@[-WQ
M[_7R(,3IX??EW_'I\^?R("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<Q"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RXB"FUS9W-T<B`B
MQ.7M(.SP[_'^(.WA(.'M[]_N^2#T[R#VW.KEZ^\@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C<P"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`BQ.7M(.SP[_'^(.WA(.3IX>+<\_D@)7,N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*
M(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B
M"B+!Y/WMX?3G(.<@X?'WZ>KO\._?Y_/G(/3O]2#J^>3IZN_](./IX2#T[^T@
MX>GT[_WLY>WO(/?QWO/TYRX@RMSP[^GA(-X@_.OE\B`B"B+OZ2#KY?#T[^S=
M\>7IY?(@Y.7M(.7?[>'I(//Y\_3=\BX@SN'MX>3OZNGLW//TY2#>(.7PZ>KO
MZ>WY[=[S].4@[.4@].\@Y.GA]^7I+2(*(O'I\_3>(.'M(/?QY>G<\^7SZ.4@
M\.7QZ?/S_/3E\><@XN_>Z.7IX2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S0Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.3(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,SDX"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM
M<V=S='(@(L'D_>WA].<@YR#A[=SJ].?SYR#+W_/TX?(@RN'M_.WY[2#0\?SS
MXN'SY_(@*$%#3"DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(W.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D
M9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`BP>3][>'TYR#G(.'MW.KTY_/G(,3I
MY?7H]>WSZ>_C\=SV[_4N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,#$*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BP>3][>'TYR#G
M(.'MW.KTY_/G(,O?\_3A\B#$Z>'M[^S>\BX@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0U,@IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T
M<B`BP>3][>'TYR#G(.'MW.KTY_/G(,OI\_3^[2#$Z>'M[^S>\BX@)7,B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C8*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C,P"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(L'D_>WA].<@YR#A[=SJ].?SYR#T^>T@Z>3I[_3>]/GM(/3O]2#E
M[O7PY_'E].?TWB(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G
M:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
MP>3][>'TYR#G(.7PX>WA]N_QW"#Q]>CLW_/E^>TN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.CDU"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@)R5S)RXB"FUS9W-T
M<B`BP>3][>'TYR#G(.3IX>/QX?;>(/;AZMWK[_4@*')M9&ER*2!<(B5S7"(N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*;7-G:60@(D-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L3E(.SP[_'^
M(.WA(.'P[^CGZN7]\_D@)7,@\?7H[-_SY>GR+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G
M<W1R("+$Y2#L\._Q_B#MX2#JW.WY(.7VY>3QZ>K\(.'M]-_C\>'V[R#T^>T@
M\?7H[-_SY?GM+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R("+$Y2#L\._Q_B#MX2#JW.WY(.7VY>3QZ>K\(.'M]-_C\>'V[R#T
M^>T@\?7H[-_SY?GM.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDR"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@)R5S)RXB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@X?#OZ.?JY?WS^2#P
M\?SC\>'L[.$@Y>WG[-WQ^?/G\B#S].\@)R5S)RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`BQ.4@[/#O\?X@
M[>$@X?#OZ.?JY?WS^2#E]N7D\>GJ_"#A\??EW^\@\?7H[-_SY?GM("5S+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*(L3E(.SP[_'^(.WA(.'P[^CGZN7]\_D@
M].\@X?'WY=_O(/'UZ.S?\^7Y[2`E<RX@S/#O\>7?].4@Y=_TY2#MX2#W\>?S
MZ>SO\._IWBTB"B+SY?3E(.SIX2#A\/P@].GR(.7PZ>OOX]WR(./IX2#MX2#A
M\._HY^KE_?/E].4@\-_S^2#S].\@)7,@WB#A[?3IX_'<^/3E(.SE(/3O("(*
M(O?=\>D@]._M(.K^Y.GJX2#PW_/Y(//T[R`E<RXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$R,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C
M:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(L'D_>WA].<@YR#A[>'FWO3G
M\^<@\_3O[2#E[O7PY_'E].?TWB!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HX-PIM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R`G)7,G+B(*;7-G<W1R("+$
MY2#L\._Q_B#MX2#A\._S]>WDW?/Y(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(R,0IM<V=I9"`B0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("+$Y2#L\._Q_B#M
MX2#E[>?LY?'^\_D@].?M(.7PX?;>+B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#`Y"FUS9VED(")#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+$Y2#L
M\._Q_B#MX2#E[>?LY?'^\_D@].<@R]_S].$@Q.GA[>_LWO(N("5S(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"FUS9VED(")#;W5L9"!N;W0@=W)I
M=&4@8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,B"FUS9W-T<B`BQ.4@[/#O
M\?X@[>$@X_'<^/D@].GR(/'U[-_SY>GR(./IX2`G)7,G.B`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3`*;7-G:60@(D-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN(@IM<V=S='(@(B(*(L3E(.SP[_'^(.WA(.+Q_B#TYR#PZ^7U\>GJ
MWB#L\-SQX2#T[_4@36]Z:6QL82X@PN7BX>GYZ.7?].'I(/STZ2#EW^WAZ2`B
M"B+A[>_IZO3>+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$U.0IM<V=I9"`B0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,B"FUS
M9W-T<B`B(@HBQ.4@[/#O\?X@[>$@Y/[S^2#S].\@]_'>\_3G("<E<R<@].$@
M\.'QX>K<]/D@Y.GJX>G^[.'TX2#S].\@]MSJY>OO("<E<R<Z("5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q-0IM<V=I9"`B0V]U;G1E9"!T
M97AT(@IM<V=S='(@(LSE]/'G[-WM[R#JY=_LY>WO(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(D-O=6YT<GDB"FUS
M9W-T<B`BU_[QX2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*
M;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BT._QY=_E\B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3<*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,0IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(L3G[.GO]?'CW^$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G
M:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`BQ.?LZ>_U\>/?X2#E[?SR(//U
M[>3=\^SO]2(*"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(L3G
M[.GO]?'CW^$@[.GA\B#MW>'R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.34*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R("+$Y^SI[_7QX]_A(/7P[_;AZMWK^>TB"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M,C(*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ>[O]?/I
M[^3O]-[SY>GR(,3G[.GO]?'C[_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C$T"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B
MP?'IZ.S\\B#0Z?/T^?3IZM[R(,K<\?3A\B(*"FUS9VED(")#<F5D:71S(@IM
M<V=S='(@(L7U]^'QZ?/TW^7R(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V
M"FUS9VED(")#=7)R96YT(%!H87-E(@IM<V=S='(@(M3QW??O]?/A(-;<\^<B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z
M,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("+4\=WW[_7SX2#^\>$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(M3O(/3Q
MW??O[2!54DP@Y=_MX>DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS
M9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`BU/'=]^_M(,KAZ?'\\B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(D-U
M<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`BU/'=]^_U\^$@\_7MZ-[JYSH@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("+4\=WW^>T@\_3]ZR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`BT.'Q
MX>SE]/'O\._?Y_/G(.3IX>3IZN'SZ?[M(/#O]2#EZO3EZ^_][?3AZ2#JX?3<
M(/3G[2#EW_/OY.\@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B
MP?#OZN_PWB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BP?#OZN_P
MWB#E\.GK[^/>\B(*"FUS9VED(")$1"(*;7-G<W1R("+,S"(*"FUS9VED(")$
M86EL>2(*;7-G<W1R("+'[.7QWO/IX2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,C,*;7-G:60@(D1A=&$B"FUS9W-T<B`BQ.7D[^S=[>$B"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`BQ>SVW.WI\^<@*$)R;W=S97(I($1A=&%4<F5E(@H*;7-G
M:60@(D1A=&%B87-E('%U97)Y(&9A:6QE9"XB"FUS9W-T<B`BQR#A[>'FWO3G
M\^<@\_3G(,+<\^<@Q.7D[^S=[?GM(.'PW?3U]^4N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S@Q"FUS9VED(")$871E(@IM<V=S='(@(L?LY?'O[.?M
MW^$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("+'[.7Q[^SG[=_A(/#A\>'K
MX>+>\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.34*;7-G:60@
M(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(L7PZ>OOX]X@Q^SE\>_LY^W?X?(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")$
M87DB"FUS9W-T<B`BQ^S=\>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(D1E7VQE=&4@0V]L
M=6UN(@IM<V=S='(@(L3IX>/QX?;>(-/TWNOG\B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*
M;7-G<W1R("+$Y>K=[.+QZ>_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N
M=6UB97)S(@IM<V=S='(@(L3EZN'DZ>KOWR#A\>GH[._?(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#4*;7-G:60@
M(D1E8VQI;F5D(@IM<V=S='(@(KCW[_7M(.'Q[>?HY=\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R
M96%S92!);F1E;G0B"FUS9W-T<B`BS.7?^?/G(-#E\>GH^?'?[_4B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Y,B!L:6(O<')E9G,N<&AP
M.C$P.`IM<V=I9"`B1&5F875L="(*;7-G<W1R("+0\>_JX>CO\>GS[-WM[R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q
M"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(M#Q[^7PZ>OEX^S=[>\@
MU_'^[.$B"@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+0\>_E
M\.GKY>/LW>WG(-3A]?3\].?TX2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$Q.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-`IM<V=I9"`B
M1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R("+0\>_JX>CO\>GS[-WMY?(@
MQ>[O]?/I[^3O]-[SY>GR(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR,#4*;7-G:60@(D1E9F%U;'0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B
MT/'OZN'H[_'I\^S=[>7R(,7N[_7SZ>_D[_3>\^7I\B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B
MS_'I\^SOWR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C0S"FUS9VED(")$96QE9V%T92!P;W-I=&EO;B(*;7-G<W1R
M("+(W?/G(.'M].GP\>_S_O#O]2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-CDS"FUS9VED(")$96QE9V%T960B"FUS
M9W-T<B`BP>WTZ?#Q[_/Y\.?LW>WO(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR.3<@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,C<*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS-#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHT,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3D*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,C(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-#4*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#@@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M.2!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3,*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D1E;&5T92(*
M;7-G<W1R("+$Z>'C\>'VWB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@Y(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T
M<B`BQ.GAX_'A]MX@S^S<Y.'R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HV,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@T"FUS
M9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("+$Z>'C\>'VWB#%[N_U
M\^GOY/STY_/G\B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDV"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(L3IX>/QX?;>(.KAZ2#EZNK=[?GSYR#LY^WU[-ST^>TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W
M"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("+$Z>'C\>'VWB#JY>OI[_TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(L3IX>/QX?;>
M(-/TWNOG\B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(L3I
MX>/QX?;>(/7PW/'W[^WT[_(@Y>WAZ^OAZO3IZN_](/#Q[_3]\._U(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU,"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,R-@IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B`G
M)7,G(@IM<V=S='(@(L3IX>/QX?;>(.7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)R5S
M)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S(Y"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_(@IM<V=S='(@(L3IX>/QX?;>(.7N[_7SZ>_D[_3>\^7Y[2#C
MZ>$@)R5S)R#JX>D@ZMSHY2#U\.\MY>[O]?/I[^3\].?SYSLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@<F]W(@IM<V=S='(@(L3IX>/QX?;>(//TWNOG\B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@
M(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("+0\>_E\.GKY>/L
MW>WG(-3A]?3\].?TX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(&-O;'5M;B(*;7-G<W1R("+$Z>'C\>'VWB#T\=WW[_7SX?(@\_3>Z^?R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8R"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S
M='(@(L3IX>/QX?;>(/3QW??O]?/A\B#C\>'L[-[R(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HT.`IM<V=I9"`B1&5L971E('1H:7,@<&5R;6ES<VEO
M;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`BQ.GAX_'A]MX@
MX?7TWO(@].?R(.7N[_7SZ>_D_/3G\^?R(.KAZ2#JW.CE(/7P[RWE[N_U\^GO
MY/STY_/G\CLB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-0IM<V=I
M9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R
M("+$Z>'C\=SVY^KE(/3O('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(V,0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("*_
M\>$@W/;I[N?R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV-#(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("+!
M\>WG\^<@X>GTWNSA]._R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT-S$*;7-G:60@(D1E;GD@<F5Q=65S="!F;W(@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S='(@(L'Q[>?SYR#AZ?3>[.'T
M[_(@X^GA(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z.34@<V5R=FEC97,O<')O8FQE;2YP:'`Z.3D@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z,3`Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R("+0Y?'IX_'A]MX@]._U(-#Q[^+KWNSA]._R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-C4@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R
M:7!T:6]N(@IM<V=S='(@(M#E\>GC\>'VWB(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ(@IM<V=S='(@(LOE\/3O[-WQY>GE\B`HY?#?\^?R(.KA
MZ2#S].\@X?'WY=_O(.KA].'C\>'VWO(@]._U($AO<F1E*3HB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-0IM<V=I9"`B1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
MS^D@Z^7P]._LW?'EZ>7R(-WW[_7M(.KA].'C\>'VY=\@X^GA(/3O[2#DZ>'W
MY>GQZ?/TWBXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DS"FUS
M9VED(")$979E;&]P;65N="(*;7-G<W1R("+![=SP]/7NYR(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$U"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B
MT^?LY=_O(,3Q[_/IW/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("+3Y^SEW^\@Q/'O
M\^G<\CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3(*;7-G:60@(D1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`BT^?LY=_O(,3Q[_/I
MW/(@X^GA(/3G[2#TY>OE]?3AW^$@_O'A.B`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H="(*;7-G<W1R("+*X?3E_>CU[?/G(.'P_"#A\>GS].7Q
MW"#P\>_R(/3A(.3E[NG<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0B"FUS9W-T<B`BRN'TY?WH]>WSYR#A\/P@].$@Y.7NZ=P@\/'O\B#TX2#A
M\>GS].7QW"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$
M:7)E8W1O<GDB"FUS9W-T<B`BRN'TW.OOX^_R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(U,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R("+%[/;<[>GSYR#^\>'R(//E(#(T^?'G(.SO\?;>.R(*"FUS9VED
M(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BQ?#IZ^_CW?(@Q>SVW.WI\^?R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,PIM<V=I9"`B1&ES<&QA>2!F
M;W)E8V%S="`H5$%&*2(*;7-G<W1R("+%[/;<[>GSYR#P\>_BZ]WXY?GM("A4
M048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-0IM<V=I9"`B
M1&ES<&QA>2!F;W)M870B"FUS9W-T<B`BS._Q]MX@Q>SVW.WI\^?R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,PIM<V=I9"`B1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(L7MY^S=\?GSYR#$Z=STX>[G
M\B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS,C<*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS
M9W-T<B`BS.<@Y.GAX_'<]N7I\B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR-`IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'`B"FUS9W-T<B`BS.?M(.7PZ??EZ?'>\^7TY2#MX2#A[>_?[N7T
MY2#A\.7UZ.7?X?(@].\@X?'WY=_O(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$Y('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$Y"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM
M<V=S='(@(M#E\>G=]^7I(.<@\/'^].<@X_'A[.S>(._M_.SA].$@\.7DW_GM
M.R#![2#MX>D@]//EZMSQY?3E(.'U]/PZ(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#8V"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M("+*X?3=XN'S[.$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-C8*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(LKA]-WBX?/L
MX2`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-38*;7-G:60@(D1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M(@IM<V=S='(@(LKA]-WBX?/LX2#T[_4@X?'WY=_O]2#PX?'A[-WT\?GM(//A
M[2!02%`M<V-R:7!T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M.3`*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(LO?\_3A(,KA].'Q
MW.KTY_(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R
M=6=S(@IM<V=S='(@(M;<\>SAZN$M[>'QZOGTZ>K<(@H*;7-G:60@(D5D:70B
M"FUS9W-T<B`BQ?#E[N7QX^'SW^$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4Q('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G
M:60@(D5D:70@0FQO8VLB"FUS9W-T<B`BQ?#E[N7QX^'SW^$@0FQO8VLB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$X."!A9&UI;B]G<F]U<',N<&AP.C(Q-@IM
M<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("+%\.7NY?'CX?/?X2#/[-SDX?(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C4Y(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#,*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;B(*;7-G<W1R("+%\.7NY?'CX?/?X2#%[N_U\^GOY/STY_/G\B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BQ?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0IM<V=I9"`B161I="!0
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BQ?#E[N7QX^'SW^$@Q>[O]?/I
M[^3O]-[SY?GM(./IX2`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.CD*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(L7PY>[E\>/A
M\]_A(.7PZ>OOX_[M(./IX3HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("+%\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E^>T@X^GA("5S(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,C`T(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C@X"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`G)7,G(@IM
M<V=S='(@(L7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)R5S)R(*
M"FUS9VED(")%;&5F<VES($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@
MQ>OE]?/?[>'R(@H*;7-G:60@(DAE<F%K;&EO;B!!:7)P;W)T(@IM<V=S='(@
M(L'E\>_KZ>S=[>'R(,?QX>KKY=_O]2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N
M="XN+B(*;7-G<W1R("+3]._I]^7?[RXN+B(*"FUS9VED(")%;6%I;"(*;7-G
M<W1R("+!Z^OGZ^_C\>'VW^$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X.2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#`*;7-G
M:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G($5M86EL(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B16UA:6P@
M861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(L<@Y.GE_>CU[?/G($5M
M86EL(/#QW?#EZ2#MX2#TX>GQZ=SFY>DN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW,@IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`BS-[M]>SA(.SE(/'UZ.S?\^7I\B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR.#`*;7-G:60@(D5M;W1I8V]N
M<R(*;7-G<W1R("+!Z?/HWNSA].$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(D5M<'1Y(&UE<W-A
M9V4N(@IM<V=S='(@(LKE[?P@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,3,Q"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S
M='(@(L3E[2#E\.GS]/'<]N?JX>T@P?#O].7KW?/LX?3A+B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,30*;7-G:60@(D5M<'1Y('-E
M87)C:"!T97)M<R(*;7-G<W1R("+!Y.7IY?(@\_7MZ-[JY?(@X>WAYM[TY_/G
M\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(D5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_(@IM<V=S='(@(L7MY?'C[_#OW^?SYR#EZ?/AX_GCWO(@Y>GJ_.WY
M[2#A\.\@4&AO=&\@0V%L;&5R:65W(//T[R#JY=_LY>WO.R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,#$*;7-G:60@(D5N86)L92!R:6=H="!C;&EC
M:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(LWA(.7MY?'C[_#OZ>?HY=\@].\@
M[.7M[_T@[.4@Y.7NWR#JZ^GJ.R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0X"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34S"FUS9VED(")%;F0B"FUS9W-T
M<B`BU-WK[_(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DP(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3D*;7-G:60@(D5N9"!Y96%R(@IM
M<V=S='(@(KCT[_(@U-WK[_7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS
M9W-T<B`BS.7CW>WH]?/G(,KEZ>SE[>_C\=SV[_4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C`U"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HBQ/[S].4@[.GA(.7Q_O3G
M\^<@X?/VX>OEW^'R+"#G(._P[]_A(.CA(//A\B#FY_3GZ.7?(.'M(/?QY>GA
M\^CEWR#MX2#AZ^O<[N4M(@HB].4@]._M(.KYY.GJ_"#SX?(L(/`N]RX@)]#O
MZ?P@Y=_MX>D@].\@_.WO[.$@]._U(.KA]._IZNGDW^_U(//A\CLG.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S
M='(@(L3^\_3E(/3G(//][>3E\^<@].?R(.7IZOSMX?(@Y>3^(@H*;7-G:60@
M(D5R<F]R(@IM<V=S='(@(LO<Z._R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ.34*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR-S@*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#<*;7-G:60@(D5R<F]R
M('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R("++W.CO\B#A\._S]-WKZ^_M
M].'R(.'PW.WTY_/G.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R("++W.CO\B#LY2#LWNWU[.$@96UA:6PN(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$T,PIM<V=I9"`B17)R;W(@=W)I=&EN9R`G
M)7,G+B(*;7-G<W1R("++W.CO\B#C\=SV[^WTX?(@7"(E<UPB+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@
M(L7H[>GJ_"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B175R;W!E(@IM<V=S='(@(L7U\?[PYR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,C,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T
M<B`BRMSHY2`Q-2#KY?#TW"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+*W.CE(#(@R^7P
M]-PB"@IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+*W.CE(#,P
M(.3E]?3E\?SKY?#TX2(*"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`BRMSHY2`U(.OE\/3<(@H*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@
M(LK<Z.4@]N_QW"#P[_4@[/#AW^WE].4@\_3G[2#U\.?QY?/?X2(*"FUS9VED
M(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BRMSHY2#LZ?/>(/[QX2(*"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BRMSHY2#KY?#T_"(*"FUS9VED
M(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BT.'QX>3EZ>/LX?3IZMWR(/3I
M[-WR.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW-B!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$S-@IM<V=I9"`B17AE8W5T
M92(*;7-G<W1R("+%ZO3=Z^7SYR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C,X-@IM<V=I9"`B17AP86YD(@IM<V=S='(@(L7PW>KT
MX?/G(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,0IM<V=I
M9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`BQ?#=ZO3A\^<@T.OE]?'IZM[R
M(,SPW/'A\B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-CD*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("+![>'LW>WO[?3A[2`G
M*2<B"@HC.B!C+69O<FUA=`IM<V=I9"`B17AP96-T960@7")"14=)3EPB(&EN
M('1H92!L:6YE("5D+B(*;7-G<W1R("+![>'LY>W\[.7M[R!<(D)%1TE.7"(@
M\_3G(./QX>SLWB`E9"XB"@HC.B!C+69O<FUA=`IM<V=I9"`B17AP96-T960@
M7")%3D0Z)7-<(B!I;B!L:6YE("5D+B(*;7-G<W1R("+![>'LY>W\[.7M[R!<
M(D5.1#HE<UPB(//TYR#C\>'L[-X@)60N(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$W-@IM<V=I9"`B17AP96-T960@8F%R92!W;W)D
M(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("+![>'LW>WO[?3A[2#A
M\.O>(.O=[N<@WB#S]>WHWNKG(.'MX>;>].?SY_(@\^4@Y>GSX>/YX^GJW"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.`IM<V=I9"`B
M17AP:7)A=&EO;B!$871E(@IM<V=S='(@(L?LY?'O[.?MW^$@R][NY_(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B
M17AP;VYE;G0B"FUS9W-T<B`BQ>KHW?3G\B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O
M;&]R(@IM<V=S='(@(M?Q_NSA(/#Q[_/JWNWI[_4B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Q"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM
M<V=S='(@(M'UZ.S?\^7I\B#CZ>$@1E10('5P;&]A9"(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(T,`IM<V=I9"`B1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(L'P[_3U]]_A(.KA]-P@].?M
M(/#Q[_/PW.CEZ>$@X>W<ZO3G\^?R(/3Y[2#P\>_TZ>S>\^7Y[2XB"@IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(L'P[_3U]]_A(//][>3E\^?R(//T[^T@Y.GAZN_LZ?/TWB#*X?3AZ_SC[_4N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C$P,PIM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`BP?#O
M]/7WW^$@\_WMY.7SY_(@\_3O[2!334(M4V5R=F5R+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-C,Q"FUS9VED(")&86EL960@=&\@8V]P>2!F
M<F]M(%PB)7-<(BXB"FUS9W-T<B`BP?#O]/7WW^$@X>WTZ>/QX?;>\B#A\/P@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C,V"FUS
M9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(L'P[_3U
M]]_A(.'M].GC\>'VWO(@\^4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<V%S;"YP:'`Z.3(*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`BP?#O]/7WW^$@Y.?LZ>_U\>/?
MX?(@\_WMY.7SY_(@4T%33"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8W,0IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G
M<W1R("+!\._T]???X2#LY?3A]N_QW/(@\^4@7"(E<UPB+B(*"FUS9VED(")&
M86EL=7)E(&EN(&-H86YG:6YG('!A<W-W;W)D(&9O<B!U<V5R("5S(&9R;VT@
M8VQI96YT("5S+"!R96%S;VX@)7,B"FUS9W-T<B`B(@HBP?#O]/7WW^$@ZN'T
MW"#TY^T@X>OKX>/>(.KYY.GJ[_T@X^GA(/3O[2#W\=[S].<@)7,@X?#\(/3O
M(//TX>CL_"`E<RP@Z_SC[_(@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S$V"FUS9VED(")&86ER(@IM<V=S='(@(L'?Z/'I[_(B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,U"FUS9VED(")&871A;"!%<G)O
M<CHB"FUS9W-T<B`BT._K_2#S[^+A\?P@R]SH[_(Z(@H*;7-G:60@(D9A>"(*
M;7-G<W1R("+6P<XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`BUN7B\>_UW/'I
M[_(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q.`IM<V=I9"`B1F5E;',@
M3&EK92(*;7-G<W1R("+$Z=SHY?/G(./IX2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ.#`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R
M("+$Z=SHY?/G(./IX3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q-PIM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`BR]_CY?(@XO'O
M]]WR(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.`IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("++W^/E\B#WZ>_M[_#T_O/E
MZ?(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3(W"FUS9VED(")&
M:65L9"!M871R:7@B"FUS9W-T<B`BT-_MX>KA\B#0Y>3?[_4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL92(*;7-G<W1R("+!\>GH[/SR(.'Q]^7?[_4Z("5S(.'Q]^7?[R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE<R(*;7-G<W1R("+!\>GH[/SR(.'Q]^7?[_4Z("5S(.'Q]^7?
MX2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@(D9I
M;&4@36%N86=E<B(*;7-G<W1R("+$Z>'WY>GQZ?/TWO(@P?'WY=_Y[2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&:6QE($YA;64B
M"FUS9W-T<B`BO.WO[.$@P?'WY=_O]2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y-SD*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(L7P
MZ>OOX]X@P?'WY=_O]2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M.#(*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B?![=WBX?/LX2<@P?'W
MY=_O]2(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-`IM
M<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B?!
M[=WBX?/LX2<@P?'WY=_O]2#DY>T@]?#O\_3G\=_FY?3AZ2XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#8*;7-G:60@(D9I;'1E<G,B"FUS9W-T
M<B`BUM_K]/'A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$W,0IM<V=I9"`B
M1FER<W0@2&%L9B(*;7-G<W1R("+0\?[T[R#,Z?/\(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER
M<W0@475A<G1E<B(*;7-G<W1R("+0\?[T[R#4W?3A\?3O(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.0IM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(M/TX>CE\?SR(.O\X^_R(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`IM<V=I9"`B1FQI<"(*
M;7-G<W1R(")&;&EP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B1FQO
M870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED
M(")&;V<B"FUS9W-T<B`BS^S?]^OG(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P.`IM
M<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(L\@]MSJ
MY>OO\B`E<R#DY>T@]?#<\??EZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T
M<B`BU_'^[.$@X_'<[.SA]._R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(M3Q[_;>(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R("+#Z>$@0G)O=W-E<G,L(/#O]2#DY>T@]?#O\_3G\=_F[_7M(.7I
MZOSMY?(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDU"FUS9VED
M(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`BSN7WW//A].4@]._M
M(.KYY.GJ_"#SX?([(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M,0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BUOSQ[.7R(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(M#Q_.+K
MY?CG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T
M=6YE('1Y<&4B"FUS9W-T<B`BU/WP[_(@T/'\XNOE^.?R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("+0
M\>_BZ]WXY>GR(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(M#Q[^+KW?CEZ?(@,B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,30*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M(")&;W)U;7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4X"FUS
M9VED(")&;W)W87)D<R(*;7-G<W1R("+0\>_YZ-[SY>GR(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B
M"FUS9W-T<B`BT.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`BT.OA
MW_/IX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#$W"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T
M<B`BT.OG\>_V[_'?Y?(@Q.GAZ.7SZ>S\].?TX?(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R-PIM<V=I9"`B1G)E
M92]"=7-Y(%)E<&QY(@IM<V=S='(@(L'PW.WTY_/G(,3IX>CE\^GL_/3G].'R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HT,C(*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S='(@(L'?].?L
MX2#$Z>'HY?/I[/STY_3A\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0Q"FUS9VED(")&<F5E+T)U<WD@4F5Q
M=65S="!297-P;VYS92(*;7-G<W1R("+!\-SM].?SYR#SY2#AW_3G[.$@Q.GA
MZ.7SZ>S\].?TX?(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<Y"FUS9VED(")&<F]M(@IM<V=S='(@(L'P_"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.3<*;7-G:60@(D9R;VT@=&AE
M("(*;7-G<W1R("+!\/P@].\@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
MP>WAZ_7TZ>K>(-#E\>GC\>'VWB(*"FUS9VED(")&=6QL($1E<V-R:7!T:6]N
M.B(*;7-G<W1R("+![>'K]?3IZMX@T.7QZ>/QX?;>.B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HX,B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3@Q"FUS9VED(")&
M=6QL($UO;VXB"FUS9W-T<B`BT.O>\>?R(-/EZ][MYR(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,SD*;7-G:60@(D9U;&P@3F%M92(*
M;7-G<W1R("+0Z][QY?(@O.WO[.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&QE<GD@X?#\(/3G
M[2#O\._?X2#HX2#PX=_Q[>_M].'I(._I(.7IZOSMY?(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*
M;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&QE<GDZ(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(D=I=F5N($YA
M;64B"FUS9W-T<B`BS.GJ\?P@O.WO[.$B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T
M:6]N<R(*;7-G<W1R("+#Y>WIZMWR(,7PZ>OOX]WR(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,38*;7-G:60@(D=O(@IM<V=S='(@(LSE]-SBX?/G
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=R965C92(*;7-G<W1R("+%Z^O<Y.$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(L7KZ^?MZ>K<("A)4T\M.#@U.2TW*2(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3<P"FUS9VED(")'<F]U<"!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("+$Z>'WY=_QZ?/G(,_LW.3Y[2(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"YP:'`Z-3<*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y(@IM<V=S='(@(M3A(._M_.SA].$@]/GM(._LW.3Y[2#D
MY>T@\/'=\.7I(.WA(.7?[>'I(.KE[=PB"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HR,#$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.#4*;7-G
M:60@(D=R;W5P('!E<FUI<W-I;VYS(@IM<V=S='(@(L7N[_7SZ>_D[_3>\^7I
M\B#/[-SD^>TB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-S8@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-3@*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#,*;7-G:60@
M(D=R;W5P<R(*;7-G<W1R("+/[-SDY?(B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,C<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,3,*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY-`IM<V=I9"`B1W5E<W0@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`BR>3I_/3G].7R($=U97-T(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3(X(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C$T"FUS9VED(")'=65S="!P97)M:7-S:6]N<R(*;7-G<W1R("+)Y.G\
M].?TY?(@1W5E<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y
M"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B1W5E<W1B;V]K(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-C0*;7-G:60@(DA45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("+4[R#S_?/TY^SA(.'U
MZ.7M].GJ[_#OW^?SY_(@2%144"#DY2#B\=WHY^KE+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@
M(DAE:6=H="(*;7-G<W1R("*^^._R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP
M:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E
M<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(L+OWNCE
MZ>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("+"[][HY>GA
M(./IX2#TYR#W\=[SYR#T[_4@ZN7I[.7M[^/QW/;O]2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-C<*;7-G:60@(DAE;'!E<B(*;7-G<W1R("+"
M[^?H_/(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES
M<&AE<F4B"FUS9W-T<B`BQ^SI\_;AW_'I[R(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W
M"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM
M<V=S='(@(L7D_B#EW^WAZ2#G(.'Q]]X@]._U(.'Q]^7?[_4Z(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0IM<V=I9"`B2&EG:"(*;7-G
M<W1R("+8Y^O<(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z
M,S(R"FUS9VED(")(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y(@IM<V=S='(@(L<@Y>/C\>'VWB#I\_3O\>GJ[_T@Y.7M(/#QW?#EZ2#M
MX2#EW^WAZ2#JY>W>(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHT"FUS9VED(")(
M;U]M92(*;7-G<W1R("+!\??IZMX@T^7KW^3A(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-#8P"FUS9VED(")(;VUE(@IM<V=S='(@(L'Q]^GJ
MWB#3Y>O?Y.$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-3@*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+$Z>7]Z/7M
M\^<@T_#I].GO_2(*"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(M3GZ]WV
M^>WO(-/PZ?3I[_TB"@IM<V=I9"`B2&]R9&4B"FUS9W-T<B`BP?'WZ>K>(-/E
MZ]_DX2(*"FUS9VED(")(;W)D92!,;V=I;B(*;7-G<W1R("+%W_/OY._R(//T
MY^T@U?#G\>7SW^$@Q\OEZO3Q[^WIZN_](-3A]_7D\>_LY=_O]2(*"FUS9VED
M(")(;W)D92!3>7-T96TB"FUS9W-T<B`BT_WS].?LX2`G2&]R9&4G(@H*;7-G
M:60@(DAO<F1E(%=I<F5L97-S(@IM<V=S='(@(B=(;W)D92<@P?/]\>SA].<B
M"@IM<V=I9"`B2&]R9&4@:7,@;F]T('!R;W!E<FQY(&-O;F9I9W5R960B"FUS
M9W-T<B`BU.\@\/'\X_'A[.SA("=(;W)D92<@Y.7M(-WWY>D@\?7H[.GS].7?
M(//Y\_3<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(L_QZ>;\
M[?3I[_(@RN'M_.WA\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G
M<W1R("+/\>GF_.WTZ>\@)^/=[.GS[.$G(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB
M"FUS9W-T<B`BS_'IYOSM].GO.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`BT/GR(/;H
MW//A].4@Y>3^.R`H\.'QX>KAZ_X@[>$@].\@X>WA]MWQY?3E(//T[R#DZ>'W
MY>GQZ?/TWB$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BT/SSY?(@\_3>Z^7R(.C=
MZ^7TY2#MX2#E[>_P[^G>\^7TY3LB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR.`IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(M#\\^$@\.7DW^$@*//TWNOE\BD@Y=_MX>D@
MY>KEWSLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R("+0_//E\B#C\>'L[-WR(.C=Z^7TY2#M
MX2#E[>_P[^G>\^7TY3LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.`IM
M<V=I9"`B2'5M:61I='DB"FUS9W-T<B`BU>/QX?/?X2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#,*;7-G:60@(DAU;6ED:71Y.B`B"FUS
M9W-T<B`BU>/QX?/?X3HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*
M;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("+7Z>_U[._QW_/TX?(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S8@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C(R,PIM<V=I9"`B24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BQR#$Y^SI[_7QX]_A(./QX>SL
MX?3OZ/7QW^3A\B!)34%0(.'PW?3U]^4Z("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C(P(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR.#@*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S(@IM<V=S='(@(L<@Y.GAX_'A]MX@X_'A[.SA]._H]?'?Y.'R($E-
M05`@X?#=]/7WY3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ.#,@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S,`IM
M<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`BQR#$Y^SI[_7QX]_A(/#EZ?'O\>GS[/[M("AQ=6]T82D@X_'A
M[.SA]._H]?'?Y.'R($E-05`@X?#=]/7WY3H@)7,B"@IM<V=I9"`B24Y"3U@B
M"FUS9W-T<B`BQ>GSY?'W_.SE[>$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S$Q"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0+<3IY?WH
M]>WSYR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#(*
M;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`M
MQ.GE_>CU[?/G(.3E[2#EW^WAZ2#DZ>'HW?/I[.<N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I<&)A<VEC+G!H<#HY-`IM<V=I9"`B25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`MQ.GE
M_>CU[?/G(.SG(.7PZ?3QY?#TWB#LW?/A(//E($-)1%(M0FQO8VLN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T
M"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(LKKY=_D
M^>SA+=#A\>'BW^'SYR!)4"XB"@IM<V=I9"`B25]N8F]X(@IM<V=S='(@(L7I
M\^7Q]_SLY>WA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B
M"FUS9W-T<B`BQ>GSX>/YX]X@P_'A[.S>\B#0\>GM(@H*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`BS/SM[R#%Z>KO[=_DZ>$B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("+%
MZ>KO[=_DZ>$@X^GA("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V
M,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(L7IZN_MW^3IX2#J
MX>D@RN7?[.7M[R(*"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@
M(L_M[^SA(/3A]?3\].?TX?(Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-C`X"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D
M(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM
M<V=S='(@(L'M(.3E[2#E[/;A[=_FY?3AZ2#S^?/TW"P@)7,@X^GA(.WA(.'M
M[]_NY>D@\^4@[=WO(/#A\=SH]?'O+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,SD*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS
M('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE
M8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB
M"FUS9W-T<B`B(@HBP>T@Y.4@XNO=\.7TY2#JX>W=[>$@Y>GJ[^W?Y.GO(/?Q
MY_/I[._P[^G^[?3A\B#T[^T@26YT97)N970@17AP;&]R97(L(-_S^?(@(@HB
M\/'=\.7I(.WA(/3SY>K<\>7TY2#EY/X@X^GA(.WA(.'PY>WE\>/O\._IWO/E
M].4@].<@Y.GA]MSMY>GA(%!.1RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,34X"FUS9VED("(B"B))9B!Y;W4@<V5E('1H
M:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T
M;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BXB"FUS9W-T<B`B(@HBP>T@XNO=\.7TY2#A]?3\(/3O(.S>[?7LX2#W^?'?
M\B#EZ>K\[>$L(.<@Y>GJ_.WA(/#O]2#HW>OE].4@[>$@ZN'TY>+<\^7TY2#D
MY2`B"B+L\._QY=\@[>$@Y>SVX>WI\^CEWR#A\/P@]._M(&)R;W=S97(@\^'R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B
MT/'OY?#I\^K\\.GSYR#%Z>K\[>'R.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%52
M3"(*;7-G<W1R(")54DP@Q>GJ_.WA\B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(L7IZOSMX2#A\/P@1V%L;&5R>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R
M("+%Z>K\[>$@X?#\($=A;&QE<GDZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<T.`IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(L'P[_/T
M[^O>(,7IZOSMX?(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I
M9"`B26UA9V5S(@IM<V=S='(@(L7IZOSMY?(B"@IM<V=I9"`B26UP;W)T(@IM
M<V=S='(@(L7I\^'C^>/>(@H*;7-G:60@(DEM<&]R="!%<G)O<CH@(@IM<V=S
M='(@(LO<Z._R(.KA]-P@].?M(,7I\^'C^>/>.B`B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ,`HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED("));7!O<G0L(%-T97`@)60B
M"FUS9W-T<B`BQ>GSX>/YX]XL(,+>[.$@)60B"@HC('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C(P+"!C+69O<FUA=`HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHR,`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S
M='(@(M#EY-_O(/#O]2#EZ?/>]^CG.B`E<R(*"FUS9VED("));7!O<G1E9"!F
M:65L9',Z(@IM<V=S='(@(M#EY-_A(/#O]2#EZ?/>]^CG\^'M.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`Q"FUS
M9VED("));B!0<F]C97-S(@IM<V=S='(@(M/E(,7PY>[E\>/A\]_A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("+%Z?/AX_GC
MWB##\>'L[-[R(,SE]-PB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ-#$*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BXB"FUS9W-T<B`BQ/SHY^KE(.O<Z._R(.KYY.GJ_/(@Y>W=\>/EZ>'R
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C4W"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R("++W.CO\B#\[>_LX2#W\=[S].<@WB_JX>D@ZOGDZ>K\
M\BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B
M(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B++W.CO\B#\[>_L
MX2#W\=[S].<@WB#E[>'KZ^'J].GJWB#DZ>7]Z/7M\^<N(,[A[>'D[^KI[-SS
M].4@WB#E\.GJ[^GM^>W>\_3E(.SE("(*(O3O(.3IX??EZ?'I\_3>(./IX2#P
MY?'AZ?3=\?D@XN_>Z.7IX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS
M9W-T<B`BP?WNY_/G(-#E\>GH^?'?[_4B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ-#$@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-#`*;7-G:60@
M(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`BR>3IX=_TY?'OZ2#7\=[S].7R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,@IM<V=I9"`B26YF;R(*;7-G<W1R("+0Z^?Q[_;O\=_E\B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#D*;7-G:60@(DEN9F]R;6%T:6]N(@IM
M<V=S='(@(M#KY_'O]N_QW^7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@0U]O
M;'5M;B!!9G1E<B(*;7-G<W1R("+%Z?/AX_GCWB#3]-[KY_(@S.7TW"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(L7I\^'C^>/>
M(,7IZOSMX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`BQ>GSX>/Y
MX]X@T-_MX>KA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(L7I
M\^'C^>/>(//][>3E\^?R(%=E8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B26YS97)T(%]#
M;VQU;6X@0F5F;W)E(@IM<V=S='(@(L7I\^'C^>/>(-/TWNOG\B#0\>GM(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("+%Z?/AX_GCWB#MW>'R(//TWNOG\B#LY?3<
M(/3G[2#T\=WW[_7SX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L7I\^'C^>/>
M(.W=X?(@\_3>Z^?R(/#QZ>T@X?#\(/3G[2#T\=WW[_7SX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`BQ>GSX>/YX]X@[=WA\B#C\>'L[-[R(.SE]-P@].?M(/3QW??O
M]?/A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8P"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BQ>GSX>/YX]X@[=WA\B#C\>'L[-[R
M(.SE]-P@].?M(/3QW??O]?/A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P
M87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("+%Z>'C
M^>/>(/#A\>'C\=SV[_4@[.7TW"#T[^T@]/'=]^_M].$@ZOSLXN\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C@*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("+%Z?/AX_GCWB#PX?'AX_'<]N_U(/#QZ>T@]._M
M(/3QW??O[?3A(.K\[.+O(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*
M;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BQ>GS
MX>/YX]X@Y>WAZ^OAZO3IZN_](/#Q[_3]\._U(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R,PIM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@
M=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM
M<V=S='(@(B(*(L3^\_3E(&5M86EL(.3IY?WH]>WSYR#S].?M(._P[]_A(.7P
MZ>CU[.7?].4@[>$@\.'QX>O<XN7TY2#T[R#MW>\@\^'R(.KYY.GJ_#HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("+%Z?/AX_GC
MWB#JY>OI[_T@[.7TW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R
M92(*;7-G<W1R("+%Z?/AX_GCWB#JY>OI[_T@\/'I[2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@
M(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`BQ>GSX>/YX]X@\_3>Z^?R
M(.SE]-PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G
M<W1R("+%Z?/AX_GCWB#S]-[KY_(@\/'I[2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`BQ>GSX>/YX]X@[.?M_>SA]._R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(L7I\^'C^>/>(/#A
M\>'C\=SV[_4@[.7TW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!B969O<F4B"FUS9W-T<B`BQ>GSX>/YX]X@\.'QX>/QW/;O]2#P\>GM(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("+%Z?/AX_GC
MWB#C\>'L[-[R(.SE]-PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R("+%Z?/AX_GCWB#C\>'L[-[R(/#QZ>TB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C$T"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D
M(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(L7I
M\^'C^>/>(/3G\B#A\.'I]._][.7MY_(@X?#<[?3G\^?R(//TY^T@Y?'^].?S
MYR#A\_;AZ^7?X?(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G
M<W1R("+%Z?/AX_GCWB_$Z?SQZ/GSYR#%Z>K\[>'R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!,:6YK(@IM<V=S='(@(L7I\^'C^>/>+\3I_/'H^?/G(-/][>3E
M\^?R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-C@*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(LSG(.7PX?'JW?(@
M]?#\Z^_I\.\@X^GA(.'P[_/T[^O>(//TYR#KW_/TX2#DZ>'M[^S>\BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V
M,`IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`BS.<@Y?#A
M\>K=\B#U\/SK[^GP[RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#8Y"FUS9VED("));G1E9V5R(@IM<V=S='(@(L'JW?'AZ>_R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R-PIM<V=I9"`B26YT96=E<B!L:7-T
M(@IM<V=S='(@(LO?\_3A(,'JY?'AW_GM(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#,*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3(*;7-G:60@(DEN=F%L
M:60@06-T:6]N('-E;&5C=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T
M<B`BQ?#IZ]WNX?3E(,O<Z._R(,7MW?'CY>GA(./I)R#A]?3\(/3O(//U\_3A
M].GJ_"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN(@IM<V=S='(@(L'J]?'O(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L
M:60@87!P;&EC871I;VXN(@IM<V=S='(@(LSG(-WCZO7QYR#E]N'Q[._CWBXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,C$*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(L'J]?'O
M($)A=&-H+4E$+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T,0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.#`*
M;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(M/TW.OH
MY^KA[2#KW.CO\B#DY>3O[-WMX2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(DEN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`BP>KU\><@Y.GE_>CU[?/G(/#Q
M[^_QZ?/L[_TN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#0*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`S"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,PIM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("+,YR#=
MX^KU\><@[._Q]MX@X?'WY=_O]2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-@IM<V=I9"`B26YV86QI9"!M<V=?
M='EP92XB"FUS9W-T<B`BS.<@W>/J]?'O(&US9U]T>7!E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`BS.<@W>/J
M]?'O(-X@Z^7?\.7I(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("+,YR#=X^KU\>7R(-X@Y>OK
MZ?#EW_(@\.'QW.SE]/'OZ2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-#,*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED("))
M;G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("+,YR#=X^KU\>\@\/'Y]/SJ[^OK
M[RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.CDQ"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@)R5S)R(*;7-G<W1R
M("+,YR#=X^KU\>_R(/#A\>'KWO#TY_(Z("<E<R<B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$P-S$@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C0X"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("+,
MYR#=X^KU\>\@ZN_I[?SW\>?S].\@X>WTZ>KEW^SE[>\B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(LSG(-WCZO7QYR#A
M\??IZMX@Y.GE_>CU[?/G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,R,`IM<V=I9"`B26YV86QI9"!U;FEC;V1E
M(&1A=&$N(@IM<V=S='(@(LSG(-WCZO7QX2#DY>3O[-WMX2!5;FEC;V1E+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(DEN=F5N
M=&]R>2(*;7-G<W1R("+*X?3<Z^_C[_(@U?#A\??\[?3Y[2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A
M;&EC(@IM<V=S='(@(M#KX>/IX2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-S0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(LGA
M[>_UW/'I[_(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("+)[_WKZ>_R(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU
M;F4B"FUS9W-T<B`BR>_][>GO\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS
M9W-T<B`BQ?7H]>/QW.SLZ?/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N
M=&5R(@IM<V=S='(@(L7UZ/7C\=SL[.GSYR#S].\@RMWM]/'O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*
M;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("+0Z][QY_(@Q?7H]>/QW.SL
MZ?/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("+%]>CU
MX_'<[.SI\^<@P?'I\_3E\=PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H
M="(*;7-G<W1R("+%]>CUX_'<[.SI\^<@Q.7NZ=PB"@IM<V=I9"`B2V%L86UA
M=&$@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#*X>OA[-STX?(B"@IM
M<V=I9"`B2V%R<&%T:&]S($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@
MRN'Q\-SH[_4B"@IM<V=I9"`B2V%S=&]R:6$@06ER<&]R="(*;7-G<W1R("+!
MY?'OZ^GLW>WA\B#*X?/T[_'IW/(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0V"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("+-X2#J\>'TWO/Y(/3O(.'UZ.7M].GJ_#LB"@IM<V=I9"`B2V5F
M86QH;FEA($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@RN7VX>OO[>G<
M\B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#<*;7-G:60@
M(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B2V5R8F5R;W,M4V5R=F5R(.'Q[=[HY^KE(/3G[2#A]>CE[?3IZN_P
M[]_G\^<N(@H*;7-G:60@(DME<FMY<F$@06ER<&]R="(*;7-G<W1R("+!Y?'O
MZ^GLW>WA\B#*W?'J]?'A\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`BS=WA(.'P_"!+97)N
M96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3<*;7-G
M:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("+$Y^SI[_7QX]_A(,KKY>GDZ>_]
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED
M(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`BP?#O]/WP^>SA(,KKY>GDZ>_]
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDX"FUS9VED
M(")+97D@3&5N9W1H(@IM<V=S='(@(LS>ZN_R(,KKY>GDZ>_](@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDW"FUS9VED(")+97D@5'EP
M92(*;7-G<W1R("+4_?#O\B#*Z^7IY.GO_2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C(R"FUS9VED(")+97D@57-A9V4B"FUS9W-T
M<B`BU_'>\^<@RNOEZ>3I[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW-#,*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BU.\@ZNOEZ>3?(/7PW/'WY>D@
MWN3G(//T[^T@Y>[U\.?QY?3G]-X@Y.?L_//I^>T@ZNOEZ>3I_NTN(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@
M(M#AZ>3IW"(*"FUS9VED(")+;W,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GL
MW>WA\B#*^2(*"FUS9VED(")+;WIA;FD@06ER<&]R="(*;7-G<W1R("+!Y?'O
MZ^GLW>WA\B#*[^;<[>?R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(L3IW/3A[N<B"@IM<V=I9"`B
M3&%R:7-A($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@R]SQZ?/A\B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DQA<W0@2&%L9B(*
M;7-G<W1R("+4Y>OE]?3AW^\@S.GS_"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX."!L:6(O0FQO8VLO;6]O;BYP:'`Z.3`*;7-G:60@(DQA<W0@475A<G1E
M<B(*;7-G<W1R("+4Y>OE]?3AW^\@U-WTX?'T[R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,30Y"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(M3E
MZ^7U].'?X2#%[>?LW?'Y\^<Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-CDQ"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+4Y>OE]?3A
MW^$@Q=_S[^3O\B#S].?M(/7PY_'E\]_A.B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C8Y,PIM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<R(*;7-G<W1R("+4Y>OE]?3AW^$@Q=_S[^3O\B#S].?M(/7PY_'E\]_A.B`E
M<R#A\/P@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HV.#@*;7-G
M:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(M3EZ^7U].'?X2#%W_/O
MY._R(//TY^T@]?#G\>7SW^$Z(-#O]-TB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("+-_.SO\B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I
M9"`B3&%Y;W5T(@IM<V=S='(@(L3IW/3A[N<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(L'VWO/TY2#JY>W\(./IX2#MX2#L
MY^T@]?#<\??O]>T@\.7QZ>C^\>GA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S
M='(@(L'QZ?/TY?'<(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P
M,PIM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`BP?'I\_3E\=X@Q?#IZN7V
MX>O?Y.$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DY"FUS9VED
M("),969T('9A;'5E<R(*;7-G<W1R("+!\>GS].7QW?(@U.GLW?(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(M#E[?3<\_3I]^\B"@IM<V=I9"`B3&EM;F]S($%I<G!O<G0B"FUS9W-T
M<B`BP>7Q[^OI[-WMX?(@R][L[>_U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@P,0IM<V=I9"`B3&EN:R(*;7-G<W1R("+3_>WDY?/G(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4V"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`BT_WMY.7SYR#P
M[_4@Y.7?]^WEZ2#SY3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#4X"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP
M;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(M/][>3E\^<@].?R
M(.3IY?WH]>WSYR#CZ>$@W.WOZ>/LX2#PX?'AZ/WQ[_4@\_WMZ.7SY_([(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$V,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`BT_7MY-WSY>GR(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS
M9W-T<B`B3&EN=7@M0V]O:VEE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T("T@SR#W\=[S].?R(.SP[_'EWR#M
MX2#DY=\@].\@]MSJY>OO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S.`IM
M<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`BR]_S].$@PMSSY?GM(,3E
MY._LW>WY[2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED
M("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(LO?\_3A(.CE[-ST^>T@PN_>
MZ.7IX?(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,W"FUS9VED("),:7-T
M(%1A8FQE<R(*;7-G<W1R("++W_/TX2#0Z>W<ZOGM(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHT"FUS9VED("),:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+'(.3G[.GO]?'CW^$@Z]_S].'R(/?Q
MY_/T_NT@W??EZ2#A\.7MY?'C[_#OZ>?HY=\N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX-@IM<V=I9"`B3&]A9&EN9RXN
M+B(*;7-G<W1R("+6_/'T^?/G+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(M3O
M\.GJWB"_\>$Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I
M9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(M3\\._R(.KAZ2#^\>$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W,"!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3`*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C,*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(M3\\._HY?/?X2(*"FUS9VED("),;V<@:6XB"FUS9W-T
M<B`BQ=_S[^3O\B(*"FUS9VED("),;V<@;W5T(@IM<V=S='(@(KCN[^3O\B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A
M<VMS(@IM<V=S='(@(L3IY?'CX?/?Y?(@Y>GS_.3O]2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDU,@IM<V=I9"`B(@HB3&]G:6X@9F%I;&5D(&9O
M<B!S;VUE(')E87-O;BX@36]S="!L:6ME;'D@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@(@HB96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B
M(@HBQR#EW_/OY._R(,'PW?3U]^4N(-#IZ.'M_/3A].$@Y/SHY^KE(.O<Z._R
M(/3O(+SM[^SA(-?QWO/TYR#>(.\@ROGDZ>K\\BXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY-#@*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T
M<B`BQ=_S[^3O\B#!\-WT]??E+B(*"FUS9VED("),;V=O=70B"FUS9W-T<B`B
MN.[OY._R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V,0IM<V=I
M9"`B3&]N9R!T97AT(@IM<V=S='(@(LSEX]SK[R#*Y=_LY>WO(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(L'C
MW/#G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U.0IM<V=I
M9"`B3&]W(@IM<V=S='(@(M?A[.?K_"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R
M(&=R965K(&QE='1E<G,B"FUS9W-T<B`BS.GJ\=P@Q>OKY^WIZMP@X_'<[.SA
M].$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S
M='(@(LSIZO'<(.OA].GMZ>K<(./QW.SLX?3A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("+,Z>KQW"#1^>SA^NK>(,'Q
MW^CLY_/G(@H*;7-G:60@(DU-(@IM<V=S='(@(LS,(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R("+,X>/IZOPB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S$*;7-G:60@(DUA:6PB
M"FUS9W-T<B`BP>OKY^OOX_'A]M_A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Q-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("+$Z>'WY=_Q
MZ?/G($5M86EL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S
M='(@(L3G[.GO]?'CW^$@T_WMY.7SY_(N+BXB"@IM<V=I9"`B(@HB36%N86=E
M('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E
M;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RXB"FUS9W-T<B`BQ.GA]^7?\>GSYR#JX?3GX^_QZ?[M(.KA
MZ2#W\?GLW/3Y[2#P[_4@Z.$@Y>SVX>W?YN_M].'I(.'U]-WR+B(*"FUS9VED
M(")-86YU86PB"FUS9W-T<B`BQ>/WY>GQW^3I[R(*"FUS9VED(")-87`@1&%T
M92!A;F0@5&EM92!&:65L9',B"FUS9W-T<B`BT.7DW^$@Q^SE\>_LY^W?X?(@
MZN'I(+_QX?(B"@IM<V=I9"`B36%P($EM<&]R="!&:65L9',B"FUS9W-T<B`B
MT.7DW^$@Y>GSX>/YX][R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,W-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(LS<\?3I[_(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`BO/'I[R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`BS.'QZMSQZ?/LX2#L
MY2#=[>3EZ>[G(,'MX>/M^?/LW>WO]2_,YR#A[>'C[?GS[-WM[_4B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB"FUS9W-T<B`BS.'QZMSQZ?/LX2#LY2#<Z^OG(-WMY.7I[N<@*/`N]RX@
MT^?LX>WTZ>K\+\'PX>WTY^S=[>\I(@H*;7-G:60@(DUA=&-H:6YG(&9I96QD
M<R(*;7-G<W1R("+0Y>3?X2#P[_4@].'I\>G<YN_U[2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R-`IM<V=I9"`B
M36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("+,W>/I\_3G(.7PZ?3QY?#T
MWB#PW_/T^?/G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q-PIM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N(@IM<V=S='(@(M7PW?'BX?/G(._QW^_U(.SG[?WLX?3O\BXB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-`IM<V=I9"`B36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(LS=X^GS].<@Z.7Q[._J\>'SW^$@].7K
MY?7TX=_Y[2`R-"#Y\?[M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M-@IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`BS-WC
MZ?/TYR#HY?'L[^KQX?/?X2#TY>OE]?3AW_GM(#8@^?'^[3H@(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,`IM<V=I
M9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`BS-WCZ?/T[R#LWNKO\B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S@*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED
M(")-87DB"FUS9W-T<B`BS-SI[_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4S,0IM<V=I9"`B365E=&EN9R!#86YC
M96QL871I;VXB"FUS9W-T<B`BP>K]\?GSYR#3]>W<[?3G\^?R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#,*;7-G
M:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`BT.OG\>_V[_'?Y?(@
MT_7MW.WTY_/G\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3`Y"FUS9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S
M='(@(M#Q_/3A\^<@X^GA(-/U[=SM].?SYR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(U"FUS9VED(")-965T:6YG
M(%)E<&QY(@IM<V=S='(@(L'PW.WTY_/G(./IX2#3]>W<[?3G\^<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q-`IM
M<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T<B`BQ>WG[-WQ^?/G(./IX2#3
M]>W<[?3G\^<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4Q.0IM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*
M;7-G<W1R("+!W_3G[.$@Y>WG[-WQ^?/G\B#CZ>$@T_7MW.WTY_/G(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ.0IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R("+,W>OG(@H*;7-G:60@(DUE;6]S(@IM<V=S='(@(M/G
M[.7I_O/EZ?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8R"FUS9VED
M(")-96YU(&UO9&4Z(@IM<V=S='(@(LKA]-SS].'SYR#,Y>WO_3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("+3]>/W_NWE]?/G(.KEZ^G^
M[2(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S(*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
MS-[M]>SA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,C8*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"B+4[R#LWNWU[.$@Y?#IXN7BX>G^Z.?JY2#E
M\.GT]??^\BP@X>OKW"#T[R#PZ?/T[_#OZ>?TZ>K\(/3O]2#U\._C\=SV[^WT
MX2#DY2`B"B+L\._QY=\@[>$@Y?#IXN7BX>GYZ.7?+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q.0IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("+4[R#LWNWU[.$@W>OG[N4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.3$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C,S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(V.`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(M3]
M\._R(.SG[?WLX?3O\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("+*X>GQ_/(@X?#\($UE=&%R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,`IM<V=I9"`B(@HB
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C<P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("+,W>CO
MY._R(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,B!F<F%M
M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*;7-G:60@(DUE=&AO9"`G)7,G
M(&ES(&YO="!D969I;F5D(@IM<V=S='(@(L<@S-WH[^3O\B`G)7,G(.3E[2#O
M\=_SZ.?JY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU.2!L
M:6(O0FQO8VLO;65T87(N<&AP.C<S"FUS9VED(")-971R:6,B"FUS9W-T<B`B
MS.7T\>GJ_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(LSE\^'?[R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C0Q"FUS
M9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B36EM92!4>7!E(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#@*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R("+,Z>KQ_/3E\><@Z.7Q[._J\>'SW^$@].7KY?7TX=_Y
M[2`R-"#Y\?[M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,`IM<V=I
M9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`BS.GJ\?STY?'G
M(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@-B#Y\?[M.B`B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$W"FUS9VED(")-:7)R
M;W(B"FUS9W-T<B`BRN'H\=WP].?R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(L3IW/;O\>$B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#D*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#4*;7-G:60@(B(*
M(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"B++Y=_PY>D@].\@8V]N9FEG=7)A=&EO;BX@T/'=\.7I
M(.WA(/3O(.3G[.GO]?'CWO/E].4@X>T@Z-WKY?3E(.WA(/?QY_/I+2(*(NSO
M\._IWO/E].4@X?7TWB#TY^T@Y?;A\>SOX]XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(LOEW_#EZ2#T[R!)1"#T[_4@[.?M
M_>SA]._R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C4W"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+B(*;7-G<W1R(")-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$
M+B(*;7-G<W1R("++Y=_PY>D@].\@240@].?R(//][>3E\^?R+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@
M(DUO(@IM<V=S='(@(L3E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$R,@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B16UA:6P@RNGMY_3>
M\B#4Y^OE]OGMW^'R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V,`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`BS-WT\>GO\B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-CD@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E
M(@IM<V=S='(@(L?LY?'O[.?MW^$@]/'O\._P[]_G\^?R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")-;V1I9GD@55),(@IM<V=S='(@(M3Q[_#O\._?Y_/G(%523"(*"FUS
M9VED(")-;VYT:"!6:65W(@IM<V=S='(@(L7L]MSMZ?/G(,S>[>$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@V"FUS9VED(")-;VYT:"!A;F0@
M>65A<B(*;7-G<W1R("+,WNWA\B#JX>D@W?3O\B(*"FUS9VED(")-;VYT:&QY
M($5V96YT<R!,:7-T(@IM<V=S='(@(LSG[>GAW^$@R]_S].$@P^7C[^W\]/GM
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HS
M-@IM<V=I9"`B36]N=&AL>2(*;7-G<W1R("+,Y^WIX=_A(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R("+6W//EZ?(@T^7KWNWG\B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0R,`IM<V=I9"`B36]V92!$
M;W=N(@IM<V=S='(@(LK?[>?SYR#JW/3Y(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-#(T"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`BRM_MY_/G(.'QZ?/TY?'<(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#(X"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(LK?
M[>?SYR#DY>[IW"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C0Q-@IM<V=I9"`B36]V92!5<"(*;7-G<W1R("+*W^WG\^<@\-SM^2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.3<*
M;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+*W^WG\^<@ZMST^2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.38*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-PIM<V=I9"`B
M36]V92!U<"(*;7-G<W1R("+*W^WG\^<@\-SM^2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q-C<*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<R(*;7-G<W1R("+0[^OKX?#KW?(@Z]_S].7R(.7PZ>OOX][R("CJ
MX?3A\?'<ZO3E\BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(U
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BT._KZ^'PZ]X@
MY?#IZ^_CWB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S0@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I9"`B37D@06-C;W5N="(*
M;7-G<W1R("+/(,OOX^'QZ>'S[/SR(.SO]2(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("+/(.GS
M]/ST[_#\\B#L[_4@*'!O<G1A;"DB"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z,3(T"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(L<@
MY>SVW.WI\^<@]._U(.GS]/ST[_#O_2#L[_4@*'!O<G1A;"DB"@IM<V=I9"`B
M37D@4W5M;6%R>2(*;7-G<W1R("+'(-#E\=_KY_CG(.SO]3HB"@IM<V=I9"`B
M37ET:6QI;FD@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#,]?3GZ][M
MY_(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O
M;2YI;F,Z-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(L_7
MR2P@Q,4@\_7L]OGM_B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C,Y-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C0Q
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3@S"FUS9VED(").86UE(@IM<V=S='(@(KSM[^SA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#8*;7-G:60@(DYE
M961S($%C=&EO;B(*;7-G<W1R("+!\.'I].7?].'I(.7MW?'CY>GA(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,@IM<V=I9"`B3F5T=V]R:R(*
M;7-G<W1R("+$W^KT]>\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q.0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(").979E<B(*;7-G<W1R("+0[_3=
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,C<*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("+-W>$@RN'TY^/O
M\=_A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N
M+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Y"FUS9VED(").97<@36]O
M;B(*;7-G<W1R("+-W>$@T^7KWNWG(@H*;7-G:60@(DYE=R!087-S=V]R9"(*
M;7-G<W1R("+-W>_R(,KYY.GJ_/(B"@IM<V=I9"`B3F5W(%!A<W-W;W)D("AA
M9V%I;BDB"FUS9W-T<B`BS=WO\B#*^>3IZOSR("CNX>W<*2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(LW=[R#\[>_LX2#7\=[S].<@*/#Q
M[^'I\>7TZ>K\*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T
M<B`BS=WO(/#A\=SH]?'O("CJY>W\*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(").97=S(@IM<V=S='(@(LW=X2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#8*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`BS^S<Y.7R(./IX2#MW>$@*&YE=W-G<F]U<',I(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-#8*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,S<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,S(*;7-G:60@(DYE
M>'0B"FUS9W-T<B`BQ?#\[.7M[R(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z,3$U(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3$V"FUS9VED
M(").97AT(%!A9V4B"FUS9W-T<B`BQ?#\[.7MYR#3Y>O?Y.$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@4&AA<V4B"FUS9W-T<B`B
MQ?#\[.7MYR#6W//G(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-C8@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S`*;7-G:60@
M(DYE>'0@;W!T:6]N<R(*;7-G<W1R("+%\/SLY>WE\B#%\.GK[^/=\B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.#@*;7-G
M:60@(DYO(@IM<V=S='(@(L_WZ2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]D:69F+FAT;6PZ,38*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T
M:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(L3E
M[2#U\-SQ]^7I(.3IX>C=\^GL[R!C;VYF:6=U<F%T:6]N(./IX2#MX2#DY=_N
M^2#DZ>'V[_'=\BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.C$Q,0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`BQ.7M(/7PW/'WY>D@Y.GA
MZ-WSZ>SG(//T\>'TY^/IZMX@X^GA(.3G[.GO]?'CW^$@25-/(&EM86=E<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,C(*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("+$Y>T@
M]?#<\??EZ2#P\?ST]?#O(./IX2!"871C:"XB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HW."!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HR,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,C0V"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;B(*;7-G<W1R("+$Y>T@]?#<\??EZ2!";&]C:R#S].?M
M(.'I]._][.7MYR#HW?/G(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HU-`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BQ.4@Y/SHY^KE(/SM[^SA
M(./IX2#A]>CE[?3IZN_P[]_G\^<@34-!3"XB"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HU-0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("+$Y>T@]?#<
M\??O]>T@X>OKX>/=\BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T-`IM<V=I9"`B3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E
M(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN(@IM<V=S='(@(L3E(.SP[_'O_>T@
M[>$@\/'O\_3EZ._][2#E[N_U\^GOY._TWO/EZ?(@ZMST^2#A\"<@X?7T_"#T
M[R#E\-_PY>3O+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,0IM
M<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`BQ.7M(.SP[_'O_>T@[>$@\/'O\_3EZ._][2#U\._J
MX?3GX^_QW^7R(//E(.'U]-X@].?M(.7N[_7SZ>_D_/3G\^<N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S,@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HT.3,*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S4S"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(L3E[2#O\=_SZ.?JX>T@\.OG\>_V[_'?Y?(@\?7H
M[-_SY?GM(./IX2`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<W,PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N(@IM<V=S='(@(L3E[2#O\=_SZ.?JX>T@\.OG
M\>_V[_'?Y?(@\?7H[-_SY?GM(./IX2!&5%`@5D93+B(*"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@3$1!4"!0
M<F5F97)E;F-E<RXB"FUS9W-T<B`BQ.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#P
MZ^?Q[_;O\=_E\B#CZ>$@].?M(/7PY_'E\]_A(,KA].'K_./O]2XB"@IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!#871E9V]R:65S+B(*;7-G<W1R("+$Y>T@W??O]>T@\?7H[.GS].7?
M(._I(/#KY_'O]N_QW^7R(./IX2#TZ?(@ZN'TY^/O\=_E\B#TY_(@4U%,+B(*
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%!R969E<F5N8V5S+B(*;7-G<W1R("+$Y>T@W??O]>T@\?7H
M[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2#TZ?(@\/'O].GLWO/EZ?(@].?R
M(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C4Y-0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(L3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG
M\>_V[_'?Y?(@X^GA(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<T.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B
MQ.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@4U%,+49I
M;&4@5D93+B(*"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+$
MY>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2#TY^T@X?7H
MY>WTZ>KO\._?Y_/G(//TY^T@4U%,+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R,PIM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(L3E[2#=[.7I[>4@\-_S]/GSYRXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U.0IM<V=I
M9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(L3E(.3^\^'T
MY2#P\>_O\>GS[/PN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#DR"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(L3E(/;O
M\?3^Z.?JX>T@X?'WY=_A(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q
M"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`BQ.4@XO'=Z.?JX>T@
MY>GJ[^W?Y.GA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,#(@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(Q"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(L3E[2#O\=_SZ.?JY2#T[_#OZ.7SW^$N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-3@*;7-G:60@(DYO(&UE<W-A
M9V4@<W5P<&QI960N(@IM<V=S='(@(L3E(.3^\^'TY2#LWNWU[.$N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C$*
M;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("+$Y>T@[_'?\^CG
MZN4@_.WO[.$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-C(*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM
M<V=S='(@(L3E[2#O\=_SZ.?JY2#A\>GH[/SR+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(L3E[2#U\-SQ]^_U[2#D]?/<\>7S].7R(/#Q[^+KW?CEZ?(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ.0IM<V=I9"`B
M3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("+$Y>T@Y>KJ\>7L[_WM(.7?
M\^_D[^DN(@H*;7-G:60@(DYO('!R969E<F5N8V5S(&%R92!A=F%I;&%B;&4N
M(@IM<V=S='(@(L_I(/#Q[_3I[-[SY>GR(.3E[2#EW^WAZ2#DZ>'HW?/I[.7R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(L3E[2#U\-SQ]^_U
M[2#JX>W\[>7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`BQ.7M
M(/7PW/'W[_7M(/#KY?7QW?(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$R"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(L3E[2#U\-SQ]^7I(/#Q[_/Y\>GM
M_/(@]_[Q[_(@X^GA(.SMWNSG(&-A8VAE+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C4V"FUS9VED(").;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BQ.7M(.3\Z.?J
MY2#\[>_LX2#W\=[S].<@WB_JX>D@ZOGDZ>K\\BXB"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C$T,0IM<V=I9"`B3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960B"FUS9W-T<B`BQ.7M(.7PZ?/T\=SVY^KA[2#=X^/U\>$@
M6$U,(.3EY._LW>WA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@Y-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY,3<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDS-`IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(L3E[2#U\-SQ
M]^_U[2#TZ>S=\B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3`*;7-G
M:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+$Y2#B\=WH
MY^KE(-WJY._SYR#S].\@X?'WZ>K\(&-O;F9I9W5R871I;VXN(,[A[>'DY^SI
M[_7QX][S].4@].\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ.4@XO'=Z.?J
MY2#=ZN3O\^<@\_3O(.'Q]^GJ_"#SX?(@8V]N9FEG=7)A=&EO;BX@SN'MX>3G
M[.GO]?'CWO/TY2#T[RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8P-`IM<V=I9"`B3F]N(%!A<G1I8VEP86YT(@IM
M<V=S='(@(LKA[=WMX?(@T_7L[.7TW??Y[2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.#@*;7-G:60@(DYO;F4B"FUS9W-T<B`B
MRN'L[-_A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("+*
MX>W=[>$@*-?QWO/G(/#Q[^KAZ._QZ?/LW>WO]2DB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T
M:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(L+\\>7I[R#'[.GS]N'?\>GO(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*;7-G:60@
M(DYO="!!9G1E<B(*;7-G<W1R("*\]^D@S.7TW"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"FUS9VED(").;W0@0F5F;W)E(@IM
M<V=S='(@(KSWZ2#0\>GM(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S4W"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`BQ.7M(.7?
M[>'I(.KA]-SK[^/O\B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z-C<*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.34*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.0HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C8P"FUS9VED
M(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(L3E[2#=]^7I(._K[^KKY_'Y
MZ.7?+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`BQ.7M(-WWZ>4@].7HY=\B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3@T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR,#,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(R,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-34@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(W,0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C@Y(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,C4*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,X."!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-#<R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-#0@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4V,@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`BQ.7M(/7P[_/TY_'?YN7TY2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0W(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-3D*;7-G:60@(DYO=&5S(@IM<V=S='(@(M/G[.7I_O/EZ?(B"@IM<V=I
M9"`B3F]T97,Z(@IM<V=S='(@(M/G[.7I_O/EZ?(Z(@H*;7-G:60@(DYO=&5S
M(%-U;6UA<GDB"FUS9W-T<B`BT^?LY>G^\^7I\B`M(-#E\=_KY_CG(@H*;7-G
M:60@(B(*(DYO=&5S(&ES(&%N(&%P<&QI8V%T:6]N('=H:6-H(&%L;&]W<R!Y
M;W4@=&\@8W)E871E('1H92!C;VUP=71E<B!E<75I=F%L96YT("(*(F]F('-T
M:6-K>2!N;W1E<RX@3F]T97,@8V%N(&)E(&-R96%T960L(&UO9&EF:65D+"!D
M96QE=&5D+"!A;F0@<')I;G1E9"X@66]U("(*(F-A;B!A;'-O('-E87)C:"!O
M;B!Y;W5R(&YO=&5S('1O(&QO8V%T92!I;F9O<FUA=&EO;BX@4W5P<&]R="!F
M;W(@:6UP;W)T:6YG("(*(F%N9"!E>'!O<G1I;F<@;F]T97,@:7,@86QS;R!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*(L_I(//G[.7I_O/EZ?(@Y=_MX>D@[.GA
M(.7VX?'L[^/>(/#O]2#SX?(@Y?#I]/'=\.7I(.WA(.3G[.GO]?'CWO/E].4@
M].\@(@HBX>WTW_/T[^GW[R#T^>T@ZM_T\>GM^>T@[.GJ\?[M(/?A\?3I_NT@
M\_3O[2#U\._K[^/I\_3>+B#,\._QY=_TY2#MX2`B"B+DY^SI[_7QX][SY?3E
M+"#MX2#T\>_P[_#OZ=[SY?3E+"#MX2#DZ>'C\=SXY?3E(.KAZ2#MX2#T]?#^
M\^7TY2X@S/#O\>7?].4@(@HBY?#?\^?R(.WA(/C<[N7TY2#S].GR(//G[.7?
M^?/EZ?(@\^'R(./IX2#MX2#E[?3O\-_SY?3E(.SIX2#PZ^?Q[_;O\=_A+B`B
M"B+5\._S].?QW^;E].'I(.KAZ2#EZ?/AX_GCWB`M(.7NX>/YX]X@]/GM(//G
M[.7I_O/E^>TN(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V
M"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B
MU-_P[_3A(./IX2#E[/;<[>GSYRP@Y?#I\_3Q[_;>+B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*;7-G:60@(DYO=&EC
M92(*;7-G<W1R("+![>'J[^GM_O/EZ?(B"@HC+"!C+69O<FUA=`IM<V=I9"`B
M3F]T:69I8V%T:6]N(&QI<W1E;F5R("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B
MU.\@\/'\X_'A[.SA(/#O]2#DZ>'WY>GQW^;E].'I(/3I\B#EZ>3O\._IWO/E
MZ?(@)7,@Y.7M(.+QW>CGZN4N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(LWO
MW>SB\>GO\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#`*;7-G
M:60@(DYU;6)E<B(*;7-G<W1R("+!\>GH[/SR(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R,0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B
M"FUS9W-T<B`BP?'IZ.S\\B#WX?'AZO3>\?GM(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O
M9B!C;VQU;6YS(@IM<V=S='(@(L'QZ>CL_/(@\_3GZ_[M(@H*;7-G:60@(DYU
M;6)E<B!O9B!C;VQU;6YS(&EN('1H92!S=6UM87)Y('9I97<Z(@IM<V=S='(@
M(L'QZ>CL_/(@\_3GZ_[M(//TY^T@Y>SVW.WI\^<@].?R(/#E\=_KY_CG\CHB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30S.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`BP?'IZ.S\\B#C\>'L
M[/[M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-CD*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(L3E[2#O\=_S
MZ.?JY2#A\>GH[/SR(./IX2#E[>?LW?'Y\^<@]/GM(.OI\_3^[2#DZ>'M[^S>
M\BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#$T"FUS9VED(")/8FIE8W0B"FUS9W-T<B`BP>WTZ>KEW^SE[>\B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-PIM<V=I9"`B3V)J96-T($-R
M96%T;W(B"FUS9W-T<B`BQ.?LZ>_U\>/\\B#![?3IZN7I[-WM[_4B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,C,*;7-G:60@(D]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS
M(@IM<V=S='(@(L7N[_7SZ>_D[_3>\^7I\B#$Y^SI[_7QX^_](,'M].GJY>GL
MW>WO]2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.3@*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(L_J].'DZ>K\\B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S
M='(@(L_J]/[B\>GO\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`BUM_K]/'O(/#Q[_/B[^O^
M[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#0*;7-G:60@(D]F
M9FEC92(*;7-G<W1R("+#\>'VY=_O(@H*;7-G:60@(D]L9"!087-S=V]R9"(*
M;7-G<W1R("+0X>OI_/(@ROGDZ>K\\B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<V"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("+,_.WO($E-05`M
M4V5R=F5R<R#U\._S].?QW^;O]>T@ZN_U[?SW\>?S]._U\B#VX>K=Z^OO]?(N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("+,_.WO(.3U\]SQY?/TY?(@\/'O
MXNO=^.7I\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,S0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU-`IM<V=I9"`B3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("+,_.WO(.SIX2!%;6%I;"#D
MZ>7]Z/7M\^<@Y?#I]/'=\.7TX>DN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B
M"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B+,_.WO(.\@
MZ>3I[^KTWO3G\B#>(.\@Y.GA]^7I\>GS]-[R(//U\_3>[.'T[_(@[/#O\>7?
M(.WA(.'KZ]SNY>D@].?M("(*(NGDZ>_J].?SW^$@WB#TZ?(@Y>[O]?/I[^3O
M]-[SY>GR(/3O]2#IY.GOZO3>].<@X^GA(.KOZ>W>(/?QWO/G+B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("+![>_IX^SA(//E(.W=[R#PX?'<Z/7Q[R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C4W"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N4U-,+<O<Z._R.B#$Y>T@
M[/#O\?X@[>$@XN/<Z_D@Y.7D[^S=[>$@X?#\(%,O34E-12#U\._CY>/QX>SL
MW>WO(.S=\>_R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("+![>_IX^SA(.'U]-[R(/3G\B#S_>WD
MY?/G\B#SY2#MW>\@\.'QW.CU\>\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`BR^7I]._U
M\>/IZOP@T_WS].?LX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C`P"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N
M="(*;7-G<W1R("+0\>_E\>'I].GJ_/(@T_7L[.7TW??Y[2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS
M9W-T<B`BQ?#IZ^_CW?(B"@IM<V=I9"`B3W!T:6]N<R!F;W(B"FUS9W-T<B`B
MQ?#IZ^_CW?(@X^GA(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C(Y('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C0*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM
M<V=S='(@(L7PZ>OOX]WR(./IX2`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*
M;7-G<W1R("+4X>[I[>_LY^S=[><@R]_S].$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,0IM<V=I9"`B3W)G86YI<V%T:6]N(@IM
M<V=S='(@(L_QX^'MZ?/L_/(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,@IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G
M<W1R("+4[-[LX2#/\>/A[>GS[._](@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$R-PIM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("+/\>/<[?GS
MYR(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("+!]>CE[?3IZOP@\/'\
M]/7P[R#E]N'Q[._CWO(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PIM
M<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("+!]>CE
M[?3IZMP@\/'\]/7PX2#S92`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3(P('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B
M3W1H97(B"FUS9W-T<B`BP>OK[R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Y"FUS9VED(")/=&AE<B!);F9O<FUA
M=&EO;B(*;7-G<W1R("+!Z^OE\B#0Z^?Q[_;O\=_E\B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S<*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(L7N[_7SZ>_D[_3>\^7I\B#)Y.GOZO3>].<B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z.#,*;7-G:60@(E!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+'(,'UZ.7M].GJ
M[_#OW^?SYR!004T@Y.7M(.7?[>'I(.3IX>C=\^GLYRXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<Y"FUS9VED(")01U`@1&EG:71A
M;"!3:6=N871U<F4B"FUS9W-T<B`BV.?VZ>'JWB#5\._C\>'VWB!01U`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S(X"FUS9VED(")0
M1U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`BRO'U\/3OX_'A]N?LW>WA(.3E
MY._LW>WA(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S.#<*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(L3G[/SSZ>\@
MRNOEZ>3?(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S-C8*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T
M<B`BU?#OX^7C\>'L[-WMX2_*\?7P]._C\>'VY^S=[>$@4$=0(.3EY._LW>WA
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8S"FUS9VED(")02%`@0V]D92(*
M;7-G<W1R(")02%`@RO[DZ>KA\B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR
M,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4"#*W>OU]N_R(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(V"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!(
M4"#*W>OU]N_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("+#W>SI
M\^SA(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4U-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,#,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P,0HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<P('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S8*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,V-PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BROGDZ>K\\B(*"FUS
M9VED(")087-S=V]R9"!C:&%N9V5D(&9O<B!U<V5R("5S(&9R;VT@8VQI96YT
M("5S(@IM<V=S='(@(L\@ZOGDZ>K\\B#<Z^OA[N4@X^GA(/3O[2#W\=[S].<@
M)7,@X?#\(/3O(//TX>CL_"`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3,U-`IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM
M<V=S='(@(LO<Z._R(.KYY.GJ_/(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W)A9&EU<RYP:'`Z,34W"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@
M4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+!\.'I].7?].'I(.KY
MY.GJ_/(@X^GA(.'UZ.7M].GJ[_#OW^?SYR!2041)55,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-@IM<V=I9"`B4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VXB"FUS9W-T<B`BROGDZ>K\\B#LY2#E\.GBY>+AW_GSYR(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S
M<W=O<F0Z(@IM<V=S='(@(LKYY.GJ_/(Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BROGD
MZ>K\\CH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,3<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@
M(L\@ZOGDZ>K\\B#P\=WPY>D@[>$@].'I\>G<YN7I+B(*"FUS9VED(")087-T
M($5V96YT<R!,:7-T(@IM<V=S='(@(LO?\_3A(-#E\>'S[-WM^>T@X^7C[^W\
M]/GM(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R."!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A
M<W1E(@IM<V=S='(@(L7PZ>K\Z^OG\^<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L
M:7!B;V%R9"(*;7-G<W1R("+%\.GJ_.OKY_/G(.'P_"#T[R!C;&EP8F]A<F0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"FUS9VED(")0871H(@IM<V=S='(@(L3IX>3Q[^S>(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-"!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C0*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`BQ=_S[^3OZ2#P[_4@Y>KJ\>7L[_WM.B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(L'MZ/'Y
M\._I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`BT._S[_/T_"(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z-@IM<V=I
M9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(L7J
M]-WKY?/G(,OEZ?3O]?'CZ?[M(-/U[?3>\>?SY_(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(L7J]-WKY?/G(,OEZ?3O]?'C
MZ?[M(-/U[?3>\>?SY_(@ZN'TW"#TY^T@Y=_S[^3O.R(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HV,2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C0*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8W"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(L7N[_7SZ>_D_/3G\^<B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C8X"FUS9VED(")097)M:7-S:6]N("<E<R<@;F]T(&1E
M;&5T960N(@IM<V=S='(@(L7N[_7SZ>_D_/3G\^<@X^GA("<E<R<@Y.4@Y.GA
MX_'<]N?JY2XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,C0@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.CDS"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H
M<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C<T"FUS9VED(")097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+$Z>'WY=_QZ?/G(,7N[_7S
MZ>_D[_3>\^7Y[2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30Y(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34R"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N
M<R!F;W(B"FUS9W-T<B`BQ>[O]?/I[^3O]-[SY>GR(./IX2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I
M;VXB"FUS9W-T<B`BT/'O\_GPZ>K=\B#PZ^?Q[_;O\=_E\B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("+*X?3O
MZ>K?Y.GA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y.0IM<V=I9"`B4&AO;F4B"FUS9W-T<B`BU.?KW?;Y[>\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0W"FUS9VED(")0:&]T;W,B"FUS
M9W-T<B`BUOGT[^/QX?;?Y?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(L7I
MZN_M[_/T[^GWY=_A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS
M9VED(")0;&%T:71U9&5S(@IM<V=S='(@(LKOZ>WO]/7PW^7R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM
M<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(M#A
M\>'JX>O^(.K<[?3E(.KKZ>H@\^4@ZMSP[^GO(.KEZ]\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#@*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#HB"FUS9W-T<B`BT.'QX>KAZ_X@Y?#IXN7BX>G^\_3E(/ST
MZ2#HW>OE].4@[>$@Y.GAX_'<^.7TY2#A]?3\(/3O(//T[^GWY=_O.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("+0X?'AZN'K_B#E\.GBY>+A
MZ?[S].4@_/3I(.C=Z^7TY2#MX2#A\._S]>WDW?/E].4@X?7T_"#T[R#S]._I
M]^7?[RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-34U"FUS9VED
M(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("+0
MX?'AZN'K_B#D_O/TY2#LWNWA(.KAZ2#=]._R+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("+0
MX?'AZN'K_B#D_O/TY2#=[>$@_.WO[.$@X^GA(/3G(.W=X2#JX?3GX^_QW^$Z
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Y.`IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`BT.'QX>KA
MZ_X@Y/[S].4@[.GA(-WCZO7QYR!)4"#DZ>7]Z/7M\^<N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B(@HBT.'QX>KAZ_X@Y/[S].4@[.GA(-WCZO7QYR#G
M[.7Q[^SG[=_A+"#EZ]WN].4@]._M(.'QZ>CL_"#T^>T@Y^SE\?[M(/3O]2#L
MWNWA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,S,*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(M#A\>'JX>O^
M(.3^\_3E(-WCZO7QYR#^\>$N(@H*;7-G:60@(E!L96%S92!P<F]V:61E(&$@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(/3O(.W=[R#J
M^>3IZOP@\^'R(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+B(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#LZ>$@\.7QW^OG^.<@]._U
M(/#Q[^+KWNSA]._R+B(*"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('!A
M<W-W;W)D(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(/3O[2#J^>3IZOP@\^'R
M(@H*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64B"FUS9W-T
M<B`BT.'QX>KAZ_X@Y/[S].4@].\@O.WO[.$@U_'>\_3G(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ."!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9"(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#T[R#\[>_LX2#J
MX>D@]._M(.KYY.GJ_"#SX?(B"@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!W:71H($!D;VUA:6XB"FUS9W-T<B`BT_7L\.OG\?[S].4@
M].\@_.WO[.$@]_'>\_3G(.SE(/3O[2#T[^S=X2`H0&5R;6ES+GED="DB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z,3(*
M;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO
M=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES
M=&5M+B(*;7-G<W1R("(B"B+0X?'AZN'K_B#DZ>'BW//TY2#T[R#AZOSK[_7H
M[R#JY=_LY>_M+B#0\=WPY>D@[>$@\_7L]OGMY=_TY2#LY2#T[_7R(/SQ[_7R
M("(*(N/IX2#MX2#W\>?SZ>SO\._IWO/E].4@X?7T_"#T[R#S_?/TY^SA+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-30P"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF
M;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@
M(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@HBT.'QX>KAZ_X@Y.7?].4@].GR
M(.'J_.OO]>CE\B#PZ^?Q[_;O\=_E\B#JX>D@Y?#IZ]WN].4@[.GA(.7MW?'C
MY>GA(.'P_"#T[R`B"B+PX?'AZMST^2#LY>WO_2XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0S-0IM<V=I9"`B4&QE
M87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS
M9W-T<B`BT.'QX>KAZ_X@Y?#IZ]WN].4@[.GA(.7MW?'CY>GA(.'P_"#T[R#P
MX?'AZMST^2#LY>WO_2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,@IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#T[R#\
M[>_LX2#TY_(@[=WA\B#JX?3GX^_QW^'R.B(*"FUS9VED(")0;&5A<V4@=F5R
M:69Y('EO=7(@;F5W('!A<W-W;W)D(@IM<V=S='(@(M#A\>'JX>O^(.7PZ>+E
MXN'I_O/TY2#T[R#MW>\@ZOGDZ>K\(//A\B(*"FUS9VED(")0<F5C961E('EO
M=7(@<VEG;F%T=7)E('=I=&@@9&%S:&5S("@G+2T@)RD_(@IM<V=S='(@(LWA
M(/#Q[_3<\_/O[?3AZ2#D_>\@\.']Z^7R(/#QW^T@].?M(/7P[^/QX?;>(//A
M\B`H)RTM)RD[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E(@IM<V=S='(@(LC=\^<@X?7TWO(@].?R(.7IZOSMX?(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM
M<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("+4[_#O
MZ.7T_NWTX?(@X?7T_"#T[^T@\-_MX>KA(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(E!O<W0@=&\@=&AI<R!F
M;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("+!\._S]._K
MWB#SY2#A]?3\(/3O(/;<ZN7K[R`HY.7M(/7P[_/TY_'?YN7TX>D@X?#\(/3O
M($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C0@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-CD*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@(@IM<V=S='(@(LKA].'J\=[L[>GSYR#CZ>$@].GR(/3E
MZ^7U].'?Y?(@)7,@_O'A*.7R*3H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+VQD87`N<&AP.CDY"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z
M(,3E(.+QW>CGZN4@YR#A\.'I]._][.7MYR#E\-WJ].'SYR!,1$%0+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS-@IM<V=I9"`B
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B#$Y2#B\=WHY^KE(.<@
MX?#AZ?3O_>SE[><@Y?#=ZO3A\^<@\_7MY>3QW^'R+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.3@*;7-G:60@(E!R97-E;G1A=&EO;G,B"FUS
M9W-T<B`BT.'Q[_7SZ=SSY>GR(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C,*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(M#?Y?/G(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-3<*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E
M;#H@(@IM<V=S='(@(M#?Y?/G(//T[R#E\-_PY>3O(/3G\B#HW.OA\_/A\CH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-`IM<V=I9"`B
M4')E<W-U<F4Z("(*;7-G<W1R("+0W^7SYSH@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`BT/'OY?#I\^K\\.GSYR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM
M<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(M#Q[^7PZ?/J_/#I\^<@].?R(.7IZOSM[^'R(//E(.W=[R#PX?'<Z/7Q
M[R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-S$@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HW,@IM<V=I9"`B4')E=FEO=7,@4&%G92(*;7-G
M<W1R("+0\>_GX^_][.7MYR#3Y>O?Y.$B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("+0\>_GX^_]
M[.7MY?(@Q?#IZ^_CW?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M("+%ZO3]\/GSYR#EX^/QW/;O]2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0P.0IM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`BT/'O
M\_GPZ>K\(,KKY>GDWR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-S4*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`BT/'\XNOG[.$B"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,3(*;7-G:60@(E!R;V)L96T@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`BT.7QZ>/QX?;>(-#Q[^+KWNSA]._R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q-@IM<V=I9"`B4')O:F5C=',B
M"FUS9W-T<B`BN/'C[R`H<')O:F5C="DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-S$*;7-G
M:60@(E!R;VUP="!T97AT(@IM<V=S='(@(LKEW^SE[>\@\/'O]/'O\-[R(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`Y"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(L3G[/SSZ>\@RNOEZ>3?(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-CD*;7-G:60@(E!U8FQI8R!+
M97D@06QG;W)I=&AM(@IM<V=S='(@(L'KX_SQZ>CL[_(@Q.?L_//I[_4@RNOE
MZ>3I[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR,C,*
M;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(M3O(.;E_>/O\B#$Y^S\\^GO]2_0\>_S
M^?#IZN_](.KKY>GDZ>_](.3E(.3G[.GO]?'CWNCGZN4@Y?#I]/7W_O(N(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C<P"FUS9VED(")1=65R>2(*;7-G<W1R
M("+%\?[TY_/G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV.#<*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@
M(L3G[/SSZ>\@RNOEZ>3?(%)302`H)60@0FET*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-#<*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G
M<W1R("+%\.GK[^/?(.7M_/(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`BU/7WX=_A(-#Q_.+K
MY?CG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HW
M,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED
M(")2871I;R(*;7-G<W1R("++_./O\B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,CDU('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDW"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(P
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30S"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@V"FUS9VED(")296%D(@IM<V=S='(@(L'MW./M
M^?/G(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3`*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`BP>W<X^WY\^<@[.?M
M_>SA]._R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,@IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BQ=_S].4@XMWBX>GO\B#CZ>$@].<@
MY.GAX_'A]MX@)7,[(,'U]/P@Y.7M(.SP[_'EWR#MX2#E\.'MW>OHY>DN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"FUS9VED(")2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HBQ=_S].4@\]_C
M[_7Q[_(@X^GA(/3G(.3IX>/QX?;>(/3Y[2#DY>3O[-WM^>T@]._U(/?QWO/T
MYR`E<SL@P?7T_"#DY>T@[/#O\>7?("(*(NWA(.7PX>W=Z^CEZ2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED
M(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+%\.'MY>KTW>OE
M\^<@].?R(/3EZ^7U].'?X?(@Y?'CX?/?X?(@\^'R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z(@IM<V=S='(@(L'MX>W=^?/G(/3Y[2#D]>WA[.GJ_NT@\_3O
MZ??EW_GM(/3O]2#,Y>WO_3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S(U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("+![>'M
MW?GSYR#TY_(@Y>SVW.WI\^?R(/3O]2!0;W)T86PZ(@H*;7-G:60@(E)E9G)E
M<V@@4W5M;6%R>2!6:65W.B(*;7-G<W1R("+![>'MW?GSYR#TY_(@T/'OXN_K
MWO(@T.7QW^OG^.?R.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@X
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,C8*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E9V5X
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,PIM<V=I9"`B4F5L
M871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`BQ>SVW.WI\^<@T_?=\^7Y[2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(T"FUS9VED(")296UA<FMS(@IM
M<V=S='(@(M/W_.OIX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#4W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#<V"FUS9VED(")296UE;6)E<B!T:&4@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("+!\._L[>?L_.WE]?/G(/#K
MY_'O]N_QZ?[M(.3IX>CE\^GL_/3G].'R+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(L'P
M[^SAZO'U\^S=[>_I(,7N]?#G\>7TY_3=\B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(L'P[^SAZO'U\^S=[><@
MY.GE_>CU[?/G("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C0P"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,34*;7-G:60@(E)E;6]V92(*;7-G
M<W1R("+!]N'?\>7SYR(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(L'VX=_QY?/G(,SP
MZ_SJ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4S,@IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("+!]N'?\>7SYR#3
M]-[KY_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("+!]N'?
M\>7SYR#L[_'V[_#OW^?SY_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8U.`IM<V=I9"`B4F5M;W9E(&9R;VT@;7D@
M8V%L96YD87(B"FUS9W-T<B`BP?;AW_'E\^<@X?#\(/3O(.?LY?'OZ_SCZ?P@
M[._U(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S8*;7-G:60@
M(E)E;6]V92!P86ER(@IM<V=S='(@(L'VX=_QY?/G(.;E_>/O]?(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3DV"FUS9VED(")296UO=F4@<V%V960@
M<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@HBP?;AW_'E\^<@X?#OZ.?JY?7LW>WO]2!S8W)I<'0@X?#\(/3O
M[2#P\>_S^?'I[?P@ZN'TW.OOX^\@]._U(.7N]?#G\>7TY_3>+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("+!]N'?\>7SYR#T[_4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#D*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE
M;G0B"FUS9W-T<B`BP?;AW_'E\^<@X?7T[_T@]._U(.K\[.+O]2#A\/P@].\@
MW>/C\>'V[R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,38*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(L3IX>/QX?;>(/?QWO/T
MYR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-PIM<V=I
M9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(L3IX>/QX?;>(-?QWO/TYSH@
M)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C$Y-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C(X,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C,T.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`BT_3<
MZ^CGZN4@P?#<[?3G\^<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT-3D*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-C@*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S@*;7-G:60@(E)E<&QY('=I=&@@
M3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(L'PW.WTY_/G(.SE(,S'
M(/7P[_/TY_'IYOSLY>WO(.S>[?7LX2XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-@IM<V=I9"`B4F5P;'D@=VET
M:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(L'PW.WT
MY_/G(.SE(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R(./IX2#T[_7R(.7P
M_.SE[>_U\B#D_>\@[-[MY?(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-C4*;7-G:60@(E)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`BP?#<[?3G
M\^<@[.4@].GR(.;G]._][.7MY?(@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?T
MX?(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HQ.#D*;7-G:60@(E)E<&QY.B`E<R(*;7-G<W1R("+!\-SM].?SYSH@
M)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.0IM<V=I
M9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R
M;W)C;V1E.B`B"FUS9W-T<B`BU.\@X=_TY^SA(.3E(.SP[_'EWR#MX2#A\.'M
M].?HY=\N(,7PZ?/T\>7V_.SE[>_R(.KYY.GJ_/(@Z]SH[_7R.B`B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X,"!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4P,PIM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(M3O(.'PX>GT[_WL
MY>WO("<E<R<@Y.7M(.KAZ._QW_/HY^KE(//T[R`E<R!C;VYF:6=U<F%T:6]N
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C`Q(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-S<Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW-34*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P96-I
M9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BU.\@X?#AZ?3O
M_>SE[>\@)R5S)R#DY>T@ZN'H[_'?\^CGZN4@\_3O(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<V,0IM<V=I9"`B
M4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(M3O(.'PX>GT[_WLY>WO("<E<R<@Y.7M(.KAZ._QW_/HY^KE
M(//T[R!C;VYF:6=U<F%T:6]N+B(*"FUS9VED(")297%U:7)E9"`G8F%S961N
M)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=B87-E9&XG(.3E[2#=
M]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G
M\BXB"@IM<V=I9"`B4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I
M;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A
M\.'I]._][.7M[R`G8F%S961N)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@
M\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@
M)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=D871A
M8F%S92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B`B"B+A
M]>CE[?3IZN_P[]_G\^?R+B(*"FUS9VED(")297%U:7)E9"`G9&%T86)A<V4G
M(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G9&%T86)A<V4G(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2XB"@IM<V=I
M9"`B4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN('!R969E
M<F5N8V5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WL
MY>WO("=D871A8F%S92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?
M\^7I\B#T^>T@\/'O].GLWO/E^>TN(@H*;7-G:60@(E)E<75I<F5D("=H;W-T
M<W!E8R<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G:&]S='-P96,G
M(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@(@HBX?7HY>WT
MZ>KO\._?Y_/G\BXB"@IM<V=I9"`B4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@
M<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)VAO<W1S<&5C)R#DY>T@W??EZ2#JX>CO
M\>GS].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN(@H*;7-G:60@(E)E
M<75I<F5D("=H;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G
M:&]S='-P96,G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@
M]/GM(/#Q[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E9"`G<&%S<W=O<F0G
M(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W!A<W-W;W)D)R#DY>T@
MW??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR("(*(N'UZ.7M].GJ[_#O
MW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I
M9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(M3O(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M(-WWY>D@ZN'H[_'I\_3E
MWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U:7)E
M9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W!A<W-W
M;W)D)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P
M\>_TZ>S>\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S
M<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W!H<'1Y<&4G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BXB"@IM
M<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@8V%T
M96=O<FEE<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._]
M[.7M[R`G<&AP='EP92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?
M\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U:7)E9"`G<&AP='EP92<@
M;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G<&AP='EP92<@Y.7M(-WWY>D@
MZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN(@H*
M;7-G:60@(E)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!A=71H
M96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I
M]._][.7M[R`G=&%B;&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CL
MW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BXB"@IM<V=I9"`B4F5Q=6ER960@)W1A
M8FQE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`BU.\@X?#AZ?3O_>SE[>\@)W1A8FQE)R#DY>T@W??EZ2#J
MX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN(@H*;7-G:60@
M(E)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G
M=&%B;&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM
M(/#Q[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E9"`G=6ED)R!N;W0@<W!E
M8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(M3O(.'PX>GT[_WLY>WO("=U:60G(.3E[2#=]^7I(.KAZ._QZ?/T
MY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BXB"@IM<V=I9"`B
M4F5Q=6ER960@)W5I9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G=6ED
M)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_T
MZ>S>\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E
M8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(M3O(.'PX>GT[_WLY>WO("=U<V5R;F%M92<@Y.7M(-WWY>D@ZN'H
M[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B`B"B+A]>CE[?3IZN_P[]_G\^?R+B(*
M"FUS9VED(")297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@
M8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I
M]._][.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q
M]>CLW_/EZ?(@ZN'TY^/O\>G^[2XB"@IM<V=I9"`B4F5Q=6ER960@)W5S97)N
M86UE)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=U<V5R;F%M92<@Y.7M
M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E
M^>TN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(X
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("+!\.'I]._][.7M[R#0
MY>3?[R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-3DR"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R
M("+!\.'I]._][.7M[_(@T_7L[.7TW??Y[2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,34@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,0HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0T"FUS9VED(")297-E="(*;7-G<W1R("+%\.'MX?;O\=PB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S
M<W=O<F0B"FUS9W-T<B`BP>OKX>/>(,KYY.GJ[_TB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R("+!Z^O<[O3E(/3O[2#*^>3IZOP@\^'R(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C8V(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-S,*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`BP?#O].7K
MW?/LX?3A(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T
M:6]N<R(*;7-G<W1R("+%\.GS]/'O]MX@\_3I\B#%\.GK[^/=\B(*"FUS9VED
M(")2971U<FX@=&\@;6%I;"(*;7-G<W1R("+%\.GS]/'O]MX@\_3G[2#AZ^OG
MZ^_C\>'VW^$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(L7PX>W=[?GSYR(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I
M9W5R871I;VXB"FUS9W-T<B`BQ?#A[>'V[_'<($-O;F9I9W5R871I;VXB"@IM
M<V=I9"`B4FAO9&5S($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@T?SD
M[_4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,P"FUS9VED(")2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`BQ?#IZ^_CW?(@Y?#E[N7Q
MX^'S]-X@Y>SPZ^_U].GS[-WM[_4@ZN7I[-WM[_4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`BP>GMW^/L
MX?3A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("+$Y>[IW"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#4*;7-G:60@(E)I9VAT(&AE861E
M<B(*;7-G<W1R("+$Y>[IW"#E\.GJY?;AZ]_DX2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,#$*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R
M("+$Y>[IW?(@].GLW?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("+)Y.G\].?TY?(@X_'A[.S>\BXN+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*;7-G:60@
M(E)O;&4B"FUS9W-T<B`BT?SK[_(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C`X"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S
M='(@(M#E\>GS]/'O]MX@,3@PL"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,#4*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(M#E\>GS]/'O]MX@P?'I\_3E\=PB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$Q"FUS9VED(")2;W1A=&4@4FEG:'0B
M"FUS9W-T<B`BT.7QZ?/T\>_VWB#$Y>[IW"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0
M<F]P97)T:65S(@IM<V=S='(@(LGDZ?STY_3E\B##\>'L[-[R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM
M<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`BR>3I_/3G].7R(,/QX>SL
MWO(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`BP_'A[.S=\CHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS
M9VED(")2=6QE<R(*;7-G<W1R("+*X>W\[>7R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*
M;7-G<W1R("+/Z2#JX>W\[>7R(.CA(.7L]N'MW^;O[?3AZ2#LY?3A[OT@_.OY
M[2#T^>T@X_'A[.S^[2#JX>D@]/GM(//TY^O^[2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@
M(L_I(.KA[?SMY?(@Z.$@Y>SVX>W?YN_M].'I(.SE].'N_2#T^>T@\_3GZ_[M
M(.S\[>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R("+/Z2#JX>W\[>7R(.CA(.7L]N'MW^;O[?3A
MZ2#LY?3A[OT@]/GM(./QX>SL_NT@[/SM[R(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,CD*;7-G:60@(E)U;B(*;7-G<W1R("+%ZO3=Z^7SYR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S`P"FUS9VED(")3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`BU?#OX_'A]MX@
MRO'U\/3OX_'<]N?SY_(@4R]-24U%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS-#$*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S
M<V%G92(*;7-G<W1R("+*\?7P]._C\>'VY^S=[>\@[-[M]>SA(%,O34E-12(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#8*;7-G:60@(E-!
M4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
MQR#A]>CE[?3IZN_P[]_G\^<@4T%33"#DY>T@Y=_MX>D@Y.GAZ-WSZ>SG+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#$*;7-G:60@(E--4R!-
M97-S86=I;F<B"FUS9W-T<B`BS.?M_>SA].$@4TU3(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,(,K=
MZ_7V[_(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,X"FUS9VED(")354-#15-3(@IM<V=S
M='(@(L70R=35U]G3(@H*(SH@;&EB+V%P:2YP:'`Z,3,P"FUS9VED(")37U%,
M(%-H96QL(@IM<V=S='(@(E-?44P@RMWK]?;O\B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S
M='(@(M/A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(KKD
MZ>\@\.OAW_/I[R`H7W-E;&8I(@H*;7-G:60@(E-A;6]S($%I<G!O<G0B"FUS
M9W-T<B`BP>7Q[^OI[-WMX?(@T]SL[_4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3(P"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS
M9W-T<B`BT-SQ[_?O\B#$[_'U]OSQ[_4B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`BP?#OZ-[JY?7S
MYR(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C(R"FUS9VED(")3
M879E("5S(@IM<V=S='(@(L'P[^C>ZN7U\^<@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C0Y"FUS9VED(")3879E("<E<R<B"FUS
M9W-T<B`BP?#OZ-[JY?7SYR`G)7,G(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(L'P[^C>ZN7U
M\^<@Q?#IZ^_C_NTB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38Q"FUS
M9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*(L'P[^C>ZN7U\^<@]._U(&-O;F9I9W5R871I;VX@
M\._U(.3G[.GO]?'CWNCGZN4@\^'M(%!(4"!38W)I<'0@\_3O[2#P\>_S^?'I
M[?P@(@HBZN'TW.OOX^\@]._U(.7N]?#G\>7TY_3>+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C8Y"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("+!\._HY^KE]>S=[>\@)7,@8V]N9FEG=7)A=&EO;BXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,`IM<V=I9"`B4V%V960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N(@IM<V=S='(@(M3O('-C
M<FEP="#E[>?LW?'Y\^?R(/3O('-E='5P(.'P[^CGZN7]Z.?JY2#S].\Z("<E
M<R<N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE
M;F-E(@IM<V=S='(@(L7PZ?/TWNSG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,34@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,3<*;7-G:60@(E-E87)C:"(*;7-G<W1R("+![>'FWO3G\^<B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")396%R8V@@16YG:6YE
M<R(*;7-G<W1R("+,Y_?A[=WR(,'MX>;>].?SY_(B"@IM<V=I9"`B4V5A<F-H
M($UA:6PB"FUS9W-T<B`BP>WAYM[TY_/G(,SG[?7LW/3Y[2(*"FUS9VED(")3
M96%R8V@@4F5S=6QT<R(*;7-G<W1R("+!\._TY>O=\^SA].$@P>WAYM[TY_/G
M\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-3<*;7-G:60@(E-E
M;&5C="!&:6QE<R(*;7-G<W1R("+%\.GK[^/>(,'Q]^7?^>TB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")3
M96QE8W0@82!D871E(@IM<V=S='(@(L7PZ>O=[O3E(.SIX2#G[.7Q[^SG[=_A
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,#0*;7-G:60@(E-E
M;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("+%\.GKW>[TY2#O[-SDX2#C
MZ>$@\/'O\^C>ZN<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0Y
M"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`BQ?#IZ]WN].4@
M[=WO(,GDZ>_J]-[TYR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(L7PZ>O=[O3E
M(.7N]?#G\>7TY_3>(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-C(*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(L7PZ>O=
M[O3E(/?QWO/TYR#CZ>$@\/'O\^C>ZN<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C4T"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RXB"FUS9W-T<B`BQ?#IZ^_CWB#\Z_GM(/3Y[2#G[.7Q[^SG[>G^[2XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$T"FUS
M9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(L7PZ>OOX]X@Y>W\\B#A
M[?3IZN7I[-WM[_4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G
M:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X=&%R96$N(@IM<V=S='(@(B(*(L7PZ>O=[O3E
M(/3O]?(@]^'QX>KTWO'E\B#P[_4@Z-WKY?3E(.'P_"#TZ?(@\.'QX>K<]/D@
MZ]_S].7R+B#*X?3\\.GM[/#O\>7?].4@(@HB[>$@].$@X>WTZ>/QW/CE].4@
MZN'I(.WA(/3A(.7PZ>KOZ^O>\^7TY2#S].\@[-[M]>SA(//A\BXB"@IM<V=I
M9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`BQ?#IZ^_C
MWB#T[_4@Y.GA]_GQZ?/TWB#G[.7Q[^SG[=_A\CHB"@IM<V=I9"`B4V5L96-T
M('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`BQ?#IZ^_CWB#TY_(@[._Q]M[R
M(/#O]2#HX2#=]^7I(.<@Y^SE\>_LY^W?X3HB"@IM<V=I9"`B4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(L7PZ>O=
M[O3E(/3G(/3A]?3\].?TX2#P[_4@Z-WKY?3E(.WA(.'KZ]SNY?3E.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE
M('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("+%\.GKW>[TY2#T[R#DZ>'W^?'I
M\_3>(/[QX?(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(L7PZ>O=[O3E
M(/3G(.SO\?;>(/#O]2#HX2#=]^7I(.<@_O'A.B(*"FUS9VED(")396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`BQ?#IZ]WN].4@Y/WO(/#E
MY-_A(/#O]2#TX>GQZ=SF[_7M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR.3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T
M<B`BQ?#IZ]WN].4@].\@]_'Y[.'TZ>K\("?S]][LX2<N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(S,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R("+%\.GKW>[TY2#TYR#CZ_[S\^$@\^'R
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C4S"FUS9VED(")396YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R
M("+!\._S]._KWB#T^>T@\.GO(/#Q_//VX?3Y[2#PZ^?Q[_;O\>G^[2(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(L'P[_/T[^O>(,'MX?;O\=SR(-#Q
M[^+KWNSA]._R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV-`IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`BP?#O\_3OZ]X@
M4TU3(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,30*;7-G:60@(E-E;G-O
M<CH@(@IM<V=S='(@(L'I\^CG]-[QX?(Z("(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`BT^7P]-WLXO'I[_(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<R-0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("+3
MY>GQZ>'J_/(@P?'IZ.S\\B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I
M<F5D+B(*;7-G<W1R("+4[R!)1"#TY_(@\_WMY.7SY_(@W>OG[N4N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y-0IM<V=I9"`B4V5T(@IM<V=S
M='(@(LC=\^4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@
M(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HBR-WS].4@
MY?#IZ^_CW?(@\._U(.CA(//A\B#E\.GT\=WP[_7M(.WA(.'KZ]SFY?3E(/3O
M[2#J^>3IZOP@\^'R+"#AZOSLYR#JX>D@(@HBX>T@]._M(-WWY?3E(.[E]]SS
MY>DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(M#A\>'LY?3Q[_#OW^?SYR#A\._L
MX>KQ]?/LW>WY[2#E[O7PY_'E].?T_NT@\._U(.C=Z^7TY2#P\?SSXN'SYRXB
M"@IM<V=I9"`B4V5T('EO=7(@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B+1]>CLW_/TY2#DZ=SV[_'E
M\B#E\.GK[^/=\B#E[/;<[>GSY_(@ZN'I(/3O(/?Q_.WO(.'MX>W=^?/G\B#T
M^>T@\^7KW^3Y[2XB"@IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&1I<W!L
M87D@;&%N9W5A9V4N(@IM<V=S='(@(L7PZ>OOX]X@].?R(/#Q[_3I[._][.7M
MY_(@X^O^\_/A\BXB"@IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("+*X>CO
M\=_S].4@].?M(/#Q[_3I[/[LY>WG(./K_O/SX2P@YO[MYR#^\>'R(.KAZ2#L
M[_'VWB#G[.7Q[^SG[=_A\BXB"@IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(LKA
MZ._QW_/TY2#TY^T@Y?;A\>SOX]X@Y>KJW^WG\^?R+"#TX2#P\>_TZ>S^[.7M
MX2#W\?[LX?3A+"#TYR#PY?'?[^3O("(*(N'MX>W=^?/G\B#TY_(@\^7KW^3A
M\B#JX>D@W.OKY?(@Y?#IZ^_CW?(@Y>SVW.WI\^?R+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S0*;7-G:60@(E-E='5P(@IM<V=S='(@(M']Z.SI
M\^<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS.`IM
M<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R
M("+%W^WAZ2#DZ>'HW?/I[.$@4V-R:7!T<R#E[>?LW?'Y\^?R(/'UZ.S?\^7Y
M[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S4*;7-G:60@
M(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E
M<CH@(@IM<V=S='(@(M#OZ^O=\B#T[_#OZ.7SW^7R(.7?[>'I(/#IZ.'MW?(@
M[.4@X?7TWB#TYR#PX?'<[.7T\>\Z("(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S,*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(L'C[_'=\B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3
M:&]R="!3=6UM87)Y(@IM<V=S='(@(M/][?3O[.<@T.7QW^OG^.<B"@IM<V=I
M9"`B4VAO<G0@4W5M;6%R>3HB"FUS9W-T<B`BT_WM]._LYR#0Y?'?Z^?XYSHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,P"FUS9VED(")3:&]U;&0@
M86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T
M<B`BT/'=\.7I(/3O(.KKY>GDWR#P\?SSXN'SY_(@[>$@[_'I\^CEWR#CZ>$@
M\.7QZ?/S_/3E\>7R(//U[>3=\^7I\CLB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(Y-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Y"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T,@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X-0IM<V=I9"`B4VAO=R(*;7-G<W1R("+%[/;<
M[>GSYR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#D*;7-G:60@(B(*
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HBQ>SVW.WI\^<@Y.GA]N_Q_NT@[.7TX>[](/3O]2#A\._HY^KE]>S=
M[>_U(.KAZ2#T[_4@Y.?LZ>_U\>/GZ-WM]._R("(*(F-O;F9I9W5R871I;VXN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0W-`IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("+%[/;<
M[>GSYR#TY_(@_O'A\B#TY>OE]?3AW^'R(.7I\_SD[_4@_/3A[2#L\.'?[>_U
M[.4@\_3O(//]\_3G[.$[(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<U,@IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G
M<W1R("+%[/;<[>GSYR#E\.GK[^/>\B#CZ>$@X?#OZ-[JY?7SYR#T[_4@X?7H
MY>WTZ>KO_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#$*;7-G
M:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(L7L]MSMZ?/G(//UZ^O=ZO3G(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P.0IM<V=I9"`B4VAO=R!T86)L
M92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("+-X2#E[/;A[=_FY?3A
MZ2#T[R#LY>WO_2#LY2#E\>/A\]_E\B#PW^WAZN$[(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S,PIM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\B"FUS9W-T<B`BQ>SVW.WI\^<@]._U("5S(,SE[>_](//TX2#A
M\>GS].7QW#LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>SVW.WI\^<@]._U(.3IX>O\
MX^_U(,GDZ>_TWO3Y[2#*Y>OI_NT@T-_MX>KA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+%[/;<
M[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(-#?[>'JX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(L7L]MSMZ?/G(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@P_'A[.S^
M[2#0W^WAZN$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(L7L]MSMZ?/G(/3O]2#DZ>'K_./O]2#)
MY.GO]-[T^>T@Q>GJ_.WA\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-3`*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(L7L]MSMZ?/G(/;\
M\?3Y\^?R("AU<&QO860I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,SDQ"FUS9VED(")3:')I;FLB"FUS9W-T<B`BT_7Q\=_J[?GS
MYR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C8X-"!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-#8*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#`T(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C@V-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HY,#$@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z.3,X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDV-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.38*;7-G
M:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("+0\?[TX2#S]?'QW^KM^?/G(-X@
M[.7TX>K?[>?SYR#CY>GT[^WIZO[M(/3LY^S<]/GM(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W.`IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R("+%W_/OY._R+=7P[^/QX?;>(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHX.0IM<V=I9"`B4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*
M;7-G<W1R("+'(,7?\^_D[_(MU?#OX_'A]MX@Y.7M(-WWY>D@ZN'TX??Y\>?H
MY=\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,S8*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+5\._C\>'VWB(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S,U"FUS9VED(")3:6=N871U
M<F4@06QG;W)I=&AM(@IM<V=S='(@(L'KX_SQZ>CL[_(@U?#OX_'A]M[R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DP"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-PIM<V=I9"`B4VEZ92(*
M;7-G<W1R("+,W>/EZ._R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?8F]T=&]M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM
M<V=S='(@(L'J_?'Y\^<@T_7M]-[QY_/G\B(*"FUS9VED(")3;VUE(&]F($AO
M<F1E)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@;6ES<VEN9SHB"FUS9W-T
M<B`BS.7QZ>K<(.'P_"#TX2#A\??EW^$@Y.GA]^7?\>GSY_(@]._U($AO<F1E
M(-WW[_7M(/?AZ.7?.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,30*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(L7PZ>OO
MX]X@ZN'TY?WH]>WSY_(@].'NZ>W\[.?SY_(B"@IM<V=I9"`B4V]U9&$@06ER
M<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#3[_WDX?(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X,0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8Q,PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C4U"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+$Z>7]Z/7M\^<@
MT.?CWO(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO
M;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@
M(LW\].GO(,?LZ?/VX=_QZ>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(*;7-G<W1R("+$Z=SS].?LX2#LY?3A[OT@X^7I]._MZ>K^
M[2#JY>OI_NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;"(*;7-G<W1R("+$Z=SS].?LX2#LY?3A[OT@\.7QZ>7W
M[^S=[>_U(.KAZ2#C\>'L[-[R(.KEZ^G^[2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Q-`IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(M#KWNKT\>\@
MQ.GA\_3>[.'T[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`BP?'A
MW_GSYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T
M<B`BP?'AW_GSYR#JX>D@X]WLZ?/LX2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HY-0IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E
M<B!);G!U="(*;7-G<W1R("+%Z?/AX_GCWB#%Z>3IZO[M(-?A\>'J]-[Q^>TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(L3IX=_QY?/G(.KE
MZ^GO_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("+$Z>'?
M\>7SYR#S]-[KY_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B
MQ.GAW_'E\^<@X_'A[.S>\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(L'HZ][LX?3A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-#,*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-#@*;7-G
M:60@(E-T87)T(@IM<V=S='(@(KCMX?'NYR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-PIM
M<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("*X]._R(+CMX?'NY_(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B4W1A
M=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BT._KZ?3EW^$@WB#%\.'Q]]_A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M.#,*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G
M:60@(E-T871U<R(*;7-G<W1R("+*X?3<\_3A\^<B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`S"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G
M<W1R("+,[_'VWB#A\._HWNKE]?/G\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")3=')E970@061D<F5S<R(*;7-G
M<W1R("+$Z>7]Z/7M\^<MS^3\\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS
M9W-T<B`BQ.GAX_'A[.SI\^S=[>$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C(T"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("++W_/TX2#K
MW>[E^>TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4V"FUS9VED
M(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("+!]N'?
M\>7SYR#T[_4@9&]M86EN(.'P_"#TYR#DZ>7]Z/7M\^<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED
M(")3='EL92!;0U-372(*;7-G<W1R("+3]/WK(%M#4U-=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B
M"FUS9W-T<B`BRO4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*;7-G
M:60@(E-U8F1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`BSR#U
M\._VW.KEZ^_R("<E<R<@Y.4@XO'=Z.?JY2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<X"FUS9VED(")3=6)J96-T(@IM<V=S='(@
M(LC=[.$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V
M.`IM<V=I9"`B4W5B:F5C="!0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`BR-WL
MX2`GT.OG\>_V[_'?Y?(@Q.?L_//I[_4@RNOEZ>3I[_TG(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,Q,@IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(L'P[_/T[^O>
M(@H*(SH@<VEG;G5P+G!H<#HU,`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E
M<W0@=&\@861D("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G
M(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB
M"FUS9W-T<B`B(@HBU.\@X=_TY^SA(./IX2#P\>_SZ-[JYR`G)7,G(//T[R#S
M_?/TY^SA(.'PY?/TW.OG+B#$Y2#L\._QY=_TY2#MX2#NX>WA[/#EW_3E("(*
M(NS=]_'I(.WA(.7CZO'IZ.7?(/3O(.'?].?LW"#SX?(N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(M7P[^3EW^KTY_(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3$S"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`BQ?#I]/7WW^$B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`BQ?#I]/7WWO(@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX2XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@
M(M3A(.3EY._LW>WA(/3O]2#W\=[S].<@)R5S)R#DZ>'C\=SVY^KA[2#E\.GT
M]??^\B#A\/P@].\@\_WS].?LX2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@Q
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C$*;7-G:60@(E-U8V-E<W-F=6QL
M>2!D96QE=&5D("<E<R<N(@IM<V=S='(@(L7PZ?3U]][R(.3IX>/QX?;>("<E
M<R<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5M;W9E9"`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BQ?#I
M]/7WWO(@Y.GAX_'A]MX@)R5S)R#A\/P@].\@\_WS].?LX2XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*
M;7-G<W1R("(B"B+/Z2#Q]>CLW_/EZ?(@Y?#A[>'VW?'HY^KA[2#E\.GT]??^
M\BX@RMSM].4@Y?#A[>'V_/'T^?/G(./IX2#MX2#DY=_TY2#TZ?(@(@HBX>OK
MX>/=\BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-34*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ?#I]/7WWO(@Y?#OZ-[J
MY?7SYR#E]N7D\>GJ[_T@8V]N9FEG=7)A=&EO;BXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8R"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(L7PZ?3U
M]][R(.'P[^C>ZN7U\^<@]._U(.7VY>3QZ>KO_2#A\??EW^_U(&-O;F9I9W5R
M871I;VX@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"FUS9VED(")3=6-C
M97-S9G5L;'D@=7!D871E9"`G)7,G(@IM<V=S='(@(L7PZ?3U]][R(.7MY^S=
M\?GSYR`G)7,G(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S(*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T
M92`E<R(*;7-G<W1R("+%\.GT]??>\B#EX^/QX?;>("5S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-3@*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-C`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+3_>WO^.<@+2#0Y?'?Z^?XYR(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-@IM<V=I9"`B4W5N(%)I<V4B
M"FUS9W-T<B`BP>WA]._KWB(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW
M,0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("+$_?/G(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R
M("+![>'T[^O>(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R("+![>'T[^O>+\3]\^<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`BP>WA]._KWCH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.`IM<V=I9"`B
M4W5N<V5T(@IM<V=S='(@(L3]\^<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38W"FUS9VED(")3=6YS970Z("(*;7-G<W1R("+$_?/G.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S
M"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("+5\.7QY.7?ZO3E\B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C4*;7-G:60@(E-U<'!O<G0B
M"FUS9W-T<B`BU?#O\_3>\>GNYR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DX"FUS9VED(")3=7)N86UE(@IM<V=S='(@(L7PW^CE
M].\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B
M4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("+4[R#A\??EW^\@ZN'TX>/QX?;>
M\B#S]>/W\>_MZ?/L[_T@Y.GAX_'<]N?JY2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3@*;7-G:60@(E-Y
M;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`BR]SH[_(@\_WM
M].'NY_(@\_3O]?(@_/'O]?(@X>WAYM[TY_/G\B(*"B,Z(&9R86UE=V]R:R]5
M22]522]486)L92YP:'`Z,3,U"FUS9VED(")486)L92(*;7-G<W1R("+0W^WA
MZN'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("+)
MY.G\].?TY?(@T-_MX>KA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R("+)Y.G\].?TY?(@T-_MX>KA(@H*;7-G:60@(E1A;F%G<F$@
M06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#4X>W<X_'A\B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@
M(E1A<F=E=#HB"FUS9W-T<B`BT_3\]^_R.B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-C@*;7-G:60@(E1A<VMS(@IM<V=S='(@(L7QX^'SW^7R
M(@H*;7-G:60@(E1A=&]I($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@
MU.'T[_KO]2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DW"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(L'QZ>CL_/(@
MU.?KY?;^[>_U(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#@*;7-G:60@
M(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(LCE\>SOZO'A\]_A(/3G
M[2#TY>OE]?3AW^$@_O'A.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q
M,@IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`BR.7Q[._J\>'SW^$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<R"FUS9VED(")496UP
M97)A='5R93H@(@IM<V=S='(@(LCE\>SOZO'A\]_A.B`B"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C(Q,0IM<V=I9"`B5&5M<&QA=&4@
M)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(M3O(/#Q_/3U\.\@)R5S)R#DY2#B
M\=WHY^KE+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")4
M96UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+$Z>'WY=_QZ?/G(-#Q
M[_3]\._U(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV-#$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T
M(@IM<V=S='(@(M#Q[_/Y\>GMWB#!\._D[_?>(.'I]-[LX?3O\B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Y"FUS
M9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R("+0\>_S^?'I[=P@
MP?#OY.7J]/PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`R"FUS
M9VED(")497AT(@IM<V=S='(@(LKEW^SE[>\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`BS/SM[R#*
MY=_LY>WO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("+3]._?
M]^?SYR#JY>GLW>WO]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`BRN_Q]?;>
M(.KEZ>S=[>_U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`BU.4B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY-#0*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`BQ?7WX?'I\_3O_>SE(/#O]2#W\>?S
MZ>SO\._IWO/A].4@].\@T_WS].?LW"#LX?(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW-CD*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L<@Y?#=ZO3A\^<@1E10(.3E[2#E
MW^WAZ2#AZOSLYR#DZ>'HW?/I[.<N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C0*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`BU.\@
M\_WS].?LX2!(;W)D92]+;VQA8B#DY>T@]?#O\_3G\=_FY>D@7"(E<UPB(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(Y"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(L3IX??EW_'I\^<Z.B#'(.KKW//G(.3E(/;O\?3^Z.?JY2#E\.GT
M]??^\B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*
M;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+B(*;7-G<W1R("+4[R#PX?'<Z/7Q[R#E\.GK[^/^[2#=ZNOEZ?/E+B"X[N_D
M[_(N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ-C`@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HQ-S$*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HQ.#(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.30*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#4@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,S4@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-S0*;7-G:60@(B(*(E1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!0
M97)M:7-S:6]N<RXB"FUS9W-T<B`B(@HBSR#DZ>'WY>GQZ?/TWO(@\/'=\.7I
M(.WA(/'UZ.S?\^7I(-WMX2#L_.WI[.\@\.OAW_/I[R#%[N_U\^GOY._TWO/E
M^>TL(./IX2#MX2`B"B+L\._QY=_TY2#MX2#W\>?SZ>SO\._IWO/E].4@Y>[O
M]?/I[^3O]-[SY>GR+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O
M;FQY(@IM<V=S='(@(L<@ZMST^2#PZ^7U\=P@[/SM[R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#D*;7-G:60@(E1H
M92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`BU.$@Y.7D[^S=
M[>$@Y^SE\>_K[^/?[_4@Y.7M(.7?[>'I(-WCZO7QX2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8T"FUS9VED("(B
M"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N
M(@IM<V=S='(@(B(*(M3O($E$(/3G\B#E\.'VWO(@Y.7M(.KAZ._QW_/HY^KE
M+"#>].'M(.KE[?P@WB#DY2#B\=WHY^KE(//TYR#BW//G(.3EY._LW>WY[2XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-30*
M;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(L<@Y?#A]MX@\/'O\_3=Z.?J
MY2#E\.GT]??^\B#S].\@Q.GE]>CU[?/I[^/QW/;O(//A\BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<Q"FUS9VED("(B"B)4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+4[R#T[-[L
MX2!01U`@\._U(.'P[_/PW//HY^KE(.'PX>GTY=_T[R#CZ>$@].?M(.7PX>O>
MZ.7U\^<@]._U(/7P[^/EX_'A[.S=[>_U("(*(NSG[=[LX?3O\BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V-@IM
M<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@
M=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B+4[R!)1"#TY_(@Z]_S].'R(.3I
MX>WO[-[R(.3E[2#O\=_SZ.?JY2P@WO3A[2#JY>W\(-X@Y.4@XO'=Z.?JY2#S
M].<@XMSSYR`B"B+DY>3O[-WM^>TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C<*;7-G:60@(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`BQR#KW_/T
MX2#DZ>'M[^S>\B#DY>T@ZN'H[_'?\^CGZN4N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+G!H<#HQ,C<*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(L_I(.3U[>'T_/3G].7R(.KQ]?#T[^/QW/;G\^?R(.'PX>GT[_WM(.'S]N'K
MWB#S_>WDY?/G(%=%0BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C<X"FUS9VED(")4:&4@979E;G0@:&%S(&)E96X@
M861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS9W-T<B`BU.\@X^7C[^W\\B#P
M\>_S]-WHY^KE(//T[R#G[.7Q[^O\X^G\(//A\BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$X,2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4P-`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+B(*;7-G<W1R("+4[R#A\??EW^\@)7,@\/'=\.7I(.WA(/#E\>G=
M]^7I(.SIX2`E<R#Q_>CLZ?/G+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#DT"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+B(*;7-G<W1R("+4[R#A\??EW^\@)7,@\/'=\.7I(.WA(/#E\>G=]^7I(.K<
M\._IY?(@)7,@\?7H[-_SY>GR+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$V-0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@
M;VYT;R!I='-E;&8N(@IM<V=S='(@(M3O(.'Q]^7?[R#DY2#L\._QY=\@[>$@
MX>WTZ>/QX?;EWR#S]._M(.7A]?3\(/3O]2XB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR-C0*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R("+4[R#A\??EW^\@Y.7M(/#E\>G=]^7I(.3EY._LW>WA
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S(*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(M3A(/#A\>'J
MW/3Y(.7?[>'I(.7PZ>KE]N'KW^3E\B#CZ>$@X?7T_"#T[R#LWNWU[.$O<F9C
M.#(R(.S>[?7LX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T
M;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(L<@ZN'TW//TX?/G(/#KWO'O
M]?(@[^C\[>?R(.7?[>'I(./M^?/T_"#\].D@Y.?LZ>_U\>/EWR#P\?SBZ^?L
MX2#LY2#T[^T@(@HB26YT97)N970@17AP;&]R97(L(.7NX>GTW^'R(/#Q[^+K
MY^S<]/GM("AB=6=S*2#T[_4@8G)O=W-E<BP@].$@[_#OW^$@Y.7M("(*(N7?
MX>D@Y/7MX?3\(.WA(.[E\.7QX?/H[_WM+B#,\._QY=\@[>$@Y.7?].4@)_/J
M[_7PW^3IX2<@\_3G[2#OZ/SMYRP@(@HB\/'OXNO>[.'TX2#S].<@Z^7I]._U
M\>/?X2#T[_4@8G)O=W-E<B#>(.KAZ2#J_.OG[-P@]._U+B#![2#T[R#S_?/T
MY^S<(//A\B`B"B+EW^WAZ2!7:6YD;W<@.7@@Y=_MX>D@\._K_2#PZ>CA[?P@
M[>$@Y.7?].4@)\/E[>GJWB#!\._T]???X2#0\>_S].'SW^'R)R#JX>D@(@HB
M[>$@\/'=\.7I(.WA(.7PX>WEZNKI[=[SY?3E("AR96)O;W0I+EQ<;EQ<P?7T
MWB#EW^WAZ2#P\>_EZ>3O\._?Y_/G+B#0X?3>\_3E("(*(L_*(.'M(.C=Z^7T
MY2#AZOSLYR#MX2#D[_7KW?CE].4@\^4@ZN'TW//TX?/G(/#KWO'O]?(@[^C\
M[>?R+B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HX.`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+'(/3A
M]?3\].?TX2!<(B5S7"(@Y.GAX_'<]N?JY2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("+'(.'QZ?/TY?'>(/#KY?7Q
MW"#L_.WO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,V
M"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T
M<B`B(@HBQR#HW?/G(/3O]2#P\>_C\=SL[.'T[_(@1VYU4$<@\/'=\.7I(.WA
M(.3OZ.7?(./IX2#TYR!#<GEP=%]P9W`Z.B#JZ]SSYRXB"@IM<V=I9"`B5&AE
M(&UA:6QB;W@@=')A<V@@:7,@86QR96%D>2!E;7!T>2XB"FUS9W-T<B`BQR#C
M\>'L[.'T[^CU\=_DX2`GZMSD[_(G(.7?[>'I(-[DYR#<Y.7IX2XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C$T"FUS9VED("(B"B)4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@
M:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M(@IM<V=S='(@(B(*(M3O(.S>[?7LX2#P[_4@\_3<Z^CGZN4@\_3I\B`E<R#S
M]._M("5S(.SE(.C=[.$@)7,@Y>SVX>W?\^CGZN4N7&XB"B+!]?3\(.3E[2#A
M\._TY>OEWR#E\.GBY>+AW_GSYR#\].D@Y.GAXMSSZ.?JY2#JX>D@W>/I[>4@
MZN'TX>WOY_3\+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C`*
M;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O
M;7!O<V4@<&%G92(*;7-G<W1R("+4[R#\[>_LX2#P[_4@Z.$@]_'G\^GL[_#O
MZ>7?].'I(/STX>T@\_7MY-WE\_3E(//TYR#SY>O?Y.$@\_WMZ.7SY_(N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C4Y"FUS9VED
M(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("+'(.+IXNOI[^C>ZN<@
M3W!E;E-33"#A\.'I].7?].'I(./IX2!(;W)D95]#<GEP=%]S;6EM93HZ(.KK
MW//G+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDQ"FUS9VED
M("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL
M;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HBQR#P\>_TW^SG\^<@7"(E<UPB(.3E
M[2#L\/SQY?/E(.WA(.'P[^CGZN7UZ.7?(./IX?3?(/3A(.3EY._LW>WA(/3G
M\B`B"B+U\.7QXN'?[>_U[2#T[R#LW>/I\_3O(.7PZ?3QY?#T_"#LW>/EZ._R
M(@H*(R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS
M-2P@8RUF;W)M870*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B
M+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP
M="YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E
M<G!O:6YT+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<W=O<F0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P
M;2YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P
M+G!H<#HT,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H
M;&ET92YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E
M>&-E;"YP:'`Z,S4*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&UE<W-A9V4@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B(@HBU.\@\/'\X_'A[.SA(/#O]2#W\>?SZ>SO
M\._IY=_TY2#CZ>$@].?M(.7L]MSMZ?/G(.'U]._](/3O]2#EW^3O]?(@[.?M
M]>S<]/GM("(*(B@E<RD@Y.7M(.+QW>CGZN4@\_3O(//]\_3G[.$N(@H*;7-G
M:60@(B(*(E1H92!R96=I<W1R>2!I<R!H;W<@2&]R9&4@87!P;&EC871I;VYS
M(&9I;F0@;W5T(&AO=R!T;R!T86QK('1O(&5A8V@@;W1H97(N("(*(EEO=2!S
M:&]U;&0@;&ES="!A;GD@:6YS=&%L;&5D($AO<F1E(&%P<&QI8V%T:6]N<R!T
M:&%T('EO=2!H879E(&AE<F4N(@IM<V=S='(@(B(*(L<@<F5G:7-T<GD@Y=_M
MX>D@[R#T\?SP[_(@[.4@]._M(._P[]_O(._I(.7VX?'L[^/=\B#T[_4@2&]R
M9&4@Y?#IZN_I[?GM[_WM+B`B"B+LY?3A[OT@]._U\BX@Q>3^(/#QW?#EZ2#M
MX2#C\=SXY?3E(/STZ2#E]N'Q[._CW?(@]._U($AO<F1E(-WWY?3E("(*(N7C
MZN'TX?/TWO/EZ2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>2(*;7-G<W1R("+'(.'QZ?/TY?'>(.KAZ2#DY>[IW"#PZ^7U
M\=WR(.S\[>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`BQR#DY>[IW"#PZ^7U\=P@[/SM[R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C<X"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("+/(.7N]?#G\>7TY_3>\B!<
M(B5S7"(@Y.GAX_'<Y^KE+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C0Y"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`BSR#E[O7PY_'E]-[R(%PB)7-<(B#A\._HY^KE_>CGZN4N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(M3O(.'?
M].?LX2#EZ?/\Y._U(./IX2`E<R#DZ>'C\=SVY^KE+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(X-`IM<V=I9"`B5&AE('-P96-I
M9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L<@X_'A[.S>(/#O
M]2#O\=_SX?3E(.3E[2#U\-SQ]^7I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`X"FUS9VED(")4:&4@=&%S:R!H
M87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R("+'(.7Q
MX^'SW^$@\/'O\_3=Z.?JY2#S].<@Z]_S].$@Y?'CX?/I_NT@\^'R+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3$Q"FUS9VED(")4:&4@=&5M
M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+4
M[R#P\>_S^?'I[?P@X?'WY=_O(%PB)7-<(B#DY>T@]?#<\??EZ2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y
M"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R
M("+'(/#<[?D@ZN'I(.K<]/D@\.OE]?'=\B#L_.WO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B
M5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`BQR#PW.WY(/#KY?7QW"#L_.WO
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S$Q"FUS9VED(")4:&4@
M=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E
M<"XB"FUS9W-T<B`BU.$@Y.7D[^S=[>$@\._U(//TW>OMX?3E(/?<Z.?JX>T@
MX?#\(/3O(/#Q[^?C[_WLY>WO(.+>[.$N(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]C<W8N<&AP.C(U,"!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,3<W"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N(@IM<V=S='(@(M3O(.'Q]^7?[R#P[_4@\_3EW^OA].4@Y.4@[/#\\>7S
MY2#MX2#S^>CEWRXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.CDS"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I
M;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R("+/
MZ2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\B#A\._HY^KE_>CGZN'M(.7P
MZ?3U]_[R+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0IM<V=I9"`B
M5&AE;65S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`BSR#J
MX?3<Z^_C[_(@Z.7LW/3Y[2`G)7,G(.3E(.+QW>CGZN4N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#,*;7-G:60@(E1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BQ.7M(/7PW/'W[_7M(,7P
MZ>OOX]WR(.3IX>C=\^GLY?(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z,S0P"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`BQ.7M(/7PW/'W
M[_7M(/3LWNSA].$@\._U(.3E(.SP[_'O_>T@[>$@Y>SVX>WI\^CO_>T@Y>WS
M^>SA]/GLW>WA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3<*
M;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B+5\-SQ
M]^_U[2#P[^OK[]\@]^'QX>KTWO'E\B#SY2#A]?3\(/3O(/#EY-_O+B#%Z?/A
MX]SCX?3E("5S(/?A\>'J]-[QY?(L("(*(O#QW?#EZ2#MX2#U\-SQ]^_U[2#K
MZ>/\].7Q[^D@X?#\("5S+B(*"B,Z('-I9VYU<"YP:'`Z-34*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;2X@
M)7,N(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@].?M(/#Q[_/HWNKG("<E<R<@
M\_3O(//]\_3G[.$N("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<S"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T
M96TZ("5S(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@].?M(/#Q[_/HWNKG("<E
M<R<@\_3O(//]\_3G[.$Z("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BT/'\XNOG[.$@
MZN'TW"#TYR#DZ>'C\>'VWB#DY>3O[-WM^>T@]._U(/?QWO/TYR`G)7,G(.'P
M_"#T[R#S_?/TY^SA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R("+0\?SBZ^?LX2#JX?3<(/3G(.3IX>/QX?;>("<E
M<R<@X?#\(/3O(//]\_3G[.$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G.B`E<R(*
M;7-G<W1R("+0\?SBZ^?LX2#JX?3<(/3G[2#E[>?LW?'Y\^<@)R5S)SH@)7,B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3D*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`BT/'\XNOG[.$@ZN'TW"#TY^T@
MX?#O\_3OZ]X@X?'WY=_O]3H@Q.7M(//TW.OHY^KE("5S+B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP-`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2XB"FUS9W-T<B`B(@HBT.'Q[_7SZ=SSZ.?JY2#P\?SBZ^?LX2#J
MX?3<(/3G[2#A\._S]._KWB#T[_4@X?'WY=_O]3H@U.\@)7,@Y=_MX>D@[.7C
MX>O]].7Q[R`B"B+A\/P@].\@[-WCZ?/T[R#E\.GT\>7P_.SE[>\@[-WCY>CO
M\B`H)60@0GET97,I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDP-@IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB"FUS9W-T<B`B(@HBT.'Q[_7SZ=SSZ.?JY2#P\?SBZ^?LX2#JX?3<
M(/3G[2#A\._S]._KWB#T[_4@X?'WY=_O]3H@T_3<Z^CGZN4@[/SM[R#=[>$@
M(@HB].S>[.$@]._U("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z,S@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*(M#A\>_U
M\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7L]MSMZ?/G(.'U]._](/3O]2#T
M[-[LX?3O\B#T[_4@[.?M_>SA]._R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HT,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`BT.'Q[_7S
MZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@Y.7D[^S=[?GM(,3I
MY?7H]>WSZ>_C\=SV[_4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HW-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R("+0X?'O]?/IW//H
MY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#T[_4@X^7C[^WO]._R.B`E
M<RXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S(*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D
M871A+B(*;7-G<W1R("+0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#E
MZ?/AX_GCWB#DY>3O[-WM^>T@Y^SE\>_K[^/?[_4N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,#4*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G
M<W1R("+0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#T
MY_(@Y?'CX?/?X?(Z("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z.3$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N
M(@IM<V=S='(@(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C
M^>/>(/#KY_'O]N_QZ?[M(.3IX>CE\^GL_/3G].'R.B`E<RXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<Y"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HBT.'Q
M[_7SZ=SSZ.?JY2#S]MSK[.$@\_3G(/;\\>SA(/'UZ.S?\^7Y[2X@NO/Y\B#A
M]M[SX?3E(.KE[?P@ZMSP[^GO("(*(N'PX>GT[_WLY>WO(/#EY-_O+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8S
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@
M<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HBT.'Q[_7SZ=SSZ.?JY2#S]MSK
M[.$@\_3G[2#EZO3=Z^7SYR#TY_(@ZN'H[_'I\^S=[>?R(.OEZ?3O]?'CW^'R
M(/3O]2`B"B+$Z>7UZ/7M\^GOX_'<]N_U+B#0X?'AZN'K_B#D[^KI[-SS].4@
MX?'C_/3E\>$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-C4*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)"96D@9&5R($%K='5A;&ES:65R=6YG(&1E
M<B!+;VYT86MT9&5T86EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@
M0FET=&4@(@HB=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(B(*(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7M
MY^S=\?GSYR#TY_(@Z]_S].'R(.3IX>WO[-[R+B#0X?'AZN'K_B`B"B+D[^KI
M[-SS].4@X?'C_/3E\>$N(@H*;7-G:60@(E1H97-S86QO;FEK:2!!:7)P;W)T
M(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,CE\_/AZ^_MW^KG\B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U,PIM<V=I9"`B5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RXB"FUS9W-T<B`BSR#E[O7PY_'E].?TWO(@24U!4"#DY>T@]?#O\_3G\=_F
MY>D@ZN_I[?SW\>?S]._U\B#VX>K=Z^_U\BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C@R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR,#`*;7-G:60@
M(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(L'U]-X@
MYR#E[=WQX^7IX2#DY>T@]?#O\_3G\=_FY?3AZ2XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Q.`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,U.0IM<V=I9"`B
M5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
MP?7TWB#G(.OEZ?3O]?'CW^$@Y.7M(-WWY>D@[^OOZNOG\?GHY=\@X>K\[.<N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU,0IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92XB"FUS9W-T<B`BP?7T_"#DY2#VX=_MY?3AZ2#MX2#EW^WAZ2#=
MX^KU\>\@X?'WY=_O(')A<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4U"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("+!]?3\(.3E(/;AW^WE
M].'I(.WA(.7?[>'I(-WCZO7Q[R#A\??EW^\@>FEP+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,CD*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E
M;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("+!]?3\(.3E
M(/;AW^WE].'I(.WA(.7?[>'I(-WCZO7Q[_(@X?'IZ.S\\B#JW/'TX?(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@W"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"B+!]?3\\B#O(._DY^/\\B#SX?(@Y?#I]/'=\.7I(.WA(//TW>OM
MY?3E(.SG[?WLX?3A(.S=\_D@0VQI8VMA=&5L;"TH:'1T<#HO+R(*(F-L:6-K
M871E;&PN8V]M*2#LW?/Y($A45%`M05!)+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,T"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HBP?7T_/(@[R#OY.?C
M_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S]-WK[>7TY2#LY^W][.'TX2#LW?/Y('-M
M<S)E;6%I;"TH:'1T<#HO+R(*(G-M<S)M86EL+F-O;2D@[-WS^2!(5%10+4%0
M22XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX,@IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HBP?7T_/(@
M[R#OY.?C_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S]-WK[>7TY2#LY^W][.'TX2#L
MW?/Y(%--5%`@(.KAZ2#TY_(@(@HB5F]D869O;F4M271A;'D@[/SM[R#SY2#A
M\>GH[._]\B!6;V1A9F]N92X@P?#AZ?3EWR#=[>$@Z^_CX?'IX?/L_"!E;6%I
M;"#S].<@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(X,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDT"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$U-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@R-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`Q,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(P-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDR(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,S8*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,X-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SDT"FUS
M9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("+4[R#PY>3?
M[R#A]?3\(.'PX>GTY=_TX>DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+B(*;7-G<W1R("+4[R#PY>3?[R#A]?3\(.SP[_'EWR#MX2#=]^7I
M(.S\[>\@X>K=\>'I[_7R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,#`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*(L'U]/P@].\@\.7DW^_U
M(.SP[_'EWR#MX2#PY?'IW??EZ2#L_.WO(.'QZ>CL[_WR(.KAZ2#<[?D@ZMST
M^2#TY>OEW^$@*#HI+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M.#@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N(@IM<V=S='(@(L'U]/P@].\@\.7DW^\@[/#O\>7?(.WA(/#E\>G=
M]^7I(.S\[>\@[^KTX>3IZMWR(/3I[-WR+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,3<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(B(*(L'U]/P@].\@\.7DW^\@[/#O\>7?(.WA(/#E\>G=]^7I(.S\[>\@
MZ]_S].$@X?'IZ.S^[2#W^?'I\^S=[?GM(.SE(.KE[?P@WB`B"B+EZ^OG[>GJ
M_"#E\?GTY^SA].GJ_"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX
M,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*
M;7-G<W1R("+!]?3\(/3O(/#EY-_O(/#QW?#EZ2#MX2#EW^WAZ2#=[>'R(-WC
MZO7Q[_(@X?'IZ.S\\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#(T"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G
M(S$R,S1A9B<N(@IM<V=S='(@(B(*(L'U]/P@].\@\.7DW^\@\/'=\.7I(.WA
M(/#E\>G=]^7I(.KYY.GJ_"#W\?[LX?3O\B#SY2!21T(@Y.7JX>7NX>3IZMX@
M[._Q]MXL(/`N(@HB]RX@)R,Q,C,T868G+B(*"FUS9VED("(B"B)4:&ES(&9I
M;&4@8V]N=')O;',@=&AE(&=L;V)A;"!S970@;V8@34E-12!D<FEV97)S(&9O
M<B!T:&4@2&]R9&4@9G)A;65W;W)K+"`B"B)A;&QO=VEN9R!A<'!L:6-A=&EO
M;G,@=&\@;6%K92!U<V4@;V8@<')O9W)A;7,@<W5C:"!A<R!E;G-C<FEP="!O
M<B!M<W=O<F1V:65W("(*(G1O(')E;F1E<B!C;VYT96YT(&EN=&\@2%1-3"!F
M;W(@=FEE=VEN9R!I;B!A(&)R;W=S97(N(@IM<V=S='(@(B(*(L'U]/P@].\@
MX?'WY=_O(/#E\>G=]^7I(/3O]?(@34E-12!D<FEV97)S(/#O]2#W\>?SZ>SO
M\._I[_WM].'I(.'P_"#TY^T@(@HB]?#G\>7SW^$@Y?#I]/'=\._M].'R(.3I
MW/;O\>$@\/'OX_'<[.SA].$@[>$@Y.GA]^7I\=_F[^WTX>D@].$@\.7QZ>7W
M_.SE[>$@(@HB]/GM(&5M86EL(.KAZ2#MX2#TX2#E[/;A[=_F[_7M(.SE(/3O
M[2#JX?3<Z^OGZ^\@]/'\\.\N(@H*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT
M<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@=&\@<V5T(&-O;&]R
M<R!A;F0@9F]N=',@9F]R("(*(G1H92!(;W)D92!F<F%M97=O<FL@86YD(&%L
M;"!A<'!L:6-A=&EO;G,@=&AA="!D;R!N;W0@<')O=FED92!T:&5I<B!O=VX@
M(@HB<V5T=&EN9W,N(@IM<V=S='(@(B(*(L'U]/P@].\@X?'WY=_O(.7KW>/W
MY>D@].GR(/'UZ.S?\^7I\B#T^>T@]_'Y[-ST^>T@ZN'I(/3Y[2#C\>'L[.'T
M[_/EZ?'^[2#CZ>$@(@HB_.OA(/3O(/#Q_./QX>SLX2#T[_4@2&]R9&4L(.KA
MZ2#CZ>$@].GR(.7VX?'L[^/=\B#P[_4@Y=_MX>D@Y>/JX?3E\_3G[-WMY?(@
M(@HB\^4@X?7T_"#JX>D@Y.7M(/#A\=WW[_7M(.3IZMWR(/3O]?(@Y?#IZ^_C
MW?(@X^GA(.'U]-WR(/3I\B#Q]>CLW_/EZ?(N(@H*;7-G:60@(B(*(E1H:7,@
M9FEL92!M87!S(&9I;&4@97AT96YS:6]N<R!T;R!L;V=I8V%L($U)344@='EP
M97,L(&5N86)L:6YG($AO<F1E("(*(F%P<&QI8V%T:6]N<R!T;R!F:6=U<F4@
M;W5T(&AO=R!T;R!H86YD;&4@<V]M92!C;VYT96YT('-U8V@@87,@96UA:6P@
M(@HB871T86-H;65N=',@;W(@0U93(&-H96-K;W5T<RXB"FUS9W-T<B`B(@HB
MP?7T_"#T[R#A\??EW^\@ZN'TX>/QW/;EZ2#TZ?(@Y?#EZO3<\^7I\B#T^>T@
M]/WP^>T@S,G,Q2P@_O/TY2#TX2#PY?'IY??\[.7MX2`B"B+O\>GS[-WM^>T@
M;6%I;"#MX2#E[/;A[=_F[^WTX>D@[.4@]._M(.KA]-SKZ^?K[R#T\?SP[RXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C(*;7-G:60@(E1H:7,@
M9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`BP?7T
MWB#G(/;\\>SA(-WWY>D@WN3G(.7PY>[E\>/A\^CEWRXB"@HC.B!T96UP;&%T
M97,O:&5L<"]A8F]U="YI;F,Z,0IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T
M<B`BP?7T_"#EW^WAZ2`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0S-PIM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O
M8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E
M;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L
M:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(L'U]/P@Y=_MX>D@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@P^GA(.WA(.3EW_3E(/3O(.'M].GJ
MY=_LY>WO(.'U]/P@(@HB]_'EZ=SFY?/HY2#=[>$@\/'\X_'A[.SA(&5M86EL
M(/#O]2#JX?3AZ^'BX=_MY>D@X?7TWB#TYR#L[_'VWBX@P^GA(.O?\_3A("(*
M(O3=]._I^>T@\/'OX_'A[.S<]/GM(.SP[_'EW_3E(.WA(.7PZ?/JY?7HY=_T
MY2#T[R`E<R(*"FUS9VED("(B"B)4:&ES(&ES('1H92!M86EN($AO<F1E(&-O
M;F9I9W5R871I;VX@9FEL92X@270@8V]N=&%I;G,@<&%T:',@86YD(&)A<VEC
M(&ET96US("(*(G1H870@87!P;'D@=&\@=&AE(&-O<F4@9G)A;65W;W)K(&%N
M9"!A;&P@2&]R9&4@87!P;&EC871I;VYS+B(*;7-G<W1R("(B"B+!]?3\(.7?
M[>'I(/3O(.+A\^GJ_"#A\??EW^\@\?7H[-_SY?GM(/3O]2#P\>_C\=SL[.'T
M[_(@)TAO<F1E)RX@T.7QZ=WWY>D@].$@(@HB[._M[_#<].GA(.KAZ2#TX2#B
MX?/IZMP@[-WQYR#P[_4@]_'G\^GL[_#OZ>_][?3AZ2#A\/P@]._M(/#U\=[M
MX2#JX>D@].GR("(*(N7VX?'L[^/=\B#T[_4@\_7S]-[LX?3O\BX@(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`W"FUS9VED(")4
M:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E
M<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HBU.\@[-[M]>SA
M(.'U]/P@X_'<]NCGZN4@[.4@ZOGDZ>KO\^7KW^3A("@E<RD@Y.GA]N_QY?3I
MZMX@X?#\(/3G(.3IZMX@\^'R+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(Y"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92XB"FUS9W-T<B`BP?7T_/(@[R#A\>GH[/SR(/#QW?#EZ2#MX2#E
MW^WAZ2#T[_7KW/?I\_3O[2#=[>$N(@H*;7-G:60@(B(*(E1H:7,@<')O8FQE
M;2!R97!O<G0@=V%S(')E8V5I=F5D(&9R;VT@)7,N(%1H92!U<V5R(&-L:6-K
M960@=&AE('!R;V)L96T@(@HB<F5P;W)T(&QI;FL@9G)O;2!T:&4@9F]L;&]W
M:6YG(&QO8V%T:6]N.B5S(&%N9"!I<R!U<VEN9R!T:&4@9F]L;&]W:6YG("(*
M(F)R;W=S97(Z)7,B"FUS9W-T<B`B(@HBU.\@\/'\XNOG[.$@X?7T_"#A[>'V
MW?'HY^KE(.'P_"`E<RX@SR#W\=[S].?R(.K<Z^7SY2#TY^T\8G(O/N'MX?;O
M\=P@(@HB\/'OXNO>[.'T[_(@X?#\(/3O(/#A\>'JW/3Y(%523#H\8G(O/B5S
M(.KAZ2#W\>?SZ>SO\._IY=\@]._M(.'J_.OO]>CO("(*(F)R;W=S97(Z/&)R
M+SXE<R(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HT.`IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(L'U]/SR(.\@Y>[U\.?QY?3G]-[R
M(.3E(.SP[_'EWR#MX2#A\._S]>SPZ=WSY>D@>FEP(.KAZ2!G>FEP(.'Q]^7?
MX2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$T
M-PIM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+B(*;7-G<W1R("+4[R#S_?/TY^SA(.'U]/P@W??EZ2#A\.7MY?'C[_#OZ>?H
MY=\N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C<*;7-G
M:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`BP?7T
MWB#G(/3I[-X@\/'=\.7I(.WA(.7?[>'I(.'QZ>CL_/(N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(R-0IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R
M("+%Z?/I]-[QZ>$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P
M"FUS9VED(")4:6UE(@IM<V=S='(@(MGQX2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,3$*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B
MR??MY^OA]/[M].'R(/3G[2#^\>$B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(LSO\?;>(/[QX?(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3(Q"FUS9VED(")4:6UE('-E
M;&5C=&EO;B(*;7-G<W1R("+%\.GK[^/>(/[QX?(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,R(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+4W_3K[_(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED
M(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(M3?].OO\B`H5&]O;'1I<"DZ
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HX
M,`IM<V=I9"`B5&\B"FUS9W-T<B`BT/'\\B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV,CD*;7-G:60@(B(*(E1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S
M='(@(B(*(L/IX2#MX2#J\>'TWO/E].4@\._KZ^'PZ]P@X>WTZ>KEW^SE[>$L
M(.KQX?3>\_3E(/#A].?LW.WO(/3O($-O;G1R;VP@*%!#*2#>("(*(O3O($-O
M;6UA;F0@*$UA8RD@\.O>ZO3Q[RP@Y>W^(.K<[>7TY2#JZ^GJ+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*;7-G:60@(E1O9&%Y(@IM
M<V=S='(@(M/>[.7QX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G
M<W1R("+%[>'KZ^'CWB#SY2#PY^/AW^\@2%1-3"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@
M(L']\>GO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`BRN_Q]?;>(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("+0W.WY(/#KX=_SZ>\@*%]T
M;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N
M<VQA=&EO;G,B"FUS9W-T<B`BS.7TX?;QW//EZ?(B"@IM<V=I9"`B5')I<&]L
M:7,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#4\=_P[^OG\B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-S<*;7-G:60@(E1R=64@;W(@
M9F%L<V4B"FUS9W-T<B`BP>OGZ-WR(-X@^.7UY-WR(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS
M9W-T<B`BU/$B"@IM<V=I9"`B5'EP92!M:7-M871C:"XB"FUS9W-T<B`BR^'M
MZ.'S[-WM[_(@]/WP[_(@Y.7D[^S=[?GM+B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C(*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M("+0Z^?J]/'OZ^_CWO/TY2#TY^T@Y?#IZ^_CWB#SX?(Z("(*"FUS9VED(")5
M4DPB"FUS9W-T<B`BQ^OEZO3Q[^WIZMX@Q.GE_>CU[?/G(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C$*;7-G:60@
M(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*
M;7-G<W1R("(B"B+'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<@X^GA(.7PZ?/T\>_V
MWB#A[>'V[_'<\B#JX?3<\_3A\^?R(/3O]2#P\>_C\=SL[.'T_/(@\^'R(@H*
M;7-G:60@(E523#HB"FUS9W-T<B`BQ^OEZO3Q[^WIZMX@Q.GE_>CU[?/G.B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,V,0IM<V=I9"`B56YA
M8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+!Y/WMX?3G
M(.<@\/'\\^+A\^<@\_3O[2!61E,@ZN'TW.OOX^\N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C$P,`IM<V=I9"`B56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS
M9W-T<B`BP>3][>'TYR#G(/#Q[_/HWNKE(.7PZ?#KW>_M(/#KY_'O]N_QZ?[M
M(.KA]-P@].?M(.7?\^_D[R#T[_4@]_'>\_3G+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S0V"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BP>3][>'T
MYR#G(.'KZ^'CWB#E[N_U\^GOY._TWO/E^>T@X^GA(/3O(%9&4R#A\??EW^\@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-3`R"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G
M<W1R("+!Y/WMX?3G(.<@X>OKX>/>(.7N[_7SZ>_D[_3>\^7Y[2#CZ>$@].\@
M5D93(.'Q]^7?[R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<P-`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T
M<B`BP>3][>'TYR#G(.'KZ^'CWB#T[_4@)7,N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C,W-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`BQ.7M(.7?[>'I(.3U[>'TWB#G(//]
M[>3E\^<@\_3O(.3IX>KO[.GS]-X@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S@X"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"XB"FUS9W-T<B`BQ.7M(.7?[>'I(.3U[>'TWB#G(//][>3E\^<@[.4@
M4U-,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,2!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S8*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("+!
MY/WMX?3G(.<@X>WTZ>/QX?;>(%9&4R#A\??EW^_U+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S(P"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.?L
MZ>_U\>/?X2#JX?3AZ_SC[_4@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR.38@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C8Y
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(L'D_>WA].<@YR#DY^SI[_7QX]_A(.KA].'K_./O]2!61E,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-@IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`BP>3][>'TYR#G(.3G[.GO
M]?'CW^$@5D93(.'Q]^7?[_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C$S"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2#JY>WO_2!61E,@
MX?'WY=_O]2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R
M+G!H<#HW.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP
M:'`Z.#(*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S
M='(@(L'D_>WA].<@YR#A\._S]>SPW^7SYR#DY>3O[-WM^>TN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR-#D*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS
M9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(%PB)7-<(BP@[R#VW.KEZ^_R(.3E
M[2#EW^WAZ2#JY>W\\BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S8Q"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("+!Y/WMX?3G(.<@
MY.GAX_'A]MX@)7,L(.\@]MSJY>OO\B#DY>T@Y=_MX>D@ZN7M_/(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<Y(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3D*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@)R5S)SH@)7,N(@IM<V=S='(@(L'D
M_>WA].<@YR#DZ>'C\>'VWB`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.#$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>
M(.KA].'K_./O]2!61E,@Y?#A[>'K[.+A[?SLY>WA("AR96-U<G-I=F5L>2DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS-#@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,V,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S8Y
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-S,*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BP>3]
M[>'TYR#G(.3IX>/QX?;>(.KA].'K_./O]2!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT
M(&=E;/9S8VAT('=E<F1E;CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U(%9&4R#A
M\??EW^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$W,R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@V"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.3,@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0Q,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A
M]MX@]._U(%9&4R#A\??EW^_U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S,W"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB!61E,@Y?#A
M[>'KX>SBX>W\[.7MX2`H<F5C=7)S:79E;'DI.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<U,@IM<V=I9"`B56YA8FQE('1O(&1E=&5R
M;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@
M\/'O\^3I[_'?\_D@]._M(/3QW??O[?3A(.KA]-SK[^/O+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(W"FUS9VED(")5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(L3E(.SP
M[_'^(.WA(.7NW./Y(/#KY_'O]N_QW^7R(/#I\_3O\._IY_3IZN_](@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0V,"!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]!=71H+G!H<#HQ,3D*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+!Y/WMX?3G(.<@]OSQ
M]/GSYR#O\>GS[._](/3O]2`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ-#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,30U"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C0@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V.0IM<V=I9"`B56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N(@IM<V=S='(@(L'D_>WA].<@YR#LY?3AZM_MY_/G(/3O
M]2!61E,@X?'WW^_U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-SD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BP>3][>'T[R#T[R#<[>_IX^SA(/3O]2!61E,@X?'WY=_O]2!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(P(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,C<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S,`IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(L'D_>WA].\@].\@W.WO
MZ>/LX2#T[_4@5D93(.'Q]^7?[_4@X^GA(./QW/CI[.\N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-S0@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB
M"FUS9W-T<B`BP>3][>'T[R#T[R#<[>_IX^SA(/3O]2!61E,@X?'WY=_O]2XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0W"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S
M='(@(L3E(.SP[_'^(.WA(.'M[]_N^2#T[R#S]>SPZ>7S[-WM[R#A\??EW^\N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C(S"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@
M(L3E(.SP[_'^(.WA(.3IX>+<\_D@]._M(.K]\>GO(.KA]-SK[^/O(%9&4R`H
M=F9S<F]O="DN(@H*;7-G:60@(E5N86)L92!T;R!R96=I<W1E<B!P<F5F97)E
M;F-E<R!I;B!S97-S:6]N+B(*;7-G<W1R("+$Y>T@Y=_MX>D@Y/7MX?3\[2#M
MX2#JX?3A]_GQY^CO_>T@[^D@\/'O].GLWO/EZ?(@X^GA(.'U]-X@].?M(//]
M[>3E\^<N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#DU"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`BP>3][>'TYR#G(.SE]._M
M[^SA\]_A(/3O]2`E<R#SY2`E<SH@[R#VW.KEZ^OO\B#U\-SQ]^7I(-[DYR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,34*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BP>3]
M[>'TYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@ZN'TX>O\X^_U+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C4U"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+!Y/WMX?3G(.<@
M[.7T[^WO[.'SW^$@]._U(%9&4R#JX?3AZ_SC[_4Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDV"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BP>3][>'TYR#G(.SE]._M
M[^SA\]_A(/3O]2!61E,@X?'WY=_O]2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-38T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR-#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N(@IM<V=S='(@(L'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.'Q
M]^7?[_4@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M-#D@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#@U(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS,#0*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,R-@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS
M9W-T<B`BP>3][>'TYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@X?'WY=_O]2XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3$*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G
M<W1R("+!Y/WMX?3G(.<@Y>KTW>OE\^<@]._U(%PB;6MI<V]F<UPB+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-C(*;7-G
M:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM
M<V=S='(@(L3E[2#L\/SQY?/E(.WA(.SE].'V\>'S].7?(.'U]/P@].\@W>/C
M\>'V[R!7;W)D(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ,C<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ,S`*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L3E(.SP[_'^(.WA
M(./QW/CY(//T[R!61E,@X?'WY=_O(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,C$*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(L3E(.SP[_'^(.WA
M(./QW/CG(//T[R!61E,@X?'WY=_O("AC;W!Y*"D@X?#=]/7WY2DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(T(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S0*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N(@IM<V=S='(@(L3E(.SP[_'^(.WA(./QW/CY(.3EY._LW>WA(/3O
M]2!61E,@X?'WY=_O]2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`BU?#O
MX_'A[.SI\^S=[>$B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS
M9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`BP>K]\?GSYR#!Z^OAX_[M(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM
M<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BP>KU\?[M
MY>D@].<@].7KY?7TX=_A(//A\B#E[=WQX^7IX2(*"FUS9VED(")5;F5X<&5C
M=&5D(&5N9"!O9B!F:6QE+B(*;7-G<W1R("+,YR#A[>'LY>W\[.7M[R#TW>OO
M\B#T[_4@X?'WY=_O]2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,S`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,SDY"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("+,YR#A[>'LY>W\[.7M
MYR#A\-SM].?SYR#A\/P@]._M(.7N]?#G\>7TY_3>(//TYR#S_>WDY?/G.B`B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C8*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S4P"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3,*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R
M("+,YR#A[>'LY>W\[.7MYR#A\-SM].?SYR#A\/P@]._M(.7N]?#G\>7TY_3>
M(//T[SH@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3@*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C0*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BS.<@P?'WY>GO
MZ.7TY^S=[>\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C,X-`IM<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T
M>7!E.B`E<R(*;7-G<W1R("+,YR#WY>GQZ>;\[.7M[R#S]._I]^7?[R#T_?#O
M]3H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HV.0IM<V=I9"`B56YI=',B"FUS9W-T<B`BS._M
MW.3E\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,38*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`BP>/M^?/T[R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")5;FMN;W=N(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(E5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(E5N
M:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(L'C[?GS].\@
M_.WO[.$@]_'>\_3G(-X@ZOGDZ>K\\BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(E5N;&EN
M:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(L'P[_/][>3E\^<@]/'=
M]^_M]._R(//T[^GWY=_O]2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z,CDX"FUS9VED(")5;FYA;65D(@IM<V=S='(@(L'M_NWU[.\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y
M"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL
M;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@
M(B(*(LSG(.7N[_7SZ>_D[_3G[-WMX2#P\>_C\=SL[.'TX2#DY2#L\._Q[_WM
M(.WA(-WW[_7M(/#Q_//BX?/G(//E(.OEZ?3O]?'CW^7R("(*(N'P[^KO\-[R
M+^'M].GC\>'VWO(OY?#IZOSKY_/G\B#CZ>$@Z_SC[_7R(.'S]N'KY=_A\BX@
MT.'TWO/TY2#/RB#CZ>$@[>$@Y.7?].4@(@HB].7W[>GJW?(@\^?LY>G^\^7I
M\B#S].\@;6]Z:6QL82YO<F<@\._U(//A\B#DY=_W[>_U[2#P^?(@[>$@Y?#I
M]/'=^.7TY2#SY2`B"B+P\>_C\=SL[.'TX2#TYR#P\?SSXN'SYR#S].\@8VQI
M<&)O87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`BS.<@
M[_'I\^S=[>\@]_'^[.$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,"!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDU
M,@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDU.`IM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(LSG(/7P[_/TY_'I
MYOSLY>WG(.7PW>KTX?/G(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`V
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DQ"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,V"FUS9VED(")5<&1A=&4B"FUS9W-T
M<B`BQ>WG[-WQ^?/G(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS,0IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(L7MY^S=\?GSYR`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C0X"FUS9VED(")5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T
M<B`BQ>WG[-WQ^?/G(.KA]-SS].'SY_(@X?#A[?3G[-WM[_4B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"FUS9VED(")5<&1A=&4@
M=7-E<B(*;7-G<W1R("+%[>?LW?'Y\^<@]_'>\_3G(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ,S<@861M:6XO<&5R;7,O961I="YP:'`Z,C$W('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S`*;7-G:60@(E5P9&%T960@)R5S)RXB"FUS
M9W-T<B`B)R5S)R#%[>?LY?'^Z.?JY2XB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX,0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS
M9W-T<B`BU.\@\/'\X_'A[.SA(.'MX>+<Z.SI\^?R(.3IX>/QW/;GZN4N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@R"FUS9VED(")5<&QO860B"FUS9W-T
M<B`BP?#O\_3OZ]XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"FUS
M9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BXB"FUS9W-T<B`BP?#O\_3OZ]X@_.OY[2#T^>T@X?'WY=_Y
M[2#Q]>CLW_/E^>T@\_3O[2#E[O7PY_'E].?TWBXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED
M(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(LKE]N'KX=_A(.OA].GM
MZ>K<(./QW.SLX?3A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R("+1^>SA^NKOWR#A\>GH[._?+<KE]N'KX=_A(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#8*
M;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("+7\=[SYR#T\=WW[^WT
M[_(Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-3@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`BU_'>\^<@4U-,
M(@H*;7-G:60@(E5S92!$969A=6QT(%9A;'5E(@IM<V=S='(@(LWA(/?QY_/I
M[._P[^GGZ.7?(.<@\/'OY?#IZ^7C[-WMYR#TZ>S>(@H*;7-G:60@(E5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M(@IM<V=S='(@(M?QY_/I[._P[^GEW_3AZ2#A[2#T[R#\[>_LX2_J^>3IZOSR
M(.7?[>'I(.3IX?;O\>7TZ>K<+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-C4Q"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`BSR#W\=[S].?R("5S(.3E[2#EW^WA
MZ2#E[N_U\^GOY._TY^S=[>_R(./IX2`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HR,#0*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`BQ.GA
M]^7?\>GSYR#7\>?S]/[M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("+%\.GK[^/=
M\B#7\=[S].<B"@HC.B!S:6=N=7`N<&AP.C8T"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R("+%X^/QX?;>(-?QWO/TYR(*"B,Z('-I9VYU<"YP
M:'`Z,3D*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(L<@Y>/C\>'VWB#W\=[S].<@
MW??EZ2#A\.7MY?'C[_#OZ>?HY=\@X^DG(.'U]/P@].\@<VET92XB"@IM<V=I
M9"`B57-E<B!P87-S=V]R9"!C:&%N9V4B"FUS9W-T<B`BP>OKX>/>(.KYY.GJ
M[_T@]_'>\_3G(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<R(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T"FUS9VED(")5<V5R('!E<FUI
M<W-I;VYS(@IM<V=S='(@(L7N[_7SZ>_D[_3>\^7I\B#7\=[S].<B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#(@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHV-2!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,0IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BO.WO[.$@U_'>\_3G
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$S,0IM<V=I
M9"`B57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`BU.\@
M_.WO[.$@]_'>\_3G("<E<R<@]?#<\??EZ2#>Y.<N(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`BO.WO[.$@U_'>\_3G.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`BO.WO[.$@U_'>\_3G
M.B`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-PIM<V=I
M9"`B57-E<G,B"FUS9W-T<B`BU_'>\_3E\B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ
M(@IM<V=S='(@(M?QWO/TY?(@\_3O(-/]\_3G[.$Z(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3$P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(P,PIM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`BSR#JX?3<Z^_C[_(@5D93(.3E[2#U\-SQ]^7I+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(L3IX>KO\-WR(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#8P"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM
M<V=S='(@(KCCZO7QY?(@]._P[^CE\]_E\B#P[_4@XO'=Z.?JX>T@\_7L\.7Q
MZ>OA[.+<[>_M].'I.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8V,@IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`BQ>/J]?'\].?T
MX2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(V,PIM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB
M"FUS9W-T<B`BU.GLWB#SY2#KY?#TW"#A\/P@]/[QX2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C(W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3$V"FUS9VED(")686QU97,B"FUS9W-T<B`B
MU.GLW?(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DR(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-CD*;7-G:60@(E9A;'5E<R!T;R!S96QE
M8W0@9G)O;2(*;7-G<W1R("+$_O/TY2#TZ>S=\B#CZ>$@[>$@Y?#IZ]WN^2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.3,*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(LSE].'BZ^?TWB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C(X"FUS9VED(")697)I9FEC871I;VX@9F%I
M;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET
M:"XB"FUS9W-T<B`BQR#E\.GBY>+AW_GSYR#A\-WT]??E("T@X?7T_"#T[R#L
MWNWU[.$@[/#O\>7?(.WA(-SKZ^'NY2#LY2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<R-`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R
M("*XZN3O\^<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`P"FUS
M9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`BN.OEX_?O\B"XZN3O\^?R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`BRMSHY?3G
M(,7UZ/7C\=SL[.GSYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`BRMSHY?3O(./=[.GS[.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B
MRMSHY?3A.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C(*
M;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("+0[^O](/CGZ]XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY.3(*;7-G:60@(E9I97<@
M)7,B"FUS9W-T<B`BQ>SVW.WI\^<@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S
M='(@(L7L]MSMZ?/G(.7N^?3E\>GJWO(@Z?/T[_/EZ]_DX?(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#4*;7-G:60@(E9I97<@
M87,@)7,B"FUS9W-T<B`BQ>SVW.WI\^<@\^'M("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.0IM<V=I9"`B5FEE
M=R!E=F5N="(*;7-G<W1R("+%[/;<[>GSYR#CY>/O[?ST[_(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P.0IM<V=I
M9"`B5FEE=R!T87-K(@IM<V=S='(@(L7L]MSMZ?/G(.7QX^'SW^'R(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#<*;7-G:60@(E9I<VEB:6QI='DB"FUS
M9W-T<B`BS_'A]/STY_3A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(P-PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(L_QX?3\].?T
MX3HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX,0IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS
M9W-T<B`B5F]D869O;F4@R?3AZ]_A\B#LW?/Y(%--5%`B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,Y"FUS9VED(")705).(@IM<V=S='(@(M#1S]//U\<B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(M#1S]//U\<A
M(2$@P=;!R='%T]3%(-3/(-#1S\/1P<S,P2#,S\W/R2#3P=,@P=#/("5S+B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,S$*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BT/'O
MY>GD[_#OW^?SYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(M3E(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HS-PIM<V=I9"`B5V5E
M:VQY(@IM<V=S='(@(L7BY._LX>3IX=_A(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`BRN'K^?/>
MZ^CA].4B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-3`*;7-G:60@(E=E;&-O;64@=&\@)7,B
M"FUS9W-T<B`BRN'K^?/>Z^CA].4@\_3O("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR
M"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("+*X>OY\][KZ.'TY2P@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Q"FUS9VED(")7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G
M<W1R("+0[^G<(.7VX?'L[^/>(.CA(.7L]N'LW^;EZ2#T[R`E<R#A]N_](//U
M[>3EZ.7?].4@\_3G[2#U\.?QY?/?X3LB"@IM<V=I9"`B5VAA="!A<'!L:6-A
M=&EO;B!S:&]U;&0@2&]R9&4@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T
M<B`BT._IX2#E]N'Q[._CWB#MX2#E[/;A[=_FY?3AZ2#A]N_](//U[>3EZ.7?
M].4@\_3G[2#U\.?QY?/?X3LB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR,0IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E
M<C\B"FUS9W-T<B`BT._I_/(@Y=_MX>D@[R#DZ>'W^?'I\_3IZOSR(/?A\>'J
M]-[QX?([(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C0*;7-G
M:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`BT._I
M_/(@Y=_MX>D@[R#WX?'AZO3>\>'R(.7I\^'C^>/IZO[M.R(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@
M(M#OZ=WR(-;<\^7I\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$*
M;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BXB"FUS9W-T<B`B(@HBRN'H[_'?\_3E(/#OZ=P@\/'\\^CE
M].$@Z.$@Y>WE\>/O\._IY^CO_>T@\_3O[2#E\.7NY?'CX?/TWB#E[/#K[_7T
MZ?/LW>WO]2`B"B+JY>GLW>WO]2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G
M<W1R("+0Z]ST[_(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`Y
M"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`BT.O<]._R(//E
M(.SO[=SDY?(@0U-3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM
M<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(M#KW/3O\B#T[_4@
M)7,@[.7M[_T@\_3A(.'QZ?/TY?'<("CHX2#E]N'Q[._SZ.7?(//TY^T@Y?#\
M[.7MYR#EW_/OY.\I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS
M9W-T<B`BT.O<]._R(/3O]2#PW^WAZN$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*
M;7-G<W1R("+,[^W<Y.$@\.O<]._U\B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T
M<B`BT.O<]._R.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`BN.WTX?/G(.'MW>SO]2#S
MY2#J_.SB[_7R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-30*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(L'MY>SO\CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3DQ"FUS9VED(")7:6YD.B`B"FUS9W-T<B`BP>WE[._R
M.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O
M;2(*;7-G<W1R("+3[_;?X2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-S<*;7-G:60@(E=I<VAL:7-T<R(*;7-G<W1R("++W_/TX2#E\.GH]>SI
M_NTB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB
M"FUS9W-T<B`BQ?'CX?/?X2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$V-PIM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@
M(L3IY?WH]>WSYR#%\>/A\]_A\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.34*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T
M<B`BU.?KW?;Y[>\@Q?'CX?/?X?(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,T"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$W"FUS9VED(")8-3`Y
M=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S(,+A\^GJ[]\@
MT.7QZ>_QZ?/L[]\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8Q-@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G
M<W1R(")8-3`Y=C,@U_'>\^<@Y?#EZO3A[-WM[_4@ZNOEZ>3I[_TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q.`IM<V=I9"`B6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@
MQ>WAZ^'J].GJ_""\[>_LX2#(W>SA]._R(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,3D*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME
M>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV,R#![>'C[?GQZ?/TZ>K\(,KK
MY>GDWR#(W>SA]._R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#8*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U
M,#EV,R#%\.7J]-SSY>GR(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(EE9(@IM<V=S='(@(L7%(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,X-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#(W"FUS9VED(")965E9(@IM<V=S='(@(L7%Q<4B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C,U
M"FUS9VED(")996%R;'DB"FUS9W-T<B`BQ?3>\^GA(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.`IM<V=I9"`B665S(@IM
M<V=S='(@(LWAWR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE
M;G1?8F]T=&]M+FEN8SHV"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B
MS>'I+"#3]>SV^>W^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M(@IM<V=S='(@(B(*(L7?\_3E(//E(.KA]-SS].'SYR#*Q<G,Q<W/U2X@U_'G
M\^GL[_#OZ>7?\_3E(/3O(%L\/ET@\.O>ZO3Q[R#CZ>$@[>$@(@HBY?#I\_3Q
MW?CE].4@\^4@ZN'TW//TX?/G(%=94TE724<N(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ,S(P"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+B(*;7-G<W1R("+$Y>T@W??E].4@X?7HY>WTZ>KO\._IY^CEWRXB
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P-`IM<V=I
M9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N(@IM<V=S='(@(L3E[2#E\.GT\=WPY?3AZ2#MX2#=]^7T
MY2#T[R#WX?'AZO3>\>$@)UQ<)R#S].\@O.WO[-P@\^'R+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X,S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DU.`IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("+$Y2#D_O/A].4@W>/C]?'G(.3IY?WH]>WS
MYR!E;6%I;"XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR-S0*;7-G
M:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@
M)7,N(@IM<V=S='(@(B(*(L3E[2#A[?3I\_3OZ???\^'TY2#JX>W=[>$@\.7D
MW^\@X?#\(/3O(.'Q]^7?[R#EZ?/AX_GCWO(@\^4@X>WTW_/T[^GWX2#PY>3?
MX2`B"B+S].\@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.30T
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(KCW
MY?3E(.'P[_/U[>3EZ.7?+B(*"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N/&)R("\^5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*
M;7-G<W1R("*X]^7TY2#A\._S]>WDY>CEWRX\8G(@+S[%]??A\>GS]._][.4@
M\._U(/?QY_/I[._P[^G>\^'TY2#TY^T@]?#G\>7SW^$N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$W.0IM<V=I9"`B66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`BT/'=\.7I(.WA(.3^\^7TY2#L
MZ>$@W>/J]?'G(/3I[-XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C,X"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E
M92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("+0\=WPY>D@[>$@
M\?7H[-_SY?3E(/3O($1A=&%4<F5E(./IX2#MX2#W\>?SZ>SO\._IY=_TY2!3
M:6=N=7!S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#0W"FUS
M9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T
M<B`BT/'=\.7I(.WA(/'UZ.S?\^7TY2#T[R!61E,M0F%C:V5N9"XB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(M#QW?#EZ2#MX2#PY?'IX_'<
M^.7TY2#T[R#P\?SBZ^?LX2#P\>GM(//TY=_KY?3E(.'MX?;O\=P@X^GA(.'U
M]/PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(M#QW?#EZ2#MX2#S]>SPZ^?Q_O/E
M].4@].\@55),(/#O]2#DY=_W[>7I(.'U]-X@YR#S_>WDY?/G(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BT/'=\.7I
M(.WA(.7PZ>O=[N7TY2#T[^T@Y>[U\.?QY?3G]-X@X^GA(.3IX>/QX?;>+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`BT/'=\.7I(.WA
M(._QW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#CZ>$@Y.GAX_'A]MXN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("+0\=WPY>D@[>$@[_'?\^7T
MY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#DZ>'C\>'VWBXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB
M"FUS9W-T<B`BT/'=\.7I(.WA(._QW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#C
MZ>$@\/'O\^C>ZN<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S
M='(@(M#QW?#EZ2#MX2#O\=_SY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(.7M
MY^S=\?GSYRXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ-#0*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2XB"FUS9W-T<B`BT/'=\.7I(.WA(._QW_/E].4@[.GA(.7M
MW?'CY>GA(./IX2#EZO3=Z^7SYRXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,PIM<V=I9"`B66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("+0\=WPY>D@[>$@Y/[S
MY?3E(-WMX2#\[>_LX2#CZ>$@].<@[=WA(.KA].?C[_'?X2XB"@HC(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDS,BP@8RUF;W)M870*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3,R"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BQR#S_>WD
MY?/G(//A\B`E<R#DZ>'J_/#GZN4N(-#A\>'JX>O^(.3OZNGLW//TY2#MX2#N
MX>WA\_7MY.7HY=_TY2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(L<@
MQ^OEZO3Q[^WIZMX@\^'R(,3IY?WH]>WSYR(*"FUS9VED(")9;W5R($5M86EL
M($%D9')E<W,Z(@IM<V=S='(@(L<@Q^OEZO3Q[^WIZMX@\^'R(,3IY?WH]>WS
MYSHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DV"FUS9VED(")9;W5R
M($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(L<@P?#\.B#$Z>7]Z/7M\^<Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(L_I(-#KY_'O]N_QW^7R(//A\B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDS-@IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B+'($EN=&5R;F5T(.3IY?WH]>WSWB#S
MX?(@W.OKX>[E(.'P_"#TY^T@W>WA\>[G(/3G\B`E<R#S_>WDY?/>\B#SX?(N
M(,/IX2#TY^T@(@HB\/'O\_3A\]_A(/3G\B#A\_;<Z^7IX?(@\/'=\.7I(.WA
M(.[A[>'S]>WDY>CEW_3E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BU.\@_.WO[-P@
M\^'R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.CD*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B
M"B+4[R#S_?/TY^SA(.'UZ.7M].GJ[_#OW^?SY_(@Y.7M(/7P[_/TY_'?YN7I
M(/#Q[_/HWNKG(/?QY_/T_NTL(-X@YR#KY>GT[_7QX]_A("(*(N'U]-X@W??E
MZ2#A\.7MY?'C[_#OZ>?HY=\@X^GA(.K<\._I[R#K_./O+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B+4[R#S_?/TY^SA
M(.'UZ.7M].GJ[_#OW^?SY_(@Y.7M(/7P[_/TY_'?YN7I(.O?\_3A(/?QY_/T
M_NTL(-X@YR#KY>GT[_7QX]_A("(*(N'U]-X@W??EZ2#A\.7MY?'C[_#OZ>?H
MY=\@X^GA(.K<\._I[R#K_./O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDT,`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B+/($)R;W=S97(@\^'R(/;AW^WE].'I
M(.WA(-WWY>D@X>OKW.[EZ2#A\/P@].?M(-WMX?'NYR#TY_(@)7,@\_WMY.7S
MWO(@\^'R+B`B"B+#Z>$@].?M(/#Q[_/TX?/?X2#TY_(@X?/VW.OEZ>'R+"#H
MX2#P\=WPY>D@[>$@[N'MX?/U[>3EZ.7?].4N(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`BSR!"<F]W<V5R(//A\B#DY>T@
M]?#O\_3G\=_FY>D@X?7TWB#TYR#KY>GT[_7QX]_A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W!R:6YT+FIS.C(W"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@
M0V]N=')O;"]/<'1I;VX@*R!0('1O("(*(G!R:6YT+B(*;7-G<W1R("(B"B+/
M($)R;W=S97(@\^'R(.3E[2#U\._S].?QW^;EZ2#A]?3>(/3G[2#E\.GK[^/>
M(.7J]/WP^?/G\BX@T.'TWO/TY2!#;VYT<F]L+R(*(D]P=&EO;B`K(%`@X^GA
M(.7J]/WP^?/G+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#$*;7-G
M:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(L<@]/'=]^_U
M\^$@YO[MYR#^\>'R.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#@*
M;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BQR#P\>_J
MX>CO\>GS[-WMYR#SX?(@].'U]/STY_3A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#<*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("+4
M[R#PZ][QY?(@_.WO[-P@\^'R.B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<V"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S(@IM<V=S='(@(L\@[=WO\B#SX?(@ZOGDZ>K\\B#CZ>$@)7,@Y=_MX>DZ
M("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-3<*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`BS^D@Y?#IZ^_CW?(@
M\^'R(-WW[_7M(.7MY^SE\?GHY=\@X^GA(/3G(.3IW/'JY>GA(.'U]-[R(/3G
M\B#S_>WDY?/G\BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U.0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R("+/Z2#E\.GK[^/=\B#SX?(@W??O]>T@Y>WG[.7Q^>CEWRXB"@IM
M<V=I9"`B66]U<B!P87-S=V]R9',@9&\@;F]T(&UA=&-H(@IM<V=S='(@(L_I
M(.W=[^D@ZOGDZ>KOWR#DY>T@].'I\>G<YN_U[2(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T(@IM<V=S='(@(L\@ZOGDZ>K\\B#SX?(@W.OKX>[E(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B
M"B+/(.KYY.GJ_/(@\^'R(-SKZ^'NY2P@Y>O=X^[TY2#TX2#LY^W][.'TW"#S
MX?(@ZN'I(.K<[?3E(.7?\^_D[R#LY2#T[R#MW>\@\^'R("(*(NKYY.GJ_"XB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO
M=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(L_I(.'P[^SAZO'U\^S=[>_I
M(//A\B#E[O7PY_'E].?TW?(Z(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(EO!\/SJ\?7XYR#JY>GLW>WO]2#SY2#EZ?/A
MX_GCZ>K<72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C4V"FUS9VED(");
M4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EO![>'V[_'<(-#Q[^+KWNSA]._R
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EO%[/;<[>GS
MYR#JY>GLW>WO]2#SY2#EZ?/AX_GCZ>K<("TB"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");Q>SV
MW.WI\^<@ZN7I[-WM[_4@\^4@Y>GSX>/YX^GJW"`M("5S(./QX>SLW?)=(@H*
M(R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.2P@8RUF;W)M870*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(EML:6YE("5S
M(&]F("5S72(*;7-G<W1R(");X_'A[.S>("5S(.'P_"`E<UTB"@IM<V=I9"`B
M7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I\^<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(L3IX>/QX?;>(,/QX>SLWO(B
M"@HC.B!L:6(O87!I+G!H<#HQ,30*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B
MS^S<Y.7R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$X
M,0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BPN_>Z.7IX2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BR>3I_/3G].7R(,7I
MZOSMX?(N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,C`P"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(L7?\^_D[_(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DV"FUS9VED(")?3&]G(&]U
M="(*;7-G<W1R("+%[N_D[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN
M:RXN+B(*;7-G<W1R("+4\>_P[_#OW^?SYR#3_>WDY?/L[_4N+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<P"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R("+%\.GK[^/=\B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.`IM
M<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(L7N[_7SZ>_D[_3>\^7I\B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(L3IX>/Q
MX?;>(-/U[>3=\^SO]2XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$P-@IM<V=I9"`B
M7U-E='5P(@IM<V=S='(@(M'UZ.S?\^7I\B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B7U1A
M8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BR>3I_/3G].7R(-#?[>'JX2XN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,`IM<V=I9"`B7U5S97)S(@IM<V=S='(@
M(M?QWO/TY?(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,0IM
M<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(L3IY?7H]>WSZ>_C\=SV[_(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP,PIM<V=I9"`B8V%L
M96YD87(B"FUS9W-T<B`BQ^SE\>_K_./I[R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<P(&QI8B]";&]C:R]M971A<BYP:'`Z,S4V"FUS9VED(")C86QM
M(@IM<V=S='(@(N?QY>S?X2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C8P.`IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("+PX?3>
M\_3E(.7D_B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W
M,`IM<V=I9"`B9FEL92(*;7-G<W1R("+A\??EW^\B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U."!L:6(O0FQO
M8VLO;65T87(N<&AP.C,X-`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<R(*;7-G<W1R("+A\/P@].\@)7,@*"5S*2#S].GR("5S("5S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I
M9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,CD*;7-G:60@(FEM;65D:6%T92(*
M;7-G<W1R("+<[.7SX2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8X(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<V"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
MY>WS^>SA]/GLW>WO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("+C\>'L[-WR72(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU-`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA
M:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,MZOGDZ>K\\B#KW.CO]?(@)60@
MZN'TW"#TYR#DY^SI[_7QX]_A($E33RXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C(X."!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C`V"FUS9VED(")N86UE(@IM<V=S='(@(OSM[^SA(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,N<&AP.C$R,@IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(N3E[2#=]^7I(.7CZN'TX?/TX>CEWR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(T-0IM<V=I9"`B;F]T('EE="!I;7!L96UE
M;G1E9"(*;7-G<W1R("+DY>T@W??EZ2#EX^KA].'S].'HY=\@X>K\[.<B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@Y-0IM<V=I9"`B;F]T97!A
M9"(*;7-G<W1R("+SY^SEZ?GLX?3<\>GO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N
M="(*;7-G<W1R("+T[^GR(.7JX?3\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM
M<V=S='(@(N7IZN_M[_/T[^GWY=_A(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HY.`IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("+E[/;<
M[>GSYR#DZ>'V[_'^[2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,S"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B
M"FUS9W-T<B`B<VUS(//E(&5M86EL(.S=\_D@2%144"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-C0*;7-G:60@(G-T96%D>2(*;7-G<W1R
M("+S].'HY?'\\B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$Y
M"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`BZ]_S].$@Y?'CX?/I_NTB"@IM
M<V=I9"`B=')A<V@B"FUS9W-T<B`BZMSD[_(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C@R"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(L/QW/CTY2#T[^T@ZOGDZ>K\(.3][R#V[_'=\B#CZ>$@Y?#IXN7BX=_Y\^<B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F
M+G!H<#HW-@IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("+E[>_P[^GG[-WMX2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,3<*;7-G:60@(G5N
M;F%M960B"FUS9W-T<B`BX>W^[?7LX2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R.0IM<V=I9"`B=7-E<B!S
M96QE8W0B"FUS9W-T<B`BY?#IZ^_CWB#W\=[S].<B"@IM<V=I9"`B=D-A<F0B
M"FUS9W-T<B`BV.?VZ>'JWB#*W/'TX2(*````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VMO7TM2+G!O````
M````````````````````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V
M-3`P,#,`,3`U,34T,S$P-C,`,#$V,S<V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````",@2V]R96%N('1R86YS;&%T:6]N<R!F
M;W(@:&]R9&4@<&%C:V%G90HC(&AO<F1E(,;0Q;#!]K^A(+3KQ]$@Q]&QN;[N
M(+GXOZJYKBX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!H;W)D92!P86-K86=E+@HC"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P,2TQ,2TP.2`Q-CHR.2LP.3`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($II;FAY;VL@2&5O(#QN;W9E;6)R94!O=7)N871U<F4N
M;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]155#+4M27&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("BT
MW,/@Q;`@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D
M87DI(@IM<V=S='(@(B`HO\"TPRDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*+.[P,\I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY
M97-T97)D87DI(@IM<V=S='(@(B`HON[!IBDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I
M9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`BM?"WNL7DN*XB"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("*_
MP[G9N*4@L,N[]B"Y_,'6N*8@P-2WPL?/O+R_Y"XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(B5S)\#,*+"A*2!(;W)D92"WN<'VO;K&
MKKBNOZ&\K2"\L\&DM<>^[B#`UL'V(+[*O<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S
M='(@(B<E<R>PH2"]P[VZQ=N_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y
M<W1E;2XB"FUS9W-T<B`B)R5S)["A(+W#O;K%V[^A(,/?L*&UQ[[ZO<"TS[39
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T
M(&-R96%T960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("\@)60@*+C>O</!
M]CH@)60I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("+"_,&V(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R#`K\'VL/RXKB#`
MV[[W("T@R*[`SB(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B7"(E<UPBM,(@P,RYS"#`UKW`M,^TV2XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)60@+R`E9"`HN-Z]P\'V.B`E9"DB
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BP?:QW2"\]L?@Q](@P-N^
M]\"[(+RQQ</'S[R\O^0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(UNM`@N+:T
MV2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ
M,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`BQ>O!]B"XKKVZL\H@)7/`NRBXIBD@PZ/`NR"\]B"^^+W`M,^T
MV2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R
M("(E9"`O("5D("BXWKW#P?8Z("5D*2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($%D9')E<W,@0F]O:R(*;7-G<W1R("+!UKS2M\\B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("*TWK?"(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(KSVO<6PQ;K.
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS
M9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A
M<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HW-#D*(RP@9G5Z>GD*;7-G:60@(BTM
M('-E;&5C="`M+2(*;7-G<W1R("*QU,2B*+?\*2"\L<7#(+_`M_DB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@
M1F]R;6%T(@IM<V=S='(@(L&DNK@B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,3D*(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(L&D
MNK@B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@
M:&]U<G,B"FUS9W-T<B`B,C0@O<.PHR(*"B,Z(&9R86UE=V]R:R]522]522]0
M86=E<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R
M("+`S,#\(,;DP,S!]B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS
M9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@
M8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38P"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R("(\8C[$H;CMP/O`SB"_P+?Y(+G?N_TZ/"]B/B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(KJYN^<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ>0IM<V=I9"`B04T@3&EG:'0@
M4F%I;B(*;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,0HC+"!F=7IZ>0IM<V=I9"`B04T@4F%I;B(*
M;7-G<W1R("*PH<#EP-JXKB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS
M9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(K_`P/PO
MO\#(Q"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B
M;W5T('1H:7,@961I=&]R(@IM<V=S='(@(L#,(+^AM?#%S;3"(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("*^QK>A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,@HC+"!F=7IZ>0IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(K"AO^ZUI2(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*(RP@9G5Z>GD*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@HC+"!F=7IZ
M>0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS
M9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED
M(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(L&DNK@B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`BOL_(HR#(KL#.(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"B,L(&9U>GIY"FUS
M9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`BO\"XI\+WO/@B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"B,L(&9U>GIY"FUS9VED(")!
M8V-O=6YT:6YG(@IM<V=S='(@(K_`N*?"][SX(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q
M"FUS9VED(")!9&0B"FUS9W-T<B`BP]^PH2(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@
M1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"B,L(&9U
M>GIY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("*PL\#.
M(+C>P,\B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ
M>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(KOGO^O`VB##W["A(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@X"B,L(&9U>GIY"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`BL+/`SB"XWL#/(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(DQ$05`@O*VY]B#!
MHKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B)7,@L<?'T2"\]L&D(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G
M<W1R("*[];?.O^X@N^>_Z\#:(,/?L*$Z(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`HC+"!F=7IZ>0IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("*_K2"ZT,?2(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(KOUM\Z_[B"[Y[_KP-H@P]^PH3HB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G
M<W1R("+&Y+[N*'!A:7(I(,/?L*$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(B@E<RFXIB#!UKS2M\^_
MH2##W["A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K
M(@IM<V=S='(@(B@E<RFXIB#!UKS2M\^_H2##W["A(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(KOGO^O`VB##W["A
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS
M9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D
M9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R("*[Y[_KP-H@P]^PH2"[Y[_KOLC'U"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(L'6O-(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`BP=:\TK?/(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S
M"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("*P_+BN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S
M(@IM<V=S='(@(L/?L*$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")!
M9F=H86YI<W1A;B(*;7-G<W1R("*TW,.\(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ
M>0IM<V=I9"`B06QB86YI82(*;7-G<W1R("*^\[;SP,R^[KVZ(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R("*^\[;SP,R^
M[KVZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`BOO.V\\#,ONZ]NB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*
M;7-G:60@(D%L:6=N(@IM<V=S='(@(L&DM\0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z
M(@IM<V=S='(@(L&DM\0Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W
M"FUS9VED(")!;&PB"FUS9W-T<B`BN/"USB"\L<7#(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E
M<G,B"FUS9W-T<B`BN-[`SR#`_+3>(+_`M_DZ(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B
M06QL($=R;W5P<R(*;7-G<W1R("*[Z,&F(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R
M964N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BQ>2WT"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S
M='(@(KCPM><@-+CI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`HC+"!F=7IZ
M>0IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B7"(E<UPBM,(@P,RY
MS"#`UKW`M,^TV2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS
M9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`W"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA
M=&4@24U34"!087-S=V]R9"(*;7-G<W1R("*^S\BC(,BNP,XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5
M<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E
M<W,B"FUS9W-T<B`BP-^X^+7((,#,N-[`SR#!UKS2(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!T96UP
M;&%T97,B"FUS9W-T<B`BM.O#O""QVR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT
M97)N871E('1E>'0Z(@IM<V=S='(@(K3KP[P@L=LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(L#?N/BUR""YKL#:L*$@P-:]P+3/M-DN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B
M06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B/&(^Q*&X
M[<#[P,X@O\"W^2"YW[O].CPO8CXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(D%N<W=E<B(*;7-G<W1R
M("+(N+W%Q]$@N-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R
M8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*
M(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(KW'Q^`B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(D%P
M<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BO<?'X"(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(&ES
M(')E861Y+B(*;7-G<W1R("*]Q\?@(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(C2_^2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M
M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")!<F-H
M:79E($YA;64B"FUS9W-T<B`BQ\JUY<#,N*<B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("*PZ+S3(,'XQ^#'
MS[W#L-J]P+3/L>X_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R
M;W5P<S\B"FUS9W-T<B`BP,P@N-Z]P\'VN*8@O[6_^,CW(+OHP:;'S[W#L-J]
MP+3/L>X_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B07)G96YT:6YA
M(@IM<V=S='(@(K[SMO/`S+[NO;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE
M;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS
M9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I
M9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!
M<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<S\B"FUS9W-T<B`BP*_!]K#\N*Z]Q\?@P/P@R*[`SL?/L>(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"B,L(&9U>GIY"FUS
M9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`BOZT@NM#'TB(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(CB_^2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*(RP@
M9G5Z>GD*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(XO_DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"B,L(&9U>GIY"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(CB_^2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B
M"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z
M-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`BP-.]P[JXL/S'U"#`^L#E(+_`M_DN(+RMN?;`QR"_P+?Y
M(+C>O</!]CH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T
M<B`BP-.]P[JXL/S'U"#`^L#E(+_`M_DN(+RMN?;`QR"_P+?Y(+C>O</!]CH@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I
M9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E
M<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H
M7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDP"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A
M=&EO;B!F86EL960B"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,B"FUS9W-T<B`BN-[`SR#`_+3>(+_`M_DZ(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$W-@HC+"!F=7IZ>0IM<V=I9"`B075T:&5N
M=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B
M9G1P(+RMN?8@OZRPX2"_P+?Y+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#4Q"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B9G1P(+RMN?8@OZRPX2"_P+?Y
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B9G1P(+RMN?8@OZRPX2"_P+?Y+B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z
M(@IM<V=S='(@(K"AM,G'T2#'RK7E.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z
M97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I
M9"`B0F%C:V=R;W5N9"(*;7-G<W1R("*YZ+#F(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N
M9"!#;VQO<B(*;7-G<W1R("*YZ+#F(+OVL?(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0F%H86UA<R(*;7-G<W1R
M("+`S+BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R("+`I;C>P,\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM
M<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A<V4@
M9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S
M"B,L(&9U>GIY"FUS9VED(")"87-E;&EN92(*;7-G<W1R("+%J;'B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"B,L(&9U>GIY"FUS9VED(")"96QG:75M(@IM<V=S='(@(L6IL>(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B"FUS9W-T<B`BQ:FQXB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(KO]P,\B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S
M7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
MQ>O!]B"XKKVZL\H@)7/`NRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E
M='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`BL;VPU"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM
M<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R("*PYK#H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS
M9W-T<B`BL.:PZ""USK*R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R
M("*PYK#H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O
M=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*
M;7-G:60@(D)O=&@B"FUS9W-T<B`BN/"USB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S
M='(@(K[&MZ$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R87II;"(*
M;7-G<W1R("+`I;C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*(RP@9G5Z>GD*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(K[SMO/`S+[N
MO;HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(K'BR*,@N*Z]NL:N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3
M(@IM<V=S='(@(D-64R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L
M;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]EO+\@O-.\NBXN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("*TWK?"(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T-@HC+"!F=7IZ>0IM<V=I9"`B0V%L;2(*
M;7-G<W1R("+#Z[S2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-A;65R;V]N
M(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<
M(B5S7"(B"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV
M(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B
M0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR
M,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,B"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*;7-G<W1R("*TWK?"
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BP^N\
MTB(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED
M(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BO\"W^2"ZN+#MQ\^Q
MXB##Z[S2(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W
M:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(DUA:6YT96YA;F-E7U1A<VL@N/"UXB`E<\"[*+BF*2"_K2"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N
M<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(L2X
MO,<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`BR-ZTZ\;Y
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(KR_(+S3
MO+HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("*\OR#&Y+7Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(KR_(+S3O+HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("*\OR"PH[#=(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE
M(@IM<V=S='(@(LC>M.O&^2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V
M"FUS9VED(")#96YT97(B"FUS9W-T<B`BL*&_[K6E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T
M86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")V0V%R9"(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("*ZK[#F
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY
M"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("*^S\BC(,BN
MP,XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*(RP@9G5Z>GD*;7-G
M:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA
M:6QS+B(*;7-G<W1R("*XWL#/P+L@NKBSOK:G(+OGO^O'TB#`S+BG+"#!UKS2
M+""\K;CMP+L@NJ^PYL?5M,^TV2XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")V0V%R9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B7VNXM<6I
M(+#+N^<N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*
M;7-G<W1R("+!IKCQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T
M<B`BP=^QN2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('!A<W-W
M;W)D(@IM<V=S='(@(K[/R*,@R*[`SB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-C@*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('5S
M97)N86UE(@IM<V=S='(@(KC>O</!]B#`V[RZ(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`BO/B\K2"X
MKKVZQJX@P;ZW^2"\L<7#(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N
M<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`BQ>O!]B"XKKVZL\H@)7/`NRBXIBD@PZ/`NR"\]B"^
M^+W`M,^TV2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`BM-ZWPB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*
M;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B35._P,?'O;H@
MQ=>QUR#!]K_LL>(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"B,L(&9U
M>GIY"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("*PR[OVQ]>X\2##RK'B
MR*TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(K#+N_;'U[CQ(,/*L>+(K2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B(*
M;7-G<W1R("*PR[OVQ]>X\2##RK'BR*TB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B!D
M871A(@IM<V=S='(@(K#+N_;'U[CQ(,/*L>+(K2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED(")#
M;&5A<FEN9R!,871E(@IM<V=S='(@(K#+N_;'U[CQ(,/*L>+(K2(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED
M(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L
M:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS
M9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`BPZ(@M-VQXB(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0T"B,L(&9U>GIY"FUS9VED(")#;&]U9',B"FUS
M9W-T<B`BNKF[YR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$V"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T
M<B`BNKF[YR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"B,L(&9U>GIY"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BNKF[YR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*
M;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`BO]["RKBWM.L@M-VQ
MXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(L?5
MP\3!^""PYK#H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0V]L;VUB
M:6$B"FUS9W-T<B`BN_:Q\B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G
M<W1R("*[]K'R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM
M<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X-#8*(RP@9G5Z>GD*;7-G:60@(D-O;&]U<B!S96QE
M8W1I;VXB"FUS9W-T<B`BO+'%P[OGQ]<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S
M='(@(K^M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G
M:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(D-O;6EC
M<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B
M0V]M;6%N9"(*;7-G<W1R("+(N+OG(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(P"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(LBX
MN^<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@
M9G5Z>GD*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`BR+B[YR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"B,L(&9U>GIY"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R("+`S+BG.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L
M(&9U>GIY"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(LBXN^<B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("*[
M]2"XWL#/(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PHC
M+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(K#AM]`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET
M:6]N<R(*;7-G<W1R("*PX;?0(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N
M9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF
M:7)M(%!A<W-W;W)D(@IM<V=S='(@(K[/R*,@R*[`SB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*
M(RP@9G5Z>GD*;7-G:60@(D-O;F=O(@IM<V=S='(@(KG>M,(@N^>V]R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960N(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"B,L(&9U>GIY"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM
M<V=S='(@(F9T<""\K;GV(+^LL.$@O\"W^2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(F9T<""\K;GV(+^LL.$@O\"W
M^2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0HC+"!F=7IZ
M>0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B9G1P(+RMN?8@OZRPX2"_P+?Y+B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*(RP@9G5Z
M>GD*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("+'U[CQ(%PB)7-<(K"A(,'6
MO-*WS[^A(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT
M<R!O9B!<(B5S7"(B"FUS9W-T<B`B)R5S)\#'(+.[O^LB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(K#A
MM]`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"B,L(&9U>GIY"FUS9VED
M(")#;V]K:64B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P
M>2(*;7-G<W1R("*ZN;OG(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D
M.B`E<R(*;7-G<W1R("*[Z,&F(+W'QM`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO
M;B(*;7-G<W1R("*ZN;OG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(C&PL\#'(+OU
MM\Z_[B"XWKW#P?:PH2#`UKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#4S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B,;"SP,<@N_6WSK_N(+C>O</!
M]K"A(,#6O<"TS[39+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,SDS"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BN-Z]P\'V(,#\O-LB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(C&P
ML\#'(+OUM\Z_[B"XWKW#P?:PH2#`UKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*
M;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@
MO<?&T"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B5SN*8@O[&TS[39
M/R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@
M(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R
M("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(KZRL>*PH;3)Q]$@P=:\TK?/P,P@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B2&]R9&6PH2"YV;BCL-0@O+/!I+7'P?8@OLJ^
MTKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M2&]R9&6PH2"YV;BCL-0@O+/!I+7'P?8@OLJ^TKW`M,^TV2XB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`BP-^X^+7((,#,N-[`SR#!UKS2
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR.#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(KZRL>*PH;3)Q]$@P=:\TK?/P,P@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B36%I;G1E
M;F%N8V5?5&%S:R"X\+7B("5SP+LHN*8I(+^M(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@
M9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@
M(B5SN*8@O[&TS[39/R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(E<[BF(+^QM,^T
MV3\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM
M<V=S='(@(B5SN*8@O[&TS[39/R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B5SN*8@O[&T
MS[39/R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DUA:6YT96YA;F-E
M7U1A<VL@N/"UXB`E<R"XIB"_K2"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DUA:6YT96YA
M;F-E7U1A<VL@N/"UXB`E<\"[*+BF*2"_K2"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3
M(+W'QM`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N
M(@IM<V=S='(@(B5SN*8@O[&TS[39/R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C@U"B,L(&9U>GIY"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HBP]^PH<?/M,*UI2"_
MP+?YL*$@N=^[_<??O<"TS[39+B"]P[VZQ=NP_+BNP-J_H;#4(+6UO_+`NR"_
MY,.[Q\^]P['B(+G9MOBTS[39+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!!0TPB"FUS9W-T<B`BOK*QXK"AM,G'T2#!UKS2M\_`S""^^+W`M,^TV2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(W-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`BOK*QXK"AM,G'T2#!
MUKS2M\_`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R("*^LK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("*^LK'BL*&TR<?1
M(,'6O-*WS\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(KZRL>*PH;3)
MQ]$@P=:\TK?/P,P@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D9;"A(+G9N*.PU""\L\&DM<?!]B"^
MRK[2O<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_
MH;RM("=P;W)T)\#,(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0HC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*
M;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,B"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@
MOOB]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"T
MS[39+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M(%PB)7-<(BXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(DUA:6YT96YA;F-E7U1A<VL@N/"UXB`E<\"[*+BF
M*2"_K2"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET
M92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E
ML*$@N=FXH[#4(+RSP:2UQ\'V(+[*OM*]P+3/M-DN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I
M=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F
M;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#$Y"B,L(&9U>GIY"FUS9VED(")#;W5N=&5D('1E>'0B
M"FUS9W-T<B`BL;/!I+7((+FNP-J_K2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38Y"B,L(&9U>GIY"FUS9VED(")#;W5N=')Y(@IM
M<V=S='(@(KOU(+C>P,\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C<S"B,L(&9U>GIY"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(KOU(+C>P,\B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("*XN+7IL>(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`BN+7%J2"XN+7I
ML>(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT
M"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(LC>
MP?;%ZR"[];?.(+BXM>FQXB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@<W5B(&9O
M;&1E<G,B"FUS9W-T<B`BN_7&^K3U(+BXM>FQXB(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&]R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(KOGO^O`VB"QQ\?1(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`HC+"!F=7IZ>0IM<V=I9"`B0W)E9&ET
M(&-A<F0@;G5M8F5R(@IM<V=S='(@(KS]P-HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0HC+"!F
M=7IZ>0IM<V=I9"`B0W)O871I82(*;7-G<W1R("*XN+7IL>(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G
M<W1R("+']L#G(+VZQ;C`SR(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`HC
M+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("+']L#G
M(%523,"Z(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I
M;64N<&AP.C,P"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`BL;/!I+7((+FNP-J_K2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@
M:7,B"FUS9W-T<B`BQ_;`YR!54DS`NB(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("+'
M]L#G(+VZQ;C`SR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("+']L#G(+VZQ;C`
MSR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`BL.&WT"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*
M;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`BQ_;`YR"]NL6XP,\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N(@IM<V=S='(@(DE-4""WSK'7O\*]PR"]P\#;M<>TPB#`V[[WP+L@
MO+/!I,?5M,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("+`VKBC
ML>(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(L#:N*.QXB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y
M<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B
M0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`BM.O'T;G.L;DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS
M9W-T<B`BP,^ZL"(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0HC+"!F=7IZ
M>0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("+`S\#:(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@
M3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y
M.0IM<V=I9"`B1&%T92(*;7-G<W1R("*SK\*E(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D1A=&4@
M4F5C96EV960B"FUS9W-T<B`BO/:]Q2"SK\*E.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,#<*(RP@9G5Z>GD*;7-G:60@(D1A=&4@<V5L96-T
M:6]N(@IM<V=S='(@(L#:N*.QXB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC
M+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(L#/NK`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E]LOZT@N^C!IB(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$
M96-E;6)E<B(*;7-G<W1R("(Q,K_Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA
M;"!N=6UB97)S(@IM<V=S='(@(KS]P-HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E
M;G0B"FUS9W-T<B`BL[N^[KZRL>(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L
M="(*;7-G<W1R("*QXKJ[(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L
M;W(B"FUS9W-T<B`BL>*ZN["J(+OGO^LB"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM
M<V=S='(@(K'BNKL@O<2ZL,#:(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(K'B
MNKLB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*(RP@9G5Z>GD*;7-G
M:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(K'4Q*(@P:3`QR(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T
M92(*;7-G<W1R("*[Z,&F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@0V5L;"(*;7-G<W1R("*\OR"[Z,&F(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!'<F]U<"(*;7-G<W1R("*[Z,&F(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM
M<V=S='(@(L?@(+OHP:8B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("*XWKW#P?8@
MN^C!IB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"B,L(&9U>GIY"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S
M(@IM<V=S='(@(KOHP::UR""XWL#/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E
M;&PB"FUS9W-T<B`BO+\@N^C!IB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU
M;6XB"FUS9W-T<B`BOZT@N^C!IB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L
M971E(')O=R(*;7-G<W1R("+'X""[Z,&F(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(KW$NK#`VB"\L<7#(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@
M(L?VP.<@OZT@P?:_\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(')O=R(*;7-G<W1R("+']L#G(,?@(,'VO_(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G
M<W1R("*[Z,&F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I
M9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`BO\"W^2"\L[CM(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R
M:7!T:6]N(@IM<V=S='(@(KRSN.TZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(KR\NL[!I+JXL*$@L/RXKL#:
MN*8@P*?'V""QXK?/M<>^[L&SO<"TS[39+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@
M(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I
M<F5C=&]R>2(*;7-G<W1R("*U\+>ZQ>2XKB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-C8*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\B"FUS9W-T<B`BR*VXZ2"\L\&D(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BR*VX
MZ2"\L\&D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L
M(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S
M='(@(LBMN.D@O+/!I"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*(RP@
M9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
MR*VXZ2"\L\&D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`BR*VXZ2"\
ML\&D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(KJYL;@B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP(@IM<V=S='(@(FUA:6YT96YA;F-E+G!H<+^A(,'WP:(@
MP:*QV<?/P?8@N+:\O+_D+B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(L.YN?C"L"#'X,"Z(,?7
MN/$@P,RXI\"[(+"NL.T@P-:]P+3/L>X_(+'7M[BTV;CI+""_J;'BN*8@P[S%
MJ<?/O+R_Y#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")$;VUI;FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`BM.O'T;G.L;DB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I
M9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BL[NWP;G>
ML>(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B)7,@
ML[NWP;G>L>(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED
M(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R
M:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(D1R=6=S(@IM
M<V=S='(@(KGZM[FUZ2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(L"EN-[`
MSR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,C4*;7-G:60@(D5D:70B"FUS9W-T<B`BO/;!I"(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN
M8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@HC+"!F=7IZ>0IM
M<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("*[Z,&F(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S:6]N(@IM
M<V=S='(@(K"SP,X@N-[`SR(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S<*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B)7,@L<?'T2"\]L&D(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R
M("*\L<7#N^?'UR"\]L&D.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B)7,@L<?'T2"\]L&D(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T
M<B`B)7,@L<?'T2"\]L&D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U
M"B,L(&9U>GIY"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`BO-*PLR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I
M=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-
M3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE
M;G0N+BXB"FUS9W-T<B`BO^2\TBXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")E
M;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB
M"FUS9W-T<B`BP,RXWL#/(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,L(&9U
M>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(L#,N-[`SR#!UKS2
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*(RP@9G5Z>GD*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("*^
MS\BCL*$@P,_$H<?/P?8@OLJ]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`BL>+%N"#!I+JX(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O
M+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R("+`S+CPQKS$W"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S
M<V%G92XB"FUS9W-T<B`BP=^_Y,?1(+C>P,\B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R
M97-U;'0N(@IM<V=S='(@(K#AL/H@OOC`O2(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS
M9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*(RP@9G5Z>GD*
M;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(K_>PLJXM[3K(,BNP.4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("+&[<']L>(@R*ZTZR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C
M=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U
M(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I
M<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("*Q
MU[BR(%523"#`U+?"(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I
M;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BO\"W^2(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@
M(C$UNM`@N+:TV2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@
M9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("(UNM`@N+:T
MV2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R
M("(S,,/*(+BVM-DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E
M<R(*;7-G<W1R("(UNM`@N+:TV2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S
M='(@(KCPM><@M\ZQU\#.(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(C,PNM`@N+:TV2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(KC%NM`B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA
M;7!L92!V86QU97,Z(@IM<V=S='(@(K^Y.B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN
M<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*(RP@9G5Z>GD*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("*X\+7.(,BNP.4B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G
M<W1R("*_WL+*N+>TZR#(KL#E(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@
M(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R
M"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*(RP@9G5Z>GD*;7-G:60@
M(D5X<&]N96YT(@IM<V=S='(@(K^BO;K&]\:N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@
M0V]L;W(B"FUS9W-T<B`BP/RPYKOV(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@
M(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("+(K[#F
MO+/!I"#`T+'B(+_`M_DN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB
M+B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B3$1!4""\
MK;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3$1!4""_K+#A("5S(+W'QM`B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("),1$%0(+RMN?8@
MP:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V
M93H@)7,B"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"B,L(&9U>GIY"FUS
M9VED(")&86ER(@IM<V=S='(@(L?*Q<TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("+`
MT,'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*
M(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("+`T+[NO\"Q
MXBC`T\;WQJXI(+_`M_DZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("+&T;VZ(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I
M9"`B1F%X97,B"FUS9W-T<B`BQM&]NB(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R
M("(RO_DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("+!IKCQ(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B
MQL3`SR"P_+BNP-HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC
M+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(L?*M>7`S+BG(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0HC+"!F=7IZ>0IM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`BL=3$HBBW_"D@O+'%PR"_P+?Y
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@HC+"!F=7IZ>0IM
M<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`BQ\JUY2(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S
M(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("+'RL7-(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("+#
MH['B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@HC+"!F=7IZ>0IM<V=I
M9"`B1FER<W0@2&%L9B(*;7-G<W1R("+#N<;DP,S!]B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*(RP@9G5Z>GD*
M;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`BP[G&Y,#,P?8B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED
M(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@
M(D9O;G0@0V]L;W(B"FUS9W-T<B`BL=O`VB"[]K'R(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-@HC+"!F=7IZ>0IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@
M<W5P<&]R="!I;6%G97,B"FUS9W-T<B`BNNJV\[_LP/JPH2#`S""QXK3)P+L@
MP?:_^,?/P?8@OLJ]P+3/M-DN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@
M1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS
M(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C
M;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@HC+"!F=7IZ>0IM<V=I9"`B
M1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(K[/R*,@R*[`SB(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*(RP@9G5Z>GD*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(L"GQ*$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BPOS!MB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B
M1F]R='5N92!T>7!E(@IM<V=S='(@(L+\P;8B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@
M(L+\P;8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`BPOS!MB(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-3,*(RP@9G5Z>GD*;7-G:60@(D9O<G5M<R(*
M;7-G<W1R("*XWL#/Q]0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3`Y"B,L(&9U>GIY"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("+`_+3>(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`HC
M+"!F=7IZ>0IM<V=I9"`B1G(B"FUS9W-T<B`BP*?$H2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@
M(D9R86UE<R(*;7-G<W1R("+'P;>YP-,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`BP^N\TB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN
M97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM
M<V=S='(@(L"GQ*$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@HC+"!F=7IZ>0IM<V=I9"`B1G)O
M;2!T:&4@(@IM<V=S='(@(L"GQ*$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO
M;B(*;7-G<W1R("+`_,.\(+RSN.TZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B
M1G5L;"!.86UE(@IM<V=S='(@(L#,N*<Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@
M(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(KC>P,\@O*VY]B#!I+JXN^?'UR(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T
M960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T
M<B`BM;;`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=H86YA(@IM
M<V=S='(@(L'?L;DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S4*(RP@9G5Z>GD*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`BQ\JUY<#,
MN*<B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B
M"FUS9W-T<B`BL*&QXB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM
M<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G
M;&4@36%P<R(*;7-G<W1R("*PR[OVQ]>X\2##RK'BR*TB"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")';V]G;&4@4V5A
M<F-H(@IM<V=S='(@(K#+N_;'U[CQ(,/*L>+(K2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E
M:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ
M>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("+`
MT,'V(+[*P+H@N-[`SR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"B,L(&9U
M>GIY"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*P_+BN
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`BP-.]P[JXL/S'
MU"#`^L#E(+_`M_DN(+RMN?;`QR"_P+?Y(+C>O</!]CH@)7,B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")6
M1E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"B,L
M(&9U>GIY"FUS9VED(")'=6%M(@IM<V=S='(@(C:_^2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B1W5E<FYS97DB"FUS
M9W-T<B`BM;;`SR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*(RP@9G5Z>GD*;7-G
M:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(KC>O</!]B"[Z,&F(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC+"!F=7IZ>0IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(L'6O-*WSR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@
M9G5Z>GD*;7-G:60@(D=U:6YE82(*;7-G<W1R("(VO_DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@*(RP@9G5Z>GD*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B-K_Y
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B-K_Y(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED
M(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*(RP@9G5Z>GD*
M;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("*[Z,&F(+W'QM`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@
M(DAA>F4B"FUS9W-T<B`BQ^RUY;;SP,XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@HC+"!F
M=7IZ>0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(L?LM>6V\\#.(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ
M>0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("+'[+7EMO/`SB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX
M.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S
M='(@(K/TP,PB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BM;6_\KB[(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L
M<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`BM;6_\KB[(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(K6UO_*XNR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0HC+"!F
M=7IZ>0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("*UM;_RN+LB"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.B(*;7-G<W1R("+&Q,#/P,<@O</`V\#,(+39P+VP^B"PL+W`
MM,^TV3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.0HC+"!F=7IZ>0IM<V=I9"`B2&EG:"(*;7-G<W1R("*S],#,(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(L'](,'6
MO-(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*(RP@9G5Z>GD*;7-G
M:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(K7PM[K%Y+BN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B
M2&]M92!0:&]N92(*;7-G<W1R("+!_2#`_,BMN?C(HR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U
M;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@
M;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S(%PB)7-<(B(*;7-G<W1R("*XWL#/Q]0@7"(E<UPBP,P@7"(E<UPB
MM\X@NJ^PYK7'OOJ]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R("*XWL#/Q]0@7"(E<UPBP,P@7"(E<UPB
MM\X@NJ^PYK7'OOJ]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3$Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@
M(EPB)7-<(B"XWL#/Q]3`NR"[Y[_KQ]6TS[39+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S(@IM<V=S='(@(EPB)7-<(B"XWL#/Q]3`NR"[Y[_KQ]6TS[39+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BO/;&\KRQ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(K"AM\X@PZ2_
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(K"AM\XZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("+'U<2AL.T@O<W`NB"_
MK<#'(+SV(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G
M:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G
M<W1R("+'U[CQ*+^M*<#'(+SV/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(L?5Q*&P[2"]
MS<"Z(,?@P,<@O/8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y
M"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
MN-[`SR#`_+3>(+_`M_DZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(KC>P,\@P/RTWB"_
MP+?Y.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z
M>GD*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`BP=:\TB(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*(RP@9G5Z>GD*;7-G:60@
M(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BP,R_Z["AM,G'
MT2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B
M25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G
M:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")?;K[5OZ$@Q^`@P]^P
MH2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B26-E;&%N9"(*;7-G
M<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`BOL;`S,3<(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B)7._H;#4(+S2L+,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H
M('1E>'0B"FUS9W-T<B`BOL;`S,3<L/H@N:[`VB(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T
M<B`BO<2ZL,#:(,#,N*<Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO
M="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W
M('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B
M"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("*QU[BR
M(+G,N*ZZN+'B.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("*Q
MU[BR(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R
M("*QU[BR(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@
M9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V,0HC+"!F=7IZ>0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@
M(L?*M>4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PHC+"!F=7IZ>0IM
M<V=I9"`B26UA9V5S(@IM<V=S='(@(K'7N+(@55),(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(K"AP:Z_P+'B+""TW+#H("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(K"AP:Z_
MPB#'U[CQ.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*
M;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BL*'!KK_"(,?7N/$Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")?
M<[39P+V_H2#'X"##W["A(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E
M8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("*[Y[_KP-K`
MS+BGL/H@OL_(H[BF(,#4M\+'S[R\O^0B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"B+#W["AQ\^TPK6E(+_`M_FPH2"YW[O]Q]^]
MP+3/M-DN(+W#O;K%V[#\N*[`VK^AL-0@M;6_\L"[(+_DP[O'S[W#L>(@N=FV
M^+3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(K7IOZF^
MLK'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q"B,L(&9U>GIY"FUS9VED("));F1I82(*;7-G
M<W1R("*^^,"](@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY
M"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`BOOC`O2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(DEN9F\B"FUS9W-T<B`BN:N]PR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3<*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S
M='(@(L&DNK@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P
M"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R
M(")?;[39P+V_H2"_K2##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@
M26UA9V4B"FUS9W-T<B`BL=>XLB##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE
M(@IM<V=S='(@(L>E(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS
M9W-T<B`BP*4@N+7%J2##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O
M;'5M;B!"969O<F4B"FUS9W-T<B`B7V.^U;^A(+^M(,/?L*$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*
M;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(L?VP.<@OZT@M=J_H2"[]2"_K2##W["A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`BQ_;`YR"_K2"^U;^A(+OU(+^M(,/?L*$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(L?VP.<@Q^`@M=J_H2"[]2#'X"##W["A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`BQ_;`YR#'X""^U;^A(+OU(,?@(,/?L*$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*
M;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E(@IM<V=S='(@(L?VP.<@P?;!H2"UVK^A(+3<MO0@P]^PH2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(L?VP.<@P?;!H2"^U;^A(+3<MO0@P]^PH2(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(K3KP[P@L=LB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA
M:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P
M87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@
M869T97(B"FUS9W-T<B`BM=J_H2"\OR##W["A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS
M97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(K[5OZ$@O+\@P]^PH2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*
M;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`BM=J_H2"_K2##
MW["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T
M<B`BOM6_H2"_K2##W["A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M97-S86=E
M<R(*;7-G<W1R("+(N+W%Q]$@N-[`SR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T
M('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("*UVK^A(+3<MO0@P]^PH2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B
MOM6_H2"TW+;T(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R
M(@IM<V=S='(@(K7:OZ$@Q^`@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R
M;W<@8F5F;W)E(@IM<V=S='(@(K[5OZ$@Q^`@P]^PH2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM
M<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("*QU[BR(,/?L*$O
MO/;!I"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("*XM<6I
M(,/?L*$OO/;!I"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0HC+"!F=7IZ>0IM<V=I9"`B
M26YT96=E<B(*;7-G<W1R("*PH;_NM:4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R
M("+`W[CXM<@@P,RXIRXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R
M("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3(*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M8F%T8V@@240N(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!D
M871A('-U8FUI='1E9"XB"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM
M<V=S='(@(L#?N/BUR"#`S+C>P,\@P=:\TB(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HR,C`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M9FEL92!F;W)M870B"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BP-^X^+7(
M(,#,N*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&US9U]T>7!E
M+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(L#?N/BUR"#`
MS+BG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BP-^X^+7((,'6O-*WSR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`BP-^X^+7((,'6
MO-*WSR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("+`
MW[CXM<@@P=:\TK?/(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`V"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R("+`W[CXM<@@P=:\TK?/(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,C8R"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-H87)E(&]B
M:F5C="(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(L#?N/BUR"#`
MS+C>P,\@P=:\TB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!U;FEC
M;V1E(&1A=&$N(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<Y"B,L(&9U>GIY"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@
M(L#:N*.QXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("*TZ\?1N<ZQN2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M(RP@9G5Z>GD*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>
MP,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B
M27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B27-R
M865L(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("*QXK_OP,RQXB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`BP,^ZL"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N
M=6%R>2(*;7-G<W1R("(QO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N
M(@IM<V=S='(@(L#/NKLB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("+`S[J[ONX@
M*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N
M('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES
M<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU
M;'DB"FUS9W-T<B`B-[_Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B-K_Y(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("+!I+?$(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@
M(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(K"AO^ZUI2#!I+?$(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*
M;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("*^Y\+*(,&DM\0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(K_>PLH@P:2WQ"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(K_`N*7"RB#!I+?$
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*
M;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0HC+"!F
M=7IZ>0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(L2XO,<B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&
M:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+
M97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S
M='(@(KC>O</!]B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<T,`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`
MM_DN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("*TZ\?1
MN<ZQN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(K3KQ]&YSK&Y(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("+'T;&YONX@*$55
M0RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"B,L(&9U>GIY"FUS9VED
M("),85]Y;W5T(@IM<V=S='(@(K?.L=>^QK_T(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BOO"^
M[B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(KBVP?:X
MMR#&Y,#,P?8B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z
M>GD*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(K[/R*,B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@X"B,L(&9U>GIY"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`BN+;!
M]KBW(,;DP,S!]B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"B,L(&9U
M>GIY"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(KBVP?:XMR#&Y,#,
MP?8B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BN+;!]KBW(+?.
ML=?`SCH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G
M<W1R("*XML'VN+<@M\ZQU\#..B`E<RP@P:*\TR#`I\2A.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@
M3F5V97(B"FUS9W-T<B`BN+;!]KBW(+?.L=?`SCH@OOC`O2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0HC+"!F=7IZ>0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(KBXM>FQXB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(K>YP,R^QK_T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM
M<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS
M9VED("),969T(@IM<V=S='(@(K_>PLHB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$Y"B,L(&9U>GIY"FUS9VED("),969T(&AE861E<B(*;7-G
M<W1R("*_N3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L
M(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("*_N3HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E
M;"(*;7-G<W1R("+`S+6_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@
M2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI
M96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(DQI9VAT($1R
M:7IZ;&4B"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A
M:6XB"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6X@
M16%R;'DB"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A
M:6X@3&%T92(*;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@
M4F%I;B!3:&]W97(B"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*(RP@9G5Z>GD*;7-G:60@(DQI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"B,L(&9U>GIY
M"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H
M="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB
M"FUS9W-T<B`BM\ZQU\#.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T
M;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S
M92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"B,L(&9U
M>GIY"FUS9VED("),:6YK<R(*;7-G<W1R("*WSK'7P,X@O</`V\#;OO<B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(DQI
M;G5X($-O;VMI92(*;7-G<W1R("*[]2"XWL#/(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED("),:7-T($1A=&%B87-E<R(*
M;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BM;6_
M\K[+(+CQPO<B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"B,L(&9U>GIY
M"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*(RP@9G5Z
M>GD*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("*[Y[_KQ\_!]B"^RK3"
M(+C>P,_'U""\^['H(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("*U
MM;_ROLL@N/'"]R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DV"B,L(&9U>GIY"FUS9VED("),:7-T+4ED(@IM<V=S='(@(K6UO_*^
MRR"X\<+W(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3(*(RP@9G5Z>GD*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`BM;6_\K[+
M(+CQPO<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"B,L(&9U>GIY"FUS9VED("),:7-T
M+5-U8G-C<FEB92(*;7-G<W1R("*[Y[_KQ\_!]B"^RK3"(+C>P,_'U""\^['H
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*(RP@
M9G5Z>GD*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`BN^>_Z\?/
MP?8@OLJTPB"XWL#/Q]0@O/NQZ"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N
M<R!F86EL960Z("5S(@IM<V=S='(@(KOGO^O'TB"\]B"^^+3"(+OGO^O`VB"X
M\;?/+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S
M='(@(KOGO^O'TB"\]B"^^+3"(+OGO^O`VB"X\;?/+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BN^>_Z\?2(+SV(+[XM,(@N^>_Z\#:
M(+CQM\\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"B,L(&9U>GIY
M"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(KRMN.TZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"B,L(&9U>GIY"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`BL\JZ\2"T
MW,"G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"B,L(&9U>GIY"FUS9VED("),;V-A
M;"!T:6UE.B`B"FUS9W-T<B`BO<?'X"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`BO<?'X"(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*
M;7-G<W1R("*WSK'7P,XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM
M<V=I9"`B3&]G(&]U="(*;7-G<W1R("*WSK'7OL:_]"(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`BM\ZQU\#.(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I
M9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BM\ZQU\#.(+W#P-O`V[[W(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV"B,L(&9U>GIY"FUS9VED("),
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B*^[K:R(,#,
MP*^WSB"WSK'7P,[`S""]Q\;0Q]^]P+3/M-DN(+3KNLZZT,#'(+#FO^P@N^>_
MZ\#:(,#,N*<@ML>TPB"^S\BCL*$@P-\B"B*X^"#`U+?"M<@@L.:_[""YW[O]
MQ]6TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@HC+"!F
M=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("*[Z,&F(+W'QM`B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS
M9VED("),;VYG('1E>'0B"FUS9W-T<B`BM\ZQU[[&O_0B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(DQO=F4B"FUS9W-T
M<B`BP,RUOR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("*QU[BNO;H@O-*YKL#:(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("*V
M\\:^(+S2N:[`VB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`BM\ZXMB"\TKFNP-H@O/W`VB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@HC+"!F=7IZ
M>0IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R("+&Q,#/OZ$@OL:YJ[>Q(,#:M^&PH2"^^+W`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")-4T<B"FUS9W-T<B`B
M0U93(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86-A;R(*;7-G
M<W1R("(SO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*
M;7-G<W1R("+`I;C>P,\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`BN-[`SR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(E]KN+7%
MJ2"XN+7IL>(N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA
M;&%W:2(*;7-G<W1R("+`I;C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*
M;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(L"EN-[`SR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`HC+"!F=7IZ>0IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`BN-[`SR#'RL7-
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@
M(L"EN-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B
M"FUS9W-T<B`BP*6XWL#/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ
M"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@
M:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I
M9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U
M"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C
M:"(*;7-G<W1R("(SO_DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B
ML*'`Y<#:N*XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS
M"B,L(&9U>GIY"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(K"AP.7`VKBN
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA
M=&-H:6YG(&9I96QD<R(*;7-G<W1R("+`S\2AQ\^TPB#'U[CQ(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(K"A
MP.7`VKBN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`HC+"!F=7IZ>0IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N(@IM<V=S='(@(KC>O</!]B#'U[CQ(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B
M36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-CD*;7-G:60@(DUA>2(*;7-G<W1R("(UO_DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L
M(&9U>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(C6_^2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B365D:6-I;F4B
M"FUS9W-T<B`BN^C!IK7((+C>P,\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S
M='(@(C$QO_DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED
M(")-96YU(&UO9&4Z(@IM<V=S='(@(KC>M+H@N/"UY2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@
M(DUE<F=E(&-E;&QS(@IM<V=S='(@(KR_(,?5Q*&QXB(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")-97-S86=E(@IM<V=S='(@(KC>O</!]B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(KC>O</!
M]B#'U[CQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!T>7!E(@IM<V=S='(@(KC>O</!]B#`S\#:(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@O+'%
MP[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q
M,@HC+"!F=7IZ>0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`BO+RZSL&DNKBPH2"P_+BNP-JXIB#`I\?8(+'BM\^U
MQ[[NP;.]P+3/M-DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L
M;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@
M(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI
M9&1L92(*;7-G<W1R("*PH;_NM:4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y
M"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M("*_P+?Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-
M:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`T"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S
M='(@(KC>O</!]B#`S+6_Q\^QXB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*(RP@
M9G5Z>GD*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`BN-Z]
MP\'V(,#,M;_'S['B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B36\B"FUS9W-T<B`BP,RU
MOR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`HC+"!F=7IZ>0IM
M<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E
M<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G
M:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B55),(+SVP:0B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PHC+"!F=7IZ>0IM<V=I9"`B
M36]D=6QU<R(*;7-G<W1R("*_JL?2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"B,L(&9U>GIY
M"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("*TZ\?1N<ZQ
MN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B36]N86-O(@IM<V=S
M='(@(C._^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B
M36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G
M<W1R("*XQ;_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`HC+"!F=7IZ>0IM<V=I
M9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("*ZN;OG(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3
M=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("*^QK>AM\X@
MP,RUOR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q
M,PHC+"!F=7IZ>0IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(L"GM\X@P,RU
MOR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PHC
M+"!F=7IZ>0IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("*_P+BEPLHB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`BP*>WSB#`S+6_(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`HC+"!F=7IZ>0IM<V=I9"`B
M36]V92!D;W=N(@IM<V=S='(@(K[&MZ&WSB#`S+6_(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"B,L(&9U>GIY"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(L"GM\X@P,RUOR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"B,L(&9U
M>GIY"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BL=3$HBBW
M_"D@O+'%PR"_P+?Y(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("*_P+BGPO>\
M^"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I
M9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("+!I+JX(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*
M;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"B,L(&9U>GIY"FUS9VED(")->6%N;6%R(@IM<V=S='(@(L#,N*<B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM
M<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(L#,
MN*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYE<&%L(@IM<V=S='(@(KOU(+C>P,\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYE=&AE<FQA;F1S(@IM
M<V=S='(@(KOU(+C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N
M9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM
M<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B
M3F5T=V]R:R(*;7-G<W1R("*SU\:NO_;%J2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(KOGO^N^R,?4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L
M961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BN-Z]P\'V(,#;O+H@*"5S*2(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B3F5W($UO
M;VXB"FUS9W-T<B`BN_4@N-[`SR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S4*(RP@9G5Z>GD*;7-G:60@(DYE=R!5<V5R;F%M92`H
M;W!T:6]N86PI(@IM<V=S='(@(K6UO_*XNR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(K[/R*,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE
M=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED
M(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("*^S\BCL*$@
MP,_$H<?/P?8@OLJ]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK
M*2(*;7-G<W1R("*[]2##HBA?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS
M9W-T<B`BN_4@N-[`SR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B
MM-G`O2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("*TV<"](,;DP,S!]B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO
M;G,B"FUS9W-T<B`BO\F\Q\"XM\X@M;F^QK"AL>(B"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS
M9W-T<B`BM-G`O2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B
M"FUS9W-T<B`BN^>_Z[[(Q]0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G
M:60@(DYI9V5R:6$B"FUS9W-T<B`BN^>_Z[[(Q]0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"B,L(&9U>GIY"FUS9VED(").:6=H="(*
M;7-G<W1R("*_P+BEPLHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@
M(DYI=64B"FUS9W-T<B`BPOS!MB(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(K[&M,^_
MP"(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I
M9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(E-13"#`SL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-H86YG92XB"FUS9W-T<B`BNJ^PYKOGQ]<@M<>UN;BNL>(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-S<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S
M='(@(E-13"!61E,@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@
M(D944"!61E.XIB#`I\?1(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G
M<W1R(")344P@5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RXB"FUS9W-T<B`B4U%,+49I;&4@5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*
M(RP@9G5Z>GD*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R("*[]2"XWL#/(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#<W"B,L(&9U>GIY"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S
M='(@(L?*M>4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@
M(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@
M:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`BQOJT];BF(+RQQ</'S[R\O^0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PHC+"!F=7IZ>0IM
M<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`BN_4@N-[`SR(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,V"B,L(&9U>GIY"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T
M<B`BN:[`VK^M(,#4M\(@O\"W^2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("*YKL#:OZT@P-2WPB"_P+?Y(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]H='1P+G!H<#HY,0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"#`
MSL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")3
M44P@P,[!]2"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H
M<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\L\&D
MP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S
M<W=D+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"#`
MSL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.C@T"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@
MP,[!]2"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T
M:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R
M>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(L&FN/$@OOC`O2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(L+\P;8B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*(RP@9G5Z>GD*
M;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(KFNP-J_
MK2#`U+?"(+_`M_DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*
M;7-G<W1R("+"_,&V(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.#,*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("+"_,&V
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(KOGO^O`VL#,N*>P^B"^S\BCN*8@
MP-2WPL?/O+R_Y"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY
M,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P
M.0HC+"!F=7IZ>0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(L+\P;8B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM
M<V=I9"`B3F]N92(*;7-G<W1R("*\L<7#Q\_!]B"^RL"](@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N
M92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO
M;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B
M3F]R=V%Y(@IM<V=S='(@(L#\M-XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM
M<V=S='(@(L#3O<.ZN+#\M<?!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0HC+"!F=7IZ>0IM<V=I9"`B3F]T
M($)E9F]R92(*;7-G<W1R("+`T[W#NKBP_+7'P?8@OLK`NB"XWL#/(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"B,L(&9U>GIY"FUS9VED
M(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`BM?"WNL7DN*XB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3F]T(&EM<&QE;65N
M=&5D+B(*;7-G<W1R("*[Z,&FM<?!]B"^RL"Z(+C>P,\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS
M9VED(").;W0@<V5T(@IM<V=S='(@(L&FN/$@OOC`O2(*"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"B,L(&9U>GIY"FUS9VED(").;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R("*[Z,&FM<?!]B"^RL"Z(+C>P,\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(L+\P;8B"@HC.B!S97)V
M:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`B,3&_^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*
M(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R("(Q,;_Y(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0HC+"!F=7IZ>0IM<V=I9"`B3G5M
M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BQ^#`QR"\]B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("*_K<#'(+SV(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU
M;6)E<B!O9B!R;W=S(@IM<V=S='(@(L?@P,<@O/8B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U
M>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T<B`BP::X\2(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$Q"B,L(&9U>GIY"FUS9VED(")/8FIE8W0@
M0W)E871O<B(*;7-G<W1R("+!IKCQ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$P-`HC+"!F=7IZ>0IM<V=I9"`B3V-T86PB"FUS9W-T<B`BP,^Z
ML"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(C$PO_DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*(RP@9G5Z>GD*
M;7-G:60@(D]F9FEC92(*;7-G<W1R("+!IKCQ(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R
M9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A
M<W-W;W)D(@IM<V=S='(@(K[/R*,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N
M;W0@8V]R<F5C="XB"FUS9W-T<B`BOL_(HR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P
M<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*(RP@9G5Z>GD*;7-G:60@
M(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`BP-^X
M^+7((,#,N-[`SR#!UKS2(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M
M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`BN_4@PZ*_H2"XM<6I(+^ML>(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E
M<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)
M344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(KOU(,.BOZ$@N+7%J2"_
MK;'B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R
M871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`BO+'%P[OG
MQ]<B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B)7,@O+'%P[OGQ]<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B
M"FUS9W-T<B`BO/W`VB"X\;?/(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("*T
MW,.\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*
M(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
MM-S#O"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*(RP@9G5Z
M>GD*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`BM-S#O"(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("*QXL6X(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I
M;VXB"FUS9W-T<B`BL>+%N"#!I+JX(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`BN^>_Z\#:(+''Q]$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A;2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("*[Z,&F(+W'QM`B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G
M:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"B,L(&9U>GIY"FUS9VED(")0
M1U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`BO*VX[3HB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#
M;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P
M"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(E!-
M($QI9VAT(%)A:6XB"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS
M9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R
M("+&Y+7Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")086MI<W1A
M;B(*;7-G<W1R("*ZV<#,L>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"B,L(&9U>GIY"FUS
M9VED(")086QA=2(*;7-G<W1R("+`I;C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S
M='(@(L#,N*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN
M96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T
M<B`BNKF[YR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(K[/R*,B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D
M(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z>GD*;7-G:60@
M(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("*^S\BC(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"B,L(&9U>GIY"FUS9VED(")0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("*QXL6X(,&DNK@B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*
M;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("*^S\BC(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D
M.B`B"FUS9W-T<B`BOL_(HR(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R("*^S\BCL*$@P,_$H<?/P?8@OLJ]P+3/M-DN(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@
M(KK9P,RQXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@
M(L6LN+.ZN+7EOZ&\K2"ZV<#,L>(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(K#F
MM\XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B
M4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R("*_
MJL?2(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`BQMN\OL:N(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@
M(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+`K\'V
M(+#\N*X@P-N^]R"]Q\?@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+`K\'V(+#\N*X@P-N^]R"]Q\?@(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`BL+/`SB"XWL#/(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@
M(KW$NK#`VB!<(B5S7"(@L*$@N^C!IK7'OOJ]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G
M<W1R("+%Y+?0(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP
M:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC+"!F=7IZ>0IM<V=I
M9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`BL/RXKB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@
M26YF;W)M871I;VXB"FUS9W-T<B`BL+/`SB#!I+JX(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-0HC+"!F=7IZ>0IM<V=I9"`B4&5T<R(*;7-G<W1R("+'R+R_(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R("+`_,BMN?C(HR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I
M9"`B4&EX96QS(@IM<V=S='(@(L?(O+\B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM
M<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H
M:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4W,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BN_6WSK_N(,#,N*?`NR#`U+?"Q\^\
MO+_D.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")<7&Z[];?.O^X@N-[`S\?4
MP,<@P,RXI\"[(,#4M\+'S[R\O^0Z7%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`BO\.YV;BE(+#+N_8@N?S!UKBF
M(,#4M\+'S[R\O^0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0HC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BO\.YV;BE(+#+
MN_8@N?S!UKBF(,#4M\+'S[R\O^0N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("*YKL&FOZ$@M.O'T2"_Y+[@P+L@
MP-2WPL?8(,'6O+R_Y"XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@
M(KOGO^O`VL#,N*>P^B"^S\BCN*8@P-2WPL?/O+R_Y"(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE
M(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*(RP@9G5Z
M>GD*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB
M"FUS9W-T<B`BN_6WSK_N(,#,N*?`NR#`U+?"Q\^\O+_D.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(LBXN^<B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*(RP@
M9G5Z>GD*;7-G:60@(E!O;&QS(@IM<V=S='(@(K^M.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0HC+"!F
M=7IZ>0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R
M("+'I<#'(+/*NO$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED
M(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S
M:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E
M(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S4*(RP@9G5Z>GD*;7-G:60@(E!R97-S=7)E.B`B
M"FUS9W-T<B`BOL_(HR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S
M='(@(KG,N*ZZN+'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BN_4@PZ*_H2"YS+BNNKBQ
MXB(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0
M<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(L#,P/P@N-Z]P\'V(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B
M4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`BN:Z\K2#`SKSB(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(KFNP:8@
MN=^[_3\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R
M;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BN:[!IB"\L[CM(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#4*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S
M='(@(K&SP:2UR""YKL#:OZTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U
M8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN
M9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"B,L(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R("+`S\#:(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*
M(RP@9G5Z>GD*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("*]P["C
M(+RSP:0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B(*;7-G<W1R("*PH<#EP-JXKB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS
M9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*(RP@9G5Z>GD*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(L+\P;8B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(L2XO,<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"(*;7-G<W1R("+`T,'V
M(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S
M='(@(KOU(+C>P,\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(KBV
MP?:XMR"X[;?)(+G=NKDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5F
M<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`BN-[`S\?4(+OUM\X@P-"QXCHB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,U"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R("+`Y[RSP:0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO
M;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>
MP,\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"B,L
M(&9U>GIY"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("*\L<7#M<@@
MN-[`SR"[Z,&F(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T
M"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`BQN2^[BAP86ER*2"[
MZ,&F(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`BO+'%P[7((+C>P,\@
MN^C!IB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-3<*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B
MOL:WH;?.(,#,M;\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN
M9R(*;7-G<W1R("*^QK>AM\X@P,RUOR(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+&Y+[N
M*'!A:7(I(+OHP:8B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS
M9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@=&AE(@IM<V=S='(@(KRQQ<.UR""XWL#/(+OHP:8B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B
MQN2^[BAP86ER*2"[Z,&F(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@
M=7-E<CH@)7,B"FUS9W-T<B`BQN2^[BAP86ER*2"[Z,&F(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@
M9G5Z>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"XB"FUS9W-T<B`BO*VX[<"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,
M(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93(+RS
MP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&
M:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]2
M96YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I
M9"`B4F5S970B"FUS9W-T<B`BP-2WPB##Z[S2(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W
M;W)D(@IM<V=S='(@(K[/R*,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*
M;7-G<W1R("*^S\BC(,BNP,XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P
M"B,L(&9U>GIY"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B
MN+;!]KBW(,;DP,S!]B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"B,L(&9U
M>GIY"FUS9VED(")297-U;'1S(@IM<V=S='(@(K#+N_8@L.&P^B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
MO\F\Q\"XM\X@M;F^QK"AL>(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B
M"FUS9W-T<B`BOL_(HR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")2979E<G0@
M0V]N9FEG=7)A=&EO;B(*;7-G<W1R("*XWL#/(+RMN?8@P:2ZN+OGQ]<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`BO\F\Q\"XM\X@M;F^
MQK"AL>(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*(RP@9G5Z>GD*
M;7-G:60@(E)I9&1L97,B"FUS9W-T<B`BL*&_[K6E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2
M:6=H="(*;7-G<W1R("*_P+BEPLHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ>0IM<V=I9"`B
M4FEG:'0@=F%L=65S(@IM<V=S='(@(K^Y.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?
M=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]WQ^`@O-.\NBXN+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@
M(E)O;&4B"FUS9W-T<B`BOZK'TB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O
M;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R
M"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("+`I[?.(,#,
MM;\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I
M9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`BQ^`@O-.\NB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G
M:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(L?@(+S3O+HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B
M4F]W<SHB"FUS9W-T<B`BQ^`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L
M97,B"FUS9W-T<B`BOZK'TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B
MM-ZWPB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U
M"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*
M(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R("*XWKW#P?8@P/R\VR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3
M($UE<W-A9VEN9R(*;7-G<W1R("*XWKW#P?8@NKBQXB(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T
M96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM<V=S='(@(L#ZP.4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("*PL,"Z(,?!M[G`TRA?<V5L9BDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@
M(K"AP.7`VKBN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD
M(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED
M(")3879E(@IM<V=S='(@(L#ZP.4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R("*TV;BEP,RXI\"XM\X@P/K`Y2(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(K39N*7`S+BGP+BWSB#`^L#E
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/
M<'1I;VYS(@IM<V=S='(@(KRQQ<.[Y\?7(,#ZP.4B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@O+/!I"#!
MI+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B
M4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(K#+
MN_8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"B,L(&9U>GIY
M"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("*PR[OV(+#AL/HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@1FEL97,B"FUS9W-T<B`BN/"USB"\L<7#(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("*]Q+JPP-H@O+'%PR(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`BN:[`VK^M(+RQQ<,Z
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(KRQQ<,@P^N\TB(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(KFNP-J_K2"\L<7#.B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("*YKL#:OZT@O+'%
MPSHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<W"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(KCPM<X@
MO+'%PR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R
M("*SK\#:(,?\O<0@O+'%PR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!O
M8FIE8W0B"FUS9W-T<B`BO+'%PR##Z[S2(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&YO;F4B"FUS9W-T<B`BO+'%PR##Z[S2(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS
M9W-T<B`BOL:WH2"[\\#:OZ&\K2#'RK_DQ]$@N:[`VKBF(+RQQ</'S[#M(+JY
MN^?'S[^I(+K9OZFSUL"XO+R_Y"XB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS
M9W-T<B`BLZ_`VB"QN+K0QZ6]PR"\L<7#.B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R("*SK\#:(,?\O<0@O+'%PR(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("+`T\;W
MQJ['TB#`I\2A(+RQQ<,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M(@IM<V=S='(@(K.OP-H@L;BZT,>EO<,@O+'%PSHB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA
M=#HB"FUS9W-T<B`BO<.PHR#'_+W$(+RQQ<,B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RXB"FUS9W-T<B`BM<ZPL\#'(,#/Q*''S[3"(,?7N/$@O+'%PR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R
M(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E.B(*;7-G<W1R("+`VL'6N^>_Z\?/M,(@OO"^[KBF(+RQQ</'S[R\O^0N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@
M(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BN:[!IKG?N_T@NKBP[;RM
M(,#\O-O'S['B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,SD*(RP@9G5Z>GD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(KC>O</!]B#`_+S;(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@HC+"!F=7IZ
M>0IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(,&FN/$Z("(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T
M96UB97(B"FUS9W-T<B`B.;_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0HC+"!F=7IZ>0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("*\
M_<#:(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0HC+"!F
M=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`BP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S
M<VEO;B!!9&UI;B(*;7-G<W1R("*P_+BN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"B,L(&9U>GIY"FUS9VED
M(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(KC>O</!]B#'U[CQ(@H*
M(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R("+%Y+?0(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-`HC+"!F=7IZ>0IM<V=I9"`B4V5T(@IM<V=S='(@(KC>O</!]B"\L<7#(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G
M:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`BQN3`S,'V(+"[O<7!UK'B(+G7(+'B
MQ;@@R*VXZ2"\L\&DP+L@Q\^\O+_D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(L;DP,S!]B"P
MN[W%P=:QXB"YUR"QXL6X(,BMN.D@O+/!I,"[(,?/O+R_Y"XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")3971U<"(*
M;7-G<W1R("*XWKW#P?8@O+'%PR(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y-@HC+"!F=7IZ>0IM<V=I9"`B4VAO<'!I;F<B
M"FUS9W-T<B`BL,6XKB(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@
M(K"CM-S'T2"_Y+[@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3`*(RP@9G5Z>GD*;7-G:60@(E-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BM\ZQU\#.
MO<,@P];!OB"WSK'7P,X@O<.PHR"ZN+^IP=:QXB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@
M;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R-@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("+'I2"\T[RZPZ(@
MNKBQXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(KR_(+S3O+K#HB"ZN+'B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R("+'I2"\T[RZPZ(@NKBQXB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(K^M(+S3
MO+K#HB"ZN+'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("*QU[BR(+S3O+K#HB"ZN+'B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PHC+"!F=7IZ>0IM<V=I9"`B
M4VAO=R!U<&QO860B"FUS9W-T<B`BL[NWP;G>L>(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B
M4VAO=V5R<R(*;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*(RP@9G5Z>GD*;7-G
M:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`BL*.TW,?1(+_DON`Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#@P"B,L(&9U>GIY"FUS9VED(")3:')I;FLB"FUS9W-T
M<B`BM\ZQU\#.(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0HC+"!F=7IZ>0IM
M<V=I9"`B4VEG;B!U<"(*;7-G<W1R("*\K;CM.B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"B,L(&9U>GIY"FUS9VED(")3:6=N
M871U<F4B"FUS9W-T<B`BO*VX[3HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<Q,0HC+"!F=7IZ>0IM<V=I9"`B4VEG;F%T=7)E($%L
M9V]R:71H;2(*;7-G<W1R("*\K;CM.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z
M>GD*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("*\K;CM.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B
MQ:FQXB(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(L"OP?:P
M_+BN(+O]MZLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-`IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO
M=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@
M3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC
M+"!F=7IZ>0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B#!IKCQ.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*(RP@9G5Z>GD*;7-G
M:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(L&DM\0@N>:Y_2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S
M='(@(L'WP.4@P=:\TB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F
M<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("*\O["CL-TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G
M<W1R("*\OR"PYK#HO\T@L[N_ZR"[Y\#,P,<@L*.PW2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM
M<V=S='(@(L#ZP.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`BL,6X
MKB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B
ML,6XKK_-(,.DO^RQXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")3
M<&%I;B(*;7-G<W1R("*PQ;BN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.CDX"B,L(&9U>GIY"FUS9VED(")3<&%M(@IM<V=S='(@(L#ZP.4B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA
M<F%C=&5R($EN<'5T(@IM<V=S='(@(L:OO/8@N:[`VB#`U+?"(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM
M<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("*\OR"ZT,?2(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I
M9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(K^M(+K0Q](B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED
M(")3<&QI="!R;W<B"FUS9W-T<B`BQ^`@NM#'TB(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@
M(L#0ONZ_P+'B*,#3QO?&KBDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,
M86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B
M4W1A;F1A<F0B"FUS9W-T<B`BM-ZWPB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@
M;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED
M(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("*XWL#/(+RMN?8@P:2ZN+OGQ]<B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F
M=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`BP??`Y2#!UKS2
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("*PH;_NM:7!V2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*(RP@9G5Z>GD*;7-G:60@
M(E-T<FEN9R!L:7-T(@IM<V=S='(@(KSVO<6PQ;K.(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@
M=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-3
M4UTB"FUS9W-T<B`BO;K%N,#/6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BP::X\2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("+!IL/B(@H*(SH@
M<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T
M960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@
M87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R
M("*^QK>AP[?`VB(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("*\NK#X(@H*(SH@
M861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B)R5S)["A(+W#O;K%V[^A(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ&\K2"[Z,&F
MM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B)R5S)["A
M(+W#O;K%V[^A(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S
M)["A(+W#O;K%V[^AO*T@N^C!IK7'OOJ]P+3/M-DN(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D
M(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9&4R"\L\&D
M(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*
M;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ$@P]^PH;7'OOJ]P+3/M-DN(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!W<F]T92`E<R(*;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ$@P]^PH;7'OOJ]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("*_Y+[@(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R("+!IKCQ(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X
M"B,L(&9U>GIY"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(L&FN/$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B
M4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-@HC+"!F=7IZ>0IM<V=I9"`B4W5N<FES92(*;7-G<W1R("+!IKCQ
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C$V"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R("+!IKCQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-0HC+"!F=7IZ>0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B#!IKCQ.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"B,L(&9U>GIY
M"FUS9VED(")3=6YS970B"FUS9W-T<B`BP::X\2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3@*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(B#!IKCQ.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R
M("+`K<.WP-HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L
M(&9U>GIY"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(L#0ONZ_P+'B*,#3QO?&
MKBDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*
M;7-G<W1R("+`S+BG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BP,RX
MIR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y
M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B
M4W=A>FEL86YD(@IM<V=S='(@(L.CL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U
M>GIY"FUS9VED(")3=V5D96XB"FUS9W-T<B`BP-#`NB"XWL#/(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC
M(&QO9R!D96QE=&5D(@IM<V=S='(@(KJYL;@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED
M(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`BP*?$
MH2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S
M"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@
M9FEL92(*;7-G<W1R("+!IKCQ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE
M+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(L&FN/$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(L>E(+S3
MO+HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4W"B,L(&9U>GIY"FUS9VED(")486)L92!3970B"FUS9W-T<B`BP::X\2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`BQZ4@O-.\
MNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`BM.O'T;G.L;DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"B,L(&9U>GIY"FUS9VED
M(")487)G970Z(@IM<V=S='(@(KC>O</!]B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B5&%S:W,B"FUS9W-T<B`BP-N^]R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")4
M96UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M
M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E
M/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/
MM-DN(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G
M:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#\N*XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`BN:[`VK^M(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY
M(@IM<V=S='(@(KFNP-HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S
M='(@(KFNP-H@P:2WQ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T
M<B`BN:[`VK^M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1H86EL86YD(@IM
M<V=S='(@(L.CL>(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*
M;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`BN^>_Z\?8P=:\Q;RM(+"HN^?'U;3/M-DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,C`*(RP@9G5Z>GD*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@
MO+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN
M<&AP.C$R.3(*(RP@9G5Z>GD*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(KRMN.W`NR"ZK[#FQ](@O/8@
MOOB]P+3/M-DN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS
M9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(L?7N/$@7"(E<UPBL*$@P=:\TK?/OZ$@P]^PH;7'
MOOJ]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES
M="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*
M;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ
M,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED
M(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS
M9W-T<B`BQL3`S[^A(+[&N:NWL2#`VK?AL*$@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82XB"FUS9W-T<B`BQL3`S[^A(+[&N:NWL2#`VK?AL*$@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B
MOL:WH;3"(,#,(&UE<W-A9V4O<F9C.#(R(,;MP?;`QR"XT[BTN+O`U+3/M-DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@
M8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*
M(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K
M87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P
M;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B
M<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<
M;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R("*]Q+JPP-H@7"(E<UPB(+"A(+OHP::UQ[[Z
MO<"TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U
M>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R
M:6,N(@IM<V=S='(@(L#,(+"JP+H@O/W`VK^IOM\@Q]6TS[39+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP.C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(L#,(+C>
MO</!]B#'_,7"*"5S*;BF(+JXL>(@P*?'T2#'P;?.L=>WI<"[(,.CP+L@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T
M"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@
M(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T
M;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(KW$NK#`VB!<(B5S7"(@L*$@N^C!IK7'OOJ]P+3/
MM-DN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N('-A=F5D+B(*;7-G<W1R("*]Q+JPP-H@7"(E<UPB(+"A(,#ZP.6UQ[[Z
MO<"TS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+B(*;7-G<W1R("*]Q+JPP-H@7"(E<UPB(+"A(,#ZP.6U
MQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<
M(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E
M<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W
M"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,3<R"B,L(&9U>GIY"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N(@IM<V=S='(@(KRMN.W`NR"ZK[#FQ](@O/8@OOB]P+3/
MM-DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,3D*(RP@9G5Z>GD*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@
MOOB]P+3/M-DN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.C
MP+L@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92XB"FUS9W-T<B`BP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@O+'%P[OGQ]?`
MS""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*
M;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B
M)R5S)[BF(+W#O;K%V[^A(,/?L*''TB"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B)R5S)[BF(+W#O;K%V[^A
MO*T@N^C!IL?2(+SV(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B)R5S)[BF(+W#O;K%V[^AO*T@N^C!IL?2(+SV(+[XO<"TS[39+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM
M<V=S='(@(B<E<R>XIB"]P[VZQ=N_H2##W["AQ](@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`BQL3`SR"_
MP[BNL>*_H2"YKL&FL*$@P-:]P+3/M-DN("5S(,;$P,_`S""^][?.M>6UQ\'V
M(+[*OM*]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@
M8GET97,I+B(*;7-G<W1R("(B"B+&Q,#/(+[WM\ZUY2"_P+?Y+B#`S,;$P,_`
MNB"^][?.M>4@Q^._Z[7((,/6M.L@Q:FQXB@E9"!-0BFZN+39(,6KL,T@L+"]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B*^][?.M>4@QL3`S[^A
M(+FNP::PH2#`UKW`M,^TV2X@P,S&Q,#/P+H@OO>WSK7E(,/6M.O'X[_KQ:FQ
MXKBF(,/*L/K'U;3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B
MN-Z]P\'V(,#\O-L@O\"W^2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`BM:7`
MS,6X(,#3QO?&KB"_P+?Y(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N
M<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`BM:7`S,6X(,#3
MQO?&KB"_P+?Y(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q
M=6ER960@9FEE;&0N(@IM<V=S='(@(K_DP[NUR""XWKW#P?8@P-"QXB"_P+?Y
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S@*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("*_Y,.[M<@@
MN-Z]P\'V(,#0L>(@O\"W^2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BOO>WSK7E(,;$P,\@
MP-/&]\:N(+_`M_DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BO^3#N[7((+C>O</!]B#`T+'B
M(+_`M_DB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(KKJMO._[,#Z
ML*$@P,P@L>*TR<"[(,'VO_C'S\'V(+[*O<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N(@IM<V=S='(@(L#,(+"JP+H@O/W`VK^IOM\@Q]6TS[39+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*(RP@9G5Z>GD*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N(@IM<V=S='(@(L#,(+"JP+H@O/W`VK^IOM\@Q]6TS[39+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R
M+B(*;7-G<W1R("+`S""PJL"Z(+S]P-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I
M9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED
M(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BP,P@L*K`NB"\_<#:
MOZF^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S
M-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q
M,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HU-C$*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`BP,RYS"#!UKS2M\^_H2"U[K?/M<>^
M[B#`UKW`M,^TV2XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*
M(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(L#,(+S]P-JTPB##UKS2
MQ]$@,<#:N*X@P,R[\\#,ONZ^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`BP,P@L*K`NB"\_<#:OZF^WR#'U;3/M-DN(@H*(SH@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@
M(L&FN/$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
MO<.PHR"\L\&D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0HC
M+"!F=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`BO<.PHR"\
ML\&D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS
M9W-T<B`BP::X\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B
MQ;C`S,:R*,7XQL$I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(KG>M,(@N^>V]R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*
M;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI
M;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(E1O9&%Y(@IM<V=S='(@
M(KJ[N:XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B2%1-
M3""\TKVZ(+JXL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4
M;V=O(@IM<V=S='(@(KG>M,(@N^>V]R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,PHC+"!F=7IZ>0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B
M("BSN\#/*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E1O;F=A
M(@IM<V=S='(@(KG>M,(@N^>V]R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@
M(L"G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("*[\\"G(,?!
MM[G`TRA?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F
M=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(LBOL.:\L\&D(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED
M(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56=A;F1A(@IM<V=S='(@(K3>M\(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S
M='(@(KG8P=DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS
M9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE
M;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,X.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP,<@QMNYS+S'P+L@NJ^PYL?2(+SV
M(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X
M-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP,<@QMNYS+S'
MP+L@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(")344P@O*VY]K^A(,&BO-/'
MTB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S
M+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E
M<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B4U%,(+RMN?:_H2#!HKS3Q](@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*
M;7-G<W1R(")344P@O*VY]K^A(,&BO-/'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B5D93
M(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@M?"W
MNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$
MP,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B5D93(,;$
MP,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`BR*^PYKRS
MP:3`NR"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B
M=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(CH@)7,N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'
MTB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2XB"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(K7PM[K%Y+BN(+#+N_:_P+?Y.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,C`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93
M(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS.3$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`
MNRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@
M(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@
M(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M
M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(B5S(,&DP,>XIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T
M<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@
M(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92XB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV
M(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`BR*^PYKRSP:3`NR"ZK[#FQ](@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^P
MYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5S
MP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")61E,@
MQL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@
MM?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR
M96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BN
MN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5D93(,;$
MP,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S0S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@
M)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LH
MN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF
M*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B5D93(,;$P,\@
M)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(L#,
M(+_VM>6YKKRMN*8@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E
M<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3<Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")61E,@
MQL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JO
ML.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#0Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L
M('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(E9&4R#&Q,#/("5S
M+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI
M;F4B"FUS9W-T<B`BN=C!V2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("*ZK[#FN^?'UR"UQ[6Y
MN*ZQXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(KBVP?:XMR"X[;?)(,/KO-(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0HC
M+"!F=7IZ>0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("+`T,'V(+[*P+H@N-[`
MSR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*(RP@9G5Z>GD*;7-G
M:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(KG,L;DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(K^UL;DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@
M(KG,L;DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*
M;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34Y"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3$*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(KOGO^O`VL#,N*>P^B"^S\BCN*8@P-2W
MPL?/O+R_Y"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`BQ_;`YR"_Y+S2OZ$@N+7%J2#!IK#%(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`BP,RXIR"^^,"](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B
M"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R("*[]K'R(,&FL,4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")5<&1A
M=&4B"FUS9W-T<B`BP,_`VB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M92`E<R(*;7-G<W1R("+`S\#:(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B"FUS
M9W-T<B`BN^>_Z\#:(,/?L*$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<
M(B5S7"(N(@IM<V=S='(@(KOGO^O`VB##W["A(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B
M57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5
M<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(K;SQKZ^[B"TZ[FNP-HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(K?.
MN+8@M.NYKL#:(+S]P-HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`BQ_;`YR"]NL6XP,\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I
M9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R
M(@IM<V=S='(@(KOGO^O`VKCM(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E
M<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C(P,PHC+"!F=7IZ>0IM<V=I9"`B57-E<B!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")(;W)D92"[Y[_KP-H@L/RXKB(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO
M;G,B"FUS9W-T<B`BN^>_Z\#:(+RQQ<.[Y\?7(@H*(SH@<VEG;G5P+G!H<#HV
M,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B
M2&]R9&4@N^>_Z\#:(+#\N*XB"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y
M"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(KOG
MO^O`VKCM(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB
M(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("*XWL#/Q]0@7"(E<UPBL*$@P,RY
MS""[Y[_KP=_`U+3/M-DN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BN^>_
MZ\#:N.TB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U
M>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(KOGO^O`VKCM(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@
M:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`BO<.]NL7;P,<@N^>_Z\#:.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5D93(&1I<F5C=&]R
M>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BQ>O!]B"XKKVZL\H@)7/`NRBX
MIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3$X"B,L(&9U>GIY"FUS9VED(")686-A=&EO;B(*;7-G<W1R("*]
MQ\?@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")6
M86QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI
M;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L
M('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@
M;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*(RP@9G5Z>GD*
M;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(L&FN/$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("*P
ML\#.(+C>P,\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"B,L
M(&9U>GIY"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`BL+/`SB"X
MWL#/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`BO/;!
M]R#!I+?$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("*\]L'W
M(,.DO_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`BO/;!
M]R#!I+?$(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"B,L(&9U>GIY"FUS9VED(")6:65T($YA;2(*;7-G<W1R("+'RK7EP,RX
MIR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M
M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W
M("5S(@IM<V=S='(@(B5S(+JXL>(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R
M("(E<R"ZN+'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES
M:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)
M=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%
M(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A
M;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R
M("*PYK#M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*
M;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N
M8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS
M9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E
M:VQY(@IM<V=S='(@(KC%P=8B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE
M+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("+(K[^U(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B
M"FUS9W-T<B`BR*^_M<?5M,^TV2$@)7,@P-2TS[39+B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R
M("+(K[^UQ]6TS[39+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU
M"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N
M(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("*QN+K0(+FNP-JTPB"Y
MJ[[YP-2TS['N/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W
M"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@
M(L#.O^L@NL[(H[3"(+FKOOG`U+3/L>X_(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S
M=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(K/*NO$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(U"B,L(&9U>GIY"FUS9VED(")7:61T:"!I;B!#
M4U,@=6YI=',B"FUS9W-T<B`BL\JZ\2"TW,"G(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L
M92(*;7-G<W1R("+'I<#'(+/*NO$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G
M<W1R("*SRKKQ(+3<P*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(K/*NO$Z
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK
M:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"B,L
M(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(L.CL>(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM<V=I
M9"`B5VEN9"!%87)L>2(*;7-G<W1R("+#H['B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@HC+"!F=7IZ>0IM<V=I
M9"`B5VEN9#HB"FUS9W-T<B`BPZ.QXB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#(*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G<W1R
M("+#H['B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"B,L(&9U>GIY
M"FUS9VED(")7:7-D;VTB"FUS9W-T<B`BPZ.QXB(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B
M5V]R:R(*;7-G<W1R("*VQ[3"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T
M<B`BP??`Y2#!UKS2.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BP??`
MY2#`_,BMN?C(HR(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V
M.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@
M<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(EE9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@
M(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A
M<FQY(@IM<V=S='(@(KC%L^(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS
M9VED(")996UE;B(*;7-G<W1R("+`T,"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS
M9W-T<B`BO[DB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G
M:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R(")415A4N/"U
MY<#4M,^TV2X@6SP^72"Y]L:PP+L@M*FXH[CI(%=94TE764<@N/"UY;?.(+6Y
MOL:PJ;3/M-DN(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@
M=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S4*(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`BP-^X
M^+7((,#,N-[`SR#!UKS2(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,CDP"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("+`T\;W
MQJZUR"#&Q,#/P,<@ONZVLB#'U[CQM;4@5'5R8F'`QR#'U[CQOZ$@N,*PU""\
ML\&DQ\_!]B"^RK[2O<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G
M<W1R("*WSK'7OL:_]"#'S[^TO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3@X"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+B(*;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("*Y
MKL&F(+JXL.V\K;BF(+JXL[NQXL#\OZ$@P,RYKL&FOZ$@M.O'T2"\L[CMP+L@
MP-2WPL?8OM\@Q]6TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("+`S""XM<6I
ML*$@L*&XKL2AM,(@55),P+L@P-2WPL?8OM\@Q]6TS[39+B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(KC5P/H@N^C!IL?2(+W$NK#`VKBF(+RQQ</'V+[?(,?5M,^TV2XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(KOHP:;'
MTB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N(@IM<V=S='(@(KOHP:;'TB"[Y[_KP-H@P,RXI\"[(,#4
MM\+'V+[?(,?5M,^TV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`BP]^PH<?2(+OG
MO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("+#W["AQ](@N^>_Z\#:(,#,
MN*?`NR#`U+?"Q]B^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(KSV
MO<7`SL#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(KOHP:;'TB"[
MY[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B5S(+R\O,?`S""XN+?A
MM<>^^KW`M,^TV2X@M-F]PR"WSK'7P,['S[R\O^0N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D
M<F5S<R(*;7-G<W1R("+`S+C>P,\@P=:\TCHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S
M='(@(KC>P,\@P=:\TCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@
M26YF;W)M871I;VXB"FUS9W-T<B`BP:2ZN"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA
M;64B"FUS9W-T<B`BP,RXISHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HBM.>]Q<#'(,#.P?7%K+;S
MP,R^\,:NL*$@N^>_Z\#:N*8@P]^PH<?2(+SV(+[XO<"TS[39+B"VQ[3"(+39
MN*4@P,S`K[?.(+OGO^O`VB`B"B+#W["AL>*TR<"[(+OGO^O'TB"\]B"^^+W`
MM,^TV2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*
M;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T
M<B`B(@HBM.>]Q<#'(,#.P?7%K+;SP,R^\,:NL*$@N^>_Z\#:(+CQM\^ZN+'B
MN*8@P?:_^,?/P?8@OLJ]P+3/M-DN(+;'M,(@M-FXI2#`S,"O(@HBM\X@N^>_
MZ\#:(+CQM\^ZN+'BN*8@N^>_Z\?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S
M='(@(KKJMO._[,#ZL*$@P,P@L>*TR<"[(,'VO_C'S\'V(+[*O<"TS[39+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T
M;R!P<FEN="XB"FUS9W-T<B`B(@HBN^>_Z\?/L.T@L.B]Q2"ZZK;SO^S`^K3"
M(,#.O.(@O\F\Q\"[(,'VO_C'S\'V(+[*O<"TS[39+B#`SKSBQ\^QXB#`I\?8
MO*VTPB#$P2(*(L:NM]$OO\F\Q\6PO\T@4+BF(+2IN*.\O+_D+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z(@IM<V=S='(@(L?VP.<@O<.PH[3K.B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED
M96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(K'BNKL@O<2ZL,#:
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BL>*ZNR"]Q+JPP-HZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA
M;64Z(@IM<V=S='(@(L#\P[P@P,RXISHB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("*_R;S'P,P@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+`S""\O+S'(+6_OL@@
MO\F\Q\#,(,#ZP.6UR[3/M-DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"XB"FUS9W-T<B`BO\F\Q\#,(,#ZP.6UQ[[ZO<"TS[39+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E
M<G,Z(@IM<V=S='(@(KC>P,\@P=:\TCHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(EIA:7)E(@IM
M<V=S='(@(L?*Q<TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X
M=%TB"FUS9W-T<B`B6\#.O^L@O/NQXK'B72(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EN_
MP+?Y(+JXL.W'S['B72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S
M='(@(EO`SK_K(+JXL>(@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M6\#.O^L@NKBQXB`M("5S(,'972(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R(");MO/`SB`E<R`O("5S72(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q
M"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T&P_+BN(@H*(SH@
M;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S
M='(@(L#/P-HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@
M(E]$Q^`@P?:_\B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R("*UM;_RN+LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*
M;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E])L=>XLB"\
MT[RZ+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("*WSK'7P,XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?
M3&]G(&]U="(*;7-G<W1R(")?3+?.L=>^QK_T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?
M36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7VVXM<6I(+SVP:0N+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R(")?3[RQQ<.[Y\?7(@H*(SH@;&EB+V%P:2YP:'`Z,3,W
M"B,L(&9U>GIY"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ>2WT"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]RN+7%
MJ2"[Z,&F+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*(RP@9G5Z>GD*;7-G:60@
M(E]3971U<"(*;7-G<W1R("*XWKW#P?8@O+'%PR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B
M7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7W3'I2"\T[RZ+BXN(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")?57-E<G,B"FUS
M9W-T<B`BN^>_Z\#:N.TB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(L'6
MO-*WSR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T
M"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("+!
MUKS2M\\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F
M=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BM-ZWPB(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(L/KO-(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I
M9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N
M;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R
M"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z
M>GD*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`BN-[`SR"\
MK;GV(,&DNKB[Y\?7(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY
M"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`BQ>O!]B"XKKVZL\H@
M)7/`NRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*
M(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`BP::X\2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM<V=I9"`B9W5S
M=&EN9R(*;7-G<W1R("(XO_DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED
M(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M(RP@9G5Z>GD*;7-G:60@(FEN;&EN92(*;7-G<W1R("*^^,"](@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T
M+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("+!V5TB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*;7-G<W1R("+`
MS+BG(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0HC+"!F=7IZ>0IM
M<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(KOHP::UQ\'V(+[*P+H@
MN-[`SR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q
M.0HC+"!F=7IZ>0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R
M("*[Z,&FM<?!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDP-0HC+"!F=7IZ>0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("+`
MT,'V(+[*P+H@N-[`SR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B
MQMN\OL:N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@
M(K"SP,X@N-[`SR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("+'R+R_
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G
M:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ
M>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(K#FL.TB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V
M86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.CDY"B,L(&9U>GIY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@
M(KOGO^O`VB#(K[#F(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B
M<W1E861Y(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C
M<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"B,L(&9U>GIY"FUS9VED
M(")T87-K(&QI<W0B"FUS9W-T<B`BO/:]Q;#%NLXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A
M:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("*X\+7G
M(+?.L=?`SB(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D
M('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*
M;7-G:60@(G5N:69I960B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D
M(@IM<V=S='(@(L#,N*<@OOC`O2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B
M=7-E<B!S96QE8W0B"FUS9W-T<B`BL=3$HBBW_"D@O+'%PR"_P+?Y(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED
M(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-#$*(RP@9G5Z>GD*;7-G:60@(G<Z(@IM
M<V=S='(@(L#\M-XZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O````````````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C0`,#$V,3`R`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V-R:7!T<R]L9&%P+P``````````````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,3<P,C(`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+VQD87`O:&]R9&4N<V-H96UA````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,T-3`V`#$P-3$U-#,Q
M,#8T`#`R,3,Q,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C("1(;W)D93H@:&]R9&4O<V-R:7!T<R]L9&%P+VAO<F1E+G-C
M:&5M82QV(#$N,C`N,3`N-2`R,#`U+S$P+S$X(#$Q.C,T.C`P(&IA;B!%>'`@
M)`HC"B,@5&AE(&]F9FEC86P@:&]R9&4@3TE$(&%S<VEG;F5D(&)Y($E!3D$@
M:7,@,3,P-#`N"B,*(R!4:&ES('-C:&5M82!D97!E;F1S(&]N.@HC"2T@8V]R
M92YS8VAE;6$*(PHC(`HC($AO<F1E(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,BXQ+BH*(R!)35`@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XS+C$N*@HC(%1U<F)A(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+BH*(R!+<F]N;VQI=&@@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU+C$N*@HC($YA9R!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C8N,2XJ"B,@1V]L;&5M(&%T
M=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-RXQ+BH*(R!#:&]R
M82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XJ"B,@
M36YE;6\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N
M*@HC(%1R;VQL(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,3`N,2XJ"B,@2VQU='H@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XQ,2XQ+BH*(R!*;VYA:"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C$R+C$N*@HC($AE<FUE<R!A='1R:6)U=&4@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$S+C$N*@HC($IU;F\@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XQ+BH*(R!4<F5A;B!A='1R:6)U=&4@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$U+C$N*@HC(%=H=7!S(&%T=')I
M8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,38N,2XJ"B,@26YG;R!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$W+C$N*@HC($%N
M<V5L(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3@N,2XJ
M"B,@1V5N:64@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ
M.2XQ+BH*(R!38W)Y(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,C`N,2XJ"B,@5VEC:V5D(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,C$N,2XJ"B,@06=O<F$@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR,BXQ+BH*(R!';V]P<R!A='1R:6)U=&4@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(T+C$N*@HC($UE<FL@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-2XQ+BH*(R!-:6UP(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C8N,2XJ"B,@36]T=&QE(&%T
M=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C<N,2XJ"B,@3FEC
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C@N,2XJ"B,@
M3V-C86T@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR.2XQ
M+BH*(R!/9&EN(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,S`N,2XJ"B,@4F%K:6T@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XS,2XQ+BH*(R!397-H82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C,R+C$N*@HC(%-W;V]S:"!A='1R:6)U=&4@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C,S+C$N*@HC(%1H;W(@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-"XQ+BH*(R!5;&%F;W)M(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,2XJ"B,@5F]L;W,@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-BXQ+BH*(R`*(R!(
M;W)D92!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,BXR
M+BH*(R!)35`@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,N,BXJ"B,@5'5R8F$@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C0N,BXJ"B,@2W)O;F]L:71H(&]B:F5C=&-L87-S(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XU+C(N*@HC($Y!1R!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N-BXR+BH*(R!';VQL96T@;V)J96-T8VQA
M<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,BXJ"B,@0VAO<F$@;V)J
M96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,BXJ"B,@36YE
M;6\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+CDN,BXJ
M"B,@5')O;&P@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C$P+C(N*@HC($ML=71Z(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XQ,2XR+BH*(R!*;VYA:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,3(N,BXJ"B,@2&5R;65S(&]B:F5C=&-L87-S(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXR+BH*(R!*=6YO(&]B:F5C=&-L
M87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XR+BH*(R!4<F5A;B!O
M8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,34N,BXJ"B,@
M5VAU<',@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$V
M+C(N*@HC($EN9V\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C$W+C(N*@HC($%N<V5L(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XQ."XR+BH*(R!'96YI92!O8FIE8W1C;&%S<R!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,3DN,BXJ"B,@4V-R>2!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C`N,BXJ"B,@5VEC:V5D(&]B:F5C
M=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XR+BH*(R!!9V]R
M82!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C(N,BXJ
M"B,@1V]O<',@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C(T+C(N*@HC($UE<FL@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(U+C(N*@HC($UI;7`@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C(V+C(N*@HC($UO='1L92!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C<N,BXJ"B,@3FEC(&]B:F5C=&-L87-S
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR."XR+BH*(R!/8V-A;2!O8FIE
M8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,CDN,BXJ"B,@3V1I
M;B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S`N,BXJ
M"B,@4F%K:6T@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,Q+C(N*@HC(%-E<VAA(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XS,BXR+BH*(R!3=V]O<V@@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C,S+C(N*@HC(%1H;W(@;V)J96-T8VQA<W,@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,T+C(N*@HC(%5L869O<FT@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,U+C(N*@HC(%9O;&]S
M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-BXR+BH*
M"B,*(R!(;W)D92!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C(N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(N
M,2XQ"@E.04U%("=H;W)D95!R969S)PH)1$530R`G2&]R9&4@4')E9F5R96YC
M97,G"@E%455!3$E462!C87-E26=N;W)E24$U36%T8V@*"5-93E1!6"`Q+C,N
M-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@24U0(&%T
M=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,RXQ+BH*(PIA='1R
M:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,RXQ+C$*"4Y!344@)VEM
M<%!R969S)PH)1$530R`G24U0(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S
M94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N
M,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%1U<F)A(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS
M+C8N,2XT+C$N,3,P-#`N-"XQ+C$*"4Y!344@)W1U<F)A4')E9G,G"@E$15-#
M("=4=7)B82!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-
M871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P
M,C1]("D*"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XT+C$N
M,@H)3D%-12`G='5R8F%4>7!E)PH)1$530R`G5'5R8F$@3V)J96-T(%1Y<&4Z
M($-O;G1A8W0O3&ES="<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)
M4U5"4U12(&-A<V5)9VYO<F5)0353=6)S=')I;F=S36%T8V@*"5-93E1!6"`Q
M+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLX?2`I"@IA='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C,*"4Y!344@)W1U<F)A365M
M8F5R<R<*"41%4T,@)T5N8V]D960@;65M8F5R<R!O9B!A(%1U<F)A(&QI<W0G
M"@E355`@;F%M92`I"@IA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P
M-#`N-"XQ+C0*"4Y!344@)W1U<F)A4$=04'5B;&EC2V5Y)PH)1$530R`G4$=0
M+T=01R!0=6)L:6,@2V5Y)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)
M035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V
M>S0P,#!]("D*"B,*(R!+<F]N;VQI=&@@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XU+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XU+C$N,0H)3D%-12`G:W)O;F]L:71H4')E9G,G"@E$15-#
M("=+<F]N;VQI=&@@4')E9F5R96YC97,G"@E%455!3$E462!C87-E26=N;W)E
M24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR
M-GLQ,#(T?2`I"@HC"B,@3F%G(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N-BXQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N
M,3,P-#`N-BXQ+C$*"4Y!344@)VYA9U!R969S)PH)1$530R`G3F%G(%!R969E
M<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($=O
M;&QE;2!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,2XJ
M"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,2XQ"@E.
M04U%("=G;VQL96U0<F5F<R<*"41%4T,@)T=O;&QE;2!0<F5F97)E;F-E<R<*
M"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N
M-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!#:&]R82!A='1R
M:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XJ"B,*871T<FEB
M=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XQ"@E.04U%("=C:&]R
M85!R969S)PH)1$530R`G0VAO<F$@4')E9F5R96YC97,G"@E%455!3$E462!C
M87-E26=N;W)E24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q
M-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@36YE;6\@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N,0H)3D%-12`G;6YE;6]0<F5F<R<*"41%
M4T,@)TUN96UO(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC(%1R;VQL(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,3`N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$P+C$N,0H)3D%-12`G=')O;&Q0<F5F<R<*"41%4T,@)U1R;VQL
M(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC($ML=71Z(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,3$N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$Q
M+C$N,0H)3D%-12`G:VQU='I0<F5F<R<*"41%4T,@)TML=71Z(%!R969E<F5N
M8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($IO;F%H
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$R+C$N,0H)3D%-
M12`G:F]N86A0<F5F<R<*"41%4T,@)TIO;F%H(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($AE<FUE<R!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$S+C$N*@HC"F%T=')I8G5T
M971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXQ+C$*"4Y!344@)VAE<FUE
M<U!R969S)PH)1$530R`G2&5R;65S(%!R969E<F5N8V5S)PH)15%504Q)5%D@
M8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ
M,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($IU;F\@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@
M,2XS+C8N,2XT+C$N,3,P-#`N,30N,2XQ"@E.04U%("=J=6YO4')E9G,G"@E$
M15-#("=*=6YO(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC(%1R96%N(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,34N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$U+C$N,0H)3D%-12`G=')E86Y0<F5F<R<*"41%4T,@)U1R96%N
M(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC(%=H=7!S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,38N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$V
M+C$N,0H)3D%-12`G=VAU<'-0<F5F<R<*"41%4T,@)U=H=7!S(%!R969E<F5N
M8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($EN9V\@
M871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-RXQ+BH*(PIA
M='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,3<N,2XQ"B`@("`@
M("!.04U%("=I;F=O4')E9G,G"B`@("`@("!$15-#("=);F=O(%!R969E<F5N
M8V5S)PH@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"B`@("`@
M("!364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@
M*0H*(PHC($%N<V5L(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,3@N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C$X+C$N,0H@("`@("`@3D%-12`G86YS96Q0<F5F<R<*("`@("`@($1%4T,@
M)T%N<V5L(%!R969E<F5N8V5S)PH@("`@("`@15%504Q)5%D@8V%S94EG;F]R
M94E!-4UA=&-H"B`@("`@("!364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N
M,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($=E;FEE(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,3DN,2XJ"B,*871T<FEB=71E='EP92`H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$Y+C$N,0H)3D%-12`G9V5N:650<F5F<R<*"41%
M4T,@)T=E;FEE(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC(%-C<GD@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XR,"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N
M,3,P-#`N,C`N,2XQ"@E.04U%("=S8W)Y4')E9G,G"@E$15-#("=38W)Y(%!R
M969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M(%=I8VME9"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(Q
M+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XQ
M+C$*"4Y!344@)W=I8VME9%!R969S)PH)1$530R`G5VEC:V5D(%!R969E<F5N
M8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($%G;W)A
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C(N,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(R+C$N,0H@("`@
M("`@($Y!344@)V%G;W)A4')E9G,G"B`@("`@("`@1$530R`G06=O<F$@4')E
M9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H
M"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@
M*0H*(PHC($=O;W!S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,C0N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C(T+C$N,0H@("`@("`@($Y!344@)V=O;W!S4')E9G,G"B`@("`@("`@1$53
M0R`G1V]O<',@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC($UE<FL@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR-2XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N
M,2XT+C$N,3,P-#`N,C4N,2XQ"B`@("`@("`@3D%-12`G;65R:U!R969S)PH@
M("`@("`@($1%4T,@)TUE<FL@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)
M5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($UI;7`@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-BXQ+BH*(PIA='1R:6)U=&5T>7!E
M("@@,2XS+C8N,2XT+C$N,3,P-#`N,C8N,2XQ"B`@("`@("`@3D%-12`G;6EM
M<%!R969S)PH@("`@("`@($1%4T,@)TU)35`@4')E9F5R96YC97,G"B`@("`@
M("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($UO='1L92!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(W+C$N*@HC"F%T
M=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-RXQ+C$*("`@("`@
M("!.04U%("=M;W1T;&50<F5F<R<*("`@("`@("!$15-#("=-;W1T;&4@4')E
M9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H
M"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@
M*0H*(PHC($YI8R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C(X+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR
M."XQ+C$*("`@("`@("!.04U%("=N:6-0<F5F<R<*("`@("`@("!$15-#("=.
M24,@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($]C8V%M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,CDN,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(Y+C$N,0H@("`@("`@($Y!344@)V]C8V%M4')E9G,G"B`@("`@
M("`@1$530R`G3V-C86T@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@
M8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ
M,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($]D:6X@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@
M,2XS+C8N,2XT+C$N,3,P-#`N,S`N,2XQ"B`@("`@("`@3D%-12`G;V1I;E!R
M969S)PH@("`@("`@($1%4T,@)T]D:6X@4')E9F5R96YC97,G"B`@("`@("`@
M15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT
M+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%)A:VEM(&%T=')I
M8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S$N,2XJ"B,*871T<FEB
M=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C$N,0H@("`@("`@($Y!
M344@)W)A:VEM4')E9G,G"B`@("`@("`@1$530R`G4F%K:6T@4')E9F5R96YC
M97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M(%-E<VAA(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S(N
M,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,R+C$N
M,0H@("`@("`@($Y!344@)W-E<VAA4')E9G,G"B`@("`@("`@1$530R`G4V5S
M:&$@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC(%-W;V]S:"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C,S+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XS,RXQ+C$*("`@("`@("!.04U%("=S=V]O<VA0<F5F<R<*("`@
M("`@("!$15-#("=3=V]O<V@@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)
M5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%1H;W(@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-"XQ+BH*(PIA='1R:6)U=&5T>7!E
M("@@,2XS+C8N,2XT+C$N,3,P-#`N,S0N,2XQ"B`@("`@("`@3D%-12`G=&AO
M<E!R969S)PH@("`@("`@($1%4T,@)U1H;W(@4')E9F5R96YC97,G"B`@("`@
M("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%5L869O<FT@
M871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-2XQ+BH*(PIA
M='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,2XQ"B`@("`@
M("`@3D%-12`G=6QA9F]R;5!R969S)PH@("`@("`@($1%4T,@)U5L869O<FT@
M4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA
M=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R
M-'T@*0H*(PHC(%9O;&]S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,S8N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C,V+C$N,0H@("`@("`@($Y!344@)W9O;&]S4')E9G,G"B`@("`@("`@
M1$530R`G5F]L;W,@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S
M94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N
M,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($AO<F1E(&]B:F5C=&-L87-S(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR+C(N*@HC"F]B:F5C=&-L87-S("@@,2XS
M+C8N,2XT+C$N,3,P-#`N,BXR+C$*("`@($Y!344@)VAO<F1E4&5R<V]N)PH@
M("`@1$530R`G2&]R9&4@4')E9F5R96YC97,G"B`@("!355`@=&]P"B`@("!!
M55A)3$E!4ED*("`@($U!62`H(&UA:6P@)"!H;W)D95!R969S("0@:6UP4')E
M9G,@)"!T=7)B85!R969S("0*("`@("`@("!G;VQL96U0<F5F<R`D(&MR;VYO
M;&ET:%!R969S("0@;6YE;6]0<F5F<R`D"B`@("`@("`@=')O;&Q0<F5F<R`D
M(&YA9U!R969S("0@:VQU='I0<F5F<R`D"B`@("`@("`@:F]N86A0<F5F<R`D
M(&AE<FUE<U!R969S("0@:G5N;U!R969S("0*("`@("`@("!T<F5A;E!R969S
M("0@=VAU<'-0<F5F<R`D(&EN9V]0<F5F<R`D"B`@("`@("`@9V5N:650<F5F
M<R`D('-C<GE0<F5F<R`D(&%N<V5L4')E9G,@)`H@("`@("`@('=I8VME9%!R
M969S("0@8VAO<F%0<F5F<R`D(&%G;W)A4')E9G,@)`H@("`@("`@(&=O;W!S
M4')E9G,@)"!M97)K4')E9G,@)"!V;VQO<U!R969S("0*("`@("`@("!M:6UP
M4')E9G,@)"!M;W1T;&50<F5F<R`D(&YI8U!R969S("0*("`@("`@("!O8V-A
M;5!R969S("0@;V1I;E!R969S("0@<F%K:6U0<F5F<R`D"B`@("`@("`@<V5S
M:&%0<F5F<R`D('-W;V]S:%!R969S("0@=&AO<E!R969S("0*("`@("`@("!U
M;&%F;W)M4')E9G,*("`@("D@*0H*;V)J96-T8VQA<W,@*"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XR+C(N,@H@("`@3D%-12`G:&]R9&5'<F]U<"<*("`@($1%4T,@
M)TAO<F1E($=R;W5P)PH@("`@4U50('1O<`H@("`@055824Q)05)9"B`@("!-
M05D@*"!M86EL("D@*0H*(PHC($E-4"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,RXR+BH*(PH*(R!4=7)B82!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XR+BH*;V)J96-T8VQA<W,@*"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XT+C(N,0H@($Y!344@)W1U<F)A0V]N=&%C="<*
M("!$15-#("=4=7)B82!#;VYT86-T)PH@(%-54"!T;W`*("!!55A)3$E!4ED*
M("!-05D@*"!T=7)B851Y<&4@)"!T=7)B84UE;6)E<G,@*0H@*0H*(PHC($MR
M;VYO;&ET:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M-2XR+BH*(PH*(PHC($YA9R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N-BXR+BH*(PH*(PHC($=O;&QE;2!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N-RXR+BH*(PH*(PHC($-H;W)A(&]B:F5C
M=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XX+C(N*@HC"@HC"B,@
M36YE;6\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+CDN
M,BXJ"B,*"B,*(R!4<F]L;"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,3`N,BXJ"B,*"B,*(R!+;'5T>B!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3$N,BXJ"B,*"B,*(R!*;VYA:"!O8FIE
M8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N,BXJ"B,*"B,*
M(R!(97)M97,@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C$S+C(N*@HC"@HC"B,@2G5N;R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,30N,BXJ"B,*"B,*(R!4<F5A;B!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,34N,BXJ"B,*"B,*(R!7:'5P<R!O
M8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,38N,BXJ"B,*
M"B,*(R!);F=O(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XQ-RXR+BH*(PH*(PHC($%N<V5L(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XQ."XR+BH*(PH*(PHC($=E;FEE(&]B:F5C=&-L87-S
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ.2XR+BH*(PH*(PHC(%-C<GD@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(P+C(N*@HC
M"@HC"B,@5VEC:V5D(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XR,2XR+BH*(PH*(PHC($%G;W)A(&]B:F5C=&-L87-S(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XR,BXR+BH*(PH*(PHC($=O;W!S(&]B:F5C=&-L
M87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-"XR+BH*(PH*(PHC($UE
M<FL@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(U+C(N
M*@HC"@HC"B,@36EM<"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,C8N,BXJ"B,*"B,*(R!-;W1T;&4@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(W+C(N*@HC"@HC"B,@3FEC(&]B:F5C=&-L
M87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR."XR+BH*(PH*(PHC($]C
M8V%M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR.2XR
M+BH*(PH*(PHC($]D:6X@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C,P+C(N*@HC"@HC"B,@4F%K:6T@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C(N*@HC"@HC"B,@4V5S:&$@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,R+C(N*@HC"@HC"B,@
M4W=O;W-H(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS
M,RXR+BH*(PH*(PHC(%1H;W(@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C,T+C(N*@HC"@HC"B,@56QA9F]R;2!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,BXJ"B,*"B,*(R!6;VQO<R!O
M8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S8N,BXJ"B,*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A
M9&5S+P``````````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#8T`#`Q-S<Q-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-C<FEP=',O=7!G<F%D97,O;6]V95]H:7-T;W)Y7V]U=%]O9E]D871A
M=')E92YP:'``````````````````````````````````,#$P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#8T-#``,3`U,34T,S$P-C0`,#(V-#`T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````",A+W5S
M<B]B:6XO<&AP("UQ"CP_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP
M=',O=7!G<F%D97,O;6]V95]H:7-T;W)Y7V]U=%]O9E]D871A=')E92YP:'`L
M=B`Q+C,N,BXQ(#(P,#4O,3`O,3@@,3$Z,S0Z,#$@:F%N($5X<"`D"B`J"B`J
M(%1H:7,@:7,@82!S8W)I<'0@=&\@;6EG<F%T92!(:7-T;W)Y(&EN9F]R;6%T
M:6]N(&]U="!O9B!T:&4@9&%T871R964*("H@=&%B;&5S(&%N9"!I;G1O(&ET
M<R!O=VX@9&%T86)A<V4@=&%B;&4N"B`J+PH*+R\@1FEN9"!T:&4@8F%S92!F
M:6QE('!A=&@@;V8@2&]R9&4N"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R
M=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+RXN+RXN)RD["@HO+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N
M="!S971U<"!F:7)S="X*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI
M8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO
M+R!-86ME('-U<F4@;F\@;VYE(')U;G,@=&AI<R!F<F]M('1H92!W96(N"FEF
M("@A2&]R9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-
M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,
M;V%D('1H92!#3$D@96YV:7)O;FUE;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N
M;R!T:6UE(&QI;6ET+"!I;FET"B\O('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO
M<F1E7T-,23HZ:6YI="@I.PHD8VQI(#T@2&]R9&5?0TQ).CIS:6YG;&5T;VXH
M*3L*"B1C;&DM/G=R:71E;&XH)&-L:2T^>65L;&]W*")"96=I;FYI;F<@;6EG
M<F%T:6]N+B!4:&ES(&UA>2!T86ME(&$@=F5R>2!L;VYG('1I;64@=&\@8V]M
M<&QE=&4N(BDI.PHD8VQI+3YW<FET96QN*"D["@IR97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]$871A5')E92YP:'`G.PH*8VQA<W,@1&%T851R965/8FIE8W1?2&ES=&]R
M>2!E>'1E;F1S($1A=&%4<F5E3V)J96-T('L*"B`@("!F=6YC=&EO;B!?9G)O
M;4%T=')I8G5T97,H)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@+RH@26YI
M=&EA;&EZ92!D871A(&%R<F%Y+B`J+PH@("`@("`@("1T:&ES+3YD871A(#T@
M87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&%T
M='(I('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^9&%T85LD871T
M<ELG;F%M92==72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1A
M='1R6R=N86UE)UU=(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^9&%T85LD871T<ELG;F%M92==75LD871T<ELG:V5Y)UU=
M(#T@)&%T=');)W9A;'5E)UT["B`@("`@("`@?0H@("`@?0H*?0H*)&1A=&%T
M<F5E(#T@)D1A=&%4<F5E.CIF86-T;W)Y*"=S<6PG+"!A<G)A>5]M97)G92A(
M;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("=S<6PG*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9W)O=7`G(#T^("=H;W)D92YH:7-T;W)Y)RDI*3L*)&1B(#T@
M)B1D871A=')E92T^7V1B.PH*)&ES<6P@/2`G24Y315)4($E.5$\@:&]R9&5?
M:&ES=&]R:65S("AH:7-T;W)Y7VED+"!O8FIE8W1?=6ED+"!H:7-T;W)Y7V%C
M=&EO;BP@:&ES=&]R>5]D97-C+"!H:7-T;W)Y7W=H;RP@:&ES=&]R>5]T<RP@
M:&ES=&]R>5]E>'1R82DG("X*("`@("`@("`G(%9!3%5%4R`H/RP@/RP@/RP@
M/RP@/RP@/RP@/RDG.PH*)&%L;"`]("1D871A=')E92T^9V5T*$1!5$%44D5%
M7T9/4DU!5%]&3$%4+"!$051!5%)%15]23T]4+"!T<G5E*3L*=6YS970H)&%L
M;%M$051!5%)%15]23T]472D["B1I9',@/2!A<G)A>5]K97ES*"1A;&PI.PH*
M9F]R96%C:"`H)&ED<R!A<R`D:60I('L*("`@("1O8B`]("1D871A=')E92T^
M9V5T3V)J96-T0GE)9"@D:60L("=$871A5')E94]B:F5C=%](:7-T;W)Y)RD[
M"B`@("!F;W)E86-H("@D;V(M/F=E=$1A=&$H*2!A<R`D<F]W*2!["B`@("`@
M("`@)'9A;'5E<R`](&%R<F%Y*"1D8BT^;F5X=$ED*"=H;W)D95]H:7-T;W)I
M97,G*2P@("`@("`@("`@("`@("`@("`O+R!H:7-T;W)Y7VED"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O8BT^9V5T3F%M92@I+"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!O8FIE8W1?=6ED"B`@("`@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1R;W=;)V%C=&EO;B==*2`_("1R;W=;)V%C
M=&EO;B==(#H@;G5L;"P@("`O+R!H:7-T;W)Y7V%C=&EO;@H@("`@("`@("`@
M("`@("`@("`@("`@("!I<W-E="@D<F]W6R=D97-C)UTI(#\@)')O=ULG9&5S
M8R==(#H@;G5L;"P@("`@("`@+R\@:&ES=&]R>5]D97-C"B`@("`@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1R;W=;)W=H;R==*2`_("1R;W=;)W=H;R==
M(#H@;G5L;"P@("`@("`@("`O+R!H:7-T;W)Y7W=H;PH@("`@("`@("`@("`@
M("`@("`@("`@("!I<W-E="@D<F]W6R=T<R==*2`_("1R;W=;)W1S)UT@.B!N
M=6QL+"`@("`@("`@("`@+R\@:&ES=&]R>5]T<PH@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH*("`@("`@("!U;G-E="@D<F]W6R=A8W1I;VXG72D["B`@
M("`@("`@=6YS970H)')O=ULG9&5S8R==*3L*("`@("`@("!U;G-E="@D<F]W
M6R=W:&\G72D["B`@("`@("`@=6YS970H)')O=ULG=',G72D["B`@("`@("`@
M:68@*&-O=6YT*"1R;W<I*2!["B`@("`@("`@("`@("1V86QU97-;72`]('-E
M<FEA;&EZ92@D<F]W*3L@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!H:7-T;W)Y7V5X=')A"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'9A;'5E<UM=(#T@;G5L;#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&AI<W1O<GE?97AT<F$*("`@("`@("!]
M"@H@("`@("`@(&-H96-K*"1D8BT^<75E<GDH)&ES<6PL("1V86QU97,I*3L*
M("`@('T*"B`@("!C:&5C:R@D9&(M/G%U97)Y*"=$14Q%5$4@1E)/32!H;W)D
M95]D871A=')E95]A='1R:6)U=&5S(%=(15)%(&1A=&%T<F5E7VED(#T@/R<L
M(&%R<F%Y*"1I9"DI*3L*("`@(&-H96-K*"1D8BT^<75E<GDH)T1%3$5412!&
M4D]-(&AO<F1E7V1A=&%T<F5E(%=(15)%(&1A=&%T<F5E7VED(#T@/R<L(&%R
M<F%Y*"1I9"DI*3L*?0H*)&-L:2T^=W)I=&5L;B@D8VQI+3YG<F5E;B@B1&]N
M92X@36EG<F%T960@(B`N(&-O=6YT*"1I9',I("X@(B!O8FIE8W1S+B(I*3L*
M"F9U;F-T:6]N(&-H96-K*"1R97-U;'0I"GL*("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("!V87)?9'5M<"@D<F5S=6QT
M*3L*("`@("`@("!E>&ET.PH@("`@?0I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(P,#8M,#8M,CE?:&]R9&5?<')E9G-?
M:6YD97AE<RYS<6P``````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-34Q`#$P-3$U-#,Q,#8T`#`R-34W-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+2!4
M:&ES('-C<FEP="!A9&1S(&%D9&ET:6]N86P@:6YD97AE<R!T;R!T:&4@:&]R
M9&5?<')E9G,@=&%B;&4@=&AA="!S:&]U;&0*+2T@:6UP<F]V92!L;V%D:6YG
M(&]F('!R969E<F5N8V5S(&9R;VT@=&AE('!R969E<F5N8V4@=&%B;&4N"BTM
M"BTM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R,#`V+3`V+3(Y
M7VAO<F1E7W!R969S7VEN9&5X97,N<W%L+'8@,2XQ+C(N,2`R,#`V+S`V+S(Y
M(#$V.C(Y.C`S(&IA;B!%>'`@)`H*0U)%051%($E.1$58('!R969?=6ED7VED
M>"!/3B!H;W)D95]P<F5F<R`H<')E9E]U:60I.PI#4D5!5$4@24Y$15@@<')E
M9E]S8V]P95]I9'@@3TX@:&]R9&5?<')E9G,@*'!R969?<V-O<&4I.PH*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T
M<R]U<&=R861E<R\R+C)?=&]?,RXP+G!G<W%L+G-Q;```````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#<Q,``Q,#4Q-30S,3`V-``P,C,Q-#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2T@66]U(&-A;B!S:6UP
M;'D@97AE8W5T92!T:&ES(&9I;&4@:6X@>6]U<B!D871A8F%S92X*+2T*+2T@
M4G5N(&%S.@HM+0HM+2`D('!S<6P@/&1B(&YA;64^("UF(#(N,E]T;U\S+C`N
M<&]S=&=R97-Q;"YS<6P*"D)%1TE..PI!3%1%4B!404),12!H;W)D95]P<F5F
M<R!!1$0@0T],54U.('!R969?=6ED7VYE=R!605)#2$%2*#(P,"D["E501$%4
M12!H;W)D95]P<F5F<R!3150@<')E9E]U:61?;F5W(#T@<')E9E]U:60["D%,
M5$52(%1!0DQ%(&AO<F1E7W!R969S($123U`@<')E9E]U:60["D%,5$52(%1!
M0DQ%(&AO<F1E7W!R969S(%)%3D%-12!P<F5F7W5I9%]N97<@5$\@<')E9E]U
M:60["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($%,5$52($-/3%5-3B!P<F5F
M7W5I9"!3150@3D]4($Y53$P["D-/34U)5#L*1$5,151%($923TT@:&]R9&5?
M<')E9G,@5TA%4D4@<')E9E]N86UE(#T@)VQA<W1?;&]G:6XG($%.1"!P<F5F
M7W-C;W!E(#T@)VEM<"<["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@
M*`H@("`@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@("`@9W)O
M=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@('5S97)?=6ED
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?<&%R96YT
M<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]O<F1E
M<B!)3E0L"B`@("`@("!D871A=')E95]D871A(%1%6%0L"B`@("`@("!D871A
M=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*
M("`@("`@(&1A=&%T<F5E7W5P9&%T960@5$E-15-404U0+`H*("`@("`@(%!2
M24U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A
M=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T
M871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@
M3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D
M871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I
M.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R
M9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*0U)%051%(%1!
M0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?
M:60@24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2D@
M1$5&055,5"`G)R!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]V86QU92!415A4
M"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H
M;W)D95]D871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%4
M12!)3D1%6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T
M871R965?871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@
M5$\@:&]R9&4["D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S(%1/(&AO<F1E.PH*0U)%
M051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`@("!T;VME;E]A9&1R97-S("`@
M(%9!4D-(05(H."D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@(%9!
M4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@=&]K96Y?=&EM97-T86UP("!"24=)
M3E0@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L
M('1O:V5N7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@
M1$5,151%($].(&AO<F1E7W1O:V5N<R!43R!H;W)D93L*"D-214%412!404),
M12!H;W)D95]V9G,@*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@
M=F9S7W!A=&@@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?
M;F%M92`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I
M9FEE9"`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?9&%T82`@("`@(%1%6%0L"@H@
M("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F
M<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.
M1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V
M9G,@5$\@:&]R9&4["@H`````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?,RXP+FUY<W%L+G-Q;```
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8W-P`Q,#4Q-30S,3`V-``P,C,Q-S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+2T@
M)$AO<F1E.B!H;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(N,E]T;U\S+C`N;7ES
M<6PN<W%L+'8@,2XR+C@N,B`R,#`U+S$P+S$X(#$Q.C,T.C`Q(&IA;B!%>'`@
M)`HM+0HM+2!9;W4@8V%N('-I;7!L>2!E>&5C=71E('1H:7,@9FEL92!I;B!Y
M;W5R(&1A=&%B87-E+@HM+0HM+2!2=6X@87,Z"BTM"BTM("0@;7ES<6P@+2UU
M<V5R/7)O;W0@+2UP87-S=V]R9#T\37E344PM<F]O="UP87-S=V]R9#X@/&1B
M(&YA;64^(#P@,BXR7W1O7S,N,"YM>7-Q;"YS<6P*"E5312!H;W)D93L*"D%,
M5$52(%1!0DQ%(&AO<F1E7W!R969S($-(04Y'12!#3TQ534X@<')E9E]U:60@
M<')E9E]U:60@5D%20TA!4B@R,#`I($Y/5"!.54Q,.PI$14Q%5$4@1E)/32!H
M;W)D95]P<F5F<R!72$5212!P<F5F7VYA;64@/2`G;&%S=%]L;V=I;B<@04Y$
M('!R969?<V-O<&4@/2`G:6UP)SL*"D-214%412!404),12!H;W)D95]D871A
M=')E92`H"B`@("`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("`@
M("!G<F]U<%]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@=7-E
M<E]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?
M;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]P
M87)E;G1S(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E
M7V]R9&5R($E.5"P*("`@("`@(&1A=&%T<F5E7V1A=&$@5$585"P*("`@("`@
M(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&055,5"`P($Y/5"!.
M54Q,+`H@("`@("`@9&%T871R965?=7!D871E9"!424U%4U1!35`L"@H@("`@
M("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI.PH*0U)%051%($E.1$58
M(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E
M("AD871A=')E95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P
M7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O=7!?=6ED*3L*0U)%051%($E.
M1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R
M7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/
M3B!H;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@I#4D5!
M5$4@5$%"3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A
M=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H
M,C4U*2!$149!54Q4("<G($Y/5"!.54Q,+`H@("`@871T<FEB=71E7W9A;'5E
M(%1%6%0**3L*"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:61X
M($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED*3L*
M0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE7VED>"!/3B!H
M;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?;F%M92D["D-2
M14%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED>"!/3B!H;W)D
M95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y*3L*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A
M=')E92!43R!H;W)D94!L;V-A;&AO<W0["D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M(%1/(&AO<F1E0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]T;VME
M;G,@*`H@("`@=&]K96Y?861D<F5S<R`@("!605)#2$%2*#@I($Y/5"!.54Q,
M+`H@("`@=&]K96Y?:60@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*
M("`@('1O:V5N7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`H*("`@(%!2
M24U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D**3L*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]T;VME
M;G,@5$\@:&]R9&5`;&]C86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W9F
M<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F
M<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)
M3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@3$].1T),3T(L"@H@("`@4%))
M34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H
M7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F
M<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@
M:&]R9&5`;&]C86QH;W-T.PH`````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?,RXP
M+F]C:3@N<W%L````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#0W,P`Q,#4Q-30S
M,3`V-``P,C(V-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(N
M,E]T;U\S+C`N;V-I."YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#0O,#8@,C(Z-3,Z
M-#`@:F%N($5X<"`D"@I!3%1%4B!404),12!H;W)D95]P<F5F<R!-3T1)1ED@
M<')E9E]U:60@5D%20TA!4C(H,C4U*3L*04Q415(@5$%"3$4@:&]R9&5?<')E
M9G,@34]$2499('!R969?<V-O<&4@5D%20TA!4C(H,38I.PI!3%1%4B!404),
M12!H;W)D95]P<F5F<R!-3T1)1ED@<')E9E]N86UE(%9!4D-(05(R*#,R*3L*
M55!$051%(&AO<F1E7W!R969S(%-%5"!P<F5F7W5I9"`](%)44DE-*'!R969?
M=6ED*3L*55!$051%(&AO<F1E7W!R969S(%-%5"!P<F5F7W-C;W!E(#T@4E12
M24TH<')E9E]S8V]P92D["E501$%412!H;W)D95]P<F5F<R!3150@<')E9E]N
M86UE(#T@4E1224TH<')E9E]N86UE*3L*"D1%3$5412!&4D]-(&AO<F1E7W!R
M969S(%=(15)%('!R969?;F%M92`]("=L87-T7VQO9VEN)R!!3D0@<')E9E]S
M8V]P92`]("=I;7`G.PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*
M("`@(&1A=&%T<F5E7VED("`@("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL
M"B`@("!G<F]U<%]U:60@("`@("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.
M54Q,+`H@("`@=7-E<E]U:60@("`@("`@("`@("`@5D%20TA!4C(H,C4U*2P*
M("`@(&1A=&%T<F5E7VYA;64@("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y5
M3$PL"B`@("!D871A=')E95]P87)E;G1S("`@("!605)#2$%2,B@R-34I+`H@
M("`@9&%T871R965?;W)D97(@("`@("`@3E5-0D52*#$V*2P*("`@(&1A=&%T
M<F5E7V1A=&$@("`@("`@($-,3T(L"B`@("!D871A=')E95]S97)I86QI>F5D
M("!.54U"15(H."D@1$5&055,5"`P($Y/5"!.54Q,+`H@("`@9&%T871R965?
M=7!D871E9"`@("`@1$%412P*"B`@("!04DE-05)9($M%62`H9&%T871R965?
M:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R965?;F%M95]I
M9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG
M<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E<E]I9'@@3TX@
M:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.1$58(&1A=&%T
M<F5E7V]R9&5R7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;W)D
M97(I.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@
M:&]R9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*0U)%051%
M(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R
M965?:60@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@871T<FEB=71E
M7VYA;64@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E
M7VME>2`@("!605)#2$%2,B@R-34I+`H@("`@871T<FEB=71E7W9A;'5E("!6
M05)#2$%2,B@T,#`P*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I
M8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H9&%T871R
M965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VYA;65?
M:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]N
M86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K97E?:61X
M($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]K97DI
M.PH*0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`@("!T;VME;E]A9&1R
M97-S("`@(%9!4D-(05(R*#$P,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@
M("`@("`@(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S
M=&%M<"`@3E5-0D52*#$V*2!.3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H
M=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD["@I#4D5!5$4@5$%"3$4@:&]R
M9&5?=F9S("@*("`@('9F<U]I9"`@("`@("`@3E5-0D52*#$V*2!.3U0@3E5,
M3"P*("`@('9F<U]T>7!E("`@("`@3E5-0D52*#@I($Y/5"!.54Q,+`H@("`@
M=F9S7W!A=&@@("`@("!605)#2$%2,B@R-34I+`H@("`@=F9S7VYA;64@("`@
M("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!.
M54U"15(H,38I($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2
M,B@R-34I+`H@("`@=F9S7V1A=&$@("`@("!"3$]"+`H*("`@(%!224U!4ED@
M2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@
M3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M
M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E
M<R\S+C!?=&]?,RXQ+FUY<W%L+G-Q;```````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3<R-``Q,#4Q-30S,3`V-``P,C,Q-C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W5P9W)A9&5S+S,N,%]T;U\S+C$N;7ES<6PN<W%L+'8@,2XQ+C(N,2`R,#`V
M+S`Q+S`V(#$P.C0Q.C$S(&IA;B!%>'`@)`HM+0HM+2!9;W4@8V%N('-I;7!L
M>2!E>&5C=71E('1H:7,@9FEL92!I;B!Y;W5R(&1A=&%B87-E+@HM+0HM+2!2
M=6X@87,Z"BTM"BTM("0@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S=V]R9#T\
M37E344PM<F]O="UP87-S=V]R9#X@/&1B(&YA;64^(#P@,RXP7W1O7S,N,2YM
M>7-Q;"YS<6P*"D%,5$52(%1!0DQ%(&AO<F1E7W5S97)S($%$1"!#3TQ534X@
M=7-E<E]S;V9T7V5X<&ER871I;VY?9&%T92!)3E0["D%,5$52(%1!0DQ%(&AO
M<F1E7W5S97)S($%$1"!#3TQ534X@=7-E<E]H87)D7V5X<&ER871I;VY?9&%T
M92!)3E0["@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@(&AI
M<W1O<GE?:60@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I
M9"`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C
M=&EO;B`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@
M("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@(%1%
M6%0L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*("`@(&AI
M<W1O<GE?97AT<F$@("`@5$585"P*+2T*("`@(%!224U!4ED@2T59("AH:7-T
M;W)Y7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/
M3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.
M1$58(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R
M>5]T<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?
M:&ES=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@:&]R9&5`
M;&]C86QH;W-T.PH`````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U
M<&=R861E<R\S+C!?=&]?,RXQ+F]C:3@N<W%L````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,3,U-``Q,#4Q-30S,3`V-``P,C(V-C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N;V-I."YS<6PL=B`Q+C$N,BXQ
M(#(P,#8O,#0O,#8@,C(Z-3,Z-30@:F%N($5X<"`D"@I!3%1%4B!404),12!H
M;W)D95]U<V5R<R!!1$0@=7-E<E]S;V9T7V5X<&ER871I;VY?9&%T92!.54U"
M15(H,38I.PI!3%1%4B!404),12!H;W)D95]U<V5R<R!!1$0@=7-E<E]H87)D
M7V5X<&ER871I;VY?9&%T92!.54U"15(H,38I.PH*0U)%051%(%1!0DQ%(&AO
M<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($Y534)%4B@Q
M-BD@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED("`@("`@(%9!4D-(05(R*#(U
M-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO;B`@(%9!4D-(05(R*#,R
M*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@3E5-0D52*#$V*2!.
M3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@0TQ/0BP*("`@(&AI<W1O
M<GE?=VAO("`@("`@5D%20TA!4C(H,C4U*2P*("`@(&AI<W1O<GE?97AT<F$@
M("`@0TQ/0BP*"B`@("!04DE-05)9($M%62`H:&ES=&]R>5]I9"D**3L*"D-2
M14%412!)3D1%6"!H:7-T;W)Y7V%C=&EO;E]I9'@@3TX@:&]R9&5?:&ES=&]R
M:65S("AH:7-T;W)Y7V%C=&EO;BD["D-214%412!)3D1%6"!H:7-T;W)Y7W1S
M7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?=',I.PI#4D5!5$4@
M24Y$15@@:&ES=&]R>5]U:61?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H;V)J
M96-T7W5I9"D["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]U<&=R861E<R\R,#`U+3`Y+3(R7VAO<F1E7W!R969S7W9A<F-H87(R
M+F]C:3@N<W%L```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3$W,P`Q,#4Q-30S,3`V-``P,C8U,#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2T@57-E('1H:7,@
M<V-R:7!T('1O(&-O;G9E<G0@0TA!4B!C;VQU;6YS(&EN(&AO<F1E7W!R969S
M('1O(%9!4D-(05(R(&%N9"!T<FEM"BTM('1H92!S<&%C92!P861D:6YG+B`@
M5&AI<R!I<R!O;FQY(&YE8V5S<V%R>2!I9B!H;W)D95]P<F5F<R!W87,@8W)E
M871E9"!U<VEN9PHM+2!S8W)I<'1S+W-Q;"]C<F5A=&4N;V-I."YS<6P*+2T*
M+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(P,#4M,#DM,C)?
M:&]R9&5?<')E9G-?=F%R8VAA<C(N;V-I."YS<6PL=B`Q+C$N,BXQ(#(P,#4O
M,3`O,3@@,3$Z,S0Z,#$@:F%N($5X<"`D"BTM"D%,5$52(%1!0DQ%(&AO<F1E
M7W!R969S($U/1$E&62!P<F5F7W5I9"!605)#2$%2,B@R-34I.PI!3%1%4B!4
M04),12!H;W)D95]P<F5F<R!-3T1)1ED@<')E9E]S8V]P92!605)#2$%2,B@Q
M-BD["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($U/1$E&62!P<F5F7VYA;64@
M5D%20TA!4C(H,S(I.PI54$1!5$4@:&]R9&5?<')E9G,@4T54('!R969?=6ED
M(#T@4E1224TH<')E9E]U:60I.PI54$1!5$4@:&]R9&5?<')E9G,@4T54('!R
M969?<V-O<&4@/2!25%))32AP<F5F7W-C;W!E*3L*55!$051%(&AO<F1E7W!R
M969S(%-%5"!P<F5F7VYA;64@/2!25%))32AP<F5F7VYA;64I.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?,RXQ+G-Q;```````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3,S-@`Q,#4Q-30S,3`V-``P,C(P,C``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@)$AO
M<F1E.B!H;W)D92]S8W)I<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N<W%L+'8@
M,2XQ+C(N,2`R,#`V+S`S+S(Y(#(Q.C(W.C4R(&IA;B!%>'`@)`H*04Q415(@
M5$%"3$4@:&]R9&5?=7-E<G,@041$($-/3%5-3B!U<V5R7W-O9G1?97AP:7)A
M=&EO;E]D871E($E.5#L*04Q415(@5$%"3$4@:&]R9&5?=7-E<G,@041$($-/
M3%5-3B!U<V5R7VAA<F1?97AP:7)A=&EO;E]D871E($E.5#L*"D-214%412!4
M04),12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES=&]R>5]I9"`@("`@("!"
M24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED("`@("`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T:6]N("`@5D%20TA!4B@S
M,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@("`@($))1TE.5"!.3U0@
M3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@5$585"P*("`@(&AI<W1O<GE?
M=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@:&ES=&]R>5]E>'1R82`@("!4
M15A4+`HM+0H@("`@4%))34%262!+15D@*&AI<W1O<GE?:60I"BD["@I#4D5!
M5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X($].(&AO<F1E7VAI<W1O<FEE
M<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]T<U]I
M9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7W1S*3L*0U)%051%($E.
M1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&]B:F5C
M=%]U:60I.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V-R:7!T<R]S<6PO````````````````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,38W
M,#$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N
M;V-I."YS<6P`````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,3`U
M`#$P-3$U-#,Q,#8T`#`R,34R,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!S970@9&]C(&]F9CL*<V5T('-Q;&)L86YK;&EN
M97,@;VX["@HO*BH*("H@3W)A8VQE(%1A8FQE($-R96%T:6]N(%-C<FEP=',N
M"B`J(`H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YO8VDX
M+G-Q;"QV(#$N-"XX+C$P(#(P,#8O,#8O,CD@,38Z,CDZ,#,@:F%N($5X<"`D
M"B`J(`H@*B!`875T:&]R($UI9W5E;"!787)D(#QM=V%R9$!A;'5A<BYC;VTN
M87(^"B`J(`H@*B!4:&ES('-Q;"!C<F5A=&5S('1H92!(;W)D92!344P@=&%B
M;&5S(&EN(&%N($]R86-L92`X+G@@9&%T86)A<V4N(%-H;W5L9`H@*B!W;W)K
M('=I=&@@3W)A8VQE(#DN>"`H86YD($]R86-L93<@=7-I;F<@=F%R8VAA<C(I
M+@H@*B`*("H@3F]T97,Z"B`J(`H@*B`@*B!/8G9I;W5S;'D@>6]U(&UU<W0@
M:&%V92!/<F%C;&4@:6YS=&%L;&5D(&]N('1H:7,@;6%C:&EN92!!3D0@>6]U
M(&UU<W0*("H@("`@:&%V92!C;VUP:6QE9"!02%`@=VET:"!/<F%C;&4@*'EO
M=2!I;F-L=61E9"`M+7=I=&@M;V-I."UI;G-T86YT"B`J("`@("TM=VET:"UO
M8VDX(&]R(&EN('1H92!B=6EL9"!A<F=U;65N=',@9F]R(%!(4"P@;W(@=6YC
M;VUM96YT960@=&AE(&]C:3@*("H@("`@97AT96YS:6]N(&EN('!H<"YI;FDI
M+@H@*B`*("H@("H@268@>6]U(&1O;B=T('5S92!T:&4@26YS=&%N="!#;&EE
M;G0L(&UA:V4@<W5R92!T:&%T('1H92!U<V5R('1H870@<W1A<G1S"B`J("`@
M('5P($%P86-H92`H=7-U86QL>2!N;V)O9'D@;W(@=W=W+61A=&$I(&AA<R!T
M:&4@9F]L;&]W:6YG(&5N=FER;VYM96YT"B`J("`@('9A<FEA8FQE<R!D969I
M;F5D.@H@*B`*("H@("`@97AP;W)T($]204-,15](3TU%/2]H;VUE+V]R86-L
M92]/<F%(;VUE,0H@*B`@("!E>'!O<G0@3U)!7TY,4STO:&]M92]O<F%C;&4O
M3W)A2&]M93$O;V-O;6UO;B]N;',O861M:6XO9&%T80H@*B`@("!E>'!O<G0@
M3U)!7TY,4S,S/2]H;VUE+V]R86-L92]/<F%(;VUE,2]O8V]M;6]N+VYL<R]A
M9&UI;B]D871A"B`J("`@(&5X<&]R="!,1%],24)205)97U!!5$@])$]204-,
M15](3TU%+VQI8CHD3$1?3$E"4D%265]0051("B`J(`H@*B`@("!93U4@3553
M5"!#55-43TU)6D4@5$A%4T4@5D%,5453(%1/($)%($%04%)/4%))051%(%1/
M(%E/55(@24Y35$%,3$%424]."B`J(`H@*B`@("!9;W4@8V%N(&EN8VQU9&4@
M=&AE<V4@=F%R:6%B;&5S(&EN('1H92!U<V5R)W,@;&]C86P@+G!R;V9I;&4@
M;W(@:6X*("H@("`@+V5T8R]P<F]F:6QE+"!E=&,N"B`J(`H@*B`@*B!.;R!G
M<F%N=',@87)E(&YE8V5S<V%R>2!S:6YC92!W92!C;VYN96-T(&%S('1H92!O
M=VYE<B!O9B!T:&4@=&%B;&5S+B!)9@H@*B`@("!Y;W4@=VES:"!Y;W4@8V%N
M(&%D87!T('1H92!C<F5A=&EO;B!O9B!T86)L97,@=&\@:6YC;'5D92!T86)L
M97-P86-E(&%N9`H@*B`@("!S=&]R86=E(&EN9F]R;6%T:6]N+B!3:6YC92!W
M92!I;F-L=61E(&YO;F4@:70@=VEL;"!U<V4@=&AE(&1E9F%U;'0*("H@("`@
M=&%B;&5S<&%C92!V86QU97,@9F]R('1H92!U<V5R(&-R96%T:6YG('1H97-E
M('1A8FQE<RX@4V%M92!W:71H('1H90H@*B`@("!I;F1E>&5S("AI;B!T:&5O
M<GD@=&AE<V4@<VAO=6QD('5S92!A(&1I9F9E<F5N="!T86)L97-P86-E*2X*
M("H@"B`J("`J(%1H97)E(&ES(&YO(&YE960@=&\@<VAU="!D;W=N(&%N9"!S
M=&%R="!U<"!T:&4@9&%T86)A<V4A"B`J+PH*<F5M(&-O;FX@:&]R9&4O)FAO
M<F1E7W!A<W-W;W)D0&1A=&%B87-E"@HO*BH*("H@5&AI<R!I<R!T:&4@2&]R
M9&4@=7-E<G,@=&%B;&4L(&YE961E9"!O;FQY(&EF('EO=2!A<F4@=7-I;F<@
M4U%,"B`J(&%U=&AE;G1I8V%T:6]N+B`@3F]T92!T:&%T('!A<W-O=W)D<R!I
M;B!T:&ES('1A8FQE(&YE960@=&\@8F4@;60U+65N8V]D960N"B`J+PH*0U)%
M051%(%1!0DQ%(&AO<F1E7W5S97)S("@*("`@('5S97)?=6ED("`@("`@("`@
M("`@("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]P
M87-S("`@("`@("`@("`@("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL
M"B`@("!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E("`@3E5-0D52*#$V*2P*
M("`@('5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4@("!.54U"15(H,38I+`H*
M("`@(%!224U!4ED@2T59("AU<V5R7W5I9"D**3L*"@HO*BH*("H@5&AI<R!I
M<R!T:&4@2&]R9&4@<')E9F5R96YC97,@=&%B;&4L(&AO;&1I;F<@86QL(&]F
M('1H92!U<V5R+7-P96-I9FEC"B`J(&]P=&EO;G,@9F]R(&5V97)Y($AO<F1E
M('5S97(N"B`J(`H@*B!P<F5F7W5I9"`@(&ES('1H92!U<V5R;F%M92X*("H@
M<')E9E]S8V]P92!I<R!T:&4@87!P;&EC871I;VX@=&AE('!R968@8F5L;VYG
M<R!T;RX*("H@<')E9E]N86UE("!I<R!T:&4@;F%M92!O9B!T:&4@=F%R:6%B
M;&4@=&\@<V%V92X*("H@<')E9E]V86QU92!I<R!T:&4@=F%L=64@<V%V960@
M*&-A;B!B92!V97)Y(&QO;F<I+@H@*B`*("H@5V4@=7-E(&$@0TQ/0B!C;VQU
M;6X@<V\@=&AA="!L;VYG97(@8V]L=6UN('9A;'5E<R!A<F4@<W5P<&]R=&5D
M+@H@*B`*("H@268@<W1I;&P@=7-I;F<@3W)A8VQE(#<@=&AI<R!S:&]U;&0@
M=V]R:R!B=70@>6]U(&AA=F4@=&\@=7-E"B`J(%9!4D-(05(R*#(P,#`I('=H
M:6-H(&ES('1H92!L:6UI="!I;7!O<V5D(&)Y('-A:60@=F5R<VEO;BX*("HO
M"@I#4D5!5$4@5$%"3$4@:&]R9&5?<')E9G,@*`H@("`@<')E9E]U:60@("`@
M5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@('!R969?<V-O<&4@(%9!4D-(
M05(R*#$V*2!.3U0@3E5,3"P*("`@('!R969?;F%M92`@(%9!4D-(05(R*#,R
M*2!.3U0@3E5,3"P*+2T@(%-E92!A8F]V92!N;W1E<R!O;B!#3$]"<RX*("`@
M('!R969?=F%L=64@($-,3T(L"@H@("`@4%))34%262!+15D@*'!R969?=6ED
M+"!P<F5F7W-C;W!E+"!P<F5F7VYA;64I"BD["@I#4D5!5$4@24Y$15@@<')E
M9E]U:61?:61X($].(&AO<F1E7W!R969S("AP<F5F7W5I9"D["D-214%412!)
M3D1%6"!P<F5F7W-C;W!E7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]S8V]P
M92D["@H*+RHJ"B`J(%1H92!$871A5')E92!T86)L97,@87)E('5S960@9F]R
M(&AO;&1I;F<@:&EE<F%R8VAI8V%L(&1A=&$@<W5C:"!A<R!'<F]U<',L"B`J
M(%!E<FUI<W-I;VYS+"!A;F0@9&%T82!F;W(@<V]M92!(;W)D92!A<'!L:6-A
M=&EO;G,N"B`J+PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@
M(&1A=&%T<F5E7VED("`@("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@
M("!G<F]U<%]U:60@("`@("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,
M+`H@("`@=7-E<E]U:60@("`@("`@("`@("`@5D%20TA!4C(H,C4U*2P*("`@
M(&1A=&%T<F5E7VYA;64@("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL
M"B`@("!D871A=')E95]P87)E;G1S("`@("!605)#2$%2,B@R-34I+`H@("`@
M9&%T871R965?;W)D97(@("`@("`@3E5-0D52*#$V*2P*("`@(&1A=&%T<F5E
M7V1A=&$@("`@("`@($-,3T(L"B`@("!D871A=')E95]S97)I86QI>F5D("!.
M54U"15(H."D@1$5&055,5"`P($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59
M("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D871A
M=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M
M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?
M9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]U
M<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?;W)D97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AD
M871A=')E95]O<F1E<BD["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI
M>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE
M9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M"B`@("!D871A=')E95]I9"`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@
M("!A='1R:6)U=&5?;F%M92`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@
M("!A='1R:6)U=&5?:V5Y("`@(%9!4D-(05(R*#(U-2DL"B`@("!A='1R:6)U
M=&5?=F%L=64@(%9!4D-(05(R*#0P,#`I"BD["@I#4D5!5$4@24Y$15@@9&%T
M871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%6"!D871A=')E95]A='1R
M:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB
M=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T
M<FEB=71E7VME>2D["@H*0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`@
M("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(R*#$P,"D@3D]4($Y53$PL"B`@
M("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@
M('1O:V5N7W1I;65S=&%M<"`@3E5-0D52*#$V*2!.3U0@3E5,3"P*"B`@("!0
M4DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD["@H*0U)%
M051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@("`@("`@($Y534)%
M4B@Q-BD@3D]4($Y53$PL"B`@("!V9G-?='EP92`@("`@($Y534)%4B@X*2!.
M3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%20TA!4C(H,C4U*2P*("`@
M('9F<U]N86UE("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@('9F
M<U]M;V1I9FEE9"`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@('9F<U]O=VYE
M<B`@("`@5D%20TA!4C(H,C4U*2P*("`@('9F<U]D871A("`@("`@0DQ/0BP*
M"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@
M=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@
M24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*
M"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES=&]R>5]I
M9"`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@
M("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I
M;VX@("!605)#2$%2,B@S,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@
M("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@
M($-,3T(L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(R*#(U-2DL"B`@
M("!H:7-T;W)Y7V5X=')A("`@($-,3T(L"@H@("`@4%))34%262!+15D@*&AI
M<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X
M($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@
M24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T
M;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D
M95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*"D-214%412!404),12!H;W)D
M95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED("`@("`@("`@("`@
M(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO9&EF
M:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]D871A("`@("`@("`@
M("!"3$]"+`H*("`@(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI.PH*"F5X
M:70*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YM>7-Q
M;"YS<6P`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(S,#<`,3`U
M,34T,S$P-C0`,#(R,#,Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO8W)E
M871E+FUY<W%L+G-Q;"QV(#$N-"XV+CD@,C`P-B\P-R\P-2`Q-3HU,SHQ,"!J
M86X@17AP("0*+2T*+2T@268@>6]U(&%R92!I;G-T86QL:6YG($AO<F1E(&9O
M<B!T:&4@9FER<W0@=&EM92P@>6]U(&-A;B!S:6UP;'D*+2T@9&ER96-T('1H
M:7,@9FEL92!T;R!M>7-Q;"!A<R!35$1)3CH*+2T*+2T@)"!M>7-Q;"`M+75S
M97(]<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\(&-R
M96%T92YM>7-Q;"YS<6P*+2T*+2T@268@>6]U(&%R92!U<&=R861I;F<@9G)O
M;2!A('!R979I;W5S('9E<G-I;VXL('EO=2!W:6QL(&YE960@=&\@8V]M;65N
M=`HM+2!O=70@=&AE('1H92!U<V5R(&-R96%T:6]N('-T97!S(&)E;&]W+"!A
M<R!W96QL(&%S('1H92!S8VAE;6%S(&9O<B!A;GD*+2T@=&%B;&5S('1H870@
M86QR96%D>2!E>&ES="X*+2T*+2T@268@>6]U(&-H;V]S92!T;R!G<F%N="!P
M97)M:7-S:6]N<R!M86YU86QL>2P@;F]T92!T:&%T('=I=&@@37E344PL(%!%
M05(@1$(*+2T@96UU;&%T97,@<V5Q=65N8V5S(&)Y(&%U=&]M871I8V%L;'D@
M8W)E871I;F<@97AT<F$@=&%B;&5S(&5N9&EN9R!I;B!?<V5Q+`HM+2!S;R!T
M:&4@37E344P@(FAO<F1E(B!U<V5R(&UU<W0@:&%V92!#4D5!5$4@<')I=FEL
M96=E(&]N('1H92`B:&]R9&4B"BTM(&1A=&%B87-E+@HM+0HM+2!)9B!Y;W4@
M87)E('5P9W)A9&EN9R!F<F]M($AO<F1E(#$N>"P@=&AE($AO<F1E('1A8FQE
M<R!Y;W4@:&%V92!F<F]M"BTM('1H870@=F5R<VEO;B!A<F4@;F\@;&]N9V5R
M('5S960[('EO=2!M87D@=VES:"!T;R!E:71H97(@9&5L971E('1H;W-E"BTM
M('1A8FQE<R!O<B!S:6UP;'D@<F5C<F5A=&4@=&AE(&1A=&%B87-E(&%N97<N
M"@I54T4@;7ES<6P["@I215!,04-%($E.5$\@=7-E<B`H:&]S="P@=7-E<BP@
M<&%S<W=O<F0I"B`@("!604Q515,@*`H@("`@("`@("=L;V-A;&AO<W0G+`H@
M("`@("`@("=H;W)D92<L"@E005-35T]21"@G0%=%0DU!24Q?4$%34U=/4D1`
M)RD**3L*"E)%4$Q!0T4@24Y43R!D8B`H:&]S="P@9&(L('5S97(L('-E;&5C
M=%]P<FEV+"!I;G-E<G1?<')I=BP@=7!D871E7W!R:78L"B`@("`@("`@("`@
M("`@("`@9&5L971E7W!R:78L(&-R96%T95]P<FEV+"!D<F]P7W!R:78L(&EN
M9&5X7W!R:78I"B`@("!604Q515,@*`H@("`@("`@("=L;V-A;&AO<W0G+`H@
M("`@("`@("=H;W)D92<L"B`@("`@("`@)VAO<F1E)RP*("`@("`@("`G62<L
M("=9)RP@)UDG+"`G62<L"B`@("`@("`@)UDG+"`G62<L("=9)PHI.PH*+2T@
M36%K92!S=7)E('1H870@<')I=FEL:6=E<R!A<F4@<F5L;V%D960N"D9,55-(
M(%!2259)3$5'15,["@HM+2!->5-13"`S+C(S+G@@87!P96%R<R!T;R!H879E
M(")#4D5!5$4@1$%404)!4T4@248@3D]4($5825-44R(@86YD"BTM(")#4D5!
M5$4@5$%"3$4@248@3D]4($5825-44R(@=VAI8V@@=V]U;&0@8F4@82!N:6-E
M('=A>2!T;R!H86YD;&4*+2T@<F5I;G-T86QL<R!G<F%C969U;&QY("AS;VUE
M9&%Y*2X@($9O<B!N;W<L(&1R;W`@=&AE(&1A=&%B87-E"BTM(&UA;G5A;&QY
M('1O(&%V;VED($-214%412!E<G)O<G,N"D-214%412!$051!0D%312!H;W)D
M93L*"E5312!H;W)D93L*"D-214%412!404),12!H;W)D95]U<V5R<R`H"B`@
M("!U<V5R7W5I9"`@("`@("`@("`@("`@("`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@=7-E<E]P87-S("`@("`@("`@("`@("`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<V]F=%]E>'!I<F%T:6]N7V1A
M=&4@("!)3E0L"B`@("!U<V5R7VAA<F1?97AP:7)A=&EO;E]D871E("`@24Y4
M+`H*("`@(%!224U!4ED@2T59("AU<V5R7W5I9"D**3L*"D=204Y4(%-%3$5#
M5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]U<V5R<R!43R!H
M;W)D94!L;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?<')E9G,@*`H@
M("`@<')E9E]U:60@("`@("`@(%9!4D-(05(H,C`P*2!.3U0@3E5,3"P*("`@
M('!R969?<V-O<&4@("`@("!605)#2$%2*#$V*2!.3U0@3E5,3"!$149!54Q4
M("<G+`H@("`@<')E9E]N86UE("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,
M+`H@("`@<')E9E]V86QU92`@("`@($Q/3D=415A4($Y53$PL"@H@("`@4%))
M34%262!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P<F5F7VYA;64I"BD[
M"@I#4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO<F1E7W!R969S("AP
M<F5F7W5I9"D["D-214%412!)3D1%6"!P<F5F7W-C;W!E7VED>"!/3B!H;W)D
M95]P<F5F<R`H<')E9E]S8V]P92D["@I'4D%.5"!314Q%0U0L($E.4T525"P@
M55!$051%+"!$14Q%5$4@3TX@:&]R9&5?<')E9G,@5$\@:&]R9&5`;&]C86QH
M;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@("`@(&1A
M=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@("`@(&=R;W5P7W5I9"!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!U<V5R7W5I9"!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]N86UE(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7W!A<F5N=',@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?;W)D97(@24Y4+`H@("`@
M("`@9&%T871R965?9&%T82!415A4+`H@("`@("`@9&%T871R965?<V5R:6%L
M:7IE9"!334%,3$E.5"!$149!54Q4(#`@3D]4($Y53$PL"@H@("`@("`@4%))
M34%262!+15D@*&1A=&%T<F5E7VED*0HI.PH*0U)%051%($E.1$58(&1A=&%T
M<F5E7V1A=&%T<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A
M=')E95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/
M3B!H;W)D95]D871A=')E92`H9W)O=7!?=6ED*3L*0U)%051%($E.1$58(&1A
M=&%T<F5E7W5S97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D[
M"D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D
M95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"
M3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I
M9"!)3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2!$
M149!54Q4("<G($Y/5"!.54Q,+`H@("`@871T<FEB=71E7W9A;'5E(%1%6%0*
M*3L*"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:61X($].(&AO
M<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%051%
M($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE7VED>"!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?;F%M92D["D-214%412!)
M3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D871A
M=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y*3L*"D=204Y4(%-%3$5#
M5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E92!4
M3R!H;W)D94!L;V-A;&AO<W0["D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!
M5$4L($1%3$5412!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S(%1/(&AO
M<F1E0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]T;VME;G,@*`H@
M("`@=&]K96Y?861D<F5S<R`@("!605)#2$%2*#$P,"D@3D]4($Y53$PL"B`@
M("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@
M=&]K96Y?=&EM97-T86UP("!"24=)3E0@3D]4($Y53$PL"@H@("`@4%))34%2
M62!+15D@*'1O:V5N7V%D9')E<W,L('1O:V5N7VED*0HI.PH*1U)!3E0@4T5,
M14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W1O:V5N<R!4
M3R!H;W)D94!L;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*
M("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7W1Y
M<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($))1TE.5"!.
M3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@=F9S7V1A=&$@("`@("!,3TY'0DQ/0BP*"B`@("!04DE-05)9
M($M%62`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H7VED>"!/
M3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F<U]N86UE
M7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@:&]R9&5`
M;&]C86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H"B`@
M("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&]B:F5C
M=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@:&ES=&]R
M>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?
M=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C("`@
M("!415A4+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U-2DL"B`@
M("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L"@H@("`@4%))34%262!+15D@*&AI
M<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X
M($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@
M24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T
M;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D
M95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%
M4E0L(%501$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!43R!H;W)D
M94!L;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L
M97(@*`H@("`@<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#2$%2*#,R*2!.
M3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.
M54Q,+`H@("`@<V5S<VEO;E]D871A("`@("`@("`@("!,3TY'0DQ/0BP*"B`@
M("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D**2!%3D=)3D4@/2!);FYO1$([
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R
M9&5?<V5S<VEO;FAA;F1L97(@5$\@:&]R9&5`;&]C86QH;W-T.PH*1DQ54T@@
M4%))5DE,14=%4SL*"BTM($1O;F4A"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-Q;```````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`V-3``,3`U,34T,S$P-C0`,#(S-C(R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<W%L
M+'8@,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%4
M12!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED
M("`@("`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO
M;E]L87-T;6]D:69I960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A
M=&$@("`@("`@("`@($Q/3D="3$]"+`HM+2!/<BP@;VX@<V]M92!$0DU3('-Y
M<W1E;7,Z"BTM("!S97-S:6]N7V1A=&$@("`@("`@("`@($E-04=%+`H*("`@
M(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W-E<W-I;VYH86YD;&5R
M(%1/(&AO<F1E.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q
M;"]C<F5A=&4N;7-D92YS<6P`````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`V-#$P`#$P-3$U-#,Q,#8T`#`R,38Q,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<W%L+V-R96%T92YM<V1E+G-Q;"QV(#$N,2XR+C4@,C`P-B\P-B\R
M.2`Q-CHR.3HP,B!J86X@17AP("0*"E5312!M87-T97(*1T\*"D-214%412!$
M051!0D%312!H;W)D90I'3PH*15A%0R!S<%]A9&1L;V=I;B`G:&]R9&4G+"`G
M:&]R9&5?;6=R)RP@)VAO<F1E)PI'3PH*55-%(&AO<F1E"D=/"@I%6$5#('-P
M7V=R86YT9&)A8V-E<W,@)VAO<F1E)PI'3PH*0U)%051%(%1!0DQ%(&AO<F1E
M7W5S97)S("@*("`@('5S97)?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@('5S97)?<&%S<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"@H@("`@4%))
M34%262!+15D@*'5S97)?=6ED*0HI"D=/"@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&4*1T\*
M"D-214%412!404),12!H;W)D95]P<F5F<R`H"B`@("!P<F5F7W5I9"!605)#
M2$%2*#(P,"D@3D]4($Y53$PL"B`@("!P<F5F7W-C;W!E(%9!4D-(05(H,38I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"B`@("!P<F5F7VYA;64@5D%20TA!4B@S
M,BD@3D]4($Y53$PL"B`@("!P<F5F7W9A;'5E(%1%6%0@3E5,3"P*"B`@("!0
M4DE-05)9($M%62`H<')E9E]U:60L('!R969?<V-O<&4L('!R969?;F%M92D*
M*0I'3PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].
M(&AO<F1E7W!R969S(%1/(&AO<F1E"D=/"@I#4D5!5$4@24Y$15@@<')E9E]U
M:61?:61X($].(&AO<F1E7W!R969S("AP<F5F7W5I9"D*0U)%051%($E.1$58
M('!R969?<V-O<&5?:61X($].(&AO<F1E7W!R969S("AP<F5F7W-C;W!E*0I'
M3PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@(&1A=&%T<F5E
M7VED($E.5"!.3U0@3E5,3"P*("`@(&=R;W5P7W5I9"!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!U<V5R7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL
M"B`@("!D871A=')E95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M(&1A=&%T<F5E7W!A<F5N=',@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M9&%T871R965?;W)D97(@24Y4+`H@("`@9&%T871R965?9&%T82!415A4+`H@
M("`@9&%T871R965?<V5R:6%L:7IE9"!334%,3$E.5"!$149!54Q4(#`@3D]4
M($Y53$PL"@H@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI"D=/"@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M9&%T871R964@5$\@:&]R9&4*1T\*"D-214%412!)3D1%6"!D871A=')E95]D
M871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?
M;F%M92D*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D
M95]D871A=')E92`H9W)O=7!?=6ED*0I#4D5!5$4@24Y$15@@9&%T871R965?
M=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?=6ED*0I#4D5!5$4@
M24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?9&%T871R
M964@*&1A=&%T<F5E7W-E<FEA;&EZ960I"D=/"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)3E0@
M3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2!$149!54Q4
M("<G($Y/5"!.54Q,+`H@("`@871T<FEB=71E7W9A;'5E(%1%6%0**0I'3PH*
M1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E
M7V1A=&%T<F5E(%1/(&AO<F1E"D=/"@I#4D5!5$4@24Y$15@@9&%T871R965?
M871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AD
M871A=')E95]I9"D*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N
M86UE7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U
M=&5?;F%M92D*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K97E?
M:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]K
M97DI"D=/"@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS("@*("`@('1O:V5N
M7V%D9')E<W,@5D%20TA!4B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K96Y?:60@
M5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!T;VME;E]T:6UE<W1A;7`@0DE'
M24Y4($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S
M+"!T;VME;E]I9"D**0I'3PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7W1O:V5N<R!43R!H;W)D90I'3PH*0U)%051%
M(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@0DE'24Y4($Y/5"!.54Q,
M+`H@("`@=F9S7W1Y<&4@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T
M:"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@0DE'24Y4($Y/5"!.
M54Q,+`H@("`@=F9S7V]W;F5R(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M('9F<U]D871A(%1%6%0L"@H@("`@4%))34%262!+15D@("`H=F9S7VED*0HI
M"D=/"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@
M:&]R9&5?=F9S(%1/(&AO<F1E"D=/"@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?
M:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I"D-214%412!)3D1%6"!V9G-?
M;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D*1T\*"D-214%412!4
M04),12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES=&]R>5]I9"`@("`@("!"
M24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED("`@("`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T:6]N("`@5D%20TA!4B@S
M,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@("`@($))1TE.5"!.3U0@
M3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@5$585"P*("`@(&AI<W1O<GE?
M=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@:&ES=&]R>5]E>'1R82`@("!4
M15A4+`H*("`@(%!224U!4ED@2T59("AH:7-T;W)Y7VED*0HI"D=/"@I'4D%.
M5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES
M=&]R:65S(%1/(&AO<F1E"D=/"@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I
M;VY?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI"D-2
M14%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@
M*&AI<W1O<GE?=',I"D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@
M:&]R9&5?:&ES=&]R:65S("AO8FIE8W1?=6ED*0I'3PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S
M<6PO4D5!1$U%````````````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,C4U,P`Q,#4Q-30S,3`V-``P,3<U-C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E($1A=&%B87-E($EN<W1A;&QA=&EO
M;B!'=6ED90H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`U+S$P+S$X(#$Q.C,T.C`P("0*
M.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XR+C$P+C,@)`HZ0V]N=&%C
M=#H@("`@("`@:&]R9&5`;&ES=',N:&]R9&4N;W)G"@H*4'5R<&]S92!O9B!T
M:&ES(&9I;&4*?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E1H:7,@9FEL92!W:6QL
M(&AO<&5F=6QL>2!E87-E('1H92!I;G-T86QL871I;VX@86YD(&-O;F9I9W5R
M871I;VX@;V8@>6]U<@ID871A8F%S92!F;W(@=7-E('=I=&@@2&]R9&4N("!4
M:&4@<V-O<&4@;V8@=&AE(&1O8W5M96YT(&1E86QS('!R:6UA<FEL>2!W:71H
M"G5S:6YG('EO=7(@9&%T86)A<V4@=VET:"!(;W)D92!A;F0@<VAO=6QD(&YO
M="!B92!C;VYS:61E<F5D(&$@<F5S;W5R8V4@9F]R"F=E;F5R86P@9&%T86)A
M<V4@=&%S:W,N"@H*4F5Q=6ER96UE;G1S(&9O<B!(;W)D90I^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^"@I(;W)D92!C=7)R96YT;'D@<W5P<&]R=',@870@;&5A
M<W0@-R!D871A8F%S97,Z"@H@("`@+2!->5-13"`@("`@("`@(&AT='`Z+R]W
M=W<N;7ES<6PN8V]M+PH@("`@+2!0;W-T9W)E4U%,("`@(&AT='`Z+R]W=W<N
M<&]S=&=R97-Q;"YO<F<O"B`@("`M($]R86-L92`@("`@("`@:'1T<#HO+W=W
M=RYO<F%C;&4N8V]M+PH@("`@+2!3>6)A<V4@("`@("`@(&AT='`Z+R]W=W<N
M<WEB87-E+F-O;2\*("`@("T@4U%,:71E("`@("`@("!H='1P.B\O=W=W+G-Q
M;&ET92YO<F<O"B`@("`M($U3(%-13"`@("`@("`@:'1T<#HO+W=W=RYM:6-R
M;W-O9G0N8V]M+W-Q;"\*("`@("T@35-$12`@("`@("`@("!H='1P.B\O=W=W
M+FUI8W)O<V]F="YC;VTO<W%L+VUS9&4O"@I->5-13"!A;F0@4&]S=&=R95-1
M3"!A<F4@<F5G=6QA<FQY('5S960@8GD@=&AE(&1E=F5L;W!M96YT('1E86TL
M(&%N9"!W:6QL('=O<FL*=VET:"!N;R!P<F]B;&5M<RX@($]R86-L92!A;F0@
M4U%,:71E('-U<'!O<G0@:&%S(&)E96X@;75C:"!I;7!R;W9E9"!R96-E;G1L
M>0IA;F0@=V]R:W,@9FEN92!T;V\N("!3>6)A<V4@=V5R92!R97!O<G1E9"!W
M;W)K:6YG(&EN('1H92!P<F5V:6]U<R!V97)S:6]N(&]F"DAO<F1E+TE-4"!B
M>2!S;VUE(&]F(&]U<B!U<V5R<RP@86YD(&%R92!A<W-U;65D('1O('-T:6QL
M('=O<FLN+BX@8G5T('1H870*:&%S;B=T(&)E96X@=F5R:69I960@<F5C96YT
M;'DN"@H*0F5F;W)E(%EO=2!"96=I;@I^?GY^?GY^?GY^?GY^?GY^"@I9;W4@
M=VEL;"!N965D('1O(&AA=F4@>6]U<B!D871A8F%S92!P<F5C;VYF:6=U<F5D
M(&%N9"!W;W)K:6YG(&]N('EO=7(@<WES=&5M"F)E9F]R92!Y;W4@979E;B!G
M970@=&\@=&AI<R!S=&%G92X@($9O<B!H96QP('=I=&@@=&AI<RP@<&QE87-E
M(&-O;G-U;'0@>6]U<@ID871A8F%S92!S<&5C:69I8R!H96QP(&9I;&5S+@H*
M0F5F;W)E('5S:6YG(&%N>2!O9B!T:&4@<V-R:7!T<R!L:7-T960@8F5L;W<L
M('!L96%S92!L;V]K(&]V97(@=&AE;2!T;R!E;G-U<F4*=&AA="!A;GD@<WES
M=&5M+7-P96-I9FEC('-E='1I;F=S("AO<B!P97)S;VYA;"!C:&]I8V5S*2!A
M<F4@<V5T('1O('EO=7(*9&5S:7)E9"!S971T:6YG<R`H96<N(&!@=7-E<FYA
M;65@8"P@971C+BDN"@HJ*E!,14%312!.3U1%*BH@=&AA="!T:&4@9&%T86)A
M<V4@8V]N9FEG=7)A=&EO;B!S=&5P<R!L:7-T960@8F5L;W<@*BI-55-4*BH*
M;6%T8V@@=VAA="!I<R!C;VYF:6=U<F5D('=I=&AI;B!(;W)D92X*"E-P96-I
M9FEC86QL>2P@:68@>6]U(&-H86YG92!T:&4@9&%T86)A<V4@;F%M92P@=7-E
M<BP@;W(@<&%S<W=O<F0@=VAI;&4*8V]N9FEG=7)I;F<@=&AE(&1A=&%B87-E
M("AB96QO=RDL('EO=2!W:6QL(&YE960@=&\@;6%K92!T:&4@<V%M92!C:&%N
M9V5S('1O"GEO=7(@2&]R9&4@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<R!W96QL
M+@H*"DUY4U%,"GY^?GY^"@I4:&4@;7ES<6Q?8W)E871E+G-Q;"!S8W)I<'0@
M=VEL;"!C<F5A=&4@82!D871A8F%S92!C86QL960@8&!H;W)D96!@+"!A;F0@
M80IU<V5R(&-A;&QE9"!@8&AO<F1E8&`@*'=I=&@@<&%S<W=O<F0@8&!H;W)D
M96!@*2!T:&%T(&AA<R!F=6QL(')I9VAT<R!T;R!T:&4*9&%T86)A<V4N("`J
M3F]T92!T:&%T('=I=&@@37E344PL(%!%05(@1$(@96UU;&%T97,@<V5Q=65N
M8V5S(&)Y(&%U=&]M871I8V%L;'D*8W)E871I;F<@97AT<F$@=&%B;&5S(&5N
M9&EN9R!I;B!?<V5Q+"!S;R!T:&4@37E344P@8&!H;W)D96!@('5S97(@;75S
M="!H879E"F!@0U)%051%8&`@<')I=FEL96=E(&]N('1H92!@8&AO<F1E8&`@
M9&%T86)A<V4N"@I4:&ES('-C<FEP="!N965D<R!T;R!B92!R=6X@87,@=&AE
M($UY4U%,(')O;W0@=7-E<B`H=VAI8V@@:7,@*DY/5"H@=&AE('-A;64@87,*
M=&AE(%5.25@O3&EN=7@@<F]O="!U<V5R*3HZ"@H@("0@;7ES<6P@+2UU<V5R
M/7)O;W0@+2UP87-S=V]R9#T\37E344PM<F]O="UP87-S=V0^(#P@8W)E871E
M+FUY<W%L+G-Q;`H*069T97(@<G5N;FEN9R!T:&ES('-C<FEP="P@:70G<R!A
M(&=O;V0@:61E82!T;R!R97-T87)T('EO=7(@37E344P@<V5R=F5R.CH*"B`@
M)"!M>7-Q;&%D;6EN("TM=7-E<CUR;V]T("TM<&%S<W=O<F0]/$UY4U%,+7)O
M;W0M<&%S<W=D/B!R96QO860*"E1O(&-H96-K('1H870@=&AI<R!I<R!W;W)K
M:6YG+"!T:&4@9F]L;&]W:6YG(&-O;6UA;F0@<VAO=6QD(&-O;FYE8W0@=VET
M:&]U=`IE<G)O<G,Z.@H*("`D(&UY<W%L("TM=7-E<CUH;W)D92`M+7!A<W-W
M;W)D/6AO<F1E(&AO<F1E"@I4>7!E(&!@<75I=&!@('1O('%U:70@37E344PN
M"@H*4&]S=&=R95-13`I^?GY^?GY^?GY^"@H@(",@<W4@+2!P;W-T9W)E<R`@
M*&]R('=H871E=F5R('EO=7(@9&%T86)A<V4@<G5N<R!A<RXN+B!U<W5A;&QY
M('!O<W1G<F5S*0H@("0@<'-Q;"`M9"!T96UP;&%T93$@+68@8W)E871E+G!G
M<W%L+G-Q;`H*5&AI<R!S8W)I<'0@=VEL;"!C<F5A=&4@82!@8&AO<F1E8&`@
M9&%T86)A<V4@86YD(&$@8&!H;W)D96!@('5S97(N("!9;W4@<VAO=6QD"G-E
M="!A('!A<W-W;W)D(&9O<B!T:&ES('5S97(@=VET:"!T:&ES(&-O;6UA;F0@
M*&EF('EO=2!D:61N)W0@=6YC;VUM96YT('1H90IO;F4@:6X@<&=S<6Q?8W)E
M871E+G-Q;"DZ.@H*("`D('!S<6P@+7%C(")!3%1%4B!54T52(&AO<F1E(%=)
M5$@@4$%34U=/4D0@)W!A<W,G.R(@=&5M<&QA=&4Q('!O<W1G<F5S"@I4:&5N
M(&-R96%T92!T:&4@=&%B;&5S('=I=&AI;B!T:&4@8&!H;W)D96!@(&1A=&%B
M87-E.CH*"B`@)"!P<W%L("UD(&AO<F1E("UF(&AO<F1E7W5S97)S+G-Q;`H@
M("0@<'-Q;"`M9"!H;W)D92`M9B!H;W)D95]P<F5F<RYS<6P*("`D('!S<6P@
M+60@:&]R9&4@+68@:&]R9&5?9&%T871R964N<W%L"@I4:&5S92!S8W)I<'1S
M('=I;&P@86QS;R!G<F%N="!T:&4@8&!H;W)D96!@('5S97(@=&AE(&YE8V5S
M<V%R>2!P<FEV:6QE9V5S('1O"F5A8V@@;V8@=&AE('1A8FQE<RX*"@I/<F%C
M;&4*?GY^?GY^"@I2=6X@8&!S<6QP;'5S8&`N("!,;V=I;BP@=&AE;B!;=V4@
M;F5E9"!I;G-T<G5C=&EO;G,@9F]R(&-R96%T:6YG('1H92!D871A8F%S90IA
M;F0@=7-E<B!H97)E72X*"E1H870@<VAO=6QD(&)E(&ET+B`@4F5S=&%R="!/
M<F%C;&4@:G5S="!T;R!B92!S=7)E+"!A;F0@=')Y(&ET+B`@5&AE;B!C<F5A
M=&4*=&AE('1A8FQE<R!W:71H:6X@=&AE(&!@:&]R9&5@8"!D871A8F%S93HZ
M"@I;06QS;R!N965D('1H;W-E(&EN<W1R=6-T:6]N<R!H97)E+ET*"@I3>6)A
M<V4*?GY^?GY^"@I4;R!C<F5A=&4@=&AE(&1A=&%B87-E+"!F<F]M(&!@:7-Q
M;&!@(')U;CHZ"@H@(&-R96%T92!D871A8F%S92!H;W)D90H*3F5X="P@>6]U
M('-H;W5L9"`H<F5C;VUM96YD960I(&-R96%T92!A(&QO9VEN('1O('5S92!W
M:71H('1H:7,@9&%T86)A<V4N("!4:&4*8&!I<W%L8&`@8V]M;6%N9"!F;W(@
M=&AI<R!I<SHZ"@H@('-P7V%D9&QO9VEN(#QU<V5R;F%M93X@/'!A<W-W;W)D
M/@H*3F5X="!Y;W4@;F5E9"!T;R!C:&%N9V4@=&AE(&]W;F5R<VAI<"!O9B!T
M:&4@9&%T86)A<V4@=&\@=&AI<R!N97<@=7-E<BX@(%1H90I@8&ES<6Q@8"!C
M;VUM86YD(&9O<B!T:&ES(&ES.CH*"B`@<W!?8VAA;F=E9&)O=VYE<B`\=7-E
M<FYA;64^"@I!9G1E<B!T:&%T+"!Y;W4@:G5S="!N965D('1O('-E="!U<"!Y
M;W5R('1A8FQE<R!W:71H:6X@=&AE(&1A=&%B87-E+B`@5&\@9&\*=&AA="P@
M:G5S="!R=6X@=&AI<R!C;VUM86YD(&9R;VT@=&AE(&-O;6UA;F0@;&EN93HZ
M"@H@(&ES<6P@+6D@:&]R9&5?=7-E<G,N<W%L("U5/'5S97)N86UE/B`M4#QP
M87-S=V]R9#X*("!I<W%L("UI(&AO<F1E7W!R969S+G-Q;"`M53QU<V5R;F%M
M93X@+5`\<&%S<W=O<F0^"@H*35-$12`R,#`P("AA;F0@<&]S<VEB;'D@35,@
M4U%,(%-E<G9E<BD*?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GX*"E1O(&-R96%T92!U<V5R(&%N9"!D871A8F%S92P@=7-E('1H92!O
M<W%L(&-O;6UA;F0Z.@H*("!#.EP^;W-Q;"`M52!S82`M4"!A9&UI;E]P87-S
M=V]R9"`M4R!L;V-A;&AO<W0@+6D@8W)E871E+FUS9&4N<W%L"@I"92!S=7)E
M('1O(&-H86YG92!T:&4@<&%S<W=O<F0@9F]R('1H92!H;W)D92!U<V5R(&EN
M('1H92!S8W)I<'0@9FEL92X@(%1O"G-P96-I9GD@82!P87)T:6-U;&%R(&EN
M<W1A;F-E(&]F('1H92!344P@<V5R=F5R('5S92!T:&4*/'-E<G9E<FYA;64^
M+SQI;G-T86YC93X@9F]R('1H92`M4R!F;&%G+B`@268@>6]U(&%R96XG="!U
M<VEN9R!M:7AE9"!344P*875T:&5N=&EC871I;VXL('1H96X@>6]U)VQL(&YE
M960@=&\@;6]D:69Y('1H92!S8W)I<'0@=&\@87-S;V-I871E('1H92!H;W)D
M90IU<V5R('=I=&@@82!W:6YD;W=S('5S97(@86-C;W5N="!A;F0@<G5N('1H
M92!S8W)I<'0@:6X@=&AE(&9O;&QO=VEN9R!M86YN97(@87,*=&AE($%D;6EN
M:7-T<F%T;W(Z.@H*("!#.EP^;W-Q;"`M12`M4R!L;V-A;&AO<W0@+6D@8W)E
M871E+FUS9&4N<W%L"@I)9B!Y;W4G<F4@:&%V:6YG('!R;V)L96US(')U;FYI
M;F<@=&AI<R!S8W)I<'0@;VX@82!344P@<V5R=F5R(&]N('1H92!N971W;W)K
M+`IB92!S=7)E('1H92!S97)V97(@:7,@<V5T('5P('1O(&%L;&]W(&YE='=O
M<FL@86-C97-S+@H*"D%D9&ET:6]N86P@3F]T97,*?GY^?GY^?GY^?GY^?GY^
M?@H*5&AI<R!I<R!B>2!F87(@;F]T(&$@8V]M<&QE=&4@2$]75$\N("!4:&ES
M(&ES(&IU<W0@82!C;VUP:6QE9"!L:7-T(&]F('=H870*<&5O<&QE(&AA=F4@
M8V]N=')I8G5T960@<V\@9F%R+B`@268@>6]U(&AA=F4@=&EP<RP@:61E87,L
M('-U9V=E<W1I;VYS(&]R"F%N>71H:6YG(&5L<V4@=&AA="!Y;W4@=&AI;FL@
M8V]U;&0@:&5L<"!O=&AE<G,@:6X@<V5T=&EN9R!U<"!T:&5I<B!D871A8F%S
M90IF;W(@=7-E('=I=&@@2&]R9&4L('!L96%S92!L970@=7,@:VYO=RX*"CQD
M979`;&ES=',N:&]R9&4N;W)G/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO<V-R:7!T+FEN:71I86Q?:&]R
M9&5?=7-E<BYS<6P````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4S,P`Q,#4Q-30S,3`V
M-``P,C0U-S,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]S8W)I<'0N:6YI
M=&EA;%]H;W)D95]U<V5R+G-Q;"QV(#$N,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y
M(&-H=6-K($5X<"`D"BTM"BTM(%1H:7,@<V-R:7!T('=I;&P@8W)E871E(&%N
M(&EN:71I86P@=7-E<B!I;B!A(&AO<F1E7W5S97)S('1A8FQE+B!4:&4*+2T@
M<&%S<W=O<F0@8F5I;F<@=7-E9"!I<R`G861M:6XG+"!W:&EC:"!Y;W4@<VAO
M=6QD(&-H86YG90HM+2!)34U%1$E!5$5,62X*"DE.4T525"!)3E1/(&AO<F1E
M7W5S97)S("AU<V5R7W5I9"P@=7-E<E]P87-S*2!604Q515,@*"=A9&UI;B<L
M("<R,3(S,F8R.3=A-3=A-6$W-#,X.31A,&4T83@P,69C,R<I.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7VAI<W1O<FEE<RYM<W-Q;"YS<6P`````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$R-C(`,3`U,34T,S$P-C0`,#(S-S4P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM("1(
M;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?:&ES=&]R:65S+FUS<W%L
M+G-Q;"QV(#$N,2XR+C$@,C`P-B\P,2\Q."`Q.3HU.#HT,B!B96X@17AP("0*
M"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES=&]R>5]I
M9"`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED("`@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T:6]N("`@
M5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@("`@($))
M1TE.5"!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@5D%20TA!4BA-
M05@I+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U-2DL"B`@("!H
M:7-T;W)Y7V5X=')A("`@(%9!4D-(05(H34%8*2P*+2T*("`@(%!224U!4ED@
M2T59("AH:7-T;W)Y7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T
M:6]N7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*
M0U)%051%($E.1$58(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE
M<R`H:&ES=&]R>5]T<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@
M3TX@:&]R9&5?:&ES=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#
M5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@
M5$\@:&]R9&4["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YS<6P`````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<T-C<`,3`U,34T,S$P-C0`,#(P
M-S`P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+G-Q;"QV(#$N
M,2XR+C,@,C`P-B\P-2\R,B`R,3HR-SHS,R!J86X@17AP("0*"D-214%412!4
M04),12!H;W)D95]U<V5R<R`H"B`@("!U<V5R7W5I9"`@("`@("`@("`@("`@
M("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]P87-S("`@
M("`@("`@("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S
M97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`H@("`@=7-E<E]H
M87)D7V5X<&ER871I;VY?9&%T92`@($E.5$5'15(L"BTM"B`@("!04DE-05)9
M($M%62`H=7-E<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&4["@H*0U)%051%
M(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R969?=6ED("`@("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!P<F5F7W-C;W!E("`@("`@5D%20TA!
M4B@Q-BD@1$5&055,5"`G)R!.3U0@3E5,3"P*("`@('!R969?;F%M92`@("`@
M("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('!R969?=F%L=64@("`@("!4
M15A4+`HM+0H@("`@4%))34%262!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E
M+"!P<F5F7VYA;64I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?<')E9G,@5$\@:&]R9&4["@H*0U)%051%(%1!
M0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@
M3E5,3"P*("`@(&=R;W5P7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@
M("!U<V5R7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E
M95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A
M<F5N=',@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;W)D
M97(@24Y4+`H*+2T@5&AE<F4@:7,@;F\@<&]R=&%B;&4@=V%Y('1O(&1O('1H
M:7,@87!P87)E;G1L>2X@268@>6]U<B!D8B!D;V5S;B=T"BTM(&%L;&]W(%1%
M6%0@8V]L=6UN<RP@=&AE;B!M87EB92!I="!A;&QO=W,@;&%R9V4@5D%20TA!
M4B!C;VQU;6YS+"!S;PHM+2!T<GD@=&AE('-E8V]N9"!L:6YE+@HM+0H@("`@
M9&%T871R965?9&%T82!415A4+`HM+2`@9&%T871R965?9&%T82!605)#2$%2
M*#0P.38I+`H*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&
M055,5"`P($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AD871A=')E95]I
M9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D871A=')E95]N86UE7VED
M>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M92D["D-214%412!)
M3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R
M;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H
M;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?;W)D97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E
M<BD["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H
M;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@
M5$%"3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E
M95]I9"!)3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U
M*2P*("`@(&%T=')I8G5T95]V86QU92!415A4"BD["@I#4D5!5$4@24Y$15@@
M9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E95]A='1R
M:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%6"!D871A=')E95]A
M='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E
M<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T
M<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R9&4["D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E
M95]A='1R:6)U=&5S(%1/(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]T
M;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@("!605)#2$%2*#$P,"D@3D]4
M($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.
M54Q,+`H@("`@=&]K96Y?=&EM97-T86UP("!"24=)3E0@3D]4($Y53$PL"BTM
M"B`@("!04DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD[
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R
M9&5?=&]K96YS(%1/(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]V9G,@
M*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?
M='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@
M("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'24Y4
M($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`HM+2!/<BP@;VX@
M<V]M92!$0DU3('-Y<W1E;7,Z"BTM("!V9G-?9&%T82`@("`@($E-04=%+`H@
M("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F
M<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.
M1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V
M9G,@5$\@:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H
M"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&]B
M:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@:&ES
M=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O
M<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C
M("`@("!415A4+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U-2DL
M"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L"BTM"B`@("!04DE-05)9($M%
M62`H:&ES=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO
M;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD["D-2
M14%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@
M*&AI<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].
M(&AO<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@I'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES=&]R:65S(%1/
M(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H
M"B`@("!S97-S:6]N7VED("`@("`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.
M54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I960@("!)3E0@3D]4($Y53$PL
M"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@($Q/3D="3$]"+`HM+2!/<BP@
M;VX@<V]M92!$0DU3('-Y<W1E;7,Z"BTM("!S97-S:6]N7V1A=&$@("`@("`@
M("`@($E-04=%+`H*("`@(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI.PH*
M1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E
M7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T
M92YX;6P`````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<S
M-34`,3`U,34T,S$P-C0`,#(P-C<V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I
M;F<](DE33RTX.#4Y+3$B(#\^"CQD871A8F%S93X*"B`\;F%M93X\=F%R:6%B
M;&4^;F%M93PO=F%R:6%B;&4^/"]N86UE/@H@/&-R96%T93X\=F%R:6%B;&4^
M8W)E871E/"]V87)I86)L93X\+V-R96%T93X*"B`\=&%B;&4^"@H@(#QN86UE
M/FAO<F1E7V1A=&%T<F5E/"]N86UE/@H*("`\9&5C;&%R871I;VX^"@H@("`\
M9FEE;&0^"B`@("`\;F%M93YD871A=')E95]I9#PO;F%M93X*("`@(#QT>7!E
M/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@
M("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^9W)O=7!?=6ED/"]N
M86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U/"]L
M96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD
M/@H*("`@/&9I96QD/@H@("`@/&YA;64^=7-E<E]U:60\+VYA;64^"B`@("`\
M='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@
M(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE
M;&0^"B`@("`\;F%M93YD871A=')E95]N86UE/"]N86UE/@H@("`@/'1Y<&4^
M=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T
M;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^9&%T871R965?<&%R96YT<SPO;F%M93X*("`@(#QT>7!E/G1E
M>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO=&YU
M;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@
M(#QN86UE/F1A=&%T<F5E7V]R9&5R/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E
M<CPO='EP93X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/F1A
M=&%T<F5E7V1A=&$\+VYA;64^"B`@("`\='EP93YC;&]B/"]T>7!E/@H@("`\
M+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^9&%T871R965?<V5R:6%L
M:7IE9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;&5N
M9W1H/C(\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@
M(#PO9FEE;&0^"@H@("`\:6YD97@^"B`@("`\;F%M93YD871A=')E95]D871A
M=')E95]N86UE/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/F1A=&%T
M<F5E7VYA;64\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`@
M/&EN9&5X/@H@("`@/&YA;64^9&%T871R965?9W)O=7`\+VYA;64^"B`@("`\
M9FEE;&0^"B`@("`@/&YA;64^9W)O=7!?=6ED/"]N86UE/@H@("`@/"]F:65L
M9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/F1A=&%T<F5E
M7W5S97(\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^=7-E<E]U:60\
M+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X/@H@
M("`@/&YA;64^9&%T871R965?<V5R:6%L:7IE9#PO;F%M93X*("`@(#QF:65L
M9#X*("`@("`\;F%M93YD871A=')E95]S97)I86QI>F5D/"]N86UE/@H@("`@
M/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/G!R
M:6UA<GD\+VYA;64^"B`@("`\<')I;6%R>3YT<G5E/"]P<FEM87)Y/@H@("`@
M/&9I96QD/@H@("`@(#QN86UE/F1A=&%T<F5E7VED/"]N86UE/@H@("`@/"]F
M:65L9#X*("`@/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A8FQE
M/@H*(#QT86)L93X*"B`@/&YA;64^:&]R9&5?9&%T871R965?871T<FEB=71E
M<SPO;F%M93X*"B`@/&1E8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA
M;64^9&%T871R965?:60\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E
M/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@
M(#QF:65L9#X*("`@(#QN86UE/F%T=')I8G5T95]N86UE/"]N86UE/@H@("`@
M/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@
M("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I
M96QD/@H@("`@/&YA;64^871T<FEB=71E7VME>3PO;F%M93X*("`@(#QT>7!E
M/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO
M=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*
M("`@(#QN86UE/F%T=')I8G5T95]V86QU93PO;F%M93X*("`@(#QT>7!E/F-L
M;V(\+W1Y<&4^"B`@(#PO9FEE;&0^"@H@("`\:6YD97@^"B`@("`\;F%M93YD
M871A=')E95]A='1R:6)U=&4\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA
M;64^9&%T871R965?:60\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X
M/@H*("`@/&EN9&5X/@H@("`@/&YA;64^9&%T871R965?871T<FEB=71E7VYA
M;64\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^871T<FEB=71E7VYA
M;64\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X
M/@H@("`@/&YA;64^9&%T871R965?871T<FEB=71E7VME>3PO;F%M93X*("`@
M(#QF:65L9#X*("`@("`\;F%M93YA='1R:6)U=&5?:V5Y/"]N86UE/@H@("`@
M/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A
M8FQE/@H*(#QT86)L93X*"B`@/&YA;64^:&]R9&5?:&ES=&]R:65S/"]N86UE
M/@H*("`\9&5C;&%R871I;VX^"@H@("`\9FEE;&0^"B`@("`\;F%M93YH:7-T
M;W)Y7VED/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@(#QN
M;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^
M"B`@("`\;F%M93YO8FIE8W1?=6ED/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO
M='EP93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT
M<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA
M;64^:&ES=&]R>5]A8W1I;VX\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E
M/@H@("`@/&QE;F=T:#XS,CPO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO
M;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/FAI
M<W1O<GE?=',\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`@
M/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L
M9#X*("`@(#QN86UE/FAI<W1O<GE?9&5S8SPO;F%M93X*("`@(#QT>7!E/F-L
M;V(\+W1Y<&4^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YH
M:7-T;W)Y7W=H;SPO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\
M;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^:&ES=&]R>5]E>'1R83PO;F%M93X*("`@(#QT>7!E/F-L;V(\
M+W1Y<&4^"B`@(#PO9FEE;&0^"@H@("`\:6YD97@^"B`@("`\;F%M93YH:7-T
M;W)Y7V%C=&EO;CPO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YH:7-T
M;W)Y7V%C=&EO;CPO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@
M("`\:6YD97@^"B`@("`\;F%M93YH:7-T;W)Y7W1S/"]N86UE/@H@("`@/&9I
M96QD/@H@("`@(#QN86UE/FAI<W1O<GE?=',\+VYA;64^"B`@("`\+V9I96QD
M/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X/@H@("`@/&YA;64^:&ES=&]R>5]U
M:60\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^;V)J96-T7W5I9#PO
M;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@
M("`\;F%M93YP<FEM87)Y/"]N86UE/@H@("`@/'!R:6UA<GD^=')U93PO<')I
M;6%R>3X*("`@(#QF:65L9#X*("`@("`\;F%M93YH:7-T;W)Y7VED/"]N86UE
M/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*
M"B`\+W1A8FQE/@H*(#QT86)L93X*"B`@/&YA;64^:&]R9&5?<')E9G,\+VYA
M;64^"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/G!R
M969?=6ED/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG
M=&@^,C`P/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@
M("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^<')E9E]S8V]P93PO
M;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C$V/"]L
M96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD
M/@H*("`@/&9I96QD/@H@("`@/&YA;64^<')E9E]N86UE/"]N86UE/@H@("`@
M/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,S(\+VQE;F=T:#X*("`@
M(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE
M;&0^"B`@("`\;F%M93YP<F5F7W9A;'5E/"]N86UE/@H@("`@/'1Y<&4^8VQO
M8CPO='EP93X*("`@/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/G!R
M:6UA<GD\+VYA;64^"B`@("`\<')I;6%R>3YT<G5E/"]P<FEM87)Y/@H@("`@
M/&9I96QD/@H@("`@(#QN86UE/G!R969?=6ED/"]N86UE/@H@("`@/"]F:65L
M9#X*("`@(#QF:65L9#X*("`@("`\;F%M93YP<F5F7W-C;W!E/"]N86UE/@H@
M("`@/"]F:65L9#X*("`@(#QF:65L9#X*("`@("`\;F%M93YP<F5F7VYA;64\
M+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X/@H@
M("`@/&YA;64^<')E9E]U:60\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA
M;64^<')E9E]U:60\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*
M("`@/&EN9&5X/@H@("`@/&YA;64^<')E9E]S8V]P93PO;F%M93X*("`@(#QF
M:65L9#X*("`@("`\;F%M93YP<F5F7W-C;W!E/"]N86UE/@H@("`@/"]F:65L
M9#X*("`@/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A8FQE/@H*
M(#QT86)L93X*"B`@/&YA;64^:&]R9&5?<V5S<VEO;FAA;F1L97(\+VYA;64^
M"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/G-E<W-I
M;VY?:60\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T
M:#XS,CPO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@
M/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/G-E<W-I;VY?;&%S=&UO
M9&EF:65D/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@(#QN
M;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^
M"B`@("`\;F%M93YS97-S:6]N7V1A=&$\+VYA;64^"B`@("`\='EP93YB;&]B
M/"]T>7!E/@H@("`\+V9I96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I
M;6%R>3PO;F%M93X*("`@(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\
M9FEE;&0^"B`@("`@/&YA;64^<V5S<VEO;E]I9#PO;F%M93X*("`@(#PO9FEE
M;&0^"B`@(#PO:6YD97@^"@H@(#PO9&5C;&%R871I;VX^"@H@/"]T86)L93X*
M"B`\=&%B;&4^"@H@(#QN86UE/FAO<F1E7W1O:V5N<SPO;F%M93X*"B`@/&1E
M8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^=&]K96Y?861D<F5S
M<SPO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C$P
M,#PO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F
M:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/G1O:V5N7VED/"]N86UE/@H@
M("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,S(\+VQE;F=T:#X*
M("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\
M9FEE;&0^"B`@("`\;F%M93YT;VME;E]T:6UE<W1A;7`\+VYA;64^"B`@("`\
M='EP93YI;G1E9V5R/"]T>7!E/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L
M;#X*("`@/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/G!R:6UA<GD\
M+VYA;64^"B`@("`\<')I;6%R>3YT<G5E/"]P<FEM87)Y/@H@("`@/&9I96QD
M/@H@("`@(#QN86UE/G1O:V5N7V%D9')E<W,\+VYA;64^"B`@("`\+V9I96QD
M/@H@("`@/&9I96QD/@H@("`@(#QN86UE/G1O:V5N7VED/"]N86UE/@H@("`@
M/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A
M8FQE/@H*(#QT86)L93X*"B`@/&YA;64^:&]R9&5?=7-E<G,\+VYA;64^"@H@
M(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/G5S97)?=6ED
M/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U
M/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I
M96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^=7-E<E]P87-S/"]N86UE/@H@
M("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^
M"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@
M/&9I96QD/@H@("`@/&YA;64^=7-E<E]S;V9T7V5X<&ER871I;VY?9&%T93PO
M;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@(#PO9FEE;&0^"@H@
M("`\9FEE;&0^"B`@("`\;F%M93YU<V5R7VAA<F1?97AP:7)A=&EO;E]D871E
M/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@/"]F:65L9#X*
M"B`@(#QI;F1E>#X*("`@(#QN86UE/G!R:6UA<GD\+VYA;64^"B`@("`\<')I
M;6%R>3YT<G5E/"]P<FEM87)Y/@H@("`@/&9I96QD/@H@("`@(#QN86UE/G5S
M97)?=6ED/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@/"]D
M96-L87)A=&EO;CX*"B`\+W1A8FQE/@H*(#QT86)L93X*"B`@/&YA;64^:&]R
M9&5?=F9S/"]N86UE/@H*("`\9&5C;&%R871I;VX^"@H@("`\9FEE;&0^"B`@
M("`\;F%M93YV9G-?:60\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E
M/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@
M(#QF:65L9#X*("`@(#QN86UE/G9F<U]T>7!E/"]N86UE/@H@("`@/'1Y<&4^
M:6YT96=E<CPO='EP93X*("`@(#QL96YG=&@^,3PO;&5N9W1H/@H@("`@/&YO
M=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*
M("`@(#QN86UE/G9F<U]P871H/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP
M93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E
M/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^
M=F9S7VYA;64\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE
M;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^
M"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YV9G-?;6]D:69I
M960\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`@/&YO=&YU
M;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@
M(#QN86UE/G9F<U]O=VYE<CPO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^
M"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO
M;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/G9F
M<U]D871A/"]N86UE/@H@("`@/'1Y<&4^8FQO8CPO='EP93X*("`@/"]F:65L
M9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/G!R:6UA<GD\+VYA;64^"B`@("`\
M<')I;6%R>3YT<G5E/"]P<FEM87)Y/@H@("`@/&9I96QD/@H@("`@(#QN86UE
M/G9F<U]I9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\
M:6YD97@^"B`@("`\;F%M93YV9G-?<&%T:#PO;F%M93X*("`@(#QF:65L9#X*
M("`@("`\;F%M93YV9G-?<&%T:#PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO
M:6YD97@^"@H@("`\:6YD97@^"B`@("`\;F%M93YV9G-?;F%M93PO;F%M93X*
M("`@(#QF:65L9#X*("`@("`\;F%M93YV9G-?;F%M93PO;F%M93X*("`@(#PO
M9FEE;&0^"B`@(#PO:6YD97@^"@H@(#PO9&5C;&%R871I;VX^"@H@/"]T86)L
M93X*"CPO9&%T86)A<V4^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYP9W-Q;"YS<6P`
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-34Q`#$P-3$U-#,Q,#8T`#`R-#<T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+2`D2&]R
M9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G!G
M<W%L+G-Q;"QV(#$N,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y(&-H=6-K($5X<"`D
M"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@<V5S
M<VEO;E]I9"`@("`@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@
M('-E<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S
M<VEO;E]D871A("`@("`@("`@("!415A4+`H@("`@4%))34%262!+15D@*'-E
M<W-I;VY?:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$
M14Q%5$4@3TX@:&]R9&5?<V5S<VEO;FAA;F1L97(@5$\@:&]R9&4[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S
M<6PO:&]R9&5?9&%T871R964N<W%L````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,S`S-``Q,#4Q-30S,3`V-``P,C(S-S$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]D871A=')E92YS<6PL=B`Q+C$N,3`N,2`R,#`V
M+S`U+S(R(#(Q.C(W.C,S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E
M7V1A=&%T<F5E("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@
M(&=R;W5P7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W5I
M9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]N86UE(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A<F5N=',@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;W)D97(@24Y4+`H*
M+2T@5&AE<F4@:7,@;F\@<&]R=&%B;&4@=V%Y('1O(&1O('1H:7,@87!P87)E
M;G1L>2X@268@>6]U<B!D8B!D;V5S;B=T"BTM(&%L;&]W(%1%6%0@8V]L=6UN
M<RP@=&AE;B!M87EB92!I="!A;&QO=W,@;&%R9V4@5D%20TA!4B!C;VQU;6YS
M+"!S;PHM+2!T<GD@=&AE('-E8V]N9"!L:6YE+@HM+0H@("`@9&%T871R965?
M9&%T82!415A4+`HM+2`@9&%T871R965?9&%T82!605)#2$%2*#0P.38I+`H*
M("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&055,5"`P($Y/
M5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-2
M14%412!)3D1%6"!D871A=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D
M95]D871A=')E92`H9&%T871R965?;F%M92D["D-214%412!)3D1%6"!D871A
M=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D[
M"D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A
M=')E92`H=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?;W)D97)?
M:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E<BD["D-214%4
M12!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A
M=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@H*0U)%051%(%1!0DQ%(&AO
M<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?:60@24Y4
M($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2DL"B`@("!A
M='1R:6)U=&5?=F%L=64@5$585`HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E
M7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I
M8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K
M97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T
M95]K97DI.PH*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!H;W)D95]D871A=')E92!43R!H;W)D93L*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@5$\@:&]R9&4["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7W-E<W-I;VYH86YD;&5R+FUY<W%L+G-Q;```````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`V,3,`,3`U,34T,S$P-C0`,#(T-S8U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N;7ES<6PN<W%L+'8@,2XQ+C(N
M,2`R,#`V+S`S+S(R(#$X.C,P.C(S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%
M(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?:60@("`@("`@
M("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!S97-S:6]N7VQA<W1M
M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?9&%T82`@("`@
M("`@("`@3$].1T),3T(L"@H@("`@4%))34%262!+15D@*'-E<W-I;VY?:60I
M"BD@14Y'24Y%(#T@26YN;T1".PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E
M0&QO8V%L:&]S=#L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A=')E
M92YM<W-Q;"YS<6P`````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-30W`#$P-3$U
M-#,Q,#8T`#`R,S4S-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7V1A=&%T<F5E+FUS<W%L+G-Q;"QV(#$N,2XR+C(@,C`P-B\P-2\R,B`R,3HR
M-SHS,R!J86X@17AP("0*"D-214%412!404),12!H;W)D95]D871A=')E92`H
M"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!G<F]U<%]U:60@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]U:60@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;F%M92!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!D871A=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@(&1A=&%T<F5E7V]R9&5R($E.5"P*("`@(&1A=&%T<F5E
M7V1A=&$@5D%20TA!4BA-05@I+`H@("`@9&%T871R965?<V5R:6%L:7IE9"!3
M34%,3$E.5"!$149!54Q4(#`@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@
M*&1A=&%T<F5E7VED*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T
M<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D
M871A=')E92`H9W)O=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S
M97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)
M3D1%6"!D871A=')E95]O<F1E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A
M=&%T<F5E7V]R9&5R*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ
M961?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D
M*3L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?
M;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y
M(%9!4D-(05(H,C4U*2P*("`@(&%T=')I8G5T95]V86QU92!605)#2$%2*$U!
M6"D**3L*"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:61X($].
M(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%
M051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE7VED>"!/3B!H;W)D
M95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?;F%M92D["D-214%4
M12!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y*3L*"@I'4D%.5"!3
M14Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R
M964@5$\@:&]R9&4["D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%
M3$5412!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S(%1/(&AO<F1E.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7VUU=F9S+G-Q;```````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$Q,C4`,3`U,34T,S$P-C0`,#(Q-S,W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM("1(;W)D93H@
M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;75V9G,N<W%L+'8@,2XQ(#(P,#0O
M,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%412!404),12!H;W)D
M95]M=79F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*
M("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?
M<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE
M("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D
M("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@('9F<U]P97)M<R`@("`@4TU!3$Q)3E0@3D]4
M($Y53$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`HM+2!/<BP@;VX@
M<V]M92!$0DU3('-Y<W1E;7,Z"BTM("!V9G-?9&%T82`@("`@($E-04=%+`H@
M("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F
M<U]P871H7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7W!A=&@I.PI#4D5!5$4@
M24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7VUU=F9S("AV9G-?;F%M92D[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYP9W-Q;"YS<6P`````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$P-C(`,3`U,34T,S$P-C0`,#(R-3(R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM("1(
M;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=F9S+G!G<W%L+G-Q;"QV
M(#$N,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y(&-H=6-K($5X<"`D"@I#4D5!5$4@
M5$%"3$4@:&]R9&5?=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/
M5"!.54Q,+`H@("`@=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*
M("`@('9F<U]P871H("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M=F9S7VYA;64@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?
M;6]D:69I960@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7V1A=&$@("`@("!415A4
M+`H*("`@(%!224U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%
M6"!V9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%4
M12!)3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D[
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R
M9&5?=F9S(%1/(&AO<F1E.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VQO9RYS<6P`````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,C<`,3`U,34T,S$P-C0`,#(Q
M,S8V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;&]G+G-Q;"QV
M(#$N,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y(&-H=6-K($5X<"`D"@I#4D5!5$4@
M5$%"3$4@:&]R9&5?;&]G("@*("`@(&ED("`@("`@("`@($E.5"!.3U0@3E5,
M3"P*("`@(&QO9W1I;64@("`@(%1)34535$%-4"!.3U0@3E5,3"P*("`@(&ED
M96YT("`@("`@($-(05(H,38I($Y/5"!.54Q,+`H@("`@<')I;W)I='D@("`@
M24Y4($Y/5"!.54Q,+`H@("`@+2T@1F]R($1"<R!T:&%T(&1O;B=T('-U<'!O
M<G0@=&AE(%1%6%0@9FEE;&0@='EP93H*("`@("TM(&UE<W-A9V4@(%9!4D-(
M05(H,C`T."DL"B`@("!M97-S86=E("`@("!415A4+`H@("`@4%))34%262!+
M15D@*&ED*0HI.PH*1U)!3E0@24Y315)4($].(&AO<F1E7VQO9R!43R!H;W)D
M93L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]214%$344N3T-).```````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(S-#,V`#$P-3$U-#,Q,#8T`#`R,#(V-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!&25)35"!/1B!!
M3$PZ"E1H:7,@:7,@;F]T(&UY(&9I<G-T(&1O8W5M96YT871I;VXA(&)U="!M
M>2!F:7)S="!I;B!E;F=L:7-H+@I&965L(&9R964@=&\@8V]N=&%C="!M92!A
M="!T;W)S=&5N0&9L86UM:6=E<BYO<F<@:68@>6]U(&AA=F4@"F%N>2!S=6=G
M97-T:6]N<R!O<B!P<F]B;&5M<R!R96QA=&5D('1O('1H:7,@9&]C<PH*06QL
M(&D@=VEL;"!W<FET92!A8F]U="!/<F%C;&4@=VET:"!(;W)D92!I<R!B87-E
M9"!O;B!/<F%C;&4@/CT@.&D*=&AO=6=H(&ET('-H;W5L9"!W;W)K('=I=&@@
M.6D@=&]O+B`*"DD@=&AI;FL@*&DG;2!S=7)E*2`G57`@=&\@9&%T92<@879A
M:6QA8FQE(&1I<W1R:6)U=&EO;G,*87)E(&-A<&%B;&4@=&\@<G5N($]R86-L
M92X@22!H879E('1E<W1E9"!I="!O;@I3;&%C:W=A<F4@-RXQ+S@N,"`H."XQ
M+C8I(&%N9"!H879E(')U;FYI;F<@:70@;VX@1V5N=&]O(#$N,B`H."XQ+C<N
M-"D*=VET:&]U="!A;GD@4')O8FQE;7,N(%-O;64@9&ES=')I8G5T:6]N<R!A
M<F4@8V5R=&EF:65D(&QI:V4@4W5312!O<B`*4F5D2&%T+B!/;B!$96)I86X@
M:70@<VAO=6QD(&%L<V\@<G5N+@H*1G5R=&AE<FUO<F4@:2=L;"!A<W-U;64L
M('1H870@;F\@(FYO<FUA;"(@=7-E<B!I<R!G;VEN9R!T;R!I;G-T86QL"F]R
M(&ES(&EN(&YE960@=&\@:6YS=&%L;"!A;B!/<F%C;&4@1$(@*&]F(&-O=7)S
M92!T:&5R92!A<F4@<V]M92!F<F5A:W,@.RD*<V\@:VYO=VQE9&=E(&%B;W5T
M('-E='1I;F<@=7`@86YD(&UA:6YT86EN(&%N($]R86-L90I$0B!I<R!I;F1I
M<W!E;G-A8FQE(2!-87EB92!T:&ES(&ES('1H92!R96%S;VX@=VAY(&YO($%D
M;6EN"FAA<R!E=F5R('!O<W1E9"!A;GD@9&]C<R!A8F]U="!G971T:6YG($AO
M<F1E('=O<FL@=VET:"!/<F%C;&4*"DY/5$4Z(&%L;"!D;V-S(&%R92!A=F%I
M;&%B;&4@9G)O;2!W=W<N;W)A8VQE+F-O;2!F;W(@9G)E92`H049!24LI"@I.
M;W<@;&5T)W,@8F5G:6XZ"@I#87-E(#$I(`I))VQL(&%S<W5M92!T:&%T('EO
M=2!D;R!N;W0@:&%V92!A;B!I;G-T86YC92!R=6YN:6YG(&%N9"!T:&5R969O
M<F4*87)E(&%B;W5T('1O(&EN<W1A;&P@82!F<F5S:"!I;G-T86YC92`B:&]R
M9&4B("X*"BTM"6-H96-K(&%N9"!I9B!N965D960@8VAA;F=E('-H87)E9"!M
M96UO<GD@<&%R86UE=&5R<PHM+0EC<F5A=&4@870@;&5A<W0@=&AE(&1B82!G
M<F]U<`HM+0EC<F5A=&4@>6]U<B!O<F%C;&4@=7-E<BP@;F%M92!I="!A<R!Y
M;W4@;&EK90H);6%K92!S=7)E('EO=7(@;W)A+75S97(@:7,@:6X@=&AE(&=R
M;W5P(&1B80HM+0ES=2`M(#QY;W5R(&9R97-H(&]R86-L92!U<V5R/@HM+2`)
M<V5T('5P(&%L;"!T:&4@87!P<F]P<FEA=&4@96YV:7)O;FUE;G0@=F%R:6%B
M;&5S(&9O<B!O<F%C;&4*"71A:V4@82!C;&]S92!L;V]K(&%T('1H92!I;G-T
M86QL(&AO=W1O('!R;W9I9&5D(&)Y(&]R86-L90HM+0EM;W5N="!T:&4@0T0@
M*&EF(&ET(&ES('EO=7(@<V]U<F-E(&UE9&EA*0HM+0ER=6X@=&AE('-C<FEP
M="!R=6Y);G-T86QL97(@+2!B971T97(@=&\@:&%V92!8,3$@:6YS=&%L;&5D
M(#LI"@E!='1E;G1I;VXZ($EF('EO=2!A<F4@86)O=70@=&\@:6YS=&%L;"!/
M<F%C;&4@.6D*"61O($Y/5"!R=6X@=&AE(&EN<W1A;&QE<B!F<F]M(&1I<F5C
M=&QY(&9R;VT@>6]U<B!#1"$*"6QI:V4@8V0@+V-D<F]M(&%N9"!T:&5N('-T
M87)T(&ET(&)Y('1Y<&EN9R`N+W)U;DEN<W1A;&QE<@H)>6]U('=O;B=T(&)E
M(&%B;&4@=&\@=6YM;W5N="!T:&4@0T0@;&%T97(@;VX@8G5T('EO=2!H879E
M('1O"@EB96-A=7-E(#EI(&ES(&$@,T-$+5-E=`HM+0EF;VQL;W<@=&AE(&EN
M<W1R=6-T:6]N<R!G:79E;B!B>2!T:&4@:6YS=&%L;&%T:6]N('!R;V=R86UM
M"@EA="!T:&4@<&]I;G0@=VAE<F4@>6]U(&%R92!A<VME9"!F;W(@86X@:6YS
M=&%L;&%T:6]N(&UE=&AO9`H)8VAO;W-E(")U<V5R+61E9FEN960B+B!4:&ES
M(&ES="!E<W!E8VEA;&QY(%9%4ED@24U03U)414Y4(&EF('EO=0H)87)E(&%B
M;W5T('1O(&EN<W1A;&P@.&D@<VEN8V4@>6]U(&AA=F4@=&\@<&%T8V@@=&AE
M(&EN<W1A;&QA=&EO;@H)0D5&3U)%('EO=2!C<F5A=&4@>6]U<B!D871A8F%S
M92$@268@>6]U(&YO="!C:&]O<V4@(G5S97(M9&5F:6YE9"(*"71H92!P<F]G
M<F%M(")D8F%S<VES="(@=VEL;"!A=71O;6%T:6-A;&QY('-T87)T(&%T('1H
M92!E;F0@;V8*"71H92!I;G-T86QL871I;VX@<')O8V5S<R!A;F0@=VEL;"!H
M86YG(&%N9"]O<B!F86EL+@HM+0EA="!T:&4@96YD(&]F('EO=7(@:6YS=&%L
M;&%T:6]N('EO=2!H879E('1O(&-O;F9I9W5R92!Y;W5R(&QI<W1E;F5R+F]R
M82P*"71N<VYA;65S+F]R82!A;F0@>6]U<B!S<6QN970N;W)A(%1H:7,@:7,@
M86QL(&1O;F4@8GD@=&AE"@EI;G-T86QL871I;VX@<')O9W)A;6TN(`HM+0E.
M;W<Z(&EF('EO=2!U<V4@."XQ+C<@9V5T('1H92!P871C:"!G;&EB8RTR+C$N
M,RUS='5B<RYT87(N9WH@9G)O;2!/<F%C;&4N(`H)270G<R!A="!T:&4@<V%M
M92!P86=E(&QI:V4@=&AE(&1B+7-O=7)C92X@26YS=&%L;"!A<R!D97-C<FEB
M960@:6X@4D5!1$U%+G-T=6(*"2AI="=S(&EN('1H92!P86-K86=E('-O(&9I
M<G-T('5N=&%R(&ET('-O;65W:&5R92!E;'-E(&]R('5S92`G;6,G("D*+2T)
M3F]W(&-R96%T92!Y;W5R(&1A=&%B87-E+B!2=6X@(F1B87-S:7-T(@H)270G
M<R!N;W<@;VX@>6]U('1O(&1E8VED92!H;W<@8FEG('1H92!I;FET:6%L('1A
M8FQE<W!A8V5S(&%R92P@:&]W(&UA;GD*"6-O;G1R;VP@9FEL97,@>6]U(&QI
M:V4L(&]F(&-O=7)S92!H;W<@:70G<R!N86UE('=I;&P@8F4@86YD('=H870*
M"6]P=&EO;B!Y;W4@<&QA;B!T;R!U<V4@;&EK92!);G1E<DUE9&EA+B!)="=S
M(%EO=7(@1&5C:7-I;VX@(0H)*$)45SH@=&AE(&1E9F%U;'1S('=I;&P@=V]R
M:R!A;F0@87)E('9E<GD@=&EM92!C;VYS=6UI;F<@.RD*"4%T('1H92!E;F0@
M;&5T('1H92!D8F%S:7-T('!R;V=R86T@<V%V92!T:&4@8V]N9FEG=7)A=&EO
M;BX@66]U(&-A;B!C:&]O<V4*"6QO8V%T:6]N(&%N9"!N86UE+B!.;W<@>6]U
M(&-A;B!C;&]S92!D8F%S<VES="X*+2T)8VAA;F=E('1O('1H92!L;V-A=&EO
M;B!W:&5R92!Y;W4@<W1O<F5D('1H92!S8W)I<'1S(&%N9"!T86ME(&$@<VAO
M<G0@;&]O:PH)870@;&5A<W0@:6YT;R!O<F%C;&5R=6XN<V@@86YD(&]R86-L
M97)U;C$N<V@N($EF(&%L;"!I<R!/2R!C<F5A=&4@=&AE(&1A=&%B87-E.@H)
M<G5N("XO;W)A8VQE<G5N+G-H+B`*"5-I="!B86-K('1A:V4@82!C=7`@;V8@
M8V]F9F5E(&%N9"!H;W!E(&%L;"!W:6QL(&)E(&=O;V0@.RD*"@E)9B!Y;W4@
M8VAO;W-E9"!T:&4@26YT97)-961I82!O<'1I;VX@=&AE(&-R96%T:6]N('!R
M;V-E<W,@=VEL;"!T86ME"@EA8F]U="`R(&%N9"!A(&AA;&8@:&]U<B`H;VX@
M;7D@-3`P34AZ+5`S(#HM*2X@5VET:&]U="!*879A(&ET('=I;&P@=&%K90H)
M86)O=70@,2!H;W5R+B`H=&AI<R!B;W1H(&ES="!S:&]R="`M(#EI('1A:V5S
M(&%S(&UI;BX@='=I8V4@=&AA="!T:6UE("$I"@D*"4Y/5$4Z(&-H;V]S:6YG
M($EN=&5R365D:6$@=VEL;"!G:79E('EO=2!E;FAA;F-E9"!P;W-S:6)I;&ET
M:65S(&9O<B!S=&]R:6YG"@EA;F0@;6%N:7!U;&%T:6YG(&UE9&EA(&9I;&5S
M+B!,;V]K(&%T(&AT='`Z+R]I;G1E<FUE9&EA+F%S+61A=&%S97)V:6-E+F1E
M+PH)9F]R(&%N(&5X86UP;&4N+BX*"0H)04Y/5$A%4B!.3U1%.B!I9B!Y;W4@
M:6YS=&%L;&5D(#@N,2XW(&%N9"!A9G1E<G=A<F1S(&%P<&QI960@86X@=7`@
M=&\@9&%T90H)<&%T8VAS970@*&QI:V4@."XQ+C<N-"D@>6]U($U54U0@<F5P
M871C:"!Y;W5R(&EN<W1A;&QA=&EO;B!W:71H('1H92`*"6=L:6)C+7-T=6)S
M('!A=&-H(&]R('EO=7(@1$(@=V]N)W0@<G5N"@D*"5!23T),14U3(#\Z($QO
M;VL@870@=W=W+F]R869A<2YC;VT@9F]R('EO=7(@86YS=V5R"@I!;&P@=V5N
M="!F:6YE/R!';V]D+"!L971S(&=O(&%H96%D(&%N9"!C<F5A=&4@82!N97<@
M=&%B;&5S<&%C92!C86QL960@:&]R9&4*"BTM"51H92!D871A8F%S92!S:&]U
M;&0@<G5N(&%F=&5R(&ET('=A<R!S=6-C97-F=6QL>2!C<F5A=&5D+B!,;V=I
M;B!A<R!U<V5R('-Y<W1E;0H);W(@<WES("AL:6ME('EO=2!P<F5F97(I+B!4
M:&4@<&%S<W=O<F1S('=H97)E('=R:71T96X@=&\@>6]U(&]N(%-41$]55"X*
M"5!L96%S92!C:&%N9V4@=&AE;2$@22!K;F]W(&1A=&%B87-E<R!R=6YN:6YG
M(&9O<B!Y96%R<R!S=&]R:6YG(&EM<&]R=&%N="!D871A"@EA;F0@<W1I;&P@
M:&%V92!T:&4@9&5F875L="!P87-S=V]R9"`A(0H)*&UA;F%G97(@9F]R('-Y
M<W1E;2!A;F0@8VAA;F=E7V]N7VEN<W1A;&P@9F]R('-Y<RD*"BTM"7-Q;'!L
M=7,@<WES+V-H86YG95]O;E]I;G-T86QL0#QY;W5R(%-)1#X*"6EF('EO=2!P
M<F]P97)L>2!S970@=&AE($]204-,15]3240@96YV:7)O;FUE;G0@=F%R:6%B
M;&4@>6]U(&-A;B!O;6UI="!T:&4*"71R86EL:6YG($`\>6]U<B!S:60^('=H
M96X@>6]U(&%R92!L;V=G960@;VX@=&\@=&AE(&UA8VAI;F4@=VAI8V@@:7,@
M<G5N;FEN9R!T:&4@1$(N"@HM+0EC<F5A=&4@=&AE('1A8FQE<W!A8V4@9F]R
M(&AO<F1E"@ES<6P^($-214%412!404),15-004-%($A/4D1%"B`@("`@("`@
M("`@("`@3$]'1TE.1PH@("`@("`@("`@("`@($1!5$%&24Q%("<\64]54B!0
M051(($A%4D4^+TA/4D1%+F1B9B<@4TE:12`\05,@64]5($Q)2T4^33L*"@E4
M:&ES(&ES(&EN9&5E9"!V97)Y('-I;7!L92!B=70@:70@=V]R:W,@86YD(&YO
M=&AI;F<@:&%S('1O(&)E(&EN('5P<&5R8V%S90H);&5T=&5R<RX@069T97(@
M82!F97<@<V5C;VYD<R!O<B!M:6YU=&5S("T@9&5P96YD<R!O;B!H;W<@;6%N
M>2!M96=A8GET97,*"7EO=2!G879E('1O('1H870@=&%B;&5S<&%C92`M(&$@
M;F5W(&1A=&%F:6QE(&AA<R!B965N(&-R96%T960N"@HM+0E792!C86X@;F]W
M(&-R96%T92!A('5S97(@=VET:"!D969A=6QT('1A8FQE<W!A8V4@2$]21$4L
M(&QE=',@;F%M92!H:6T@:&]R9&4Z"@H)0U)%051%(%5315(@2$]21$4@4%)/
M1DE,12!$149!54Q4($E$14Y4249)140@0ED@/'EO=7(@<&%S<W=O<F0@:&5R
M93X@"B`@("`@("`@5$%"3$534$%#12!(3U)$12!414U03U)!4ED@5$%"3$53
M4$%#12!414U0(%%53U1!(%5.3$E-251%1"!/3B!414U0"@E154]402!53DQ)
M34E4140@3TX@2$]21$4@04-#3U5.5"!53DQ/0TL["@E'4D%.5"!#3TY.14-4
M(%1/($A/4D1%.PH*+2T)8V]M;6ET('EO=7(@=V]R:SH@/B!C;VUM:70["@EA
M;F0@;&]G(&]U=`HM+0EL;V=I;B!A<R!U<V5R(&AO<F1E.B!S<6QP;'5S(&AO
M<F1E+SQP87-S=V]R9#Y`/'EO=7(@<VED/B!A;F0@8W)E871E('1H92!T86)L
M97,*"2$\<&%T:"!T;R!H;W)D93XO<V-R:7!T<R]D8B]O<F%C;&5?8W)E871E
M+G-Q;"!A;F0@8V]M;6ET('EO=7(@86MT:6]N.B`^(&-O;6UI=#L*"71H92!T
M86)L97,@=VEL;"!B92!C<F5A=&5D(&EN('1H92!D969A=6QT('1A8FQE<W!A
M8V4@9F]R('EO=7(@:&]R9&4@=7-E<@H)"D]+(&YO=R!Y;W4@8V%N(&-O;F9I
M9W5R92!(;W)D92!T;R!U<V4@>6]U<B!I;G-T86YC92!B=70@869T97(@82!R
M96)O;W0@3W)A8VQE"G=I;&P@;F]T('-T87)T(&%U=&]M871I8VQY+B!4:&%T
M(&ES('=H870@=V4@87)E(&=O:6YG('1O(&-O;F9I9W5R92!N;W<N"@HM+0EL
M;V=O=70@;V8@;W)A8VQE+"!L;V=I;B!A<R!U<V5R('-Y<R!O<B`\>6]U<B!O
M<F%C;&4@=7-E<CX@"@EA;F0@<VAU=&1O=VX@>6]U<B!I;G-T86YC93H@*&AO
M<&4@>6]U<B!O<F%C;&4@=7-E<B!I<R!I;B!T:&4@9W)O=7`@9&)A("T*"6EF
M(&YO="!H92!C86XG="!S:'5T(&1O=VX@>6]U<B!I;G-T86YC92D*"3X@8V]N
M;F5C="!I;G1E<FYA;`H)/B!S:'5T9&]W;B!I;6UE9&EA=&4*"6%N9"!L;V=O
M=70N+BX*"0HM+0ET97-T('1H92!S8W)I<'0@(F1B<W1A<G0B(&EN("1/4D%#
M3$5?2$]-12]B:6X@268@=&AE($1"(&1O97,@;F]T('-T87)T"@EY;W4@:&%V
M92!T;R!E9&ET(&ET(&]R(&-R96%T92!A(&QI;FL@9G)O;2`D3U)!0TQ%7TA/
M344O9&)S+VEN:70\<VED+6YA;64^+F]R80H)=&\@)$]204-,15](3TU%+V%D
M;6EN+SQS:60@;F%M93XO<&9I;&4O:6YI=#QS:60M;F%M93XN;W)A"@DH(&1B
M<W1A<G0@=VEL;"!L;V]K(&9O<B!Y;W5R('-I9"UF:6QE<R!I;B!S=6)D:7(@
M(F1B<R(@8G5T('1H97-E(&%R92!S=&]R960*"75N9&5R("1/4D%#3$5?2$]-
M12]A9&UI;B\\<VED(&YA;64^+W!F:6QE+R`M('1H:7,@;6%Y8F4@:7,@82!B
M=6<@;W(@80H)9F5A='5R92!I;B!T:&4@;W)A8VQE(&EN<W1A;&QE<B`I"@ET
M97-T(")D8G-T87)T(B!A9V%I;B`M(&YO=R!I="!S:&]U;&0@=V]R:RP@:2!H
M;W!E"@HM+0EE9&ET('1H92!F:6QE("]E=&,O;W)A=&%B"@E#:&%N9V4@=&AE
M(&QI;F4*"3QS:60M;F%M93XZ/'EO=7(@3W)A8VQE($AO;64@+2!&=6QL('%U
M86QI9FEE9"!P871H/CI.("`@=&\*"3QS:60M;F%M93XZ/'EO=7(@3W)A8VQE
M($AO;64@+2!&=6QL('%U86QI9FEE9"!P871H/CI9"@HM+0EN;W<@8VAA;F=E
M(&]R(&-R96%T92!A('-T87)T=7`@<V-R:7!T('=H:6-H(&ES(&5X96-U=&5D
M(&%T(&)O;W0@=&EM92X@270@<VAO=6QD(&-O;G1A:6X*"7-O;65T:&EN9R!L
M:6ME('1H:7,Z"@D*"7-U("T@/'EO=7(@;W)A8VQE('5S97(^("UC("(\:&]U
M<B!P871H(&AE<F4^+V)I;B]L<VYR8W1L('-T87)T(@H)<W4@+2`\>6]U<B!O
M<F%C;&4@=7-E<CX@+6,@(CQY;W5R('!A=&@@:&5R93XO8FEN+V1B<W1A<G0B
M"@H)86YD(&]F(&-O=7)S92!Y;W5R(&EN<W1A;F-E('-H;W5L9"!B92!S=&]P
M<&5D(&$@<F5G=6QA<B!W87DN(%!L86-E('1H:7,*"6EN('1H92!A<'!R;W!R
M:6%T92!S8W)I<'0@=VAI8V@@:7,@97AE8W5T960@870@<VAU=&1O=VX@=&EM
M90H*"7-U("T@/'EO=7(@;W)A8VQE('5S97(^("UC("(\:&]U<B!P871H(&AE
M<F4^+V)I;B]L<VYR8W1L('-T;W`B"@ES=2`M(#QY;W5R(&]R86-L92!U<V5R
M/B`M8R`B/'EO=7(@<&%T:"!H97)E/B]B:6XO9&)S:'5T(@H*+2T)=&5S="!I
M=`H*16YD(&]F($-A<V4@,2D*"@I#87-E(#(I"@I0<F]B;&5M.B!9;W4@:&%V
M92!A;B!A;&QR96%D>2!R=6YN:6YG(&]R86-L92!D871A8F%S92!A;F0@=V]U
M;&0@;&EK90IT;R!A9&0@82!N97<@:6YS=&%N8V4N(%-O;'5T:6]N(&ES('%U
M:65T(&5A<WDN"D9O<B!N;W<L('1H92!N97<@9&%T86)A<V4G(&YA;64@=VEL
M;"!B92`M+3X@:&]R9&4*"D)E9F]R92!I('-T87)T(&DG;&P@;6%K92!S;VUE
M(&%S<W5M<'1I;VYS.@HH4$Q%05-%($-(04Y'12!42$4@4$%42$Y!3453($%3
M($Y%0T534T%262`I"@HQ+@DD3U)!0TQ%7TA/344]+VAO;64O;W)A8VQE"C(N
M"21/4D%#3$5?0D%312`]("1/4D%#3$5?2$]-10HS+@E9;W5R(&5X:7-T:6YG
M($1A=&%B87-E(&ES(&EN<W1A;&QE9"!U;F1E<B`D3U)!0TQ%7TA/344O;W)A
M9&%T82\\>6]U<B!I;G-T86YC92!N86UE/@HT+@E9;W5R(&5X:7-T:6YG(%1R
M86-E+T1U;7`O<&9I;&4O8F1U;7`N+BX@+2!D:7)E8W1O<FEE<R!A<F4@:6YS
M=&%L;&5D('5N9&5R"@D@)$]204-,15](3TU%+V%D;6EN+SQY;W5R(&EN<W1A
M;F-E(&YA;64^+PH*"51H97)E9F]R92!Y;W5R(&YE=R!H;W)D92!D871A8F%S
M92!F:6QE<R!W:6QL(&=O(&EN=&\@86YO=&AE<B!D:7)E8W1O<GDZ"@DD3U)!
M0TQ%7TA/344O;W)A9&%T82]H;W)D92\*"@E4:&4@5')A8V4O1'5M<"]P9FEL
M92]B9'5M<"XN+B`M(&1I<G,@9V\@=&\Z"@DD3U)!0TQ%7TA/344O861M:6XO
M:&]R9&4O"@H)5&AE(&EN:71H;W)D92YO<F$@9FEL92!I;B`D3U)!0TQ%7TA/
M344O9&)S('-H;W5L9"!B92!A(&QI;FL@=&\Z"@DD3U)!0TQ%7TA/344O861M
M:6XO:&]R9&4O<&9I;&4O:6YI="YO<F$*"DQE=',@8F5G:6XZ"@HM+0EC<F5A
M=&4@=&AE(&1I<F5C=&]R:65S(&9O<B!Y;W5R(&YE=R!D8B`H87,@>6]U<B!/
M4D%#3$4@=7-E<BDZ"@DC/B!M:V1I<B`M<"`D3U)!0TQ%7TA/344O;W)A9&%T
M82]H;W)D92]A<F-H:79E"@DC/B!M:V1I<B`M<"`D3U)!0TQ%7TA/344O861M
M:6XO:&]R9&4O861H;V,@7`H)"2`@("`D3U)!0TQ%7TA/344O861M:6XO:&]R
M9&4O8F1U;7`@7`H)"2`@("`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O8V1U
M;7`@7`H)"2`@("`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O8W)E871E(%P*
M"0D@("`@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+V5X<"!<"@D)("`@("1/
M4D%#3$5?2$]-12]A9&UI;B]H;W)D92]P9FEL92!<"@D)("`@("1/4D%#3$5?
M2$]-12]A9&UI;B]H;W)D92]U9'5M<`H*+2T)8V]P>2!Y;W5R(&5X:7-T:6YG
M(&EN:70N;W)A(&9I;&4@9G)O;2`D3U)!0TQ%7TA/344O861M:6XO/&5X:7-T
M:6YG(&EN<W1A;F-E/B]P9FEL92\*"71O("1/4D%#3$5?2$]-12]A9&UI;B]H
M;W)D92]P9FEL92\@86YD(&UA:V4@=&AE(&%P<')O<')I871E(&-H86YG97,@
M:6X@:70*"4-(04Y'12!!5"!,14%35"!42$4@4$%42$Y!3453("$A(0H*+2T)
M;6%K92!T:&4@;&EN:R!F<F]M("1/4D%#3$5?2$]-12]D8G,O:6YI=&AO<F1E
M+F]R82!T;PH))$]204-,15](3TU%+V%D;6EN+VAO<F1E+W!F:6QE+VEN:70N
M;W)A"@H)(SX@;&X@+7,@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+W!F:6QE
M+VEN:70N;W)A("1/4D%#3$5?2$]-12]D8G,O:6YI=&AO<F1E+F]R80H*+2T)
M<V5T($]204-,15]3240@=&\@:&]R9&4*"2,^($]204-,15]3240]:&]R9&4*
M"BTM"6QO9VEN(&%N9"!S=&%R='5P('1H92!I;G-T86YC90H)(SX@<W%L<&QU
M<R`O;F]L;V<*"7-Q;#X@<W1A<G1U<"!P9FEL93TO:&]M92]O<F%C;&4O861M
M:6XO:&]R9&4O<&9I;&4O:6YI="YO<F$@;F]M;W5N=`H*+2T)8W)E871E('1H
M92!D871A8F%S92!F<F]M(&-R96%T95]H;W)D95]D8BYS<6P@+2!Y;W4@<VAO
M=6QD(&]F(&-O=7)S92!H879E('-A=F5D(&ET('-O;7=H97)E(#LI"@ES<6P^
M("$O<&%T:"]T;R]C<F5A=&5?:&]R9&5?9&(N<W%L"@H)87,@=&5M<&QA=&4@
M:2!T;V]K('1H92!S8W)I<'0@9G)O;0H):'1T<#HO+W=W=RYA9'`M9VUB:"YC
M:"]O<F$O861M:6XO8W)E871I;F=D8FUA;G5A;&QY+FAT;6PC<V%M<&QE8W)E
M871E9&%T86)A<V4*"6%N9"!M861E('-O;64@;6EN;W(@8VAA;F=E<RX*"BTM
M"6-R96%T92!T:&4@9&%T82!D:6-T:6]N87)Y+"!E=&,N"@ES<6P^("$O:&]M
M92]O<F%C;&4O<F1B;7,O861M:6XO8V%T86QO9RYS<6P*"7-Q;#X@(2]H;VUE
M+V]R86-L92]R9&)M<R]A9&UI;B]C871P<F]C+G-Q;`H)<W%L/B`A+VAO;64O
M;W)A8VQE+W)D8FUS+V%D;6EN+V-A=&AS+G-Q;`H)<W%L/B!C;VUM:70["@ES
M<6P^(&5X:70*"BTM"6YO=R!A9&0@82!N97<@;&EN92!T;R`O971C+V]R871A
M8@H*"6]L9"`H(&]N;'D@,2!I;G-T86YC92`I.@H)/'EO=7(@:6YS=&%L;&5D
M(&EN<W1A;F-E(&YA;64^.B]H;VUE+V]R86-L93I9"@H);F5W("@@=VET:"!T
M:&4@;F5W(&]N92`I.@H)/'EO=7(@:6YS=&%L;&5D(&EN<W1A;F-E(&YA;64^
M.B]H;VUE+V]R86-L93I9"@EH;W)D93HO:&]M92]O<F%C;&4Z60H*+2T)861D
M('1H92!N97<@:6YS=&%N8V4@=&\@>6]U<B!T;G-N86UE<RYO<F$*"75S92!T
M:&4@:F%V82!G=6D@;F5T.&%S<VES="!O<B!C;W!Y(&%N9"!P87-T92!T:&4@
M<W1A=&5M96YT<R!B>2!Y;W5R<V5L9B!A;F0*"6UA:V4@=&AE(&-H86YG97,@
M87,@;F5E9&5D"@HM+0EA9G1E<B!A;&PL('1H92!S8W)I<'1S(&1B<W1A<G0@
M=6YD(&1B<VAU="!W:6QL('1H96X@875T;VUA=&EC;'D@<W1A<G0@86YD('-H
M=71D;W=N(&%L;`H):6YS=&%N8V5S(&%T(&]N8V4*"D-R96%T:6YG('1H92!4
M86)L97-P86-E(&%N9"!R97%U:7)E9"!U<V5R(&ES('1H92!S86UE(&%S("!D
M97-C<FEB960@86)O=F4*"@I)(&AO<&4@=&AA="!T:&5R92!A<F4@;F]T('-O
M(&UA;GD@<W!E;&QI;F<@;6ES=&%K97,@*"!M>2!N871I=F4@;&%N9W5A9V4@
M:7,@9V5R;6%N("D@"F%N9"!T:&%T('1H:7,@=VEL;"!B92!H96QP9G5L;"!F
M;W(@<V]M96]N90H*16YD(&]F($-A<V4@,BD*"B1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]S<6PO4D5!1$U%+D]#23@L=B`Q+C(@,C`P-"\P.2\R-2`Q.3HU-CHQ
M,B!C:'5C:R!%>'`@)`H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]U<V5R<RYS<6P`````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-C(R`#$P-3$U-#,Q,#8T`#`R,3<T,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+2`D2&]R9&4Z(&AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W5S97)S+G-Q;"QV(#$N,BXQ,"XR(#(P
M,#4O,3`O,3@@,3$Z,S0Z,#`@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?=7-E<G,@*`H@("`@=7-E<E]U:60@("`@("`@("`@("`@("`@("`@(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<&%S<R`@("`@("`@("`@
M("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W-O9G1?
M97AP:7)A=&EO;E]D871E("`@24Y414=%4BP*("`@('5S97)?:&%R9%]E>'!I
M<F%T:6]N7V1A=&4@("!)3E1%1T52+`HM+0H@("`@4%))34%262!+15D@*'5S
M97)?=6ED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,
M151%($].(&AO<F1E7W5S97)S(%1/(&AO<F1E.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?:&ES=&]R:65S+G-Q;```````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3(S-``Q,#4Q-30S,3`V-``P,C(V,3$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]H:7-T;W)I97,N<W%L+'8@,2XQ+C(N,2`R,#`U+S$P+S$X
M(#$Q.C,T.C`P(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O
M<FEE<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*
M("`@(&]B:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@
M("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@
M(&AI<W1O<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R
M>5]D97-C("`@("!415A4+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2
M*#(U-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L"BTM"B`@("!04DE-
M05)9($M%62`H:&ES=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y
M7V%C=&EO;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO
M;BD["D-214%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T
M;W)I97,@*&AI<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?
M:61X($].(&AO<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@I'4D%.5"!3
M14Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES=&]R
M:65S(%1/(&AO<F1E.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S
M<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N;V-I."YS<6P`````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#4V,``Q,#4Q-30S,3`V-``P,C0T-C,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYO8VDX+G-Q;"QV(#$N
M,BXQ,"XQ(#(P,#4O,3`O,3@@,3$Z,S0Z,#`@:F%N($5X<"`D"@I#4D5!5$4@
M5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO;E]I9"`@
M("`@("`@("`@("!605)#2$%2,B@S,BD@3D]4($Y53$PL"B`@("!S97-S:6]N
M7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?9&%T
M82`@("`@("`@("`@0DQ/0BP*+2T*("`@(%!224U!4ED@2T59("AS97-S:6]N
M7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%
M($].(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F
M<RYO8VDX+G-Q;```````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P-34`
M,3`U,34T,S$P-C0`,#(R,C0P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?=F9S+F]C:3@N<W%L+'8@,2XS(#(P,#0O,#DO,C$@,#,Z,S0Z,#8@
M8VAU8VL@17AP("0*"D-214%412!404),12!H;W)D95]V9G,@*`H@("`@=F9S
M7VED("`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@
M("`@("!.54U"15(H."D@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!
M4D-(05(R*#(U-2DL"B`@("!V9G-?;F%M92`@("`@(%9!4D-(05(R*#(U-2D@
M3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($Y534)%4B@Q-BD@3D]4($Y5
M3$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(R*#(U-2DL"B`@("!V9G-?
M9&%T82`@("`@($),3T(L"BTM"B`@("!04DE-05)9($M%62`@("AV9G-?:60I
M"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H
M=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E
M7W9F<R`H=F9S7VYA;64I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7W9F<R!43R!H;W)D93L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7W!R969S+FUS<W%L+G-Q;```````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$P,3$`,3`U,34T,S$P-C0`,#(S,#0V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?<')E9G,N;7-S<6PN<W%L+'8@,2XQ+C(N,B`R,#`V+S`V
M+S(Y(#$V.C(Y.C`S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7W!R
M969S("@*("`@('!R969?=6ED("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!P<F5F7W-C;W!E("`@("`@5D%20TA!4B@Q-BD@3D]4($Y53$P@
M1$5&055,5"`G)RP*("`@('!R969?;F%M92`@("`@("!605)#2$%2*#,R*2!.
M3U0@3E5,3"P*("`@('!R969?=F%L=64@("`@("!605)#2$%2*$U!6"DL"BTM
M"B`@("!04DE-05)9($M%62`H<')E9E]U:60L('!R969?<V-O<&4L('!R969?
M;F%M92D**3L*"D-214%412!)3D1%6"!P<F5F7W5I9%]I9'@@3TX@:&]R9&5?
M<')E9G,@*'!R969?=6ED*3L*0U)%051%($E.1$58('!R969?<V-O<&5?:61X
M($].(&AO<F1E7W!R969S("AP<F5F7W-C;W!E*3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]P<F5F<R!43R!H;W)D
M93L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7W1O:V5N<RYS<6P`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`U-#$`,3`U,34T,S$P-C0`,#(R,3`S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM("1(;W)D93H@:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?=&]K96YS+G-Q;"QV(#$N,BXQ,"XR(#(P,#4O
M,3`O,3@@,3$Z,S0Z,#`@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M=&]K96YS("@*("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!4B@Q,#`I($Y/
M5"!.54Q,+`H@("`@=&]K96Y?:60@("`@("`@("!605)#2$%2*#,R*2!.3U0@
M3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`HM
M+0H@("`@4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L('1O:V5N7VED*0HI
M.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO
M<F1E7W1O:V5N<R!43R!H;W)D93L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S
M97-S:6]N:&%N9&QE<BYM<W-Q;"YS<6P`````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-38W
M`#$P-3$U-#,Q,#8T`#`R-#<V-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7W-E<W-I;VYH86YD;&5R+FUS<W%L+G-Q;"QV(#$N,2XR+C$@,C`P
M-B\P,2\Q."`Q.3HU.3HQ,"!B96X@17AP("0*"D-214%412!404),12!H;W)D
M95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED("`@("`@("`@("`@
M(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I
M960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@
M(%9!4D))3D%262A-05@I+`H*("`@(%!224U!4ED@2T59("AS97-S:6]N7VED
M*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].
M(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;&]G+FUS<W%L+G-Q
M;``````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8U-P`Q,#4Q-30S,3`V
M-``P,C(U,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]L;V<N
M;7-S<6PN<W%L+'8@,2XQ+C(N,2`R,#`V+S`Q+S$X(#$Y.C4X.C0X(&)E;B!%
M>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7VQO9R`H"B`@("!I9"`@("`@("`@
M("!)3E0@3D]4($Y53$PL"B`@("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4
M($Y53$PL"B`@("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("`@
M('!R:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("`@("TM($9O<B!$0G,@=&AA
M="!D;VXG="!S=7!P;W)T('1H92!605)#2$%2*$U!6"D@9FEE;&0@='EP93H*
M("`@("TM(&UE<W-A9V4@(%9!4D-(05(H,C`T."DL"B`@("!M97-S86=E("`@
M("!605)#2$%2*$U!6"DL"B`@("!04DE-05)9($M%62`H:60I"BD["@I'4D%.
M5"!)3E-%4E0@3TX@:&]R9&5?;&]G(%1/(&AO<F1E.PH`````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-A<&1B+G-Q
M;```````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`T-#8`,3`U,34T,S$P-C0`,#(T-S$U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM("1(
M;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N
M<V%P9&(N<W%L+'8@,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP
M("0*"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S
M97-S:6]N7VED("`@("`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@
M("`@<V5S<VEO;E]L87-T;6]D:69I960@("!)3E0@3D]4($Y53$PL"B`@("!S
M97-S:6]N7V1A=&$@("`@("`@("`@($Q/3D<@0EE412P*("`@(%!224U!4ED@
M2T59("AS97-S:6]N7VED*0HI"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]M=79F<RYM<W-Q;"YS<6P`````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,#4U`#$P-3$U-#,Q,#8T`#`R,S`W-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7VUU=F9S+FUS<W%L+G-Q;"QV(#$N,2XR+C$@
M,C`P-B\P,2\Q."`Q.3HU.#HU-"!B96X@17AP("0*"D-214%412!404),12!H
M;W)D95]M=79F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,
M3"P*("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V
M9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N
M86UE("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF
M:65D("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]P97)M<R`@("`@4TU!3$Q)3E0@
M3D]4($Y53$PL"B`@("!V9G-?9&%T82`@("`@(%9!4D))3D%262A-05@I+`H@
M("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F
M<U]P871H7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7W!A=&@I.PI#4D5!5$4@
M24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7VUU=F9S("AV9G-?;F%M92D[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]C<F5A=&4N<WEB87-E+G-Q;```````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$P,34W`#$P-3$U-#,Q,#8T`#`R,C$U,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YS>6)A<V4N<W%L+'8@,2XQ+C$P
M+C4@,C`P-B\P-B\R.2`Q-CHR.3HP,R!J86X@17AP("0*+2T*+2T@:&]R9&4@
M=&%B;&5S(&1E9FEN:71I;VYS(#H@<W%L('-C<FEP=`HM+2`P,2\R,B\R,#`S
M("T@1BX@2&5L;'D@/&9R86YC;VES+FAE;&QY0'=A;F%D;V\N9G(^"BTM(&-O
M;6UA;F0@;&EN92!S>6YT87@@.B`@:7-Q;"`M:6AO<F1E7W-Y8F%S92YS<6P*
M+2T@=V%R;FEN9R`Z('5S92!N=F%R8VAA<B!O;FQY(&EF('EO=2!N965D('5N
M:6-O9&4@96YC;V1I;F<@9F]R('-O;64@<W1R:6YG<PH*=7-E(&AO<F1E"F=O
M"@H*1%)/4"!404),12!H;W)D95]D871A=')E90IG;PH*1%)/4"!404),12!H
M;W)D95]P<F5F<PIG;PH*1%)/4"!404),12!H;W)D95]U<V5R<PIG;PH*1%)/
M4"!404),12!H;W)D95]S97-S:6]N:&%N9&QE<@IG;PH*+2T@1%)/4"!404),
M12!H;W)D95]D871A=')E95]S97$*+2T@9V\*"BTM($123U`@5$%"3$4@:&]R
M9&5?=&]K96YS"BTM(&=O"@HM+2!$4D]0(%1!0DQ%(&AO<F1E7W9F<PHM+2!G
M;PH*+2T@1%)/4"!404),12!H;W)D95]M=79F<PHM+2!G;PH*"D-214%412!4
M04),12!H;W)D95]U<V5R<R`H"B`@=7-E<E]U:60@=F%R8VAA<B@R-38I($Y/
M5"!.54Q,+`H@('5S97)?<&%S<R!V87)C:&%R*#(U-BD@3D]4($Y53$PL"B`@
M=7-E<E]S;V9T7V5X<&ER871I;VY?9&%T92!N=6UE<FEC*#$P+#`I+`H@('5S
M97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4@;G5M97)I8R@Q,"PP*2P*("!04DE-
M05)9($M%62`@*'5S97)?=6ED*0HI"F=O"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M9&%T871R964@*`H@(&1A=&%T<F5E7VED(&YU;65R:6,H,3$L,"D@241%3E1)
M5%D@3D]4($Y53$PL"B`@9W)O=7!?=6ED('9A<F-H87(H,C4V*2!.3U0@3E5,
M3"P*("!U<V5R7W5I9"!V87)C:&%R*#(U-BD@3D]4($Y53$PL"B`@9&%T871R
M965?;F%M92!V87)C:&%R*#(U-BD@3D]4($Y53$PL"B`@9&%T871R965?<&%R
M96YT<R!V87)C:&%R*#(U-BD@3E5,3"P*("!D871A=')E95]D871A('1E>'0@
M3E5,3"P*("!D871A=')E95]S97)I86QI>F5D('-M86QL:6YT($1%1D%53%0@
M,"!.3U0@3E5,3"P*("!04DE-05)9($M%62`@*&1A=&%T<F5E7VED*2P*("!&
M3U)%24=.($M%62`H=7-E<E]U:60I"B`@("!2149%4D5.0T53(&AO<F1E7W5S
M97)S*'5S97)?=6ED*0H@*0IG;PH*0U)%051%(%1!0DQ%(&AO<F1E7W!R969S
M("@*("!P<F5F7W5I9"!V87)C:&%R*#(U-BD@3D]4($Y53$PL"B`@<')E9E]S
M8V]P92!V87)C:&%R*#$V*2!.3U0@3E5,3"P*("!P<F5F7VYA;64@=F%R8VAA
M<B@S,BD@3D]4($Y53$PL"B`@<')E9E]V86QU92!T97AT($Y53$PL"B`@4%))
M34%262!+15D@("AP<F5F7W5I9"QP<F5F7W-C;W!E+'!R969?;F%M92D**0IG
M;PH*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*("!S97-S
M:6]N7VED('9A<F-H87(H,S(I($Y/5"!.54Q,+`H@('-E<W-I;VY?;&%S=&UO
M9&EF:65D(&YU;65R:6,H,3$L,"D@3D]4($Y53$PL"B`@<V5S<VEO;E]D871A
M(&EM86=E($Y53$PL"B`@4%))34%262!+15D@("AS97-S:6]N7VED*0HI"F=O
M"@H*+2T@0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7W-E<2`H"BTM("`@
M:60@;G5M97)I8R@Q,"PP*2!)1$5.5$E462!.3U0@3E5,3"P*+2T@("!04DE-
M05)9($M%62`@*&ED*0HM+2`I"BTM(&=O"@HM+2!#4D5!5$4@5$%"3$4@:&]R
M9&5?=&]K96YS("@*+2T@("!T;VME;E]A9&1R97-S('9A<F-H87(H,3`P*2!.
M3U0@3E5,3"P*+2T@("!T;VME;E]I9"!V87)C:&%R*#,R*2!.3U0@3E5,3"P*
M+2T@("!T;VME;E]T:6UE<W1A;7`@;G5M97)I8R@R,"PP*2!.3U0@3E5,3"P*
M+2T@("!04DE-05)9($M%62`@*'1O:V5N7V%D9')E<W,L=&]K96Y?:60I"BTM
M("D*+2T@9V\*"BTM($-214%412!404),12!H;W)D95]V9G,@*`HM+2`@('9F
M<U]I9"!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,+`HM+2`@('9F<U]T>7!E(&YU
M;65R:6,H."PP*2!.3U0@3E5,3"P*+2T@("!V9G-?<&%T:"!V87)C:&%R*#(U
M-BD@3D]4($Y53$PL"BTM("`@=F9S7VYA;64@;G9A<F-H87(H,C4V*2!.3U0@
M3E5,3"P*+2T@("!V9G-?;6]D:69I960@;G5M97)I8R@R,"PP*2!.3U0@3E5,
M3"P*+2T@("!V9G-?;W=N97(@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`HM+2`@
M('9F<U]D871A(&EM86=E($Y53$PL"BTM("`@4%))34%262!+15D@("AV9G-?
M:60I"BTM("D*+2T@9V\*"BTM($-214%412!404),12!H;W)D95]M=79F<R`H
M"BTM("`@=F9S7VED("!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,+`HM+2`@('9F
M<U]T>7!E("`@("`@;G5M97)I8R@X+#`I($Y/5"!.54Q,+`HM+2`@('9F<U]P
M871H("`@("`@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`HM+2`@('9F<U]N86UE
M("`@("`@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`HM+2`@('9F<U]M;V1I9FEE
M9"`@;G5M97)I8R@X+#`I($Y/5"!.54Q,+`HM+2`@('9F<U]O=VYE<B`@("`@
M=F%R8VAA<B@R-38I($Y/5"!.54Q,+`HM+2`@('9F<U]P97)M<R`@("`@<VUA
M;&QI;G0@3D]4($Y53$PL"BTM("`@=F9S7V1A=&$@("`@("!I;6%G92!.54Q,
M+`HM+2`@(%!224U!4ED@2T59("`@*'9F<U]I9"D*+2T@("`I"BTM(&=O"@H*
M0U)%051%($E.1$58('!R969?=6ED7VED>"!/3B!H;W)D95]P<F5F<R`H<')E
M9E]U:60I"F=O"@I#4D5!5$4@24Y$15@@<')E9E]S8V]P95]I9'@@3TX@:&]R
M9&5?<')E9G,@*'!R969?<V-O<&4I"F=O"@I#4D5!5$4@24Y$15@@9&%T871R
M965?9&%T871R965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T
M<F5E7VYA;64I"F=O"@I#4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X
M($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U:60I"F=O"@I#4D5!5$4@24Y$
M15@@9&%T871R965?=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?
M=6ED*0IG;PH*0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X
M($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*0IG;PH*
M+2T@0U)%051%($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F
M<U]P871H*0HM+2!G;PH*+2T@0U)%051%($E.1$58('9F<U]N86UE7VED>"!/
M3B!H;W)D95]V9G,@*'9F<U]N86UE*0HM+2!G;PH*+2T@0U)%051%($E.1$58
M('9F<U]P871H7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7W!A=&@I"BTM(&=O
M"@HM+2!#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7VUU=F9S
M("AV9G-?;F%M92D*+2T@9V\*"@IG<F%N="!S96QE8W0L(&EN<V5R="P@9&5L
M971E+"!U<&1A=&4@;VX@961I=&]R('1O(&AO<F1E"F=O"F=R86YT('-E;&5C
M="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W-T('1O(&AO<F1E"F=O
M"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!D8F%S
M92!T;R!H;W)D90IG;PIG<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U
M<&1A=&4@;VX@<VET92!T;R!H;W)D90IG;PIG<F%N="!S96QE8W0L(&EN<V5R
M="P@9&5L971E+"!U<&1A=&4@;VX@8V]N;F5C=&EO;B!T;R!H;W)D90IG;PIG
M<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@:&]R9&5?
M9&%T871R964@=&\@:&]R9&4*9V\*9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E
M;&5T92P@=7!D871E(&]N(&AO<F1E7W!R969S('1O(&AO<F1E"F=O"F=R86YT
M('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W)D95]S97-S
M:6]N:&%N9&QE<B!T;R!H;W)D90IG;PH*+2T@9W)A;G0@<V5L96-T+"!I;G-E
M<G0L(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7V1A=&%T<F5E7W-E<2!T;R!H
M;W)D90HM+2!G;PHM+2!G<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U
M<&1A=&4@;VX@:&]R9&5?=&]K96YS('1O(&AO<F1E"BTM(&=O"BTM(&=R86YT
M('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W)D95]V9G,@
M=&\@:&]R9&4*+2T@9V\*+2T@9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E;&5T
M92P@=7!D871E(&]N(&AO<F1E7VUU=F9S('1O(&AO<F1E"BTM(&=O"@H*"BTM
M(&%D9"!Y;W4@861M:6Y?=7-E<E]U:60@86YD(&%D;6EN7W5S97)?<&%S<PH*
M+2T@:6YS97)T(&EN=&\@:&]R9&5?=7-E<G,@=F%L=65S("@G>6]U<E]A9&UI
M;E]U<V5R7W5I9"<L("=Y;W5R7V%D;6EN7W5S97)?<&%S<U]M9#5?96YC<GEP
M=&5D)RD*+2T@9V\*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7W9F<RYS<6P`````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$Q-3``,3`U,34T,S$P-C0`,#(Q,S<S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?=F9S+G-Q;"QV(#$N,2XQ,"XR(#(P,#4O,3`O,3@@
M,3$Z,S0Z,#`@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*
M("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7W1Y
M<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($))1TE.5"!.
M3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@=F9S7V1A=&$@("`@("!,3TY'0DQ/0BP*+2T@3W(L(&]N('-O
M;64@1$)-4R!S>7-T96US.@HM+2`@=F9S7V1A=&$@("`@("!)34%'12P*("`@
M(%!224U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?
M<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%
M6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.
M5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S
M(%1/(&AO<F1E.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP
M=',O<W%L+VAO<F1E7W9F<RYM<W-Q;"YS<6P`````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P-S4`,3`U,34T,S$P-C0`,#(R-3,W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM("1(;W)D93H@:&]R
M9&4O<V-R:7!T<R]S<6PO:&]R9&5?=F9S+FUS<W%L+G-Q;"QV(#$N,2XR+C$@
M,C`P-B\P,2\Q."`Q.3HU.3HQ-B!B96X@17AP("0*"D-214%412!404),12!H
M;W)D95]V9G,@*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL
M"B`@("!V9G-?='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S
M7W!A=&@@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M
M92`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE
M9"`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?9&%T82`@("`@(%9!4D))3D%262A-
M05@I+`H@("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.
M1$58('9F<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%
M051%($E.1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE
M*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]V9G,@5$\@:&]R9&4["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7W!R969S+G-Q;```````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`W-S0`,3`U,34T,S$P-C0`,#(Q-S(W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<')E9G,N<W%L+'8@,2XR+C$P
M+C$@,C`P-B\P-B\R.2`Q-CHR.3HP,R!J86X@17AP("0*"D-214%412!404),
M12!H;W)D95]P<F5F<R`H"B`@("!P<F5F7W5I9"`@("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@<')E9E]S8V]P92`@("`@(%9!4D-(05(H,38I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"B`@("!P<F5F7VYA;64@("`@("`@5D%2
M0TA!4B@S,BD@3D]4($Y53$PL"B`@("!P<F5F7W9A;'5E("`@("`@5$585"P*
M+2T*("`@(%!224U!4ED@2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E
M9E]N86UE*0HI.PH*0U)%051%($E.1$58('!R969?=6ED7VED>"!/3B!H;W)D
M95]P<F5F<R`H<')E9E]U:60I.PI#4D5!5$4@24Y$15@@<')E9E]S8V]P95]I
M9'@@3TX@:&]R9&5?<')E9G,@*'!R969?<V-O<&4I.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO
M<F1E.PH`````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q
M;"]H;W)D95]D871A=')E92YM>7-Q;"YS<6P`````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-3(T`#$P-3$U-#,Q,#8T`#`R,S4T,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E+FUY<W%L+G-Q;"QV(#$N,2XQ,"XQ
M(#(P,#8O,#4O,C(@,C$Z,C<Z,S,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?9&%T871R964@*`H@("`@("`@9&%T871R965?:60@24Y4($Y/5"!.
M54Q,+`H@("`@("`@9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@("`@('5S97)?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@
M(&1A=&%T<F5E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@
M9&%T871R965?<&%R96YT<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@
M("!D871A=')E95]O<F1E<B!)3E0L"B`@("`@("!D871A=')E95]D871A(%1%
M6%0L"B`@("`@("!D871A=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%5
M3%0@,"!.3U0@3E5,3"P*("`@("`@(%!224U!4ED@2T59("AD871A=')E95]I
M9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D871A=')E95]N86UE7VED
M>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M92D["D-214%412!)
M3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R
M;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H
M;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E
M7W-E<FEA;&EZ960I.PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7V%T
M=')I8G5T97,@*`H@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@
M871T<FEB=71E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@871T
M<FEB=71E7VME>2!605)#2$%2*#(U-2D@1$5&055,5"`G)R!.3U0@3E5,3"P*
M("`@(&%T=')I8G5T95]V86QU92!415A4"BD["@I#4D5!5$4@24Y$15@@9&%T
M871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%6"!D871A=')E95]A='1R
M:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB
M=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T
M<FEB=71E7VME>2D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$
M14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R9&5`;&]C86QH;W-T.PI'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R!43R!H;W)D94!L;V-A;&AO<W0["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YP9W-Q;"YS<6P`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<U,#4`,3`U,34T,S$P-C0`
M,#(R,#$V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+G!G<W%L
M+G-Q;"QV(#$N,2XQ,"XU(#(P,#8O,#@O,#0@,C`Z-#DZ-#,@:F%N($5X<"`D
M"BTM"BTM(%5N8V]M;65N="!T:&4@04Q415(@;&EN92!B96QO=RP@86YD(&-H
M86YG92!T:&4@<&%S<W=O<F0N("!4:&5N(')U;B!A<SH*+2T*+2T@)"!P<W%L
M("UD('1E;7!L871E,2`M9B!C<F5A=&4N<&=S<6PN<W%L"@I#4D5!5$4@1$%4
M04)!4T4@:&]R9&4["@I<8R!H;W)D93L*"D-214%412!54T52(&AO<F1E.PH*
M+2T@04Q415(@55-%4B!H;W)D92!7251((%!!4U-73U)$("=P87-S)SL*"@I#
M4D5!5$4@5$%"3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E<E]U:60@("`@("`@
M("`@("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?
M<&%S<R`@("`@("`@("`@("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL
M"B`@("!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E("`@24Y414=%4BP*("`@
M('5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`HM+0H@("`@
M4%))34%262!+15D@*'5S97)?=6ED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%
M4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W5S97)S(%1/(&AO<F1E.PH*
M"D-214%412!404),12!H;W)D95]P<F5F<R`H"B`@("!P<F5F7W5I9"`@("`@
M("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@<')E9E]S8V]P92`@("`@
M(%9!4D-(05(H,38I($1%1D%53%0@)R<@3D]4($Y53$PL"B`@("!P<F5F7VYA
M;64@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!P<F5F7W9A;'5E
M("`@("`@5$585"P*+2T*("`@(%!224U!4ED@2T59("AP<F5F7W5I9"P@<')E
M9E]S8V]P92P@<')E9E]N86UE*0HI.PH*0U)%051%($E.1$58('!R969?=6ED
M7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]U:60I.PI#4D5!5$4@24Y$15@@
M<')E9E]S8V]P95]I9'@@3TX@:&]R9&5?<')E9G,@*'!R969?<V-O<&4I.PH*
M1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E
M7W!R969S(%1/(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]D871A=')E
M92`H"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!G<F]U<%]U
M:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]U:60@5D%20TA!
M4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;F%M92!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!D871A=')E95]P87)E;G1S(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7V]R9&5R($E.5"P*("`@(&1A=&%T
M<F5E7V1A=&$@5$585"P*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)
M3E0@1$5&055,5"`P($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AD871A
M=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D871A=')E95]N
M86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M92D["D-2
M14%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R
M964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED
M>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?;W)D97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E
M95]O<F1E<BD["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED
M>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@H*
M0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@
M9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#
M2$%2*#(U-2DL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI.PH*0U)%051%
M($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T
M871R965?871T<FEB=71E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T
M=')I8G5T97,@*&%T=')I8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T
M<F5E7V%T=')I8G5T95]K97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@*&%T=')I8G5T95]K97DI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO<F1E.PI'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R!43R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?=&]K96YS("@*("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!4B@Q
M,#`I($Y/5"!.54Q,+`H@("`@=&]K96Y?:60@("`@("`@("!605)#2$%2*#,R
M*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.
M54Q,+`HM+0H@("`@4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L('1O:V5N
M7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%
M($].(&AO<F1E7W1O:V5N<R!43R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@
M("`@=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P
M871H("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@
M($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7V1A=&$@("`@("!415A4+`H*("`@(%!2
M24U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T
M:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V
M9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!3
M14Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/
M(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H
M"B`@("!S97-S:6]N7VED("`@("`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.
M54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I960@("!)3E0@3D]4($Y53$PL
M"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@(%1%6%0L"B`@("!04DE-05)9
M($M%62`H<V5S<VEO;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D
M93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@(&AI<W1O
M<GE?:60@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO
M;B`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@
M("!"24=)3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@(%1%6%0L
M"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*("`@(&AI<W1O
M<GE?97AT<F$@("`@5$585"P*+2T*("`@(%!224U!4ED@2T59("AH:7-T;W)Y
M7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H
M;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.1$58
M(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T
M<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES
M=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@:&]R9&4["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O8W)O;F0`
M````````````````````````````````````````````````````````````
M````````````````````,#$P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$V,3$`,3`U,34T,S$P-C0`,#$W,3,Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````",A+W5S<B]L;V-A;"]P<V$O861M:6XO
M8FEN+W!H<`H\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+V-R
M;VYD+'8@,2XT+C$P+C4@,C`P-B\P-B\Q-B`P.#HR-#HR.2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*<F5Q=6ER
M95]O;F-E("=(;W)D92]#3$DN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]3
M8VAE9'5L97(N<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N<R!T:&ES
M(&9R;VT@=&AE('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)
M*"DI('L*("`@(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@
M;&EN95QN(BD["GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N;65N="`M(&UA
M:V4@<W5R92!T:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70*+R\@<V]M92!V
M87)I86)L97,L(&5T8RX*2&]R9&5?0TQ).CII;FET*"D["@HO+R!'970@86X@
M:6YS=&%N8V4@;V8@=&AE(&-R;VX@<V-H961U;&5R+@HD9&%E;6]N(#T@)DAO
M<F1E7U-C:&5D=6QE<CHZ<VEN9VQE=&]N*"=C<F]N)RD["@HO+R!.;W<@861D
M('-O;64@8W)O;B!J;V)S('1O(&1O+"!O<B!A9&0@<&%R<VEN9R!T;R!R96%D
M(&$@8V]N9FEG(&9I;&4N"B\O("1D865M;VXM/F%D9%1A<VLH)VQS)RP@)S`L
M-2PQ,"PQ-2PR,"PS,"PT,"`J("H@*B`J)RD["@HO+R!3=&%R="!T:&4@9&%E
M;6]N(&=O:6YG+@HD9&%E;6]N+3YR=6XH*3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M=&AE;65S7V-H96-K+G!H<```````````````````````````````````````
M````````````````````````````,#$P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,30U-C8`,3`U,34T,S$P-C0`,#(Q,C4Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",A+W5S<B]L;V-A;"]P<V$O
M861M:6XO8FEN+W!H<`H\/W!H<`HO*BH*("H@5&AI<R!S8W)I<'0@9&]E<R!S
M;VUE(&-H96-K:6YG(&]F('1H96UE<RP@=&\@;6%K92!S=7)E(&EM86=E<R!A
M<F4*("H@<WEN8VAR;VYI<V5D(&%C<F]S<R!T:&5M97,N"B`J"B`J("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]T:&5M97-?8VAE8VLN<&AP+'8@,2XS+C$P+C4@
M,C`P-B\P-"\Q."`Q-CHR-CHP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!4:&4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D
M92YO<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA<FMO($1J
M=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO*B!#
M3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S="X@*B\*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO*B!-86ME('-U<F4@;F\@;VYE
M(')U;G,@=&AI<R!F<F]M('1H92!W96(N("HO"FEF("@A2&]R9&5?0TQ).CIR
M=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M
M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO*B!'970@86YY(&]P=&EO;G,N
M("HO"B1S:6UP;&4@/2!F86QS93L*)&EG;F]R92`](&%R<F%Y*"D["FEF("AI
M<W-E="@D87)G=BDI('L*("`@("\J($=E="!R:60@;V8@=&AE(&9I<G-T(&%R
M9R!W:&EC:"!I<R!T:&4@<V-R:7!T(&YA;64N("HO"B`@("!A<G)A>5]S:&EF
M="@D87)G=BD["B`@("!W:&EL92`H)&%R9R`](&%R<F%Y7W-H:69T*"1A<F=V
M*2D@>PH@("`@("`@(&EF("@D87)G(#T]("<M+6AE;'`G*2!["B`@("`@("`@
M("`@('!R:6YT7W5S86=E*"D["B`@("`@("`@?2!E;'-E:68@*"1A<F<@/3T@
M)RUS)RD@>PH@("`@("`@("`@("`D<VEM<&QE(#T@=')U93L*("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1A<F<L("<M:2<I(#T]/2`P*2!["B`@("`@("`@
M("`@(&QI<W0H+"1I9VYO<F5;72D@/2!E>'!L;V1E*"<])RP@)&%R9RD["B`@
M("`@("`@("`@("\O)&EG;F]R95M=(#T@)&D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<')I;G1?=7-A9V4H(E5N<F5C;V=N:7-E9"!O<'1I;VX@
M)&%R9R(I.PH@("`@("`@('T*("`@('T*?0H*+RH@4V5T('5P($-,22X@*B\*
M)&-L:2`]("9N97<@2&]R9&5?0TQ)*"D["@HO*B!#:&5C:R!I9B!A="!L96%S
M="!T:&4@<F5G:7-T<GD@:7,@879A:6%B;&4N("HO"FEF("@A0&9I;&5?97AI
M<W1S*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP:'`G*2D@>PH@
M("`@)&-L:2T^=W)I=&5L;B@D8VQI+3YR960H)TYO($AO<F1E(')E9VES=')Y
M(&9I;&4N)RDI.PH@("`@97AI=#L*?0H*+R\D8VQI+3YW<FET96QN*"1C;&DM
M/F=R965N*"=296%D:6YG+BXN)RDI.PIR97%U:7)E7V]N8V4@2$]21$5?0D%3
M12`N("<O;&EB+V)A<V4N<&AP)SL*"B\J($=E="!T:&4@87!P<R!A;F0@<W1A
M<G0@9&]I;F<@8VAE8VMS+B`J+PHD87!P<R`]("1R96=I<W1R>2T^;&ES=$%P
M<',H87)R87DH)VAI9&1E;B<L("=N;W1O;VQB87(G+"`G86-T:79E)RP@)V%D
M;6EN)RDI.PH*+RH@1V5T(&$@;&ES="!O9B!T:&5M97,N("HO"B1T:&5M97,@
M/2!A<G)A>2@I.PHD=&AE;65S7V1I<B`]("1R96=I<W1R>2T^9V5T*"=T:&5M
M97-F<R<L("=H;W)D92<I.PII9B`H)&AA;F1L92`](&]P96YD:7(H)'1H96UE
M<U]D:7(I*2!["B`@("!W:&EL92`H)&9I;&4@/2!R96%D9&ER*"1H86YD;&4I
M*2!["B`@("`@("`@:68@*"1F:6QE(#T]("<N)R!\?"`D9FEL92`]/2`G+BXG
M('Q\("1F:6QE(#T]("=#5E,G('Q\"B`@("`@("`@("`@("1F:6QE(#T]("<N
M<W9N)R!\?`H@("`@("`@("`@("`A0&9I;&5?97AI<W1S*"(D=&AE;65S7V1I
M<B\D9FEL92]I;F9O+G!H<"(I('Q\"B`@("`@("`@("`@("%`9FEL95]E>&ES
M=',H(B1T:&5M97-?9&ER+R1F:6QE+V=R87!H:6-S(BDI('L*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("`O*B!$;VXG="!B;W1H
M97(@8VAE8VMI;F<@=6YL97-S('1H92!T:&5M92!E>'!L:6-I=&QY('-T871E
M<R!T:&%T"B`@("`@("`@("H@:6-O;G,@=VEL;"!B92!R97!L86-E9"!F;W(@
M=&AI<R!A<'!L:6-A=&EO;BX@*B\*("`@("`@("!I;F-L=61E("(D=&AE;65S
M7V1I<B\D9FEL92]I;F9O+G!H<"(["B`@("`@("`@:68@*"%I<W-E="@D=&AE
M;65?:6-O;G,I*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4W1O<F4@=&AE(&%P<',@86YD('1H96ER('1H96UE(&1I
M<F5C=&]R:65S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&5M95]I8V]N<R!A
M<R`D87!P*2!["B`@("`@("`@("`@("1A<'!?=&AE;65S7V1I<B`]("1R96=I
M<W1R>2T^9V5T*"=T:&5M97-F<R<L("1A<'`I.PH@("`@("`@("`@("`D=&AE
M;65S6R1A<'!=6R1F:6QE72`]("(D87!P7W1H96UE<U]D:7(O)&9I;&4O9W)A
M<&AI8W,B.PH@("`@("`@('T*"B`@("`@("`@+RH@56YS970@=&AI<RP@=&\@
M;6%K92!S=7)E(&ET(&ES(&-H96-K960@=&AE(&YE>'0@=&EM92!A<F]U;F0N
M("HO"B`@("`@("`@=6YS970H)'1H96UE7VEC;VYS*3L*("`@('T*?0H*9F]R
M96%C:"`H)&%P<',@87,@)&%P<"D@>PH@("`@+RH@4V5T('5P('-O;64@9&ER
M<RX@*B\*("`@("1T:&5M97-?9&ER(#T@)')E9VES=')Y+3YG970H)W1H96UE
M<V9S)RP@)&%P<"D["B`@("`D:&]R9&5?=&AE;65?9&ER(#T@)'1H96UE<U]D
M:7(@+B`G+VAO<F1E)SL*("`@("1H;W)D95]I8V]N7V1I<B`]("1H;W)D95]T
M:&5M95]D:7(@+B`G+V=R87!H:6-S)SL*"B`@("`O*B!386YI='D@8VAE8VL@
M9F]R('1H92!D:7)E8W1O<FEE<RX@*B\*("`@(&EF("@A0&9I;&5?97AI<W1S
M*"1H;W)D95]T:&5M95]D:7(I('Q\("%`9FEL95]E>&ES=',H)&AO<F1E7VEC
M;VY?9&ER*2D@>PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@("\J($=E
M="!A(&QI<W0@;V8@86QL(&AO<F1E(&EM86=E<R!R96-U<G-I=F5L>2X@*B\*
M("`@("1H;W)D95]I8V]N7VQI<W0@/2!A<G)A>2@I.PH@("`@<F5A9$1I<E)E
M8W5R<VEV96QY*"1H;W)D95]I8V]N7V1I<BP@)&AO<F1E7VEC;VY?9&ER+"`D
M:&]R9&5?:6-O;E]L:7-T*3L*"B`@("`O*B!,;V]P('1H<F]U9V@@=&AE;65S
M('1H870@<F5P;&%C92!I8V]N<R!A;F0@8VAE8VL@9F]R(&1I9F9E<F5N8V5S
M+B`J+PH@("`@9F]R96%C:"`H)'1H96UE<ULD87!P72!A<R`D=&AE;64@/3X@
M)'1H96UE7VEC;VY?9&ER*2!["B`@("`@("`@)'1H96UE7VEC;VY?;&ES="`]
M(&%R<F%Y*"D["B`@("`@("`@<F5A9$1I<E)E8W5R<VEV96QY*"1T:&5M95]I
M8V]N7V1I<BP@)'1H96UE7VEC;VY?9&ER+"`D=&AE;65?:6-O;E]L:7-T*3L*
M"B`@("`@("`@+RH@0VAE8VL@9F]R(&EC;VYS('1H870@87)E(&EN('1H92!(
M;W)D92!B87-E('1H96UE(&%N9"!N;W0@:6X@=&AE"B`@("`@("`@("H@8W5S
M=&]M('1H96UE+B`J+PH@("`@("`@("1D:69F(#T@87)R87E?9&EF9B@D:&]R
M9&5?:6-O;E]L:7-T+"`D=&AE;65?:6-O;E]L:7-T*3L*("`@("`@("`O*B!$
M;VXG="!B;W1H97(@<F5P;W)T:6YG(&%N>71H:6YG(&9O<B!T:&5M97,@=&AA
M="!H879E(&%L;"!T:&4@:&]R9&4*("`@("`@("`@*B!B87-E(&EC;VYS+B`J
M+PH@("`@("`@(&EF("AE;7!T>2@D9&EF9BDI('L*("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@?0H*("`@("`@("`D8VQI+3YW<FET96QN*"1C;&DM
M/G)E9"AS<')I;G1F*"=;)7-=("(E<R(@=&AE;64@;6ES<VEN9R!T:&5S92!I
M8V]N<SHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<G1O
M=7!P97(H)&%P<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H96UE*2DI.PH@("`@("`@(&9O<F5A8V@@*"1D:69F(&%S("1I8V]N*2![
M"B`@("`@("`@("`@("1C;&DM/G=R:71E;&XH)&EC;VXI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0VAE8VL@:68@;VYL>2!D;VEN9R!A($AO<F1E(&)A<V4@
M=&AE;64@=&\@8W5S=&]M('1H96UE(&-H96-K+B!3:VEP"B`@("`@("`@("H@
M=&AE(')E=F5R<V4@8VAE8VMI;F<@:68@=')U92X@*B\*("`@("`@("!I9B`H
M)'-I;7!L92D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@
M("`@("`@("\J($-H96-K(&9O<B!I8V]N<R!T:&%T(&%R92!I;B!T:&4@2&]R
M9&4@8F%S92!T:&5M92!A;F0@;F]T(&EN('1H90H@("`@("`@("`J(&-U<W1O
M;2!T:&5M92X@*B\*("`@("`@("`D9&EF9B`](&%R<F%Y7V1I9F8H)'1H96UE
M7VEC;VY?;&ES="P@)&AO<F1E7VEC;VY?;&ES="D["B`@("`@("`@+RH@1&]N
M)W0@8F]T:&5R(')E<&]R=&EN9R!A;GET:&EN9R!F;W(@=&AE;65S('1H870@
M9&]N)W0@:&%V92!A;GD@:6-O;G,*("`@("`@("`@*B!M;W)E('1H86X@=&AE
M(&)A<V4@=&AE;64N("HO"B`@("`@("`@:68@*&5M<'1Y*"1D:69F*2D@>PH@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@("1C;&DM
M/G=R:71E;&XH)&-L:2T^8FQU92AS<')I;G1F*"=;)7-=("(E<R(@=&AE;64@
M:&%S('1H97-E(&5X=')A(&EC;VYS.B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1R=&]U<'!E<B@D87!P*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AE;64I*2D["B`@("`@("`@9F]R96%C:"`H
M)&1I9F8@87,@)&EC;VXI('L*("`@("`@("`@("`@)&-L:2T^=W)I=&5L;B@D
M:6-O;BD["B`@("`@("`@?0H@("`@?0I]"@HD8VQI+3YW<FET96QN*"1C;&DM
M/F=R965N*"=$;VYE+B<I*3L*97AI=#L*"B\J*@H@*B!,;V]P<R!T:')O=6=H
M('1H92!D:7)E8W1O<GD@<F5C=7)S:79E;'D@86YD('-T;W)E<R!T:&4@9F]U
M;F0@9W)A<&AI8W,@:6YT;PH@*B!A;B!A<G)A>2X*("HO"F9U;F-T:6]N(')E
M861$:7)296-U<G-I=F5L>2@D<&%T:"P@)&)A<V5P871H+"`F)&QI<W0I"GL*
M("`@(&=L;V)A;"`D:6=N;W)E.PH*("`@(&EF("@D:&%N9&QE(#T@;W!E;F1I
M<B@D<&%T:"DI('L*("`@("`@("!W:&EL92`H)&9I;&4@/2!R96%D9&ER*"1H
M86YD;&4I*2!["B`@("`@("`@("`@(&EF("@D9FEL92`]/2`G+B<@?'P@)&9I
M;&4@/3T@)RXN)R!\?"`D9FEL92`]/2`G0U93)PH@("`@("`@("`@("`@("`@
M?'P@)&9I;&4@/3T@)RYS=FXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?9&ER*"(D<&%T
M:"\D9FEL92(I*2!["B`@("`@("`@("`@("`@("!R96%D1&ER4F5C=7)S:79E
M;'DH(B1P871H+R1F:6QE(BP@)&)A<V5P871H+"`D;&ES="D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:6=N;W)E
M(&%S("1P871T97)N*2!["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H)'!A='1E<FXL("1F:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L:7-T6UT@/2!S=6)S='(H
M)'!A=&@L('-T<FQE;B@D8F%S97!A=&@I*2`N("(O)&9I;&4B.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&-L;W-E9&ER*"1H86YD;&4I.PH@
M("`@?0H*?0H*9G5N8W1I;VX@<')I;G1?=7-A9V4H)&UE<W-A9V4@/2`G)RD@
M>PH*("`@(&EF("@A96UP='DH)&UE<W-A9V4I*2!["B`@("`@("`@<')I;G0@
M(G1H96UE<U]C:&5C:RYP:'`Z("1M97-S86=E7&Y<;B(["B`@("!]"@H@("`@
M<')I;G0@/#P\55-!1T4*57-A9V4Z('1H96UE<U]C:&5C:RYP:'`@6T]05$E/
M3ET*"E!O<W-I8FQE(&]P=&EO;G,Z"B`@+7,@("`@("`@("`@("!$;R!O;FQY
M(&$@<VEM<&QE(&-H96-K(&9O<B!A;GD@2&]R9&4@8F%S92!T:&5M92!G<F%P
M:&EC<R!T:&%T"B`@("`@("`@("`@("`@("!A<F4@;6ES<VEN9R!F<F]M('1H
M92!O=&AE<B!T:&5M97,L(&%N9"!N;R!C:&5C:R!O9B!T:&4*("`@("`@("`@
M("`@("`@(&]P<&]S:71E+@H@("UI/5!!5%1%4DX@("`@26YS97)T(&%N>2!V
M86QI9"!R96=E>"!P871T97)N('1O(&EG;F]R92!F:6QE<R!F<F]M(&)E:6YG
M"B`@("`@("`@("`@("`@("!C:&5C:V5D+B!9;W4@8V%N(&5N=&5R(&UU;'1I
M<&QE("UI(&]P=&EO;G,@=&\@:6YC;'5D92!M=6QT:7!L90H@("`@("`@("`@
M("`@("`@<&%T=&5R;G,N($9O<B!E>&%M<&QE.B`M:3TB+WAC9B0O('1O(&EG
M;F]R92!A;GD@;W)I9VEN86P*("`@("`@("`@("`@("`@($=)35`@9FEL97,N
M"@I54T%'13L*("`@(&5X:70["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+V-O=6YT7W-E<W-I;VYS+G!H<```````````````````
M`````````````````````````````````````````````#`Q,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,34R`#$P-3$U-#,Q,#8T`#`R,38W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C(2]U
M<W(O8FEN+W!H<`H\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+V-O=6YT7W-E<W-I;VYS+G!H<"QV(#$N-2XR+C,@,C`P-B\P-"\Q."`Q-CHR
M-#HU."!J86X@17AP("0*("H*("H@5&AI<R!S8W)I<'0@8V]U;G1S('1H92!N
M=6UB97(@;V8@86-T:79E(&%U=&AE;G1I8V%T960@=7-E<B!S97-S:6]N<RX*
M("H*("H@0V]M;6%N9"!L:6YE(&]P=&EO;G,Z"B`J("`@)RUL)R`@($QI<W0@
M=&AE('5S97)N86UE(&]F(&%C=&EV92!A=71H96YT:6-A=&5D('5S97)S"B`J
M("`@)RUL;"<@($QI<W0@=&AE('5S97)N86UE(&%N9"!L;V=I;B!T:6UE(&]F
M(&%C=&EV92!A=71H96YT:6-A=&5D('5S97)S"B`J+PH*+R\@3F\@875T:"X*
M0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["@HO+R!&:6YD('1H92!B
M87-E(&9I;&4@<&%T:"!O9B!(;W)D92X*0&1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K
M<R!A;F0@96YV:7)O;FUE;G0@<V5T=7`@9FER<W0N"G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+T-,22YP:'`G.PH*+R\@36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@
M9G)O;2!T:&4@=V5B+@II9B`H(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH
M*2D@>PH@("`@97AI="@B375S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L
M:6YE7&XB*3L*?0H*+R\@3&]A9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K
M92!S=7)E('1H97)E)W,@;F\@=&EM92!L:6UI="P@:6YI=`HO+R!S;VUE('9A
M<FEA8FQE<RP@971C+@I(;W)D95]#3$DZ.FEN:70H*3L*)&-L:2`]("9N97<@
M2&]R9&5?0TQ)*"D["@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*"B\J($UA:V4@<W5R92!T:&5R92=S(&YO(&-O;7!R97-S
M:6]N+B`J+PI`;V)?96YD7V-L96%N*"D["@HD='EP92`]("%E;7!T>2@D8V]N
M9ELG<V5S<VEO;FAA;F1L97(G75LG='EP92==*2`_"B`@("`D8V]N9ELG<V5S
M<VEO;FAA;F1L97(G75LG='EP92==(#H@)V)U:6QT:6XG.PH*:68@*"1T>7!E
M(#T]("=E>'1E<FYA;"<I('L*("`@($AO<F1E.CIF871A;"A014%2.CIR86ES
M945R<F]R*"=397-S:6]N(&-O=6YT:6YG(&ES(&YO="!S=7!P;W)T960@:6X@
M=&AE(%PG97AT97)N86Q<)R!397-S:6]N2&%N9&QE<B!A="!T:&ES('1I;64N
M)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I.PI](&5L<V4@>PH@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]397-S:6]N2&%N9&QE<BYP:'`G.PH@("`@
M)%]S97-S:6]N7VAA;F1L97(@/2`F4V5S<VEO;DAA;F1L97(Z.G-I;F=L971O
M;B@D8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG='EP92==*3L*("`@(&EF("AI
M<U]A*"1?<V5S<VEO;E]H86YD;&5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@B2&]R
M9&4@:7,@=6YA8FQE('1O(&QO860@<V5S<VEO;B!H86YD;&5R(&]F('1Y<&4@
M7"(E<UPB+B(L("1T>7!E*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I
M.PH@("`@?0H*("`@(&EF("@D87)G8R`\(#(@?'P@*"1A<F=V6S%=("$]("<M
M;"<@)B8@)&%R9W9;,5T@(3T@)RUL;"<I*2!["B`@("`@("`@)&-O=6YT(#T@
M)%]S97-S:6]N7VAA;F1L97(M/F-O=6YT075T:&5N=&EC871E9%5S97)S*"D[
M"B`@("`@("`@:68@*&ES7V$H)&-O=6YT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"@D8V]U;G0L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@)&-L:2T^=W)I=&5L
M;B@D8V]U;G0I.PH@("`@?2!E;'-E('L*("`@("`@("`D=7-E<G,@/2`D7W-E
M<W-I;VY?:&%N9&QE<BT^;&ES=$%U=&AE;G1I8V%T9615<V5R<R@D87)G=ELQ
M72`]/2`G+6QL)RD["B`@("`@("`@:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@D=7-E<G,L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@
M9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*2!["B`@("`@("`@("`@("1C;&DM
M/G=R:71E;&XH)'5S97(I.PH@("`@("`@('T*("`@('T*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+RYH=&%C8V5S<P``````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#$V`#$P-3$U-#,Q
M,#8T`#`Q-S8W,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!$96YY(&9R;VT@86QL"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V-R:7!T<R]H='1P7VQO9VEN7W)E9F5R+G!H<```````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3<Q-``Q,#4Q-30S,3`V-``P,C(Q-#4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]H='1P7VQO9VEN7W)E
M9F5R+G!H<"QV(#$N,RXQ,BXS(#(P,#8O,#$O,#$@,C$Z,CDZ,#D@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@IR97%U:7)E7V]N8V4@)RXN+VQI8B]B87-E+G!H<"<["@HD875T:"`]("9!
M=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*+R\@
M0VAE8VL@9F]R($A45%`@875T:"X*:68@*&5M<'1Y*"1?4T525D526R=02%!?
M05542%]54T52)UTI('Q\"B`@("!E;7!T>2@D7U-%4E9%4ELG4$A07T%55$A?
M4%<G72D@?'P*("`@("$D875T:"T^875T:&5N=&EC871E*"1?4T525D526R=0
M2%!?05542%]54T52)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G<&%S<W=O<F0G(#T^("1?4T525D526R=02%!?05542%]05R==*2DI('L*
M"B`@("!H96%D97(H)U=75RU!=71H96YT:6-A=&4Z($)A<VEC(')E86QM/2(G
M("X@)&%U=&@M/F=E=%!A<F%M*"=R96%L;2<I("X@)R(G*3L*("`@(&AE861E
M<B@G2%144"\Q+C`@-#`Q(%5N875T:&]R:7IE9"<I.PH@("`@97AI="@G1F]R
M8FED9&5N)RD["GT*"FEF("@D=7)L(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R
M;"<I*2!["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["GT@96QS
M92!["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=L;V=I;BYP:'`G*2D["GT*````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V-R:7!T<R]M:6=R871E7W5S97)?8V%T96=O<FEE<RYP
M:'`````````````````````````````````````````````````````P,3`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#4V-0`Q,#4Q-30S,3`V-``P
M,C,U,34`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R$O=7-R+VQO8V%L+W!S82]A9&UI;B]B:6XO<&AP("UQ"CP_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O;6EG<F%T95]U<V5R7V-A=&5G
M;W)I97,N<&AP+'8@,2XU+C$P+C$@,C`P-2\Q,"\Q."`Q,3HS-#HP,"!J86X@
M17AP("0*("H*("H@02!S8W)I<'0@=&\@=7!D871E('5S97)S('!R969E<F5N
M8V5S('1O(&-O;6)I;F4@=&AE:7(@8V%T96=O<FEE<PH@*B!A;F0@8V%T96=O
M<GD@8V]L;W)S(&9R;VT@1V5N:64L($MR;VYO;&ET:"P@36YE;6\L(&%N9"!.
M86<@:6YT;R!T:&4*("H@;F5W($AO<F1E+7=I9&4@<')E9F5R96YC97,N($5X
M<&5C=',@=&\@8F4@9VEV96X@82!L:7-T(&]F('5S97)S(&]N"B`J(%-41$E.
M+"!O;F4@=7-E<FYA;64@<&5R(&QI;F4L('1O(&-O;G9E<G0N(%5S97)N86UE
M<R!N965D('1O(&UA=&-H"B`J('1H92!V86QU97,@<W1O<F5D(&EN('1H92!P
M<F5F97)E;F-E<R!B86-K96YD+@H@*B\*"B\O($9I;F0@=&AE(&)A<V4@9FEL
M92!P871H(&]F($AO<F1E+@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E
M*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K<R!A;F0@96YV:7)O;FUE;G0@<V5T
M=7`@9FER<W0N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R
M92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*+R\@36%K
M92!S=7)E(&YO(&]N92!R=6YS('1H:7,@9G)O;2!T:&4@=V5B+@II9B`H(4AO
M<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*2D@>PH@("`@97AI="@B375S="!B
M92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE7&XB*3L*?0H*+R\@3&]A9"!T
M:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K92!S=7)E('1H97)E)W,@;F\@=&EM
M92!L:6UI="P@:6YI=`HO+R!S;VUE('9A<FEA8FQE<RP@971C+@I(;W)D95]#
M3$DZ.FEN:70H*3L*"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O
M8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`G.PHD8VQI(#T@)DAO<F1E7T-,23HZ<VEN9VQE=&]N*"D[
M"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV
M97(G72D["B1C36%N86=E<B`]("9N97<@4')E9G-?0V%T96=O<GE-86YA9V5R
M*"D["B1A<'!S(#T@)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G:&ED9&5N
M)RP@)VYO=&]O;&)A<B<L("=A8W1I=F4G+"`G861M:6XG*2D["@HO+R!296%D
M(&EN('1H92!L:7-T(&]F('5S97)N86UE<R!O;B!35$1)3BX*)'5S97)S(#T@
M87)R87DH*3L*=VAI;&4@*"%F96]F*%-41$E.*2D@>PH@("`@)&QI;F4@/2!F
M9V5T<RA35$1)3BD["B`@("`D;&EN92`]('1R:6TH)&QI;F4I.PH@("`@:68@
M*"%E;7!T>2@D;&EN92DI('L*("`@("`@("`D=7-E<G-;72`]("1L:6YE.PH@
M("`@?0I]"@HO+R!,;V]P('1H<F]U9V@@=7-E<G,@86YD(&-O;G9E<G0@<')E
M9G,@9F]R($=E;FEE+"!-;F5M;RP@3F%G+"!A;F0*+R\@2W)O;F]L:71H+@IF
M;W)E86-H("@D=7-E<G,@87,@)'5S97(I('L*("`@(&5C:&\@)TUI9W)A=&EN
M9R!P<F5F<R!F;W(@)R`N("1C;&DM/F)O;&0H)'5S97(I.PH*("`@("\O(%-E
M="`D=7-E<B!A<R!T:&4@8W5R<F5N="!U<V5R+@H@("`@)&%U=&@M/G-E=$%U
M=&@H)'5S97(L(&%R<F%Y*"DL("<G*3L*"B`@("`O+R!&971C:"!C=7)R96YT
M(&-A=&5G;W)I97,@86YD(&-O;&]R<RX*("`@("1C;VQO<G,@/2`D8TUA;F%G
M97(M/F-O;&]R<R@I.PH*("`@("\O($=E;FEE+@H@("`@:68@*&EN7V%R<F%Y
M*"=G96YI92<L("1A<'!S*2D@>PH@("`@("`@(&5C:&\@)R`N(&=E;FEE)SL*
M("`@("`@("`D<F5S=6QT(#T@)')E9VES=')Y+3YP=7-H07!P*"=G96YI92<L
M(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D9U]C871E9V]R:65S(#T@;&ES=$-A=&5G
M;W)I97,H)W=I<VA?8V%T96=O<FEE<R<I.PH@("`@("`@("`@("!F;W)E86-H
M("@D9U]C871E9V]R:65S(&%S("1C871E9V]R>2D@>PH@("`@("`@("`@("`@
M("`@)&--86YA9V5R+3YA9&0H)&-A=&5G;W)Y*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O+R!-;F5M;RX*("`@(&EF("AI;E]A<G)A
M>2@G;6YE;6\G+"`D87!P<RDI('L*("`@("`@("!E8VAO("<@+B!M;F5M;R<[
M"B`@("`@("`@)')E<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@G;6YE;6\G
M+"!F86QS92D["B`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@)&U?8V%T96=O<FEE<R`](&QI<W1#871E
M9V]R:65S*"=M96UO7V-A=&5G;W)I97,G*3L*("`@("`@("`@("`@)&U?8V]L
M;W)S(#T@;&ES=$-O;&]R<R@G;65M;U]C;VQO<G,G*3L*("`@("`@("`@("`@
M9F]R96%C:"`H)&U?8V%T96=O<FEE<R!A<R`D:V5Y(#T^("1C871E9V]R>2D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M7V-O;&]R<ULD:V5Y72DI
M('L*("`@("`@("`@("`@("`@("`@("`D8V]L;W)S6R1C871E9V]R>5T@/2`D
M;5]C;VQO<G-;)&ME>5T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D8TUA;F%G97(M/F%D9"@D8V%T96=O<GDI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\O($YA9RX*("`@(&EF("AI;E]A<G)A
M>2@G;F%G)RP@)&%P<',I*2!["B`@("`@("`@96-H;R`G("X@;F%G)SL*("`@
M("`@("`D<F5S=6QT(#T@)')E9VES=')Y+3YP=7-H07!P*"=N86<G+"!F86QS
M92D["B`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)&Y?8V%T96=O<FEE<R`](&QI<W1#871E9V]R:65S
M*"=T87-K7V-A=&5G;W)I97,G*3L*("`@("`@("`@("`@9F]R96%C:"`H)&Y?
M8V%T96=O<FEE<R!A<R`D8V%T96=O<GDI('L*("`@("`@("`@("`@("`@("1C
M36%N86=E<BT^861D*"1C871E9V]R>2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@2W)O;F]L:71H+@H@("`@:68@*&EN7V%R<F%Y
M*"=K<F]N;VQI=&@G+"`D87!P<RDI('L*("`@("`@("!E8VAO("<@+B!K<F]N
M;VQI=&@G.PH@("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H
M)VMR;VYO;&ET:"<L(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D:U]C871E9V]R:65S
M(#T@;&ES=$-A=&5G;W)I97,H)V5V96YT7V-A=&5G;W)I97,G*3L*("`@("`@
M("`@("`@:68@*&-O=6YT*"1K7V-A=&5G;W)I97,I*2!V87)?9'5M<"@D:U]C
M871E9V]R:65S*3L*("`@("`@("`@("`@)&M?8V]L;W)S(#T@;&ES=$-O;&]R
M<R@G979E;G1?8V]L;W)S)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1K7V-A
M=&5G;W)I97,@87,@)&ME>2`]/B`D8V%T96=O<GDI('L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D:U]C;VQO<G-;)&ME>5TI*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-O;&]R<ULD8V%T96=O<GE=(#T@)&M?8V]L;W)S6R1K97E=
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&--86YA9V5R
M+3YA9&0H)&-A=&5G;W)Y*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`D8TUA;F%G97(M/G-E=$-O;&]R<R@D8V]L;W)S*3L*("`@("1P
M<F5F<RT^<W1O<F4H*3L*("`@("1C;&DM/G=R:71E;&XH*3L*?0H*)&-L:2T^
M=W)I=&5L;B@I.PHD8VQI+3YW<FET96QN*"1C;&DM/F=R965N*"=$3TY%)RDI
M.PIE>&ET.PH*9G5N8W1I;VX@;&ES=$-A=&5G;W)I97,H)'!R969N86UE*0I[
M"B`@("!G;&]B86P@)'!R969S.PH*("`@("1S=')I;F<@/2`D<')E9G,M/F=E
M=%9A;'5E*"1P<F5F;F%M92D["B`@("!I9B`H96UP='DH)'-T<FEN9RDI('L*
M("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*"B`@("`D8V%T<R`](&5X
M<&QO9&4H)WPG+"`D<W1R:6YG*3L*("`@(&9O<F5A8V@@*"1C871S(&%S("1C
M870I('L*("`@("`@("!L:7-T*"1K97DL("1V86PI(#T@97AP;&]D92@G.B<L
M("1C870I.PH@("`@("`@("1C871E9V]R:65S6R1K97E=(#T@)'9A;#L*("`@
M('T*"B`@("!R971U<FX@)&-A=&5G;W)I97,["GT*"F9U;F-T:6]N(&QI<W1#
M;VQO<G,H)'!R969N86UE*0I["B`@("!G;&]B86P@)'!R969S.PH*("`@("1S
M=')I;F<@/2`D<')E9G,M/F=E=%9A;'5E*"1P<F5F;F%M92D["B`@("!I9B`H
M96UP='DH)'-T<FEN9RDI('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@
M('T*("`@("1C;VQS(#T@97AP;&]D92@G?"<L("1S=')I;F<I.PH@("`@)&-O
M;&]R<R`](&%R<F%Y*"D["B`@("!F;W)E86-H("@D8V]L<R!A<R`D8V]L*2![
M"B`@("`@("`@;&ES="@D:V5Y+"`D=F%L*2`](&5X<&QO9&4H)SHG+"`D8V]L
M*3L*("`@("`@("`D8V]L;W)S6R1K97E=(#T@)'9A;#L*("`@('T*"B`@("!R
M971U<FX@)&-O;&]R<SL*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S8W)I<'1S+W)E;6]V95]P<F5F<RYP:'``````````````````````````
M`````````````````````````````````````````#`Q,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`T-C(R`#$P-3$U-#,Q,#8T`#`R,3,Q,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C(2]U<W(O
M;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`*/#]P:'`*+RHJ"B`J("1(;W)D93H@
M:&]R9&4O<V-R:7!T<R]R96UO=F5?<')E9G,N<&AP+'8@,2XS+C$P+C<@,C`P
M-B\P-"\Q."`Q-CHR-3HS,2!J86X@17AP("0*("H*("H@5&AI<R!S8W)I<'0@
M<F5M;W9E<R!A('!R968@9G)O;2!U<V5R<R<@<V5T=&EN9W,N($AE;'!S('=H
M96X@82!S971T:6YG(&ES"B`J('1O(&)E(&UO=F5D(&9R;VT@;&]C:V5D(#T@
M9F%L<V4L('1O(&QO8VME9"`]('1R=64@86YD('1H97)E(&AA=F4@86QR96%D
M>0H@*B!B965N('!R969S('-E="!B>2!T:&4@=7-E<G,N"B`J+PH*+RHJ"B`J
M*B!3970@=&AI<R!T;R!T<G5E(&EF('EO=2!W86YT($1"(&UO9&EF:6-A=&EO
M;G,@9&]N92X*("HJ+PHD;&EV92`](&9A;'-E.PH*+R\@3F\@875T:"X*0&1E
M9FEN92@G05542%](04Y$3$52)RP@=')U92D["@HO+R!&:6YD('1H92!B87-E
M(&9I;&4@<&%T:"!O9B!(;W)D92X*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K<R!A
M;F0@96YV:7)O;FUE;G0@<V5T=7`@9FER<W0N"G)E<75I<F5?;VYC92!(3U)$
M15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+T-,22YP:'`G.PH*+R\@36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@9G)O
M;2!T:&4@=V5B+@II9B`H(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*2D@
M>PH@("`@97AI="@B375S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE
M7&XB*3L*?0H*+R\@3&]A9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K92!S
M=7)E('1H97)E)W,@;F\@=&EM92!L:6UI="P@:6YI=`HO+R!S;VUE('9A<FEA
M8FQE<RP@971C+@I(;W)D95]#3$DZ.FEN:70H*3L*)&-L:2`]("9N97<@2&]R
M9&5?0TQ)*"D["@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]$871A5')E92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O4VAA<F4N<&AP)SL*"B\J($UA:V4@<W5R92!T:&5R92=S(&YO(&-O
M;7!R97-S:6]N+B`J+PIO8E]E;F1?8VQE86XH*3L*"@HD<V-O<&4@/2`D8VQI
M+3YP<F]M<'0H7R@B16YT97(@=F%L=64@9F]R('!R969?<V-O<&4Z(BDI.PHD
M;F%M92`]("1C;&DM/G!R;VUP="A?*")%;G1E<B!V86QU92!F;W(@<')E9E]N
M86UE.B(I*3L*"B\J($]P96X@=&AE(&1A=&%B87-E+B`J+PHD9&(@/2`F1$(Z
M.F-O;FYE8W0H)&-O;F9;)W-Q;"==*3L*:68@*&ES7V$H)&1B+"`G4$5!4E]%
M<G)O<B<I*2!["B`@('9A<E]D=6UP*"1D8BD[(&5X:70["GT*"B\O(%-E="!$
M0B!P;W)T86)I;&ET>2!O<'1I;VYS+@IS=VET8V@@*"1D8BT^<&AP='EP92D@
M>PIC87-E("=M<W-Q;"<Z"B`@("`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI
M='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E4
M65]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("!B<F5A:SL*
M9&5F875L=#H*("`@("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"
M7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]2
M4RD["GT*"FEF("@D;&EV92D@>PH@("`@)'-Q;"`]("=$14Q%5$4@1E)/32!H
M;W)D95]P<F5F<R!72$5212!P<F5F7W-C;W!E(#T@/R!!3D0@<')E9E]N86UE
M(#T@/R<["B`@("`D=F%L=65S(#T@87)R87DH)'-C;W!E+"`D;F%M92D["B`@
M("`D<F5S=6QT(#T@)&1B+3YG971!;&PH)'-Q;"P@)'9A;'5E<RD["B`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@=F%R
M7V1U;7`H)')E<W5L="D["B`@("!](&5L<V5I9B`H96UP='DH)')E<W5L="DI
M('L*("`@("`@("`D8VQI+3YW<FET96QN*'-P<FEN=&8H7R@B3F\@<')E9F5R
M96YC92!<(B5S7"(@9F]U;F0@:6X@<V-O<&4@7"(E<UPB+B(I+"`D;F%M92P@
M)'-C;W!E*2D["B`@("!](&5L<V4@>PH@("`@("`@("1C;&DM/G=R:71E;&XH
M<W!R:6YT9BA?*")0<F5F97)E;F-E<R!<(B5S7"(@9&5L971E9"!I;B!S8V]P
M92!<(B5S7"(N(BDL("1N86UE+"`D<V-O<&4I*3L*("`@('T*?2!E;'-E('L*
M("`@("1S<6P@/2`G4T5,14-4("H@1E)/32!H;W)D95]P<F5F<R!72$5212!P
M<F5F7W-C;W!E(#T@/R!!3D0@<')E9E]N86UE(#T@/R<["B`@("`D=F%L=65S
M(#T@87)R87DH)'-C;W!E+"`D;F%M92D["B`@("`D<F5S=6QT(#T@)&1B+3YG
M971!;&PH)'-Q;"P@)'9A;'5E<RD["B`@("!I9B`H96UP='DH)')E<W5L="DI
M('L*("`@("`@("`D8VQI+3YW<FET96QN*'-P<FEN=&8H7R@B3F\@<')E9F5R
M96YC92!<(B5S7"(@9F]U;F0@:6X@<V-O<&4@7"(E<UPB+B(I+"`D;F%M92P@
M)'-C;W!E*2D["B`@("!](&5L<V4@>PH@("`@("`@('9A<E]D=6UP*"1R97-U
M;'0I.PH@("`@?0I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S8W)I<'1S+W-E='5P+G!H<```````````````````
M`````````````````````````````````````````````````````````#`Q
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-30T`#$P-3$U-#,Q,#8T
M`#`Q-S<V,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C(2]U<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`*/#]P:'`*+RHJ
M"B`J(%1H92!M86EN($AO<F1E('-E='5P('-C<FEP="!W:&EC:"!A;&QO=W,@
M9F]R(&$@<W1E<"!B>2!S=&5P('-E='5P"B`J(&]R(')E8V]N9FEG=7)A=&EO
M;B!O9B!A($AO<F1E(&EN<W1A;&QA=&EO;BX*("H*("H@)$AO<F1E.B!H;W)D
M92]S8W)I<'1S+W-E='5P+G!H<"QV(#$N,C4N,3`N,3`@,C`P-B\P-2\Q."`Q
M-3HT-SHS,B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@
M/&UA<FMO0&]B;&\N8V]M/@H@*B!`875T:&]R("!#:&%R;&5S($HN($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G
M2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]#3$DN<&AP)SL*"B1C;&D@/2!N97<@2&]R9&5?0TQ)
M*"D["@HO*B!#:&5C:R!F;W(@8V]N9FEG(&9I;&5S+B`J+PHD9FEL97,@/2!A
M<G)A>2@G8V]N9BYP:'`G+`H@("`@("`@("`@("`@("`G;6EM95]D<FEV97)S
M+G!H<"<L"B`@("`@("`@("`@("`@("=N;',N<&AP)RP*("`@("`@("`@("`@
M("`@)W!R969S+G!H<"<L"B`@("`@("`@("`@("`@("=R96=I<W1R>2YP:'`G
M*3L*9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE;F%M92D@>PH@("`@)&9I;&4@
M/2!(3U)$15]"05-%("X@)R]C;VYF:6<O)R`N("1F:6QE;F%M93L*("`@(&EF
M("AF:6QE7V5X:7-T<R@D9FEL92DI('L*("`@("`@("!C;&E?;&]G*'-P<FEN
M=&8H7R@B1FEL92!<(B5S7"(@:7,@879A:6QA8FQE+B(I+"`D9FEL96YA;64I
M+"`G;65S<V%G92<I.PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@(&-L
M:5]L;V<H<W!R:6YT9BA?*")&:6QE(%PB)7-<(B!I<R!M:7-S:6YG+B(I+"`D
M9FEL96YA;64I+"`G=V%R;FEN9R<I.PH*("`@("1D:7-T9FEL92`]("1F:6QE
M("X@)RYD:7-T)SL*("`@(&EF("AF:6QE7V5X:7-T<R@D9&ES=&9I;&4I*2![
M"B`@("`@("`@)&-R96%T95]C;VYF:6<@/2`D8VQI+3YP<F]M<'0H<W!R:6YT
M9BA?*")#<F5A=&4@7"(E<UPB(&9R;VT@9&5F875L=',@;F]W/R(I+"`D9FEL
M96YA;64I+"!A<G)A>2@G>2<@/3X@7R@B665S(BDL("=N)R`]/B!?*").;R(I
M*2D["B`@("`@("`@:68@*"1C<F5A=&5?8V]N9FEG(#T]("=Y)RD@>PH@("`@
M("`@("`@("!I9B`H(6-O<'DH)&1I<W1F:6QE+"`D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C;&DM/F9A=&%L*'-P<FEN=&8H7R@B0V]P>6EN9R!<(B4Q
M)',N9&ES=%PB('1O(%PB)3$D<UPB(&9A:6QE9"X@0VAE8VL@>6]U<B!I;G-T
M86QL871I;VXN(BDL("1F:6QE;F%M92DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&-L:5]L;V<H<W!R:6YT9BA?*")&:6QE("5S(&-R96%T960N(BDL
M("1F:6QE;F%M92DL("=S=6-C97-S)RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&-L:2T^9F%T86PH<W!R:6YT9BA?*")9;W4@;F5E9"!T:&4@
M7"(E<UPB(&9I;&4@=&\@8V]N=&EN=64@<V5T=7`@86YD('1O('5S92!(;W)D
M92XB*2P@)&9I;&5N86UE*2D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@
M("`@("`D8VQI+3YF871A;"AS<')I;G1F*%\H(D-A;FYO="!F:6YD(%PB)7-<
M(BP@8VAE8VL@>6]U<B!I;G-T86QL871I;VXN(BDL("1D:7-T9FEL92DI.PH@
M("`@?0I]"@IC;&E?;&]G*%\H(DEN:71I86P@<V5T=7`@8V]M<&QE=&5D+B!.
M;W<@8V]N=&EN=64@=&AE('-E='5P('=I=&@@>6]U<B!B<F]W<V5R+"!G;R!T
M;SH@:'1T<#HO+SQ9;W5R($AO<F1E(&EN<W1A;&P@55),/B]A9&UI;B\B*2P@
M)W-U8V-E<W,G*3L*97AI=#L*"B\J*@H@*B!7<F%P('1H92!M97-S86=E<R!W
M:71H(&%N(&EN9&5N="P@;F5A=&5R('-C<F5E;B!D:7-P;&%Y+@H@*B\*9G5N
M8W1I;VX@8VQI7VQO9R@D;65S<V%G92P@)'1Y<&4@/2`G;65S<V%G92<I"GL*
M("`@("1M97-S86=E(#T@=V]R9'=R87`H)&UE<W-A9V4L(#8Y+"`B7&X@("`@
M("`@("`@("(I.PH@("`@)$=,3T)!3%-;)V-L:2==+3YM97-S86=E*"1M97-S
M86=E+"`G8VQI+B<@+B`D='EP92D["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W1E;7`M8VQE86YU
M<"YC<F]N````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#`S
M`#$P-3$U-#,Q,#8T`#`R,3,U,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C(2]B:6XO<V@*"B,@5&AI<R!I<R!A;B!E>&%M
M<&QE(&-R;VX@:F]B('-H96QL('-C<FEP="!W:&EC:"!W:6QL(&-L96%N('5P
M(&%N>0HC('1E;7!O<F%R>2!F:6QE<R!W:&EC:"!M87D@9V5T('-T<F%N9&5D
M(&)Y($AO<F1E('5S97)S(&EN('1H90HC('=E8G-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN"B,*(R!9;W4@;6%Y(&AA=F4@=&\@8VAA;F=E("]T;7`@
M=&\@86YO=&AE<B!L;V-A=&EO;B!D97!E;F1I;F<@;VX@>6]U<@HC(&-O;F9I
M9W5R871I;VXN("!/=&AE<B!M;V1I9FEC871I;VYS(&UA>2!A;'-O(&)E(')E
M<75I<F5D+@HC"B,@5&AI<R!S8W)I<'0@:7,@<')O=FED960@87,M:7,@86YD
M(&ES('1O(&)E('5S960@870@>6]U<B!O=VX@<FES:RX@"B,@2&]R9&4@86YD
M('1H92!A=71H;W)S(&%C8V5P="!N;R!R97-P;VYS:6)I;&ET>2!F;W(@86YY
M(&1A;6%G97,@;W(*(R!L;W-E<R!C875S960@8GD@=&AI<R!S8W)I<'0@=VAE
M=&AE<B!I;F1I<F5C="P@:6YC:61E;G1A;"P@;W(*(R!C;VYS97%U96YT:6%L
M+"`@=VAE=&AE<B!O<B!N;W0@<W5C:"!D86UA9V5S(&-O=6QD(&)E(&9O<G-E
M96XN"B,*(R!(;W<@=&\@=7-E('1H:7,@<V-R:7!T('=I;&P@9&5P96YD(&]N
M('EO=7(@<WES=&5M+B`@1F]R('-O;64@<WES=&5M<RP*(R!I="!I<R!A<R!S
M:6UP;'D@87,@<'5T=&EN9R!T:&ES(&9I;&4@:6X@=&AE("]E=&,O8W)O;BYD
M86EL>2!D:7)E8W1O<GDN"B,@1F]R(&]T:&5R<RP@;6]R92!O<B!D:69F97)E
M;G0@<V5T=7`@=VEL;"!B92!R97%U:7)E9"X@(%-E92!T:&4*(R!D;V-U;65N
M=&%T:6]N(&9O<B!Y;W5R('-Y<W1E;7,@:F]B('-C:&5D=6QE<B!F;W(@;6]R
M92!I;F9O<FUA=&EO;BX*(PH*(R!4:&4@;&]C871I;VX@;V8@4$A0)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>0I435!?1$E2/2]T;7`*"@HC($U35V]R9"!A='1A
M8VAM96YT<R`H9V5N97)A=&5D(&)Y('1H92!-4W=O<F0@=FEE=V5R*0IF;W(@
M35-73U)$7T9)3$4@:6X@8&9I;F0@)%1-4%]$25(@+71Y<&4@9B`M;F%M92!M
M<W=O<F1<*B`M8W1I;64@*S(@8#L@9&\*"7)M("UF("1-4U=/4D1?1DE,10ID
M;VYE"@HC($E-4"!A='1A8VAM96YT<PIF;W(@24U07T9)3$4@:6X@8&9I;F0@
M)%1-4%]$25(@+71Y<&4@9B`M;F%M92!I;7!A='1<*B`M8W1I;64@*S(@8#L@
M9&\*"7)M("UF("1)35!?1DE,10ID;VYE"@HC($ML=71Z('1E;7!O<F%R>2!F
M:6QE<PIF;W(@2TQ55%I?1DE,12!I;B!@9FEN9"`D5$U07T1)4B`M='EP92!F
M("UN86UE($ML=71Z7"H@+6-T:6UE("LR(&`[(&1O"@ER;2`M9B`D2TQ55%I?
M1DE,10ID;VYE"@HC(%-P96QL(&-H96-K:6YG('1E;7!O<F%R>2!F:6QE<PIF
M;W(@4U!%3$Q?1DE,12!I;B!@9FEN9"`D5$U07T1)4B`M='EP92!F("UN86UE
M('-P96QL7"H@+6-T:6UE("LR(&`[(&1O"@ER;2`M9B`D4U!%3$Q?1DE,10ID
M;VYE"@HC(%9&4R!T96UP;W)A<GD@9FEL97,*9F]R($E-4%]&24Q%(&EN(&!F
M:6YD("1435!?1$E2("UT>7!E(&8@+6YA;64@=F9S7"H@+6-T:6UE("LR(&`[
M(&1O"@ER;2`M9B`D24U07T9)3$4*9&]N90H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S971?<&5R;7,N<V@`````
M````````````````````````````````````````````````````````````
M```````P,3`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8P,0`Q,#4Q
M-30S,3`V-``P,C`T,S<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R$O8FEN+W-H"B,*(R!S971?<&5R;7,N<V@@+2!*;VX@
M4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^"B,*(R`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<V5T7W!E<FUS+G-H+'8@,2XW(#(P,#$O,#0O,34@,#$Z-34Z,S(@
M8VAU8VL@17AP("0*"B,@(D1A;F=E<F]U<R(@4$A0('-C<FEP=',*(PI$04Y'
M15)/55-?1DE,15,](G1E<W0N<&AP(@H*(R!$969A=6QT(&YO;BUW96(@<V5R
M=F5R('5S97(@=VAO('=I;&P@;W=N('1H92!T<F5E+@HC"D]73D52/7)O;W0*
M"B,@26YT<F]D=6-T;W)Y('1E>'0*(PIC870@/#P@14]&"@I4:&ES('-C<FEP
M="!W:6QL('-E="!T:&4@<&5R;6ES<VEO;G,@;VX@>6]U<B!(;W)D90IT<F5E
M('-O('1H870@=&AE(&9I;&5S('=I;&P@8F4@86-C97-S:6)L92!B>2!T:&4@
M=V5B"G-E<G9E<BX*"EEO=2!C86X@8V%N8V5L('1H:7,@<V-R:7!T(&%T(&%N
M>2!T:6UE('5S:6YG($-T<FPM0RX*"D5/1@H*(R!697)I9GD@=&AA="!W92=R
M92!A="!T:&4@=&]P(&]F('1H92!(;W)D92!T<F5E+@HC"G!W9`IE8VAO"F5C
M:&\@+6X@(DES('1H:7,@9&ER96-T;W)Y('1H92!T;W`@;V8@>6]U<B!(;W)D
M92!I;G-T86QL871I;VX_(%MY+$Y=("(*<F5A9"!215-03TY312`*:68@6R`B
M)%)%4U!/3E-%(B`A/2`B>2(@+6$@(B1215-03TY312(@(3T@(EDB(%T[('1H
M96X*("`@(&5C:&\*("`@(&5C:&\@+6X@(D5N=&5R('EO=7(@2&]R9&4@9&ER
M96-T;W)Y.B`B"B`@("!R96%D($1)4B`@"@EI9B!;(")X)$1)4B(@/2`B>"(@
M73L@=&AE;@H)"65C:&\@(D5X:71I;F<N+BXB"@D)97AI=`H)96QS90H@("`@
M"6-D("1$25(*"69I"F9I"F5C:&\*"B,@1V5T('1H92!W96(@<V5R=F5R)W,@
M9W)O=7`N"B,*96-H;R`M;B`B56YD97(@=VAA="!G<F]U<"!D;V5S('1H92!W
M96(@<')O8V5S<R!R=6X_(%MN;V)O9'E=("(*<F5A9"!714)?1U)/55`*:68@
M6R`B>"1714)?1U)/55`B(#T@(G@B(%T[('1H96X*("`@(%=%0E]'4D]54#TB
M;F]B;V1Y(B`*9FD*"B,@07-K(&)E9F]R92!P<F]C965D:6YG+@HC"F5C:&\*
M96-H;R`M;B`B4')O8V5E9"!W:71H(&-H86YG:6YG(&]W;F5R<VAI<"!A;F0@
M<&5R;6ES<VEO;G,_(%MY+$Y=("(*<F5A9"!215-03TY312`*:68@6R`B)%)%
M4U!/3E-%(B`A/2`G>2<@+6$@(B1215-03TY312(@(3T@)UDG(%T[('1H96X*
M("`@(&5C:&\@(D5X:71I;F<N+BXB"B`@("!E>&ET"F9I"@HC(%-E="!T:&4@
M=7-E<B!A;F0@9W)O=7`@;W=N97)S:&EP(')E8W5R<VEV96QY+@HC"F5C:&\*
M96-H;R`M;B`B4V5T=&EN9R!O=VYE<G-H:7`@<F5C=7)S:79E;'DN+BX@(@IC
M:&]W;B`M4B`D3U=.15(@+@IC:&=R<"`M4B`D5T5"7T=23U50("X*96-H;R`B
M9&]N92XB"@HC(%-E="!T:&4@<&5R;6ES<VEO;G,@;VX@9FEL97,@*#`V-#`I
M(&%N9"!D:7)E8W1O<FEE<R`H,#<U,"DN"B,*96-H;R`M;B`B4V5T=&EN9R!P
M97)M:7-S:6]N<R!R96-U<G-I=F5L>2XN+B`B"F9I;F0@+B`M='EP92!F("UE
M>&5C(&-H;6]D(#`V-#`@>WT@7#L*9FEN9"`N("UT>7!E(&0@+65X96,@8VAM
M;V0@,#<U,"![?2!<.PIE8VAO(")D;VYE+B(*"B,@1&ES86)L92!A;GD@(F1A
M;F=E<F]U<R(@4$A0('-C<FEP=',@:6X@=&AE(&1I<W1R:6)U=&EO;B`H,#`P
M,"DN"B,*96-H;R`M;B`B1&ES86)L:6YG('!O=&5N=&EA;&QY(%PB9&%N9V5R
M;W5S7"(@4$A0('-C<FEP=',N+BX@(@IF;W(@1DE,12!I;B`D1$%.1T523U53
M7T9)3$53.R!D;PH):68@6R`M9B`D1DE,12!=.R!T:&5N"@D)8VAM;V0@,#`P
M,"`D1DE,10H)9FD*9&]N90IE8VAO(")D;VYE+B(*"B,@4V%Y(&=O;V0M8GEE
M+@HC"F5C:&\*96-H;R`B268@>6]U(')E8V5I=F5D(&%N>2!E<G)O<G,L('EO
M=2!M87D@;F]T(&AA=F4@<W5F9FEC:65N="!A8V-E<W,B"F5C:&\@(G1O(&-H
M86YG92!F:6QE(&]W;F5R<VAI<"!A;F0@<&5R;6ES<VEO;G,N(@IE8VAO"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O8W)E871E+7-Y;6QI;FMS+G!H<```
M````````````````````````````````````````````````````````````
M,#$P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<S-C(`,3`U,34T,S$P
M-C0`,#(Q-S,V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<`H\/W!H<`HO
M*BH*("H@5&AI<R!S8W)I<'0@8W)E871E<R!S;V9T;&EN:W,@=&\@=&AE(&QI
M8G)A<GD@9FEL97,@>6]U(')E=')I979E9"!F<F]M"B`J('1H92!#5E,@(F9R
M86UE=V]R:R(@;6]D=6QE+@H@*@H@*B!)="!C<F5A=&5S('1H92!S86UE(&1I
M<F5C=&]R>2!S=')U8W1U<F4@=&AE('!A8VMA9V5S('=O=6QD(&AA=F4@:68@
M=&AE>0H@*B!W97)E(&EN<W1A;&QE9"!W:71H(")P96%R(&EN<W1A;&P@<&%C
M:V%G92YX;6PB+@H@*B!&;W(@8W)E871I;F<@=&AI<R!S=')U8W1U<F4@:70@
M=7-E<R!T:&4@:6YF;W)M871I;VX@9VEV96X@:6X@=&AE"B`J('!A8VMA9V4N
M>&UL(&9I;&5S(&EN<VED92!E86-H('!A8VMA9V4@9&ER96-T;W)Y+@H@*@H@
M*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O8W)E871E+7-Y;6QI;FMS+G!H<"QV
M(#$N,30N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`Y(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,B!7;VQF<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR
M:65S:6YG+F1E/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`J($!A
M=71H;W(@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M($AO<F1E(#,N,`H@*B\*"B\O($9I;F0@=&AE(&)A<V4@9FEL92!P871H(&]F
M($AO<F1E+@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN)RD["@HO+R!#;VYF:6=U<F%T:6]N+@HO+R!%;G1E<B!D:7)E
M8W1O<FEE<R!W:71H;W5T('1R86EL:6YG('-L87-H97,N"@HO+R!4:&4@9&ER
M96-T;W)Y('=I=&@@=&AE($-64R!C:&5C:V]U="X*)'-R8T1I<B`]($A/4D1%
M7T)!4T4@+B`G+V9R86UE=V]R:R<["@HO+R!4:&4@9&ER96-T;W)Y('=H97)E
M('1H92!S;V9T;&EN:W,@87)E(&-R96%T960N"B\O(%1H:7,@:7,@86QS;R!T
M:&4@9&ER96-T;W)Y('=H:6-H('EO=2!S:&]U;&0@<'5T(&EN('EO=7(@:6YC
M;'5D92!P871H"B\O(&%F=&5R(&-R96%T:6YG('1H92!L:6YK<RX*)&1E<W1$
M:7(@/2!(3U)$15]"05-%("X@)R]L:6)S)SL*"B1C;W!Y(#T@9F%L<V4["@II
M9B`H:7-S970H)&%R9W8I*2!["B`@("`O*B!'970@<FED(&]F('1H92!F:7)S
M="!A<F<@=VAI8V@@:7,@=&AE('-C<FEP="!N86UE+B`J+PH@("`@87)R87E?
M<VAI9G0H)&%R9W8I.PH@("`@=VAI;&4@*"1A<F<@/2!A<G)A>5]S:&EF="@D
M87)G=BDI('L*("`@("`@("!I9B`H)&%R9R`]/2`G+2UH96QP)RD@>PH@("`@
M("`@("`@("!P<FEN=%]U<V%G92@I.PH@("`@("`@('T@96QS96EF("@D87)G
M(#T]("<M+6-O<'DG*2!["B`@("`@("`@("`@("1C;W!Y(#T@=')U93L*("`@
M("`@("!](&5L<V5I9B`H<W1R<W1R*"1A<F<L("<M+7-R8R<I*2!["B`@("`@
M("`@("`@(&QI<W0H+"1S<F-$:7(I(#T@97AP;&]D92@G/2<L("1A<F<I.PH@
M("`@("`@('T@96QS96EF("AS=')S='(H)&%R9RP@)RTM9&5S="<I*2!["B`@
M("`@("`@("`@(&QI<W0H+"1D97-T1&ER*2`](&5X<&QO9&4H)STG+"`D87)G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN=%]U<V%G92@B
M56YR96-O9VYI<V5D(&]P=&EO;B`D87)G(BD["B`@("`@("`@?0H@("`@?0I]
M"@HO+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S
M="X*<F5Q=6ER95]O;F-E("1S<F-$:7(@+B`G+T-,22]#3$DN<&AP)SL*"B\O
M($UA:V4@<W5R92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@=&AE('=E8BX*:68@
M*"%(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@(&5X:70H(DUU
M<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN(BD["GT*"B\O($QO
M860@=&AE($-,22!E;G9I<F]N;65N="`M(&UA:V4@<W5R92!T:&5R92=S(&YO
M('1I;64@;&EM:70L(&EN:70*+R\@<V]M92!V87)I86)L97,L(&5T8RX*2&]R
M9&5?0TQ).CII;FET*"D["@I`:6YC;'5D95]O;F-E("=4<F5E+U1R964N<&AP
M)SL*:68@*"%C;&%S<U]E>&ES=',H)U1R964G*2D@>PH@("`@97AI="@B66]U
M(&YE960@=&AE(%!%05(@)U1R964G('!A8VMA9V4@:6YS=&%L;&5D7&XB*3L*
M?0H*)&QI;FME<B`]("9N97<@3&EN:V5R*"1C;W!Y*3L*:68@*"1H86YD;&4@
M/2!O<&5N9&ER*"1S<F-$:7(I*2!["B`@("!W:&EL92`H)&9I;&4@/2!R96%D
M9&ER*"1H86YD;&4I*2!["B`@("`@("`@:68@*"1F:6QE("$]("<N)R`F)@H@
M("`@("`@("`@("`D9FEL92`A/2`G+BXG("8F"B`@("`@("`@("`@("1F:6QE
M("$]("=#5E,G("8F"B`@("`@("`@("`@(&ES7V1I<B@B)'-R8T1I<B\D9FEL
M92(I*2!["B`@("`@("`@("`@("1L:6YK97(M/G!R;V-E<W,H(B1S<F-$:7(O
M)&9I;&4B+"`D9&5S=$1I<BD["B`@("`@("`@?0H@("`@?0H@("`@8VQO<V5D
M:7(H)&AA;F1L92D["B!]"@IE8VAO(")<;B(["@HO+R`@<&]S<VEB;&4@>&UL
M+7-T<G5C=',*+R\@(#QF:6QE;&ES=#X*+R\@("`@("`\9&ER(&YA;64](B\B
M(&)A<V5I;G-T86QL9&ER/2)834PB/@HO+R`@("`@("`@("`\9FEL92!R;VQE
M/2)P:'`B/E!A<G-E<BYP:'`\+V9I;&4^"B\O("`@("`@("`@(#QF:6QE(')O
M;&4](G!H<"(@;F%M93TB4E-3+G!H<"(@+SX*+R\@("`@("`\+V1I<CX*+R\@
M(#PO9FEL96QI<W0^"B\O"B\O("`\9FEL96QI<W0^"B\O("`@("`@/&9I;&4@
M<F]L93TB<&AP(B!B87-E:6YS=&%L;&1I<CTB+R(^1$(N<&AP/"]F:6QE/@HO
M+R`@("`@(#QD:7(@;F%M93TB1$(B/@HO+R`@("`@("`@("`\9FEL92!R;VQE
M/2)P:'`B/F-O;6UO;BYP:'`\+V9I;&4^"B\O("`@("`@/"]D:7(^"B\O("`\
M+V9I;&5L:7-T/@IC;&%S<R!,:6YK97(@>PH*("`@('9A<B`D7W-R8T1I<CL*
M"B`@("!V87(@)%]B87-E26YS=&%L;$1I<CL*"B`@("!V87(@)%]F:6QE<F]L
M97,@/2!A<G)A>2@G<&AP)RD["@H@("`@=F%R("1?<F]L93L*"B`@("!V87(@
M)%]C;W!Y.PH*("`@(&9U;F-T:6]N($QI;FME<B@D8V]P>2`](&9A;'-E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?8V]P>2`]("1C;W!Y.PH@("`@?0H*("`@
M(&9U;F-T:6]N('!R;V-E<W,H)'-R8T1I<BP@)&1E<W1$:7(I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S<F-$:7(@/2`D<W)C1&ER.PH@("`@("`@("1P86-K
M86=E1FEL92`]("1T:&ES+3Y?<W)C1&ER("X@)R]P86-K86=E+GAM;"<["B`@
M("`@("`@)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH*("`@("`@
M("!I9B`H(6ES7V9I;&4H)'!A8VMA9V5&:6QE*2D@>PH@("`@("`@("`@("`D
M8VQI+3YM97-S86=E*"=.;R!P86-K86=E+GAM;"!I;B`G("X@)'1H:7,M/E]S
M<F-$:7(L("=C;&DN=V%R;FEN9R<I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D=')E92`](%1R964Z.G-E='5P365M
M;W)Y*"=834PG+"`D<&%C:V%G949I;&4I.PH@("`@("`@("1T<F5E+3YS971U
M<"@I.PH*("`@("`@("`O+R!R96%D('!A8VMA9V4@;F%M90H@("`@("`@("1P
M86-K86=E3F%M92`]('1R:6TH)'1R964M/F=E=$5L96UE;G1#;VYT96YT*"<O
M<&%C:V%G92]N86UE)RP@)V-D871A)RDI.PH@("`@("`@("1C;&DM/G=R:71E
M;&XH(E!R;V-E<W-I;F<@<&%C:V%G92`D<&%C:V%G94YA;64N(BD["@H@("`@
M("`@("\O(&QO;VL@9F]R(&9I;&5L:7-T(&EN("<O<&%C:V%G92]R96QE87-E
M+V9I;&5L:7-T)PH@("`@("`@("1F:6QE;&ES="`]("1T<F5E+3YG971%;&5M
M96YT0GE0871H*"<O<&%C:V%G92]R96QE87-E+V9I;&5L:7-T)RD["@H@("`@
M("`@(&EF("@D9FEL96QI<W0I('L*("`@("`@("`@("`@+R\@9&\@=&AI<R!B
M971T97(L(&UA:V4@=&AE('1R964@8VQA<W,@=V]R:R!C87-E(&EN<V5N<VET
M:79E"B`@("`@("`@("`@("1B87-E26YS=&%L;$1I<B`]("1F:6QE;&ES=%LG
M8VAI;&0G75LG871T<FEB=71E<R==6R=B87-E:6YS=&%L;&1I<B==.PH*("`@
M("`@("`@("`@)'1H:7,M/E]B87-E26YS=&%L;$1I<B`]("1D97-T1&ER.PH@
M("`@("`@("`@("!I9B`H)&)A<V5);G-T86QL1&ER("$]("<O)RD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]B87-E26YS=&%L;$1I<B`N/2`G+R<@+B`D
M8F%S94EN<W1A;&Q$:7(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]B87-E26YS=&%L;$1I<B`]('!R96=?<F5P;&%C92@G?"\K?"<L("<O
M)RP@)'1H:7,M/E]B87-E26YS=&%L;$1I<BD["@H@("`@("`@("`@("!I9B`H
M(6ES7V1I<B@D=&AI<RT^7V)A<V5);G-T86QL1&ER*2D@>PH@("`@("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL*("`@("`@("`@("`@
M("`@(%-Y<W1E;3HZ;6MD:7(H)RUP("<@+B`D=&AI<RT^7V)A<V5);G-T86QL
M1&ER*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]H86YD
M;&5&:6QE;&ES=%1A9R@D9FEL96QI<W0I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1C;&DM/FUE<W-A9V4H)TYO(&9I;&5L:7-T('1A9R!F;W5N
M9"!I;G-I9&4Z("<@+B`D<&%C:V%G949I;&4L("=C;&DN=V%R;FEN9R<I.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?:&%N9&QE1FEL96QI<W14
M86<H)&5L96UE;G0L("1C=7)$:7(@/2`G)RD*("`@('L*("`@("`@("!F;W)E
M86-H("@D96QE;65N=%LG8VAI;&1R96XG72!A<R`D8VAI;&0I('L*("`@("`@
M("`@("`@<W=I=&-H("@D8VAI;&1;)VYA;64G72D@>PH@("`@("`@("`@("!C
M87-E("=F:6QE)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?:&%N9&QE1FEL
M951A9R@D8VAI;&0L("1C=7)$:7(I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@)V1I<B<Z"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VAA;F1L941I<E1A9R@D8VAI;&0L("1C=7)$:7(I.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("`D8VQI(#T@)DAO<F1E7T-,23HZ<VEN9VQE=&]N*"D["B`@("`@("`@
M("`@("`@("`D8VQI+3YM97-S86=E*"=';W0@;F\@:&%N9&QE<B!F;W(@=&%G
M.B`G("X@)&-H:6QD6R=N86UE)UTL("=C;&DM=V%R;FEN9R<I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M?0H*("`@(&9U;F-T:6]N(%]H86YD;&5$:7)486<H)&5L96UE;G0L("1C=7)$
M:7(I"B`@("!["B`@("`@("`@:68@*"1E;&5M96YT6R=A='1R:6)U=&5S)UU;
M)VYA;64G72`A/2`G+R<I('L*("`@("`@("`@("`@:68@*'-U8G-T<B@D8W5R
M1&ER+"`M,2D@(3T@)R\G*2!["B`@("`@("`@("`@("`@("`D8W5R1&ER(#T@
M)&-U<D1I<B`N("<O)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8W5R
M1&ER(#T@)&-U<D1I<B`N("1E;&5M96YT6R=A='1R:6)U=&5S)UU;)VYA;64G
M73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&5L96UE;G1;)V%T
M=')I8G5T97,G75LG<F]L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)O
M;&4@/2`D96QE;65N=%LG871T<FEB=71E<R==6R=R;VQE)UT["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES7V1I<B@D=&AI<RT^7V)A<V5);G-T86QL1&ER
M("X@)&-U<D1I<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T
M96TN<&AP)SL*("`@("`@("`@("`@4WES=&5M.CIM:V1I<B@G+7`@)R`N("1T
M:&ES+3Y?8F%S94EN<W1A;&Q$:7(@+B`D8W5R1&ER*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?:&%N9&QE1FEL96QI<W1486<H)&5L96UE;G0L("1C
M=7)$:7(I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]H86YD;&5&:6QE5&%G*"1E
M;&5M96YT+"`D9&ER*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)&5L96UE
M;G1;)V%T=')I8G5T97,G75LG<F]L92==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W)O;&4@/2`D96QE;65N=%LG871T<FEB=71E<R==6R=R;VQE)UT["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1T:&ES+3Y?<F]L92P@
M)'1H:7,M/E]F:6QE<F]L97,I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&5L96UE;G1;)V%T=')I8G5T
M97,G75LG;F%M92==*2D@>PH@("`@("`@("`@("`D9FEL96YA;64@/2`D96QE
M;65N=%LG871T<FEB=71E<R==6R=N86UE)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&9I;&5N86UE(#T@)&5L96UE;G1;)V-D871A)UT["B`@
M("`@("`@?0H@("`@("`@("1F:6QE;F%M92`]('1R:6TH)&9I;&5N86UE*3L*
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V]P>2D@>PH@("`@("`@("`@("`D8VUD
M(#T@(F-P('LD=&AI<RT^7W-R8T1I<GTD9&ER+R1F:6QE;F%M92![)'1H:7,M
M/E]B87-E26YS=&%L;$1I<GTD9&ER+R1F:6QE;F%M92(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'!A<F5N="`]("1T:&ES+3Y?9FEN9$-O;6UO
M;E!A<F5N="@D=&AI<RT^7W-R8T1I<B`N("1D:7(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B87-E
M26YS=&%L;$1I<B`N("1D:7(I.PH@("`@("`@("`@("`D9&ER<R`]('-U8G-T
M<E]C;W5N="AS=6)S='(H)'1H:7,M/E]B87-E26YS=&%L;$1I<B`N("1D:7(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')L
M96XH)'!A<F5N="DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G+R<I.PH@("`@("`@("`@("`D<W)C(#T@<W1R7W)E<&5A="@G+BXO)RP@
M)&1I<G,I("X*("`@("`@("`@("`@("`@('-U8G-T<B@D=&AI<RT^7W-R8T1I
M<B`N("1D:7(L('-T<FQE;B@D<&%R96YT*2`K(#$I.PH@("`@("`@("`@("`D
M8VUD(#T@(FQN("US9B`D<W)C+R1F:6QE;F%M92![)'1H:7,M/E]B87-E26YS
M=&%L;$1I<GTD9&ER+R1F:6QE;F%M92(["B`@("`@("`@?0H@("`@("`@(&5X
M96,H)&-M9"D["B`@("!]"@H@("`@9G5N8W1I;VX@7V9I;F1#;VUM;VY087)E
M;G0H)&$L("1B*0H@("`@>PH@("`@("`@(&9O<B`H)&-O;6UO;B`]("<G+"`D
M;&%S='!O<R`](#`L("1P;W,@/2!S=')P;W,H)&$L("<O)RP@,2D["B`@("`@
M("`@("`@("`D<&]S("$]/2!F86QS92`F)B!S=')P;W,H)&(L('-U8G-T<B@D
M82P@,"P@)'!O<RDI(#T]/2`P.PH@("`@("`@("`@("`@)'!O<R`]('-T<G!O
M<R@D82P@)R\G+"`D<&]S("L@,2DI('L*("`@("`@("`@("`@)&-O;6UO;B`N
M/2!S=6)S='(H)&$L("1L87-T<&]S+"`D<&]S("T@)&QA<W1P;W,I.PH@("`@
M("`@("`@("`D;&%S='!O<R`]("1P;W,["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D8V]M;6]N.PH@("`@?0H*?0H*9G5N8W1I;VX@<')I;G1?=7-A9V4H
M)&UE<W-A9V4@/2`G)RD@>PH*("`@(&EF("@A96UP='DH)&UE<W-A9V4I*2![
M"B`@("`@("`@<')I;G0@(F-R96%T92US>6UL:6YK<RYP:'`Z("1M97-S86=E
M7&Y<;B(["B`@("!]"@H@("`@<')I;G0@/#P\55-!1T4*57-A9V4Z(&-R96%T
M92US>6UL:6YK<RYP:'`@6T]05$E/3ET*"E!O<W-I8FQE(&]P=&EO;G,Z"B`@
M+2UC;W!Y("`@("`@("!$;R!N;W0@8W)E871E('-Y;6)O;&EC(&QI;FMS+"!B
M=70@86-T=6%L;'D@8V]P>2!T:&4@;&EB<F%R:65S+@H@("TM<W)C/41)4B`@
M("`@5&AE('-O=7)C92!D:7)E8W1O<GD@9F]R('1H92!F<F%M97=O<FL@;&EB
M<F%R:65S+@H@("TM9&5S=#U$25(@("`@5&AE(&1E<W1I;F%T:6]N(&1I<F5C
M=&]R>2!F;W(@=&AE(&9R86UE=V]R:R!L:6)R87)I97,N"@I54T%'13L*("`@
M(&5X:70["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+V-O
M;VMI95]L;V=I;BYP:'``````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-C$W`#$P-3$U-#,Q,#8T`#`R,3(U-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]S8W)I<'1S+V-O;VMI95]L;V=I;BYP:'`L=B`Q+C(N,BXR(#(P
M,#8O,#$O,#$@,C$Z,CDZ,#D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D
M969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG
M*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<[
M"@HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I
M=F5R)UTI.PH*+R\@0VAE8VL@9F]R($-/3TM)12!A=71H+@II9B`H96UP='DH
M)%]#3T]+245;)W5S97(G72D@?'P@96UP='DH)%]#3T]+245;)W!A<W-W;W)D
M)UTI('Q\"B`@("`A)&%U=&@M/F%U=&AE;G1I8V%T92@D7T-/3TM)15LG=7-E
M<B==+"!A<G)A>2@G<&%S<W=O<F0G(#T^("1?0T]/2TE%6R=P87-S=V]R9"==
M*2DI('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)VQO9VEN+G!H<#]L;V=O=71?<F5A<V]N/2<@+B!!551(7U)%
M05-/3E]"041,3T=)3BP@=')U92DI.PH@("`@97AI=#L*?0H*)'5R;"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=U<FPG*3L*:68@*&5M<'1Y*"1U<FPI*2!["B`@
M("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=I;F1E>"YP:'`G+"!T
M<G5E*3L*?0IH96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I
M<'1S+U-#4DE05%,`````````````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`T-#(S`#$P-3$U-#,Q,#8T`#`Q-S$U-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@2&]R9&4@571I;&ET>2!38W)I<'1S"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"@I);G1R;V1U8W1I;VX*?GY^?GY^?GY^?GY^"E1H:7,@
M9&ER96-T;W)Y(&-O;G1A:6YS('9A<FEO=7,@=71I;&ET>2!S8W)I<'1S(&9O
M<B!T:&4@2&]R9&4@9&ES=')I8G5T:6]N+@I4:&5Y(&%R92!H97)E(&9O<B!Y
M;W5R(&-O;G9E;FEE;F-E+@H*"E-C<FEP="!);F1E>`I^?GY^?GY^?GY^?GX*
M8V]M<&%R95]R979I<VEO;G,N<V@*("`@($-O;7!A<F5S(&1I9F9E<F5N="!#
M5E,@<F5V:7-I;VYS(&]F('1H92!S86UE(&9I;&4N"@IC;V]K:65?;&]G:6XN
M<&AP"B`@("!!;&QO=W,@=&\@;&]G:6X@=VET:"!U<V5R(&-R961E;G1I86QS
M('!R;W9I9&5D(&)Y(&-O;VMI97,N"@IC<F5A=&4M<WEM;&EN:W,N<&AP"B`@
M("!#<F5A=&5S('-Y;6)O;&EC(&QI;FMS(&YE8V5S<V%R>2!F;W(@9&5V96QO
M<&5R<R!T;R!W;W)K(&1I<F5C=&QY(&]N('1H90H@("`@9FEL97,@:6X@=&AE
M(&9R86UE=V]R:R!M;V1U;&4@=VET:&]U="!N965D:6YG('1O(&EN<W1A;&P@
M=&AE(&-H86YG960*("`@('!A8VMA9V5S+@H*8W)O;F0*("`@('1B9`H*9V5T
M7VQO9VEN+G!H<`H@("`@06QL;W=S('1O(&QO9VEN('=I=&@@=7-E<B!C<F5D
M96YT:6%L<R!P<F]V:61E9"!B>2!'150@<&%R86UE=&5R<RX*"FAI9VAL:6=H
M="YP:'`*("`@($AI9VAL:6=H=',@<V]U<F-E(&9I;&5S(&]N('1H92!C;VYS
M;VQE+@H*:&]R9&4M<G-Y;F,N<V@*("`@(%!E<F9O<FUS(&$@8VAE8VMO=70@
M;V8@=&AE(&QA=&5S="!(;W)D92!C=G,@<V]U<F-E<R!U<VEN9R!R<WEN8RX*
M"FAT='!?;&]G:6Y?<F5F97(N<&AP"B`@("!T8F0*"FUA:V4M<VYA<',N<&AP
M"B`@("!T8F0*"FUA:V4M<F5L96%S92YP:'`*("`@($)U:6QD<R!D:7-T<FEB
M=71I;VX@=&%R8F%L;',@9F]R($AO<F1E(&%N9"!(;W)D92!M;V1U;&5S+@H*
M;65R9V4N<&AP"B`@("!-97)G97,@8V]M;6ET<R!F<F]M(&$@8V]M;6ET(&UE
M<W-A9V4@:6YT;R!T:&4@0U93('1R964@;V8@=&AE(&-U<G)E;G0*("`@(&1I
M<F5C=&]R>2X*"FUI9W)A=&5?8V%T96=O<FEE<RYP:'`*("`@($UI9W)A=&5S
M(&]L9"!C871E9V]R:65S('1O('1H92!N97<@:&]R9&5?8V%T96=O<GE?871T
M<FEB=71E<R!T86)L92X*"FUI9W)A=&5?;&EN:W,N<&AP"B`@("!-:6=R871E
M<R!O;&0@2&]R9&5?3&EN:W,@=&\@=&AE(&AO<F1E7V-A=&5G;W)Y7V%T=')I
M8G5T97,@=&%B;&4N"@IP86-K86=E+F1T9`H@("`@5&AE(%!%05(@<&%C:V%G
M92!D97-C<FEP=&EO;BX*"G)P8RUT97-T+G!H<`H@("`@4')O=FED97,@=&5S
M=',@9F]R('1H92!24$,@8VQI96YT(&%G86EN<W0@<V5V97)A;"`H:6YC;'5D
M:6YG(&]U<B!O=VXI(%)00PH@("`@<V5R=F5R<RX*"G-E=%]P97)M<RYS:`H@
M("`@4V5T<R!F:6QE(&]W;F5R<VAI<"!A;F0@<&5R;6ES<VEO;G,@;VX@=&AE
M($AO<F1E('1R964@9F]R(&AI9V@@<V5C=7)I='DN"@IS971U<"YP:'`*("`@
M(%1H92!M86EN($AO<F1E('-E='5P('-C<FEP="!W:&EC:"!A;&QO=W,@9F]R
M(&$@<W1E<"!B>2!S=&5P('-E='5P(&]R"B`@("!R96-O;F9I9W5R871I;VX@
M;V8@82!(;W)D92!I;G-T86QL871I;VXN"@IT96UP+6-L96%N=7`N8W)O;@H@
M("`@06X@97AA;7!L92!C<F]N(&IO8B!S:&5L;"!S8W)I<'0@=VAI8V@@=VEL
M;"!C;&5A;B!U<"!A;GD@=&5M<&]R87)Y(&9I;&5S"B`@("!W:&EC:"!M87D@
M9V5T('-T<F%N9&5D(&)Y($AO<F1E('5S97)S(&EN('1H92!W96(@<V5R=F5R
M)W,@=&5M<&]R87)Y"B`@("!D:7)E8W1O<GDN"@IU<&1A=&5?:&]R9&4N<V@*
M("`@($9A8VEL:71A=&5S('1H92!U<&1A=&EN9R!A;F0O;W(@:6YS=&%L;&%T
M:6]N(&]F(&AO<F1E(&%N9"!I=',*("`@(&%P<&QI8V%T:6]N<RX*"FUI;65?
M;6%P<&EN9R\*("`@(%1H:7,@<V-R:7!T(&-O;G9E<G1S(&%N($%P86-H92US
M='EL92!M:6UE+G1Y<&5S(&9I;&4@:6YT;R!A"B`@("!M:6UE+FUA<'!I;F<N
M<&AP(&1R:79E<B!F:6QE('-U:71A8FQE(&9O<B!U<V4@=VET:"!(;W)D92X@
M($ET(&ES('5S969U;`H@("`@9F]R('-Y;F-I;F<@07!A8VAE('5P9&%T97,@
M=&\@=&AE:7(@34E-12!T>7!E<R!W:71H($AO<F1E+@H*"D1A=&%B87-E(%-C
M<FEP=',*?GY^?GY^?GY^?GY^?GY^?@I$871A8F%S92!T86)L92!S8VAE;6%S
M(&%N9"!A<W-O8VEA=&5D('5T:6QI='D@<V-R:7!T<R!A<F4@;&]C871E9"!I
M;B!T:&4@<W%L+PIS=6)D:7)E8W1O<GDN"@H*3$1!4"!38VAE;6%S"GY^?GY^
M?GY^?GY^?@I,1$%0('-C:&5M87,@87)E(&QO8V%T960@:6X@=&AE(&QD87`O
M('-U8F1I<F5C=&]R>2X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S8W)I<'1S+V=E=%]L;V=I;BYP:'``````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S<U`#$P-3$U-#,Q,#8T`#`R,#4V
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+V=E=%]L;V=I;BYP
M:'`L=B`Q+C,N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`Y(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IO96P@5F%N9&%L(#QJ=F%N9&%L
M0&EN9F]T96-K+G%C+F-A/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!
M551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B1A=71H(#T@)D%U=&@Z.G-I;F=L
M971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D["@HO+R!#:&5C:R!F;W(@
M1T54(&%U=&@N"FEF("AE;7!T>2@D7T=%5%LG=7-E<B==*2!\?"`A)&%U=&@M
M/F%U=&AE;G1I8V%T92@D7T=%5%LG=7-E<B==+"!A<G)A>2@G<&%S<W=O<F0G
M(#T^("1?1T546R=P87-S)UTI*2D@>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@
M)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G;&]G:6XN<&AP/VQO9V]U=%]R
M96%S;VX];&]G;W5T)RDI.PH@("`@97AI=#L*?0H*:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G:6YD97@N<&AP)RDI.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R\`````````````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8T
M`#`Q-C(S-@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B\`````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S$P-C0`,#$W-3(T`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+P``````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,C$S,C$`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M;&%N9R\`````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8T`#`R,C(T,@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]L86YG+V5N+FIS````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,34U,C4`,3`U,34T,S$P-C0`,#(S,C`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\O($DQ.$X@8V]N<W1A;G1S
M"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&+3@@?"!)4T\M.#@U.2TQ
M"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA<F-H+F-O;2]M
M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*+R\@("`Q+B!03$5!4T4@
M4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!0D]612!,24Y%"B\O("`@
M("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D<F5S<RD*+R\*+R\@("`R
M+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@14Y#3T1)3D<["B\O("`@
M("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P;&5A<V4@:6YC;'5D92!A
M(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@=VAA="!E;F-O9&EN9R!I
M<R!N96-E<W-A<GDN*0H*2%1-3$%R96$N23$X3B`]('L*"@DO+R!T:&4@9F]L
M;&]W:6YG('-H;W5L9"!B92!T:&4@9FEL96YA;64@=VET:&]U="`N:G,@97AT
M96YS:6]N"@DO+R!I="!W:6QL(&)E('5S960@9F]R(&%U=&]M871I8V%L;'D@
M;&]A9"!P;'5G:6X@;&%N9W5A9V4N"@EL86YG.B`B96XB+`H*"71O;VQT:7!S
M.B!["@D)8F]L9#H@("`@("`@("`@(")";VQD(BP*"0EI=&%L:6,Z("`@("`@
M("`@(DET86QI8R(L"@D)=6YD97)L:6YE.B`@("`@(")5;F1E<FQI;F4B+`H)
M"7-T<FEK971H<F]U9V@Z("`B4W1R:6ME=&AR;W5G:"(L"@D)<W5B<V-R:7!T
M.B`@("`@(")3=6)S8W)I<'0B+`H)"7-U<&5R<V-R:7!T.B`@("`B4W5P97)S
M8W)I<'0B+`H)"6IU<W1I9GEL969T.B`@("`B2G5S=&EF>2!,969T(BP*"0EJ
M=7-T:69Y8V5N=&5R.B`@(DIU<W1I9GD@0V5N=&5R(BP*"0EJ=7-T:69Y<FEG
M:'0Z("`@(DIU<W1I9GD@4FEG:'0B+`H)"6IU<W1I9GEF=6QL.B`@("`B2G5S
M=&EF>2!&=6QL(BP*"0EO<F1E<F5D;&ES=#H@("`@(D]R9&5R960@3&ES="(L
M"@D)=6YO<F1E<F5D;&ES=#H@(")"=6QL971E9"!,:7-T(BP*"0EO=71D96YT
M.B`@("`@("`@(D1E8W)E87-E($EN9&5N="(L"@D):6YD96YT.B`@("`@("`@
M("));F-R96%S92!);F1E;G0B+`H)"69O<F5C;VQO<CH@("`@("`B1F]N="!#
M;VQO<B(L"@D):&EL:71E8V]L;W(Z("`@(")"86-K9W)O=6YD($-O;&]R(BP*
M"0EH;W)I>F]N=&%L<G5L93H@(DAO<FEZ;VYT86P@4G5L92(L"@D)8W)E871E
M;&EN:SH@("`@("));G-E<G0@5V5B($QI;FLB+`H)"6EN<V5R=&EM86=E.B`@
M("`B26YS97)T+TUO9&EF>2!);6%G92(L"@D):6YS97)T=&%B;&4Z("`@("))
M;G-E<G0@5&%B;&4B+`H)"6AT;6QM;V1E.B`@("`@("`B5&]G9VQE($A434P@
M4V]U<F-E(BP*"0EP;W!U<&5D:71O<CH@("`@(D5N;&%R9V4@161I=&]R(BP*
M"0EA8F]U=#H@("`@("`@("`@(D%B;W5T('1H:7,@961I=&]R(BP*"0ES:&]W
M:&5L<#H@("`@("`@(DAE;'`@=7-I;F<@961I=&]R(BP*"0ET97AT:6YD:6-A
M=&]R.B`@(D-U<G)E;G0@<W1Y;&4B+`H)"75N9&\Z("`@("`@("`@("`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB+`H)"7)E9&\Z("`@("`@("`@("`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB+`H)"6-U=#H@("`@("`@("`@("`B0W5T
M('-E;&5C=&EO;B(L"@D)8V]P>3H@("`@("`@("`@(")#;W!Y('-E;&5C=&EO
M;B(L"@D)<&%S=&4Z("`@("`@("`@(")087-T92!F<F]M(&-L:7!B;V%R9"(L
M"@D);&5F='1O<FEG:'0Z("`@(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(L
M"@D)<FEG:'1T;VQE9G0Z("`@(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(L
M"@D)<F5M;W9E9F]R;6%T.B`@(")296UO=F4@9F]R;6%T=&EN9R(L"@D)<')I
M;G0Z("`@("`@("`@(")0<FEN="!D;V-U;65N="(L"@D):VEL;'=O<F0Z("`@
M("`@(")#;&5A<B!-4T]F9FEC92!T86=S(@H)?2P*"@EB=71T;VYS.B!["@D)
M(F]K(CH@("`@("`@("`@(")/2R(L"@D)(F-A;F-E;"(Z("`@("`@(")#86YC
M96PB"@E]+`H*"6US9SH@>PH)"2)0871H(CH@("`@("`@("`B4&%T:"(L"@D)
M(E1%6%1?34]$12(Z("`@(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T
M:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB+`H*
M"0DB244M<W5C:W,M9G5L;"US8W)E96XB(#H*"0DO+R!T<F%N<VQA=&4@:&5R
M90H)"2)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"`B("L*"0DB9'5E('1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92`B("L*"0DB9&ES
M<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@
M8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"`B("L*"0DB:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7&Y<;B(@*PH)"2)9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB+`H*"0DB36]Z+4-L:7!B;V%R9"(@.@H)"2)5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2`B("L*"0DB9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R`B
M("L*"0DB=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"@E]+`H*"61I86QO9W,Z('L*"0DO
M+R!#;VUM;VX*"0DB3TLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B3TLB+`H)"2)#86YC96PB("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")#86YC96PB
M+`H*"0DB06QI9VYM96YT.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B06QI9VYM96YT.B(L"@D)(DYO="!S970B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DYO="!S
M970B+`H)"2),969T(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("),969T(BP*"0DB4FEG:'0B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B4FEG:'0B+`H)
M"2)497AT=&]P(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")497AT=&]P(BP*"0DB06)S;6ED9&QE(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B06)S;6ED9&QE(BP*
M"0DB0F%S96QI;F4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B0F%S96QI;F4B+`H)"2)!8G-B;W1T;VTB("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")!8G-B;W1T;VTB
M+`H)"2)";W1T;VTB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z(")";W1T;VTB+`H)"2)-:61D;&4B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")-:61D;&4B+`H)
M"2)4;W`B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")4;W`B+`H*"0DB3&%Y;W5T(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B3&%Y;W5T(BP*"0DB4W!A
M8VEN9R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B4W!A8VEN9R(L"@D)(DAO<FEZ;VYT86PZ(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DAO<FEZ;VYT86PZ(BP*"0DB
M2&]R:7IO;G1A;"!P861D:6YG(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B2&]R:7IO;G1A;"!P861D:6YG(BP*"0DB5F5R=&EC86PZ(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B5F5R
M=&EC86PZ(BP*"0DB5F5R=&EC86P@<&%D9&EN9R(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B5F5R=&EC86P@<&%D9&EN9R(L"@D)(D)O
M<F1E<B!T:&EC:VYE<W,Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(D)O<F1E<B!T:&EC:VYE<W,Z(BP*"0DB3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@.B`B3&5A=F4@
M96UP='D@9F]R(&YO(&)O<F1E<B(L"@H)"2\O($EN<V5R="!,:6YK"@D)(DEN
M<V5R="]-;V1I9GD@3&EN:R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(DEN<V5R="]-;V1I9GD@3&EN:R(L"@D)(DYO;F4@*'5S92!I;7!L
M:6-I="DB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DYO;F4@
M*'5S92!I;7!L:6-I="DB+`H)"2).97<@=VEN9&]W("A?8FQA;FLI(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").97<@=VEN9&]W("A?8FQA
M;FLI(BP*"0DB4V%M92!F<F%M92`H7W-E;&8I(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B4V%M92!F<F%M92`H7W-E;&8I(BP*"0DB5&]P
M(&9R86UE("A?=&]P*2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B5&]P(&9R86UE("A?=&]P*2(L"@D)(D]T:&5R(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D]T:&5R(BP*
M"0DB5&%R9V5T.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B5&%R9V5T.B(L"@D)(E1I=&QE("AT;V]L=&EP*3HB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E1I=&QE("AT;V]L
M=&EP*3HB+`H)"2)54DPZ(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z(")54DPZ(BP*"0DB66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(B`@.B`B66]U(&UU
M<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(BP*
M"0DO+R!);G-E<G0@5&%B;&4*"0DB26YS97)T(%1A8FQE(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B26YS97)T(%1A8FQE(BP*
M"0DB4F]W<SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B4F]W<SHB+`H)"2).=6UB97(@;V8@<F]W<R(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").=6UB97(@;V8@<F]W
M<R(L"@D)(D-O;',Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D-O;',Z(BP*"0DB3G5M8F5R(&]F(&-O;'5M;G,B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B3G5M8F5R(&]F
M(&-O;'5M;G,B+`H)"2)7:61T:#HB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")7:61T:#HB+`H)"2)7:61T:"!O9B!T
M:&4@=&%B;&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")7
M:61T:"!O9B!T:&4@=&%B;&4B+`H)"2)097)C96YT(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")097)C96YT(BP*"0DB
M4&EX96QS(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B4&EX96QS(BP*"0DB16TB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B16TB+`H)"2)7:61T:"!U
M;FET(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")7:61T:"!U;FET(BP*"0DB4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B4&]S:71I;VYI;F<@;V8@=&AI
M<R!T86)L92(L"@D)(D-E;&P@<W!A8VEN9SHB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(D-E;&P@<W!A8VEN9SHB+`H)"2)3<&%C
M92!B971W965N(&%D:F%C96YT(&-E;&QS(B`@("`@("`@("`@("`@("`@("`@
M("`Z(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(BP*"0DB0V5L;"!P
M861D:6YG.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B0V5L;"!P861D:6YG.B(L"@D)(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB("`@("`@("`@(#H@(E-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB+`H)"2\O($EN<V5R="!);6%G
M90H)"2));G-E<G0@26UA9V4B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("));G-E<G0@26UA9V4B+`H)"2));6%G92!54DPZ(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("));6%G
M92!54DPZ(BP*"0DB16YT97(@=&AE(&EM86=E(%523"!H97)E(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B16YT97(@=&AE(&EM86=E(%523"!H97)E
M(BP*"0DB4')E=FEE=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B4')E=FEE=R(L"@D)(E!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=R(@("`@("`@("`@("`@("`@(#H@(E!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(L"@D)(D%L=&5R;F%T92!T97AT
M.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D%L=&5R
M;F%T92!T97AT.B(L"@D)(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S(B`@("`@("`@("`@(#H@(D9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S(BP*"0DB4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@.B`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(L"@D)(DEM86=E(%!R979I97<Z(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DEM86=E(%!R979I97<Z(@H)
M?0I].PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;'5G:6YS+P``````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C0`,#(S,#`R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS96Q);6%G92\`````````
M```````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,C4P,#<`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]!
M;G-E;$EM86=E+VQA;F<O`````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8T`#`R
M-3<S,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]P;'5G:6YS+T%N<V5L26UA9V4O;&%N9R]E;BYJ<P``````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,Q
M-3$`,3`U,34T,S$P-C0`,#(V-C8U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\O($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'
M.B`B96XB+"!%3D-/1$E.1SH@551&+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO
M<CH@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O
M($9/4B!44D%.4TQ!5$]24SH*+R\*+R\@("`Q+B!03$5!4T4@4%54(%E/55(@
M0T].5$%#5"!)3D9/($E.(%1(12!!0D]612!,24Y%"B\O("`@("`@*&%T(&QE
M87-T(&$@=F%L:60@96UA:6P@861D<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@
M5%)9(%1/(%5312!55$8M."!&3U(@14Y#3T1)3D<["B\O("`@("`@*&EF('1H
M:7,@:7,@;F]T('!O<W-I8FQE+"!P;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*
M+R\@("`@("`@=&AA="!S=&%T97,@=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A
M<GDN*0H*06YS96Q);6%G92Y),3A.(#T@>PH)+R\@271E;7,@=&AA="!A<'!E
M87(@:6X@;65N=2X@(%!L96%S92!N;W1E('1H870@86X@=6YD97)S8V]R92`H
M7RD*"2\O(&-H87)A8W1E<B!I;B!T:&4@=')A;G-L871I;VX@*')I9VAT(&-O
M;'5M;BD@=VEL;"!C875S92!T:&4@9F]L;&]W:6YG"@DO+R!L971T97(@=&\@
M8F5C;VUE('5N9&5R;&EN960@86YD(&)E('-H;W)T8W5T(&9O<B!T:&%T(&UE
M;G4@;W!T:6]N+@H*"2));G-E<G0@26UA9V4B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("));G-E<G0@26UA9V4B+`H)(DEM86=E
M(%523#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(DEM86=E(%523#HB+`H)(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(L"@DB4')E=FEE=R(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B4')E=FEE=R(L"@DB4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W(B`@("`@("`@("`@("`@("`@.B`B4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(BP*"2)!;'1E<FYA=&4@
M=&5X=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")!
M;'1E<FYA=&4@=&5X=#HB+`H)(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S(B`@("`@("`@("`@(#H@(D9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S(BP*"2)0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@("`Z(")0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E(BP*"2));6%G92!0<F5V:65W.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("));6%G92!0<F5V:65W.B(L
M"@DB1V%L;&5R>3HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B1V%L;&5R>3HB+`H)(D=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M(B`@("`@("`@("`@("`@("`@("`@("`@(#H@(D=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M(BP*"2));6%G92!F<F]M(&=A;&QE<GDZ(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("));6%G92!F<F]M(&=A;&QE
M<GDZ(BP*"2));6%G92!F<F]M(&=A;&QE<GDB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("));6%G92!F<F]M(&=A;&QE<GDB"GT["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&QU9VEN<R]!;G-E;$EM86=E+V%N<V5L+6EM86=E+FIS````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,3`Q`#$P
M-3$U-#,Q,#8T`#`R-S4R,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O+R!!;G-E;"!);6%G92!0;'5G:6X@9F]R($A434Q!
M<F5A+3,N,`HO+R!0;'5G:6X@=&AA="!A;&QO=W,@=&AE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!T:&4*+R\@2&]R9&4@9G)A;65W;W)K(&UO9'5L92!!
M;G-E;"!I;G1O(&$@=&5X=`HO+PHO+R!-;V1U;&4@<F5U<V5S($A434Q!<F5A
M(&-O9&4*+R\*+R\@26UP;&5M96YT871I;VXZ(%)O96P@1VQO=61E;6%N<R`\
M<F]E;$!G;&]U9&5M86YS+FEN9F\^"B\O"B\O("AC*2`R,#`T+@HO+R!$:7-T
M<FEB=71E9"!U;F1E<B!T:&4@<V%M92!T97)M<R!A<R!(5$U,07)E82!I='-E
M;&8N"B\O(%1H:7,@;F]T:6-E($U54U0@<W1A>2!I;G1A8W0@9F]R('5S92`H
M<V5E(&QI8V5N<V4N='AT*2X*+R\*+R\@)$ED.B!A;G-E;"UI;6%G92YJ<RQV
M(#$N,2`R,#`T+S`Y+S`X(#$V.C`V.C$S(&QA;F-E<B!%>'`@)`H*"F9U;F-T
M:6]N($%N<V5L26UA9V4H961I=&]R*0I["@ET:&ES+F5D:71O<B`](&5D:71O
M<CL*"79A<B!I,3AN(#T@06YS96Q);6%G92Y),3A..PI].PH*"D%N<V5L26UA
M9V4N7W!L=6=I;DEN9F\@/2!["@EN86UE("`@("`@("`@(#H@(D%N<V5L26UA
M9V4B+`H)=F5R<VEO;B`@("`@("`Z("(Q+C`B+`H)9&5V96QO<&5R("`@("`Z
M(")2;V5L($=L;W5D96UA;G,B+`H)9&5V96QO<&5R7W5R;"`Z(")H='1P.B\O
M=W=W+F=L;W5D96UA;G,N:6YF;R\B+`H@("`@("`@('-P;VYS;W(@("`@("`@
M.B`B2&]R9&4@4')O:F5C="(L"B`@("`@("`@<W!O;G-O<E]U<FP@("`Z(")H
M='1P.B\O=W=W+FAO<F1E+F]R9R\B+`H);&EC96YS92`@("`@("`Z(")H=&UL
M07)E82(*?3L*"@HO+R!#86QL960@=VAE;B!T:&4@=7-E<B!C;&EC:W,@;VX@
M(DEN<V5R=$EM86=E(B!B=71T;VXN("!)9B!A;B!I;6%G92!I<R!A;')E861Y
M"B\O('1H97)E+"!I="!W:6QL(&IU<W0@;6]D:69Y(&ET)W,@<')O<&5R=&EE
M<RX*+R\@5&AI<R!F=6YC=&EO;B!O=F5R<FED97,@=&AE(&YA=&EV92!(5$U,
M07)E82!F=6YC=&EO;@I(5$U,07)E82YP<F]T;W1Y<&4N7VEN<V5R=$EM86=E
M(#T@9G5N8W1I;VXH:6UA9V4I('L*"79A<B!E9&ET;W(@/2!T:&ES.PDO+R!F
M;W(@;F5S=&5D(&9U;F-T:6]N<PH)=F%R(&]U='!A<F%M(#T@;G5L;#L*"@EI
M9B`H='EP96]F(&EM86=E(#T](")U;F1E9FEN960B*2!["@D):6UA9V4@/2!T
M:&ES+F=E=%!A<F5N=$5L96UE;G0H*3L*"0EI9B`H:6UA9V4@)B8@(2]>:6UG
M)"]I+G1E<W0H:6UA9V4N=&%G3F%M92DI"@D)"6EM86=E(#T@;G5L;#L*"7T*
M"6EF("AI;6%G92D@;W5T<&%R86T@/2!["@D)9E]B87-E("`@.B!E9&ET;W(N
M8V]N9FEG+F)A<V554DPL"@D)9E]U<FP@("`@.B!(5$U,07)E82YI<U]I92`_
M(&5D:71O<BYS=')I<$)A<V554DPH:6UA9V4N<W)C*2`Z(&EM86=E+F=E=$%T
M=')I8G5T92@B<W)C(BDL"@D)9E]A;'0@("`@.B!I;6%G92YA;'0L"@D)9E]B
M;W)D97(@.B!I;6%G92YB;W)D97(L"@D)9E]A;&EG;B`@.B!I;6%G92YA;&EG
M;BP*"0EF7W9E<G0@("`Z(&EM86=E+G9S<&%C92P*"0EF7VAO<FEZ("`Z(&EM
M86=E+FAS<&%C90H)?3L*"B`@("!V87(@;6%N86=E<B`](%]E9&ET;W)?=7)L
M("L@)W!L=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP)SL*"@E$
M:6%L;V<H;6%N86=E<BP@9G5N8W1I;VXH<&%R86TI('L*+R\)=&AI<RY?<&]P
M=7!$:6%L;V<H;6%N86=E<BP@9G5N8W1I;VXH<&%R86TI('L*"0EI9B`H(7!A
M<F%M*2!["2\O('5S97(@;75S="!H879E('!R97-S960@0V%N8V5L"@D)"7)E
M='5R;B!F86QS93L*"0E]"@D)=F%R(&EM9R`](&EM86=E.PH)"6EF("@A:6UG
M*2!["@D)"79A<B!S96P@/2!E9&ET;W(N7V=E=%-E;&5C=&EO;B@I.PH)"0EV
M87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A;F=E*'-E;"D["@D)"65D:71O
M<BY?9&]C+F5X96-#;VUM86YD*")I;G-E<G1I;6%G92(L(&9A;'-E+"!P87)A
M;2YF7W5R;"D["@D)"6EF("A(5$U,07)E82YI<U]I92D@>PH)"0D):6UG(#T@
M<F%N9V4N<&%R96YT16QE;65N="@I.PH)"0D)+R\@=V]N9&5R(&EF('1H:7,@
M=V]R:W,N+BX*"0D)"6EF("AI;6<N=&%G3F%M92YT;TQO=V5R0V%S92@I("$]
M(")I;6<B*2!["@D)"0D):6UG(#T@:6UG+G!R979I;W5S4VEB;&EN9SL*"0D)
M"7T*"0D)?2!E;'-E('L*"0D)"6EM9R`](')A;F=E+G-T87)T0V]N=&%I;F5R
M+G!R979I;W5S4VEB;&EN9SL*"0D)?0H)"7T@96QS92!["@D)"6EM9RYS<F,@
M/2!P87)A;2YF7W5R;#L*"0E]"@H)"69O<B`H=F%R(&9I96QD(&EN('!A<F%M
M*2!["@D)"79A<B!V86QU92`]('!A<F%M6V9I96QD73L*"0D)<W=I=&-H("AF
M:65L9"D@>PH)"0D@("`@8V%S92`B9E]A;'0B("`@(#H@:6UG+F%L=`D@/2!V
M86QU93L@8G)E86L["@D)"2`@("!C87-E(")F7V)O<F1E<B(@.B!I;6<N8F]R
M9&5R(#T@<&%R<V5);G0H=F%L=64@?'P@(C`B*3L@8G)E86L["@D)"2`@("!C
M87-E(")F7V%L:6=N(B`@.B!I;6<N86QI9VX)(#T@=F%L=64[(&)R96%K.PH)
M"0D@("`@8V%S92`B9E]V97)T(B`@(#H@:6UG+G9S<&%C92`]('!A<G-E26YT
M*'9A;'5E('Q\("(P(BD[(&)R96%K.PH)"0D@("`@8V%S92`B9E]H;W)I>B(@
M(#H@:6UG+FAS<&%C92`]('!A<G-E26YT*'9A;'5E('Q\("(P(BD[(&)R96%K
M.PH)"0E]"@D)?0H)?2P@;W5T<&%R86TI.PI].PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L
M26UA9V4O:6YS97)T7VEM86=E+G!H<```````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38S,#4`,3`U,34T,S$P-C0`,#,P,3<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E+VEN<V5R=%]I;6%G92YP:'`L=B`Q
M+C4N-BXU(#(P,#4O,3`O,3@@,3$Z,S0Z,#(@:F%N($5X<"`D"B`J+PH*+R\@
M0VAE8VL@9F]R(&$@<')I;W(@9&5F:6YI=&EO;B!O9B!(3U)$15]"05-%("AP
M97)H87!S(&)Y(&%N(&%U=&]?<')E<&5N9%]F:6QE"B\O(&1E9FEN:71I;VX@
M9F]R('-I=&4@8W5S=&]M:7IA=&EO;BDN"FEF("@A9&5F:6YE9"@G2$]21$5?
M0D%312<I*2!["B`@("!`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN+RXN+RXN+RXN+RXN)RD["GT*"B\O($QO860@=&AE
M($AO<F1E($9R86UE=V]R:R!C;W)E+"!A;F0@<V5T('5P(&EN8VQU<VEO;B!P
M871H<RX*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H
M<"<["@HO+R!296=I<W1R>0HD<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L
M971O;B@I.PH*+RH@1&5T97)M:6YE(&AO=R!W92!W97)E(&-A;&QE9#L@=VET
M:"!A(%523"P@;W(@=VET:"!A(&=A;&QE<GD@:60@*B\*)&=A;&QE<GEL:7-T
M(#T@)')E9VES=')Y+3YC86QL*"=I;6%G97,O;&ES=$=A;&QE<FEE<R<L(&%R
M<F%Y*&YU;&PI*3L*)&=A;&QE<GE?:60@/2!5=&EL.CIG971&;W)M1&%T82@G
M9V%L;&5R>2<L(&ME>2@D9V%L;&5R>6QI<W0I*3L*)&EM86=E;&ES="`]("1R
M96=I<W1R>2T^8V%L;"@G:6UA9V5S+VQI<W1);6%G97,G+"!A<G)A>2AN=6QL
M+"`D9V%L;&5R>5]I9"P@4$5235-?4TA/5RP@)W-C<F5E;B<L('1R=64I*3L*
M)&9I<G-T7VEM86=E(#T@8V]U;G0H)&EM86=E;&ES="D@/R`D:6UA9V5L:7-T
M6VME>2@D:6UA9V5L:7-T*5U;)W5R;"==(#H@)R<["@H_/@H\:'1M;#X*"CQH
M96%D/@H@(#QT:71L93Y);G-E<G0@26UA9V4\+W1I=&QE/@H*/'-C<FEP="!T
M>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB+BXO+BXO<&]P=7!S+W!O<'5P
M+FIS(CX\+W-C<FEP=#X*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T
M(CX*"G=I;F1O=RYR97-I>F54;R@T,#`L(#(P,"D["@IF=6YC=&EO;B!);FET
M*"D@>PH@(%]?9&QG7VEN:70H*3L*("!V87(@<&%R86T@/2!W:6YD;W<N9&EA
M;&]G07)G=6UE;G1S.PH@(&EF("AP87)A;2D@>PH@("`@("!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@B9E]U<FPB*2YV86QU92`]('!A<F%M6R)F7W5R;")=
M.PH@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]A;'0B*2YV86QU
M92`]('!A<F%M6R)F7V%L=")=.PH@("`@("!D;V-U;65N="YG971%;&5M96YT
M0GE)9"@B9E]B;W)D97(B*2YV86QU92`]('!A<F%M6R)F7V)O<F1E<B)=.PH@
M("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]A;&EG;B(I+G9A;'5E
M(#T@<&%R86U;(F9?86QI9VXB73L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H(F9?=F5R="(I+G9A;'5E(#T@<&%R86U;(F9?=F5R=")=.PH@("`@
M("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]H;W)I>B(I+G9A;'5E(#T@
M<&%R86U;(F9?:&]R:7HB73L*("`@("`@=VEN9&]W+FEP<F5V:65W+FQO8V%T
M:6]N+G)E<&QA8V4H<&%R86TN9E]U<FPI.PH@('T*("!D;V-U;65N="YG971%
M;&5M96YT0GE)9"@B9E]U<FPB*2YF;V-U<R@I.PI].PH*9G5N8W1I;VX@;VY/
M2R@I('L*("!V87(@<F5Q=6ER960@/2!["B`@("`B9E]U<FPB.B`B66]U(&UU
M<W0@96YT97(@=&AE(%523"(*("!].PH@(&9O<B`H=F%R(&D@:6X@<F5Q=6ER
M960I('L*("`@('9A<B!E;"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&DI
M.PH@("`@:68@*"%E;"YV86QU92D@>PH@("`@("!A;&5R="AR97%U:7)E9%MI
M72D["B`@("`@(&5L+F9O8W5S*"D["B`@("`@(')E='5R;B!F86QS93L*("`@
M('T*("!]"B`@+R\@<&%S<R!D871A(&)A8VL@=&\@=&AE(&-A;&QI;F<@=VEN
M9&]W"B`@=F%R(&9I96QD<R`](%LB9E]U<FPB+"`B9E]A;'0B+"`B9E]A;&EG
M;B(L(")F7V)O<F1E<B(L"B`@("`@("`@("`@("`@("`B9E]H;W)I>B(L(")F
M7W9E<G0B73L*("!V87(@<&%R86T@/2!N97<@3V)J96-T*"D["B`@9F]R("AV
M87(@:2!I;B!F:65L9',I('L*("`@('9A<B!I9"`](&9I96QD<UMI73L*("`@
M('9A<B!E;"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&ED*3L*("`@('!A
M<F%M6VED72`](&5L+G9A;'5E.PH@('T*("!?7V1L9U]C;&]S92AP87)A;2D[
M"B`@<F5T=7)N(&9A;'-E.PI].PH*9G5N8W1I;VX@;VY#86YC96PH*2!["B`@
M7U]D;&=?8VQO<V4H;G5L;"D["B`@<F5T=7)N(&9A;'-E.PI].PH*9G5N8W1I
M;VX@;VY0<F5V:65W*"D@>PH@('9A<B!F7W5R;"`](&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*")F7W5R;"(I.PH@('9A<B!U<FP@/2!F7W5R;"YV86QU93L*
M("!I9B`H(75R;"D@>PH@("`@86QE<G0H(EEO=2!H879E('1O(&5N=&5R(&%N
M(%523"!F:7)S="(I.PH@("`@9E]U<FPN9F]C=7,H*3L*("`@(')E='5R;B!F
M86QS93L*("!]"B`@=VEN9&]W+FEP<F5V:65W+FQO8V%T:6]N+G)E<&QA8V4H
M)W-H;W=I;6%G92YH=&UL/R<@*R!U<FPI.PH@(')E='5R;B!F86QS93L*?3L*
M"F9U;F-T:6]N(&-H86YG94=A;&QE<GDH*2!["B`@=F%R(')E;&]A9%]U<FP@
M/2!D;V-U;65N="YL;V-A=&EO;BYH<F5F.PH*("!R96QO861?=7)L("`@("`]
M(')E;&]A9%]U<FPN<W5B<W1R:6YG*#`L<F5L;V%D7W5R;"YL87-T26YD97A/
M9B@G/R<I*3L*("!R96QO861?=7)L("`@("`](')E;&]A9%]U<FP@*R`G/V=A
M;&QE<GD])R`K(&1O8W5M96YT+F9O<FUS6S!=+F=A;&QE<GDN=F%L=64["@H@
M(&1O8W5M96YT+FQO8V%T:6]N+G)E<&QA8V4H<F5L;V%D7W5R;"D["GT*/"]S
M8W)I<'0^"@H\<W1Y;&4@='EP93TB=&5X="]C<W,B/@IH=&UL+"!B;V1Y('L*
M("!B86-K9W)O=6YD.B!"=71T;VY&86-E.PH@(&-O;&]R.B!"=71T;VY497AT
M.PH@(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*("!M
M87)G:6XZ(#!P>#L*("!P861D:6YG.B`P<'@["GT*8F]D>2![('!A9&1I;F<Z
M(#5P>#L@?0IT86)L92!["B`@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS
M86YS+7-E<FEF.PI]"F9O<FT@<"!["B`@;6%R9VEN+71O<#H@-7!X.PH@(&UA
M<F=I;BUB;W1T;VTZ(#5P>#L*?0HN9FP@>R!W:61T:#H@.65M.R!F;&]A=#H@
M;&5F=#L@<&%D9&EN9SH@,G!X(#5P>#L@=&5X="UA;&EG;CH@<FEG:'0[('T*
M+F9R('L@=VED=&@Z(#9E;3L@9FQO870Z(&QE9G0[('!A9&1I;F<Z(#)P>"`U
M<'@[('1E>'0M86QI9VXZ(')I9VAT.R!]"F9I96QD<V5T('L@<&%D9&EN9SH@
M,'!X(#$P<'@@-7!X(#5P>#L@?0IS96QE8W0L(&EN<'5T+"!B=71T;VX@>R!F
M;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68[('T*8G5T=&]N
M('L@=VED=&@Z(#<P<'@[('T*+G-P86-E('L@<&%D9&EN9SH@,G!X.R!]"@HN
M=&ET;&4@>R!B86-K9W)O=6YD.B`C9&1F.R!C;VQO<CH@(S`P,#L@9F]N="UW
M96EG:'0Z(&)O;&0[(&9O;G0M<VEZ93H@,3(P)3L@<&%D9&EN9SH@,W!X(#$P
M<'@[(&UA<F=I;BUB;W1T;VTZ(#$P<'@["F)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"!B;&%C:SL@;&5T=&5R+7-P86-I;F<Z(#)P>#L*?0IF;W)M('L@<&%D
M9&EN9SH@,'!X.R!M87)G:6XZ(#!P>#L@?0H\+W-T>6QE/@H*/"]H96%D/@H*
M/&)O9'D@;VYL;V%D/2));FET*"DB/@H*/&1I=B!C;&%S<STB=&ET;&4B/DEN
M<V5R="!);6%G93PO9&EV/@H\(2TM+2!N97<@<W1U9F8@+2TM/@H\9F]R;2!A
M8W1I;VX](B(@;65T:&]D/2)G970B/@H\=&%B;&4@8F]R9&5R/2(P(B!W:61T
M:#TB,3`P)2(@<W1Y;&4](G!A9&1I;F<Z(#!P>#L@;6%R9VEN.B`P<'@B/@H@
M(#QT8F]D>3X*("`\='(^"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W96T[('1E
M>'0M86QI9VXZ(')I9VAT(CY'86QL97)Y.CPO=&0^"B`@("`\=&0^/'-E;&5C
M="!S:7IE/2(Q(B!N86UE/2)G86QL97)Y(B!I9#TB9E]G86QL97)Y(B!T:71L
M93TB1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB(&]N0VAA;F=E/2)C:&%N
M9V5'86QL97)Y*"D[(CX*/#]P:'`@9F]R96%C:"`H)&=A;&QE<GEL:7-T(&%S
M("1G86QL97)Y*3H@/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1G86QL97)Y+3YG971)1"@I*2`_/B(\/W!H
M<"!I9B`H)&=A;&QE<GE?:60@/3T@)&=A;&QE<GDM/F=E=$ED*"DI(&5C:&\@
M)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO('-T<E]R97!E
M870H)R9N8G-P.R<L(#(@*B`D9V%L;&5R>2T^9V5T3&5V96PH*2D@+B!H=&UL
M<W!E8VEA;&-H87)S*"1G86QL97)Y+3YG970H)VYA;64G*2D@/SX\+V]P=&EO
M;CX*/#]P:'`@96YD9F]R96%C:#L@/SX*("`@(#PO<V5L96-T/@H@("`@/"]T
M9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!S='EL93TB=VED=&@Z(#=E;3L@
M=&5X="UA;&EG;CH@<FEG:'0B/DEM86=E(&9R;VT@9V%L;&5R>3H\+W1D/@H@
M("`@/'1D/CQS96QE8W0@<VEZ93TB,2(@;F%M93TB:6UG7V=A;&QE<GDB(&ED
M/2)F7VEM9U]G86QL97)Y(B!T:71L93TB26UA9V4@9G)O;2!G86QL97)Y(B!O
M;D-H86YG93TB9&]C=6UE;G0N9F]R;7-;,%TN=7)L+G9A;'5E(#T@9&]C=6UE
M;G0N9F]R;7-;,%TN:6UG7V=A;&QE<GDN=F%L=64B/@H\/W!H<"!F;W)E86-H
M("@D:6UA9V5L:7-T(&%S("1I9"`]/B`D:6UA9V4I.B`_/@H@("`@("`\;W!T
M:6]N('9A;'5E/2(\/W!H<"!E8VAO("1I;6%G95LG=7)L)UT@/SXB/CP_<&AP
M(&5C:&\@)&EM86=E6R=N86UE)UT@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R
M96%C:#L@/SX*("`@(#PO<V5L96-T/@H@("`@/"]T9#X*("`\+W1R/@H*("`\
M='(^"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W96T[('1E>'0M86QI9VXZ(')I
M9VAT(CY);6%G92!54DPZ/"]T9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X
M="(@;F%M93TB=7)L(B!I9#TB9E]U<FPB('-T>6QE/2)W:61T:#HW-24B"B`@
M("`@('1I=&QE/2)%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B('9A;'5E/2(\
M/W!H<"!E8VAO("1F:7)S=%]I;6%G92`_/B(@+SX*("`@("`@/&)U='1O;B!N
M86UE/2)P<F5V:65W(B!O;F-L:6-K/2)R971U<FX@;VY0<F5V:65W*"D[(@H@
M("`@("!T:71L93TB4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M(CY0<F5V:65W/"]B=71T;VX^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@
M("`@/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T97AT+6%L:6=N.B!R:6=H="(^
M06QT97)N871E('1E>'0Z/"]T9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X
M="(@;F%M93TB86QT(B!I9#TB9E]A;'0B('-T>6QE/2)W:61T:#HQ,#`E(@H@
M("`@("!T:71L93TB1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,B("\^/"]T9#X*("`\+W1R/@H*("`\+W1B;V1Y/@H\+W1A8FQE/@H*
M/'`@+SX*"CQF:65L9'-E="!S='EL93TB9FQO870Z(&QE9G0[(&UA<F=I;BUL
M969T.B`U<'@[(CX*/&QE9V5N9#Y,87EO=70\+VQE9V5N9#X*"CQD:78@8VQA
M<W,](G-P86-E(CX\+V1I=CX*"CQD:78@8VQA<W,](F9L(CY!;&EG;FUE;G0Z
M/"]D:78^"CQS96QE8W0@<VEZ93TB,2(@;F%M93TB86QI9VXB(&ED/2)F7V%L
M:6=N(@H@('1I=&QE/2)0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(CX*("`\
M;W!T:6]N('9A;'5E/2(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`^
M3F]T('-E=#PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](FQE9G0B("`@("`@
M("`@("`@("`@("`@("`@("`@(#Y,969T/"]O<'1I;VX^"B`@/&]P=&EO;B!V
M86QU93TB<FEG:'0B("`@("`@("`@("`@("`@("`@("`@("`@/E)I9VAT/"]O
M<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB=&5X='1O<"(@("`@("`@("`@("`@
M("`@("`@("`@/E1E>'1T;W`\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)A
M8G-M:61D;&4B("`@("`@("`@("`@("`@("`@("`^06)S;6ED9&QE/"]O<'1I
M;VX^"B`@/&]P=&EO;B!V86QU93TB8F%S96QI;F4B('-E;&5C=&5D/2(Q(B`@
M("`@("`@/D)A<V5L:6YE/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB86)S
M8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@/D%B<V)O='1O;3PO;W!T:6]N
M/@H@(#QO<'1I;VX@=F%L=64](F)O='1O;2(@("`@("`@("`@("`@("`@("`@
M("`@(#Y";W1T;VT\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)M:61D;&4B
M("`@("`@("`@("`@("`@("`@("`@("`^36ED9&QE/"]O<'1I;VX^"B`@/&]P
M=&EO;B!V86QU93TB=&]P(B`@("`@("`@("`@("`@("`@("`@("`@("`@/E1O
M<#PO;W!T:6]N/@H\+W-E;&5C=#X*"CQP("\^"@H\9&EV(&-L87-S/2)F;"(^
M0F]R9&5R('1H:6-K;F5S<SH\+V1I=CX*/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](F)O<F1E<B(@:60](F9?8F]R9&5R(B!S:7IE/2(U(@IT:71L93TB3&5A
M=F4@96UP='D@9F]R(&YO(&)O<F1E<B(@+SX*"CQD:78@8VQA<W,](G-P86-E
M(CX\+V1I=CX*"CPO9FEE;&1S970^"@H\9FEE;&1S970@<W1Y;&4](F9L;V%T
M.G)I9VAT.R!M87)G:6XM<FEG:'0Z(#5P>#LB/@H\;&5G96YD/E-P86-I;F<\
M+VQE9V5N9#X*"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CQD:78@8VQA
M<W,](F9R(CY(;W)I>F]N=&%L.CPO9&EV/@H\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB:&]R:7HB(&ED/2)F7VAO<FEZ(B!S:7IE/2(U(@IT:71L93TB2&]R
M:7IO;G1A;"!P861D:6YG(B`O/@H*/'`@+SX*"CQD:78@8VQA<W,](F9R(CY6
M97)T:6-A;#H\+V1I=CX*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G9E<G0B
M(&ED/2)F7W9E<G0B('-I>F4](C4B"G1I=&QE/2)697)T:6-A;"!P861D:6YG
M(B`O/@H*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*/"]F:65L9'-E=#X*
M/&)R(&-L96%R/2)A;&PB("\^"CQT86)L92!W:61T:#TB,3`P)2(@<W1Y;&4]
M(FUA<F=I;BUB;W1T;VTZ(#`N,F5M(CX*(#QT<CX*("`\=&0@=F%L:6=N/2)B
M;W1T;VTB/@H@("`@26UA9V4@4')E=FEE=SH\8G(@+SX*("`@(#QI9G)A;64@
M;F%M93TB:7!R979I97<B(&ED/2)I<')E=FEE=R(@9G)A;65B;W)D97(](C`B
M('-T>6QE/2)B;W)D97(@.B`Q<'@@<V]L:60@9W)A>3LB(&AE:6=H=#TB,C`P
M(B!W:61T:#TB,S`P(B!S<F,](B(^/"]I9G)A;64^"B`@/"]T9#X*("`\=&0@
M=F%L:6=N/2)B;W1T;VTB('-T>6QE/2)T97AT+6%L:6=N.B!R:6=H="(^"B`@
M("`\8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M93TB;VLB(&]N8VQI8VL](G)E
M='5R;B!O;D]+*"D[(CY/2SPO8G5T=&]N/CQB<CX*("`@(#QB=71T;VX@='EP
M93TB8G5T=&]N(B!N86UE/2)C86YC96PB(&]N8VQI8VL](G)E='5R;B!O;D-A
M;F-E;"@I.R(^0V%N8V5L/"]B=71T;VX^"B`@/"]T9#X*(#PO='(^"CPO=&%B
M;&4^"CPO9F]R;3X*/"]B;V1Y/@H\+VAT;6P^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS
M96Q);6%G92]S:&]W:6UA9V4N:'1M;``````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(P,P`Q,#4Q-30S,3`V-``P,C<V
M-3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&)O9'D^"CQS8W)I<'0^"B!D;V-U;65N="YW<FET92@G/&EM9R!H<W!A8V4]
M(C`B('9S<&%C93TB,"(@<W)C/2(G("L@9&]C=6UE;G0N;&]C871I;VXN<V5A
M<F-H+G-U8G-T<B@Q*2`K("<B/B<I.PH\+W-C<FEP=#X*/"]B;V1Y/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T-O;G1E>'1-96YU+P``
M````````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C0`,#(U,C4S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O0V]N=&5X=$UE;G4O;&%N9R\````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V
M-``P,C8Q-S0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT97AT365N=2]L86YG+V5N+FIS````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$Q,C<U`#$P-3$U-#,Q,#8T`#`R-S$S-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O+R!),3A.(&-O;G-T86YT<PH*+R\@
M3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!
M=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O
M"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!9
M3U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA
M="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%
M05-%(%1262!43R!54T4@551&+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI
M9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM
M96YT"B\O("`@("`@('1H870@<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C
M97-S87)Y+BD*"D-O;G1E>'1-96YU+DDQ.$X@/2!["@DO+R!)=&5M<R!T:&%T
M(&%P<&5A<B!I;B!M96YU+B`@4&QE87-E(&YO=&4@=&AA="!A;B!U;F1E<G-C
M;W)E("A?*0H)+R\@8VAA<F%C=&5R(&EN('1H92!T<F%N<VQA=&EO;B`H<FEG
M:'0@8V]L=6UN*2!W:6QL(&-A=7-E('1H92!F;VQL;W=I;F<*"2\O(&QE='1E
M<B!T;R!B96-O;64@=6YD97)L:6YE9"!A;F0@8F4@<VAO<G1C=70@9F]R('1H
M870@;65N=2!O<'1I;VXN"@H)(D-U="(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")#=70B+`H)(D-O<'DB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z(")#;W!Y(BP*"2)087-T92(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B4&%S=&4B+`H)(DEM86=E
M(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z(")?26UA9V4@4')O<&5R=&EE<RXN+B(L"@DB36]D:69Y($QI;FLB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E]-;V1I9GD@3&EN:RXN+B(L"@DB0VAE8VL@3&EN:R(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-H96-?:R!,:6YK
M+BXN(BP*"2)296UO=F4@3&EN:R(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B7U)E;6]V92!,:6YK+BXN(BP*"2)#96QL
M(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B0U]E;&P@4')O<&5R=&EE<RXN+B(L"@DB4F]W(%!R;W!E<G1I
M97,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E)O7W<@4')O<&5R=&EE<RXN+B(L"@DB26YS97)T(%)O=R!"969O<F4B("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DE?;G-E<G0@
M4F]W($)E9F]R92(L"@DB26YS97)T(%)O=R!!9G1E<B(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DEN7W-E<G0@4F]W($%F=&5R
M(BP*"2)$96QE=&4@4F]W(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B7T1E;&5T92!2;W<B+`H)(D1E;&5T92!#96QL
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")$96QE=&4@0V5L;"(L"@DB5&%B;&4@4')O<&5R=&EE<R(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E]486)L92!0<F]P97)T
M:65S+BXN(BP*"2));G-E<G0@0V]L=6UN($)E9F]R92(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B26YS97)T(%]#;VQU;6X@0F5F;W)E
M(BP*"2));G-E<G0@0V]L=6UN($%F=&5R(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B26YS97)T($-?;VQU;6X@069T97(B+`H)(D1E
M;&5T92!#;VQU;6XB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")$95]L971E($-O;'5M;B(L"@DB2G5S=&EF>2!,969T(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DIU
M<W1I9GD@3&5F="(L"@DB2G5S=&EF>2!#96YT97(B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DIU<W1I9GD@0V5N=&5R(BP*
M"2)*=7-T:69Y(%)I9VAT(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B2G5S=&EF>2!2:6=H="(L"@DB2G5S=&EF>2!&=6QL
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(DIU<W1I9GD@1G5L;"(L"@DB36%K92!L:6YK(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DUA:V4@;&EN7VLN+BXB
M+`H)(E)E;6]V92!T:&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z(")296UO=F4@=&AE(BP*"2)%;&5M96YT(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M16QE;65N="XN+B(L"@DB26YS97)T('!A<F%G<F%P:"!B969O<F4B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DEN<V5R="!P87)A9W)A<&@@
M8F5F;W)E(BP*"2));G-E<G0@<&%R86=R87!H(&%F=&5R(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B26YS97)T('!A<F%G<F%P:"!A9G1E
M<B(L"@H)+R\@3W1H97(@;&%B96QS("AT;V]L=&EP<R!A;F0@86QE<G0O8V]N
M9FER;2!B;W@@;65S<V%G97,I"@H)(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB("`Z(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(BP*
M"2)296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(B`@("`@("`@
M("`@("`@("`@("`@.B`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N="(L"@DB2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2DB("`@("`@("`@("`@("`@(#H@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I(BP*"2)3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9R(@("`@("`@("`@("`@("`@("`@("`@.B`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B+`H)(DUO9&EF>2!54DPB("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")-;V1I9GD@
M55),(BP*"2)#=7)R96YT(%523"!I<R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B0W5R<F5N="!54DP@:7,B+`H)(D]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B("`@("`@("`@("`@("`@("`@
M("`@("`Z(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(BP*"2)0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(B`@.B`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+B(L"@DB3&EN:R!P;VEN=',@=&\Z(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DQI;FL@<&]I
M;G1S('1O.B(L"@DB56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(E5N;&EN:R!T:&4@8W5R<F5N="!E
M;&5M96YT(BP*"2)3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA
M;&]G(B`@("`@("`@("`@("`@("`@.B`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9R(L"@DB4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@(#H@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(L"@DB26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(B`@("`@("`@("`@("`@(#H@(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(L"@DB26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B("`@("`@("`@
M("`@("`@(#H@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(BP*"2)$96QE=&4@=&AE(&-U<G)E;G0@<F]W(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B1&5L971E('1H92!C=7)R96YT(')O=R(L
M"@DB4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B("`@("`@("`@
M("`@("`@("`@("`@(#H@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G(BP*"2));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B("`@("`@("`@("`@.B`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE(BP*"2));G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N92(@("`@("`@("`@("`@.B`B26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B+`H)(D1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6XB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(BP*"2)#<F5A=&4@82!L
M:6YK(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B0W)E871E(&$@;&EN:R(L"@DB26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E(B`@("`@("`@("`@(#H@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(L"@DB26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B("`@("`@("`@("`@
M(#H@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@I].PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O0V]N=&5X=$UE;G4O;65N=2YC
M<W,````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C0U-P`Q,#4Q-30S,3`V-``P,C8W,S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RH@<W1Y;&5S(&9O<B!T
M:&4@0V]N=&5X=$UE;G4@+TA434Q!<F5A("HO"B\J(%1H92!#;VYT97AT365N
M=2!P;'5G:6X@:7,@*&,I(&1Y;F%R8V@N8V]M(#(P,#,N("HO"B\J($1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE('1E<FUS(&%S($A434Q!<F5A(&ET<V5L
M9B`J+PH*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!["B`@<&]S:71I;VXZ
M(&%B<V]L=71E.PH@(&)O<F1E<CH@,7!X('-O;&ED("-A8V$X.3D["B`@<&%D
M9&EN9SH@,G!X.PH@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["B`@8V]L;W(Z
M(",P,#`["B`@8W5R<V]R.B!D969A=6QT.PH@('HM:6YD97@Z(#$P,#`["GT*
M"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@=&%B;&4@>PH@(&9O;G0Z(#$Q
M<'@@=&%H;VUA+'9E<F1A;F$L<V%N<RUS97)I9CL*("!B;W)D97(M8V]L;&%P
M<V4Z(&-O;&QA<'-E.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R
M+FET96T@=&0N:6-O;B!I;6<@>PH@('=I9'1H.B`Q.'!X.PH@(&AE:6=H=#H@
M,3AP>#L*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T<BYI=&5M('1D
M+FEC;VX@>PH@('!A9&1I;F<Z(#!P>"`S<'@["B`@:&5I9VAT.B`Q.'!X.PH@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-C9&8["GT*"F1I=BYH=&UL87)E82UC;VYT
M97AT+6UE;G4@='(N:71E;2!T9"YL86)E;"!["B`@<&%D9&EN9SH@,7!X(#$P
M<'@@,7!X(#-P>#L*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T<BYS
M97!A<F%T;W(@=&0@>PH@('!A9&1I;F<Z(#)P>"`P<'@["GT*"F1I=BYH=&UL
M87)E82UC;VYT97AT+6UE;G4@='(N<V5P87)A=&]R('1D(&1I=B!["B`@8F]R
M9&5R+71O<#H@,7!X('-O;&ED("-A8V$X.3D["B`@;W9E<F9L;W<Z(&AI9&1E
M;CL*("!P;W-I=&EO;CH@<F5L871I=F4["GT*"F1I=BYH=&UL87)E82UC;VYT
M97AT+6UE;G4@='(N<V5P87)A=&]R('1D+FEC;VX@>PH@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-C9&8["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N
M<V5P87)A=&]R('1D+FEC;VX@9&EV('L*+RH@(&UA<F=I;BUL969T.B`S<'@[
M("HO"B`@8F]R9&5R+6-O;&]R.B`C9F9F.PI]"@ID:78N:'1M;&%R96$M8V]N
M=&5X="UM96YU('1R+G-E<&%R871O<B!T9"YL86)E;"!D:78@>PH@(&UA<F=I
M;BUR:6=H=#H@,W!X.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R
M+FET96TN:&]V97(@>PH@(&)A8VMG<F]U;F0M8V]L;W(Z(",S,39A8S4["B`@
M8V]L;W(Z("-F9F8["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N
M:71E;2YH;W9E<B!T9"YI8V]N('L*("!B86-K9W)O=6YD+6-O;&]R.B`C-C$Y
M868U.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]#;VYT97AT365N=2]C;VYT97AT+6UE;G4N:G,`````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,S-34V`#$P-3$U-#,Q
M,#8T`#`S,#(U,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O+R!#;VYT97AT($UE;G4@4&QU9VEN(&9O<B!(5$U,07)E82TS
M+C`*+R\@4W!O;G-O<F5D(&)Y('=W=RYA;65R:6-A;F)I8FQE+F]R9PHO+R!)
M;7!L96UE;G1A=&EO;B!B>2!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N
M8V]M+VUI<VAO;R\*+R\*+R\@*&,I(&1Y;F%R8V@N8V]M(#(P,#,M,C`P-2X*
M+R\@1&ES=')I8G5T960@=6YD97(@=&AE('-A;64@=&5R;7,@87,@2%1-3$%R
M96$@:71S96QF+@HO+R!4:&ES(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O
M<B!U<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O("1)9#H@8V]N=&5X="UM
M96YU+FIS+'8@,2XV(#(P,#4O,#$O,C`@,3<Z-#DZ,#,@;6ES:&]O($5X<"`D
M"@I(5$U,07)E82YL;V%D4W1Y;&4H(FUE;G4N8W-S(BP@(D-O;G1E>'1-96YU
M(BD["@IF=6YC=&EO;B!#;VYT97AT365N=2AE9&ET;W(I('L*"71H:7,N961I
M=&]R(#T@961I=&]R.PI].PH*0V]N=&5X=$UE;G4N7W!L=6=I;DEN9F\@/2![
M"@EN86UE("`@("`@("`@(#H@(D-O;G1E>'1-96YU(BP*"79E<G-I;VX@("`@
M("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B36EH86D@0F%Z;VXB+`H)
M9&5V96QO<&5R7W5R;"`Z(")H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O+R(L
M"@EC7V]W;F5R("`@("`@(#H@(F1Y;F%R8V@N8V]M(BP*"7-P;VYS;W(@("`@
M("`@.B`B06UE<FEC86X@0FEB;&4@4V]C:65T>2(L"@ES<&]N<V]R7W5R;"`@
M(#H@(FAT='`Z+R]W=W<N86UE<FEC86YB:6)L92YO<F<B+`H);&EC96YS92`@
M("`@("`Z(")H=&UL07)E82(*?3L*"D-O;G1E>'1-96YU+G!R;W1O='EP92YO
M;D=E;F5R871E(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L9B`]('1H:7,["@EV
M87(@9&]C(#T@=&AI<RYE9&ET;W)D;V,@/2!T:&ES+F5D:71O<BY?:69R86UE
M+F-O;G1E;G17:6YD;W<N9&]C=6UE;G0["@E(5$U,07)E82Y?861D179E;G1S
M*&1O8RP@6R)C;VYT97AT;65N=2)=+`H)"0D@("`@9G5N8W1I;VX@*&5V96YT
M*2!["@D)"0D@("`@<F5T=7)N('-E;&8N<&]P=7!-96YU*$A434Q!<F5A+FES
M7VEE(#\@<V5L9BYE9&ET;W(N7VEF<F%M92YC;VYT96YT5VEN9&]W+F5V96YT
M(#H@979E;G0I.PH)"0D@("`@?2D["@ET:&ES+F-U<G)E;G1-96YU(#T@;G5L
M;#L*?3L*"D-O;G1E>'1-96YU+G!R;W1O='EP92YG971#;VYT97AT365N=2`]
M(&9U;F-T:6]N*'1A<F=E="D@>PH)=F%R('-E;&8@/2!T:&ES.PH)=F%R(&5D
M:71O<B`]('1H:7,N961I=&]R.PH)=F%R(&-O;F9I9R`](&5D:71O<BYC;VYF
M:6<["@EV87(@;65N=2`](%M=.PH)=F%R('1B;R`]('1H:7,N961I=&]R+G!L
M=6=I;G,N5&%B;&5/<&5R871I;VYS.PH):68@*'1B;RD@=&)O(#T@=&)O+FEN
M<W1A;F-E.PH)=F%R(&DQ.&X@/2!#;VYT97AT365N=2Y),3A..PH*"79A<B!S
M96QE8W1I;VX@/2!E9&ET;W(N:&%S4V5L96-T961497AT*"D["@EI9B`H<V5L
M96-T:6]N*0H)"6UE;G4N<'5S:"A;(&DQ.&Y;(D-U=")=+"!F=6YC=&EO;B@I
M('L@961I=&]R+F5X96-#;VUM86YD*")C=70B*3L@?2P@;G5L;"P@8V]N9FEG
M+F)T;DQI<W1;(F-U=")=6S%=(%TL"@D)"2`@6R!I,3AN6R)#;W!Y(ETL(&9U
M;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(F-O<'DB*3L@?2P@;G5L
M;"P@8V]N9FEG+F)T;DQI<W1;(F-O<'DB75LQ72!=*3L*"6UE;G4N<'5S:"A;
M(&DQ.&Y;(E!A<W1E(ETL(&9U;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA
M;F0H(G!A<W1E(BD[('TL(&YU;&PL(&-O;F9I9RYB=&Y,:7-T6R)P87-T92)=
M6S%=(%TI.PH*"79A<B!C=7)R96YT5&%R9V5T(#T@=&%R9V5T.PH)=F%R(&5L
M;65N=7,@/2!;73L*"79A<B!T;7`["@H)=F%R(&QI;FL@/2!N=6QL.PH)=F%R
M('1A8FQE(#T@;G5L;#L*"79A<B!T<B`](&YU;&P["@EV87(@=&0@/2!N=6QL
M.PH)=F%R(&EM9R`](&YU;&P["@H)9G5N8W1I;VX@=&%B;&5/<&5R871I;VXH
M;W!C;V1E*2!["@D)=&)O+F)U='1O;E!R97-S*&5D:71O<BP@;W!C;V1E*3L*
M"7T["@H)9G5N8W1I;VX@:6YS97)T4&%R82AC=7)R96YT5&%R9V5T+"!A9G1E
M<BD@>PH)"79A<B!E;"`](&-U<G)E;G1487)G970["@D)=F%R('!A<B`](&5L
M+G!A<F5N=$YO9&4["@D)=F%R('`@/2!E9&ET;W(N7V1O8RYC<F5A=&5%;&5M
M96YT*")P(BD["@D)<"YA<'!E;F1#:&EL9"AE9&ET;W(N7V1O8RYC<F5A=&5%
M;&5M96YT*")B<B(I*3L*"0EP87(N:6YS97)T0F5F;W)E*'`L(&%F=&5R(#\@
M96PN;F5X=%-I8FQI;F<@.B!E;"D["@D)=F%R('-E;"`](&5D:71O<BY?9V5T
M4V5L96-T:6]N*"D["@D)=F%R(')A;F=E(#T@961I=&]R+E]C<F5A=&5286YG
M92AS96PI.PH)"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0D)<V5L+G)E;6]V
M94%L;%)A;F=E<R@I.PH)"0ER86YG92YS96QE8W1.;V1E0V]N=&5N=',H<"D[
M"@D)"7)A;F=E+F-O;&QA<'-E*'1R=64I.PH)"0ES96PN861D4F%N9V4H<F%N
M9V4I.PH)"7T@96QS92!["@D)"7)A;F=E+FUO=F54;T5L96UE;G1497AT*'`I
M.PH)"0ER86YG92YC;VQL87!S92AT<G5E*3L*"0D)<F%N9V4N<V5L96-T*"D[
M"@D)?0H)?3L*"@EF;W(@*#L@=&%R9V5T.R!T87)G970@/2!T87)G970N<&%R
M96YT3F]D92D@>PH)"79A<B!T86<@/2!T87)G970N=&%G3F%M93L*"0EI9B`H
M(71A9RD*"0D)8V]N=&EN=64["@D)=&%G(#T@=&%G+G1O3&]W97)#87-E*"D[
M"@D)<W=I=&-H("AT86<I('L*"0D@("`@8V%S92`B:6UG(CH*"0D):6UG(#T@
M=&%R9V5T.PH)"0EE;&UE;G5S+G!U<V@H;G5L;"P*"0D)"2`@("`@6R!I,3AN
M6R));6%G92!0<F]P97)T:65S(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![
M"@D)"0D)("`@("`@(&5D:71O<BY?:6YS97)T26UA9V4H:6UG*3L*"0D)"2`@
M("`@("!]+`H)"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G(ETL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(FEN
M<V5R=&EM86=E(EU;,5T@70H)"0D)*3L*"0D)8G)E86L["@D)("`@(&-A<V4@
M(F$B.@H)"0EL:6YK(#T@=&%R9V5T.PH)"0EE;&UE;G5S+G!U<V@H;G5L;"P*
M"0D)"2`@("`@6R!I,3AN6R)-;V1I9GD@3&EN:R)=+`H)"0D)("`@("`@(&9U
M;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(F-R96%T96QI;FLB+"!T
M<G5E*3L@?2P*"0D)"2`@("`@("!I,3AN6R)#=7)R96YT(%523"!I<R)=("L@
M)SH@)R`K(&QI;FLN:')E9BP*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB
M8W)E871E;&EN:R)=6S%=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(D-H96-K($QI
M;FLB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@=VEN9&]W+F]P96XH;&EN
M:RYH<F5F*3L@?2P*"0D)"2`@("`@("!I,3AN6R)/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(ET@72P*"@D)"0D@("`@(%L@:3$X;ELB4F5M;W9E
M($QI;FLB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L*"0D)"0D@("`@("`@
M:68@*&-O;F9I<FTH:3$X;ELB4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B)=("L@(EQN(B`K"@D)"0D)"0D@
M("!I,3AN6R),:6YK('!O:6YT<R!T;SHB72`K("(@(B`K(&QI;FLN:')E9BDI
M('L*"0D)"0D)("`@("`@('=H:6QE("AL:6YK+F9I<G-T0VAI;&0I"@D)"0D)
M"0D@("`@("`@;&EN:RYP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AL:6YK+F9I
M<G-T0VAI;&0L(&QI;FLI.PH)"0D)"0D@("`@("`@;&EN:RYP87)E;G1.;V1E
M+G)E;6]V94-H:6QD*&QI;FLI.PH)"0D)"2`@("`@("!]"@D)"0D@("`@("`@
M?2P*"0D)"2`@("`@("!I,3AN6R)5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M=")=(%T*"0D)"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")T9"(Z"@D)"71D
M(#T@=&%R9V5T.PH)"0EI9B`H(71B;RD@8G)E86L["@D)"65L;65N=7,N<'5S
M:"AN=6QL+`H)"0D)("`@("!;(&DQ.&Y;(D-E;&P@4')O<&5R=&EE<R)=+`H)
M"0D)("`@("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M8V5L
M;"UP<F]P(BD[('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9R)=+`H)"0D)("`@("`@(&-O;F9I9RYB
M=&Y,:7-T6R)43RUC96QL+7!R;W`B75LQ72!=+`H)"0D)("`@("!;(&DQ.&Y;
M(D1E;&5T92!#96QL(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE
M3W!E<F%T:6]N*")43RUC96QL+61E;&5T92(I.R!]+"!N=6QL+`H)"0D)("`@
M("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUC96QL+61E;&5T92)=6S%=(%T*"0D)
M"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")T<B(Z"@D)"71R(#T@=&%R9V5T
M.PH)"0EI9B`H(71B;RD@8G)E86L["@D)"65L;65N=7,N<'5S:"AN=6QL+`H)
M"0D)("`@("!;(&DQ.&Y;(E)O=R!0<F]P97)T:65S(ETL"@D)"0D@("`@("`@
M9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUR;W<M<')O<"(I.R!]
M+`H)"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9R)=+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUR
M;W<M<')O<")=6S%=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(DEN<V5R="!2;W<@
M0F5F;W)E(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T
M:6]N*")43RUR;W<M:6YS97)T+6%B;W9E(BD[('TL"@D)"0D@("`@("`@:3$X
M;ELB26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(ETL
M"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/+7)O=RUI;G-E<G0M86)O
M=F4B75LQ72!=+`H*"0D)"2`@("`@6R!I,3AN6R));G-E<G0@4F]W($%F=&5R
M(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")4
M3RUR;W<M:6YS97)T+75N9&5R(BD[('TL"@D)"0D@("`@("`@:3$X;ELB26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B72P*"0D)"2`@
M("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M<F]W+6EN<V5R="UU;F1E<B)=6S%=
M(%TL"@H)"0D)("`@("!;(&DQ.&Y;(D1E;&5T92!2;W<B72P*"0D)"2`@("`@
M("!F=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+7)O=RUD96QE=&4B
M*3L@?2P*"0D)"2`@("`@("!I,3AN6R)$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M(ETL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/+7)O=RUD96QE=&4B
M75LQ72!="@D)"0DI.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B=&%B;&4B.@H)
M"0ET86)L92`]('1A<F=E=#L*"0D):68@*"%T8F\I(&)R96%K.PH)"0EE;&UE
M;G5S+G!U<V@H;G5L;"P*"0D)"2`@("`@6R!I,3AN6R)486)L92!0<F]P97)T
M:65S(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N
M*")43RUT86)L92UP<F]P(BD[('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B72P*"0D)"2`@("`@("!C;VYF
M:6<N8G1N3&ES=%LB5$\M=&%B;&4M<')O<")=6S%=(%TL"@H)"0D)("`@("!;
M(&DQ.&Y;(DEN<V5R="!#;VQU;6X@0F5F;W)E(ETL"@D)"0D@("`@("`@9G5N
M8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUC;VPM:6YS97)T+6)E9F]R
M92(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92)=+`H)"0D)("`@("`@(&-O;F9I9RYB
M=&Y,:7-T6R)43RUC;VPM:6YS97)T+6)E9F]R92)=6S%=(%TL"@H)"0D)("`@
M("!;(&DQ.&Y;(DEN<V5R="!#;VQU;6X@069T97(B72P*"0D)"2`@("`@("!F
M=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+6-O;"UI;G-E<G0M869T
M97(B*3L@?2P*"0D)"2`@("`@("!I,3AN6R));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92)=+`H)"0D)("`@("`@(&-O;F9I9RYB
M=&Y,:7-T6R)43RUC;VPM:6YS97)T+6%F=&5R(EU;,5T@72P*"@D)"0D@("`@
M(%L@:3$X;ELB1&5L971E($-O;'5M;B)=+`H)"0D)("`@("`@(&9U;F-T:6]N
M*"D@>R!T86)L94]P97)A=&EO;B@B5$\M8V]L+61E;&5T92(I.R!]+`H)"0D)
M("`@("`@(&DQ.&Y;(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB72P*"0D)
M"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M8V]L+61E;&5T92)=6S%=(%T*
M"0D)"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")B;V1Y(CH*"0D)96QM96YU
M<RYP=7-H*&YU;&PL"@D)"0D@("`@(%L@:3$X;ELB2G5S=&EF>2!,969T(ETL
M"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B
M:G5S=&EF>6QE9G0B*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C;VYF:6<N8G1N
M3&ES=%LB:G5S=&EF>6QE9G0B75LQ72!=+`H)"0D)("`@("!;(&DQ.&Y;(DIU
M<W1I9GD@0V5N=&5R(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O
M<BYE>&5C0V]M;6%N9"@B:G5S=&EF>6-E;G1E<B(I.R!]+"!N=6QL+`H)"0D)
M("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)J=7-T:69Y8V5N=&5R(EU;,5T@72P*
M"0D)"2`@("`@6R!I,3AN6R)*=7-T:69Y(%)I9VAT(ETL"@D)"0D@("`@("`@
M9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B:G5S=&EF>7)I9VAT
M(BD[('TL(&YU;&PL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(FIU<W1I
M9GER:6=H=")=6S%=(%TL"@D)"0D@("`@(%L@:3$X;ELB2G5S=&EF>2!&=6QL
M(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N
M9"@B:G5S=&EF>69U;&PB*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C;VYF:6<N
M8G1N3&ES=%LB:G5S=&EF>69U;&PB75LQ72!="@D)"0DI.PH)"0EB<F5A:SL*
M"0E]"@E]"@H):68@*'-E;&5C=&EO;B`F)B`A;&EN:RD*"0EM96YU+G!U<V@H
M;G5L;"P@6R!I,3AN6R)-86ME(&QI;FLB72P*"0D)"2`@9G5N8W1I;VXH*2![
M(&5D:71O<BYE>&5C0V]M;6%N9"@B8W)E871E;&EN:R(L('1R=64I.R!]+`H)
M"0D)("!I,3AN6R)#<F5A=&4@82!L:6YK(ETL"@D)"0D@(&-O;F9I9RYB=&Y,
M:7-T6R)C<F5A=&5L:6YK(EU;,5T@72D["@H)9F]R("AV87(@:2`](#`[(&D@
M/"!E;&UE;G5S+FQE;F=T:#L@*RMI*0H)"6UE;G4N<'5S:"AE;&UE;G5S6VE=
M*3L*"@EI9B`H(2]H=&UL?&)O9'DO:2YT97-T*&-U<G)E;G1487)G970N=&%G
M3F%M92DI('L*"0ET86)L92`_("AT;7`@/2!T86)L92P@=&%B;&4@/2!N=6QL
M*2`Z("AT;7`@/2!C=7)R96YT5&%R9V5T*3L*"0EM96YU+G!U<V@H;G5L;"P*
M"0D)("!;(&DQ.&Y;(E)E;6]V92!T:&4B72`K("(@)FQT.R(@*R!T;7`N=&%G
M3F%M92`K("(F9W0[("(@*R!I,3AN6R)%;&5M96YT(ETL"@D)"2`@("!F=6YC
M=&EO;B@I('L*"0D)"2`@("!I9B`H8V]N9FER;2AI,3AN6R)0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(ET@
M*R`B("(@*PH)"0D)"0ET;7`N=&%G3F%M92DI('L*"0D)"0D@("`@=F%R(&5L
M(#T@=&UP.PH)"0D)"2`@("!V87(@<"`](&5L+G!A<F5N=$YO9&4["@D)"0D)
M("`@('`N<F5M;W9E0VAI;&0H96PI.PH)"0D)"2`@("!I9B`H2%1-3$%R96$N
M:7-?9V5C:V\I('L*"0D)"0D)("`@(&EF("AP+G1A9TYA;64N=&],;W=E<D-A
M<V4H*2`]/2`B=&0B("8F("%P+FAA<T-H:6QD3F]D97,H*2D*"0D)"0D)"2`@
M("!P+F%P<&5N9$-H:6QD*&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(F)R
M(BDI.PH)"0D)"0D@("`@961I=&]R+F9O<F-E4F5D<F%W*"D["@D)"0D)"2`@
M("!E9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0D)"0D)("`@(&5D:71O<BYU<&1A
M=&54;V]L8F%R*"D["@D)"0D)"2`@("!I9B`H=&%B;&4I('L*"0D)"0D)"2`@
M("!V87(@<V%V95]C;VQL87!S92`]('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA
M<'-E.PH)"0D)"0D)("`@('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@
M(F-O;&QA<'-E(CL*"0D)"0D)"2`@("!T86)L92YS='EL92YB;W)D97)#;VQL
M87!S92`](")S97!A<F%T92(["@D)"0D)"0D@("`@=&%B;&4N<W1Y;&4N8F]R
M9&5R0V]L;&%P<V4@/2!S879E7V-O;&QA<'-E.PH)"0D)"0D@("`@?0H)"0D)
M"2`@("!]"@D)"0D@("`@?0H)"0D@("`@?2P*"0D)("`@(&DQ.&Y;(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B72!=+`H)"0D@(%L@:3$X
M;ELB26YS97)T('!A<F%G<F%P:"!B969O<F4B72P*"0D)("`@(&9U;F-T:6]N
M*"D@>R!I;G-E<G1087)A*'1M<"P@9F%L<V4I.R!]+`H)"0D@("`@:3$X;ELB
M26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(ET@
M72P*"0D)("!;(&DQ.&Y;(DEN<V5R="!P87)A9W)A<&@@869T97(B72P*"0D)
M("`@(&9U;F-T:6]N*"D@>R!I;G-E<G1087)A*'1M<"P@=')U92D[('TL"@D)
M"2`@("!I,3AN6R));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92)=(%T*"0D)*3L*"7T*"7)E='5R;B!M96YU.PI].PH*0V]N=&5X
M=$UE;G4N<')O=&]T>7!E+G!O<'5P365N=2`](&9U;F-T:6]N*&5V*2!["@EV
M87(@<V5L9B`]('1H:7,["@EV87(@:3$X;B`]($-O;G1E>'1-96YU+DDQ.$X[
M"@EI9B`H=&AI<RYC=7)R96YT365N=2D*"0ET:&ES+F-U<G)E;G1-96YU+G!A
M<F5N=$YO9&4N<F5M;W9E0VAI;&0H=&AI<RYC=7)R96YT365N=2D["@EF=6YC
M=&EO;B!G9710;W,H96PI('L*"0EV87(@<B`]('L@>#H@96PN;V9F<V5T3&5F
M="P@>3H@96PN;V9F<V5T5&]P('T["@D):68@*&5L+F]F9G-E=%!A<F5N="D@
M>PH)"0EV87(@=&UP(#T@9V5T4&]S*&5L+F]F9G-E=%!A<F5N="D["@D)"7(N
M>"`K/2!T;7`N>#L*"0D)<BYY("L]('1M<"YY.PH)"7T*"0ER971U<FX@<CL*
M"7T["@EF=6YC=&EO;B!D;V-U;65N=$-L:6-K*&5V*2!["@D)978@?'P@*&5V
M(#T@=VEN9&]W+F5V96YT*3L*"0EI9B`H(7-E;&8N8W5R<F5N=$UE;G4I('L*
M"0D)86QE<G0H:3$X;ELB2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2DB72D["@D)"7)E='5R;B!F86QS93L*"0E]"@D)=F%R(&5L(#T@
M2%1-3$%R96$N:7-?:64@/R!E=BYS<F-%;&5M96YT(#H@978N=&%R9V5T.PH)
M"69O<B`H.R!E;"`A/2!N=6QL("8F(&5L("$]('-E;&8N8W5R<F5N=$UE;G4[
M(&5L(#T@96PN<&%R96YT3F]D92D["@D):68@*&5L(#T](&YU;&PI"@D)"7-E
M;&8N8VQO<V5-96YU*"D["@D)+R](5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*
M"0DO+W)E='5R;B!F86QS93L*"7T["@EV87(@:V5Y<R`](%M=.PH)9G5N8W1I
M;VX@:V5Y4')E<W,H978I('L*"0EE=B!\?"`H978@/2!W:6YD;W<N979E;G0I
M.PH)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"6EF("AE=BYK97E#;V1E
M(#T](#(W*2!["@D)"7-E;&8N8VQO<V5-96YU*"D["@D)"7)E='5R;B!F86QS
M93L*"0E]"@D)=F%R(&ME>2`](%-T<FEN9RYF<F]M0VAA<D-O9&4H2%1-3$%R
M96$N:7-?:64@/R!E=BYK97E#;V1E(#H@978N8VAA<D-O9&4I+G1O3&]W97)#
M87-E*"D["@D)9F]R("AV87(@:2`](&ME>7,N;&5N9W1H.R`M+6D@/CT@,#LI
M('L*"0D)=F%R(&L@/2!K97ES6VE=.PH)"0EI9B`H:ULP72YT;TQO=V5R0V%S
M92@I(#T](&ME>2D*"0D)"6M;,5TN7U]M<V@N86-T:79A=&4H*3L*"0E]"@E]
M.PH)<V5L9BYC;&]S94UE;G4@/2!F=6YC=&EO;B@I('L*"0ES96QF+F-U<G)E
M;G1-96YU+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H<V5L9BYC=7)R96YT365N
M=2D["@D)<V5L9BYC=7)R96YT365N=2`](&YU;&P["@D)2%1-3$%R96$N7W)E
M;6]V945V96YT*&1O8W5M96YT+"`B;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC
M:RD["@D)2%1-3$%R96$N7W)E;6]V945V96YT*'-E;&8N961I=&]R9&]C+"`B
M;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC:RD["@D):68@*&ME>7,N;&5N9W1H
M(#X@,"D*"0D)2%1-3$%R96$N7W)E;6]V945V96YT*'-E;&8N961I=&]R9&]C
M+"`B:V5Y<')E<W,B+"!K97E0<F5S<RD["@D):68@*$A434Q!<F5A+FES7VEE
M*0H)"0ES96QF+FEE4&]P=7`N:&ED92@I.PH)?3L*"79A<B!T87)G970@/2!(
M5$U,07)E82YI<U]I92`_(&5V+G-R8T5L96UE;G0@.B!E=BYT87)G970["@EV
M87(@:69P;W,@/2!G9710;W,H<V5L9BYE9&ET;W(N7VEF<F%M92D["@EV87(@
M>"`](&5V+F-L:65N=%@@*R!I9G!O<RYX.PH)=F%R('D@/2!E=BYC;&EE;G19
M("L@:69P;W,N>3L*"@EV87(@9&EV.PH)=F%R(&1O8SL*"6EF("@A2%1-3$%R
M96$N:7-?:64I('L*"0ED;V,@/2!D;V-U;65N=#L*"7T@96QS92!["@D)+R\@
M244@<W1I;FMS"@D)=F%R('!O<'5P(#T@=&AI<RYI95!O<'5P(#T@=VEN9&]W
M+F-R96%T95!O<'5P*"D["@D)9&]C(#T@<&]P=7`N9&]C=6UE;G0["@D)9&]C
M+F]P96XH*3L*"0ED;V,N=W)I=&4H(CQH=&UL/CQH96%D/CQS='EL92!T>7!E
M/2=T97AT+V-S<R<^0&EM<&]R="!U<FPH(B`K(%]E9&ET;W)?=7)L("L@(G!L
M=6=I;G,O0V]N=&5X=$UE;G4O;65N=2YC<W,I.R!H=&UL+"!B;V1Y('L@<&%D
M9&EN9SH@,'!X.R!M87)G:6XZ(#!P>#L@;W9E<F9L;W<Z(&AI9&1E;CL@8F]R
M9&5R.B`P<'@[('T\+W-T>6QE/CPO:&5A9#X\8F]D>2!U;G-E;&5C=&%B;&4]
M)WEE<R<^/"]B;V1Y/CPO:'1M;#XB*3L*"0ED;V,N8VQO<V4H*3L*"7T*"61I
M=B`](&1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"6EF("A(5$U,07)E82YI
M<U]I92D*"0ED:78N=6YS96QE8W1A8FQE(#T@(F]N(CL*"61I=BYO;F-O;G1E
M>'1M96YU(#T@9G5N8W1I;VXH*2![(')E='5R;B!F86QS93L@?3L*"61I=BYC
M;&%S<TYA;64@/2`B:'1M;&%R96$M8V]N=&5X="UM96YU(CL*"6EF("@A2%1-
M3$%R96$N:7-?:64I"@D)9&EV+G-T>6QE+FQE9G0@/2!D:78N<W1Y;&4N=&]P
M(#T@(C!P>"(["@ED;V,N8F]D>2YA<'!E;F1#:&EL9"AD:78I.PH*"79A<B!T
M86)L92`](&1O8RYC<F5A=&5%;&5M96YT*")T86)L92(I.PH)9&EV+F%P<&5N
M9$-H:6QD*'1A8FQE*3L*"71A8FQE+F-E;&Q3<&%C:6YG(#T@,#L*"71A8FQE
M+F-E;&Q0861D:6YG(#T@,#L*"79A<B!P87)E;G0@/2!D;V,N8W)E871E16QE
M;65N="@B=&)O9'DB*3L*"71A8FQE+F%P<&5N9$-H:6QD*'!A<F5N="D["@H)
M=F%R(&]P=&EO;G,@/2!T:&ES+F=E=$-O;G1E>'1-96YU*'1A<F=E="D["@EF
M;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N9W1H.R`K*VDI('L*"0EV
M87(@;W!T:6]N(#T@;W!T:6]N<UMI73L*"0EV87(@:71E;2`](&1O8RYC<F5A
M=&5%;&5M96YT*")T<B(I.PH)"7!A<F5N="YA<'!E;F1#:&EL9"AI=&5M*3L*
M"0EI9B`H2%1-3$%R96$N:7-?:64I"@D)"6ET96TN=6YS96QE8W1A8FQE(#T@
M(F]N(CL*"0EE;'-E(&ET96TN;VYM;W5S961O=VX@/2!F=6YC=&EO;BAE=BD@
M>PH)"0E(5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*"0D)<F5T=7)N(&9A;'-E
M.PH)"7T["@D):68@*"%O<'1I;VXI('L*"0D):71E;2YC;&%S<TYA;64@/2`B
M<V5P87)A=&]R(CL*"0D)=F%R('1D(#T@9&]C+F-R96%T945L96UE;G0H(G1D
M(BD["@D)"71D+F-L87-S3F%M92`](")I8V]N(CL*"0D)=F%R($E%7TE37T%?
M1E5#2TE.1U]32$E4(#T@)SXG.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I('L*
M"0D)"71D+G5N<V5L96-T86)L92`](")O;B(["@D)"0E)15])4U]!7T950TM)
M3D=?4TA)5"`]("(@=6YS96QE8W1A8FQE/2=O;B<@<W1Y;&4])VAE:6=H=#TQ
M<'@G/B9N8G-P.R(["@D)"7T*"0D)=&0N:6YN97)(5$U,(#T@(CQD:78B("L@
M245?25-?05]&54-+24Y'7U-(250@*R`B/"]D:78^(CL*"0D)=F%R('1D,2`]
M('1D+F-L;VYE3F]D92AT<G5E*3L*"0D)=&0Q+F-L87-S3F%M92`](")L86)E
M;"(["@D)"6ET96TN87!P96YD0VAI;&0H=&0I.PH)"0EI=&5M+F%P<&5N9$-H
M:6QD*'1D,2D["@D)?2!E;'-E('L*"0D)=F%R(&QA8F5L(#T@;W!T:6]N6S!=
M.PH)"0EI=&5M+F-L87-S3F%M92`](")I=&5M(CL*"0D):71E;2Y?7VUS:"`]
M('L*"0D)"6ET96TZ(&ET96TL"@D)"0EL86)E;#H@;&%B96PL"@D)"0EA8W1I
M;VXZ(&]P=&EO;ELQ72P*"0D)"71O;VQT:7`Z(&]P=&EO;ELR72!\?"!N=6QL
M+`H)"0D):6-O;CH@;W!T:6]N6S-=('Q\(&YU;&PL"@D)"0EA8W1I=F%T93H@
M9G5N8W1I;VXH*2!["@D)"0D)<V5L9BYC;&]S94UE;G4H*3L*"0D)"0ES96QF
M+F5D:71O<BYF;V-U<T5D:71O<B@I.PH)"0D)"71H:7,N86-T:6]N*"D["@D)
M"0E]"@D)"7T["@D)"6QA8F5L(#T@;&%B96PN<F5P;&%C92@O7RA;82UZ02U:
M,"TY72DO+"`B/'4^)#$\+W4^(BD["@D)"6EF("AL86)E;"`A/2!O<'1I;VY;
M,%TI"@D)"0EK97ES+G!U<V@H6R!296=%>'`N)#$L(&ET96T@72D["@D)"6QA
M8F5L(#T@;&%B96PN<F5P;&%C92@O7U\O+"`B7R(I.PH)"0EV87(@=&0Q(#T@
M9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6EF("A(5$U,07)E82YI<U]I
M92D*"0D)"71D,2YU;G-E;&5C=&%B;&4@/2`B;VXB.PH)"0EI=&5M+F%P<&5N
M9$-H:6QD*'1D,2D["@D)"71D,2YC;&%S<TYA;64@/2`B:6-O;B(["@D)"6EF
M("AI=&5M+E]?;7-H+FEC;VXI"@D)"0ET9#$N:6YN97)(5$U,(#T@(CQI;6<@
M86QI9VX])VUI9&1L92<@<W)C/2<B("L@:71E;2Y?7VUS:"YI8V]N("L@(B<@
M+SXB.PH)"0EV87(@=&0R(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)
M"6EF("A(5$U,07)E82YI<U]I92D*"0D)"71D,BYU;G-E;&5C=&%B;&4@/2`B
M;VXB.PH)"0EI=&5M+F%P<&5N9$-H:6QD*'1D,BD["@D)"71D,BYC;&%S<TYA
M;64@/2`B;&%B96PB.PH)"0ET9#(N:6YN97)(5$U,(#T@;&%B96P["@D)"6ET
M96TN;VYM;W5S96]V97(@/2!F=6YC=&EO;B@I('L*"0D)"71H:7,N8VQA<W-.
M86UE("L]("(@:&]V97(B.PH)"0D)<V5L9BYE9&ET;W(N7W-T871U<T)A<E1R
M964N:6YN97)(5$U,(#T@=&AI<RY?7VUS:"YT;V]L=&EP('Q\("<F;F)S<#LG
M.PH)"0E].PH)"0EI=&5M+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L@=&AI
M<RYC;&%S<TYA;64@/2`B:71E;2([('T["@D)"6ET96TN;VYC;VYT97AT;65N
M=2`](&9U;F-T:6]N*&5V*2!["@D)"0ET:&ES+E]?;7-H+F%C=&EV871E*"D[
M"@D)"0EI9B`H(4A434Q!<F5A+FES7VEE*0H)"0D)"4A434Q!<F5A+E]S=&]P
M179E;G0H978I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E].PH)"0EI=&5M+F]N
M;6]U<V5U<"`](&9U;F-T:6]N*&5V*2!["@D)"0EV87(@=&EM95-T86UP(#T@
M*&YE=R!$871E*"DI+F=E=%1I;64H*3L*"0D)"6EF("AT:6UE4W1A;7`@+2!S
M96QF+G1I;653=&%M<"`^(#4P,"D*"0D)"0ET:&ES+E]?;7-H+F%C=&EV871E
M*"D["@D)"0EI9B`H(4A434Q!<F5A+FES7VEE*0H)"0D)"4A434Q!<F5A+E]S
M=&]P179E;G0H978I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E].PH)"0DO+VEF
M("AT>7!E;V8@;W!T:6]N6S)=(#T](")S=')I;F<B*0H)"0DO+VET96TN=&ET
M;&4@/2!O<'1I;VY;,ET["@D)?0H)?0H*"6EF("@A2%1-3$%R96$N:7-?:64I
M('L*"0EV87(@9'@@/2!X("L@9&EV+F]F9G-E=%=I9'1H("T@=VEN9&]W+FEN
M;F5R5VED=&@@*R`T.PH)"79A<B!D>2`]('D@*R!D:78N;V9F<V5T2&5I9VAT
M("T@=VEN9&]W+FEN;F5R2&5I9VAT("L@-#L*"0EI9B`H9'@@/B`P*2!X("T]
M(&1X.PH)"6EF("AD>2`^(#`I('D@+3T@9'D["@D)9&EV+G-T>6QE+FQE9G0@
M/2!X("L@(G!X(CL*"0ED:78N<W1Y;&4N=&]P(#T@>2`K(")P>"(["@E](&5L
M<V4@>PH)"2\O(&1E=&5R;6EN92!T:&4@<VEZ92`H9&ED($D@;65N=&EO;B!T
M:&%T($E%('-T:6YK<S\I"@D)=F%R(&9O;V)A<B`](&1O8W5M96YT+F-R96%T
M945L96UE;G0H(F1I=B(I.PH)"69O;V)A<BYC;&%S<TYA;64@/2`B:'1M;&%R
M96$M8V]N=&5X="UM96YU(CL*"0EF;V]B87(N:6YN97)(5$U,(#T@9&EV+FEN
M;F5R2%1-3#L*"0ED;V-U;65N="YB;V1Y+F%P<&5N9$-H:6QD*&9O;V)A<BD[
M"@D)=F%R('<@/2!F;V]B87(N;V9F<V5T5VED=&@["@D)=F%R(&@@/2!F;V]B
M87(N;V9F<V5T2&5I9VAT.PH)"61O8W5M96YT+F)O9'DN<F5M;W9E0VAI;&0H
M9F]O8F%R*3L*"0ET:&ES+FEE4&]P=7`N<VAO=RAE=BYS8W)E96Y8+"!E=BYS
M8W)E96Y9+"!W+"!H*3L*"7T*"@ET:&ES+F-U<G)E;G1-96YU(#T@9&EV.PH)
M=&AI<RYT:6UE4W1A;7`@/2`H;F5W($1A=&4H*2DN9V5T5&EM92@I.PH*"4A4
M34Q!<F5A+E]A9&1%=F5N="AD;V-U;65N="P@(FUO=7-E9&]W;B(L(&1O8W5M
M96YT0VQI8VLI.PH)2%1-3$%R96$N7V%D9$5V96YT*'1H:7,N961I=&]R9&]C
M+"`B;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC:RD["@EI9B`H:V5Y<RYL96YG
M=&@@/B`P*0H)"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F5D:71O<F1O8RP@
M(FME>7!R97-S(BP@:V5Y4')E<W,I.PH*"4A434Q!<F5A+E]S=&]P179E;G0H
M978I.PH)<F5T=7)N(&9A;'-E.PI].PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O5&%B;&5/<&5R871I;VYS+P`````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V
M-``P,C8P-S4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+P``````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#8T`#`R-C8U,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E
M<F%T:6]N<R]I;6<O8V5L;"UD96QE=&4N9VEF````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-#4`,3`U,34T,S$P-C0`,#,Q-3$T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M81(`$@"A``````#_____``#___\A^00!```#`"P`````$@`2```"-IR/J<L#
M#]L!H08@#;4XB02%T2!\"R`$*5J6IZIV[B2&ACE95^;HG53C;2J_QG"7"?*6
MS*:D```[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG
M+V-O;"US<&QI="YG:68``````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q-C$T`#$P-3$U-#,Q,#8T`#`S,3(T-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$2`!(`YP``````
M@````(``@(````"`@`"``("`P,#`P-S`ILKP0"``8"``@"``H"``P"``X"``
M`$``($``0$``8$``@$``H$``P$``X$```&``(&``0&``8&``@&``H&``P&``
MX&```(``((``0(``8(``@(``H(``P(``X(```*``(*``0*``8*``@*``H*``
MP*``X*```,``(,``0,``8,``@,``H,``P,``X,```.``(.``0.``8.``@.``
MH.``P.``X.````!`(`!`0`!`8`!`@`!`H`!`P`!`X`!``"!`("!`0"!`8"!`
M@"!`H"!`P"!`X"!``$!`($!`0$!`8$!`@$!`H$!`P$!`X$!``&!`(&!`0&!`
M8&!`@&!`H&!`P&!`X&!``(!`((!`0(!`8(!`@(!`H(!`P(!`X(!``*!`(*!`
M0*!`8*!`@*!`H*!`P*!`X*!``,!`(,!`0,!`8,!`@,!`H,!`P,!`X,!``.!`
M(.!`0.!`8.!`@.!`H.!`P.!`X.!```"`(`"`0`"`8`"`@`"`H`"`P`"`X`"`
M`""`(""`0""`8""`@""`H""`P""`X""``$"`($"`0$"`8$"`@$"`H$"`P$"`
MX$"``&"`(&"`0&"`8&"`@&"`H&"`P&"`X&"``("`(("`0("`8("`@("`H("`
MP("`X("``*"`(*"`0*"`8*"`@*"`H*"`P*"`X*"``,"`(,"`0,"`8,"`@,"`
MH,"`P,"`X,"``."`(."`0."`8."`@."`H."`P."`X."```#`(`#`0`#`8`#`
M@`#`H`#`P`#`X`#``"#`("#`0"#`8"#`@"#`H"#`P"#`X"#``$#`($#`0$#`
M8$#`@$#`H$#`P$#`X$#``&#`(&#`0&#`8&#`@&#`H&#`P&#`X&#``(#`((#`
M0(#`8(#`@(#`H(#`P(#`X(#``*#`(*#`0*#`8*#`@*#`H*#`P*#`X*#``,#`
M(,#`0,#`8,#`@,#`H,#`__OPH*"D@("`_P```/\`__\```#__P#_`/______
M(?D$`0``_0`L`````!(`$@``"&D`^PD<2+"@P8,(^P%8R+"A0P`"`?S[)W'B
MQ(H6(2J\:)%C1XT/0S*,>-'?/W\$3*)4"9*C20(G_\$TV9*BRI0G<?H#R3#F
M3)DQ:P*X2?2D4)](:9*TF;/HSJ427R:E&%%DR(18LVK=&A``.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+V-E;&PM;65R9V4N9VEF`````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q-C`P`#$P-3$U-#,Q,#8T`#`S,3,T-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
MYP``````@````(``@(````"`@`"``("`P,#`P-S`ILKP0"``8"``@"``H"``
MP"``X"```$``($``0$``8$``@$``H$``P$``X$```&``(&``0&``8&``@&``
MH&``P&``X&```(``((``0(``8(``@(``H(``P(``X(```*``(*``0*``8*``
M@*``H*``P*``X*```,``(,``0,``8,``@,``H,``P,``X,```.``(.``0.``
M8.``@.``H.``P.``X.````!`(`!`0`!`8`!`@`!`H`!`P`!`X`!``"!`("!`
M0"!`8"!`@"!`H"!`P"!`X"!``$!`($!`0$!`8$!`@$!`H$!`P$!`X$!``&!`
M(&!`0&!`8&!`@&!`H&!`P&!`X&!``(!`((!`0(!`8(!`@(!`H(!`P(!`X(!`
M`*!`(*!`0*!`8*!`@*!`H*!`P*!`X*!``,!`(,!`0,!`8,!`@,!`H,!`P,!`
MX,!``.!`(.!`0.!`8.!`@.!`H.!`P.!`X.!```"`(`"`0`"`8`"`@`"`H`"`
MP`"`X`"``""`(""`0""`8""`@""`H""`P""`X""``$"`($"`0$"`8$"`@$"`
MH$"`P$"`X$"``&"`(&"`0&"`8&"`@&"`H&"`P&"`X&"``("`(("`0("`8("`
M@("`H("`P("`X("``*"`(*"`0*"`8*"`@*"`H*"`P*"`X*"``,"`(,"`0,"`
M8,"`@,"`H,"`P,"`X,"``."`(."`0."`8."`@."`H."`P."`X."```#`(`#`
M0`#`8`#`@`#`H`#`P`#`X`#``"#`("#`0"#`8"#`@"#`H"#`P"#`X"#``$#`
M($#`0$#`8$#`@$#`H$#`P$#`X$#``&#`(&#`0&#`8&#`@&#`H&#`P&#`X&#`
M`(#`((#`0(#`8(#`@(#`H(#`P(#`X(#``*#`(*#`0*#`8*#`@*#`H*#`P*#`
MX*#``,#`(,#`0,#`8,#`@,#`H,#`__OPH*"D@("`_P```/\`__\```#__P#_
M`/______(?D$`0``_0`L`````!(`$@``"%T`^PD<2+"@P8,(^P%8R+"A0P`"
M`?S[)W'BQ(H6(2J\:)%C1XT/0S*,>-'?/Y,H3YX$R3&E2XHD*;YTR9*BRIDP
M%3+$B;*F1)XY*P(`ZL_GS:,F08H,F;"ITZ=0`P(`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P
M97)A=&EO;G,O:6UG+W)O=RUI;G-E<G0M86)O=F4N9VEF`#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,38T`#$P-3$U-#,Q,#8T`#`S,C4T,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`P@```/__``"$X8"`____````____________(?D$`0``!P`L````
M`!(`$@```SEXNMS^,`9%:I7S$#`X#"!(=!U&<9Y$6<3*MM$AS#0<T74LXX(-
MO9?88$CT/8A%'7)H=`";NJB4D0``.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM
M9R]R;W<M9&5L971E+F=I9@`````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#$U,``Q,#4Q-30S,3`V-``P,S$T,#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`*$`````
M`/____\``/___R'Y!`$```,`+``````2`!(```(YG(^IRP,/7QNAV@#FM;GM
MVC'1*`T"(@3IJF*&<!HMNP+P_<YZ!Q_D^$)\7)Y/:#$\*G[*B?,)?18``#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+RXO0$QO;F=,:6YK````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P`#`P,#`P,#``,#`P,#`P,#`Q
M-#8`,#`P,#`P,#`P,#``,#$Q-S`W`"!,````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``<F]O
M=`````````````````````````````````````!W:&5E;```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I
M;VYS+VEM9R]C96QL+6EN<V5R="UB969O<F4N9VEF````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM:6YS97)T+6)E9F]R92YG
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,38V`#$P-3$U-#,Q
M,#8T`#`S,C4P,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$2`!(`P@````"`X8"``/______````____________
M(?D$`0``!P`L`````!(`$@```SMXNMSNX,D#(KE8UDJ&\,14'<3WA2*)7<K*
M3FT@!RA,S#3<NCHY_(/:I`,42ES&!_&7="R#/61O2I4D```[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO+B]`3&]N9TQI;FL`````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``,#`P,#`P,``P,#`P,#`P,#$T-0`P,#`P,#`P,#`P,``P,3$W,#8`
M($P`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!R;V]T````````````````````````````
M`````````'=H965L````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM:6YS97)T+6%F
M=&5R+F=I9@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I
M;6<O8V5L;"UI;G-E<G0M869T97(N9VD`,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`Q-C8`,3`U,34T,S$P-C0`,#,R-3$R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y81(`$@#"````
M`(#A@(``______\```#___________\A^00!```'`"P`````$@`2```#.WBZ
MW/[PD$GC(B,/8A767$=58F`&H46<:">-(>`R@`RG35UCPB#@.5NO%[HI;#"/
M9N/Z9(`/XVQ*920``#L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM<W!L
M:70N9VEF`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M-C$S`#$P-3$U-#,Q,#8T`#`S,30P-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$2`!(`YP``````@````(``@(``
M``"`@`"``("`P,#`P-S`ILKP0"``8"``@"``H"``P"``X"```$``($``0$``
M8$``@$``H$``P$``X$```&``(&``0&``8&``@&``H&``P&``X&```(``((``
M0(``8(``@(``H(``P(``X(```*``(*``0*``8*``@*``H*``P*``X*```,``
M(,``0,``8,``@,``H,``P,``X,```.``(.``0.``8.``@.``H.``P.``X.``
M``!`(`!`0`!`8`!`@`!`H`!`P`!`X`!``"!`("!`0"!`8"!`@"!`H"!`P"!`
MX"!``$!`($!`0$!`8$!`@$!`H$!`P$!`X$!``&!`(&!`0&!`8&!`@&!`H&!`
MP&!`X&!``(!`((!`0(!`8(!`@(!`H(!`P(!`X(!``*!`(*!`0*!`8*!`@*!`
MH*!`P*!`X*!``,!`(,!`0,!`8,!`@,!`H,!`P,!`X,!``.!`(.!`0.!`8.!`
M@.!`H.!`P.!`X.!```"`(`"`0`"`8`"`@`"`H`"`P`"`X`"``""`(""`0""`
M8""`@""`H""`P""`X""``$"`($"`0$"`8$"`@$"`H$"`P$"`X$"``&"`(&"`
M0&"`8&"`@&"`H&"`P&"`X&"``("`(("`0("`8("`@("`H("`P("`X("``*"`
M(*"`0*"`8*"`@*"`H*"`P*"`X*"``,"`(,"`0,"`8,"`@,"`H,"`P,"`X,"`
M`."`(."`0."`8."`@."`H."`P."`X."```#`(`#`0`#`8`#`@`#`H`#`P`#`
MX`#``"#`("#`0"#`8"#`@"#`H"#`P"#`X"#``$#`($#`0$#`8$#`@$#`H$#`
MP$#`X$#``&#`(&#`0&#`8&#`@&#`H&#`P&#`X&#``(#`((#`0(#`8(#`@(#`
MH(#`P(#`X(#``*#`(*#`0*#`8*#`@*#`H*#`P*#`X*#``,#`(,#`0,#`8,#`
M@,#`H,#`__OPH*"D@("`_P```/\`__\```#__P#_`/______(?D$`0``_0`L
M`````!(`$@``"&@`^PD<2+"@P8,(^P%8R+"A0P`"`?S[)W'BQ(H6(2J\:)%C
M1XT/0S*,>-'?/W\$3*)4"9*C20(G_\$TV9(B@9LX<Q(`R3#F3)DQ:P)0F?)D
M47]"=2H52K3I2:$^H]*,*#)DPJM8LVH-"``[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-O
M;"UI;G-E<G0M869T97(N9VEF`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,34W`#$P-3$U-#,Q,#8T`#`S,C4Q-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$2`!(`P@``X8"```"`
M`/______````____________(?D$`0``!P`L`````!(`$@```S1XNMS^4)%!
M";@DSGI!AD0HBE%Y!&83K*FROJT;+V@\?B8A#`)>3CN?9M=K`0="$#$Y:QX2
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M+B]`3&]N9TQI;FL`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``,#`P,#`P,``P,#`P,#`P,#$T-0`P
M,#`P,#`P,#`P,``P,3$W,#8`($P`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!R;V]T````
M`````````````````````````````````'=H965L````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O
M:6UG+V-O;"UI;G-E<G0M8F5F;W)E+F=I9@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS
M+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V]L+6EN<V5R="UB969O<F4N9VD`,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-38`,3`U,34T,S$P-C0`
M,#,R-3$P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y81(`$@#"``````#A@(#___\``(``______________\A^00!
M```'`"P`````$@`2```#,WBZW/[P@4"!N"#.>D6&0"B*SA`]0WHR:;NR;V/&
MQ_BM`"$0]VGI/8V.%_MYBL,@;1E+```[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A
M=&EO;G,O:6UG+W)O=RUP<F]P+F=I9@```````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C(U`#$P-3$U-#,Q,#8T`#`S,3$R,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$2
M`!(`H@<```"`X8"`P,#``#.9S,S,____````____(?D$`0``!P`L`````!(`
M$@```UIXNMSN)LH#P#M&Z&WJR]FF>0THA)LG16>+=I8Q#"#M1H,ZX_M)[[$"
MH4`<%HE"@\(@1!J;125F15T1I(:`=LO=7I?=L/8[K5;)S*?:B86ZU5B"?$ZG
M8\WX0P(`.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C
M;VPM9&5L971E+F=I9@`````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#$T-``Q,#4Q-30S,3`V-``P,S$S-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA$@`2`*$``````/__
M__\``/___R'Y!`$```,`+``````2`!(```(UG(^IRP8!GP@OIDJGP.!"&DS<
M!92`9I:-1#7(&7:N$[;S`&\WGNZ&X#L`?8)BD7@,#H/,6P$`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V5L;"UP<F]P+F=I
M9@``````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,S,`
M,3`U,34T,S$P-C0`,#,Q,C,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y81(`$@"B!P#A@(```(#`P,``,YG,S,S_
M__\```#___\A^00!```'`"P`````$@`2```#8'BZW.XFRA/".T;H;>K+V:9Y
M#2B$FR=%9XMVEC$,(.U&@SKC^TGOL0*A0!P6B<(.1H@T,HM*`V$E)5BO4X6A
M8`!XMT>HENL%@)])[72%Q1K&SGCSO92'TYBV_DJG^JD'"0`[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R]486)L94]P97)A=&EO;G,O:6UG+W1A8FQE+7!R;W`N9VEF`````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C(Q`#$P-3$U-#,Q,#8T
M`#`S,3,W-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$2`!(`H@8```"`P,#``#.9____S,S,````____````(?D$
M`0``!@`L`````!(`$@```U9HNMSN)4H#P#,EZ%WJR]FF>0T8A)LG16>+=E8A
M""#M1H(ZX_M)[[$!84`<%HG"@J(@1!J;126&0*U:K5+F<^O,0K_;['5<]7*/
MT278V5V2R=F5?&Y(```[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+VEM9R]R;W<M<W!L:70N9VEF```````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,34W-P`Q,#4Q-30S,3`V-``P,S$S,#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M$@`2`.<``````(````"``("`````@(``@`"`@,#`P,#<P*;*\$`@`&`@`(`@
M`*`@`,`@`.`@``!``"!``$!``&!``(!``*!``,!``.!```!@`"!@`$!@`&!@
M`(!@`*!@`,!@`.!@``"``""``$"``&"``("``*"``,"``."```"@`""@`$"@
M`&"@`("@`*"@`,"@`."@``#``"#``$#``&#``(#``*#``,#``.#```#@`"#@
M`$#@`&#@`(#@`*#@`,#@`.#@````0"``0$``0&``0(``0*``0,``0.``0``@
M0"`@0$`@0&`@0(`@0*`@0,`@0.`@0`!`0"!`0$!`0&!`0(!`0*!`0,!`0.!`
M0`!@0"!@0$!@0&!@0(!@0*!@0,!@0.!@0`"`0""`0$"`0&"`0("`0*"`0,"`
M0."`0`"@0""@0$"@0&"@0("@0*"@0,"@0."@0`#`0"#`0$#`0&#`0(#`0*#`
M0,#`0.#`0`#@0"#@0$#@0&#@0(#@0*#@0,#@0.#@0```@"``@$``@&``@(``
M@*``@,``@.``@``@@"`@@$`@@&`@@(`@@*`@@,`@@.`@@`!`@"!`@$!`@&!`
M@(!`@*!`@,!`@.!`@`!@@"!@@$!@@&!@@(!@@*!@@,!@@.!@@`"`@""`@$"`
M@&"`@("`@*"`@,"`@."`@`"@@""@@$"@@&"@@("@@*"@@,"@@."@@`#`@"#`
M@$#`@&#`@(#`@*#`@,#`@.#`@`#@@"#@@$#@@&#@@(#@@*#@@,#@@.#@@```
MP"``P$``P&``P(``P*``P,``P.``P``@P"`@P$`@P&`@P(`@P*`@P,`@P.`@
MP`!`P"!`P$!`P&!`P(!`P*!`P,!`P.!`P`!@P"!@P$!@P&!@P(!@P*!@P,!@
MP.!@P`"`P""`P$"`P&"`P("`P*"`P,"`P."`P`"@P""@P$"@P&"@P("@P*"@
MP,"@P."@P`#`P"#`P$#`P&#`P(#`P*#`P/_[\*"@I("`@/\```#_`/__````
M__\`_P#______R'Y!`$``/T`+``````2`!(```A<`/L)'$BPH,&#"/L!6,BP
MH4,``@'\FSA1(L5_%B$JO(B18\:(#T,NC.CO7\F3)DU^W(BR94>,$0G(G$F3
MP$J)+E$V))DRY\V:0&_F['FSI]&2-T6&3,BTJ=.G`0$`.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B
M;&5/<&5R871I;VYS+VEM9R]R;W<M:6YS97)T+75N9&5R+F=I9@`P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$V,P`Q,#4Q-30S,3`V-``P,S(U
M-C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA$@`2`,(```#__P``A.&`@/___P```/___________R'Y!`$```<`
M+``````2`!(```,X>+K<_O"024E4(VM[];Z'EW%118%"JI*0NJ*NP#[F!$*!
M8D9!+@$#(*[7(P2#/!\!*.3I*K?H+0$`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N
M<R]L86YG+P``````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C0`,#(W,#$V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O5&%B;&5/<&5R871I;VYS+VQA;F<O96XN:G,````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#`W-@`Q,#4Q-30S,3`V
M-``P,C<W-3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$
M24Y'.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO
M;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%4
M3U)3.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@
M24X@5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E
M;6%I;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%54
M1BTX($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S
M<VEB;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T
M('-T871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I486)L94]P
M97)A=&EO;G,N23$X3B`]('L*"2)!;&EG;B(Z"0D)"0D@(")!;&EG;B(L"@DB
M06QL(&9O=7(@<VED97,B.@D)"0D@(")!;&P@9F]U<B!S:61E<R(L"@DB0F%C
M:V=R;W5N9"(Z"0D)"0D@(")"86-K9W)O=6YD(BP*"2)"87-E;&EN92(Z("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(D)A<V5L:6YE
M(BP*"2)";W)D97(B.@D)"0D)("`B0F]R9&5R(BP*"2)";W)D97)S(CH)"0D)
M"2`@(D)O<F1E<G,B+`H)(D)O='1O;2(Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`B0F]T=&]M(BP*"2)#4U,@4W1Y;&4B.@D)
M"0D)("`B4W1Y;&4@6T-34UTB+`H)(D-A<'1I;VXB.@D)"0D)("`B0V%P=&EO
M;B(L"@DB0V5L;"!0<F]P97)T:65S(CH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(")#96QL(%!R;W!E<G1I97,B+`H)(D-E;G1E<B(Z"0D)"0D@
M(")#96YT97(B+`H)(D-H87(B.B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B0VAA<B(L"@DB0V]L;&%P<V5D(&)O<F1E<G,B
M.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")#;VQL87!S960@8F]R
M9&5R<R(L"@DB0V]L;W(B.@D)"0D)("`B0V]L;W(B+`H)(D1E<V-R:7!T:6]N
M(CH)"0D)"2`@(D1E<V-R:7!T:6]N(BP*"2)&1R!#;VQO<B(Z"0D)"0D@(")&
M1R!#;VQO<B(L"@DB1FQO870B.B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(")&;&]A="(L"@DB1G)A;65S(CH)"0D)"2`@(D9R
M86UE<R(L"@DB2&5I9VAT(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(")(96EG:'0B+`H)(DAO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(CH@("`@("`B2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B+`H)(DAO=R!M86YY(')O=W,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(CH@("`@("`@("`B2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B+`H)(DEM86=E(%523"(Z
M"0D)"0D@("));6%G92!54DPB+`H)(DIU<W1I9GDB.B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B2G5S=&EF>2(L"@DB3&%Y;W5T
M(CH)"0D)"2`@(DQA>6]U="(L"@DB3&5F="(Z"0D)"0D)("`B3&5F="(L"@DB
M36%R9VEN(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")-87)G:6XB+`H)(DUI9&1L92(Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`B36ED9&QE(BP*"2).;R!R=6QE<R(Z"0D)
M"0D@(").;R!R=6QE<R(L"@DB3F\@<VED97,B.@D)"0D)("`B3F\@<VED97,B
M+`H)(DYO;F4B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B3F]N92(L"@DB4&%D9&EN9R(Z"0D)"0D@(")0861D:6YG(BP*
M"2)0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB.B`@("`@("`@("`@("`@
M("`@("`@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(L"@DB4FEG:'0B
M.@D)"0D)("`B4FEG:'0B+`H)(E)O=R!0<F]P97)T:65S(CH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B4F]W(%!R;W!E<G1I97,B+`H)(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B
M.B`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(L"@DB4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'DB.@D@(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>2(L"@DB4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB.@D)
M("`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB+`H)(E)U
M;&5S(CH)"0D)"2`@(E)U;&5S(BP*"2)3<&%C:6YG(&%N9"!P861D:6YG(CH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(E-P86-I;F<@86YD('!A9&1I
M;F<B+`H)(E-P86-I;F<B.@D)"0D)("`B4W!A8VEN9R(L"@DB4W5M;6%R>2(Z
M"0D)"0D@(")3=6UM87)Y(BP*"2)43RUC96QL+61E;&5T92(Z"0D)"2`@(D1E
M;&5T92!C96QL(BP*"2)43RUC96QL+6EN<V5R="UA9G1E<B(Z"0D)"2`@(DEN
M<V5R="!C96QL(&%F=&5R(BP*"2)43RUC96QL+6EN<V5R="UB969O<F4B.@D)
M"2`@(DEN<V5R="!C96QL(&)E9F]R92(L"@DB5$\M8V5L;"UM97)G92(Z"0D)
M"2`@(DUE<F=E(&-E;&QS(BP*"2)43RUC96QL+7!R;W`B.@D)"0D)("`B0V5L
M;"!P<F]P97)T:65S(BP*"2)43RUC96QL+7-P;&ET(CH)"0D)("`B4W!L:70@
M8V5L;"(L"@DB5$\M8V]L+61E;&5T92(Z"0D)"2`@(D1E;&5T92!C;VQU;6XB
M+`H)(E1/+6-O;"UI;G-E<G0M869T97(B.@D)"0D@("));G-E<G0@8V]L=6UN
M(&%F=&5R(BP*"2)43RUC;VPM:6YS97)T+6)E9F]R92(Z"0D)"2`@(DEN<V5R
M="!C;VQU;6X@8F5F;W)E(BP*"2)43RUC;VPM<W!L:70B.@D)"0D)("`B4W!L
M:70@8V]L=6UN(BP*"2)43RUR;W<M9&5L971E(CH)"0D)("`B1&5L971E(')O
M=R(L"@DB5$\M<F]W+6EN<V5R="UA8F]V92(Z"0D)"2`@(DEN<V5R="!R;W<@
M8F5F;W)E(BP*"2)43RUR;W<M:6YS97)T+75N9&5R(CH)"0D)("`B26YS97)T
M(')O=R!A9G1E<B(L"@DB5$\M<F]W+7!R;W`B.@D)"0D)("`B4F]W('!R;W!E
M<G1I97,B+`H)(E1/+7)O=RUS<&QI="(Z"0D)"0D@(")3<&QI="!R;W<B+`H)
M(E1/+71A8FQE+7!R;W`B.@D)"0D@(")486)L92!P<F]P97)T:65S(BP*"2)4
M86)L92!0<F]P97)T:65S(CH)"0D)("`B5&%B;&4@4')O<&5R=&EE<R(L"@DB
M5&5X="!A;&EG;B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")497AT(&%L:6=N(BP*"2)4:&4@8F]T=&]M('-I9&4@;VYL>2(Z"0D)
M"2`@(E1H92!B;W1T;VT@<VED92!O;FQY(BP*"2)4:&4@;&5F="UH86YD('-I
M9&4@;VYL>2(Z"0D)("`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB+`H)(E1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(CH)"2`@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(BP*"2)4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'DB.@D)"2`@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(L"@DB5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB.@D)("`B5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'DB+`H)(E1H92!T;W`@<VED92!O;FQY(CH)"0D)("`B
M5&AE('1O<"!S:61E(&]N;'DB+`H)(E1O<"(Z("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B5&]P(BP)"@DB56YS970@8V]L
M;W(B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")5;G-E
M="!C;VQO<B(L"@DB5F5R=&EC86P@86QI9VXB.B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(")697)T:6-A;"!A;&EG;B(L"@DB5VED=&@B.@D)
M"0D)("`B5VED=&@B+`H)(FYO="UD96PM;&%S="UC96QL(CH)"0D)("`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N(BP*"2)N;W0M9&5L+6QA<W0M8V]L(CH)"0D)("`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(L"@DB;F]T+61E;"UL87-T+7)O=R(Z"0D)"2`@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I
M;B!T86)L92XB+`H)(G!E<F-E;G0B.@D)"0D)("`B<&5R8V5N="(L"@DB<&EX
M96QS(CH)"0D)"2`@(G!I>&5L<R(*?3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P
M97)A=&EO;G,O=&%B;&4M;W!E<F%T:6]N<RYJ<P```````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,3`P,C(P`#$P-3$U-#,Q,#8T`#`S,38W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O+R!4
M86)L92!/<&5R871I;VYS(%!L=6=I;B!F;W(@2%1-3$%R96$M,RXP"B\O($EM
M<&QE;65N=&%T:6]N(&)Y($UI:&%I($)A>F]N+B`@4W!O;G-O<F5D(&)Y(&AT
M='`Z+R]W=W<N>F%P871E8RYC;VT*+R\*+R\@0V]P>7)I9VAT("AC*2!D>6YA
M<F-H+F-O;2`R,#`S+3(P,#4*+R\@5&AI<R!C;W!Y<FEG:'0@;F]T:6-E(&UU
M<W0@<W1A>2!I;G1A8W0@9F]R('5S92X*+R\*+R\@)$ED.B!T86)L92UO<&5R
M871I;VYS+FIS+'8@,2XW(#(P,#4O,#$O,C`@,3<Z-#DZ,#(@;6ES:&]O($5X
M<"`D"@HO+R!/8FIE8W0@=&AA="!W:6QL(&5N8V%P<W5L871E(&%L;"!T:&4@
M=&%B;&4@;W!E<F%T:6]N<R!P<F]V:61E9"!B>0HO+R!(5$U,07)E82TS+C`@
M*&5X8V5P="`B:6YS97)T('1A8FQE(B!W:&EC:"!I<R!I;F-L=61E9"!I;B!T
M:&4@;6%I;B!F:6QE*0IF=6YC=&EO;B!486)L94]P97)A=&EO;G,H961I=&]R
M*2!["@ET:&ES+F5D:71O<B`](&5D:71O<CL*"@EV87(@8V9G(#T@961I=&]R
M+F-O;F9I9SL*"79A<B!T="`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH)=F%R
M(&)L(#T@5&%B;&5/<&5R871I;VYS+F)T;DQI<W0["@EV87(@<V5L9B`]('1H
M:7,["@H)+R\@<F5G:7-T97(@=&AE('1O;VQB87(@8G5T=&]N<R!P<F]V:61E
M9"!B>2!T:&ES('!L=6=I;@H)=F%R('1O;VQB87(@/2!;(FQI;F5B<F5A:R)=
M.PH)9F]R("AV87(@:2`](#`[(&D@/"!B;"YL96YG=&@[("LK:2D@>PH)"79A
M<B!B=&X@/2!B;%MI73L*"0EI9B`H(6)T;BD@>PH)"0ET;V]L8F%R+G!U<V@H
M(G-E<&%R871O<B(I.PH)"7T@96QS92!["@D)"79A<B!I9"`](")43RTB("L@
M8G1N6S!=.PH)"0EC9F<N<F5G:7-T97)"=71T;VXH:60L('1T6VED72P@961I
M=&]R+FEM9U523"AB=&Y;,%T@*R`B+F=I9B(L(")486)L94]P97)A=&EO;G,B
M*2P@9F%L<V4L"@D)"0D)("`@9G5N8W1I;VXH961I=&]R+"!I9"D@>PH)"0D)
M"0D@("`O+R!D:7-P871C:"!B=71T;VX@<')E<W,@979E;G0*"0D)"0D)("`@
M<V5L9BYB=71T;VY0<F5S<RAE9&ET;W(L(&ED*3L*"0D)"0D@("!]+"!B=&Y;
M,5TI.PH)"0ET;V]L8F%R+G!U<V@H:60I.PH)"7T*"7T*"@DO+R!A9&0@82!N
M97<@;&EN92!I;B!T:&4@=&]O;&)A<@H)8V9G+G1O;VQB87(N<'5S:"AT;V]L
M8F%R*3L*?3L*"E1A8FQE3W!E<F%T:6]N<RY?<&QU9VEN26YF;R`]('L*"6YA
M;64@("`@("`@("`@.B`B5&%B;&5/<&5R871I;VYS(BP*"79E<G-I;VX@("`@
M("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B36EH86D@0F%Z;VXB+`H)
M9&5V96QO<&5R7W5R;"`Z(")H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O+R(L
M"@EC7V]W;F5R("`@("`@(#H@(DUI:&%I($)A>F]N(BP*"7-P;VYS;W(@("`@
M("`@.B`B6F%P871E8R!);F,N(BP*"7-P;VYS;W)?=7)L("`@.B`B:'1T<#HO
M+W=W=RYB;&]K:2YC;VTB+`H);&EC96YS92`@("`@("`Z(")H=&UL07)E82(*
M?3L*"B\J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH*("H@551)3$E42453"B`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHO"@HO+R!R971R:65V97,@=&AE(&-L
M;W-E<W0@96QE;65N="!H879I;F<@=&AE('-P96-I9FEE9"!T86=.86UE(&EN
M('1H92!L:7-T(&]F"B\O(&%N8V5S=&]R<R!O9B!T:&4@8W5R<F5N="!S96QE
M8W1I;VXO8V%R970N"E1A8FQE3W!E<F%T:6]N<RYP<F]T;W1Y<&4N9V5T0VQO
M<V5S="`](&9U;F-T:6]N*'1A9TYA;64I('L*"79A<B!E9&ET;W(@/2!T:&ES
M+F5D:71O<CL*"79A<B!A;F-E<W1O<G,@/2!E9&ET;W(N9V5T06QL06YC97-T
M;W)S*"D["@EV87(@<F5T(#T@;G5L;#L*"71A9TYA;64@/2`H(B(@*R!T86=.
M86UE*2YT;TQO=V5R0V%S92@I.PH)9F]R("AV87(@:2`](#`[(&D@/"!A;F-E
M<W1O<G,N;&5N9W1H.R`K*VDI('L*"0EV87(@96P@/2!A;F-E<W1O<G-;:5T[
M"@D):68@*&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*2`]/2!T86=.86UE*2![
M"@D)"7)E="`](&5L.PH)"0EB<F5A:SL*"0E]"@E]"@ER971U<FX@<F5T.PI]
M.PH*+R\@=&AI<R!F=6YC=&EO;B!R97%U:7)E<R!T:&4@9FEL92!0;W!U<$1I
M=B]0;W!U<%=I;B!T;R!B92!L;V%D960@9G)O;2!B<F]W<V5R"E1A8FQE3W!E
M<F%T:6]N<RYP<F]T;W1Y<&4N9&EA;&]G5&%B;&50<F]P97)T:65S(#T@9G5N
M8W1I;VXH*2!["@EV87(@:3$X;B`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH)
M+R\@<F5T<FEE=F4@97AI<W1I;F<@=F%L=65S"@EV87(@=&%B;&4@/2!T:&ES
M+F=E=$-L;W-E<W0H(G1A8FQE(BD["@DO+R!T:&ES+F5D:71O<BYS96QE8W1.
M;V1E0V]N=&5N=',H=&%B;&4I.PH)+R\@=&AI<RYE9&ET;W(N=7!D871E5&]O
M;&)A<B@I.PH*"79A<B!D:6%L;V<@/2!N97<@4&]P=7!7:6XH=&AI<RYE9&ET
M;W(L(&DQ.&Y;(E1A8FQE(%!R;W!E<G1I97,B72P@9G5N8W1I;VXH9&EA;&]G
M+"!P87)A;7,I('L*"0E486)L94]P97)A=&EO;G,N<')O8V5S<U-T>6QE*'!A
M<F%M<RP@=&%B;&4I.PH)"69O<B`H=F%R(&D@:6X@<&%R86US*2!["@D)"79A
M<B!V86P@/2!P87)A;7-;:5T["@D)"7-W:71C:"`H:2D@>PH)"0D@("`@8V%S
M92`B9E]C87!T:6]N(CH*"0D)"6EF("@O7%,O+G1E<W0H=F%L*2D@>PH)"0D)
M"2\O(&-O;G1A:6YS(&YO;B!W:&ET92US<&%C92!C:&%R86-T97)S"@D)"0D)
M=F%R(&-A<'1I;VX@/2!T86)L92YG971%;&5M96YT<T)Y5&%G3F%M92@B8V%P
M=&EO;B(I6S!=.PH)"0D)"6EF("@A8V%P=&EO;BD@>PH)"0D)"0EC87!T:6]N
M(#T@9&EA;&]G+F5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(F-A<'1I;VXB
M*3L*"0D)"0D)=&%B;&4N:6YS97)T0F5F;W)E*&-A<'1I;VXL('1A8FQE+F9I
M<G-T0VAI;&0I.PH)"0D)"7T*"0D)"0EC87!T:6]N+FEN;F5R2%1-3"`]('9A
M;#L*"0D)"7T@96QS92!["@D)"0D)+R\@<V5A<F-H(&9O<B!C87!T:6]N(&%N
M9"!D96QE=&4@:70@:68@9F]U;F0*"0D)"0EV87(@8V%P=&EO;B`]('1A8FQE
M+F=E=$5L96UE;G1S0GE486=.86UE*")C87!T:6]N(BE;,%T["@D)"0D):68@
M*&-A<'1I;VXI('L*"0D)"0D)8V%P=&EO;BYP87)E;G1.;V1E+G)E;6]V94-H
M:6QD*&-A<'1I;VXI.PH)"0D)"7T*"0D)"7T*"0D)"6)R96%K.PH)"0D@("`@
M8V%S92`B9E]S=6UM87)Y(CH*"0D)"71A8FQE+G-U;6UA<GD@/2!V86P["@D)
M"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?=VED=&@B.@H)"0D)=&%B;&4N<W1Y
M;&4N=VED=&@@/2`H(B(@*R!V86PI("L@<&%R86US+F9?=6YI=#L*"0D)"6)R
M96%K.PH)"0D@("`@8V%S92`B9E]A;&EG;B(Z"@D)"0ET86)L92YA;&EG;B`]
M('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]S<&%C:6YG(CH*"0D)
M"71A8FQE+F-E;&Q3<&%C:6YG(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C
M87-E(")F7W!A9&1I;F<B.@H)"0D)=&%B;&4N8V5L;%!A9&1I;F<@/2!V86P[
M"@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?8F]R9&5R<R(Z"@D)"0ET86)L
M92YB;W)D97(@/2!V86P["@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?9G)A
M;65S(CH*"0D)"71A8FQE+F9R86UE(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@
M("!C87-E(")F7W)U;&5S(CH*"0D)"71A8FQE+G)U;&5S(#T@=F%L.PH)"0D)
M8G)E86L["@D)"7T*"0E]"@D)+R\@=F%R:6]U<R!W;W)K87)O=6YD<R!T;R!R
M969R97-H('1H92!T86)L92!D:7-P;&%Y("A'96-K;RP*"0DO+R!W:&%T)W,@
M9V]I;F<@;VX_(2!D;R!N;W0@9&ES87!P;VEN="!M92$I"@D)9&EA;&]G+F5D
M:71O<BYF;W)C95)E9')A=R@I.PH)"61I86QO9RYE9&ET;W(N9F]C=7-%9&ET
M;W(H*3L*"0ED:6%L;V<N961I=&]R+G5P9&%T951O;VQB87(H*3L*"0EV87(@
M<V%V95]C;VQL87!S92`]('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E.PH)
M"71A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@(F-O;&QA<'-E(CL*"0ET
M86)L92YS='EL92YB;W)D97)#;VQL87!S92`](")S97!A<F%T92(["@D)=&%B
M;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2!S879E7V-O;&QA<'-E.PH)?2P*
M"@DO+R!T:&ES(&9U;F-T:6]N(&=E=',@8V%L;&5D('=H96X@=&AE(&1I86QO
M9R!N965D<R!T;R!B92!I;FET:6%L:7IE9`H)9G5N8W1I;VX@*&1I86QO9RD@
M>PH*"0EV87(@9E]C87!T:6]N(#T@(B(["@D)=F%R(&-A<&5L(#T@=&%B;&4N
M9V5T16QE;65N='-">51A9TYA;64H(F-A<'1I;VXB*5LP73L*"0EI9B`H8V%P
M96PI('L*"0D)9E]C87!T:6]N(#T@8V%P96PN:6YN97)(5$U,.PH)"7T*"0EV
M87(@9E]S=6UM87)Y(#T@=&%B;&4N<W5M;6%R>3L*"0EV87(@9E]W:61T:"`]
M('!A<G-E26YT*'1A8FQE+G-T>6QE+G=I9'1H*3L*"0EI<TYA3BAF7W=I9'1H
M*2`F)B`H9E]W:61T:"`]("(B*3L*"0EV87(@9E]U;FET(#T@+R4O+G1E<W0H
M=&%B;&4N<W1Y;&4N=VED=&@I(#\@)W!E<F-E;G0G(#H@)W!I>&5L<R<["@D)
M=F%R(&9?86QI9VX@/2!T86)L92YA;&EG;CL*"0EV87(@9E]S<&%C:6YG(#T@
M=&%B;&4N8V5L;%-P86-I;F<["@D)=F%R(&9?<&%D9&EN9R`]('1A8FQE+F-E
M;&Q0861D:6YG.PH)"79A<B!F7V)O<F1E<G,@/2!T86)L92YB;W)D97(["@D)
M=F%R(&9?9G)A;65S(#T@=&%B;&4N9G)A;64["@D)=F%R(&9?<G5L97,@/2!T
M86)L92YR=6QE<SL*"@D)9G5N8W1I;VX@<V5L96-T960H=F%L*2!["@D)"7)E
M='5R;B!V86P@/R`B('-E;&5C=&5D(B`Z("(B.PH)"7T["@H)"2\O(&1I86QO
M9R!C;VYT96YT<PH)"61I86QO9RYC;VYT96YT+G-T>6QE+G=I9'1H(#T@(C0P
M,'!X(CL*"0ED:6%L;V<N8V]N=&5N="YI;FYE<DA434P@/2`B(%P*/&1I=B!C
M;&%S<STG=&ET;&4G7`H@<W1Y;&4])V)A8VMG<F]U;F0Z('5R;"@B("L@9&EA
M;&]G+F)A<V554DP@*R!D:6%L;V<N961I=&]R+FEM9U523"@B=&%B;&4M<')O
M<"YG:68B+"`B5&%B;&5/<&5R871I;VYS(BD@*R`B*2`C9F9F(#DX)2`U,"4@
M;F\M<F5P96%T)SXB("L@:3$X;ELB5&%B;&4@4')O<&5R=&EE<R)=("L@(EP*
M/"]D:78^(%P*/'1A8FQE('-T>6QE/2=W:61T:#HQ,#`E)SX@7`H@(#QT<CX@
M7`H@("`@/'1D/B!<"B`@("`@(#QF:65L9'-E=#X\;&5G96YD/B(@*R!I,3AN
M6R)$97-C<FEP=&EO;B)=("L@(CPO;&5G96YD/B!<"B`@("`@("`\=&%B;&4@
M<W1Y;&4])W=I9'1H.C$P,"4G/B!<"B`@("`@("`@/'1R/B!<"B`@("`@("`@
M("`\=&0@8VQA<W,])VQA8F5L)SXB("L@:3$X;ELB0V%P=&EO;B)=("L@(CH\
M+W1D/B!<"B`@("`@("`@("`\=&0@8VQA<W,])W9A;'5E)SX\:6YP=70@='EP
M93TG=&5X="<@;F%M93TG9E]C87!T:6]N)R!V86QU93TG(B`K(&9?8V%P=&EO
M;B`K("(G+SX\+W1D/B!<"B`@("`@("`@/"]T<CX\='(^(%P*("`@("`@("`@
M(#QT9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)3=6UM87)Y(ET@*R`B.CPO
M=&0^(%P*("`@("`@("`@(#QT9"!C;&%S<STG=F%L=64G/CQI;G!U="!T>7!E
M/2=T97AT)R!N86UE/2=F7W-U;6UA<GDG('9A;'5E/2<B("L@9E]S=6UM87)Y
M("L@(B<O/CPO=&0^(%P*("`@("`@("`\+W1R/B!<"B`@("`@("`\+W1A8FQE
M/B!<"B`@("`@(#PO9FEE;&1S970^(%P*("`@(#PO=&0^(%P*("`\+W1R/B!<
M"B`@/'1R/CQT9"!I9#TG+2U(02UL87EO=70G/CPO=&0^/"]T<CX@7`H@(#QT
M<CX@7`H@("`@/'1D/B!<"B`@("`@(#QF:65L9'-E=#X\;&5G96YD/B(@*R!I
M,3AN6R)3<&%C:6YG(&%N9"!P861D:6YG(ET@*R`B/"]L96=E;F0^(%P*("`@
M("`@(#QT86)L92!S='EL93TG=VED=&@Z,3`P)2<^(%P*("`@("`@("`\='(^
M(%P*("`@("`@("`@(#QT9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)3<&%C
M:6YG(ET@*R`B.CPO=&0^(%P*("`@("`@("`@(#QT9#X\:6YP=70@='EP93TG
M=&5X="<@;F%M93TG9E]S<&%C:6YG)R!S:7IE/2<U)R!V86QU93TG(B`K(&9?
M<W!A8VEN9R`K("(G("\^("9N8G-P.R(@*R!I,3AN6R)0861D:6YG(ET@*R`B
M.EP*("`@("`@("`@("`@/&EN<'5T('1Y<&4])W1E>'0G(&YA;64])V9?<&%D
M9&EN9R<@<VEZ93TG-2<@=F%L=64])R(@*R!F7W!A9&1I;F<@*R`B)R`O/B`F
M;F)S<#LF;F)S<#LB("L@:3$X;ELB<&EX96QS(ET@*R`B7`H@("`@("`@("`@
M/"]T9#X@7`H@("`@("`@(#PO='(^(%P*("`@("`@(#PO=&%B;&4^(%P*("`@
M("`@/"]F:65L9'-E=#X@7`H@("`@/"]T9#X@7`H@(#PO='(^(%P*("`\='(^
M(%P*("`@(#QT9#X@7`H@("`@("`\9FEE;&1S970^/&QE9V5N9#Y&<F%M92!A
M;F0@8F]R9&5R<SPO;&5G96YD/B!<"B`@("`@("`@/'1A8FQE('=I9'1H/2<Q
M,#`E)SX@7`H@("`@("`@("`@/'1R/B!<"B`@("`@("`@("`@(#QT9"!C;&%S
M<STG;&%B96PG/B(@*R!I,3AN6R)";W)D97)S(ET@*R`B.CPO=&0^(%P*("`@
M("`@("`@("`@/'1D/CQI;G!U="!N86UE/2=F7V)O<F1E<G,G('1Y<&4])W1E
M>'0G('-I>F4])S4G('9A;'5E/2<B("L@9E]B;W)D97)S("L@(B<@+SX@)FYB
M<W`[)FYB<W`[(B`K(&DQ.&Y;(G!I>&5L<R)=("L@(CPO=&0^(%P*("`@("`@
M("`@(#PO='(^(%P*("`@("`@("`@(#QT<CX@7`H@("`@("`@("`@("`\=&0@
M8VQA<W,])VQA8F5L)SXB("L@:3$X;ELB1G)A;65S(ET@*R`B.CPO=&0^(%P*
M("`@("`@("`@("`@/'1D/B!<"B`@("`@("`@("`@("`@/'-E;&5C="!N86UE
M/2=F7V9R86UE<R<^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64]
M)W9O:60G(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")V;VED(BD@*R`B/B(@
M*R!I,3AN6R).;R!S:61E<R)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2=A8F]V92<B("L@<V5L96-T960H9E]F<F%M
M97,@/3T@(F%B;W9E(BD@*R`B/B(@*R!I,3AN6R)4:&4@=&]P('-I9&4@;VYL
M>2)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2=B96QO=R<B("L@<V5L96-T960H9E]F<F%M97,@/3T@(F)E;&]W(BD@
M*R`B/B(@*R!I,3AN6R)4:&4@8F]T=&]M('-I9&4@;VYL>2)=("L@(CPO;W!T
M:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=H<VED97,G
M(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")H<VED97,B*2`K("(^(B`K(&DQ
M.&Y;(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(ET@*R`B/"]O<'1I
M;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64])W9S:61E<R<B
M("L@<V5L96-T960H9E]F<F%M97,@/3T@(G9S:61E<R(I("L@(CXB("L@:3$X
M;ELB5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB72`K("(\+V]P=&EO
M;CX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG;&AS)R(@*R!S
M96QE8W1E9"AF7V9R86UE<R`]/2`B;&AS(BD@*R`B/B(@*R!I,3AN6R)4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2=R:',G(B`K('-E;&5C=&5D*&9?9G)A
M;65S(#T](")R:',B*2`K("(^(B`K(&DQ.&Y;(E1H92!R:6=H="UH86YD('-I
M9&4@;VYL>2)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2=B;W@G(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")B;W@B
M*2`K("(^(B`K(&DQ.&Y;(D%L;"!F;W5R('-I9&5S(ET@*R`B/"]O<'1I;VX^
M(%P*("`@("`@("`@("`@("`\+W-E;&5C=#X@7`H@("`@("`@("`@("`\+W1D
M/B!<"B`@("`@("`@("`\+W1R/B!<"B`@("`@("`@("`\='(^(%P*("`@("`@
M("`@("`@/'1D(&-L87-S/2=L86)E;"<^(B`K(&DQ.&Y;(E)U;&5S(ET@*R`B
M.CPO=&0^(%P*("`@("`@("`@("`@/'1D/B!<"B`@("`@("`@("`@("`@/'-E
M;&5C="!N86UE/2=F7W)U;&5S)SX@7`H@("`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TG;F]N92<B("L@<V5L96-T960H9E]R=6QE<R`]/2`B;F]N92(I
M("L@(CXB("L@:3$X;ELB3F\@<G5L97,B72`K("(\+V]P=&EO;CX@7`H@("`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG<F]W<R<B("L@<V5L96-T960H
M9E]R=6QE<R`]/2`B<F]W<R(I("L@(CXB("L@:3$X;ELB4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB72`K("(\+V]P=&EO;CX@7`H@("`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG8V]L<R<B("L@<V5L96-T960H
M9E]R=6QE<R`]/2`B8V]L<R(I("L@(CXB("L@:3$X;ELB4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB72`K("(\+V]P=&EO;CX@7`H@
M("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG86QL)R(@*R!S96QE8W1E
M9"AF7W)U;&5S(#T](")A;&PB*2`K("(^(B`K(&DQ.&Y;(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B72`K("(\+V]P
M=&EO;CX@7`H@("`@("`@("`@("`@(#PO<V5L96-T/B!<"B`@("`@("`@("`@
M(#PO=&0^(%P*("`@("`@("`@(#PO='(^(%P*("`@("`@("`\+W1A8FQE/B!<
M"B`@("`@(#PO9FEE;&1S970^(%P*("`@(#PO=&0^(%P*("`\+W1R/B!<"B`@
M/'1R/B!<"B`@("`\=&0@:60])RTM2$$M<W1Y;&4G/CPO=&0^(%P*("`\+W1R
M/B!<"CPO=&%B;&4^(%P*(CL*"0EV87(@<W1?<')O<"`](%1A8FQE3W!E<F%T
M:6]N<RYC<F5A=&53='EL949I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO9RYE
M9&ET;W(L('1A8FQE*3L*"0EV87(@<"`](&1I86QO9RYD;V,N9V5T16QE;65N
M=$)Y260H(BTM2$$M<W1Y;&4B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7W!R;W`I
M.PH)"79A<B!S=%]L87EO=70@/2!486)L94]P97)A=&EO;G,N8W)E871E4W1Y
M;&5,87EO=71&:65L9'-E="AD:6%L;V<N9&]C+"!D:6%L;V<N961I=&]R+"!T
M86)L92D["@D)<"`](&1I86QO9RYD;V,N9V5T16QE;65N=$)Y260H(BTM2$$M
M;&%Y;W5T(BD["@D)<"YA<'!E;F1#:&EL9"AS=%]L87EO=70I.PH)"61I86QO
M9RYM;V1A;"`]('1R=64["@D)9&EA;&]G+F%D9$)U='1O;G,H(F]K(BP@(F-A
M;F-E;"(I.PH)"61I86QO9RYS:&]W071%;&5M96YT*&1I86QO9RYE9&ET;W(N
M7VEF<F%M92P@(F,B*3L*"7TI.PI].PH*+R\@=&AI<R!F=6YC=&EO;B!R97%U
M:7)E<R!T:&4@9FEL92!0;W!U<$1I=B]0;W!U<%=I;B!T;R!B92!L;V%D960@
M9G)O;2!B<F]W<V5R"E1A8FQE3W!E<F%T:6]N<RYP<F]T;W1Y<&4N9&EA;&]G
M4F]W0V5L;%!R;W!E<G1I97,@/2!F=6YC=&EO;BAC96QL*2!["@EV87(@:3$X
M;B`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH)+R\@<F5T<FEE=F4@97AI<W1I
M;F<@=F%L=65S"@EV87(@96QE;65N="`]('1H:7,N9V5T0VQO<V5S="AC96QL
M(#\@(G1D(B`Z(")T<B(I.PH)=F%R('1A8FQE(#T@=&AI<RYG971#;&]S97-T
M*")T86)L92(I.PH)+R\@=&AI<RYE9&ET;W(N<V5L96-T3F]D94-O;G1E;G1S
M*&5L96UE;G0I.PH)+R\@=&AI<RYE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH*
M"79A<B!D:6%L;V<@/2!N97<@4&]P=7!7:6XH=&AI<RYE9&ET;W(L(&DQ.&Y;
M8V5L;"`_(")#96QL(%!R;W!E<G1I97,B(#H@(E)O=R!0<F]P97)T:65S(ETL
M(&9U;F-T:6]N*&1I86QO9RP@<&%R86US*2!["@D)5&%B;&5/<&5R871I;VYS
M+G!R;V-E<W-3='EL92AP87)A;7,L(&5L96UE;G0I.PH)"69O<B`H=F%R(&D@
M:6X@<&%R86US*2!["@D)"79A<B!V86P@/2!P87)A;7-;:5T["@D)"7-W:71C
M:"`H:2D@>PH)"0D@("`@8V%S92`B9E]A;&EG;B(Z"@D)"0EE;&5M96YT+F%L
M:6=N(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C87-E(")F7V-H87(B.@H)
M"0D)96QE;65N="YC:"`]('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B
M9E]V86QI9VXB.@H)"0D)96QE;65N="YV06QI9VX@/2!V86P["@D)"0EB<F5A
M:SL*"0D)?0H)"7T*"0DO+R!V87)I;W5S('=O<FMA<F]U;F1S('1O(')E9G)E
M<V@@=&AE('1A8FQE(&1I<W!L87D@*$=E8VMO+`H)"2\O('=H870G<R!G;VEN
M9R!O;C\A(&1O(&YO="!D:7-A<'!O:6YT(&UE(2D*"0ED:6%L;V<N961I=&]R
M+F9O<F-E4F5D<F%W*"D["@D)9&EA;&]G+F5D:71O<BYF;V-U<T5D:71O<B@I
M.PH)"61I86QO9RYE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"79A<B!S879E
M7V-O;&QA<'-E(#T@=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4["@D)=&%B
M;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2`B8V]L;&%P<V4B.PH)"71A8FQE
M+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@(G-E<&%R871E(CL*"0ET86)L92YS
M='EL92YB;W)D97)#;VQL87!S92`]('-A=F5?8V]L;&%P<V4["@E]+`H*"2\O
M('1H:7,@9G5N8W1I;VX@9V5T<R!C86QL960@=VAE;B!T:&4@9&EA;&]G(&YE
M961S('1O(&)E(&EN:71I86QI>F5D"@EF=6YC=&EO;B`H9&EA;&]G*2!["@H)
M"79A<B!F7V%L:6=N(#T@96QE;65N="YA;&EG;CL*"0EV87(@9E]V86QI9VX@
M/2!E;&5M96YT+G9!;&EG;CL*"0EV87(@9E]C:&%R(#T@96QE;65N="YC:#L*
M"@D)9G5N8W1I;VX@<V5L96-T960H=F%L*2!["@D)"7)E='5R;B!V86P@/R`B
M('-E;&5C=&5D(B`Z("(B.PH)"7T["@H)"2\O(&1I86QO9R!C;VYT96YT<PH)
M"61I86QO9RYC;VYT96YT+G-T>6QE+G=I9'1H(#T@(C0P,'!X(CL*"0ED:6%L
M;V<N8V]N=&5N="YI;FYE<DA434P@/2`B(%P*/&1I=B!C;&%S<STG=&ET;&4G
M7`H@<W1Y;&4])V)A8VMG<F]U;F0Z('5R;"@B("L@9&EA;&]G+F)A<V554DP@
M*R!D:6%L;V<N961I=&]R+FEM9U523"AC96QL(#\@(F-E;&PM<')O<"YG:68B
M(#H@(G)O=RUP<F]P+F=I9B(L(")486)L94]P97)A=&EO;G,B*2`K("(I("-F
M9F8@.3@E(#4P)2!N;RUR97!E870G/B(@*R!I,3AN6V-E;&P@/R`B0V5L;"!0
M<F]P97)T:65S(B`Z(")2;W<@4')O<&5R=&EE<R)=("L@(CPO9&EV/B!<"CQT
M86)L92!S='EL93TG=VED=&@Z,3`P)2<^(%P*("`\='(^(%P*("`@(#QT9"!I
M9#TG+2U(02UL87EO=70G/B!<"B`@("`\+W1D/B!<"B`@/"]T<CX@7`H@(#QT
M<CX@7`H@("`@/'1D(&ED/2<M+4A!+7-T>6QE)SX\+W1D/B!<"B`@/"]T<CX@
M7`H\+W1A8FQE/B!<"B(["@D)=F%R('-T7W!R;W`@/2!486)L94]P97)A=&EO
M;G,N8W)E871E4W1Y;&5&:65L9'-E="AD:6%L;V<N9&]C+"!D:6%L;V<N961I
M=&]R+"!E;&5M96YT*3L*"0EV87(@<"`](&1I86QO9RYD;V,N9V5T16QE;65N
M=$)Y260H(BTM2$$M<W1Y;&4B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7W!R;W`I
M.PH)"79A<B!S=%]L87EO=70@/2!486)L94]P97)A=&EO;G,N8W)E871E4W1Y
M;&5,87EO=71&:65L9'-E="AD:6%L;V<N9&]C+"!D:6%L;V<N961I=&]R+"!E
M;&5M96YT*3L*"0EP(#T@9&EA;&]G+F1O8RYG971%;&5M96YT0GE)9"@B+2U(
M02UL87EO=70B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7VQA>6]U="D["@D)9&EA
M;&]G+FUO9&%L(#T@=')U93L*"0ED:6%L;V<N861D0G5T=&]N<R@B;VLB+"`B
M8V%N8V5L(BD["@D)9&EA;&]G+G-H;W=!=$5L96UE;G0H9&EA;&]G+F5D:71O
M<BY?:69R86UE+"`B8R(I.PH)?2D["GT["@HO+R!T:&ES(&9U;F-T:6]N(&=E
M=',@8V%L;&5D('=H96X@<V]M92!B=71T;VX@9G)O;2!T:&4@5&%B;&5/<&5R
M871I;VYS('1O;VQB87(*+R\@=V%S('!R97-S960N"E1A8FQE3W!E<F%T:6]N
M<RYP<F]T;W1Y<&4N8G5T=&]N4')E<W,@/2!F=6YC=&EO;BAE9&ET;W(L(&)U
M='1O;E]I9"D@>PH)=&AI<RYE9&ET;W(@/2!E9&ET;W(["@EV87(@;6]Z8G(@
M/2!(5$U,07)E82YI<U]G96-K;R`_("(\8G(@+SXB(#H@(B(["@EV87(@:3$X
M;B`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH*"2\O(&AE;'!E<B!F=6YC=&EO
M;B!T:&%T(&-L96%R<R!T:&4@8V]N=&5N="!I;B!A('1A8FQE(')O=PH)9G5N
M8W1I;VX@8VQE87)2;W<H='(I('L*"0EV87(@=&1S(#T@='(N9V5T16QE;65N
M='-">51A9TYA;64H(G1D(BD["@D)9F]R("AV87(@:2`]('1D<RYL96YG=&@[
M("TM:2`^/2`P.RD@>PH)"0EV87(@=&0@/2!T9'-;:5T["@D)"71D+G)O=U-P
M86X@/2`Q.PH)"0ET9"YI;FYE<DA434P@/2!M;WIB<CL*"0E]"@E].PH*"69U
M;F-T:6]N('-P;&ET4F]W*'1D*2!["@D)=F%R(&X@/2!P87)S94EN="@B(B`K
M('1D+G)O=U-P86XI.PH)"79A<B!N8R`]('!A<G-E26YT*"(B("L@=&0N8V]L
M4W!A;BD["@D)=&0N<F]W4W!A;B`](#$["@D)='(@/2!T9"YP87)E;G1.;V1E
M.PH)"79A<B!I='(@/2!T<BYR;W=);F1E>#L*"0EV87(@=')S(#T@='(N<&%R
M96YT3F]D92YR;W=S.PH)"79A<B!I;F1E>"`]('1D+F-E;&Q);F1E>#L*"0EW
M:&EL92`H+2UN(#X@,"D@>PH)"0ET<B`]('1R<ULK*VET<ET["@D)"79A<B!O
M=&0@/2!E9&ET;W(N7V1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"0EO=&0N
M8V]L4W!A;B`]('1D+F-O;%-P86X["@D)"6]T9"YI;FYE<DA434P@/2!M;WIB
M<CL*"0D)='(N:6YS97)T0F5F;W)E*&]T9"P@='(N8V5L;'-;:6YD97A=*3L*
M"0E]"@D)961I=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+G5P9&%T951O
M;VQB87(H*3L*"7T["@H)9G5N8W1I;VX@<W!L:71#;VPH=&0I('L*"0EV87(@
M;F,@/2!P87)S94EN="@B(B`K('1D+F-O;%-P86XI.PH)"71D+F-O;%-P86X@
M/2`Q.PH)"71R(#T@=&0N<&%R96YT3F]D93L*"0EV87(@<F5F(#T@=&0N;F5X
M=%-I8FQI;F<["@D)=VAI;&4@*"TM;F,@/B`P*2!["@D)"79A<B!O=&0@/2!E
M9&ET;W(N7V1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"0EO=&0N<F]W4W!A
M;B`]('1D+G)O=U-P86X["@D)"6]T9"YI;FYE<DA434P@/2!M;WIB<CL*"0D)
M='(N:6YS97)T0F5F;W)E*&]T9"P@<F5F*3L*"0E]"@D)961I=&]R+F9O<F-E
M4F5D<F%W*"D["@D)961I=&]R+G5P9&%T951O;VQB87(H*3L*"7T["@H)9G5N
M8W1I;VX@<W!L:71#96QL*'1D*2!["@D)=F%R(&YC(#T@<&%R<V5);G0H(B(@
M*R!T9"YC;VQ3<&%N*3L*"0ES<&QI=$-O;"AT9"D["@D)=F%R(&ET96US(#T@
M=&0N<&%R96YT3F]D92YC96QL<SL*"0EV87(@:6YD97@@/2!T9"YC96QL26YD
M97@["@D)=VAI;&4@*&YC+2T@/B`P*2!["@D)"7-P;&ET4F]W*&ET96US6VEN
M9&5X*RM=*3L*"0E]"@E].PH*"69U;F-T:6]N('-E;&5C=$YE>'1.;V1E*&5L
M*2!["@D)=F%R(&YO9&4@/2!E;"YN97AT4VEB;&EN9SL*"0EW:&EL92`H;F]D
M92`F)B!N;V1E+FYO9&54>7!E("$](#$I('L*"0D);F]D92`](&YO9&4N;F5X
M=%-I8FQI;F<["@D)?0H)"6EF("@A;F]D92D@>PH)"0EN;V1E(#T@96PN<')E
M=FEO=7-3:6)L:6YG.PH)"0EW:&EL92`H;F]D92`F)B!N;V1E+FYO9&54>7!E
M("$](#$I('L*"0D)"6YO9&4@/2!N;V1E+G!R979I;W5S4VEB;&EN9SL*"0D)
M?0H)"7T*"0EI9B`H(6YO9&4I('L*"0D);F]D92`](&5L+G!A<F5N=$YO9&4[
M"@D)?0H)"65D:71O<BYS96QE8W1.;V1E0V]N=&5N=',H;F]D92D["@E].PH*
M"7-W:71C:"`H8G5T=&]N7VED*2!["@D)+R\@4D]74PH*"2`@("!C87-E(")4
M3RUR;W<M:6YS97)T+6%B;W9E(CH*"2`@("!C87-E(")43RUR;W<M:6YS97)T
M+75N9&5R(CH*"0EV87(@='(@/2!T:&ES+F=E=$-L;W-E<W0H(G1R(BD["@D)
M:68@*"%T<BD@>PH)"0EB<F5A:SL*"0E]"@D)=F%R(&]T<B`]('1R+F-L;VYE
M3F]D92AT<G5E*3L*"0EC;&5A<E)O=RAO='(I.PH)"71R+G!A<F5N=$YO9&4N
M:6YS97)T0F5F;W)E*&]T<BP@+W5N9&5R+RYT97-T*&)U='1O;E]I9"D@/R!T
M<BYN97AT4VEB;&EN9R`Z('1R*3L*"0EE9&ET;W(N9F]R8V52961R87<H*3L*
M"0EE9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")4
M3RUR;W<M9&5L971E(CH*"0EV87(@='(@/2!T:&ES+F=E=$-L;W-E<W0H(G1R
M(BD["@D):68@*"%T<BD@>PH)"0EB<F5A:SL*"0E]"@D)=F%R('!A<B`]('1R
M+G!A<F5N=$YO9&4["@D):68@*'!A<BYR;W=S+FQE;F=T:"`]/2`Q*2!["@D)
M"6%L97)T*&DQ.&Y;(FYO="UD96PM;&%S="UR;W<B72D["@D)"6)R96%K.PH)
M"7T*"0DO+R!S970@=&AE(&-A<F5T(&9I<G-T('1O(&$@<&]S:71I;VX@=&AA
M="!D;V5S;B=T"@D)+R\@9&ES87!P96%R+@H)"7-E;&5C=$YE>'1.;V1E*'1R
M*3L*"0EP87(N<F5M;W9E0VAI;&0H='(I.PH)"65D:71O<BYF;W)C95)E9')A
M=R@I.PH)"65D:71O<BYF;V-U<T5D:71O<B@I.PH)"65D:71O<BYU<&1A=&54
M;V]L8F%R*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M<F]W+7-P;&ET(CH*
M"0EV87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D):68@*"%T9"D@
M>PH)"0EB<F5A:SL*"0E]"@D)<W!L:712;W<H=&0I.PH)"6)R96%K.PH*"0DO
M+R!#3TQ534Y3"@H)("`@(&-A<V4@(E1/+6-O;"UI;G-E<G0M8F5F;W)E(CH*
M"2`@("!C87-E(")43RUC;VPM:6YS97)T+6%F=&5R(CH*"0EV87(@=&0@/2!T
M:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D):68@*"%T9"D@>PH)"0EB<F5A:SL*
M"0E]"@D)=F%R(')O=W,@/2!T9"YP87)E;G1.;V1E+G!A<F5N=$YO9&4N<F]W
M<SL*"0EV87(@:6YD97@@/2!T9"YC96QL26YD97@["@D)9F]R("AV87(@:2`]
M(')O=W,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)=F%R('1R(#T@<F]W<UMI
M73L*"0D)=F%R(')E9B`]('1R+F-E;&QS6VEN9&5X("L@*"]A9G1E<B\N=&5S
M="AB=71T;VY?:60I(#\@,2`Z(#`I73L*"0D)=F%R(&]T9"`](&5D:71O<BY?
M9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6]T9"YI;FYE<DA434P@/2!M
M;WIB<CL*"0D)='(N:6YS97)T0F5F;W)E*&]T9"P@<F5F*3L*"0E]"@D)961I
M=&]R+F9O8W5S161I=&]R*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V]L
M+7-P;&ET(CH*"0EV87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D)
M:68@*"%T9"D@>PH)"0EB<F5A:SL*"0E]"@D)<W!L:71#;VPH=&0I.PH)"6)R
M96%K.PH)("`@(&-A<V4@(E1/+6-O;"UD96QE=&4B.@H)"79A<B!T9"`]('1H
M:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D*2!["@D)"6)R96%K.PH)
M"7T*"0EV87(@:6YD97@@/2!T9"YC96QL26YD97@["@D):68@*'1D+G!A<F5N
M=$YO9&4N8V5L;',N;&5N9W1H(#T](#$I('L*"0D)86QE<G0H:3$X;ELB;F]T
M+61E;"UL87-T+6-O;")=*3L*"0D)8G)E86L["@D)?0H)"2\O('-E="!T:&4@
M8V%R970@9FER<W0@=&\@82!P;W-I=&EO;B!T:&%T(&1O97-N)W0@9&ES87!P
M96%R"@D)<V5L96-T3F5X=$YO9&4H=&0I.PH)"79A<B!R;W=S(#T@=&0N<&%R
M96YT3F]D92YP87)E;G1.;V1E+G)O=W,["@D)9F]R("AV87(@:2`](')O=W,N
M;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)=F%R('1R(#T@<F]W<UMI73L*"0D)
M='(N<F5M;W9E0VAI;&0H='(N8V5L;'-;:6YD97A=*3L*"0E]"@D)961I=&]R
M+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+F9O8W5S161I=&]R*"D["@D)961I
M=&]R+G5P9&%T951O;VQB87(H*3L*"0EB<F5A:SL*"@D)+R\@0T5,3%,*"@D@
M("`@8V%S92`B5$\M8V5L;"US<&QI="(Z"@D)=F%R('1D(#T@=&AI<RYG971#
M;&]S97-T*")T9"(I.PH)"6EF("@A=&0I('L*"0D)8G)E86L["@D)?0H)"7-P
M;&ET0V5L;"AT9"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V5L;"UI;G-E
M<G0M8F5F;W)E(CH*"2`@("!C87-E(")43RUC96QL+6EN<V5R="UA9G1E<B(Z
M"@D)=F%R('1D(#T@=&AI<RYG971#;&]S97-T*")T9"(I.PH)"6EF("@A=&0I
M('L*"0D)8G)E86L["@D)?0H)"79A<B!T<B`]('1D+G!A<F5N=$YO9&4["@D)
M=F%R(&]T9"`](&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)
M;W1D+FEN;F5R2%1-3"`](&UO>F)R.PH)"71R+FEN<V5R=$)E9F]R92AO=&0L
M("]A9G1E<B\N=&5S="AB=71T;VY?:60I(#\@=&0N;F5X=%-I8FQI;F<@.B!T
M9"D["@D)961I=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+F9O8W5S161I
M=&]R*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V5L;"UD96QE=&4B.@H)
M"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D*2![
M"@D)"6)R96%K.PH)"7T*"0EI9B`H=&0N<&%R96YT3F]D92YC96QL<RYL96YG
M=&@@/3T@,2D@>PH)"0EA;&5R="AI,3AN6R)N;W0M9&5L+6QA<W0M8V5L;")=
M*3L*"0D)8G)E86L["@D)?0H)"2\O('-E="!T:&4@8V%R970@9FER<W0@=&\@
M82!P;W-I=&EO;B!T:&%T(&1O97-N)W0@9&ES87!P96%R"@D)<V5L96-T3F5X
M=$YO9&4H=&0I.PH)"71D+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H=&0I.PH)
M"65D:71O<BYF;W)C95)E9')A=R@I.PH)"65D:71O<BYU<&1A=&54;V]L8F%R
M*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V5L;"UM97)G92(Z"@D)+R\@
M(2$@1DE8344Z($UO>FEL;&$@<W!E8VEF:6,@(2$*"0EV87(@<V5L(#T@961I
M=&]R+E]G971396QE8W1I;VXH*3L*"0EV87(@<F%N9V4L(&D@/2`P.PH)"79A
M<B!R;W=S(#T@6UT["@D)=F%R(')O=R`](&YU;&P["@D)=F%R(&-E;&QS(#T@
M;G5L;#L*"0EI9B`H(4A434Q!<F5A+FES7VEE*2!["@D)"71R>2!["@D)"0EW
M:&EL92`H<F%N9V4@/2!S96PN9V5T4F%N9V5!="AI*RLI*2!["@D)"0D)=F%R
M('1D(#T@<F%N9V4N<W1A<G1#;VYT86EN97(N8VAI;&1.;V1E<UMR86YG92YS
M=&%R=$]F9G-E=%T["@D)"0D):68@*'1D+G!A<F5N=$YO9&4@(3T@<F]W*2![
M"@D)"0D)"7)O=R`]('1D+G!A<F5N=$YO9&4["@D)"0D)"2AC96QL<RD@)B8@
M<F]W<RYP=7-H*&-E;&QS*3L*"0D)"0D)8V5L;',@/2!;73L*"0D)"0E]"@D)
M"0D)8V5L;',N<'5S:"AT9"D["@D)"0E]"@D)"7T@8V%T8V@H92D@>R\J(&9I
M;FES:&5D('=A;&MI;F<@=&AR;W5G:"!S96QE8W1I;VX@*B]]"@D)"7)O=W,N
M<'5S:"AC96QL<RD["@D)?2!E;'-E('L*"0D)+R\@26YT97)N970@17AP;&]R
M97(@(F)R;W=S97(B"@D)"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B
M*3L*"0D):68@*"%T9"D@>PH)"0D)86QE<G0H:3$X;ELB4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL(ETI.PH)"0D)8G)E86L["@D)"7T*"0D)=F%R('1R
M(#T@=&0N<&%R96YT16QE;65N=#L*"0D)=F%R(&YO7V-O;',@/2!P<F]M<'0H
M:3$X;ELB2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B72P@,BD["@D)"6EF("@A;F]?8V]L<RD@>PH)"0D)+R\@8V%N8V5L;&5D
M"@D)"0EB<F5A:SL*"0D)?0H)"0EV87(@;F]?<F]W<R`]('!R;VUP="AI,3AN
M6R)(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R)=+"`R
M*3L*"0D):68@*"%N;U]R;W=S*2!["@D)"0DO+R!C86YC96QL960*"0D)"6)R
M96%K.PH)"0E]"@D)"79A<B!C96QL7VEN9&5X(#T@=&0N8V5L;$EN9&5X.PH)
M"0EW:&EL92`H;F]?<F]W<RTM(#X@,"D@>PH)"0D)=&0@/2!T<BYC96QL<UMC
M96QL7VEN9&5X73L*"0D)"6-E;&QS(#T@6W1D73L*"0D)"69O<B`H=F%R(&D@
M/2`Q.R!I(#P@;F]?8V]L<SL@*RMI*2!["@D)"0D)=&0@/2!T9"YN97AT4VEB
M;&EN9SL*"0D)"0EI9B`H(71D*2!["@D)"0D)"6)R96%K.PH)"0D)"7T*"0D)
M"0EC96QL<RYP=7-H*'1D*3L*"0D)"7T*"0D)"7)O=W,N<'5S:"AC96QL<RD[
M"@D)"0ET<B`]('1R+FYE>'13:6)L:6YG.PH)"0D):68@*"%T<BD@>PH)"0D)
M"6)R96%K.PH)"0D)?0H)"0E]"@D)?0H)"79A<B!(5$U,(#T@(B(["@D)9F]R
M("AI(#T@,#L@:2`\(')O=W,N;&5N9W1H.R`K*VDI('L*"0D)+R\@:2`F)B`H
M2%1-3"`K/2`B/&)R("\^(BD["@D)"79A<B!C96QL<R`](')O=W-;:5T["@D)
M"69O<B`H=F%R(&H@/2`P.R!J(#P@8V5L;',N;&5N9W1H.R`K*VHI('L*"0D)
M"2\O(&H@)B8@*$A434P@*ST@(B9N8G-P.R(I.PH)"0D)=F%R(&-E;&P@/2!C
M96QL<UMJ73L*"0D)"4A434P@*ST@8V5L;"YI;FYE<DA434P["@D)"0DH:2!\
M?"!J*2`F)B`H8V5L;"YP87)E;G1.;V1E+G)E;6]V94-H:6QD*&-E;&PI*3L*
M"0D)?0H)"7T*"0EV87(@=&0@/2!R;W=S6S!=6S!=.PH)"71D+FEN;F5R2%1-
M3"`]($A434P["@D)=&0N<F]W4W!A;B`](')O=W,N;&5N9W1H.PH)"71D+F-O
M;%-P86X@/2!R;W=S6S!=+FQE;F=T:#L*"0EE9&ET;W(N<V5L96-T3F]D94-O
M;G1E;G1S*'1D*3L*"0EE9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N
M9F]C=7-%9&ET;W(H*3L*"0EB<F5A:SL*"@D)+R\@4%)/4$525$E%4PH*"2`@
M("!C87-E(")43RUT86)L92UP<F]P(CH*"0ET:&ES+F1I86QO9U1A8FQE4')O
M<&5R=&EE<R@I.PH)"6)R96%K.PH*"2`@("!C87-E(")43RUR;W<M<')O<"(Z
M"@D)=&AI<RYD:6%L;V=2;W=#96QL4')O<&5R=&EE<RAF86QS92D["@D)8G)E
M86L["@H)("`@(&-A<V4@(E1/+6-E;&PM<')O<"(Z"@D)=&AI<RYD:6%L;V=2
M;W=#96QL4')O<&5R=&EE<RAT<G5E*3L*"0EB<F5A:SL*"@D@("`@9&5F875L
M=#H*"0EA;&5R="@B0G5T=&]N(%LB("L@8G5T=&]N7VED("L@(ET@;F]T('EE
M="!I;7!L96UE;G1E9"(I.PH)?0I].PH*+R\@=&AE(&QI<W0@;V8@8G5T=&]N
M<R!A9&1E9"!B>2!T:&ES('!L=6=I;@I486)L94]P97)A=&EO;G,N8G1N3&ES
M="`](%L*"2\O('1A8FQE('!R;W!E<G1I97,@8G5T=&]N"@E;(G1A8FQE+7!R
M;W`B+"`@("`@("`B=&%B;&4B72P*"6YU;&PL"0D)+R\@<V5P87)A=&]R"@H)
M+R\@4D]74PH)6R)R;W<M<')O<"(L("`@("`@("`@(G1R(ETL"@E;(G)O=RUI
M;G-E<G0M86)O=F4B+"`B='(B72P*"5LB<F]W+6EN<V5R="UU;F1E<B(L(")T
M<B)=+`H)6R)R;W<M9&5L971E(BP@("`@("`@(G1R(ETL"@E;(G)O=RUS<&QI
M="(L("`@("`@("`B=&1;<F]W4W!A;B$],5TB72P*"6YU;&PL"@H)+R\@0T],
M4PH)6R)C;VPM:6YS97)T+6)E9F]R92(L(")T9")=+`H)6R)C;VPM:6YS97)T
M+6%F=&5R(BP@(")T9")=+`H)6R)C;VPM9&5L971E(BP@("`@("`@(")T9")=
M+`H)6R)C;VPM<W!L:70B+"`@("`@("`@(")T9%MC;VQ3<&%N(3TQ72)=+`H)
M;G5L;"P*"@DO+R!#14Q,4PH)6R)C96QL+7!R;W`B+"`@("`@("`@("`B=&0B
M72P*"5LB8V5L;"UI;G-E<G0M8F5F;W)E(BP@(G1D(ETL"@E;(F-E;&PM:6YS
M97)T+6%F=&5R(BP@(")T9")=+`H)6R)C96QL+61E;&5T92(L("`@("`@("`B
M=&0B72P*"5LB8V5L;"UM97)G92(L("`@("`@("`@(G1R(ETL"@E;(F-E;&PM
M<W!L:70B+"`@("`@("`@(")T9%MC;VQ3<&%N(3TQ+')O=U-P86XA/3%=(ET*
M"5T["@H*"B\O+R\@1T5.15))0R!#3T1%(%MS='EL92!O9B!A;GD@96QE;65N
M=#L@=&AI<R!S:&]U;&0@8F4@;6]V960@:6YT;R!A('-E<&%R871E"B\O+R\@
M9FEL92!A<R!I="=L;"!B92!V97)Y('5S969U;%T*+R\O+R!"14=)3B!'14Y%
M4DE#($-/1$4@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*"E1A8FQE3W!E<F%T:6]N<RYG971,96YG=&@@
M/2!F=6YC=&EO;BAV86QU92D@>PH)=F%R(&QE;B`]('!A<G-E26YT*'9A;'5E
M*3L*"6EF("AI<TYA3BAL96XI*2!["@D);&5N(#T@(B(["@E]"@ER971U<FX@
M;&5N.PI].PH*+R\@07!P;&EE<R!T:&4@<W1Y;&4@9F]U;F0@:6X@(G!A<F%M
M<R(@=&\@=&AE(&=I=F5N(&5L96UE;G0N"E1A8FQE3W!E<F%T:6]N<RYP<F]C
M97-S4W1Y;&4@/2!F=6YC=&EO;BAP87)A;7,L(&5L96UE;G0I('L*"79A<B!S
M='EL92`](&5L96UE;G0N<W1Y;&4["@EF;W(@*'9A<B!I(&EN('!A<F%M<RD@
M>PH)"79A<B!V86P@/2!P87)A;7-;:5T["@D)<W=I=&-H("AI*2!["@D)("`@
M(&-A<V4@(F9?<W1?8F%C:V=R;W5N9$-O;&]R(CH*"0D)<W1Y;&4N8F%C:V=R
M;W5N9$-O;&]R(#T@=F%L.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]C
M;VQO<B(Z"@D)"7-T>6QE+F-O;&]R(#T@=F%L.PH)"0EB<F5A:SL*"0D@("`@
M8V%S92`B9E]S=%]B86-K9W)O=6YD26UA9V4B.@H)"0EI9B`H+UQ3+RYT97-T
M*'9A;"DI('L*"0D)"7-T>6QE+F)A8VMG<F]U;F1);6%G92`](")U<FPH(B`K
M('9A;"`K("(I(CL*"0D)?2!E;'-E('L*"0D)"7-T>6QE+F)A8VMG<F]U;F1)
M;6%G92`](")N;VYE(CL*"0D)?0H)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S
M=%]B;W)D97)7:61T:"(Z"@D)"7-T>6QE+F)O<F1E<E=I9'1H(#T@=F%L.PH)
M"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]B;W)D97)3='EL92(Z"@D)"7-T
M>6QE+F)O<F1E<E-T>6QE(#T@=F%L.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B
M9E]S=%]B;W)D97)#;VQO<B(Z"@D)"7-T>6QE+F)O<F1E<D-O;&]R(#T@=F%L
M.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]B;W)D97)#;VQL87!S92(Z
M"@D)"7-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@=F%L(#\@(F-O;&QA<'-E(B`Z
M("(B.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]W:61T:"(Z"@D)"6EF
M("@O7%,O+G1E<W0H=F%L*2D@>PH)"0D)<W1Y;&4N=VED=&@@/2!V86P@*R!P
M87)A;7-;(F9?<W1?=VED=&A5;FET(ET["@D)"7T@96QS92!["@D)"0ES='EL
M92YW:61T:"`]("(B.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T
M7VAE:6=H="(Z"@D)"6EF("@O7%,O+G1E<W0H=F%L*2D@>PH)"0D)<W1Y;&4N
M:&5I9VAT(#T@=F%L("L@<&%R86US6R)F7W-T7VAE:6=H=%5N:70B73L*"0D)
M?2!E;'-E('L*"0D)"7-T>6QE+FAE:6=H="`]("(B.PH)"0E]"@D)"6)R96%K
M.PH)"2`@("!C87-E(")F7W-T7W1E>'1!;&EG;B(Z"@D)"6EF("AV86P@/3T@
M(F-H87(B*2!["@D)"0EV87(@8V@@/2!P87)A;7-;(F9?<W1?=&5X=$%L:6=N
M0VAA<B)=.PH)"0D):68@*&-H(#T]("<B)RD@>PH)"0D)"6-H(#T@)UQ<(B<[
M"@D)"0E]"@D)"0ES='EL92YT97AT06QI9VX@/2`G(B<@*R!C:"`K("<B)SL*
M"0D)?2!E;'-E('L*"0D)"7-T>6QE+G1E>'1!;&EG;B`]('9A;#L*"0D)?0H)
M"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]V97)T:6-A;$%L:6=N(CH*"0D)
M<W1Y;&4N=F5R=&EC86Q!;&EG;B`]('9A;#L*"0D)8G)E86L["@D)("`@(&-A
M<V4@(F9?<W1?9FQO870B.@H)"0ES='EL92YC<W-&;&]A="`]('9A;#L*"0D)
M8G)E86L["B\O(`D)("`@(&-A<V4@(F9?<W1?;6%R9VEN(CH*+R\@"0D)<W1Y
M;&4N;6%R9VEN(#T@=F%L("L@(G!X(CL*+R\@"0D)8G)E86L["B\O(`D)("`@
M(&-A<V4@(F9?<W1?<&%D9&EN9R(Z"B\O(`D)"7-T>6QE+G!A9&1I;F<@/2!V
M86P@*R`B<'@B.PHO+R`)"0EB<F5A:SL*"0E]"@E]"GT["@HO+R!2971U<FYS
M(&%N($A434P@96QE;65N="!F;W(@82!W:61G970@=&AA="!A;&QO=W,@8V]L
M;W(@<V5L96-T:6]N+B`@5&AA="!I<RP*+R\@82!B=71T;VX@=&AA="!C;VYT
M86EN<R!T:&4@9VEV96X@8V]L;W(L(&EF(&%N>2P@86YD('=H96X@<')E<W-E
M9"!W:6QL('!O<'5P"B\O('1H92!S;V]N97(M;W(M;&%T97(M=&\M8F4M<F5W
M<FET=&5N('-E;&5C=%]C;VQO<BYH=&UL(&1I86QO9R!A;&QO=VEN9R!U<V5R
M"B\O('1O('-E;&5C="!S;VUE(&-O;&]R+B`@268@82!C;VQO<B!I<R!S96QE
M8W1E9"P@86X@:6YP=70@9FEE;&0@=VET:"!T:&4@;F%M90HO+R`B9E]S=%\B
M*VYA;64@=VEL;"!B92!U<&1A=&5D('=I=&@@=&AE(&-O;&]R('9A;'5E(&EN
M(",Q,C,T-38@9F]R;6%T+@I486)L94]P97)A=&EO;G,N8W)E871E0V]L;W)"
M=71T;VX@/2!F=6YC=&EO;BAD;V,L(&5D:71O<BP@8V]L;W(L(&YA;64I('L*
M"6EF("@A8V]L;W(I('L*"0EC;VQO<B`]("(B.PH)?2!E;'-E(&EF("@A+R,O
M+G1E<W0H8V]L;W(I*2!["@D)8V]L;W(@/2!(5$U,07)E82Y?8V]L;W)4;U)G
M8BAC;VQO<BD["@E]"@H)=F%R(&1F(#T@9&]C+F-R96%T945L96UE;G0H(G-P
M86XB*3L*(`EV87(@9FEE;&0@/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B
M*3L*"69I96QD+G1Y<&4@/2`B:&ED9&5N(CL*"61F+F%P<&5N9$-H:6QD*&9I
M96QD*3L*(`EF:65L9"YN86UE(#T@(F9?<W1?(B`K(&YA;64["@EF:65L9"YV
M86QU92`](&-O;&]R.PH)=F%R(&)U='1O;B`](&1O8RYC<F5A=&5%;&5M96YT
M*")S<&%N(BD["@EB=71T;VXN8VQA<W-.86UE(#T@(F)U='1O;D-O;&]R(CL*
M"61F+F%P<&5N9$-H:6QD*&)U='1O;BD["@EV87(@<W!A;B`](&1O8RYC<F5A
M=&5%;&5M96YT*")S<&%N(BD["@ES<&%N+F-L87-S3F%M92`](")C:&]O<V5R
M(CL*"2\O('-P86XN:6YN97)(5$U,(#T@(B9N8G-P.R9N8G-P.R9N8G-P.R9N
M8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R(["@ES<&%N+G-T>6QE+F)A8VMG<F]U
M;F1#;VQO<B`](&-O;&]R.PH)8G5T=&]N+F%P<&5N9$-H:6QD*'-P86XI.PH)
M8G5T=&]N+F]N;6]U<V5O=F5R(#T@9G5N8W1I;VXH*2![(&EF("@A=&AI<RYD
M:7-A8FQE9"D@>R!T:&ES+F-L87-S3F%M92`K/2`B(&)U='1O;D-O;&]R+6AI
M;&ET92([('U].PH)8G5T=&]N+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L@
M:68@*"%T:&ES+F1I<V%B;&5D*2![('1H:7,N8VQA<W-.86UE(#T@(F)U='1O
M;D-O;&]R(CL@?7T["@ES<&%N+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*"0EI
M9B`H=&AI<RYP87)E;G1.;V1E+F1I<V%B;&5D*2!["@D)"7)E='5R;B!F86QS
M93L*"0E]"@D)961I=&]R+E]P;W!U<$1I86QO9R@B<V5L96-T7V-O;&]R+FAT
M;6PB+"!F=6YC=&EO;BAC;VQO<BD@>PH)"0EI9B`H8V]L;W(I('L*"0D)"7-P
M86XN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@(B,B("L@8V]L;W(["@D)"0EF
M:65L9"YV86QU92`]("(C(B`K(&-O;&]R.PH)"0E]"@D)?2P@8V]L;W(I.PH)
M?3L*"79A<B!S<&%N,B`](&1O8RYC<F5A=&5%;&5M96YT*")S<&%N(BD["@ES
M<&%N,BYI;FYE<DA434P@/2`B)B-X,#!D-SLB.PH)<W!A;C(N8VQA<W-.86UE
M(#T@(FYO8V]L;W(B.PH)<W!A;C(N=&ET;&4@/2!486)L94]P97)A=&EO;G,N
M23$X3ELB56YS970@8V]L;W(B73L*"6)U='1O;BYA<'!E;F1#:&EL9"AS<&%N
M,BD["@ES<&%N,BYO;FUO=7-E;W9E<B`](&9U;F-T:6]N*"D@>R!I9B`H(71H
M:7,N<&%R96YT3F]D92YD:7-A8FQE9"D@>R!T:&ES+F-L87-S3F%M92`K/2`B
M(&YO8V]L;W(M:&EL:71E(CL@?7T["@ES<&%N,BYO;FUO=7-E;W5T(#T@9G5N
M8W1I;VXH*2![(&EF("@A=&AI<RYP87)E;G1.;V1E+F1I<V%B;&5D*2![('1H
M:7,N8VQA<W-.86UE(#T@(FYO8V]L;W(B.R!]?3L*"7-P86XR+F]N8VQI8VL@
M/2!F=6YC=&EO;B@I('L*"0ES<&%N+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`]
M("(B.PH)"69I96QD+G9A;'5E(#T@(B(["@E].PH)<F5T=7)N(&1F.PI].PH*
M5&%B;&5/<&5R871I;VYS+F-R96%T95-T>6QE3&%Y;W5T1FEE;&1S970@/2!F
M=6YC=&EO;BAD;V,L(&5D:71O<BP@96PI('L*"79A<B!I,3AN(#T@5&%B;&5/
M<&5R871I;VYS+DDQ.$X["@EV87(@9FEE;&1S970@/2!D;V,N8W)E871E16QE
M;65N="@B9FEE;&1S970B*3L*"79A<B!L96=E;F0@/2!D;V,N8W)E871E16QE
M;65N="@B;&5G96YD(BD["@EF:65L9'-E="YA<'!E;F1#:&EL9"AL96=E;F0I
M.PH);&5G96YD+FEN;F5R2%1-3"`](&DQ.&Y;(DQA>6]U=")=.PH)=F%R('1A
M8FQE(#T@9&]C+F-R96%T945L96UE;G0H(G1A8FQE(BD["@EF:65L9'-E="YA
M<'!E;F1#:&EL9"AT86)L92D["@ET86)L92YS='EL92YW:61T:"`]("(Q,#`E
M(CL*"79A<B!T8F]D>2`](&1O8RYC<F5A=&5%;&5M96YT*")T8F]D>2(I.PH)
M=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH*"79A<B!T86=N86UE(#T@96PN
M=&%G3F%M92YT;TQO=V5R0V%S92@I.PH)=F%R('1R+"!T9"P@:6YP=70L('-E
M;&5C="P@;W!T:6]N+"!O<'1I;VYS+"!I.PH*"6EF("AT86=N86UE("$](")T
M9"(@)B8@=&%G;F%M92`A/2`B='(B("8F('1A9VYA;64@(3T@(G1H(BD@>PH)
M"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@D)=&)O9'DN87!P96YD
M0VAI;&0H='(I.PH)"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)
M=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*"0ET<BYA<'!E;F1#:&EL9"AT9"D[
M"@D)=&0N:6YN97)(5$U,(#T@:3$X;ELB1FQO870B72`K("(Z(CL*"0ET9"`]
M(&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"71R+F%P<&5N9$-H:6QD*'1D
M*3L*"0ES96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@D)
M=&0N87!P96YD0VAI;&0H<V5L96-T*3L*"0ES96QE8W0N;F%M92`](")F7W-T
M7V9L;V%T(CL*"0EO<'1I;VYS(#T@6R).;VYE(BP@(DQE9G0B+"`B4FEG:'0B
M73L*"0EF;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N9W1H.R`K*VDI
M('L*"0D)=F%R(%9A;"`](&]P=&EO;G-;:5T["@D)"79A<B!V86P@/2!O<'1I
M;VYS6VE=+G1O3&]W97)#87-E*"D["@D)"6]P=&EO;B`](&1O8RYC<F5A=&5%
M;&5M96YT*")O<'1I;VXB*3L*"0D);W!T:6]N+FEN;F5R2%1-3"`](&DQ.&Y;
M5F%L73L*"0D);W!T:6]N+G9A;'5E(#T@=F%L.PH)"0EO<'1I;VXN<V5L96-T
M960@/2`H*"(B("L@96PN<W1Y;&4N8W-S1FQO870I+G1O3&]W97)#87-E*"D@
M/3T@=F%L*3L*"0D)<V5L96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD["@D)?0H)
M?0H*"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@ET8F]D>2YA<'!E
M;F1#:&EL9"AT<BD["@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)
M=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*"71R+F%P<&5N9$-H:6QD*'1D*3L*
M"71D+FEN;F5R2%1-3"`](&DQ.&Y;(E=I9'1H(ET@*R`B.B(["@ET9"`](&1O
M8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH)
M:6YP=70@/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+G1Y
M<&4@/2`B=&5X="(["@EI;G!U="YV86QU92`](%1A8FQE3W!E<F%T:6]N<RYG
M971,96YG=&@H96PN<W1Y;&4N=VED=&@I.PH):6YP=70N<VEZ92`]("(U(CL*
M"6EN<'5T+FYA;64@/2`B9E]S=%]W:61T:"(["@EI;G!U="YS='EL92YM87)G
M:6Y2:6=H="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL9"AI;G!U="D["@ES
M96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@ES96QE8W0N
M;F%M92`](")F7W-T7W=I9'1H56YI="(["@EO<'1I;VX@/2!D;V,N8W)E871E
M16QE;65N="@B;W!T:6]N(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB
M<&5R8V5N=")=.PH);W!T:6]N+G9A;'5E(#T@(B4B.PH);W!T:6]N+G-E;&5C
M=&5D(#T@+R4O+G1E<W0H96PN<W1Y;&4N=VED=&@I.PH)<V5L96-T+F%P<&5N
M9$-H:6QD*&]P=&EO;BD["@EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B
M;W!T:6]N(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB<&EX96QS(ET[
M"@EO<'1I;VXN=F%L=64@/2`B<'@B.PH);W!T:6]N+G-E;&5C=&5D(#T@+W!X
M+RYT97-T*&5L+G-T>6QE+G=I9'1H*3L*"7-E;&5C="YA<'!E;F1#:&EL9"AO
M<'1I;VXI.PH)=&0N87!P96YD0VAI;&0H<V5L96-T*3L*"@ES96QE8W0N<W1Y
M;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H9&]C
M+F-R96%T951E>'1.;V1E*&DQ.&Y;(E1E>'0@86QI9VXB72`K("(Z(BDI.PH)
M<V5L96-T(#T@9&]C+F-R96%T945L96UE;G0H(G-E;&5C="(I.PH)<V5L96-T
M+G-T>6QE+FUA<F=I;DQE9G0@/2!S96QE8W0N<W1Y;&4N;6%R9VEN4FEG:'0@
M/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H<V5L96-T*3L*"7-E;&5C="YN
M86UE(#T@(F9?<W1?=&5X=$%L:6=N(CL*"6]P=&EO;G,@/2!;(DQE9G0B+"`B
M0V5N=&5R(BP@(E)I9VAT(BP@(DIU<W1I9GDB73L*"6EF("AT86=N86UE(#T]
M(")T9"(I('L*"0EO<'1I;VYS+G!U<V@H(D-H87(B*3L*"7T*"6EN<'5T(#T@
M9&]C+F-R96%T945L96UE;G0H(FEN<'5T(BD["@EI;G!U="YN86UE(#T@(F9?
M<W1?=&5X=$%L:6=N0VAA<B(["@EI;G!U="YS:7IE(#T@(C$B.PH):6YP=70N
M<W1Y;&4N9F]N=$9A;6EL>2`](")M;VYO<W!A8V4B.PH)=&0N87!P96YD0VAI
M;&0H:6YP=70I.PH)9F]R("AV87(@:2`](#`[(&D@/"!O<'1I;VYS+FQE;F=T
M:#L@*RMI*2!["@D)=F%R(%9A;"`](&]P=&EO;G-;:5T["@D)=F%R('9A;"`]
M(%9A;"YT;TQO=V5R0V%S92@I.PH)"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M
M96YT*")O<'1I;VXB*3L*"0EO<'1I;VXN=F%L=64@/2!V86P["@D);W!T:6]N
M+FEN;F5R2%1-3"`](&DQ.&Y;5F%L73L*"0EO<'1I;VXN<V5L96-T960@/2`H
M96PN<W1Y;&4N=&5X=$%L:6=N+G1O3&]W97)#87-E*"D@/3T@=F%L*3L*"0ES
M96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*"7T*"69U;F-T:6]N('-E=$-H
M87)6:7-I8FEL:71Y*'9A;'5E*2!["@D):6YP=70N<W1Y;&4N=FES:6)I;&ET
M>2`]('9A;'5E(#\@(G9I<VEB;&4B(#H@(FAI9&1E;B(["@D):68@*'9A;'5E
M*2!["@D)"6EN<'5T+F9O8W5S*"D["@D)"6EN<'5T+G-E;&5C="@I.PH)"7T*
M"7T["@ES96QE8W0N;VYC:&%N9V4@/2!F=6YC=&EO;B@I('L@<V5T0VAA<E9I
M<VEB:6QI='DH=&AI<RYV86QU92`]/2`B8VAA<B(I.R!].PH)<V5T0VAA<E9I
M<VEB:6QI='DH<V5L96-T+G9A;'5E(#T](")C:&%R(BD["@H)='(@/2!D;V,N
M8W)E871E16QE;65N="@B='(B*3L*"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*
M"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET9"YC;&%S<TYA;64@
M/2`B;&%B96PB.PH)='(N87!P96YD0VAI;&0H=&0I.PH)=&0N:6YN97)(5$U,
M(#T@:3$X;ELB2&5I9VAT(ET@*R`B.B(["@ET9"`](&1O8RYC<F5A=&5%;&5M
M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH):6YP=70@/2!D;V,N
M8W)E871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+G1Y<&4@/2`B=&5X="([
M"@EI;G!U="YV86QU92`](%1A8FQE3W!E<F%T:6]N<RYG971,96YG=&@H96PN
M<W1Y;&4N:&5I9VAT*3L*"6EN<'5T+G-I>F4@/2`B-2(["@EI;G!U="YN86UE
M(#T@(F9?<W1?:&5I9VAT(CL*"6EN<'5T+G-T>6QE+FUA<F=I;E)I9VAT(#T@
M(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&EN<'5T*3L*"7-E;&5C="`](&1O
M8RYC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*"7-E;&5C="YN86UE(#T@(F9?
M<W1?:&5I9VAT56YI="(["@EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B
M;W!T:6]N(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB<&5R8V5N=")=
M.PH);W!T:6]N+G9A;'5E(#T@(B4B.PH);W!T:6]N+G-E;&5C=&5D(#T@+R4O
M+G1E<W0H96PN<W1Y;&4N:&5I9VAT*3L*"7-E;&5C="YA<'!E;F1#:&EL9"AO
M<'1I;VXI.PH);W!T:6]N(#T@9&]C+F-R96%T945L96UE;G0H(F]P=&EO;B(I
M.PH);W!T:6]N+FEN;F5R2%1-3"`](&DQ.&Y;(G!I>&5L<R)=.PH);W!T:6]N
M+G9A;'5E(#T@(G!X(CL*"6]P=&EO;BYS96QE8W1E9"`]("]P>"\N=&5S="AE
M;"YS='EL92YH96EG:'0I.PH)<V5L96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD[
M"@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH*"7-E;&5C="YS='EL92YM87)G
M:6Y2:6=H="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL9"AD;V,N8W)E871E
M5&5X=$YO9&4H:3$X;ELB5F5R=&EC86P@86QI9VXB72`K("(Z(BDI.PH)<V5L
M96-T(#T@9&]C+F-R96%T945L96UE;G0H(G-E;&5C="(I.PH)<V5L96-T+FYA
M;64@/2`B9E]S=%]V97)T:6-A;$%L:6=N(CL*"7-E;&5C="YS='EL92YM87)G
M:6Y,969T(#T@(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*'-E;&5C="D["@EO
M<'1I;VYS(#T@6R)4;W`B+"`B36ED9&QE(BP@(D)O='1O;2(L(")"87-E;&EN
M92)=.PH)9F]R("AV87(@:2`](#`[(&D@/"!O<'1I;VYS+FQE;F=T:#L@*RMI
M*2!["@D)=F%R(%9A;"`](&]P=&EO;G-;:5T["@D)=F%R('9A;"`](%9A;"YT
M;TQO=V5R0V%S92@I.PH)"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M96YT*")O
M<'1I;VXB*3L*"0EO<'1I;VXN=F%L=64@/2!V86P["@D);W!T:6]N+FEN;F5R
M2%1-3"`](&DQ.&Y;5F%L73L*"0EO<'1I;VXN<V5L96-T960@/2`H96PN<W1Y
M;&4N=F5R=&EC86Q!;&EG;BYT;TQO=V5R0V%S92@I(#T]('9A;"D["@D)<V5L
M96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD["@E]"@H)<F5T=7)N(&9I96QD<V5T
M.PI].PH*+R\@4F5T=7)N<R!A;B!(5$U,(&5L96UE;G0@8V]N=&%I;FEN9R!T
M:&4@<W1Y;&4@871T<FEB=71E<R!F;W(@=&AE(&=I=F5N"B\O(&5L96UE;G0N
M("!4:&ES(&-A;B!B92!E87-I;'D@96UB961D960@:6YT;R!A;GD@9&EA;&]G
M.R!T:&4@9G5N8W1I;VYA;&ET>2!I<PHO+R!A;'-O('!R;W9I9&5D+@I486)L
M94]P97)A=&EO;G,N8W)E871E4W1Y;&5&:65L9'-E="`](&9U;F-T:6]N*&1O
M8RP@961I=&]R+"!E;"D@>PH)=F%R(&DQ.&X@/2!486)L94]P97)A=&EO;G,N
M23$X3CL*"79A<B!F:65L9'-E="`](&1O8RYC<F5A=&5%;&5M96YT*")F:65L
M9'-E="(I.PH)=F%R(&QE9V5N9"`](&1O8RYC<F5A=&5%;&5M96YT*")L96=E
M;F0B*3L*"69I96QD<V5T+F%P<&5N9$-H:6QD*&QE9V5N9"D["@EL96=E;F0N
M:6YN97)(5$U,(#T@:3$X;ELB0U-3(%-T>6QE(ET["@EV87(@=&%B;&4@/2!D
M;V,N8W)E871E16QE;65N="@B=&%B;&4B*3L*"69I96QD<V5T+F%P<&5N9$-H
M:6QD*'1A8FQE*3L*"71A8FQE+G-T>6QE+G=I9'1H(#T@(C$P,"4B.PH)=F%R
M('1B;V1Y(#T@9&]C+F-R96%T945L96UE;G0H(G1B;V1Y(BD["@ET86)L92YA
M<'!E;F1#:&EL9"AT8F]D>2D["@H)=F%R('1R+"!T9"P@:6YP=70L('-E;&5C
M="P@;W!T:6]N+"!O<'1I;VYS+"!I.PH*"71R(#T@9&]C+F-R96%T945L96UE
M;G0H(G1R(BD["@ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@ET9"`](&1O8RYC
M<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH)=&0N
M8VQA<W-.86UE(#T@(FQA8F5L(CL*"71D+FEN;F5R2%1-3"`](&DQ.&Y;(D)A
M8VMG<F]U;F0B72`K("(Z(CL*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D
M(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@EV87(@9&8@/2!486)L94]P97)A
M=&EO;G,N8W)E871E0V]L;W)"=71T;VXH9&]C+"!E9&ET;W(L(&5L+G-T>6QE
M+F)A8VMG<F]U;F1#;VQO<BP@(F)A8VMG<F]U;F1#;VQO<B(I.PH)9&8N9FER
M<W1#:&EL9"YN97AT4VEB;&EN9RYS='EL92YM87)G:6Y2:6=H="`]("(P+C5E
M;2(["@ET9"YA<'!E;F1#:&EL9"AD9BD["@ET9"YA<'!E;F1#:&EL9"AD;V,N
M8W)E871E5&5X=$YO9&4H:3$X;ELB26UA9V4@55),(ET@*R`B.B`B*2D["@EI
M;G!U="`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP=70N='EP
M92`](")T97AT(CL*"6EN<'5T+FYA;64@/2`B9E]S=%]B86-K9W)O=6YD26UA
M9V4B.PH):68@*&5L+G-T>6QE+F)A8VMG<F]U;F1);6%G92YM871C:"@O=7)L
M7"A<<RHH+BH_*5QS*EPI+RDI('L*"0EI;G!U="YV86QU92`](%)E9T5X<"XD
M,3L*"7T*"2\O(&EN<'5T+G-T>6QE+G=I9'1H(#T@(C$P,"4B.PH)=&0N87!P
M96YD0VAI;&0H:6YP=70I.PH*"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R
M(BD["@ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@ET9"`](&1O8RYC<F5A=&5%
M;&5M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH)=&0N8VQA<W-.
M86UE(#T@(FQA8F5L(CL*"71D+FEN;F5R2%1-3"`](&DQ.&Y;(D9'($-O;&]R
M(ET@*R`B.B(["@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N
M87!P96YD0VAI;&0H=&0I.PH)=&0N87!P96YD0VAI;&0H5&%B;&5/<&5R871I
M;VYS+F-R96%T94-O;&]R0G5T=&]N*&1O8RP@961I=&]R+"!E;"YS='EL92YC
M;VQO<BP@(F-O;&]R(BDI.PH*"2\O(&9O<B!B971T97(@86QI9VYM96YT('=E
M(&EN8VQU9&4@86X@:6YV:7-I8FQE(&9I96QD+@H):6YP=70@/2!D;V,N8W)E
M871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+G-T>6QE+G9I<VEB:6QI='D@
M/2`B:&ED9&5N(CL*"6EN<'5T+G1Y<&4@/2`B=&5X="(["@ET9"YA<'!E;F1#
M:&EL9"AI;G!U="D["@H)='(@/2!D;V,N8W)E871E16QE;65N="@B='(B*3L*
M"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"71D(#T@9&]C+F-R96%T945L96UE
M;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YC;&%S<TYA;64@
M/2`B;&%B96PB.PH)=&0N:6YN97)(5$U,(#T@:3$X;ELB0F]R9&5R(ET@*R`B
M.B(["@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P96YD
M0VAI;&0H=&0I.PH*"79A<B!C;VQO<D)U='1O;B`](%1A8FQE3W!E<F%T:6]N
M<RYC<F5A=&5#;VQO<D)U='1O;BAD;V,L(&5D:71O<BP@96PN<W1Y;&4N8F]R
M9&5R0V]L;W(L(")B;W)D97)#;VQO<B(I.PH)=F%R(&)T;B`](&-O;&]R0G5T
M=&]N+F9I<G-T0VAI;&0N;F5X=%-I8FQI;F<["@ET9"YA<'!E;F1#:&EL9"AC
M;VQO<D)U='1O;BD["@DO+R!B;W)D97)&:65L9',N<'5S:"AB=&XI.PH)8G1N
M+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*"@ES96QE8W0@/2!D;V,N
M8W)E871E16QE;65N="@B<V5L96-T(BD["@EV87(@8F]R9&5R1FEE;&1S(#T@
M6UT["@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH)<V5L96-T+FYA;64@/2`B
M9E]S=%]B;W)D97)3='EL92(["@EO<'1I;VYS(#T@6R)N;VYE(BP@(F1O='1E
M9"(L(")D87-H960B+"`B<V]L:60B+"`B9&]U8FQE(BP@(F=R;V]V92(L(")R
M:61G92(L(")I;G-E="(L(")O=71S970B73L*"79A<B!C=7)R96YT0F]R9&5R
M4W1Y;&4@/2!E;"YS='EL92YB;W)D97)3='EL93L*"2\O($=E8VMO(')E<&]R
M=',@(G-O;&ED('-O;&ED('-O;&ED('-O;&ED(B!F;W(@(F)O<F1E<BUS='EL
M93H@<V]L:60B+@H)+R\@5&AA="!I<RP@(G1O<"!R:6=H="!B;W1T;VT@;&5F
M="(@+2T@=V4@;VYL>2!C;VYS:61E<B!T:&4@9FER<W0*"2\O('9A;'5E+@H)
M*&-U<G)E;G1";W)D97)3='EL92YM871C:"@O*%M>7'-=*BE<<R\I*2`F)B`H
M8W5R<F5N=$)O<F1E<E-T>6QE(#T@4F5G17AP+B0Q*3L*"69O<B`H=F%R(&D@
M:6X@;W!T:6]N<RD@>PH)"79A<B!V86P@/2!O<'1I;VYS6VE=.PH)"6]P=&EO
M;B`](&1O8RYC<F5A=&5%;&5M96YT*")O<'1I;VXB*3L*"0EO<'1I;VXN=F%L
M=64@/2!V86P["@D);W!T:6]N+FEN;F5R2%1-3"`]('9A;#L*"0DH=F%L(#T]
M(&-U<G)E;G1";W)D97)3='EL92D@)B8@*&]P=&EO;BYS96QE8W1E9"`]('1R
M=64I.PH)"7-E;&5C="YA<'!E;F1#:&EL9"AO<'1I;VXI.PH)?0H)<V5L96-T
M+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*"69U;F-T:6]N('-E=$)O
M<F1E<D9I96QD<U-T871U<RAV86QU92D@>PH)"69O<B`H=F%R(&D@/2`P.R!I
M(#P@8F]R9&5R1FEE;&1S+FQE;F=T:#L@*RMI*2!["@D)"79A<B!E;"`](&)O
M<F1E<D9I96QD<UMI73L*"0D)96PN<W1Y;&4N=FES:6)I;&ET>2`]('9A;'5E
M(#\@(FAI9&1E;B(@.B`B=FES:6)L92(["@D)"6EF("@A=F%L=64@)B8@*&5L
M+G1A9TYA;64N=&],;W=E<D-A<V4H*2`]/2`B:6YP=70B*2D@>PH)"0D)96PN
M9F]C=7,H*3L*"0D)"65L+G-E;&5C="@I.PH)"0E]"@D)?0H)?3L*"7-E;&5C
M="YO;F-H86YG92`](&9U;F-T:6]N*"D@>R!S971";W)D97)&:65L9'-3=&%T
M=7,H=&AI<RYV86QU92`]/2`B;F]N92(I.R!].PH*"6EN<'5T(#T@9&]C+F-R
M96%T945L96UE;G0H(FEN<'5T(BD["@EB;W)D97)&:65L9',N<'5S:"AI;G!U
M="D["@EI;G!U="YT>7!E(#T@(G1E>'0B.PH):6YP=70N;F%M92`](")F7W-T
M7V)O<F1E<E=I9'1H(CL*"6EN<'5T+G9A;'5E(#T@5&%B;&5/<&5R871I;VYS
M+F=E=$QE;F=T:"AE;"YS='EL92YB;W)D97)7:61T:"D["@EI;G!U="YS:7IE
M(#T@(C4B.PH)=&0N87!P96YD0VAI;&0H:6YP=70I.PH):6YP=70N<W1Y;&4N
M;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH)=F%R('-P86X@/2!D;V,N8W)E871E
M16QE;65N="@B<W!A;B(I.PH)<W!A;BYI;FYE<DA434P@/2!I,3AN6R)P:7AE
M;',B73L*"71D+F%P<&5N9$-H:6QD*'-P86XI.PH)8F]R9&5R1FEE;&1S+G!U
M<V@H<W!A;BD["@H)<V5T0F]R9&5R1FEE;&1S4W1A='5S*'-E;&5C="YV86QU
M92`]/2`B;F]N92(I.PH*"6EF("AE;"YT86=.86UE+G1O3&]W97)#87-E*"D@
M/3T@(G1A8FQE(BD@>PH)"2\O('1H92!B;W)D97(M8V]L;&%P<V4@<W1Y;&4@
M:7,@;VYL>2!F;W(@=&%B;&5S"@D)='(@/2!D;V,N8W)E871E16QE;65N="@B
M='(B*3L*"0ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@D)=&0@/2!D;V,N8W)E
M871E16QE;65N="@B=&0B*3L*"0ET9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)
M"71R+F%P<&5N9$-H:6QD*'1D*3L*"0EI;G!U="`](&1O8RYC<F5A=&5%;&5M
M96YT*")I;G!U="(I.PH)"6EN<'5T+G1Y<&4@/2`B8VAE8VMB;W@B.PH)"6EN
M<'5T+FYA;64@/2`B9E]S=%]B;W)D97)#;VQL87!S92(["@D):6YP=70N:60@
M/2`B9E]S=%]B;W)D97)#;VQL87!S92(["@D)=F%R('9A;"`]("@O8V]L;&%P
M<V4O:2YT97-T*&5L+G-T>6QE+F)O<F1E<D-O;&QA<'-E*2D["@D):6YP=70N
M8VAE8VME9"`]('9A;"`_(#$@.B`P.PH)"71D+F%P<&5N9$-H:6QD*&EN<'5T
M*3L*"@D)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"0ET<BYA<'!E
M;F1#:&EL9"AT9"D["@D)=F%R(&QA8F5L(#T@9&]C+F-R96%T945L96UE;G0H
M(FQA8F5L(BD["@D);&%B96PN:'1M;$9O<B`](")F7W-T7V)O<F1E<D-O;&QA
M<'-E(CL*"0EL86)E;"YI;FYE<DA434P@/2!I,3AN6R)#;VQL87!S960@8F]R
M9&5R<R)=.PH)"71D+F%P<&5N9$-H:6QD*&QA8F5L*3L*"7T*"B\O(`ET<B`]
M(&1O8RYC<F5A=&5%;&5M96YT*")T<B(I.PHO+R`)=&)O9'DN87!P96YD0VAI
M;&0H='(I.PHO+R`)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*+R\@
M"71D+F-L87-S3F%M92`](")L86)E;"(["B\O(`ET<BYA<'!E;F1#:&EL9"AT
M9"D["B\O(`ET9"YI;FYE<DA434P@/2!I,3AN6R)-87)G:6XB72`K("(Z(CL*
M+R\@"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["B\O(`ET<BYA<'!E
M;F1#:&EL9"AT9"D["B\O(`EI;G!U="`](&1O8RYC<F5A=&5%;&5M96YT*")I
M;G!U="(I.PHO+R`):6YP=70N='EP92`](")T97AT(CL*+R\@"6EN<'5T+G-I
M>F4@/2`B-2(["B\O(`EI;G!U="YN86UE(#T@(F9?<W1?;6%R9VEN(CL*+R\@
M"71D+F%P<&5N9$-H:6QD*&EN<'5T*3L*+R\@"6EN<'5T+G-T>6QE+FUA<F=I
M;E)I9VAT(#T@(C`N-65M(CL*+R\@"71D+F%P<&5N9$-H:6QD*&1O8RYC<F5A
M=&5497AT3F]D92AI,3AN6R)0861D:6YG(ET@*R`B.B(I*3L*"B\O(`EI;G!U
M="`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PHO+R`):6YP=70N='EP
M92`](")T97AT(CL*+R\@"6EN<'5T+G-I>F4@/2`B-2(["B\O(`EI;G!U="YN
M86UE(#T@(F9?<W1?<&%D9&EN9R(["B\O(`ET9"YA<'!E;F1#:&EL9"AI;G!U
M="D["B\O(`EI;G!U="YS='EL92YM87)G:6Y,969T(#T@(C`N-65M(CL*+R\@
M"6EN<'5T+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*+R\@"71D+F%P
M<&5N9$-H:6QD*&1O8RYC<F5A=&5497AT3F]D92AI,3AN6R)P:7AE;',B72DI
M.PH*"7)E='5R;B!F:65L9'-E=#L*?3L*"B\O+R\@14Y$($=%3D5224,@0T]$
M12`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R],:7-T5'EP92\`
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8T`#`R-#4U-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+TQI<W14>7!E+VQA;F<O````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-C0`,#(U-3`P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&%N9R]E;BYJ<P``
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,30U,0`Q,#4Q-30S,3`V-``P,C8T,S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+R\@23$X3B!C;VYS=&%N=',*
M"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'.B!55$8M."!\($E33RTX.#4Y+3$*
M+R\@075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI
M<VAO;PH*+R\@1D]2(%1204Y33$%43U)3.@HO+PHO+R`@(#$N(%!,14%312!0
M550@64]54B!#3TY404-4($E.1D\@24X@5$A%($%"3U9%($Q)3D4*+R\@("`@
M("`H870@;&5A<W0@82!V86QI9"!E;6%I;"!A9&1R97-S*0HO+PHO+R`@(#(N
M(%!,14%312!44ED@5$\@55-%(%541BTX($9/4B!%3D-/1$E.1SL*+R\@("`@
M("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB;&4L('!L96%S92!I;F-L=61E(&$@
M8V]M;65N=`HO+R`@("`@("!T:&%T('-T871E<R!W:&%T(&5N8V]D:6YG(&ES
M(&YE8V5S<V%R>2XI"@I,:7-T5'EP92Y),3A.(#T@>PH)(D1E8VEM86PB("`@
M("`@("`@("`@("`@(#H@("`@(D1E8VEM86P@;G5M8F5R<R(L"@DB3&]W97(@
M<F]M86XB("`@("`@("`@("`@.B`@("`B3&]W97(@<F]M86X@;G5M8F5R<R(L
M"@DB57!P97(@<F]M86XB("`@("`@("`@("`@.B`@("`B57!P97(@<F]M86X@
M;G5M8F5R<R(L"@DB3&]W97(@;&%T:6XB("`@("`@("`@("`@.B`@("`B3&]W
M97(@;&%T:6X@;&5T=&5R<R(L"@DB57!P97(@;&%T:6XB("`@("`@("`@("`@
M.B`@("`B57!P97(@;&%T:6X@;&5T=&5R<R(L"@DB3&]W97(@9W)E96LB("`@
M("`@("`@("`@.B`@("`B3&]W97(@9W)E96L@;&5T=&5R<R(L"@DB3&ES=%-T
M>6QE5&]O;'1I<"(@("`@("`@.B`@("`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I(@I].PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&ES="UT
M>7!E+FIS```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-3$V,P`Q,#4Q-30S,3`V-``P,C<P-3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+R\@3&ES=%1Y<&4@
M4&QU9VEN(&9O<B!(5$U,07)E82TS+C`*+R\@4W!O;G-O<F5D(&)Y($U%9%1E
M8V@@56YI="`M(%%U965N)W,@56YI=F5R<VET>0HO+R!);7!L96UE;G1A=&EO
M;B!B>2!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;R\*
M+R\*+R\@*&,I(&1Y;F%R8V@N8V]M(#(P,#,M,C`P-2X*+R\@1&ES=')I8G5T
M960@=6YD97(@=&AE('-A;64@=&5R;7,@87,@2%1-3$%R96$@:71S96QF+@HO
M+R!4:&ES(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U<V4@*'-E92!L
M:6-E;G-E+G1X="DN"B\O"B\O("1)9#H@;&ES="UT>7!E+FIS+'8@,2XR(#(P
M,#4O,#$O,C`@,3<Z-#DZ,#,@;6ES:&]O($5X<"`D"@IF=6YC=&EO;B!,:7-T
M5'EP92AE9&ET;W(I('L*"71H:7,N961I=&]R(#T@961I=&]R.PH)=F%R(&-F
M9R`](&5D:71O<BYC;VYF:6<["@EV87(@=&]O;&)A<B`](&-F9RYT;V]L8F%R
M.PH)=F%R('-E;&8@/2!T:&ES.PH)=F%R(&DQ.&X@/2!,:7-T5'EP92Y),3A.
M.PH)=F%R(&]P=&EO;G,@/2![?3L*"6]P=&EO;G-;:3$X;ELB1&5C:6UA;")=
M72`](")D96-I;6%L(CL*"6]P=&EO;G-;:3$X;ELB3&]W97(@<F]M86XB75T@
M/2`B;&]W97(M<F]M86XB.PH);W!T:6]N<UMI,3AN6R)5<'!E<B!R;VUA;B)=
M72`](")U<'!E<BUR;VUA;B(["@EO<'1I;VYS6VDQ.&Y;(DQO=V5R(&QA=&EN
M(EU=(#T@(FQO=V5R+6%L<&AA(CL*"6]P=&EO;G-;:3$X;ELB57!P97(@;&%T
M:6XB75T@/2`B=7!P97(M86QP:&$B.PH):68@*"%(5$U,07)E82YI<U]I92D*
M"0DO+R!)12!D;V5S;B=T('-U<'!O<G0@=&AI<R!P<F]P97)T>3L@979E;B!W
M;W)S92P@:70@8V]M<&QA:6YS"@D)+R\@=VET:"!A(&=R;W-S(&5R<F]R(&UE
M<W-A9V4@=VAE;B!W92!T<FEE9"!T;R!S96QE8W0@:70L"@D)+R\@=&AE<F5F
M;W)E(&QE="=S(&AI9&4@:70@9G)O;2!T:&4@9&%M;B`B8G)O=W-E<B(N"@D)
M;W!T:6]N<UMI,3AN6R),;W=E<B!G<F5E:R)=72`](")L;W=E<BUG<F5E:R([
M"@EV87(@;V)J(#T@>PH)"6ED("`@("`@("`@("`@.B`B3&ES=%1Y<&4B+`H)
M"71O;VQT:7`@("`@("`@.B!I,3AN6R),:7-T4W1Y;&54;V]L=&EP(ETL"@D)
M;W!T:6]N<R`@("`@("`Z(&]P=&EO;G,L"@D)86-T:6]N("`@("`@("`Z(&9U
M;F-T:6]N*&5D:71O<BD@>R!S96QF+F]N4V5L96-T*&5D:71O<BP@=&AI<RD[
M('TL"@D)<F5F<F5S:"`@("`@("`Z(&9U;F-T:6]N*&5D:71O<BD@>R!S96QF
M+G5P9&%T959A;'5E*&5D:71O<BP@=&AI<RD[('TL"@D)8V]N=&5X="`@("`@
M("`Z(")O;"(*"7T["@EC9F<N<F5G:7-T97)$<F]P9&]W;BAO8FHI.PH)=F%R
M(&$L(&DL(&HL(&9O=6YD(#T@9F%L<V4["@EF;W(@*&D@/2`P.R`A9F]U;F0@
M)B8@:2`\('1O;VQB87(N;&5N9W1H.R`K*VDI('L*"0EA(#T@=&]O;&)A<EMI
M73L*"0EF;W(@*&H@/2`P.R!J(#P@82YL96YG=&@[("LK:BD@>PH)"0EI9B`H
M85MJ72`]/2`B=6YO<F1E<F5D;&ES="(I('L*"0D)"69O=6YD(#T@=')U93L*
M"0D)"6)R96%K.PH)"0E]"@D)?0H)?0H):68@*&9O=6YD*0H)"6$N<W!L:6-E
M*&HL(#`L(")S<&%C92(L("),:7-T5'EP92(L(")S<&%C92(I.PI].PH*3&ES
M=%1Y<&4N7W!L=6=I;DEN9F\@/2!["@EN86UE("`@("`@("`@(#H@(DQI<W14
M>7!E(BP*"79E<G-I;VX@("`@("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@
M.B`B36EH86D@0F%Z;VXB+`H)9&5V96QO<&5R7W5R;"`Z(")H='1P.B\O9'EN
M87)C:"YC;VTO;6ES:&]O+R(L"@EC7V]W;F5R("`@("`@(#H@(F1Y;F%R8V@N
M8V]M(BP*"7-P;VYS;W(@("`@("`@.B`B345D5&5C:"!5;FET("T@475E96XG
M<R!5;FEV97)S:71Y(BP*"7-P;VYS;W)?=7)L("`@.B`B:'1T<#HO+W=W=RYQ
M=65E;G-U+F-A+R(L"@EL:6-E;G-E("`@("`@(#H@(FAT;6Q!<F5A(@I].PH*
M3&ES=%1Y<&4N<')O=&]T>7!E+F]N4V5L96-T(#T@9G5N8W1I;VXH961I=&]R
M+"!C;VUB;RD@>PH)=F%R('1B;V)J(#T@961I=&]R+E]T;V]L8F%R3V)J96-T
M<UMC;VUB;RYI9%TN96QE;65N=#L*"79A<B!P87)E;G0@/2!E9&ET;W(N9V5T
M4&%R96YT16QE;65N="@I.PH)=VAI;&4@*"$O7F]L)"]I+G1E<W0H<&%R96YT
M+G1A9TYA;64I*2!["@D)<&%R96YT(#T@<&%R96YT+G!A<F5N=$YO9&4["@E]
M"@EP87)E;G0N<W1Y;&4N;&ES=%-T>6QE5'EP92`]('1B;V)J+G9A;'5E.PI]
M.PH*3&ES=%1Y<&4N<')O=&]T>7!E+G5P9&%T959A;'5E(#T@9G5N8W1I;VXH
M961I=&]R+"!C;VUB;RD@>PH)=F%R('1B;V)J(#T@961I=&]R+E]T;V]L8F%R
M3V)J96-T<UMC;VUB;RYI9%TN96QE;65N=#L*"79A<B!P87)E;G0@/2!E9&ET
M;W(N9V5T4&%R96YT16QE;65N="@I.PH)=VAI;&4@*'!A<F5N="`F)B`A+UYO
M;"0O:2YT97-T*'!A<F5N="YT86=.86UE*2D@>PH)"7!A<F5N="`]('!A<F5N
M="YP87)E;G1.;V1E.PH)?0H):68@*"%P87)E;G0I('L*"0ET8F]B:BYS96QE
M8W1E9$EN9&5X(#T@,#L*"0ER971U<FX["@E]"@EV87(@='EP92`]('!A<F5N
M="YS='EL92YL:7-T4W1Y;&54>7!E.PH):68@*"%T>7!E*2!["@D)=&)O8FHN
M<V5L96-T961);F1E>"`](#`["@E](&5L<V4@>PH)"69O<B`H=F%R(&D@/2!T
M8F]B:BYF:7)S=$-H:6QD.R!I.R!I(#T@:2YN97AT4VEB;&EN9RD@>PH)"0EI
M+G-E;&5C=&5D(#T@*'1Y<&4N:6YD97A/9BAI+G9A;'5E*2`A/2`M,2D["@D)
M?0H)?0I].PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!S+P``````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#8T`#`R,C8T-P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O9G5L;'-C<F5E;BYH=&UL
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3(W-C``,3`U,34T,S$P-C0`,#(U-S`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#PA1$]#5%E012!H
M=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XQ+R]%3B(@(FAT='`Z
M+R]W=W<N=S,N;W)G+U12+WAH=&UL,3$O1%1$+WAH=&UL,3$N9'1D(CX*/&AT
M;6P^"B`@/&AE860^"B`@("`\=&ET;&4^1G5L;'-C<F5E;B!(5$U,07)E83PO
M=&ET;&4^"B`@("`\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"B`@
M("`@(%]E9&ET;W)?=7)L(#T@=VEN9&]W+F]P96YE<BY?961I=&]R7W5R;"!\
M?"`G+BXO)SL*("`@("`@7V5D:71O<E]L86YG(#T@=VEN9&]W+F]P96YE<BY?
M961I=&]R7VQA;F<["B`@("`@(%]E9&ET;W)?8W-S(#T@=VEN9&]W+F]P96YE
M<BY?961I=&]R7V-S<SL*("`@("`@=F%R($)!4T4@/2!W:6YD;W<N;W!E;F5R
M+F1O8W5M96YT+F)A<V554DD@?'P@=VEN9&]W+F]P96YE<BYD;V-U;65N="Y5
M4DP["B`@("`@('9A<B!H96%D(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A
M9TYA;64H(FAE860B*5LP73L*("`@("`@=F%R(&)A<V4@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*")B87-E(BD["B`@("`@(&)A<V4N:')E9B`]($)!4T4[
M"B`@("`@(&AE860N87!P96YD0VAI;&0H8F%S92D["B`@("`\+W-C<FEP=#X*
M"B`@("`\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"B`@("`@("`@
M9&]C=6UE;G0N=W)I=&4H)SQS8W(G("L@)VEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B('-R8STB)R`K(%]E9&ET;W)?=7)L("L@)VAT;6QA<F5A+FIS(CX\
M+W-C<B<@*R`G:7!T/B<I.PH@("`@/"]S8W)I<'0^"B`@("`\<V-R:7!T('1Y
M<&4](G1E>'0O:F%V87-C<FEP="(^"@DO+R!L;V%D($A434Q!<F5A('-C<FEP
M=',@=&AA="!A<F4@<')E<V5N="!I;B!T:&4@;W!E;F5R(&9R86UE"@EV87(@
M<V-R:7!T<R`]('=I;F1O=RYO<&5N97(N2%1-3$%R96$N7W-C<FEP=',["@EF
M;W(@*'9A<B!I(#T@,SL@:2`\('-C<FEP=',N;&5N9W1H.R`K*VDI('L*("`@
M("`@("`@("`O+V1O8W5M96YT+G=R:71E*"(\<V-R(B`K(")I<'0@='EP93TG
M=&5X="]J879A<V-R:7!T)R!S<F,])R(@*R!S8W)I<'1S6VE=("L@(B<^/"]S
M8W(B("L@(FEP=#XB*3L*("`@("`@("`@("!(5$U,07)E82YL;V%D4V-R:7!T
M*'-C<FEP='-;:5TI.PH@("`@("`@('T*("`@(#PO<V-R:7!T/@H*("`@(#PA
M+2T@8G)O=W-E<B!T86ME<R!A(&-O9F9E92!B<F5A:R!H97)E("TM/@H@("`@
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@IV87(@<&%R96YT7V]B
M:F5C="`@/2!N=6QL.PIV87(@961I=&]R"2`@(#T@;G5L;#L)+R\@=&\@8F4@
M:6YI=&EA;&EZ960@;&%T97(@6R!F=6YC=&EO;B!I;FET*"D@70H*+RH@+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J7`H@("!&=6YC=&EO;B`@("`Z"B`@
M($1E<V-R:7!T:6]N(#H*7"H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J
M+PH*9G5N8W1I;VX@7T-L;W-E3VY%<V,H978I('L*"65V('Q\("AE=B`]('=I
M;F1O=RYE=F5N="D@?'P@*&5V(#T@961I=&]R+E]I9G)A;64N8V]N=&5N=%=I
M;F1O=RYE=F5N="D["@EI9B`H978N:V5Y0V]D92`]/2`R-RD@>PH)"2\O('5P
M9&%T95]P87)E;G0H*3L*"0EW:6YD;W<N8VQO<V4H*3L*"0ER971U<FX["@E]
M"GT*"B\J("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@*EP*("`@1G5N8W1I
M;VX@("`@.B!R97-I>F5?961I=&]R"B`@($1E<V-R:7!T:6]N(#H@<F5S:7IE
M('1H92!E9&ET;W(@=VAE;B!T:&4@=7-E<B!R97-I>F5S('1H92!P;W!U<`I<
M*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("HO"@IF=6YC=&EO;B!R97-I
M>F5?961I=&]R*"D@>R`@+R\@<F5S:7IE(&5D:71O<B!T;R!F:7@@=VEN9&]W
M"@H@('9A<B!N97=(96EG:'0["B`@:68@*&1O8W5M96YT+F%L;"D@>R`O+R!)
M10H@("`@;F5W2&5I9VAT(#T@9&]C=6UE;G0N8F]D>2YO9F9S971(96EG:'0@
M+2!E9&ET;W(N7W1O;VQB87(N;V9F<V5T2&5I9VAT.PH@("`@:68@*&YE=TAE
M:6=H="`\(#`I('L@;F5W2&5I9VAT(#T@,#L@?0H@('T@96QS92![("\O($=E
M8VMO"B`@("!N97=(96EG:'0@/2!W:6YD;W<N:6YN97)(96EG:'0@+2!E9&ET
M;W(N7W1O;VQB87(N;V9F<V5T2&5I9VAT.PH@('T*("!I9B`H961I=&]R+F-O
M;F9I9RYS=&%T=7-"87(I('L*("`@(&YE=TAE:6=H="`M/2!E9&ET;W(N7W-T
M871U<T)A<BYO9F9S971(96EG:'0["B`@?0H*("`O+R!43T1/.B!))VT@;F]T
M('-U<F4@97AA8W1L>2!W:&%T('1H97-E(&%R92!A9&IU<W1I;F<@9F]R+"!B
M=70@:68*("`O+R!Y;W4@9&]N)W0@861J=7-T('1H92!H96EG:'0@9F]R($E%
M('1H96X@9&]C=6UE;G0N8F]D>2YO9F9S971(96EG:'0*("`O+R!W:6QL(&=E
M="!L87)G97(@979E<GD@=&EM92!A;F0@=&AE("AP;W!U<"D@961I=&]R('=I
M;&P@9V5T('-T=6-K"B`@+R\@:6X@82!T:6=H="!L;V]P(&%N9"!T:&4@8G)O
M=W-E<B!W;VXG="!B92!R97-P;VYS:79E+B`@26X@9G5T=7)E('=E)VQL"B`@
M+R\@=V%N="!T;R!G970@=&AE<V4@;65A<W5R96UE;G1S(&1Y;F%M:6-A;&QY
M(&EN(&-A<V4@96QE;65N=',@8VAA;F=E('-I>F4*("`O+R!I;B!T:&4@9G5T
M=7)E+@H*("!I9B`H2%1-3$%R96$N:7-?9V5C:V\I('L@;F5W2&5I9VAT("T]
M(#@[('T*("!E;'-E("`@("`@("`@("`@("`@("`@('L@;F5W2&5I9VAT("T]
M(#$P.R!]"@H@("\O(&%D:G5S="!E;&5M96YT(&AE:6=H=`H@('9A<B!N97=(
M96EG:'17:71H4'@@/2!N97=(96EG:'0@*R`B<'@B.PH@(&5D:71O<BY?=&5X
M=$%R96$N<W1Y;&4N:&5I9VAT(#T@;F5W2&5I9VAT5VET:%!X.PH@(&5D:71O
M<BY?:69R86UE+G-T>6QE+FAE:6=H="`@(#T@;F5W2&5I9VAT5VET:%!X.PI]
M"@HO*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("I<"B`@($9U;F-T:6]N
M("`@(#H@:6YI=`H@("!$97-C<FEP=&EO;B`Z(')U;B!T:&ES(&-O9&4@;VX@
M<&%G92!L;V%D"EPJ("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@*B\*"F9U
M;F-T:6]N(&EN:70H*2!["@EP87)E;G1?;V)J96-T"2`@(#T@;W!E;F5R+DA4
M34Q!<F5A+E]O8FIE8W0["@EV87(@8V]N9FEG"2`@(#T@2%1-3$%R96$N8VQO
M;F5/8FIE8W0H('!A<F5N=%]O8FIE8W0N8V]N9FEG("D["@EC;VYF:6<N=VED
M=&@)("`@/2`B,3`P)2(["@EC;VYF:6<N:&5I9VAT"2`@(#T@(F%U=&\B.PH*
M"2\O(&-H86YG92!M87AI;6EZ92!B=71T;VX@=&\@;6EN:6UI>F4@8G5T=&]N
M"@EC;VYF:6<N8G1N3&ES=%LB<&]P=7!E9&ET;W(B72`](%L@)TUI;FEM:7IE
M($5D:71O<B<L(%]E9&ET;W)?=7)L("L@)VEM86=E<R]F=6QL<V-R965N7VUI
M;FEM:7IE+F=I9B<L('1R=64L"@D)"0D)("!F=6YC=&EO;B@I('L@=VEN9&]W
M+F-L;W-E*"D[('T@73L*"@DO+R!G96YE<F%T92!E9&ET;W(@86YD(')E<VEZ
M92!I=`H)961I=&]R(#T@;F5W($A434Q!<F5A*")E9&ET;W(B+"!C;VYF:6<I
M.PH*"2\O(')E9VES=&5R('1H92!P;'5G:6YS+"!I9B!A;GD*"69O<B`H=F%R
M(&D@:6X@<&%R96YT7V]B:F5C="YP;'5G:6YS*2!["@D)=F%R('!L=6=I;B`]
M('!A<F5N=%]O8FIE8W0N<&QU9VEN<UMI73L*"0ET<GD@>PH)"0EE=F%L*'!L
M=6=I;BYN86UE*3L*"0D)961I=&]R+G)E9VES=&5R4&QU9VEN,BAP;'5G:6XN
M;F%M92P@<&QU9VEN+F%R9W,I.PH)"7T@8V%T8V@H92D@>WT["@E]"@DO+R!A
M;F0@<F5S=&]R92!T:&4@;W)I9VEN86P@=&]O;&)A<@H@("`@("`@(&-O;F9I
M9RYT;V]L8F%R(#T@<&%R96YT7V]B:F5C="YC;VYF:6<N=&]O;&)A<CL*"65D
M:71O<BYG96YE<F%T92@I.PH)961I=&]R+E]I9G)A;64N<W1Y;&4N=VED=&@@
M/2`B,3`P)2(["@EE9&ET;W(N7W1E>'1!<F5A+G-T>6QE+G=I9'1H(#T@(C$P
M,"4B.PH)<F5S:7IE7V5D:71O<B@I.PH*"65D:71O<BYD;V-T>7!E(#T@<&%R
M96YT7V]B:F5C="YD;V-T>7!E.PH*"2\O('-E="!C:&EL9"!W:6YD;W<@8V]N
M=&5N=',@86YD(&5V96YT(&AA;F1L97)S+"!A9G1E<B!A('-M86QL(&1E;&%Y
M"@ES9714:6UE;W5T*&9U;F-T:6]N*"D@>PH)"0D@("!E9&ET;W(N<V5T2%1-
M3"AP87)E;G1?;V)J96-T+F=E=$EN;F5R2%1-3"@I*3L*"@D)"2`@("\O('-W
M:71C:"!M;V1E(&EF(&YE961E9`H)"0D@("!I9B`H<&%R96YT7V]B:F5C="Y?
M;6]D92`]/2`B=&5X=&UO9&4B*2![(&5D:71O<BYS971-;V1E*")T97AT;6]D
M92(I.R!]"@H)"0D@("`O+R!C;VYT:6YU;W5S;'D@=7!D871E('!A<F5N="!E
M9&ET;W(@=VEN9&]W"@D)"2`@('-E=$EN=&5R=F%L*'5P9&%T95]P87)E;G0L
M(#4P,"D["@H)"0D@("`O+R!S971U<"!E=F5N="!H86YD;&5R<PH)"0D@("!D
M;V-U;65N="YB;V1Y+F]N:V5Y<')E<W,@/2!?0VQO<V5/;D5S8SL*"0D)("`@
M961I=&]R+E]D;V,N8F]D>2YO;FME>7!R97-S(#T@7T-L;W-E3VY%<V,["@D)
M"2`@(&5D:71O<BY?=&5X=$%R96$N;VYK97EP<F5S<R`](%]#;&]S94]N17-C
M.PH)"0D@("!W:6YD;W<N;VYR97-I>F4@/2!R97-I>F5?961I=&]R.PH)"2`@
M('TL(#,S,RD["0D)("\O(&=I=F4@:70@<V]M92!T:6UE('1O(&UE970@=&AE
M(&YE=R!F<F%M90I]"@HO*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("I<
M"B`@($9U;F-T:6]N("`@(#H@=7!D871E7W!A<F5N=`H@("!$97-C<FEP=&EO
M;B`Z('5P9&%T92!P87)E;G0@=VEN9&]W(&5D:71O<B!F:65L9"!W:71H(&-O
M;G1E;G1S(&9R;VT@8VAI;&0@=VEN9&]W"B`@(%PJ("TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T@*B\*"F9U;F-T:6]N('5P9&%T95]P87)E;G0H*2!["@H)
M+R\@=7-E('1H92!F87-T('9E<G-I;VX*"7!A<F5N=%]O8FIE8W0N<V5T2%1-
M3"AE9&ET;W(N9V5T26YN97)(5$U,*"DI.PI]"@H@("`@/"]S8W)I<'0^"B`@
M("`\<W1Y;&4@='EP93TB=&5X="]C<W,B/B!H=&UL+"!B;V1Y('L@:&5I9VAT
M.B`Q,#`E.R!M87)G:6XZ(#!P>#L@8F]R9&5R.B`P<'@[(&)A8VMG<F]U;F0M
M8V]L;W(Z(&)U='1O;F9A8V4[('T@/"]S='EL93X*("`\+VAE860^"B`@/&)O
M9'D@<V-R;VQL/2)N;R(@;VYL;V%D/2)(5$U,07)E82YO;FQO860@/2!I;FET
M.R!(5$U,07)E82YI;FET*"D[(B!O;G5N;&]A9#TB=7!D871E7W!A<F5N="@I
M(CX*("`@(#QF;W)M('-T>6QE/2)M87)G:6XZ(#!P>#L@8F]R9&5R.B`Q<'@@
M<V]L:60[(&)O<F1E<BUC;VQO<CH@=&AR965D<VAA9&]W('1H<F5E9&AI9VAL
M:6=H="!T:')E961H:6=H;&EG:'0@=&AR965D<VAA9&]W.R(^"B`@("`@(#QT
M97AT87)E82!N86UE/2)E9&ET;W(B(&ED/2)E9&ET;W(B('-T>6QE/2)W:61T
M:#HQ,#`E.R!H96EG:'0Z,S`P<'@B/B9N8G-P.SPO=&5X=&%R96$^"B`@("`\
M+V9O<FT^"B`@/"]B;V1Y/@H\+VAT;6P^"@`````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;W!U<',O<&]P=7`N:G,`````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,C4`,3`U
M,34T,S$P-C0`,#(T,S4R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\O(&AT;6Q!<F5A('8S+C`@+2!#;W!Y<FEG:'0@*&,I
M(#(P,#(L(#(P,#,@:6YT97)A8W1I=F5T;V]L<RYC;VTL(&EN8RX*+R\@5&AI
M<R!C;W!Y<FEG:'0@;F]T:6-E($U54U0@<W1A>2!I;G1A8W0@9F]R('5S92`H
M<V5E(&QI8V5N<V4N='AT*2X*+R\*+R\@4&]R=&EO;G,@*&,I(&1Y;F%R8V@N
M8V]M+"`R,#`S"B\O"B\O($$@9G)E92!765-)5UE'(&5D:71O<B!R97!L86-E
M;65N="!F;W(@/'1E>'1A<F5A/B!F:65L9',N"B\O($9O<B!F=6QL('-O=7)C
M92!C;V1E(&%N9"!D;V-S+"!V:7-I="!H='1P.B\O=W=W+FAT;6QA<F5A+F-O
M;2\*+R\*+R\@5F5R<VEO;B`S+C`@9&5V96QO<&5D(&)Y($UI:&%I($)A>F]N
M+@HO+R`@(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*+R\*+R\@)$ED.B!P
M;W!U<"YJ<RQV(#$N,3(@,C`P-2\P,2\R-"`Q.#HR.3HT."!I=&]O;',@17AP
M("0*"F9U;F-T:6]N(&=E=$%B<V]L=71E4&]S*&5L*2!["@EV87(@<B`]('L@
M>#H@96PN;V9F<V5T3&5F="P@>3H@96PN;V9F<V5T5&]P('T["@EI9B`H96PN
M;V9F<V5T4&%R96YT*2!["@D)=F%R('1M<"`](&=E=$%B<V]L=71E4&]S*&5L
M+F]F9G-E=%!A<F5N="D["@D)<BYX("L]('1M<"YX.PH)"7(N>2`K/2!T;7`N
M>3L*"7T*"7)E='5R;B!R.PI].PH*9G5N8W1I;VX@8V]M8F]396QE8W1686QU
M92AC+"!V86PI('L*"79A<B!O<',@/2!C+F=E=$5L96UE;G1S0GE486=.86UE
M*")O<'1I;VXB*3L*"69O<B`H=F%R(&D@/2!O<',N;&5N9W1H.R`M+6D@/CT@
M,#LI('L*"0EV87(@;W`@/2!O<'-;:5T["@D);W`N<V5L96-T960@/2`H;W`N
M=F%L=64@/3T@=F%L*3L*"7T*"6,N=F%L=64@/2!V86P["GT["@IF=6YC=&EO
M;B!?7V1L9U]O;F-L;W-E*"D@>PH);W!E;F5R+D1I86QO9RY?<F5T=7)N*&YU
M;&PI.PI].PH*9G5N8W1I;VX@7U]D;&=?:6YI="AB;W1T;VTI('L*"79A<B!B
M;V1Y(#T@9&]C=6UE;G0N8F]D>3L*"79A<B!B;V1Y7VAE:6=H="`](#`["@EI
M9B`H='EP96]F(&)O='1O;2`]/2`B=6YD969I;F5D(BD@>PH)"79A<B!D:78@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")D:78B*3L*"0EB;V1Y+F%P<&5N
M9$-H:6QD*&1I=BD["@D)=F%R('!O<R`](&=E=$%B<V]L=71E4&]S*&1I=BD[
M"@D)8F]D>5]H96EG:'0@/2!P;W,N>3L*"7T@96QS92!["@D)=F%R('!O<R`]
M(&=E=$%B<V]L=71E4&]S*&)O='1O;2D["@D)8F]D>5]H96EG:'0@/2!P;W,N
M>2`K(&)O='1O;2YO9F9S971(96EG:'0["@E]"@EW:6YD;W<N9&EA;&]G07)G
M=6UE;G1S(#T@;W!E;F5R+D1I86QO9RY?87)G=6UE;G1S.PH):68@*"%D;V-U
M;65N="YA;&PI('L*"0EW:6YD;W<N<VEZ951O0V]N=&5N="@I.PH)"7=I;F1O
M=RYS:7IE5&]#;VYT96YT*"D["2\O(&9O<B!R96%S;VYS(&)E>6]N9"!U;F1E
M<G-T86YD:6YG+`H)"0D)"2\O(&]N;'D@:68@=V4@8V%L;"!I="!T=VEC92!W
M92!G970@=&AE"@D)"0D)+R\@8V]R<F5C="!S:7IE+@H)"7=I;F1O=RYA9&1%
M=F5N=$QI<W1E;F5R*")U;FQO860B+"!?7V1L9U]O;F-L;W-E+"!T<G5E*3L*
M"0EW:6YD;W<N:6YN97)7:61T:"`](&)O9'DN;V9F<V5T5VED=&@@*R`U.PH)
M"7=I;F1O=RYI;FYE<DAE:6=H="`](&)O9'E?:&5I9VAT("L@,CL*"0DO+R!C
M96YT97(@;VX@<&%R96YT"@D)=F%R('@@/2!O<&5N97(N<V-R965N6"`K("AO
M<&5N97(N;W5T97)7:61T:"`M('=I;F1O=RYO=71E<E=I9'1H*2`O(#(["@D)
M=F%R('D@/2!O<&5N97(N<V-R965N62`K("AO<&5N97(N;W5T97)(96EG:'0@
M+2!W:6YD;W<N;W5T97)(96EG:'0I("\@,CL*"0EW:6YD;W<N;6]V951O*'@L
M('DI.PH)?2!E;'-E('L*"0DO+R!W:6YD;W<N9&EA;&]G2&5I9VAT(#T@8F]D
M>2YO9F9S971(96EG:'0@*R`U,"`K(")P>"(["@D)+R\@=VEN9&]W+F1I86QO
M9U=I9'1H(#T@8F]D>2YO9F9S9717:61T:"`K(")P>"(["@D)=VEN9&]W+G)E
M<VEZ951O*&)O9'DN;V9F<V5T5VED=&@L(&)O9'E?:&5I9VAT*3L*"0EV87(@
M8V@@/2!B;V1Y+F-L:65N=$AE:6=H=#L*"0EV87(@8W<@/2!B;V1Y+F-L:65N
M=%=I9'1H.PH)"7=I;F1O=RYR97-I>F5">2AB;V1Y+F]F9G-E=%=I9'1H("T@
M8W<L(&)O9'E?:&5I9VAT("T@8V@I.PH)"79A<B!7(#T@8F]D>2YO9F9S9717
M:61T:#L*"0EV87(@2"`](#(@*B!B;V1Y7VAE:6=H="`M(&-H.PH)"79A<B!X
M(#T@*'-C<F5E;BYA=F%I;%=I9'1H("T@5RD@+R`R.PH)"79A<B!Y(#T@*'-C
M<F5E;BYA=F%I;$AE:6=H="`M($@I("\@,CL*"0EW:6YD;W<N;6]V951O*'@L
M('DI.PH)?0H)9&]C=6UE;G0N8F]D>2YO;FME>7!R97-S(#T@7U]D;&=?8VQO
M<V5?;VY?97-C.PI].PH*9G5N8W1I;VX@7U]D;&=?=')A;G-L871E*&DQ.&XI
M('L*"79A<B!T>7!E<R`](%LB:6YP=70B+"`B<V5L96-T(BP@(FQE9V5N9"(L
M(")S<&%N(BP@(F]P=&EO;B(L(")T9"(L(")B=71T;VXB+"`B9&EV(ET["@EF
M;W(@*'9A<B!T>7!E(#T@,#L@='EP92`\('1Y<&5S+FQE;F=T:#L@*RMT>7!E
M*2!["@D)=F%R('-P86YS(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA
M;64H='EP97-;='EP95TI.PH)"69O<B`H=F%R(&D@/2!S<&%N<RYL96YG=&@[
M("TM:2`^/2`P.RD@>PH)"0EV87(@<W!A;B`]('-P86YS6VE=.PH)"0EI9B`H
M<W!A;BYF:7)S=$-H:6QD("8F('-P86XN9FER<W1#:&EL9"YD871A*2!["@D)
M"0EV87(@='AT(#T@:3$X;EMS<&%N+F9I<G-T0VAI;&0N9&%T85T["@D)"0EI
M9B`H='AT*0H)"0D)"7-P86XN9FER<W1#:&EL9"YD871A(#T@='AT.PH)"0E]
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS<&%N+G1I=&QE*2!["@D)
M"0EV87(@='AT(#T@:3$X;EMS<&%N+G1I=&QE73L*"0D)"6EF("AT>'0I"@D)
M"0D)<W!A;BYT:71L92`]('1X=#L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H)"7T*"7T*"79A<B!T>'0@/2!I,3AN6V1O8W5M96YT+G1I=&QE73L*"6EF
M("AT>'0I"@D)9&]C=6UE;G0N=&ET;&4@/2!T>'0["GT["@HO+R!C;&]S97,@
M=&AE(&1I86QO9R!A;F0@<&%S<V5S('1H92!R971U<FX@:6YF;R!U<'!E<BX*
M9G5N8W1I;VX@7U]D;&=?8VQO<V4H=F%L*2!["@EO<&5N97(N1&EA;&]G+E]R
M971U<FXH=F%L*3L*"7=I;F1O=RYC;&]S92@I.PI].PH*9G5N8W1I;VX@7U]D
M;&=?8VQO<V5?;VY?97-C*&5V*2!["@EE=B!\?"`H978@/2!W:6YD;W<N979E
M;G0I.PH):68@*&5V+FME>4-O9&4@/3T@,C<I('L*"0EW:6YD;W<N8VQO<V4H
M*3L*"0ER971U<FX@9F%L<V4["@E]"@ER971U<FX@=')U93L*?3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&]P=7!S+V%B;W5T+FAT;6P`````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,P,3`U`#$P
M-3$U-#,Q,#8T`#`R-#8T,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\(2TM"@HH8RD@9'EN87)C:"YC;VTL(#(P,#,M,C`P
M-0I!=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES
M:&]O"D1I<W1R:6)U=&5D(&%S('!A<G0@;V8@2%1-3$%R96$@,RXP"@HB66]U
M(&%R92!N;W0@97AP96-T960@=&\@=6YD97)S=&%N9"!T:&ES+BXN("!)(&1O
M;B=T(&YE:71H97(N(@H*("`@("`@("`@("`@("`@("`@("`@("AF<F]M(%1H
M92!,:6YU>"!+97)N96P@4V]U<F-E($-O9&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N+V%R8V@O>#@V7S8T+VEA,S(O<'1R86-E+F,Z.3`I"@H[
M+2D*"BTM/@H*/&AT;6P@<W1Y;&4](FAE:6=H=#H@,3`P)2(^"CQH96%D/@H\
M;65T82!H='1P+65Q=6EV/2)#;VYT96YT+51Y<&4B(&-O;G1E;G0](G1E>'0O
M:'1M;#L@8VAA<G-E=#UU=&8M."(@+SX*/'1I=&QE/D%B;W5T($A434Q!<F5A
M/"]T:71L93X*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB
M<&]P=7`N:G,B/CPO<V-R:7!T/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C
M<FEP="(^"G=I;F1O=RYR97-I>F54;R@T-3`L(#(U,"D["G9A<B!404)3(#T@
M6UT["G9A<B!#55)214Y47U1!0B`](#`["G9A<B!#3TY414Y47TA%24=(5%]$
M249&(#T@,#L*=F%R($-/3E1%3E1?5TE$5$A?1$E&1B`](#`["F9U;F-T:6]N
M('-E;&5C=%1A8BAI9'@I('L*("!V87(@8W0@/2!404)36T-54E)%3E1?5$%"
M73L*("!C="YC;&%S<TYA;64@/2!C="YC;&%S<TYA;64N<F5P;&%C92@O7',J
M=&%B+6-U<G)E;G1<<RHO+"`G("<I.PH@(&-T(#T@5$%"4UM#55)214Y47U1!
M0B`](&ED>%T["B`@8W0N8VQA<W-.86UE("L]("<@=&%B+6-U<G)E;G0G.PH@
M(&9O<B`H=F%R(&D@/2!404)3+FQE;F=T:#L@+2UI(#X](#`[*2!["B`@("!V
M87(@87)E82`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")T86(M87)E82TB
M("L@:2D["B`@("!I9B`H0U524D5.5%]404(@/3T@:2D@>PH@("`@("!A<F5A
M+G-T>6QE+F1I<W!L87D@/2`B8FQO8VLB.PH@("`@?2!E;'-E('L*("`@("`@
M87)E82YS='EL92YD:7-P;&%Y(#T@(FYO;F4B.PH@("`@?0H@('T*("!D;V-U
M;65N="YB;V1Y+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N(CL*("!D;V-U
M;65N="YB;V1Y+G-T>6QE+G9I<VEB:6QI='D@/2`B=FES:6)L92(["B`@9&]C
M=6UE;G0N8V]O:VEE(#T@(DA434Q!4D5!+4%"3U54+51!0CTB("L@:61X.PI]
M"G9A<B!E9&ET;W(@/2!N=6QL.PIF=6YC=&EO;B!I;FET1&]C=6UE;G0H*2![
M"B`@961I=&]R(#T@=VEN9&]W+F1I86QO9T%R9W5M96YT<SL*("!(5$U,07)E
M82`]('=I;F1O=RYO<&5N97(N2%1-3$%R96$["@H@('9A<B!P;'5G:6YS(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(G!L=6=I;G,B*3L*("!V87(@:B`]
M(#`["B`@=F%R(&AT;6P@/2`B/'1A8FQE('=I9'1H/2<Y.24G(&-E;&QP861D
M:6YG/2<P)R!S='EL93TG;6%R9VEN+71O<#H@,65M.R!C;VQL87!S92UB;W)D
M97)S.B!C;VQL87!S93L@8F]R9&5R.B`Q<'@@<V]L:60@(SAB.#LG/B(@*PH)
M("`B/'1H96%D/CQT<CXB("L*"2`@(CQT9#Y.86UE/"]T9#XB("L*"2`@(CQT
M9#Y$979E;&]P97(\+W1D/B(@*PH)("`B/'1D/E-P;VYS;W)E9"!B>3PO=&0^
M(B`K"@D@("(\=&0^3&EC96YS93QS=7`^*CPO<W5P/CPO=&0^(B`K"@D@("(\
M+W1R/CPO=&AE860^/'1B;V1Y/B(["B`@9F]R("AV87(@:2!I;B!E9&ET;W(N
M<&QU9VEN<RD@>PH@("`@=F%R(&EN9F\@/2!E9&ET;W(N<&QU9VEN<UMI73L*
M("`@(&AT;6P@*ST@(CQT<CX\=&0^(B`K(&EN9F\N;F%M92`K("(@=B(@*R!I
M;F9O+G9E<G-I;VX@*R`B/"]T9#XB("L*("`@("`@("`@("`@(CQT9#X\82!H
M<F5F/2<B("L@:6YF;RYD979E;&]P97)?=7)L("L@(B<@=&%R9V5T/2=?8FQA
M;FLG('1I=&QE/2=6:7-I="!D979E;&]P97(@=V5B<VET92<^(B`K"@D@("`@
M:6YF;RYD979E;&]P97(@*R`B/"]A/CPO=&0^(B`K"@D@("`@(CQT9#X\82!H
M<F5F/2<B("L@:6YF;RYS<&]N<V]R7W5R;"`K("(G('1A<F=E=#TG7V)L86YK
M)R!T:71L93TG5FES:70@<W!O;G-O<B!W96)S:71E)SXB("L*"2`@("!I;F9O
M+G-P;VYS;W(@*R`B/"]A/CPO=&0^(B`K"@D@("`@(CQT9#XB("L@:6YF;RYL
M:6-E;G-E("L@(CPO=&0^/"]T<CXB.PH@("`@*RMJ.PH@('T*"B`@:68@*&HI
M('L*("`@("`@("`@(&AT;6P@*ST@(CPO=&)O9'D^/"]T86)L93XB("L*"0D@
M("(\<#X\<W5P/BH\+W-U<#X@3&EC96YS92!<(FAT;6Q!<F5A7"(@;65A;G,@
M=&AA="!T:&4@<&QU9VEN(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M('1E<FUS("(@*PH)"2`@(F%S($A434Q!<F5A(&ET<V5L9BX@(%-U8V@@<&QU
M9VEN<R!A<F4@;&EK96QY('1O(&)E('1H;W-E(&EN8VQU9&5D(&EN('1H92!O
M9F9I8VEA;"`B("L*"0D@(")(5$U,07)E82!D:7-T<FEB=71I;VX\+W`^(CL*
M"2`@<&QU9VEN<RYI;FYE<DA434P@/2`B/'`^5&AE(&9O;&QO=VEN9R!P;'5G
M:6YS(&AA=F4@8F5E;B!L;V%D960N/"]P/B(@*R!H=&UL.PH@('T@96QS92![
M"@D@('!L=6=I;G,N:6YN97)(5$U,(#T@(CQP/DYO('!L=6=I;G,@:&%V92!B
M965N(&QO861E9#PO<#XB.PH@('T*"B`@<&QU9VEN<RYI;FYE<DA434P@*ST@
M(CQP/E5S97(@86=E;G0@<F5P;W)T<SH\8G(O/B(@*R!N879I9V%T;W(N=7-E
M<D%G96YT("L@(CPO<#XB.PH*("!V87(@8V]N=&5N="`](&1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*")C;VYT96YT(BD["B`@:68@*'=I;F1O=RYI;FYE<DAE
M:6=H="D@>PH@("`@0T].5$5.5%](14E'2%1?1$E&1B`]('=I;F1O=RYI;FYE
M<DAE:6=H="`M(#(U,#L*("`@($-/3E1%3E1?5TE$5$A?1$E&1B`]('=I;F1O
M=RYI;FYE<E=I9'1H("T@8V]N=&5N="YO9F9S9717:61T:#L*("!](&5L<V4@
M>PH@("`@0T].5$5.5%](14E'2%1?1$E&1B`](&1O8W5M96YT+F)O9'DN;V9F
M<V5T2&5I9VAT("T@,C4P.PH@("`@0T].5$5.5%]724142%]$249&(#T@9&]C
M=6UE;G0N8F]D>2YO9F9S9717:61T:"`M(#0P,#L*("!]"B`@=VEN9&]W+F]N
M<F5S:7IE*"D["B`@=F%R(&)A<B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*")T86)B87(B*3L*("!J(#T@,#L*("!F;W(@*'9A<B!I(#T@8F%R+F9I<G-T
M0VAI;&0[(&D[(&D@/2!I+FYE>'13:6)L:6YG*2!["B`@("!404)3+G!U<V@H
M:2D["B`@("!I+E]?;7-H7W1A8B`](&H["B`@("!I+F]N;6]U<V5D;W=N(#T@
M9G5N8W1I;VXH978I('L@<V5L96-T5&%B*'1H:7,N7U]M<VA?=&%B*3L@2%1-
M3$%R96$N7W-T;W!%=F5N="AE=B!\?"!W:6YD;W<N979E;G0I.R!].PH@("`@
M=F%R(&%R96$@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B=&%B+6%R96$M
M(B`K(&HI.PH@("`@:68@*"]T86(M8W5R<F5N="\N=&5S="AI+F-L87-S3F%M
M92DI('L*("`@("`@0U524D5.5%]404(@/2!J.PH@("`@("!A<F5A+G-T>6QE
M+F1I<W!L87D@/2`B8FQO8VLB.PH@("`@?2!E;'-E('L*("`@("`@87)E82YS
M='EL92YD:7-P;&%Y(#T@(FYO;F4B.PH@("`@?0H@("`@*RMJ.PH@('T*("!I
M9B`H9&]C=6UE;G0N8V]O:VEE+FUA=&-H*"](5$U,05)%02U!0D]55"U404(]
M*%LP+3E=*RDO*2D*("`@('-E;&5C=%1A8BA296=%>'`N)#$I.PI]"G=I;F1O
M=RYO;G)E<VEZ92`](&9U;F-T:6]N*"D@>PH@('9A<B!C;VYT96YT(#T@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H(F-O;G1E;G0B*3L*("!I9B`H=VEN9&]W
M+FEN;F5R2&5I9VAT*2!["B`@("!C;VYT96YT+G-T>6QE+FAE:6=H="`]("AW
M:6YD;W<N:6YN97)(96EG:'0@+2!#3TY414Y47TA%24=(5%]$249&*2`K(")P
M>"(["B`@("!C;VYT96YT+G-T>6QE+G=I9'1H(#T@*'=I;F1O=RYI;FYE<E=I
M9'1H("T@0T].5$5.5%]724142%]$249&*2`K(")P>"(["B`@?2!E;'-E('L*
M("`@(&-O;G1E;G0N<W1Y;&4N:&5I9VAT(#T@*&1O8W5M96YT+F)O9'DN;V9F
M<V5T2&5I9VAT("T@0T].5$5.5%](14E'2%1?1$E&1BD@*R`B<'@B.PH@("`@
M+R]C;VYT96YT+G-T>6QE+G=I9'1H(#T@*&1O8W5M96YT+F)O9'DN;V9F<V5T
M5VED=&@@+2!#3TY414Y47U=)1%1(7T1)1D8I("L@(G!X(CL*("!]"GT*/"]S
M8W)I<'0^"CQS='EL93X*("!H=&UL+&)O9'DL=&5X=&%R96$L=&%B;&4@>R!F
M;VYT+69A;6EL>3H@=&%H;VUA+'9E<F1A;F$L87)I86P[(&9O;G0M<VEZ93H@
M,3%P>#L*<&%D9&EN9SH@,'!X.R!M87)G:6XZ(#!P>#L@?0H@('1T('L@9F]N
M="US:7IE.B`Q,C`E.R!]"B`@8F]D>2![('!A9&1I;F<Z(#!P>#L@8F%C:V=R
M;W5N9#H@(V-E83L@8V]L;W(Z(#`P,#L@?0H@(&$Z;&EN:RP@83IV:7-I=&5D
M('L@8V]L;W(Z(",P,&8[('T*("!A.FAO=F5R('L@8V]L;W(Z("-F,#`[('T*
M("!A.F%C=&EV92![(&-O;&]R.B`C9C@P.R!]"B`@8G5T=&]N('L@9F]N=#H@
M,3%P>"!T86AO;6$L=F5R9&%N82QS86YS+7-E<FEF.R!B86-K9W)O=6YD+6-O
M;&]R.B`C8V5A.PH@("`@("!B;W)D97(M=VED=&@Z(#%P>#L@?0H*("!P('L@
M;6%R9VEN.B`P+C5E;2`P<'@[('T*"B`@:#$@>R!F;VYT.B!B;VQD(#$S,"4@
M9V5O<F=I82PB=&EM97,@;F5W(')O;6%N(BQS97)I9CL@;6%R9VEN.B`P<'@[
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-F$V.R!]"B`@:#(@>R!F;VYT
M.B!B;VQD(#$Q,"4@9V5O<F=I82PB=&EM97,@;F5W(')O;6%N(BQS97)I9CL@
M;6%R9VEN.B`P+C=E;2`P<'@[('T*"B`@=&AE860@>PH@("`@9F]N="UW96EG
M:'0Z(&)O;&0["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9&9B.PH@('T*"B`@
M+FQO9V\L("YL;V=O+6AO=F5R('L*("`@('=H:71E+7-P86-E.B!N;W=R87`[
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C.&8T.R!C;VQO<CH@(S`T,#L@<&%D
M9&EN9SH@,W!X.R!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S4U-3L*("`@
M(&AE:6=H=#H@-65M.PH@('T*("`N;&]G;R`N8G)A;F0L("YL;V=O+6AO=F5R
M("YB<F%N9"!["B`@("!M87)G:6XM;&5F=#H@,"XU96T[(&UA<F=I;BUR:6=H
M=#H@,"XU96T[('!A9&1I;F<M8F]T=&]M.B`P+C%E;3L*("`@(&9O;G0M9F%M
M:6QY.B!I;7!A8W0L)V%R:6%L(&)L86-K)RQA<FEA;"QS86YS+7-E<FEF.R!F
M;VYT+7-I>F4Z(#(X<'@["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(S4Y-3L@=&5X="UA;&EG;CH@8V5N=&5R.PH@("`@8W5R<V]R.B!P;VEN=&5R
M.PH@('T*("`N;&]G;RUH;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M9F9F.PH@('T*("`N;&]G;RUH;W9E<B`N8G)A;F0@>PH@("`@8V]L;W(Z(",X
M,#`["B`@("!B;W)D97(M8V]L;W(Z(",P-&8["B`@?0H@("YL;V=O("YL971T
M97(L("YL;V=O+6AO=F5R("YL971T97(@>R!P;W-I=&EO;CH@<F5L871I=F4[
M(&9O;G0M9F%M:6QY.B!M;VYO<W!A8V4[('T*("`N;&]G;R`N;&5T=&5R,2![
M('1O<#H@,"XQ96T[('T*("`N;&]G;R`N;&5T=&5R,B![('1O<#H@,"XP-65M
M.R!]"B`@+FQO9V\@+FQE='1E<C,@>R!T;W`Z("TP+C`U96T[('T*("`N;&]G
M;R`N;&5T=&5R-"![('1O<#H@+3`N,65M.R!]"@H@("YL;V=O+6AO=F5R("YL
M971T97(Q('L@=&]P.B`M,"XQ96T[('T*("`N;&]G;RUH;W9E<B`N;&5T=&5R
M,B![('1O<#H@+3`N,#5E;3L@?0H@("YL;V=O+6AO=F5R("YL971T97(S('L@
M=&]P.B`P+C`U96T[('T*("`N;&]G;RUH;W9E<B`N;&5T=&5R-"![('1O<#H@
M,"XQ96T[('T*("`N;&]G;R`N=F5R<VEO;BP@+FQO9V\M:&]V97(@+G9E<G-I
M;VX@>R!F;VYT+69A;6EL>3H@9V5O<F=I82PB=&EM97,@;F5W(')O;6%N(BQS
M97)I9CL@?0H@("YL;V=O("YR96QE87-E('L*("`@(&9O;G0M<VEZ93H@.3`E
M.R!M87)G:6XM8F]T=&]M.B`Q96T["B`@("!T97AT+6%L:6=N.B!C96YT97([
M(&-O;&]R.B`C-#@T.PH@('T*("`N;&]G;R`N=FES:70@>R!D:7-P;&%Y.B!N
M;VYE.R!]"B`@+FQO9V\M:&]V97(@+G)E;&5A<V4@>R!D:7-P;&%Y.B!N;VYE
M.R!]"B`@+FQO9V\M:&]V97(@+G9I<VET('L*("`@(&9O;G0M<VEZ93H@.3`E
M.R!M87)G:6XM8F]T=&]M.B`Q96T["B`@("!T97AT+6%L:6=N.B!C96YT97([
M(&-O;&]R.B`C-#0X.PH@('T*("`N8G5T=&]N<R!["B`@("!T97AT+6%L:6=N
M.B!R:6=H=#L@<&%D9&EN9SH@,W!X.R!B86-K9W)O=6YD+6-O;&]R.B`C.&8T
M.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",U-34["B`@?0H@("-T86)B
M87(@>PH@("`@<&]S:71I;VXZ(')E;&%T:79E.PH@("`@;&5F=#H@,3!P>#L*
M("!]"B`@+G1A8B!["B`@("!C;VQO<CH@(S0U-#L*("`@(&-U<G-O<CH@<&]I
M;G1E<CL*("`@(&UA<F=I;BUL969T.B`M-7!X.PH@("`@9FQO870Z(&QE9G0[
M('!O<VET:6]N.B!R96QA=&EV93L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",U
M-34["B`@("!T;W`Z("TS<'@[(&QE9G0Z("TR<'@["B`@("!P861D:6YG.B`R
M<'@@,3!P>"`S<'@@,3!P>#L*("`@(&)O<F1E<BUT;W`Z(&YO;F4[(&)A8VMG
M<F]U;F0M8V]L;W(Z(",Y8C<["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#!P
M>"`P<'@@-'!X(#1P>#L*("`@('HM:6YD97@Z(#`["B`@?0H@("YT86(M8W5R
M<F5N="!["B`@("!C;VQO<CH@(S`P,#L*("`@('1O<#H@+31P>#L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-C96$["B`@("!P861D:6YG.B`S<'@@,3!P>"`T
M<'@@,3!P>#L*("`@('HM:6YD97@Z(#$P.PH@('T*("!T86)L92YS<&]N<V]R
M<R![(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C86-A.R!]"B`@=&%B;&4N<W!O
M;G-O<G,@=&0@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-A8V$[
M('9E<G1I8V%L+6%L:6=N.B!T;W`["B`@?0H@('1A8FQE+G-P;VYS;W)S('1R
M('1D('L@<&%D9&EN9SH@,G!X(#!P>#L@?0H@('1A8FQE+G-P;VYS;W)S('1R
M('1D+G-P;VYS;W(@>R!T97AT+6%L:6=N.B!R:6=H=#L@<&%D9&EN9RUR:6=H
M=#H@,"XS96T[('=H:71E+7-P86-E.B!N;W=R87`[('T*("!L:2P@;VPL('5L
M('L@;6%R9VEN+71O<#H@,'!X.R!M87)G:6XM8F]T=&]M.B`P<'@[('T*/"]S
M='EL93X\+VAE860^"CQB;V1Y(&]N;&]A9#TB7U]D;&=?:6YI="@I.R!I;FET
M1&]C=6UE;G0H*3LB"CX\=&%B;&4@8V5L;'-P86-I;F<](C`B(&-E;&QP861D
M:6YG/2(P(B!S='EL93TB8F]R9&5R+6-O;&QA<'-E.B!C;VQL87!S93L*("`@
M("`@=VED=&@Z(#$P,"4[(&AE:6=H=#H@,3`P)3LB/@H*/'1R('-T>6QE/2)H
M96EG:'0Z(#%E;2(^/'1D(&ED/2)T9&AE861E<B(^"@H\9&EV(&-L87-S/2)L
M;V=O(CX*/&1I=B!C;&%S<STB8G)A;F0B"F]N;6]U<V5O=F5R/2)T:&ES+G!A
M<F5N=$YO9&4N8VQA<W-.86UE/2=L;V=O+6AO=F5R)SLB"F]N;6]U<V5O=70]
M(G1H:7,N<&%R96YT3F]D92YC;&%S<TYA;64])VQO9V\G.R(*;VYC;&EC:STB
M=VEN9&]W+F]P96XH)VAT='`Z+R]W=W<N:'1M;&%R96$N8V]M+R<I.R(^"CQS
M<&%N(&-L87-S/2)L971T97(@;&5T=&5R,2(^)FQT.T@\+W-P86X^/'-P86X*
M8VQA<W,](FQE='1E<B!L971T97(R(CY4/"]S<&%N/CQS<&%N"F-L87-S/2)L
M971T97(@;&5T=&5R,R(^33PO<W!A;CX\<W!A;@IC;&%S<STB;&5T=&5R(&QE
M='1E<C0B/DP\+W-P86X^07)E82`\<W!A;B!C;&%S<STB;&5T=&5R(CXO)F=T
M.SPO<W!A;CX*/'-P86X@8VQA<W,](G9E<G-I;VXB/C,N,"`\<W!A;B!S='EL
M93TB<&]S:71I;VXZ(')E;&%T:79E.R!T;W`Z("TP+C9E;3L@9F]N="US:7IE
M.B`U,"4[(&9O;G0M=V5I9VAT.B!N;W)M86PB/EL@<F5V+B!B971A*R!=/"]S
M<&%N/CPO<W!A;CX\+V1I=CX*/&1I=B!C;&%S<STB<F5L96%S92(^0V]M<&EL
M960@;VX@36%Y(#$W+"`R,#`U(#`Q.C`X($=-5#PO9&EV/@H\9&EV(&-L87-S
M/2)V:7-I="(^1V\@=&\@:'1T<#HO+W=W=RYH=&UL87)E82YC;VTO(%ML871E
M<W0@;6EL97-T;VYE(')E;&5A<V5=/"]D:78^"CPO9&EV/@H*/"]T9#X\+W1R
M/@H\='(^/'1D(&ED/2)T9&-O;G1E;G0B('-T>6QE/2)P861D:6YG.B`P+C5E
M;3LB/@H*/&1I=B!S='EL93TB;W9E<F9L;W<Z(&%U=&\[(&AE:6=H=#H@,C4P
M<'@[(B!I9#TB8V]N=&5N="(^"CQD:78@:60](G1A8BUA<F5A<R(^"@H\9&EV
M(&ED/2)T86(M87)E82TP(CX*"B`@/&@Q/DA434Q!<F5A/"]H,3X*"B`@/'`^
M02!F<F5E(%=94TE764<@961I=&]R(')E<&QA8V5M96YT(&9O<B`\='0^)FQT
M.W1E>'1A<F5A)F=T.SPO='0^(&9I96QD<RX\8G(@+SX*("!&;W(@36]Z:6QL
M82`Q+C,K("AA;GD@<&QA=&9O<FTI(&]R($EN=&5R;F5T($5X<&QO<F5R(#4N
M-2L@*%=I;F1O=W,I+@H@(#PO<#X*"B`@/'`@<W1Y;&4](G1E>'0M86QI9VXZ
M(&-E;G1E<B(*("`^PJD@,C`P,BTR,#`T(#QA(&AR968](FAT='`Z+R]I;G1E
M<F%C=&EV971O;VQS+F-O;2(@=&%R9V5T/2)?8FQA;FLB/FEN=&5R86-T:79E
M=&]O;',N8V]M/"]A/BP@:6YC+CQB<B`O/@H@(,*I(#(P,#,M,C`P-2`\82!H
M<F5F/2)H='1P.B\O9'EN87)C:"YC;VTB('1A<F=E=#TB7V)L86YK(CYD>6YA
M<F-H+F-O;3PO83X@3$Q#+CQB<B`O/@H@($%L;"!2:6=H=',@4F5S97)V960N
M/"]P/@H*("`\:#(^4')O:F5C="!R97-O=7)C97,\+V@R/@H*("`\=6P^"B`@
M/&QI/CQA(&AR968](FAT='`Z+R]S;W5R8V5F;W)G92YN970O<')O:F5C=',O
M:71O;VQS+6AT;6QA<F5A+R(@=&%R9V5T/2)?8FQA;FLB"B`@/E!R;VIE8W0@
M<&%G93PO83X@*$`@<V]U<F-E9F]R9V4N;F5T*3PO;&D^"B`@/&QI/CQA(&AR
M968](FAT='`Z+R]S;W5R8V5F;W)G92YN970O8W9S+S]G<F]U<%]I9#TV.3<U
M,"(@=&%R9V5T/2)?8FQA;FLB"B`@/D%N;VYY;6]U<R!#5E,@86-C97-S/"]A
M/B`H0"!S;W5R8V5F;W)G92YN970I/"]L:3X*("`\;&D^/&$@:')E9CTB:'1T
M<#HO+W-O=7)C969O<F=E+FYE="]T<F%C:V5R+S]A=&ED/34R-38U-B9G<F]U
M<%]I9#TV.3<U,"9F=6YC/6)R;W=S92(@=&%R9V5T/2)?8FQA;FLB"B`@/D)U
M9R!S>7-T96T\+V$^("A`('-O=7)C969O<F=E+FYE="D\+VQI/@H@(#QL:3X\
M82!H<F5F/2)H='1P.B\O=W=W+FAT;6QA<F5A+F-O;2]F;W)U;2\B('1A<F=E
M=#TB7V)L86YK(@H@(#Y&;W)U;3PO83X@*$`@:6YT97)A8W1I=F5T;V]L<RYC
M;VTI/"]L:3X*("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W=RYH=&UL87)E82YC
M;VTO(B!T87)G970](E]B;&%N:R(*("`^3&%S="!P=6)L:6,@<F5L96%S93PO
M83X\+VQI/@H@(#PO=6P^"@H@(#QP/@H@($9O<B!D;W=N;&]A9"!S96-T:6]N
M('!L96%S92!S964@=&AE(#QA(&AR968](FAT='`Z+R]S;W5R8V5F;W)G92YN
M970O<')O:F5C=',O:71O;VQS+6AT;6QA<F5A+R(@=&%R9V5T/2)?8FQA;FLB
M"B`@/G!R;VIE8W0@<&%G92!`(%-O=7)C949O<F=E/"]A/BX*("`\+W`^"@H\
M+V1I=CX*"CQD:78@:60](G1A8BUA<F5A+3$B/@H\:#$^5&AA;FL@>6]U/"]H
M,3X*"B`@/'`^"B`@/&$@:')E9CTB:'1T<#HO+V1Y;F%R8V@N8V]M(B!T87)G
M970](E]B;&%N:R(^9'EN87)C:"YC;VT\+V$^('=O=6QD(&QI:V4@=&\@=&AA
M;FL@=&AE(&9O;&QO=VEN9PH@(&-O;7!A;FEE<R]P97)S;VYS(&9O<B!T:&5I
M<B`\96T^9&]N871I;VYS/"]E;3X@=&\@<W5P<&]R="!D979E;&]P;65N="!O
M9B!(5$U,07)E82`H;&ES=&5D(&%L<&AA8F5T:6-A;&QY*3H*("`\+W`^"@H@
M(#QU;#X*("`@(#QL:3X\82!H<F5F/2)H='1P.B\O=W=W+F-O;7!U=&5R;&]V
M92YC;RYU:R(@=&%R9V5T/2)?8FQA;FLB/D-O9&4@0V]M<'5T97(@3&]V92!,
M=&0N/"]A/B`H54LI/"]L:3X*("`@(#QL:3X\82!H<F5F/2)H='1P.B\O=W=W
M+FYE;VUE9&EA+G)O(B!T87)G970](E]B;&%N:R(^3F5O;65D:6$\+V$^("A2
M;VUA;FEA*3PO;&D^"B`@("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W=RYO<S,N
M:70B('1A<F=E=#TB7V)L86YK(CY/4S,\+V$^("A)=&%L>2D\+VQI/@H@("`@
M/&QI/CQA(&AR968](FAT='`Z+R]W=W<N<V]F='=E<FLN;F5T(B!T87)G970]
M(E]B;&%N:R(^4V]F=%=E<FL\+V$^("A)=&%L>2D\+VQI/@H@(#PO=6P^"@H@
M(#QP/D%L<V\@;6%N>2!T:&%N:W,@=&\@86QL('!E;W!L92!A="!);G1E<F%C
M=&EV951O;VQS+F-O;0H@(#QA(&AR968](FAT='`Z+R]W=W<N:'1M;&%R96$N
M8V]M+V9O<G5M+R(^2%1-3$%R96$@9F]R=6US/"]A/B!F;W(*("!C;VYT<FEB
M=71I;F<@=')A;G-L871I;VYS+"!F965D8F%C:RP@8G5G(')E<&]R=',@86YD
M(&9I>&5S+CPO<#X*"B`@/'`^"B`@3&%S="!B=70@;F]T(&QE87-T+"!T:&ES
M('!R;VIE8W0@=V]U;&1N)W0@:&%V92!E>&ES=&5D('=I=&AO=70*("`\82!H
M<F5F/2)H='1P.B\O:6YT97)A8W1I=F5T;V]L<RYC;VTB('1A<F=E=#TB7V)L
M86YK(CY);G1E<F%C=&EV951O;VQS+F-O;3PO83XN"B`@/"]P/@H*/"]D:78^
M"@H\9&EV(&ED/2)T86(M87)E82TR(CX*/&@Q/FAT;6Q!<F5A($QI8V5N<V4@
M*&)A<V5D(&]N($)31"!L:6-E;G-E*3PO:#$^"@H\<"!S='EL93TB=&5X="UA
M;&EG;CH@8V5N=&5R(C["J2`R,#`R+3(P,#0L(&EN=&5R86-T:79E=&]O;',N
M8V]M+"!I;F,N/&)R("\^"B`@PJD@,C`P,RTR,#`T(&1Y;F%R8V@N8V]M($Q,
M0SQB<B`O/@H@($%L;"!R:6=H=',@<F5S97)V960N/"]P/@H*/'`^"E)E9&ES
M=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L
M('=I=&@@;W(@=VET:&]U=`IM;V1I9FEC871I;VXL(&%R92!P97)M:71T960@
M<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@87)E(&UE
M=#H*/"]P/@H*/&]L/@H\;&D^"E)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@
M8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*
M=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES
M8VQA:6UE<BX*/"]L:3X*"CQL:3X*4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R
M>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`IT:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N"F%N9"]O<B!O=&AE
M<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H\
M+VQI/@H*/&QI/@I.96ET:&5R('1H92!N86UE(&]F(&EN=&5R86-T:79E=&]O
M;',N8V]M+"!I;F,N(&YO<B!T:&4@;F%M97,@;V8@:71S"F-O;G1R:6)U=&]R
M<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@
M9&5R:79E9"!F<F]M('1H:7,*<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P
M<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"CPO;&D^"CPO;VP^"@H\<#X*5$A)
M4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%
M4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"D%.1"!!3ED@15A04D534R!/
M4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)
M5$5$(%1/+"!42$4*24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))
M3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@
M3U=.15(@3U(@0T].5%))0E543U)3($)%"DQ)04),12!&3U(@04Y9($1)4D5#
M5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@
M3U(*0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@
M3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*4U5"4U1)5%5412!'3T]$4R!/
M4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2
M($)54TE.15-3"DE.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].
M($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E."D-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I"D%225-)3D<@24X@04Y9(%=!62!/550@3T8@
M5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@
M5$A%"E!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H\+W`^"@H\+V1I=CX*
M"CQD:78@:60](G1A8BUA<F5A+3,B/@H\:#$^4&QU9VEN<SPO:#$^"CQD:78@
M:60](G!L=6=I;G,B/@H\+V1I=CX*/"]D:78^"@H\+V1I=CX\+V1I=CX*"@H\
M+W1R/CPO=&0^"CQT<B!S='EL93TB:&5I9VAT.B`Q96TB/CQT9"!I9#TB=&1F
M;V]T97(B/@H*"CQD:78@8VQA<W,](F)U='1O;G,B/@H\9&EV(&ED/2)T86)B
M87(B"CX\9&EV(&-L87-S/2)T86(@=&%B+6-U<G)E;G0B"CY!8F]U=#PO9&EV
M/CQD:78@8VQA<W,](G1A8B(*/E1H86YK<SPO9&EV/CQD:78@8VQA<W,](G1A
M8B(*/DQI8V5N<V4\+V1I=CX\9&EV(&-L87-S/2)T86(B"CY0;'5G:6YS/"]D
M:78^/"]D:78^"CQB=71T;VX@='EP93TB8G5T=&]N(B!O;F-L:6-K/2)?7V1L
M9U]C;&]S92AN=6QL*3LB/DD@86=R964@:70G<R!C;V]L/"]B=71T;VX^"CPO
M9&EV/@H*/"]T9#X\+W1R/CPO=&%B;&4^"@H\+V)O9'D^/"]H=&UL/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P
M<R]S96QE8W1?8V]L;W(N:'1M;``````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W,#$T,@`Q,#4Q-30S,3`V
M-``P,C8R,3,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/"$M+2!N;W1E.B!T:&ES('9E<G-I;VX@;V8@=&AE(&-O;&]R('!I
M8VME<B!I<R!O<'1I;6EZ960@9F]R($E%(#4N-2L@;VYL>2`M+3X-"@T*/&AT
M;6P^/&AE860^/'1I=&QE/E-E;&5C="!#;VQO<CPO=&ET;&4^#0H-"CQS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](G!O<'5P+FIS(CX\+W-C
M<FEP=#X-"@T*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@T*#0IW
M:6YD;W<N<F5S:7IE5&\H,C0P+"`Q.#(I.PT*9G5N8W1I;VX@7T-L;W-E3VY%
M<V,H*2![#0H@(&EF("AE=F5N="YK97E#;V1E(#T](#(W*2![('=I;F1O=RYC
M;&]S92@I.R!R971U<FX[('T-"GT-"@T*9G5N8W1I;VX@26YI="@I('L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@<G5N(&]N('!A9V4@;&]A9`T*("!?7V1L9U]I;FET*"D[("`@
M("\O(#PA+2T@=&AI<R!C86X@8F4@9F]U;F0@:6X@<&]P=7`N:G,@+2T^#0H@
M(&1O8W5M96YT+F)O9'DN;VYK97EP<F5S<R`](%]#;&]S94]N17-C.PT*#0H@
M('9A<B!C;VQO<B`]('=I;F1O=RYD:6%L;V=!<F=U;65N=',[#0H@(&-O;&]R
M(#T@5F%L:61A=&5#;VQO<BAC;VQO<BD@?'P@)S`P,#`P,"<[#0H@(%9I97<H
M8V]L;W(I.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!S970@9&5F875L="!C;VQO<@T*?0T*
M#0IF=6YC=&EO;B!6:65W*&-O;&]R*2![("`@("`@("`@("`@("`@("`@+R\@
M<')E=FEE=R!C;VQO<@T*("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B0V]L
M;W)0<F5V:65W(BDN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@)R,G("L@8V]L
M;W([#0H@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")#;VQO<DAE>"(I+G9A
M;'5E(#T@)R,G("L@8V]L;W([#0I]#0H-"F9U;F-T:6]N(%-E="AS=')I;F<I
M('L@("`@("`@("`@("`@("`@("`@+R\@<V5L96-T(&-O;&]R#0H@('9A<B!C
M;VQO<B`](%9A;&ED871E0V]L;W(H<W1R:6YG*3L-"B`@:68@*&-O;&]R(#T]
M(&YU;&PI('L@86QE<G0H(DEN=F%L:60@8V]L;W(@8V]D93H@(B`K('-T<FEN
M9RD[('T@("`@("`@("\O(&EN=F%L:60@8V]L;W(-"B`@96QS92![("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O('9A;&ED(&-O;&]R#0H@("`@5FEE=RAC;VQO<BD[
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!S:&]W('-E;&5C=&5D(&-O
M;&]R#0H@("`@7U]D;&=?8VQO<V4H8V]L;W(I.PT*("!]#0I]#0H-"F9U;F-T
M:6]N(%9A;&ED871E0V]L;W(H<W1R:6YG*2![("`@("`@("`@("`@("`@("\O
M(')E='5R;B!V86QI9"!C;VQO<B!C;V1E#0H@('-T<FEN9R`]('-T<FEN9R!\
M?"`G)SL-"B`@<W1R:6YG(#T@<W1R:6YG("L@(B([#0H@('-T<FEN9R`]('-T
M<FEN9RYT;U5P<&5R0V%S92@I.PT*("!V87(@8VAA<G,@/2`G,#$R,S0U-C<X
M.4%"0T1%1B<[#0H@('9A<B!O=70@("`]("<G.PT*#0H@(&9O<B`H=F%R(&D]
M,#L@:3QS=')I;F<N;&5N9W1H.R!I*RLI('L@("`@("`@("`@("`@+R\@<F5M
M;W9E(&EN=F%L:60@8V]L;W(@8VAA<G,-"B`@("!V87(@<V-H87(@/2!S=')I
M;F<N8VAA<D%T*&DI.PT*("`@(&EF("AC:&%R<RYI;F1E>$]F*'-C:&%R*2`A
M/2`M,2D@>R!O=70@*ST@<V-H87([('T-"B`@?0T*#0H@(&EF("AO=70N;&5N
M9W1H("$](#8I('L@<F5T=7)N(&YU;&P[('T@("`@("`@("`@("`O+R!C:&5C
M:R!L96YG=&@-"B`@<F5T=7)N(&]U=#L-"GT-"@T*/"]S8W)I<'0^#0H\+VAE
M860^#0H\8F]D>2!S='EL93TB8F%C:V=R;W5N9#I"=71T;VY&86-E.R!M87)G
M:6XZ,'!X.R!P861D:6YG.C!P>"(@;VYL;V%D/2));FET*"DB/@T*#0H\9F]R
M;2!M971H;V0](F=E="(@<W1Y;&4](FUA<F=I;CHP<'@[('!A9&1I;F<Z,'!X
M(B!O;E-U8FUI=#TB4V5T*&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=#;VQO
M<DAE>"<I+G9A;'5E*3L@<F5T=7)N(&9A;'-E.R(^#0H\=&%B;&4@8F]R9&5R
M/2(P<'@B(&-E;&QS<&%C:6YG/2(P<'@B(&-E;&QP861D:6YG/2(T(B!W:61T
M:#TB,3`P)2(^#0H@/'1R/@T*("`\=&0@<W1Y;&4](F)A8VMG<F]U;F0Z8G5T
M=&]N9F%C92(@=F%L:6=N/6-E;G1E<CX\9&EV('-T>6QE/2)B86-K9W)O=6YD
M+6-O;&]R.B`C,#`P,#`P.R!P861D:6YG.B`Q.R!H96EG:'0Z(#(Q<'@[('=I
M9'1H.B`U,'!X(CX\9&EV(&ED/2)#;VQO<E!R979I97<B('-T>6QE/2)H96EG
M:'0Z(#$P,"4[('=I9'1H.B`Q,#`E(CX\+V1I=CX\+V1I=CX\+W1D/@T*("`\
M=&0@<W1Y;&4](F)A8VMG<F]U;F0Z8G5T=&]N9F%C92(@=F%L:6=N/6-E;G1E
M<CX\:6YP=70@='EP93TB=&5X="(@;F%M93TB0V]L;W)(97@B#0H@("`@:60]
M(D-O;&]R2&5X(B!V86QU93TB(B!S:7IE/3$U('-T>6QE/2)F;VYT+7-I>F4Z
M(#$R<'@B/CPO=&0^#0H@(#QT9"!S='EL93TB8F%C:V=R;W5N9#IB=71T;VYF
M86-E(B!W:61T:#TQ,#`E/CPO=&0^#0H@/"]T<CX-"CPO=&%B;&4^#0H\+V9O
M<FT^#0H-"CQT86)L92!B;W)D97(](C`B(&-E;&QS<&%C:6YG/2(Q<'@B(&-E
M;&QP861D:6YG/2(P<'@B('=I9'1H/2(Q,#`E(B!B9V-O;&]R/2(C,#`P,#`P
M(B!S='EL93TB8W5R<V]R.B!H86YD.R(^#0H\='(^#0H\=&0@8F=C;VQO<CTC
M,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T
M*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G
M*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]
M5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P
M(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P
M,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P,S,P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#,S,#`G*2!O;D-L
M:6-K/5-E="@G,#`S,S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#8V,#`@;VY-;W5S94]V97(]5FEE=R@G
M,#`V-C`P)RD@;VY#;&EC:SU3970H)S`P-C8P,"<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.3`P(&]N36]U
M<V5/=F5R/59I97<H)S`P.3DP,"<I(&]N0VQI8VL]4V5T*"<P,#DY,#`G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P0T,P,"!O;DUO=7-E3W9E<CU6:65W*"<P,$-#,#`G*2!O;D-L:6-K/5-E
M="@G,#!#0S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,P,$9&,#`@;VY-;W5S94]V97(]5FEE=R@G,#!&1C`P
M)RD@;VY#;&EC:SU3970H)S`P1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,P,#`P(&]N36]U<V5/=F5R
M/59I97<H)S,S,#`P,"<I(&]N0VQI8VL]4V5T*"<S,S`P,#`G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,S,P
M,"!O;DUO=7-E3W9E<CU6:65W*"<S,S,S,#`G*2!O;D-L:6-K/5-E="@G,S,S
M,S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,S8V,#`@;VY-;W5S94]V97(]5FEE=R@G,S,V-C`P)RD@;VY#
M;&EC:SU3970H)S,S-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.3`P(&]N36]U<V5/=F5R/59I97<H
M)S,S.3DP,"<I(&]N0VQI8VL]4V5T*"<S,SDY,#`G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T,P,"!O;DUO
M=7-E3W9E<CU6:65W*"<S,T-#,#`G*2!O;D-L:6-K/5-E="@G,S-#0S`P)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,S,T9&,#`@;VY-;W5S94]V97(]5FEE=R@G,S-&1C`P)RD@;VY#;&EC:SU3
M970H)S,S1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC-C8P,#`P(&]N36]U<V5/=F5R/59I97<H)S8V,#`P
M,"<I(&]N0VQI8VL]4V5T*"<V-C`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,S,P,"!O;DUO=7-E3W9E
M<CU6:65W*"<V-C,S,#`G*2!O;D-L:6-K/5-E="@G-C8S,S`P)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C8V
M,#`@;VY-;W5S94]V97(]5FEE=R@G-C8V-C`P)RD@;VY#;&EC:SU3970H)S8V
M-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C8Y.3`P(&]N36]U<V5/=F5R/59I97<H)S8V.3DP,"<I(&]N
M0VQI8VL]4V5T*"<V-CDY,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V0T,P,"!O;DUO=7-E3W9E<CU6:65W
M*"<V-D-#,#`G*2!O;D-L:6-K/5-E="@G-C9#0S`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&,#`@;VY-
M;W5S94]V97(]5FEE=R@G-C9&1C`P)RD@;VY#;&EC:SU3970H)S8V1D8P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*/'1R
M/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P
M,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S,S,S,@;VY-;W5S94]V
M97(]5FEE=R@G,S,S,S,S)RD@;VY#;&EC:SU3970H)S,S,S,S,R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P
M,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P
M,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P,#`S,R!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,S,G*2!O
M;D-L:6-K/5-E="@G,#`P,#,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#,S,S,@;VY-;W5S94]V97(]5FEE
M=R@G,#`S,S,S)RD@;VY#;&EC:SU3970H)S`P,S,S,R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-C,S(&]N
M36]U<V5/=F5R/59I97<H)S`P-C8S,R<I(&]N0VQI8VL]4V5T*"<P,#8V,S,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P.3DS,R!O;DUO=7-E3W9E<CU6:65W*"<P,#DY,S,G*2!O;D-L:6-K
M/5-E="@G,#`Y.3,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,$-#,S,@;VY-;W5S94]V97(]5FEE=R@G,#!#
M0S,S)RD@;VY#;&EC:SU3970H)S`P0T,S,R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1C,S(&]N36]U<V5/
M=F5R/59I97<H)S`P1D8S,R<I(&]N0VQI8VL]4V5T*"<P,$9&,S,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S
M,#`S,R!O;DUO=7-E3W9E<CU6:65W*"<S,S`P,S,G*2!O;D-L:6-K/5-E="@G
M,S,P,#,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,S,S,S,S,@;VY-;W5S94]V97(]5FEE=R@G,S,S,S,S)RD@
M;VY#;&EC:SU3970H)S,S,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,V-C,S(&]N36]U<V5/=F5R/59I
M97<H)S,S-C8S,R<I(&]N0VQI8VL]4V5T*"<S,S8V,S,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3DS,R!O
M;DUO=7-E3W9E<CU6:65W*"<S,SDY,S,G*2!O;D-L:6-K/5-E="@G,S,Y.3,S
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,T-#,S,@;VY-;W5S94]V97(]5FEE=R@G,S-#0S,S)RD@;VY#;&EC
M:SU3970H)S,S0T,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,S-&1C,S(&]N36]U<V5/=F5R/59I97<H)S,S
M1D8S,R<I(&]N0VQI8VL]4V5T*"<S,T9&,S,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,#`S,R!O;DUO=7-E
M3W9E<CU6:65W*"<V-C`P,S,G*2!O;D-L:6-K/5-E="@G-C8P,#,S)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V
M-C,S,S,@;VY-;W5S94]V97(]5FEE=R@G-C8S,S,S)RD@;VY#;&EC:SU3970H
M)S8V,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C8V-C,S(&]N36]U<V5/=F5R/59I97<H)S8V-C8S,R<I
M(&]N0VQI8VL]4V5T*"<V-C8V,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V.3DS,R!O;DUO=7-E3W9E<CU6
M:65W*"<V-CDY,S,G*2!O;D-L:6-K/5-E="@G-C8Y.3,S)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#,S,@
M;VY-;W5S94]V97(]5FEE=R@G-C9#0S,S)RD@;VY#;&EC:SU3970H)S8V0T,S
M,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC-C9&1C,S(&]N36]U<V5/=F5R/59I97<H)S8V1D8S,R<I(&]N0VQI
M8VL]4V5T*"<V-D9&,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S
M94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M-C8V-C8V(&]N36]U<V5/=F5R/59I97<H)S8V-C8V-B<I(&]N0VQI8VL]4V5T
M*"<V-C8V-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G
M*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P-C8@;VY-;W5S94]V97(]
M5FEE=R@G,#`P,#8V)RD@;VY#;&EC:SU3970H)S`P,#`V-B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S,S8V
M(&]N36]U<V5/=F5R/59I97<H)S`P,S,V-B<I(&]N0VQI8VL]4V5T*"<P,#,S
M-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P-C8V-B!O;DUO=7-E3W9E<CU6:65W*"<P,#8V-C8G*2!O;D-L
M:6-K/5-E="@G,#`V-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#DY-C8@;VY-;W5S94]V97(]5FEE=R@G
M,#`Y.38V)RD@;VY#;&EC:SU3970H)S`P.3DV-B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0S8V(&]N36]U
M<V5/=F5R/59I97<H)S`P0T,V-B<I(&]N0VQI8VL]4V5T*"<P,$-#-C8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P1D8V-B!O;DUO=7-E3W9E<CU6:65W*"<P,$9&-C8G*2!O;D-L:6-K/5-E
M="@G,#!&1C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,S,S`P-C8@;VY-;W5S94]V97(]5FEE=R@G,S,P,#8V
M)RD@;VY#;&EC:SU3970H)S,S,#`V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,S8V(&]N36]U<V5/=F5R
M/59I97<H)S,S,S,V-B<I(&]N0VQI8VL]4V5T*"<S,S,S-C8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S-C8V
M-B!O;DUO=7-E3W9E<CU6:65W*"<S,S8V-C8G*2!O;D-L:6-K/5-E="@G,S,V
M-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,SDY-C8@;VY-;W5S94]V97(]5FEE=R@G,S,Y.38V)RD@;VY#
M;&EC:SU3970H)S,S.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-#0S8V(&]N36]U<V5/=F5R/59I97<H
M)S,S0T,V-B<I(&]N0VQI8VL]4V5T*"<S,T-#-C8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D8V-B!O;DUO
M=7-E3W9E<CU6:65W*"<S,T9&-C8G*2!O;D-L:6-K/5-E="@G,S-&1C8V)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,V-C`P-C8@;VY-;W5S94]V97(]5FEE=R@G-C8P,#8V)RD@;VY#;&EC:SU3
M970H)S8V,#`V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC-C8S,S8V(&]N36]U<V5/=F5R/59I97<H)S8V,S,V
M-B<I(&]N0VQI8VL]4V5T*"<V-C,S-C8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C8V-B!O;DUO=7-E3W9E
M<CU6:65W*"<V-C8V-C8G*2!O;D-L:6-K/5-E="@G-C8V-C8V)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-CDY
M-C8@;VY-;W5S94]V97(]5FEE=R@G-C8Y.38V)RD@;VY#;&EC:SU3970H)S8V
M.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C9#0S8V(&]N36]U<V5/=F5R/59I97<H)S8V0T,V-B<I(&]N
M0VQI8VL]4V5T*"<V-D-#-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V1D8V-B!O;DUO=7-E3W9E<CU6:65W
M*"<V-D9&-C8G*2!O;D-L:6-K/5-E="@G-C9&1C8V)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO
M<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]
M4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](SDY.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY
M.3DG*2!O;D-L:6-K/5-E="@G.3DY.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P
M,#DY(&]N36]U<V5/=F5R/59I97<H)S`P,#`Y.2<I(&]N0VQI8VL]4V5T*"<P
M,#`P.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P,S,Y.2!O;DUO=7-E3W9E<CU6:65W*"<P,#,S.3DG*2!O
M;D-L:6-K/5-E="@G,#`S,SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#8V.3D@;VY-;W5S94]V97(]5FEE
M=R@G,#`V-CDY)RD@;VY#;&EC:SU3970H)S`P-C8Y.2<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.3DY(&]N
M36]U<V5/=F5R/59I97<H)S`P.3DY.2<I(&]N0VQI8VL]4V5T*"<P,#DY.3DG
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P0T,Y.2!O;DUO=7-E3W9E<CU6:65W*"<P,$-#.3DG*2!O;D-L:6-K
M/5-E="@G,#!#0SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,$9&.3D@;VY-;W5S94]V97(]5FEE=R@G,#!&
M1CDY)RD@;VY#;&EC:SU3970H)S`P1D8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,P,#DY(&]N36]U<V5/
M=F5R/59I97<H)S,S,#`Y.2<I(&]N0VQI8VL]4V5T*"<S,S`P.3DG*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S
M,S,Y.2!O;DUO=7-E3W9E<CU6:65W*"<S,S,S.3DG*2!O;D-L:6-K/5-E="@G
M,S,S,SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,S,S8V.3D@;VY-;W5S94]V97(]5FEE=R@G,S,V-CDY)RD@
M;VY#;&EC:SU3970H)S,S-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.3DY(&]N36]U<V5/=F5R/59I
M97<H)S,S.3DY.2<I(&]N0VQI8VL]4V5T*"<S,SDY.3DG*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T,Y.2!O
M;DUO=7-E3W9E<CU6:65W*"<S,T-#.3DG*2!O;D-L:6-K/5-E="@G,S-#0SDY
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,T9&.3D@;VY-;W5S94]V97(]5FEE=R@G,S-&1CDY)RD@;VY#;&EC
M:SU3970H)S,S1D8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC-C8P,#DY(&]N36]U<V5/=F5R/59I97<H)S8V
M,#`Y.2<I(&]N0VQI8VL]4V5T*"<V-C`P.3DG*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,S,Y.2!O;DUO=7-E
M3W9E<CU6:65W*"<V-C,S.3DG*2!O;D-L:6-K/5-E="@G-C8S,SDY)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V
M-C8V.3D@;VY-;W5S94]V97(]5FEE=R@G-C8V-CDY)RD@;VY#;&EC:SU3970H
M)S8V-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C8Y.3DY(&]N36]U<V5/=F5R/59I97<H)S8V.3DY.2<I
M(&]N0VQI8VL]4V5T*"<V-CDY.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V0T,Y.2!O;DUO=7-E3W9E<CU6
M:65W*"<V-D-#.3DG*2!O;D-L:6-K/5-E="@G-C9#0SDY)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&.3D@
M;VY-;W5S94]V97(]5FEE=R@G-C9&1CDY)RD@;VY#;&EC:SU3970H)S8V1D8Y
M.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*
M/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P
M,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0T-#0T,@;VY-;W5S
M94]V97(]5FEE=R@G0T-#0T-#)RD@;VY#;&EC:SU3970H)T-#0T-#0R<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T
M*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P,#!#0R!O;DUO=7-E3W9E<CU6:65W*"<P,#`P0T,G
M*2!O;D-L:6-K/5-E="@G,#`P,$-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#,S0T,@;VY-;W5S94]V97(]
M5FEE=R@G,#`S,T-#)RD@;VY#;&EC:SU3970H)S`P,S-#0R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-D-#
M(&]N36]U<V5/=F5R/59I97<H)S`P-C9#0R<I(&]N0VQI8VL]4V5T*"<P,#8V
M0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P.3E#0R!O;DUO=7-E3W9E<CU6:65W*"<P,#DY0T,G*2!O;D-L
M:6-K/5-E="@G,#`Y.4-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$-#0T,@;VY-;W5S94]V97(]5FEE=R@G
M,#!#0T-#)RD@;VY#;&EC:SU3970H)S`P0T-#0R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1D-#(&]N36]U
M<V5/=F5R/59I97<H)S`P1D9#0R<I(&]N0VQI8VL]4V5T*"<P,$9&0T,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S,S,#!#0R!O;DUO=7-E3W9E<CU6:65W*"<S,S`P0T,G*2!O;D-L:6-K/5-E
M="@G,S,P,$-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,S,S,S0T,@;VY-;W5S94]V97(]5FEE=R@G,S,S,T-#
M)RD@;VY#;&EC:SU3970H)S,S,S-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,V-D-#(&]N36]U<V5/=F5R
M/59I97<H)S,S-C9#0R<I(&]N0VQI8VL]4V5T*"<S,S8V0T,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3E#
M0R!O;DUO=7-E3W9E<CU6:65W*"<S,SDY0T,G*2!O;D-L:6-K/5-E="@G,S,Y
M.4-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,T-#0T,@;VY-;W5S94]V97(]5FEE=R@G,S-#0T-#)RD@;VY#
M;&EC:SU3970H)S,S0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-&1D-#(&]N36]U<V5/=F5R/59I97<H
M)S,S1D9#0R<I(&]N0VQI8VL]4V5T*"<S,T9&0T,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,#!#0R!O;DUO
M=7-E3W9E<CU6:65W*"<V-C`P0T,G*2!O;D-L:6-K/5-E="@G-C8P,$-#)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,V-C,S0T,@;VY-;W5S94]V97(]5FEE=R@G-C8S,T-#)RD@;VY#;&EC:SU3
M970H)S8V,S-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC-C8V-D-#(&]N36]U<V5/=F5R/59I97<H)S8V-C9#
M0R<I(&]N0VQI8VL]4V5T*"<V-C8V0T,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V.3E#0R!O;DUO=7-E3W9E
M<CU6:65W*"<V-CDY0T,G*2!O;D-L:6-K/5-E="@G-C8Y.4-#)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#
M0T,@;VY-;W5S94]V97(]5FEE=R@G-C9#0T-#)RD@;VY#;&EC:SU3970H)S8V
M0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C9&1D-#(&]N36]U<V5/=F5R/59I97<H)S8V1D9#0R<I(&]N
M0VQI8VL]4V5T*"<V-D9&0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-
M;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC1D9&1D9&(&]N36]U<V5/=F5R/59I97<H)T9&1D9&1B<I(&]N0VQI8VL]
M4V5T*"=&1D9&1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P
M,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P1D8@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,$9&)RD@;VY#;&EC:SU3970H)S`P,#!&1B<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S
M,T9&(&]N36]U<V5/=F5R/59I97<H)S`P,S-&1B<I(&]N0VQI8VL]4V5T*"<P
M,#,S1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P-C9&1B!O;DUO=7-E3W9E<CU6:65W*"<P,#8V1D8G*2!O
M;D-L:6-K/5-E="@G,#`V-D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#DY1D8@;VY-;W5S94]V97(]5FEE
M=R@G,#`Y.49&)RD@;VY#;&EC:SU3970H)S`P.3E&1B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0T9&(&]N
M36]U<V5/=F5R/59I97<H)S`P0T-&1B<I(&]N0VQI8VL]4V5T*"<P,$-#1D8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P1D9&1B!O;DUO=7-E3W9E<CU6:65W*"<P,$9&1D8G*2!O;D-L:6-K
M/5-E="@G,#!&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,S,S`P1D8@;VY-;W5S94]V97(]5FEE=R@G,S,P
M,$9&)RD@;VY#;&EC:SU3970H)S,S,#!&1B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,T9&(&]N36]U<V5/
M=F5R/59I97<H)S,S,S-&1B<I(&]N0VQI8VL]4V5T*"<S,S,S1D8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S
M-C9&1B!O;DUO=7-E3W9E<CU6:65W*"<S,S8V1D8G*2!O;D-L:6-K/5-E="@G
M,S,V-D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,S,SDY1D8@;VY-;W5S94]V97(]5FEE=R@G,S,Y.49&)RD@
M;VY#;&EC:SU3970H)S,S.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-#0T9&(&]N36]U<V5/=F5R/59I
M97<H)S,S0T-&1B<I(&]N0VQI8VL]4V5T*"<S,T-#1D8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D9&1B!O
M;DUO=7-E3W9E<CU6:65W*"<S,T9&1D8G*2!O;D-L:6-K/5-E="@G,S-&1D9&
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,V-C`P1D8@;VY-;W5S94]V97(]5FEE=R@G-C8P,$9&)RD@;VY#;&EC
M:SU3970H)S8V,#!&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC-C8S,T9&(&]N36]U<V5/=F5R/59I97<H)S8V
M,S-&1B<I(&]N0VQI8VL]4V5T*"<V-C,S1D8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C9&1B!O;DUO=7-E
M3W9E<CU6:65W*"<V-C8V1D8G*2!O;D-L:6-K/5-E="@G-C8V-D9&)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V
M-CDY1D8@;VY-;W5S94]V97(]5FEE=R@G-C8Y.49&)RD@;VY#;&EC:SU3970H
M)S8V.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C9#0T9&(&]N36]U<V5/=F5R/59I97<H)S8V0T-&1B<I
M(&]N0VQI8VL]4V5T*"<V-D-#1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V1D9&1B!O;DUO=7-E3W9E<CU6
M:65W*"<V-D9&1D8G*2!O;D-L:6-K/5-E="@G-C9&1D9&)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C
M;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI
M8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T9&,#`P,"!O;DUO=7-E3W9E<CU6:65W*"=&
M1C`P,#`G*2!O;D-L:6-K/5-E="@G1D8P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S
M94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M.3DP,#`P(&]N36]U<V5/=F5R/59I97<H)SDY,#`P,"<I(&]N0VQI8VL]4V5T
M*"<Y.3`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY,S,P,"!O;DUO=7-E3W9E<CU6:65W*"<Y.3,S,#`G
M*2!O;D-L:6-K/5-E="@G.3DS,S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.38V,#`@;VY-;W5S94]V97(]
M5FEE=R@G.3DV-C`P)RD@;VY#;&EC:SU3970H)SDY-C8P,"<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DY.3`P
M(&]N36]U<V5/=F5R/59I97<H)SDY.3DP,"<I(&]N0VQI8VL]4V5T*"<Y.3DY
M,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](SDY0T,P,"!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#,#`G*2!O;D-L
M:6-K/5-E="@G.3E#0S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.49&,#`@;VY-;W5S94]V97(]5FEE=R@G
M.3E&1C`P)RD@;VY#;&EC:SU3970H)SDY1D8P,"<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,#`P(&]N36]U
M<V5/=F5R/59I97<H)T-#,#`P,"<I(&]N0VQI8VL]4V5T*"=#0S`P,#`G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#,S,P,"!O;DUO=7-E3W9E<CU6:65W*"=#0S,S,#`G*2!O;D-L:6-K/5-E
M="@G0T,S,S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0S8V,#`@;VY-;W5S94]V97(]5FEE=R@G0T,V-C`P
M)RD@;VY#;&EC:SU3970H)T-#-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,Y.3`P(&]N36]U<V5/=F5R
M/59I97<H)T-#.3DP,"<I(&]N0VQI8VL]4V5T*"=#0SDY,#`G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#0T,P
M,"!O;DUO=7-E3W9E<CU6:65W*"=#0T-#,#`G*2!O;D-L:6-K/5-E="@G0T-#
M0S`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-#0T9&,#`@;VY-;W5S94]V97(]5FEE=R@G0T-&1C`P)RD@;VY#
M;&EC:SU3970H)T-#1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P,#`P(&]N36]U<V5/=F5R/59I97<H
M)T9&,#`P,"<I(&]N0VQI8VL]4V5T*"=&1C`P,#`G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S,P,"!O;DUO
M=7-E3W9E<CU6:65W*"=&1C,S,#`G*2!O;D-L:6-K/5-E="@G1D8S,S`P)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1C8V,#`@;VY-;W5S94]V97(]5FEE=R@G1D8V-C`P)RD@;VY#;&EC:SU3
M970H)T9&-C8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D8Y.3`P(&]N36]U<V5/=F5R/59I97<H)T9&.3DP
M,"<I(&]N0VQI8VL]4V5T*"=&1CDY,#`G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&0T,P,"!O;DUO=7-E3W9E
M<CU6:65W*"=&1D-#,#`G*2!O;D-L:6-K/5-E="@G1D9#0S`P)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D9&
M,#`@;VY-;W5S94]V97(]5FEE=R@G1D9&1C`P)RD@;VY#;&EC:SU3970H)T9&
M1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R
M/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W
M*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$9&,#`@;VY-
M;W5S94]V97(]5FEE=R@G,#!&1C`P)RD@;VY#;&EC:SU3970H)S`P1D8P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]
M4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](SDY,#`S,R!O;DUO=7-E3W9E<CU6:65W*"<Y.3`P
M,S,G*2!O;D-L:6-K/5-E="@G.3DP,#,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S,S,@;VY-;W5S94]V
M97(]5FEE=R@G.3DS,S,S)RD@;VY#;&EC:SU3970H)SDY,S,S,R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DV
M-C,S(&]N36]U<V5/=F5R/59I97<H)SDY-C8S,R<I(&]N0VQI8VL]4V5T*"<Y
M.38V,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY.3DS,R!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY,S,G*2!O
M;D-L:6-K/5-E="@G.3DY.3,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.4-#,S,@;VY-;W5S94]V97(]5FEE
M=R@G.3E#0S,S)RD@;VY#;&EC:SU3970H)SDY0T,S,R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1C,S(&]N
M36]U<V5/=F5R/59I97<H)SDY1D8S,R<I(&]N0VQI8VL]4V5T*"<Y.49&,S,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T-#,#`S,R!O;DUO=7-E3W9E<CU6:65W*"=#0S`P,S,G*2!O;D-L:6-K
M/5-E="@G0T,P,#,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-#0S,S,S,@;VY-;W5S94]V97(]5FEE=R@G0T,S
M,S,S)RD@;VY#;&EC:SU3970H)T-#,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V-C,S(&]N36]U<V5/
M=F5R/59I97<H)T-#-C8S,R<I(&]N0VQI8VL]4V5T*"=#0S8V,S,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M.3DS,R!O;DUO=7-E3W9E<CU6:65W*"=#0SDY,S,G*2!O;D-L:6-K/5-E="@G
M0T,Y.3,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0T-#,S,@;VY-;W5S94]V97(]5FEE=R@G0T-#0S,S)RD@
M;VY#;&EC:SU3970H)T-#0T,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-&1C,S(&]N36]U<V5/=F5R/59I
M97<H)T-#1D8S,R<I(&]N0VQI8VL]4V5T*"=#0T9&,S,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#`S,R!O
M;DUO=7-E3W9E<CU6:65W*"=&1C`P,S,G*2!O;D-L:6-K/5-E="@G1D8P,#,S
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1C,S,S,@;VY-;W5S94]V97(]5FEE=R@G1D8S,S,S)RD@;VY#;&EC
M:SU3970H)T9&,S,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D8V-C,S(&]N36]U<V5/=F5R/59I97<H)T9&
M-C8S,R<I(&]N0VQI8VL]4V5T*"=&1C8V,S,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&.3DS,R!O;DUO=7-E
M3W9E<CU6:65W*"=&1CDY,S,G*2!O;D-L:6-K/5-E="@G1D8Y.3,S)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1D-#,S,@;VY-;W5S94]V97(]5FEE=R@G1D9#0S,S)RD@;VY#;&EC:SU3970H
M)T9&0T,S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC1D9&1C,S(&]N36]U<V5/=F5R/59I97<H)T9&1D8S,R<I
M(&]N0VQI8VL]4V5T*"=&1D9&,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@
M;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P
M,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,#`P,$9&(&]N36]U<V5/=F5R/59I97<H)S`P,#!&1B<I(&]N0VQI
M8VL]4V5T*"<P,#`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P
M,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P-C8@;VY-;W5S
M94]V97(]5FEE=R@G.3DP,#8V)RD@;VY#;&EC:SU3970H)SDY,#`V-B<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M.3DS,S8V(&]N36]U<V5/=F5R/59I97<H)SDY,S,V-B<I(&]N0VQI8VL]4V5T
M*"<Y.3,S-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY-C8V-B!O;DUO=7-E3W9E<CU6:65W*"<Y.38V-C8G
M*2!O;D-L:6-K/5-E="@G.3DV-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY-C8@;VY-;W5S94]V97(]
M5FEE=R@G.3DY.38V)RD@;VY#;&EC:SU3970H)SDY.3DV-B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#0S8V
M(&]N36]U<V5/=F5R/59I97<H)SDY0T,V-B<I(&]N0VQI8VL]4V5T*"<Y.4-#
M-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](SDY1D8V-B!O;DUO=7-E3W9E<CU6:65W*"<Y.49&-C8G*2!O;D-L
M:6-K/5-E="@G.3E&1C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S`P-C8@;VY-;W5S94]V97(]5FEE=R@G
M0T,P,#8V)RD@;VY#;&EC:SU3970H)T-#,#`V-B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,S8V(&]N36]U
M<V5/=F5R/59I97<H)T-#,S,V-B<I(&]N0VQI8VL]4V5T*"=#0S,S-C8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#-C8V-B!O;DUO=7-E3W9E<CU6:65W*"=#0S8V-C8G*2!O;D-L:6-K/5-E
M="@G0T,V-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0SDY-C8@;VY-;W5S94]V97(]5FEE=R@G0T,Y.38V
M)RD@;VY#;&EC:SU3970H)T-#.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#0S8V(&]N36]U<V5/=F5R
M/59I97<H)T-#0T,V-B<I(&]N0VQI8VL]4V5T*"=#0T-#-C8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#1D8V
M-B!O;DUO=7-E3W9E<CU6:65W*"=#0T9&-C8G*2!O;D-L:6-K/5-E="@G0T-&
M1C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-&1C`P-C8@;VY-;W5S94]V97(]5FEE=R@G1D8P,#8V)RD@;VY#
M;&EC:SU3970H)T9&,#`V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8S,S8V(&]N36]U<V5/=F5R/59I97<H
M)T9&,S,V-B<I(&]N0VQI8VL]4V5T*"=&1C,S-C8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C8V-B!O;DUO
M=7-E3W9E<CU6:65W*"=&1C8V-C8G*2!O;D-L:6-K/5-E="@G1D8V-C8V)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1CDY-C8@;VY-;W5S94]V97(]5FEE=R@G1D8Y.38V)RD@;VY#;&EC:SU3
M970H)T9&.3DV-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D9#0S8V(&]N36]U<V5/=F5R/59I97<H)T9&0T,V
M-B<I(&]N0VQI8VL]4V5T*"=&1D-#-C8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D8V-B!O;DUO=7-E3W9E
M<CU6:65W*"=&1D9&-C8G*2!O;D-L:6-K/5-E="@G1D9&1C8V)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@
M8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N
M0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D8P,"!O;DUO=7-E3W9E<CU6:65W
M*"=&1D9&,#`G*2!O;D-L:6-K/5-E="@G1D9&1C`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-
M;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC.3DP,#DY(&]N36]U<V5/=F5R/59I97<H)SDY,#`Y.2<I(&]N0VQI8VL]
M4V5T*"<Y.3`P.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](SDY,S,Y.2!O;DUO=7-E3W9E<CU6:65W*"<Y.3,S
M.3DG*2!O;D-L:6-K/5-E="@G.3DS,SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.38V.3D@;VY-;W5S94]V
M97(]5FEE=R@G.3DV-CDY)RD@;VY#;&EC:SU3970H)SDY-C8Y.2<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DY
M.3DY(&]N36]U<V5/=F5R/59I97<H)SDY.3DY.2<I(&]N0VQI8VL]4V5T*"<Y
M.3DY.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY0T,Y.2!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#.3DG*2!O
M;D-L:6-K/5-E="@G.3E#0SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.49&.3D@;VY-;W5S94]V97(]5FEE
M=R@G.3E&1CDY)RD@;VY#;&EC:SU3970H)SDY1D8Y.2<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,#DY(&]N
M36]U<V5/=F5R/59I97<H)T-#,#`Y.2<I(&]N0VQI8VL]4V5T*"=#0S`P.3DG
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T-#,S,Y.2!O;DUO=7-E3W9E<CU6:65W*"=#0S,S.3DG*2!O;D-L:6-K
M/5-E="@G0T,S,SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-#0S8V.3D@;VY-;W5S94]V97(]5FEE=R@G0T,V
M-CDY)RD@;VY#;&EC:SU3970H)T-#-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,Y.3DY(&]N36]U<V5/
M=F5R/59I97<H)T-#.3DY.2<I(&]N0VQI8VL]4V5T*"=#0SDY.3DG*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M0T,Y.2!O;DUO=7-E3W9E<CU6:65W*"=#0T-#.3DG*2!O;D-L:6-K/5-E="@G
M0T-#0SDY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0T9&.3D@;VY-;W5S94]V97(]5FEE=R@G0T-&1CDY)RD@
M;VY#;&EC:SU3970H)T-#1D8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P,#DY(&]N36]U<V5/=F5R/59I
M97<H)T9&,#`Y.2<I(&]N0VQI8VL]4V5T*"=&1C`P.3DG*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S,Y.2!O
M;DUO=7-E3W9E<CU6:65W*"=&1C,S.3DG*2!O;D-L:6-K/5-E="@G1D8S,SDY
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1C8V.3D@;VY-;W5S94]V97(]5FEE=R@G1D8V-CDY)RD@;VY#;&EC
M:SU3970H)T9&-C8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D8Y.3DY(&]N36]U<V5/=F5R/59I97<H)T9&
M.3DY.2<I(&]N0VQI8VL]4V5T*"=&1CDY.3DG*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&0T,Y.2!O;DUO=7-E
M3W9E<CU6:65W*"=&1D-#.3DG*2!O;D-L:6-K/5-E="@G1D9#0SDY)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1D9&.3D@;VY-;W5S94]V97(]5FEE=R@G1D9&1CDY)RD@;VY#;&EC:SU3970H
M)T9&1D8Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M+W1R/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6
M:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$9&1D8@
M;VY-;W5S94]V97(]5FEE=R@G,#!&1D9&)RD@;VY#;&EC:SU3970H)S`P1D9&
M1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI
M8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](SDY,#!#0R!O;DUO=7-E3W9E<CU6:65W*"<Y
M.3`P0T,G*2!O;D-L:6-K/5-E="@G.3DP,$-#)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S0T,@;VY-;W5S
M94]V97(]5FEE=R@G.3DS,T-#)RD@;VY#;&EC:SU3970H)SDY,S-#0R<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M.3DV-D-#(&]N36]U<V5/=F5R/59I97<H)SDY-C9#0R<I(&]N0VQI8VL]4V5T
M*"<Y.38V0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY.3E#0R!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY0T,G
M*2!O;D-L:6-K/5-E="@G.3DY.4-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.4-#0T,@;VY-;W5S94]V97(]
M5FEE=R@G.3E#0T-#)RD@;VY#;&EC:SU3970H)SDY0T-#0R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1D-#
M(&]N36]U<V5/=F5R/59I97<H)SDY1D9#0R<I(&]N0VQI8VL]4V5T*"<Y.49&
M0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](T-#,#!#0R!O;DUO=7-E3W9E<CU6:65W*"=#0S`P0T,G*2!O;D-L
M:6-K/5-E="@G0T,P,$-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S,S0T,@;VY-;W5S94]V97(]5FEE=R@G
M0T,S,T-#)RD@;VY#;&EC:SU3970H)T-#,S-#0R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V-D-#(&]N36]U
M<V5/=F5R/59I97<H)T-#-C9#0R<I(&]N0VQI8VL]4V5T*"=#0S8V0T,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#.3E#0R!O;DUO=7-E3W9E<CU6:65W*"=#0SDY0T,G*2!O;D-L:6-K/5-E
M="@G0T,Y.4-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0T-#0T,@;VY-;W5S94]V97(]5FEE=R@G0T-#0T-#
M)RD@;VY#;&EC:SU3970H)T-#0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-&1D-#(&]N36]U<V5/=F5R
M/59I97<H)T-#1D9#0R<I(&]N0VQI8VL]4V5T*"=#0T9&0T,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#!#
M0R!O;DUO=7-E3W9E<CU6:65W*"=&1C`P0T,G*2!O;D-L:6-K/5-E="@G1D8P
M,$-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-&1C,S0T,@;VY-;W5S94]V97(]5FEE=R@G1D8S,T-#)RD@;VY#
M;&EC:SU3970H)T9&,S-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8V-D-#(&]N36]U<V5/=F5R/59I97<H
M)T9&-C9#0R<I(&]N0VQI8VL]4V5T*"=&1C8V0T,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&.3E#0R!O;DUO
M=7-E3W9E<CU6:65W*"=&1CDY0T,G*2!O;D-L:6-K/5-E="@G1D8Y.4-#)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1D-#0T,@;VY-;W5S94]V97(]5FEE=R@G1D9#0T-#)RD@;VY#;&EC:SU3
M970H)T9&0T-#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D9&1D-#(&]N36]U<V5/=F5R/59I97<H)T9&1D9#
M0R<I(&]N0VQI8VL]4V5T*"=&1D9&0T,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P
M,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P
M,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC1D8P,$9&(&]N36]U<V5/=F5R/59I97<H)T9&,#!&1B<I(&]N
M0VQI8VL]4V5T*"=&1C`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W
M*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P1D8@;VY-
M;W5S94]V97(]5FEE=R@G.3DP,$9&)RD@;VY#;&EC:SU3970H)SDY,#!&1B<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC.3DS,T9&(&]N36]U<V5/=F5R/59I97<H)SDY,S-&1B<I(&]N0VQI8VL]
M4V5T*"<Y.3,S1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](SDY-C9&1B!O;DUO=7-E3W9E<CU6:65W*"<Y.38V
M1D8G*2!O;D-L:6-K/5-E="@G.3DV-D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY1D8@;VY-;W5S94]V
M97(]5FEE=R@G.3DY.49&)RD@;VY#;&EC:SU3970H)SDY.3E&1B<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#
M0T9&(&]N36]U<V5/=F5R/59I97<H)SDY0T-&1B<I(&]N0VQI8VL]4V5T*"<Y
M.4-#1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY1D9&1B!O;DUO=7-E3W9E<CU6:65W*"<Y.49&1D8G*2!O
M;D-L:6-K/5-E="@G.3E&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S`P1D8@;VY-;W5S94]V97(]5FEE
M=R@G0T,P,$9&)RD@;VY#;&EC:SU3970H)T-#,#!&1B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,T9&(&]N
M36]U<V5/=F5R/59I97<H)T-#,S-&1B<I(&]N0VQI8VL]4V5T*"=#0S,S1D8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T-#-C9&1B!O;DUO=7-E3W9E<CU6:65W*"=#0S8V1D8G*2!O;D-L:6-K
M/5-E="@G0T,V-D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-#0SDY1D8@;VY-;W5S94]V97(]5FEE=R@G0T,Y
M.49&)RD@;VY#;&EC:SU3970H)T-#.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#0T9&(&]N36]U<V5/
M=F5R/59I97<H)T-#0T-&1B<I(&]N0VQI8VL]4V5T*"=#0T-#1D8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M1D9&1B!O;DUO=7-E3W9E<CU6:65W*"=#0T9&1D8G*2!O;D-L:6-K/5-E="@G
M0T-&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-&1C`P1D8@;VY-;W5S94]V97(]5FEE=R@G1D8P,$9&)RD@
M;VY#;&EC:SU3970H)T9&,#!&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8S,T9&(&]N36]U<V5/=F5R/59I
M97<H)T9&,S-&1B<I(&]N0VQI8VL]4V5T*"=&1C,S1D8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C9&1B!O
M;DUO=7-E3W9E<CU6:65W*"=&1C8V1D8G*2!O;D-L:6-K/5-E="@G1D8V-D9&
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1CDY1D8@;VY-;W5S94]V97(]5FEE=R@G1D8Y.49&)RD@;VY#;&EC
M:SU3970H)T9&.3E&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D9#0T9&(&]N36]U<V5/=F5R/59I97<H)T9&
M0T-&1B<I(&]N0VQI8VL]4V5T*"=&1D-#1D8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D9&1B!O;DUO=7-E
M3W9E<CU6:65W*"=&1D9&1D8G*2!O;D-L:6-K/5-E="@G1D9&1D9&)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\+W1A8FQE
M/@T*#0H\+V)O9'D^/"]H=&UL/@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+VEN
M<V5R=%]T86)L92YH=&UL`````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-3(U`#$P-3$U-#,Q,#8T`#`R
M-C(Q,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\:'1M;#X*"CQH96%D/@H@(#QT:71L93Y);G-E<G0@5&%B;&4\+W1I=&QE
M/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB<&]P=7`N
M:G,B/CPO<V-R:7!T/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/@H*=VEN9&]W+G)E<VEZ951O*#0P,"P@,3`P*3L*"F9U;F-T:6]N($EN:70H
M*2!["B`@:3$X;B`]('=I;F1O=RYO<&5N97(N2%1-3$%R96$N23$X3BYD:6%L
M;V=S.R`O+R!L;V%D('1H92!(5$U,07)E82!P;'5G:6X@86YD(&QA;F<@9FEL
M90H@(%]?9&QG7W1R86YS;&%T92AI,3AN*3L*("!?7V1L9U]I;FET*"D["B`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?<F]W<R(I+F9O8W5S*"D["GT[
M"@IF=6YC=&EO;B!O;D]+*"D@>PH@('9A<B!R97%U:7)E9"`]('L*("`@(")F
M7W)O=W,B.B`B66]U(&UU<W0@96YT97(@82!N=6UB97(@;V8@<F]W<R(L"B`@
M("`B9E]C;VQS(CH@(EEO=2!M=7-T(&5N=&5R(&$@;G5M8F5R(&]F(&-O;'5M
M;G,B"B`@?3L*("!F;W(@*'9A<B!I(&EN(')E<75I<F5D*2!["B`@("!V87(@
M96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI*3L*("`@(&EF("@A96PN
M=F%L=64I('L*("`@("`@86QE<G0H<F5Q=6ER961;:5TI.PH@("`@("!E;"YF
M;V-U<R@I.PH@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@?0H@('9A<B!F
M:65L9',@/2!;(F9?<F]W<R(L(")F7V-O;',B+"`B9E]W:61T:"(L(")F7W5N
M:70B+"`B9E]F:7AE9"(L"B`@("`@("`@("`@("`@("`B9E]A;&EG;B(L(")F
M7V)O<F1E<B(L(")F7W-P86-I;F<B+"`B9E]P861D:6YG(ET["B`@=F%R('!A
M<F%M(#T@;F5W($]B:F5C="@I.PH@(&9O<B`H=F%R(&D@:6X@9FEE;&1S*2![
M"B`@("!V87(@:60@/2!F:65L9'-;:5T["B`@("!V87(@96P@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"AI9"D["B`@("!P87)A;5MI9%T@/2`H96PN='EP
M92`]/2`B8VAE8VMB;W@B*2`_(&5L+F-H96-K960@.B!E;"YV86QU93L*("!]
M"B`@7U]D;&=?8VQO<V4H<&%R86TI.PH@(')E='5R;B!F86QS93L*?3L*"F9U
M;F-T:6]N(&]N0V%N8V5L*"D@>PH@(%]?9&QG7V-L;W-E*&YU;&PI.PH@(')E
M='5R;B!F86QS93L*?3L*"CPO<V-R:7!T/@H*/'-T>6QE('1Y<&4](G1E>'0O
M8W-S(CX*:'1M;"P@8F]D>2!["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*
M("!C;VQO<CH@0G5T=&]N5&5X=#L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D
M86YA+'-A;G,M<V5R:68["B`@;6%R9VEN.B`P<'@["B`@<&%D9&EN9SH@,'!X
M.PI]"F)O9'D@>R!P861D:6YG.B`U<'@[('T*=&%B;&4@>PH@(&9O;G0Z(#$Q
M<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*?0IF;W)M('`@>PH@(&UA
M<F=I;BUT;W`Z(#5P>#L*("!M87)G:6XM8F]T=&]M.B`U<'@["GT*+F9L('L@
M=VED=&@Z(#EE;3L@9FQO870Z(&QE9G0[('!A9&1I;F<Z(#)P>"`U<'@[('1E
M>'0M86QI9VXZ(')I9VAT.R!]"BYF<B![('=I9'1H.B`W96T[(&9L;V%T.B!L
M969T.R!P861D:6YG.B`R<'@@-7!X.R!T97AT+6%L:6=N.B!R:6=H=#L@?0IF
M:65L9'-E="![('!A9&1I;F<Z(#!P>"`Q,'!X(#5P>"`U<'@[('T*<V5L96-T
M+"!I;G!U="P@8G5T=&]N('L@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS
M86YS+7-E<FEF.R!]"F)U='1O;B![('=I9'1H.B`W,'!X.R!]"BYS<&%C92![
M('!A9&1I;F<Z(#)P>#L@?0H*+G1I=&QE('L@8F%C:V=R;W5N9#H@(V1D9CL@
M8V]L;W(Z(",P,#`[(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-I>F4Z(#$R
M,"4[('!A9&1I;F<Z(#-P>"`Q,'!X.R!M87)G:6XM8F]T=&]M.B`Q,'!X.PIB
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@8FQA8VL[(&QE='1E<BUS<&%C:6YG
M.B`R<'@["GT*9F]R;2![('!A9&1I;F<Z(#!P>#L@;6%R9VEN.B`P<'@[('T*
M/"]S='EL93X*"CPO:&5A9#X*"CQB;V1Y(&]N;&]A9#TB26YI="@I(CX*"CQD
M:78@8VQA<W,](G1I=&QE(CY);G-E<G0@5&%B;&4\+V1I=CX*"CQF;W)M(&%C
M=&EO;CTB(B!M971H;V0](F=E="(^"CQT86)L92!B;W)D97(](C`B('-T>6QE
M/2)P861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X(CX*("`\=&)O9'D^"@H@(#QT
M<CX*("`@(#QT9"!S='EL93TB=VED=&@Z(#1E;3L@=&5X="UA;&EG;CH@<FEG
M:'0B/E)O=W,Z/"]T9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB<F]W<R(@:60](F9?<F]W<R(@<VEZ93TB-2(@=&ET;&4](DYU;6)E<B!O
M9B!R;W=S(B!V86QU93TB,B(@+SX\+W1D/@H@("`@/'1D('-T>6QE/2)W:61T
M:#H@-&5M.R!T97AT+6%L:6=N.B!R:6=H="(^5VED=&@Z/"]T9#X*("`@(#QT
M9#X\:6YP=70@='EP93TB=&5X="(@;F%M93TB=VED=&@B(&ED/2)F7W=I9'1H
M(B!S:7IE/2(U(B!T:71L93TB5VED=&@@;V8@=&AE('1A8FQE(B!V86QU93TB
M,3`P(B`O/CPO=&0^"B`@("`\=&0^/'-E;&5C="!S:7IE/2(Q(B!N86UE/2)U
M;FET(B!I9#TB9E]U;FET(B!T:71L93TB5VED=&@@=6YI="(^"B`@("`@(#QO
M<'1I;VX@=F%L=64](B4B('-E;&5C=&5D/2(Q(B`@/E!E<F-E;G0\+V]P=&EO
M;CX*("`@("`@/&]P=&EO;B!V86QU93TB<'@B("`@("`@("`@("`@("`^4&EX
M96QS/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](F5M(B`@("`@("`@
M("`@("`@/D5M/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X\+W1D/@H@(#PO='(^
M"B`@/'1R/@H@("`@/'1D('-T>6QE/2)W:61T:#H@-&5M.R!T97AT+6%L:6=N
M.B!R:6=H="(^0V]L<SH\+W1D/@H@("`@/'1D/CQI;G!U="!T>7!E/2)T97AT
M(B!N86UE/2)C;VQS(B!I9#TB9E]C;VQS(B!S:7IE/2(U(B!T:71L93TB3G5M
M8F5R(&]F(&-O;'5M;G,B('9A;'5E/2(T(B`O/CPO=&0^"B`@("`\=&0@<W1Y
M;&4](G1E>'0M86QI9VXZ(')I9VAT(CX\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&-H96-K960](F-H96-K960B(&YA;64](F9I>&5D(B!I9#TB9E]F:7AE9"(@
M+SX\+W1D/@H@("`@/'1D(&-O;'-P86X](C(B/CQL86)E;"!F;W(](F9?9FEX
M960B"B`@("`^1FEX960@=VED=&@@8V]L=6UN<SPO;&%B96P^/"]T9#X*("`\
M+W1R/@H@(#PO=&)O9'D^"CPO=&%B;&4^"@H\<"`O/@H*/&9I96QD<V5T('-T
M>6QE/2)F;&]A=#H@;&5F=#L@;6%R9VEN+6QE9G0Z(#5P>#LB/@H\;&5G96YD
M/DQA>6]U=#PO;&5G96YD/@H*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*
M/&1I=B!C;&%S<STB9FPB/D%L:6=N;65N=#H\+V1I=CX*/'-E;&5C="!S:7IE
M/2(Q(B!N86UE/2)A;&EG;B(@:60](F9?86QI9VXB"B`@=&ET;&4](E!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4B/@H@(#QO<'1I;VX@=F%L=64](B(@<V5L
M96-T960](C$B("`@("`@("`@("`@("`@(#Y.;W0@<V5T/"]O<'1I;VX^"B`@
M/&]P=&EO;B!V86QU93TB;&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@
M/DQE9G0\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)R:6=H="(@("`@("`@
M("`@("`@("`@("`@("`@("`^4FEG:'0\+V]P=&EO;CX*("`\;W!T:6]N('9A
M;'5E/2)T97AT=&]P(B`@("`@("`@("`@("`@("`@("`@("`^5&5X='1O<#PO
M;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](F%B<VUI9&1L92(@("`@("`@("`@
M("`@("`@("`@(#Y!8G-M:61D;&4\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E
M/2)B87-E;&EN92(@("`@("`@("`@("`@("`@("`@("`^0F%S96QI;F4\+V]P
M=&EO;CX*("`\;W!T:6]N('9A;'5E/2)A8G-B;W1T;VTB("`@("`@("`@("`@
M("`@("`@("`^06)S8F]T=&]M/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB
M8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@("`@/D)O='1O;3PO;W!T:6]N
M/@H@(#QO<'1I;VX@=F%L=64](FUI9&1L92(@("`@("`@("`@("`@("`@("`@
M("`@(#Y-:61D;&4\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)T;W`B("`@
M("`@("`@("`@("`@("`@("`@("`@("`^5&]P/"]O<'1I;VX^"CPO<V5L96-T
M/@H*/'`@+SX*"CQD:78@8VQA<W,](F9L(CY";W)D97(@=&AI8VMN97-S.CPO
M9&EV/@H\:6YP=70@='EP93TB=&5X="(@;F%M93TB8F]R9&5R(B!I9#TB9E]B
M;W)D97(B('-I>F4](C4B('9A;'5E/2(Q(@IT:71L93TB3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(@+SX*/"$M+0H\<"`O/@H*/&1I=B!C;&%S<STB9FPB
M/D-O;&QA<'-E(&)O<F1E<G,Z/"]D:78^"CQI;G!U="!T>7!E/2)C:&5C:V)O
M>"(@;F%M93TB8V]L;&%P<V4B(&ED/2)F7V-O;&QA<'-E(B`O/@HM+3X*/&1I
M=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*/"]F:65L9'-E=#X*"CQF:65L9'-E
M="!S='EL93TB9FQO870Z<FEG:'0[(&UA<F=I;BUR:6=H=#H@-7!X.R(^"CQL
M96=E;F0^4W!A8VEN9SPO;&5G96YD/@H*/&1I=B!C;&%S<STB<W!A8V4B/CPO
M9&EV/@H*/&1I=B!C;&%S<STB9G(B/D-E;&P@<W!A8VEN9SH\+V1I=CX*/&EN
M<'5T('1Y<&4](G1E>'0B(&YA;64](G-P86-I;F<B(&ED/2)F7W-P86-I;F<B
M('-I>F4](C4B('9A;'5E/2(Q(@IT:71L93TB4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(@+SX*"CQP("\^"@H\9&EV(&-L87-S/2)F<B(^0V5L;"!P
M861D:6YG.CPO9&EV/@H\:6YP=70@='EP93TB=&5X="(@;F%M93TB<&%D9&EN
M9R(@:60](F9?<&%D9&EN9R(@<VEZ93TB-2(@=F%L=64](C$B"G1I=&QE/2)3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(B`O/@H*
M/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@H*/"]F:65L9'-E=#X*"CQD:78@
M<W1Y;&4](FUA<F=I;BUT;W`Z(#@U<'@[(&)O<F1E<BUT;W`Z(#%P>"!S;VQI
M9"`C.3DY.R!P861D:6YG.B`R<'@[('1E>'0M86QI9VXZ(')I9VAT.R(^"CQB
M=71T;VX@='EP93TB8G5T=&]N(B!N86UE/2)O:R(@;VYC;&EC:STB<F5T=7)N
M(&]N3TLH*3LB/D]+/"]B=71T;VX^"CQB=71T;VX@='EP93TB8G5T=&]N(B!N
M86UE/2)C86YC96PB(&]N8VQI8VL](G)E='5R;B!O;D-A;F-E;"@I.R(^0V%N
M8V5L/"]B=71T;VX^"CPO9&EV/@H*/"]F;W)M/@H*/"]B;V1Y/@H\+VAT;6P^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O
M<'5P<R]L:6YK+FAT;6P`````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#0S-@`Q,#4Q-30S
M,3`V-``P,C0T-S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&AT;6P^"@H\:&5A9#X*("`\=&ET;&4^26YS97)T+TUO9&EF
M>2!,:6YK/"]T:71L93X*("`\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP
M="(@<W)C/2)P;W!U<"YJ<R(^/"]S8W)I<'0^"B`@/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@H@("`@=VEN9&]W+G)E<VEZ951O*#0P,"P@,C`P
M*3L*"DDQ.$X@/2!W:6YD;W<N;W!E;F5R+DA434Q!<F5A+DDQ.$XN9&EA;&]G
M<SL*"F9U;F-T:6]N(&DQ.&XH<W1R*2!["B`@<F5T=7)N("A),3A.6W-T<ET@
M?'P@<W1R*3L*?3L*"F9U;F-T:6]N(&]N5&%R9V5T0VAA;F=E9"@I('L*("!V
M87(@9B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7V]T:&5R7W1A<F=E
M="(I.PH@(&EF("AT:&ES+G9A;'5E(#T](")?;W1H97(B*2!["B`@("!F+G-T
M>6QE+G9I<VEB:6QI='D@/2`B=FES:6)L92(["B`@("!F+G-E;&5C="@I.PH@
M("`@9BYF;V-U<R@I.PH@('T@96QS92!F+G-T>6QE+G9I<VEB:6QI='D@/2`B
M:&ED9&5N(CL*?3L*"F9U;F-T:6]N($EN:70H*2!["B`@7U]D;&=?=')A;G-L
M871E*$DQ.$XI.PH@(%]?9&QG7VEN:70H*3L*("!V87(@<&%R86T@/2!W:6YD
M;W<N9&EA;&]G07)G=6UE;G1S.PH@('9A<B!T87)G971?<V5L96-T(#T@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=&%R9V5T(BD["B`@=F%R('5S95]T
M87)G970@/2!T<G5E.PH@(&EF("AP87)A;2D@>PH@("`@:68@*"!T>7!E;V8@
M<&%R86U;(F9?=7-E=&%R9V5T(ET@(3T@(G5N9&5F:6YE9"(@*2!["B`@("`@
M('5S95]T87)G970@/2!P87)A;5LB9E]U<V5T87)G970B73L*("`@('T*("`@
M(&EF("@@='EP96]F('!A<F%M6R)F7VAR968B72`A/2`B=6YD969I;F5D(B`I
M('L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?:')E9B(I+G9A
M;'5E(#T@<&%R86U;(F9?:')E9B)=.PH@("`@("!D;V-U;65N="YG971%;&5M
M96YT0GE)9"@B9E]T:71L92(I+G9A;'5E(#T@<&%R86U;(F9?=&ET;&4B73L*
M("`@("`@8V]M8F]396QE8W1686QU92AT87)G971?<V5L96-T+"!P87)A;5LB
M9E]T87)G970B72D["B`@("`@(&EF("AT87)G971?<V5L96-T+G9A;'5E("$]
M('!A<F%M+F9?=&%R9V5T*2!["B`@("`@("`@=F%R(&]P="`](&1O8W5M96YT
M+F-R96%T945L96UE;G0H(F]P=&EO;B(I.PH@("`@("`@(&]P="YV86QU92`]
M('!A<F%M+F9?=&%R9V5T.PH@("`@("`@(&]P="YI;FYE<DA434P@/2!O<'0N
M=F%L=64["B`@("`@("`@=&%R9V5T7W-E;&5C="YA<'!E;F1#:&EL9"AO<'0I
M.PH@("`@("`@(&]P="YS96QE8W1E9"`]('1R=64["B`@("`@('T*("`@('T*
M("!]"B`@:68@*"$@=7-E7W1A<F=E="D@>PH@("`@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H(F9?=&%R9V5T7VQA8F5L(BDN<W1Y;&4N=FES:6)I;&ET>2`]
M(")H:61D96XB.PH@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=&%R
M9V5T(BDN<W1Y;&4N=FES:6)I;&ET>2`](")H:61D96XB.PH@("`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H(F9?=&%R9V5T7V]T:&5R(BDN<W1Y;&4N=FES
M:6)I;&ET>2`](")H:61D96XB.PH@('T*("!V87(@;W!T(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@B;W!T:6]N(BD["B`@;W!T+G9A;'5E(#T@(E]O=&AE
M<B(["B`@;W!T+FEN;F5R2%1-3"`](&DQ.&XH(D]T:&5R(BD["B`@=&%R9V5T
M7W-E;&5C="YA<'!E;F1#:&EL9"AO<'0I.PH@('1A<F=E=%]S96QE8W0N;VYC
M:&%N9V4@/2!O;E1A<F=E=$-H86YG960["B`@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H(F9?:')E9B(I+F9O8W5S*"D["B`@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H(F9?:')E9B(I+G-E;&5C="@I.PI].PH*9G5N8W1I;VX@;VY/2R@I
M('L*("!V87(@<F5Q=6ER960@/2!["B`@("`O+R!F7VAR968@<VAO=6QD;B=T
M(&)E(')E<75I<F5D(&]R(&]T:&5R=VES92!R96UO=FEN9R!T:&4@;&EN:R!B
M>2!E;G1E<FEN9R!A;B!E;7!T>0T*("`@("\O('5R;"!I<VXG="!P;W-S:6)L
M92!A;GEM;W)E+@T*("`@("\O(")F7VAR968B.B!I,3AN*")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B*0T*("!]
M.PH@(&9O<B`H=F%R(&D@:6X@<F5Q=6ER960I('L*("`@('9A<B!E;"`](&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*&DI.PH@("`@:68@*"%E;"YV86QU92D@
M>PH@("`@("!A;&5R="AR97%U:7)E9%MI72D["B`@("`@(&5L+F9O8W5S*"D[
M"B`@("`@(')E='5R;B!F86QS93L*("`@('T*("!]"B`@+R\@<&%S<R!D871A
M(&)A8VL@=&\@=&AE(&-A;&QI;F<@=VEN9&]W"B`@=F%R(&9I96QD<R`](%LB
M9E]H<F5F(BP@(F9?=&ET;&4B+"`B9E]T87)G970B(%T["B`@=F%R('!A<F%M
M(#T@;F5W($]B:F5C="@I.PH@(&9O<B`H=F%R(&D@:6X@9FEE;&1S*2!["B`@
M("!V87(@:60@/2!F:65L9'-;:5T["B`@("!V87(@96P@/2!D;V-U;65N="YG
M971%;&5M96YT0GE)9"AI9"D["B`@("!P87)A;5MI9%T@/2!E;"YV86QU93L*
M("!]"B`@:68@*'!A<F%M+F9?=&%R9V5T(#T](")?;W1H97(B*0H@("`@<&%R
M86TN9E]T87)G970@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]O=&AE
M<E]T87)G970B*2YV86QU93L*("!?7V1L9U]C;&]S92AP87)A;2D["B`@<F5T
M=7)N(&9A;'-E.PI].PH*9G5N8W1I;VX@;VY#86YC96PH*2!["B`@7U]D;&=?
M8VQO<V4H;G5L;"D["B`@<F5T=7)N(&9A;'-E.PI].PH*/"]S8W)I<'0^"@H\
M<W1Y;&4@='EP93TB=&5X="]C<W,B/@IH=&UL+"!B;V1Y('L*("!B86-K9W)O
M=6YD.B!"=71T;VY&86-E.PH@(&-O;&]R.B!"=71T;VY497AT.PH@(&9O;G0Z
M(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*("!M87)G:6XZ(#!P
M>#L*("!P861D:6YG.B`P<'@["GT*8F]D>2![('!A9&1I;F<Z(#5P>#L@?0IT
M86)L92!["B`@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF
M.PI]"G-E;&5C="P@:6YP=70L(&)U='1O;B![(&9O;G0Z(#$Q<'@@5&%H;VUA
M+%9E<F1A;F$L<V%N<RUS97)I9CL@?0IB=71T;VX@>R!W:61T:#H@-S!P>#L@
M?0IT86)L92`N;&%B96P@>R!T97AT+6%L:6=N.B!R:6=H=#L@=VED=&@Z(#AE
M;3L@?0H*+G1I=&QE('L@8F%C:V=R;W5N9#H@(V1D9CL@8V]L;W(Z(",P,#`[
M(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-I>F4Z(#$R,"4[('!A9&1I;F<Z
M(#-P>"`Q,'!X.R!M87)G:6XM8F]T=&]M.B`Q,'!X.PIB;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@8FQA8VL[(&QE='1E<BUS<&%C:6YG.B`R<'@["GT*"B-B
M=71T;VYS('L*("`@("`@;6%R9VEN+71O<#H@,65M.R!B;W)D97(M=&]P.B`Q
M<'@@<V]L:60@(SDY.3L*("`@("`@<&%D9&EN9SH@,G!X.R!T97AT+6%L:6=N
M.B!R:6=H=#L*?0H\+W-T>6QE/@H*/"]H96%D/@H*/&)O9'D@;VYL;V%D/2))
M;FET*"DB/@H\9&EV(&-L87-S/2)T:71L92(^26YS97)T+TUO9&EF>2!,:6YK
M/"]D:78^"CQF;W)M/@H\=&%B;&4@8F]R9&5R/2(P(B!S='EL93TB=VED=&@Z
M(#$P,"4[(CX*("`\='(^"B`@("`\=&0@8VQA<W,](FQA8F5L(CY54DPZ/"]T
M9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@:60](F9?:')E9B(@<W1Y
M;&4](G=I9'1H.B`Q,#`E(B`O/CPO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\
M=&0@8VQA<W,](FQA8F5L(CY4:71L92`H=&]O;'1I<"DZ/"]T9#X*("`@(#QT
M9#X\:6YP=70@='EP93TB=&5X="(@:60](F9?=&ET;&4B('-T>6QE/2)W:61T
M:#H@,3`P)2(@+SX\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&-L87-S
M/2)L86)E;"(^/'-P86X@:60](F9?=&%R9V5T7VQA8F5L(CY487)G970Z/"]S
M<&%N/CPO=&0^"B`@("`\=&0^/'-E;&5C="!I9#TB9E]T87)G970B/@H@("`@
M("`\;W!T:6]N('9A;'5E/2(B/DYO;F4@*'5S92!I;7!L:6-I="D\+V]P=&EO
M;CX*("`@("`@/&]P=&EO;B!V86QU93TB7V)L86YK(CY.97<@=VEN9&]W("A?
M8FQA;FLI/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](E]S96QF(CY3
M86UE(&9R86UE("A?<V5L9BD\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU
M93TB7W1O<"(^5&]P(&9R86UE("A?=&]P*3PO;W!T:6]N/@H@("`@/"]S96QE
M8W0^"B`@("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB9E]O=&AE<E]T87)G
M970B(&ED/2)F7V]T:&5R7W1A<F=E="(@<VEZ93TB,3`B('-T>6QE/2)V:7-I
M8FEL:71Y.B!H:61D96XB("\^"B`@("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^
M"@H\9&EV(&ED/2)B=71T;VYS(CX*("`\8G5T=&]N('1Y<&4](G-U8FUI="(@
M;F%M93TB;VLB(&]N8VQI8VL](G)E='5R;B!O;D]+*"D[(CY/2SPO8G5T=&]N
M/@H@(#QB=71T;VX@='EP93TB8G5T=&]N(B!N86UE/2)C86YC96PB(&]N8VQI
M8VL](G)E='5R;B!O;D-A;F-E;"@I.R(^0V%N8V5L/"]B=71T;VX^"CPO9&EV
M/@H\+V9O<FT^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+V)L86YK
M+FAT;6P``````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#$W`#$P-3$U-#,Q,#8T`#`R-#8Q
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M:'1M;#X-"CPO:'1M;#X`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]I;G-E<G1?:6UA9V4N:'1M
M;``````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,C,U,``Q,#4Q-30S,3`V-``P,C8R,#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&AT;6P^#0H-"CQH
M96%D/@T*("`\=&ET;&4^26YS97)T($EM86=E/"]T:71L93X-"@T*/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB<&]P=7`N:G,B/CPO<V-R
M:7!T/@T*#0H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^#0H-"G=I
M;F1O=RYR97-I>F54;R@T,#`L(#$P,"D[#0H-"F9U;F-T:6]N($EN:70H*2![
M#0H@(%]?9&QG7VEN:70H*3L-"B`@=F%R('!A<F%M(#T@=VEN9&]W+F1I86QO
M9T%R9W5M96YT<SL-"B`@:68@*'!A<F%M*2![#0H@("`@("!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@B9E]U<FPB*2YV86QU92`]('!A<F%M6R)F7W5R;")=
M.PT*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?86QT(BDN=F%L
M=64@/2!P87)A;5LB9E]A;'0B73L-"B`@("`@(&1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*")F7V)O<F1E<B(I+G9A;'5E(#T@<&%R86U;(F9?8F]R9&5R(ET[
M#0H@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]A;&EG;B(I+G9A
M;'5E(#T@<&%R86U;(F9?86QI9VXB73L-"B`@("`@(&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*")F7W9E<G0B*2YV86QU92`]('!A<F%M6R)F7W9E<G0B73L-
M"B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7VAO<FEZ(BDN=F%L
M=64@/2!P87)A;5LB9E]H;W)I>B)=.PT*("`@("`@=VEN9&]W+FEP<F5V:65W
M+FQO8V%T:6]N+G)E<&QA8V4H<&%R86TN9E]U<FPI.PT*("!]#0H@(&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*")F7W5R;"(I+F9O8W5S*"D[#0I].PT*#0IF
M=6YC=&EO;B!O;D]+*"D@>PT*("!V87(@<F5Q=6ER960@/2![#0H@("`@(F9?
M=7)L(CH@(EEO=2!M=7-T(&5N=&5R('1H92!54DPB#0H@('T[#0H@(&9O<B`H
M=F%R(&D@:6X@<F5Q=6ER960I('L-"B`@("!V87(@96P@/2!D;V-U;65N="YG
M971%;&5M96YT0GE)9"AI*3L-"B`@("!I9B`H(65L+G9A;'5E*2![#0H@("`@
M("!A;&5R="AR97%U:7)E9%MI72D[#0H@("`@("!E;"YF;V-U<R@I.PT*("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@?0T*("`O+R!P87-S(&1A=&$@
M8F%C:R!T;R!T:&4@8V%L;&EN9R!W:6YD;W<-"B`@=F%R(&9I96QD<R`](%LB
M9E]U<FPB+"`B9E]A;'0B+"`B9E]A;&EG;B(L(")F7V)O<F1E<B(L#0H@("`@
M("`@("`@("`@("`@(F9?:&]R:7HB+"`B9E]V97)T(ET[#0H@('9A<B!P87)A
M;2`](&YE=R!/8FIE8W0H*3L-"B`@9F]R("AV87(@:2!I;B!F:65L9',I('L-
M"B`@("!V87(@:60@/2!F:65L9'-;:5T[#0H@("`@=F%R(&5L(#T@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H:60I.PT*("`@('!A<F%M6VED72`](&5L+G9A
M;'5E.PT*("!]#0H@(%]?9&QG7V-L;W-E*'!A<F%M*3L-"B`@<F5T=7)N(&9A
M;'-E.PT*?3L-"@T*9G5N8W1I;VX@;VY#86YC96PH*2![#0H@(%]?9&QG7V-L
M;W-E*&YU;&PI.PT*("!R971U<FX@9F%L<V4[#0I].PT*#0IF=6YC=&EO;B!O
M;E!R979I97<H*2![#0H@('9A<B!F7W5R;"`](&1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*")F7W5R;"(I.PT*("!V87(@=7)L(#T@9E]U<FPN=F%L=64[#0H@
M(&EF("@A=7)L*2![#0H@("`@86QE<G0H(EEO=2!H879E('1O(&5N=&5R(&%N
M(%523"!F:7)S="(I.PT*("`@(&9?=7)L+F9O8W5S*"D[#0H@("`@<F5T=7)N
M(&9A;'-E.PT*("!]#0H@('=I;F1O=RYI<')E=FEE=RYL;V-A=&EO;BYR97!L
M86-E*'5R;"D[#0H@(')E='5R;B!F86QS93L-"GT[#0H\+W-C<FEP=#X-"@T*
M/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX-"FAT;6PL(&)O9'D@>PT*("!B86-K
M9W)O=6YD.B!"=71T;VY&86-E.PT*("!C;VQO<CH@0G5T=&]N5&5X=#L-"B`@
M9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PT*("!M87)G
M:6XZ(#!P>#L-"B`@<&%D9&EN9SH@,'!X.PT*?0T*8F]D>2![('!A9&1I;F<Z
M(#5P>#L@?0T*=&%B;&4@>PT*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA
M+'-A;G,M<V5R:68[#0I]#0IF;W)M('`@>PT*("!M87)G:6XM=&]P.B`U<'@[
M#0H@(&UA<F=I;BUB;W1T;VTZ(#5P>#L-"GT-"BYF;"![('=I9'1H.B`Y96T[
M(&9L;V%T.B!L969T.R!P861D:6YG.B`R<'@@-7!X.R!T97AT+6%L:6=N.B!R
M:6=H=#L@?0T*+F9R('L@=VED=&@Z(#9E;3L@9FQO870Z(&QE9G0[('!A9&1I
M;F<Z(#)P>"`U<'@[('1E>'0M86QI9VXZ(')I9VAT.R!]#0IF:65L9'-E="![
M('!A9&1I;F<Z(#!P>"`Q,'!X(#5P>"`U<'@[('T-"G-E;&5C="P@:6YP=70L
M(&)U='1O;B![(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I
M9CL@?0T*8G5T=&]N('L@=VED=&@Z(#<P<'@[('T-"BYS<&%C92![('!A9&1I
M;F<Z(#)P>#L@?0T*#0HN=&ET;&4@>R!B86-K9W)O=6YD.B`C9&1F.R!C;VQO
M<CH@(S`P,#L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<VEZ93H@,3(P)3L@
M<&%D9&EN9SH@,W!X(#$P<'@[(&UA<F=I;BUB;W1T;VTZ(#$P<'@[#0IB;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@8FQA8VL[(&QE='1E<BUS<&%C:6YG.B`R
M<'@[#0I]#0IF;W)M('L@<&%D9&EN9SH@,'!X.R!M87)G:6XZ(#!P>#L@?0T*
M/"]S='EL93X-"@T*/"]H96%D/@T*#0H\8F]D>2!O;FQO860](DEN:70H*2(^
M#0H-"CQD:78@8VQA<W,](G1I=&QE(CY);G-E<G0@26UA9V4\+V1I=CX-"CPA
M+2TM(&YE=R!S='5F9B`M+2T^#0H\9F]R;2!A8W1I;VX](B(@;65T:&]D/2)G
M970B/@T*/'1A8FQE(&)O<F1E<CTB,"(@=VED=&@](C$P,"4B('-T>6QE/2)P
M861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X(CX-"B`@/'1B;V1Y/@T*#0H@(#QT
M<CX-"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W96T[('1E>'0M86QI9VXZ(')I
M9VAT(CY);6%G92!54DPZ/"]T9#X-"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E
M>'0B(&YA;64](G5R;"(@:60](F9?=7)L(B!S='EL93TB=VED=&@Z-S4E(@T*
M("`@("`@=&ET;&4](D5N=&5R('1H92!I;6%G92!54DP@:&5R92(@+SX-"B`@
M("`@(#QB=71T;VX@;F%M93TB<')E=FEE=R(@;VYC;&EC:STB<F5T=7)N(&]N
M4')E=FEE=R@I.R(-"B`@("`@('1I=&QE/2)0<F5V:65W('1H92!I;6%G92!I
M;B!A(&YE=R!W:6YD;W<B/E!R979I97<\+V)U='1O;CX-"B`@("`\+W1D/@T*
M("`\+W1R/@T*("`\='(^#0H@("`@/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T
M97AT+6%L:6=N.B!R:6=H="(^06QT97)N871E('1E>'0Z/"]T9#X-"B`@("`\
M=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F%L="(@:60](F9?86QT(B!S
M='EL93TB=VED=&@Z,3`P)2(-"B`@("`@('1I=&QE/2)&;W(@8G)O=W-E<G,@
M=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(@+SX\+W1D/@T*("`\+W1R/@T*
M#0H@(#PO=&)O9'D^#0H\+W1A8FQE/@T*#0H\<"`O/@T*#0H\9FEE;&1S970@
M<W1Y;&4](F9L;V%T.B!L969T.R!M87)G:6XM;&5F=#H@-7!X.R(^#0H\;&5G
M96YD/DQA>6]U=#PO;&5G96YD/@T*#0H\9&EV(&-L87-S/2)S<&%C92(^/"]D
M:78^#0H-"CQD:78@8VQA<W,](F9L(CY!;&EG;FUE;G0Z/"]D:78^#0H\<V5L
M96-T('-I>F4](C$B(&YA;64](F%L:6=N(B!I9#TB9E]A;&EG;B(-"B`@=&ET
M;&4](E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B/@T*("`\;W!T:6]N('9A
M;'5E/2(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`^3F]T('-E=#PO
M;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E/2)L969T(B`@("`@("`@("`@("`@
M("`@("`@("`@("`^3&5F=#PO;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E/2)R
M:6=H="(@("`@("`@("`@("`@("`@("`@("`@("`^4FEG:'0\+V]P=&EO;CX-
M"B`@/&]P=&EO;B!V86QU93TB=&5X='1O<"(@("`@("`@("`@("`@("`@("`@
M("`@/E1E>'1T;W`\+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB86)S;6ED
M9&QE(B`@("`@("`@("`@("`@("`@("`@/D%B<VUI9&1L93PO;W!T:6]N/@T*
M("`\;W!T:6]N('9A;'5E/2)B87-E;&EN92(@<V5L96-T960](C$B("`@("`@
M("`^0F%S96QI;F4\+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB86)S8F]T
M=&]M(B`@("`@("`@("`@("`@("`@("`@/D%B<V)O='1O;3PO;W!T:6]N/@T*
M("`\;W!T:6]N('9A;'5E/2)B;W1T;VTB("`@("`@("`@("`@("`@("`@("`@
M("`^0F]T=&]M/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L=64](FUI9&1L92(@
M("`@("`@("`@("`@("`@("`@("`@(#Y-:61D;&4\+V]P=&EO;CX-"B`@/&]P
M=&EO;B!V86QU93TB=&]P(B`@("`@("`@("`@("`@("`@("`@("`@("`@/E1O
M<#PO;W!T:6]N/@T*/"]S96QE8W0^#0H-"CQP("\^#0H-"CQD:78@8VQA<W,]
M(F9L(CY";W)D97(@=&AI8VMN97-S.CPO9&EV/@T*/&EN<'5T('1Y<&4](G1E
M>'0B(&YA;64](F)O<F1E<B(@:60](F9?8F]R9&5R(B!S:7IE/2(U(@T*=&ET
M;&4](DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B("\^#0H-"CQD:78@8VQA
M<W,](G-P86-E(CX\+V1I=CX-"@T*/"]F:65L9'-E=#X-"@T*/&9I96QD<V5T
M('-T>6QE/2)F;&]A=#IR:6=H=#L@;6%R9VEN+7)I9VAT.B`U<'@[(CX-"CQL
M96=E;F0^4W!A8VEN9SPO;&5G96YD/@T*#0H\9&EV(&-L87-S/2)S<&%C92(^
M/"]D:78^#0H-"CQD:78@8VQA<W,](F9R(CY(;W)I>F]N=&%L.CPO9&EV/@T*
M/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](FAO<FEZ(B!I9#TB9E]H;W)I>B(@
M<VEZ93TB-2(-"G1I=&QE/2)(;W)I>F]N=&%L('!A9&1I;F<B("\^#0H-"CQP
M("\^#0H-"CQD:78@8VQA<W,](F9R(CY697)T:6-A;#H\+V1I=CX-"CQI;G!U
M="!T>7!E/2)T97AT(B!N86UE/2)V97)T(B!I9#TB9E]V97)T(B!S:7IE/2(U
M(@T*=&ET;&4](E9E<G1I8V%L('!A9&1I;F<B("\^#0H-"CQD:78@8VQA<W,]
M(G-P86-E(CX\+V1I=CX-"@T*/"]F:65L9'-E=#X-"CQB<B!C;&5A<CTB86QL
M(B`O/@T*/'1A8FQE('=I9'1H/2(Q,#`E(B!S='EL93TB;6%R9VEN+6)O='1O
M;3H@,"XR96TB/@T*(#QT<CX-"B`@/'1D('9A;&EG;CTB8F]T=&]M(CX-"B`@
M("!);6%G92!0<F5V:65W.CQB<B`O/@T*("`@(#QI9G)A;64@;F%M93TB:7!R
M979I97<B(&ED/2)I<')E=FEE=R(@9G)A;65B;W)D97(](C`B('-T>6QE/2)B
M;W)D97(@.B`Q<'@@<V]L:60@9W)A>3LB(&AE:6=H=#TB,C`P(B!W:61T:#TB
M,S`P(B!S<F,](B(^/"]I9G)A;64^#0H@(#PO=&0^#0H@(#QT9"!V86QI9VX]
M(F)O='1O;2(@<W1Y;&4](G1E>'0M86QI9VXZ(')I9VAT(CX-"B`@("`\8G5T
M=&]N('1Y<&4](F)U='1O;B(@;F%M93TB;VLB(&]N8VQI8VL](G)E='5R;B!O
M;D]+*"D[(CY/2SPO8G5T=&]N/CQB<CX-"B`@("`\8G5T=&]N('1Y<&4](F)U
M='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R971U<FX@;VY#86YC96PH
M*3LB/D-A;F-E;#PO8G5T=&]N/@T*("`\+W1D/@T*(#PO='(^#0H\+W1A8FQE
M/@T*/"]F;W)M/@T*/"]B;V1Y/@T*/"]H=&UL/@T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R\`````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`V-``P,C(U-C8`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N7VQE9G0N9VEF````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,3`U`#$P-3$U-#,Q,#8T`#`R-C`R,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$2`!(`@`$`````
M____(?D$`0```0`L`````!(`$@```AR,CZG+[0&BG/,]2JV&N&_62=\59F-2
M`N?*MD@!`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]E9%]K:6QL=V]R9"YG:68`````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(S
M,@`Q,#4Q-30S,3`V-``P,C4U-#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA$@`2`,(&````````__\``$U-3:JJ
MJO_HS?_______R'Y!`$*``<`+`$````0`!(```-?>+K<3#!*1XR]E@P50/\>
MD!F;B%V!-:P#Z`)%;!1#:'C&9Q4SGG:W`FPVJ]U<.9[2!_/P8#*AB&D17`2T
MU,D"P%JE+YVUMZA@"EZRPGR]TLJQN#P&*-=J`'P>4'?X%0D`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?8W5S=&]M+F=I9@``````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,#,`,3`U,34T,S$P
M-C0`,#(U,C(V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2```"
M&HR/J<OM#^,"0`9*):YQV_QQUGB)G4FFZFH4`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V)L86YK
M+F=I9@```````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#<P`#$P-3$U-#,Q,#8T`#`R-3`P-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`@```____````(?D$`0`````L`````!(`$@```@^$CZG+[0^CG+3:
MB[/>G!<`.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]I;F1E;G1?;&5S<RYG:68`
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#$R-P`Q,#4Q-30S,3`V-``P,C8R,S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`)$"````
MA````/___P```"'Y!`$```(`+``````2`!(```(HE(^I&>NO@FRS2H@%0+8>
ML!W=9(!F5H9&MZ@"BV+>>,7+W-CZNO=0`0`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?:6YD96YT7VUO<F4N9VEF````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q
M,C<`,3`U,34T,S$P-C0`,#(V,C(U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y81(`$@"1`@```(0```#___\````A
M^00!```"`"P`````$@`2```"*)2/J1GKKX)LLTJ(!4"V(K`9W62`9G:`1[>$
MHH5FWGC%R]S8NKCW4`$`.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7V%L:6=N7VIU<W1I9GDN9VEF````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`U`#$P-3$U-#,Q
M,#8T`#`R-C4V-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@``
M`AR,CZG+[0&BG/,]BJ5U.>_681\34N-25N?*MD<!`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M
M871?:71A;&EC+F=I9@`````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$Q-0`Q,#4Q-30S,3`V-``P,C8U,S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA$@`2`)$#`'M[>X2$A````/___R'Y!`$```,`+``````2`!(```(>G(^I
MR^T/C9@SCADLJ'8"S44>*%B7\$$49;;N"T<%`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8VAA<FUA<"YG:68`````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`R,3<`,3`U,34T,S$P-C0`,#(U,S,U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y81(`$@"B!P"`
M`(#`P,"`@(#_`````/\```#_______\A^00!```'`"P`````$@`2```#5'BZ
MW-XB/A>#E;.&P:^@QL4-@A5\C!!ZI648Z-&^I@L+Q5(21$"_`D`D)S,19I&@
MD+@[]GP1@!"G:%F.T.A09^W=D@4BU_0-3V0EF/G,%;/?\#@\`0`[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V9U;&QS8W)E96Y?;6EN:6UI>F4N9VEF````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,30Q`#$P-3$U-#,Q,#8T`#`R-S,Q,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$2`!(`@`$`````____(?D$`0``
M`0`L`````!(`$@```CB,CZD([;\"B'/5TZ1YCN5Z;5BFE=A&EA.YIJIT=8S(
MNJ+VY1P-G4EK"_$X*P5P)S19C,1=Y)DH```[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM
M86=E<R]E9%]P87-T92YG:68`````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(Q,P`Q,#4Q-30S
M,3`V-``P,C4P,S(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA$@`2`*(&`("``("`@```@/__`/___P```/___P``
M`"'Y!`$```8`+``````2`!(```-0:+K<_M"56:*A<PQ<60$!4&QC$0:=8J)2
MF%X@1P7L8H+XB;^?+OQ``4\7$!".QY\G!S`B"4:!C1C]08$JIO.95%&O0:@-
ML^5*'\'TV<)N*Q(`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8W5T
M+F=I9@``````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,S,`,3`U,34T,S$P-C0`,#(T-3$R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@"1`@```(````#___\````A^00!```"`"P`````$@`2```"+)2/
MJ<L;]QJ<TD1Q97B[SEQM8.@A0`"41@JT5<NN32K$]2S3]**O.^-2"8<%`#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W-H;W=?8F]R9&5R+F=I
M9@```````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,34P`#$P-3$U-#,Q,#8T`#`R-C(S,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`D0(`
M`#.9````____````(?D$`0```@`L`````!(`$@```CF4CZG+[0]CF+3:8`+8
MO'<L:-ZX@1@8'NB4I>T;FF<ZGRRMYIGI]JN,J\5X*UVL583=6,+:\@)E%0``
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]R961O+F=I9@``````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#$R,``Q,#4Q-30S,3`V-``P,C0V-#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`)$"`("`@```@/___P``
M`"'Y!`$```(`+``````2`!(```(AE(^IR^WO0)@!2C1/39N+["V4TF%C<IDG
M!T#N"\?R3+\%`#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I
M;6%G97,O961?;&EN:RYG:68`````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-#$`,3`U,34T
M,S$P-C0`,#(T-C4S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y81(`$@"1``#___^`@(````#___\A^00%%``#`"P`
M````$@`2```",IR/J<OM#^,(HE9C:S@4@%-YX#8(7X8*&`:HYF=0Y4RGV3JI
MG(8(9'XK97Z2HO&(3#(*`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VAE
M;'`N9VEF`````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`V`#$P-3$U-#,Q,#8T`#`R-#8T
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@```AV,CZG+[0\#
MF"!.<U_.4=;.0:'X=>8Q:N7)MNY2```[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?8F]L9"YG
M:68````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#$Q,@`Q,#4Q-30S,3`V-``P,C8R,#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA$@`2`(`!
M`````/___R'Y!`$```$`+``````2`!(```(AC(^IR^W_@)PRUC!=QI?M[5%=
M"!C@\HU*6I(B!,?R3#,%`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]I;6%G97,O961?;&5F=%]T;U]R:6=H="YG:68`````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`Q,S$`,3`U,34T,S$P-C0`,#(V-30V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y81(`$@"1`@`$`H0```#___\`
M```A^00!```"`"P`````$@`2```"*I2/J<OM#U.8#*`91%[`&JQ5W4=M2C=J
MF9F@5\AYQUHI=!2RSXWW_@\I```[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7W5N9&\N9VEF````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3(Q`#$P-3$U
M-#,Q,#8T`#`R-#8V,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$2`!(`D0(`@("```"`____````(?D$`0```@`L
M`````!(`$@```B*4CZG+[0]C"S2`%0Y%5NWL>1LFC@G(5:C12<`JQ?),UTP!
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F
M;W)M871?<W5B+F=I9@`````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$Q-@`Q,#4Q-30S,3`V-``P,C8P
M-C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA$@`2`)$"````@````/___P```"'Y!`$```(`+``````2`!(```(?
ME(^IR^WO0C`2"EGMG1KSEU4`H"%D>6JI.I;N"\=-`0`[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O:6YS97)T7W1A8FQE+F=I
M9@``````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`Q-S$`,3`U,34T,S$P-C0`,#(U-S(T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y81(`$@"B
M``#____,S,P`,YD```#___\````````````A^00%%``$`"P`````$@`2```#
M/DBZW/Z0C$FK'6J(S7O'DB=RX``$0(JJZ5F>[0JK96#?./[*?+S'0%HF1[S]
M6$A79L;DU8K$TF4ZB5BOV&P"`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]S=7`N9VEF````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,3$U`#$P-3$U-#,Q,#8T`#`R-C`W-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$2`!(`D0(`@```````____
M````(?D$`0```@`L`````!(`$@```AZ4CZG+;0`<BQ+1^K"%+`3C85ZHD>)X
M@I_&MNX+MP4`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]I;6%G92YG:68`````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(R-``Q,#4Q
M-30S,3`V-``P,C4P,#(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA$@`2`*('``"``(```("``("`@/__``#__P``
M`/___R'Y!`$```<`+``````2`!(```-9>+K<_E"90:NEAHT@N.]@M@R"89YH
M("I;5APO(1^E5K[X02BJUK\#F+`VNAV"E$*P-^H%64@BJ_0\'BE,5J!Z(:V.
M`L!!3!ZW?("T>BT%?]Z=+VH^C]COD`0`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?
M:'(N9VEF````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,#8`,3`U,34T,S$P-C0`,#(T
M,S,P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y81(`$@"1`@`S,S.9F9G___\````A^00!```"`"P`````$@`2```"
M%Y2/J<OM#Z.<M(&+LSZA^P]6XDB6YJD4`#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W)I9VAT7W1O7VQE
M9G0N9VEF`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,3,P`#$P-3$U-#,Q,#8T`#`R-C4T-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
MD0(`!`*$````____````(?D$`0```@`L`````!(`$@```BF4CZG+[?^"#'`*
MBL"RV`"M<,<'AA1&EN$U?LV9J0F<O2QDT/C.]WY2```[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]H=&UL+F=I9@``````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#$Q,P`Q,#4Q-30S,3`V-``P,C0V-C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$@`2`(`!`````/___R'Y
M!`$```$`+``````2`!(```(BC(^IR^T/`3#RU7-7QE-M]'U)V'DE>%(IRCJ7
M",7R3-='`0`[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?<V%V92YG:68`````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,3<`,3`U
M,34T,S$P-C0`,#(T-C8P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y81(`$@"B!0#<W-R`@("`@`#___\```#___\`
M```````A^00!```%`"P`````$@`2```#5%BZW/Y0D4DK;420P?L@!1$PV>9Q
M5``LY8EJ*JNY'[Q*LUO&N&9E-IE@2"R*;J'A;Q+L30(3W%$HJDIY21\4E)PJ
MMLL4L@`(F,]H\U@!:+O?[8@\`0`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D
M7V9O<FUA=%]S=')I:V4N9VEF`````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3$V`#$P-3$U-#,Q,#8T`#`R
M-C4W,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@```B6,CZG+
M[0HB"-/%<VTUFTG\4%DCE6;X/5M*(J.W=LM4AO:-YTP!`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]D96QE=&4N9VEF
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#$S,@`Q,#4Q-30S,3`V-``P,C4Q-C``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA$@`2
M`)$``/___P```/___P```"'Y!`44``(`+``````2`!(```(KE(^IR^T6`F!Q
MGEA3UMB*O72?UV"@(SZ?28;9R4F7K*17"\%CB*M4[PL>"@`[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?8V]L;W)?8F<N9VEF````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`R-C4`,3`U,34T,S$P-C0`,#(U-3$S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81(`$@"S"P``A```>P"$
MA(1[>WO_`/\`____``#__P```/____\```#___\````````````````A^00!
M```+`"P`````$@`2```$8G#)2:N52MVM\[:>]TU:H@C:6)K+D*75NBB#4`\X
MCBU)@@F&X*!`'&!Z)&!00"P8=Q*<;7H34#2UTV$K"``"3Y*KM3T,OH`P*2J8
MNC\#A'Q`J*LK`CE"4"?<*5)4-B.$A101`#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7V%B;W5T+F=I9@``````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3(W`#$P
M-3$U-#,Q,#8T`#`R-3`S-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`@`$`````____(?D$`0```0`L````
M`!(`$@```BZ,CXG`[0],5'1.FJQB6^Y[:%CF+1P9@)*:EF;79JSXHO/LAG@\
MAGEO@0A//4H!`#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E
M9%]L:7-T7V)U;&QE="YG:68````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$R,``Q,#4Q-30S,3`V-``P
M,C8R,S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`)$"````A````/___P```"'Y!`$```(`+``````2`!(`
M``(AE(^IRP;?U`,FV'O1C+S[M'TA1FK0AZ;@Z8UD=H3J3',%`#L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8V]L;W)?9F<N
M9VEF````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`R-3,`,3`U,34T,S$P-C0`,#(U-3$T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@"S"@``A```>P"$A(1[>WO_`/\`____``#__P```/\```#___\`````````
M```````````A^00!```*`"P`````$@`2```$6%#)22M-.&LKT\0?IW@=.8J7
MB::K!0YP'+O>8-Q#H0^T8M\"78%7>0D$,"22,M`(#E!!`!`@<@;0PX`*L%H&
M1[!2@!H@S@."VEL1G!$"-8'-%(/OK;Q>$0$`.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N7W)I9VAT+F=I9@``````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,3`T`#$P-3$U-#,Q,#8T`#`R-C(P-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$2`!(`@`$`````____
M(?D$`0```0`L`````!(`$@```AN,CZG+[0&BG//90^EMN8-M>1&XB!K)B>C*
MM@4`.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VEM86=E<R]E9%]F;W)M871?=6YD97)L:6YE+F=I9@``````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$R-0`Q
M,#4Q-30S,3`V-``P,C<R-34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA$@`2`)$"`'M[>P```/___P```"'Y!`$`
M``(`+``````2`!(```(FE(^IR^W_@@QBTB9/=KM>_'5,)R[D-X:H&0`"4+(3
M1"/67><Z70``.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O
M9G5L;'-C<F5E;E]M87AI;6EZ92YG:68`````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-#$`,3`U,34T,S$P-C0`
M,#(W,S$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2```".(R/
MJ0;MWQ189Z8)7;!P9\Q4E\:)U;.%JH>!J:IYKY7&<GG2]VI?</2)U(0(78A8
ME%!6N:!QN2P``#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W)M9F]R;6%T
M+F=I9@```````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,38V`#$P-3$U-#,Q,#8T`#`R-34U-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$2
M`!(`\@4`````&0``9F9FS,S,____````````````(?D$`0``!0`L`````!(`
M$@```SM8NMS^,,I)EP`8""'!(-\P`)$'GA=DAH1&.NNI;3#[S2\3WUMN>2(1
M[@$,CE)$H]#7N&0PG(IT2ETD```[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]A;&EG;E]C96YT97(N9VEF````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#$P-0`Q,#4Q-30S,3`V-``P,C8S-3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA$@`2`(`!`````/__
M_R'Y!`$```$`+``````2`!(```(<C(^IR^T!HISS64CK=;F#S7D?R(@468KH
MRK9&`0`[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?8V]P>2YG:68`````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-38`
M,3`U,34T,S$P-C0`,#(T-C<V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y81(`$@"1`P```(````#_______\A^00!
M```#`"P`````$@`2```"/YR/J<L6#]L)HHHG![4TR-X!XJAL%F`)8@(^Z*DB
M9H4^*NE<T)O&>5J#4``388`';`0AO@7RI!Q)B9FJ]8HH```[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7VQI<W1?;G5M+F=I9@```````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3(R`#$P-3$U-#,Q,#8T
M`#`R-34T-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$2`!(`D0(```"$````____````(?D$`0```@`L`````!(`
M$@```B.4CZG+"+W`,Z%:FR9T<GO8?0YU79EH2!J*JJQ6FJ<8LK98```[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]S<&QI=&-E
M;"YG:68````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#(Q-P`Q,#4Q-30S,3`V-``P,C4U-#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M%P`6`*($````@`#______P```/___P```````````"'Y!`$```0`+``````7
M`!8```-42+K<_C#*2:N=(^O-QQN"`(;A2'K.:)9D^75P]I6!$`#UG:.-:@N`
M7[#&8Z@`R*024%QLA%#B3)3#V:R!IN*X7&H)JJK8]O75AL!?.0:[N-_P>"4!
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]D:6%L;V<N:G,`````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0U-S0`,3`U,34T,S$P-C0`,#(S,3(U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\O(&AT;6Q!<F5A('8S+C`@
M+2!#;W!Y<FEG:'0@*&,I(#(P,#,M,C`P-2!D>6YA<F-H+F-O;0HO+R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`R,#`R+3(P,#,@:6YT97)A8W1I
M=F5T;V]L<RYC;VTL(&EN8RX*+R\@5&AI<R!C;W!Y<FEG:'0@;F]T:6-E($U5
M4U0@<W1A>2!I;G1A8W0@9F]R('5S92`H<V5E(&QI8V5N<V4N='AT*2X*+R\*
M+R\@4&]R=&EO;G,@*&,I(&1Y;F%R8V@N8V]M+"`R,#`S+3(P,#0*+R\*+R\@
M02!F<F5E(%=94TE764<@961I=&]R(')E<&QA8V5M96YT(&9O<B`\=&5X=&%R
M96$^(&9I96QD<RX*+R\@1F]R(&9U;&P@<V]U<F-E(&-O9&4@86YD(&1O8W,L
M('9I<VET(&AT='`Z+R]W=W<N:6YT97)A8W1I=F5T;V]L<RYC;VTO"B\O"B\O
M(%9E<G-I;VX@,RXP(&1E=F5L;W!E9"!B>2!-:6AA:2!"87IO;BX*+R\@("!H
M='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"B\O"B\O("1)9#H@9&EA;&]G+FIS
M+'8@,2XW(#(P,#4O,#$O,C`@,3<Z-#DZ,#0@;6ES:&]O($5X<"`D"@HO+R!4
M:&]U9V@@(D1I86QO9R(@;&]O:W,@;&EK92!A;B!O8FIE8W0L(&ET(&ES;B=T
M(')E86QL>2!A;B!O8FIE8W0N("!);G-T96%D"B\O(&ET)W,@:G5S="!N86UE
M<W!A8V4@9F]R('!R;W1E8W1I;F<@9VQO8F%L('-Y;6)O;',N"@IF=6YC=&EO
M;B!$:6%L;V<H=7)L+"!A8W1I;VXL(&EN:70I('L*"6EF("AT>7!E;V8@:6YI
M="`]/2`B=6YD969I;F5D(BD@>PH)"6EN:70@/2!W:6YD;W<["2\O('!A<W,@
M=&AI<R!W:6YD;W<@;V)J96-T(&)Y(&1E9F%U;'0*"7T*"41I86QO9RY?9V5C
M:V]/<&5N36]D86PH=7)L+"!A8W1I;VXL(&EN:70I.PI].PH*1&EA;&]G+E]P
M87)E;G1%=F5N="`](&9U;F-T:6]N*&5V*2!["@ES9714:6UE;W5T*"!F=6YC
M=&EO;B@I('L@:68@*$1I86QO9RY?;6]D86P@)B8@(41I86QO9RY?;6]D86PN
M8VQO<V5D*2![($1I86QO9RY?;6]D86PN9F]C=7,H*2!]('TL(#4P*3L*"6EF
M("A$:6%L;V<N7VUO9&%L("8F("%$:6%L;V<N7VUO9&%L+F-L;W-E9"D@>PH)
M"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)?0I].PH*"B\O('-H;W5L9"!B
M92!A(&9U;F-T:6]N+"!T:&4@<F5T=7)N(&AA;F1L97(@;V8@=&AE(&-U<G)E
M;G1L>2!O<&5N960@9&EA;&]G+@I$:6%L;V<N7W)E='5R;B`](&YU;&P["@HO
M+R!C;VYS=&%N="P@=&AE(&-U<G)E;G1L>2!O<&5N960@9&EA;&]G"D1I86QO
M9RY?;6]D86P@/2!N=6QL.PH*+R\@=&AE(&1I86QO9R!W:6QL(')E860@:70G
M<R!A<F=S(&9R;VT@=&AI<R!V87)I86)L90I$:6%L;V<N7V%R9W5M96YT<R`]
M(&YU;&P["@I$:6%L;V<N7V=E8VMO3W!E;DUO9&%L(#T@9G5N8W1I;VXH=7)L
M+"!A8W1I;VXL(&EN:70I('L*"79A<B!D;&<@/2!W:6YD;W<N;W!E;BAU<FPL
M(")H861I86QO9R(L"@D)"2`@("`@(")T;V]L8F%R/6YO+&UE;G5B87(];F\L
M<&5R<V]N86QB87(];F\L=VED=&@],3`L:&5I9VAT/3$P+"(@*PH)"0D@("`@
M("`B<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4]>65S+&UO9&%L/7EE<RQD97!E
M;F1A8FQE/7EE<R(I.PH)1&EA;&]G+E]M;V1A;"`](&1L9SL*"41I86QO9RY?
M87)G=6UE;G1S(#T@:6YI=#L*"@DO+R!C87!T=7)E('-O;64@=VEN9&]W)W,@
M979E;G1S"@EF=6YC=&EO;B!C87!W:6XH=RD@>PH)"4A434Q!<F5A+E]A9&1%
M=F5N="AW+"`B8VQI8VLB+"!$:6%L;V<N7W!A<F5N=$5V96YT*3L*"0E(5$U,
M07)E82Y?861D179E;G0H=RP@(FUO=7-E9&]W;B(L($1I86QO9RY?<&%R96YT
M179E;G0I.PH)"4A434Q!<F5A+E]A9&1%=F5N="AW+"`B9F]C=7,B+"!$:6%L
M;V<N7W!A<F5N=$5V96YT*3L*"7T["@DO+R!R96QE87-E('1H92!C87!T=7)E
M9"!E=F5N=',*"69U;F-T:6]N(')E;'=I;BAW*2!["@D)2%1-3$%R96$N7W)E
M;6]V945V96YT*'<L(")C;&EC:R(L($1I86QO9RY?<&%R96YT179E;G0I.PH)
M"4A434Q!<F5A+E]R96UO=F5%=F5N="AW+"`B;6]U<V5D;W=N(BP@1&EA;&]G
M+E]P87)E;G1%=F5N="D["@D)2%1-3$%R96$N7W)E;6]V945V96YT*'<L(")F
M;V-U<R(L($1I86QO9RY?<&%R96YT179E;G0I.PH)?3L*"6-A<'=I;BAW:6YD
M;W<I.PH)+R\@8V%P='5R92!O=&AE<B!F<F%M97,*"69O<B`H=F%R(&D@/2`P
M.R!I(#P@=VEN9&]W+F9R86UE<RYL96YG=&@[(&-A<'=I;BAW:6YD;W<N9G)A
M;65S6VDK*UTI*3L*"2\O(&UA:V4@=7`@82!F=6YC=&EO;B!T;R!B92!C86QL
M960@=VAE;B!T:&4@1&EA;&]G(&5N9',N"@E$:6%L;V<N7W)E='5R;B`](&9U
M;F-T:6]N("AV86PI('L*"0EI9B`H=F%L("8F(&%C=&EO;BD@>PH)"0EA8W1I
M;VXH=F%L*3L*"0E]"@D)<F5L=VEN*'=I;F1O=RD["@D)+R\@8V%P='5R92!O
M=&AE<B!F<F%M97,*"0EF;W(@*'9A<B!I(#T@,#L@:2`\('=I;F1O=RYF<F%M
M97,N;&5N9W1H.R!R96QW:6XH=VEN9&]W+F9R86UE<UMI*RM=*2D["@D)1&EA
M;&]G+E]M;V1A;"`](&YU;&P["@E].PI].PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<'=I;BYJ<P``````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#<S-3,`,3`U,34T,S$P-C0`,#(S-30U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\O("AC
M*2!D>6YA<F-H+F-O;2`R,#`S+3(P,#4*+R\@1&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@=&5R;7,@87,@2%1-3$%R96$@:71S96QF+@H*9G5N8W1I;VX@
M4&]P=7!7:6XH961I=&]R+"!T:71L92P@:&%N9&QE<BP@:6YI=$9U;F-T:6]N
M*2!["@ET:&ES+F5D:71O<B`](&5D:71O<CL*"71H:7,N:&%N9&QE<B`](&AA
M;F1L97(["@EV87(@9&QG(#T@=VEN9&]W+F]P96XH(B(L(")?7VAA7V1I86QO
M9R(L"@D)"2`@("`@(")T;V]L8F%R/6YO+&UE;G5B87(];F\L<&5R<V]N86QB
M87(];F\L=VED=&@]-C`P+&AE:6=H=#TV,#`L;&5F=#TR,"QT;W`]-#`B("L*
M"0D)("`@("`@(G-C<F]L;&)A<G,];F\L<F5S:7IA8FQE/6YO(BD["@ET:&ES
M+G=I;F1O=R`](&1L9SL*"79A<B!D;V,@/2!D;&<N9&]C=6UE;G0["@ET:&ES
M+F1O8R`](&1O8SL*"79A<B!S96QF(#T@=&AI<SL*"@EV87(@8F%S92`](&1O
M8W5M96YT+F)A<V554DD@?'P@9&]C=6UE;G0N55),.PH):68@*&)A<V4@)B8@
M8F%S92YM871C:"@O*"XJ*5PO*%M>7"]=*RDO*2D@>PH)"6)A<V4@/2!296=%
M>'`N)#$@*R`B+R(["@E]"@EI9B`H='EP96]F(%]E9&ET;W)?=7)L("$](")U
M;F1E9FEN960B("8F("$O7EPO+RYT97-T*%]E9&ET;W)?=7)L*2`F)B`A+VAT
M='`Z7"]<+R\N=&5S="A?961I=&]R7W5R;"DI('L*"0DO+R!?961I=&]R7W5R
M;"!D;V5S;B=T('-T87)T('=I=&@@)R\G('=H:6-H(&UE86YS(&ET)W,@<F5L
M871I=F4*"0DO+R!&25A-13H@=&AE<F4G<R!A('!R;V)L96T@:&5R92P@:70@
M8V]U;&0@8F4@:'1T<#HO+R!W:&EC:`H)"2\O(&1O97-N)W0@<W1A<G0@=VET
M:"!S;&%S:"!B=70@:70G<R!N;W0@<F5L871I=F4@96ET:&5R+@H)"6)A<V4@
M*ST@7V5D:71O<E]U<FP["@E](&5L<V4*"0EB87-E(#T@7V5D:71O<E]U<FP[
M"@EI9B`H(2]<+R0O+G1E<W0H8F%S92DI('L*"0DO+R!B87-E(&1O97,@;F]T
M(&5N9"!I;B!S;&%S:"P@861D(&ET(&YO=PH)"6)A<V4@*ST@)R\G.PH)?0H)
M=&AI<RYB87-E55),(#T@8F%S93L*"@ED;V,N;W!E;B@I.PH)=F%R(&AT;6P@
M/2`B/&AT;6P^/&AE860^/'1I=&QE/B(@*R!T:71L92`K("(\+W1I=&QE/EQN
M(CL*"2\O(&AT;6P@*ST@(CQB87-E(&AR968])R(@*R!B87-E("L@(FAT;6QA
M<F5A+FIS)R`O/EQN(CL*"6AT;6P@*ST@(CQS='EL92!T>7!E/2=T97AT+V-S
M<R<^0&EM<&]R="!U<FPH(B`K(&)A<V4@*R`B:'1M;&%R96$N8W-S*3L\+W-T
M>6QE/CPO:&5A9#Y<;B(["@EH=&UL("L]("(\8F]D>2!C;&%S<STG9&EA;&]G
M('!O<'5P=VEN)R!I9#TG+2U(02UB;V1Y)SX\+V)O9'D^/"]H=&UL/B(["@ED
M;V,N=W)I=&4H:'1M;"D["@ED;V,N8VQO<V4H*3L*"@DO+R!S;VUE=&EM97,@
M22!(871E($UO>FEL;&$N+BX@.RTH"@EF=6YC=&EO;B!I;FET,B@I('L*"0EV
M87(@8F]D>2`](&1O8RYB;V1Y.PH)"6EF("@A8F]D>2D@>PH)"0ES9714:6UE
M;W5T*&EN:70R+"`R-2D["@D)"7)E='5R;B!F86QS93L*"0E]"@D)9&QG+G1I
M=&QE(#T@=&ET;&4["@D)9&]C+F1O8W5M96YT16QE;65N="YS='EL92YP861D
M:6YG(#T@(C!P>"(["@D)9&]C+F1O8W5M96YT16QE;65N="YS='EL92YM87)G
M:6X@/2`B,'!X(CL*"0EV87(@8V]N=&5N="`](&1O8RYC<F5A=&5%;&5M96YT
M*")D:78B*3L*"0EC;VYT96YT+F-L87-S3F%M92`](")C;VYT96YT(CL*"0ES
M96QF+F-O;G1E;G0@/2!C;VYT96YT.PH)"6)O9'DN87!P96YD0VAI;&0H8V]N
M=&5N="D["@D)<V5L9BYE;&5M96YT(#T@8F]D>3L*"0EI;FET1G5N8W1I;VXH
M<V5L9BD["@D)9&QG+F9O8W5S*"D["@E].PH):6YI=#(H*3L*?3L*"E!O<'5P
M5VEN+G!R;W1O='EP92YC86QL2&%N9&QE<B`](&9U;F-T:6]N*"D@>PH)=F%R
M('1A9W,@/2!;(FEN<'5T(BP@(G1E>'1A<F5A(BP@(G-E;&5C=")=.PH)=F%R
M('!A<F%M<R`](&YE=R!/8FIE8W0H*3L*"69O<B`H=F%R('1I(#T@=&%G<RYL
M96YG=&@[("TM=&D@/CT@,#LI('L*"0EV87(@=&%G(#T@=&%G<UMT:5T["@D)
M=F%R(&5L<R`]('1H:7,N8V]N=&5N="YG971%;&5M96YT<T)Y5&%G3F%M92AT
M86<I.PH)"69O<B`H=F%R(&H@/2`P.R!J(#P@96QS+FQE;F=T:#L@*RMJ*2![
M"@D)"79A<B!E;"`](&5L<UMJ73L*"0D)=F%R('9A;"`](&5L+G9A;'5E.PH)
M"0EI9B`H96PN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T](")I;G!U="(I('L*
M"0D)"6EF("AE;"YT>7!E(#T](")C:&5C:V)O>"(I('L*"0D)"0EV86P@/2!E
M;"YC:&5C:V5D.PH)"0D)?0H)"0E]"@D)"7!A<F%M<UME;"YN86UE72`]('9A
M;#L*"0E]"@E]"@ET:&ES+FAA;F1L97(H=&AI<RP@<&%R86US*3L*"7)E='5R
M;B!F86QS93L*?3L*"E!O<'5P5VEN+G!R;W1O='EP92YC;&]S92`](&9U;F-T
M:6]N*"D@>PH)=&AI<RYW:6YD;W<N8VQO<V4H*3L*?3L*"E!O<'5P5VEN+G!R
M;W1O='EP92YA9&1"=71T;VYS(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L9B`]
M('1H:7,["@EV87(@9&EV(#T@=&AI<RYD;V,N8W)E871E16QE;65N="@B9&EV
M(BD["@ET:&ES+F-O;G1E;G0N87!P96YD0VAI;&0H9&EV*3L*"61I=BYC;&%S
M<TYA;64@/2`B8G5T=&]N<R(["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&%R9W5M
M96YT<RYL96YG=&@[("LK:2D@>PH)"79A<B!B=&X@/2!A<F=U;65N='-;:5T[
M"@D)=F%R(&)U='1O;B`]('1H:7,N9&]C+F-R96%T945L96UE;G0H(F)U='1O
M;B(I.PH)"61I=BYA<'!E;F1#:&EL9"AB=71T;VXI.PH)"6)U='1O;BYI;FYE
M<DA434P@/2!(5$U,07)E82Y),3A.+F)U='1O;G-;8G1N73L*"0ES=VET8V@@
M*&)T;BD@>PH)"2`@("!C87-E(")O:R(Z"@D)"6)U='1O;BYO;F-L:6-K(#T@
M9G5N8W1I;VXH*2!["@D)"0ES96QF+F-A;&Q(86YD;&5R*"D["@D)"0ES96QF
M+F-L;W-E*"D["@D)"0ER971U<FX@9F%L<V4["@D)"7T["@D)"6)R96%K.PH)
M"2`@("!C87-E(")C86YC96PB.@H)"0EB=71T;VXN;VYC;&EC:R`](&9U;F-T
M:6]N*"D@>PH)"0D)<V5L9BYC;&]S92@I.PH)"0D)<F5T=7)N(&9A;'-E.PH)
M"0E].PH)"0EB<F5A:SL*"0E]"@E]"GT["@I0;W!U<%=I;BYP<F]T;W1Y<&4N
M<VAO=T%T16QE;65N="`](&9U;F-T:6]N*"D@>PH)=F%R('-E;&8@/2!T:&ES
M.PH)+R\@36]Z:6QL82!N965D<R!S;VUE('1I;64@=&\@<F5A;&EZ92!W:&%T
M)W,@9V]I;B<@;VXN+@H)<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0EV87(@
M=R`]('-E;&8N8V]N=&5N="YO9F9S9717:61T:"`K(#0["@D)=F%R(&@@/2!S
M96QF+F-O;G1E;G0N;V9F<V5T2&5I9VAT("L@-#L*"0DO+R!S:7IE('1O(&-O
M;G1E;G0@+2T@=&AA="=S(&9U8VMI;B<@8G5G9WD@:6X@86QL(&9U8VMI;B<@
M8G)O=W-E<G,A(2$*"0DO+R!S;R!T:&%T('=E('-E="!A(&QA<F=E<B!S:7IE
M(&9O<B!T:&4@9&EA;&]G('=I;F1O=R!A;F0@=&AE;B!C96YT97(*"0DO+R!T
M:&4@96QE;65N="!I;G-I9&4N+BX@<&AU8VLA"@H)"2\O(&-E;G1E<BXN+@H)
M"79A<B!E;"`]('-E;&8N8V]N=&5N=#L*"0EV87(@<R`](&5L+G-T>6QE.PH)
M"2\O(',N=VED=&@@/2!E;"YO9F9S9717:61T:"`K(")P>"(["@D)+R\@<RYH
M96EG:'0@/2!E;"YO9F9S971(96EG:'0@*R`B<'@B.PH)"7,N<&]S:71I;VX@
M/2`B86)S;VQU=&4B.PH)"7,N;&5F="`]("AW("T@96PN;V9F<V5T5VED=&@I
M("\@,B`K(")P>"(["@D)<RYT;W`@/2`H:"`M(&5L+F]F9G-E=$AE:6=H="D@
M+R`R("L@(G!X(CL*"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\I('L*"0D)<V5L
M9BYW:6YD;W<N:6YN97)7:61T:"`]('<["@D)"7-E;&8N=VEN9&]W+FEN;F5R
M2&5I9VAT(#T@:#L*"0E](&5L<V4@>PH)"0ES96QF+G=I;F1O=RYR97-I>F54
M;RAW("L@."P@:"`K(#,U*3L*"0E]"@E]+"`R-2D["GT["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;W!U<&1I=BYJ<P``````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(V-S8`,3`U
M,34T,S$P-C0`,#(S-3,W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\J*B!4:&ES(&9I;&4@:7,@9&5R:79E9"!F<F]M(%!O
M<'5P1&EV+"!D979E;&]P960@8GD@36EH86D@0F%Z;VX@9F]R"B`J(%-A;5=A
M<F4N;F5T+B`@36]D:69I8V%T:6]N<R!W97)E(&YE961E9"!T;R!M86ME(&ET
M('5S86)L92!I;B!(5$U,07)E82X*("H@2%1-3$%R96$@:7,@82!F<F5E(%=9
M4TE764<@;VYL:6YE($A434P@961I=&]R(&9R;VT@26YT97)A8W1I=F54;V]L
M<RYC;VTN"B`J"B`J(%1H:7,@9FEL92!D;V5S(&YO="!F=6YC=&EO;B!S=&%N
M9&%L;VYE+B`@270@:7,@9&5P96YD96YT(&]F(&=L;V)A;"!F=6YC=&EO;G,*
M("H@9&5F:6YE9"!I;B!(5$U,07)E82TS+C`@*&AT;6QA<F5A+FIS*2X*("H*
M("H@4&QE87-E('-E92!F:6QE(&AT;6QA<F5A+FIS(&9O<B!F=7)T:&5R(&1E
M=&%I;',N"B`J*B\*"G9A<B!I<U]I92`]("@@*&YA=FEG871O<BYU<V5R06=E
M;G0N=&],;W=E<D-A<V4H*2YI;F1E>$]F*")M<VEE(BD@(3T@+3$I("8F"@D@
M("`@("`H;F%V:6=A=&]R+G5S97)!9V5N="YT;TQO=V5R0V%S92@I+FEN9&5X
M3V8H(F]P97)A(BD@/3T@+3$I("D["G9A<B!I<U]C;VUP870@/2`H9&]C=6UE
M;G0N8V]M<&%T36]D92`]/2`B0F%C:T-O;7!A="(I.PH*9G5N8W1I;VX@4&]P
M=7!$:78H961I=&]R+"!T:71L951E>'0L(&AA;F1L97(L(&EN:71&=6YC=&EO
M;BD@>PH)=F%R('-E;&8@/2!T:&ES.PH*"71H:7,N961I=&]R(#T@961I=&]R
M.PH)=&AI<RYD;V,@/2!E9&ET;W(N7VUD;V,["@ET:&ES+FAA;F1L97(@/2!H
M86YD;&5R.PH*"79A<B!E;"`]('1H:7,N9&]C+F-R96%T945L96UE;G0H(F1I
M=B(I.PH)96PN8VQA<W-.86UE(#T@(F-O;G1E;G0B.PH*"79A<B!P;W!U<"`]
M('1H:7,N9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)<&]P=7`N8VQA<W-.
M86UE(#T@(F1I86QO9R!P;W!U<&1I=B(["@ET:&ES+F5L96UE;G0@/2!P;W!U
M<#L*"79A<B!S(#T@<&]P=7`N<W1Y;&4["@ES+G!O<VET:6]N(#T@(F%B<V]L
M=71E(CL*"7,N;&5F="`]("(P<'@B.PH)<RYT;W`@/2`B,'!X(CL*"@EV87(@
M=&ET;&4@/2!T:&ES+F1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"71I=&QE
M+F-L87-S3F%M92`](")T:71L92(["@ET:&ES+G1I=&QE(#T@=&ET;&4["@EP
M;W!U<"YA<'!E;F1#:&EL9"AT:71L92D["@H)2%1-3$%R96$N7V%D9$5V96YT
M*'1I=&QE+"`B;6]U<V5D;W=N(BP@9G5N8W1I;VXH978I('L*"0ES96QF+E]D
M<F%G4W1A<G0H:7-?:64@/R!W:6YD;W<N979E;G0@.B!E=BD["@E]*3L*"@EV
M87(@8G5T=&]N(#T@=&AI<RYD;V,N8W)E871E16QE;65N="@B9&EV(BD["@EB
M=71T;VXN8VQA<W-.86UE(#T@(F)U='1O;B(["@ET:71L92YA<'!E;F1#:&EL
M9"AB=71T;VXI.PH)8G5T=&]N+FEN;F5R2%1-3"`]("(F(W@P,&0W.R(["@ET
M:71L92YA<'!E;F1#:&EL9"AT:&ES+F1O8RYC<F5A=&5497AT3F]D92AT:71L
M951E>'0I*3L*"71H:7,N=&ET;&5497AT(#T@=&ET;&5497AT.PH*"6)U='1O
M;BYO;FUO=7-E;W9E<B`](&9U;F-T:6]N*"D@>PH)"71H:7,N8VQA<W-.86UE
M("L]("(@8G5T=&]N+6AI;&ET92(["@E].PH)8G5T=&]N+F]N;6]U<V5O=70@
M/2!F=6YC=&EO;B@I('L*"0ET:&ES+F-L87-S3F%M92`]('1H:7,N8VQA<W-.
M86UE+G)E<&QA8V4H+UQS*F)U='1O;BUH:6QI=&5<<RHO9RP@(B`B*3L*"7T[
M"@EB=71T;VXN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH)"71H:7,N8VQA<W-.
M86UE(#T@=&AI<RYC;&%S<TYA;64N<F5P;&%C92@O7',J8G5T=&]N+6AI;&ET
M95QS*B]G+"`B("(I.PH)"7-E;&8N8VQO<V4H*3L*"7T["@H)<&]P=7`N87!P
M96YD0VAI;&0H96PI.PH)=&AI<RYC;VYT96YT(#T@96P["@H)=&AI<RYD;V,N
M8F]D>2YA<'!E;F1#:&EL9"AP;W!U<"D["@H)=&AI<RYD<F%G9VEN9R`](&9A
M;'-E.PH)=&AI<RYO;E-H;W<@/2!N=6QL.PH)=&AI<RYO;D-L;W-E(#T@;G5L
M;#L*"71H:7,N;6]D86P@/2!F86QS93L*"@EI;FET1G5N8W1I;VXH=&AI<RD[
M"GT["@I0;W!U<$1I=BYC=7)R96YT4&]P=7`@/2!N=6QL.PH*4&]P=7!$:78N
M<')O=&]T>7!E+G-H;W=!=$5L96UE;G0@/2!F=6YC=&EO;BAE;"P@;6]D92D@
M>PH)=&AI<RYD969A=6QT4VEZ92@I.PH)=F%R('!O<RP@97<L(&5H.PH)=F%R
M('!O<'5P(#T@=&AI<RYE;&5M96YT.PH)<&]P=7`N<W1Y;&4N9&ES<&QA>2`]
M(")B;&]C:R(["@EV87(@=R`]('!O<'5P+F]F9G-E=%=I9'1H.PH)=F%R(&@@
M/2!P;W!U<"YO9F9S971(96EG:'0["@EP;W!U<"YS='EL92YD:7-P;&%Y(#T@
M(FYO;F4B.PH):68@*&5L("$]('=I;F1O=RD@>PH)"7!O<R`](%!O<'5P1&EV
M+F=E=$%B<V]L=71E4&]S*&5L*3L*"0EE=R`](&5L+F]F9G-E=%=I9'1H.PH)
M"65H(#T@96PN;V9F<V5T2&5I9VAT.PH)?2!E;'-E('L*"0EP;W,@/2![>#HP
M+"!Y.C!].PH)"79A<B!S:7IE(#T@4&]P=7!$:78N9V5T5VEN9&]W4VEZ92@I
M.PH)"65W(#T@<VEZ92YX.PH)"65H(#T@<VEZ92YY.PH)?0H)=F%R($98(#T@
M9F%L<V4L($99(#T@9F%L<V4["@EI9B`H;6]D92YI;F1E>$]F*")L(BD@(3T@
M+3$I('L*"0EP;W,N>"`M/2!W.PH)"498(#T@=')U93L*"7T*"6EF("AM;V1E
M+FEN9&5X3V8H(G(B*2`A/2`M,2D@>PH)"7!O<RYX("L](&5W.PH)"498(#T@
M=')U93L*"7T*"6EF("AM;V1E+FEN9&5X3V8H(G0B*2`A/2`M,2D@>PH)"7!O
M<RYY("T](&@["@D)1ED@/2!T<G5E.PH)?0H):68@*&UO9&4N:6YD97A/9B@B
M8B(I("$]("TQ*2!["@D)<&]S+GD@*ST@96@["@D)1ED@/2!T<G5E.PH)?0H)
M:68@*&UO9&4N:6YD97A/9B@B8R(I("$]("TQ*2!["@D)1E@@?'P@*'!O<RYX
M("L]($UA=&@N<F]U;F0H*&5W("T@=RD@+R`R*2D["@D)1ED@?'P@*'!O<RYY
M("L]($UA=&@N<F]U;F0H*&5H("T@:"D@+R`R*2D["@E]"@ET:&ES+G-H;W=!
M="AP;W,N>"P@<&]S+GDI.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+F1E9F%U
M;'13:7IE(#T@9G5N8W1I;VXH*2!["@EV87(@<R`]('1H:7,N96QE;65N="YS
M='EL93L*"79A<B!C<R`]('1H:7,N96QE;65N="YC=7)R96YT4W1Y;&4["@EV
M87(@861D6"`]("AI<U]I92`F)B!I<U]C;VUP870I(#\@*'!A<G-E26YT*&-S
M+F)O<F1E<DQE9G17:61T:"D@*PH)"0D)"2`@('!A<G-E26YT*&-S+F)O<F1E
M<E)I9VAT5VED=&@I("L*"0D)"0D@("!P87)S94EN="AC<RYP861D:6YG3&5F
M="D@*PH)"0D)"2`@('!A<G-E26YT*&-S+G!A9&1I;F=2:6=H="DI(#H@,#L*
M"79A<B!A9&19(#T@*&ES7VEE("8F(&ES7V-O;7!A="D@/R`H<&%R<V5);G0H
M8W,N8F]R9&5R5&]P5VED=&@I("L*"0D)"0D@("!P87)S94EN="AC<RYB;W)D
M97)";W1T;VU7:61T:"D@*PH)"0D)"2`@('!A<G-E26YT*&-S+G!A9&1I;F=4
M;W`I("L*"0D)"0D@("!P87)S94EN="AC<RYP861D:6YG0F]T=&]M*2D@.B`P
M.PH)<RYD:7-P;&%Y(#T@(F)L;V-K(CL*"7,N=VED=&@@/2`H=&AI<RYC;VYT
M96YT+F]F9G-E=%=I9'1H("L@861D6"D@*R`B<'@B.PH)<RYH96EG:'0@/2`H
M=&AI<RYC;VYT96YT+F]F9G-E=$AE:6=H="`K('1H:7,N=&ET;&4N;V9F<V5T
M2&5I9VAT*2`K(")P>"(["@ES+F1I<W!L87D@/2`B;F]N92(["GT["@I0;W!U
M<$1I=BYP<F]T;W1Y<&4N<VAO=T%T(#T@9G5N8W1I;VXH>"P@>2D@>PH)=&AI
M<RYD969A=6QT4VEZ92@I.PH)=F%R(',@/2!T:&ES+F5L96UE;G0N<W1Y;&4[
M"@ES+F1I<W!L87D@/2`B8FQO8VLB.PH)<RYL969T(#T@>"`K(")P>"(["@ES
M+G1O<"`]('D@*R`B<'@B.PH)=&AI<RYH:61E4VAO=T-O=F5R960H*3L*"@E0
M;W!U<$1I=BYC=7)R96YT4&]P=7`@/2!T:&ES.PH)2%1-3$%R96$N7V%D9$5V
M96YT<RAT:&ES+F1O8RYB;V1Y+"!;(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0
M;W!U<$1I=BYC:&5C:U!O<'5P*3L*"4A434Q!<F5A+E]A9&1%=F5N=',H=&AI
M<RYE9&ET;W(N7V1O8RYB;V1Y+"!;(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0
M;W!U<$1I=BYC:&5C:U!O<'5P*3L*"6EF("AI<U]I92`F)B!T:&ES+FUO9&%L
M*2!["@D)=&AI<RYD;V,N8F]D>2YS971#87!T=7)E*&9A;'-E*3L*"0ET:&ES
M+F1O8RYB;V1Y+F]N;&]S96-A<'1U<F4@/2!F=6YC=&EO;B@I('L*"0D)*%!O
M<'5P1&EV+F-U<G)E;G10;W!U<"D@)B8@*'1H:7,N9&]C+F)O9'DN<V5T0V%P
M='5R92AF86QS92DI.PH)"7T["@E]"@EW:6YD;W<N979E;G0@)B8@2%1-3$%R
M96$N7W-T;W!%=F5N="AW:6YD;W<N979E;G0I.PH*"6EF("AT>7!E;V8@=&AI
M<RYO;E-H;W<@/3T@(F9U;F-T:6]N(BD@>PH)"71H:7,N;VY3:&]W*"D["@E]
M(&5L<V4@:68@*'1Y<&5O9B!T:&ES+F]N4VAO=R`]/2`B<W1R:6YG(BD@>PH)
M"65V86PH=&AI<RYO;E-H;W<I.PH)?0H*"79A<B!F:65L9"`]('1H:7,N96QE
M;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@B:6YP=70B*5LP73L*"6EF("@A
M9FEE;&0I('L*"0EF:65L9"`]('1H:7,N96QE;65N="YG971%;&5M96YT<T)Y
M5&%G3F%M92@B<V5L96-T(BE;,%T["@E]"@EI9B`H(69I96QD*2!["@D)9FEE
M;&0@/2!T:&ES+F5L96UE;G0N9V5T16QE;65N='-">51A9TYA;64H(G1E>'1A
M<F5A(BE;,%T["@E]"@EI9B`H9FEE;&0I('L*"0EF:65L9"YF;V-U<R@I.PH)
M?0I].PH*4&]P=7!$:78N<')O=&]T>7!E+F-L;W-E(#T@9G5N8W1I;VXH*2![
M"@ET:&ES+F5L96UE;G0N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"5!O<'5P
M1&EV+F-U<G)E;G10;W!U<"`](&YU;&P["@ET:&ES+FAI9&53:&]W0V]V97)E
M9"@I.PH)2%1-3$%R96$N7W)E;6]V945V96YT<RAT:&ES+F1O8RYB;V1Y+"!;
M(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O<'5P*3L*
M"4A434Q!<F5A+E]R96UO=F5%=F5N=',H=&AI<RYE9&ET;W(N7V1O8RYB;V1Y
M+"!;(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O<'5P
M*3L*"6ES7VEE("8F('1H:7,N;6]D86P@)B8@=&AI<RYD;V,N8F]D>2YR96QE
M87-E0V%P='5R92@I.PH):68@*'1Y<&5O9B!T:&ES+F]N0VQO<V4@/3T@(F9U
M;F-T:6]N(BD@>PH)"71H:7,N;VY#;&]S92@I.PH)?2!E;'-E(&EF("AT>7!E
M;V8@=&AI<RYO;D-L;W-E(#T](")S=')I;F<B*2!["@D)979A;"AT:&ES+F]N
M0VQO<V4I.PH)?0H)=&AI<RYE;&5M96YT+G!A<F5N=$YO9&4N<F5M;W9E0VAI
M;&0H=&AI<RYE;&5M96YT*3L*?3L*"E!O<'5P1&EV+G!R;W1O='EP92YG971&
M;W)M(#T@9G5N8W1I;VXH*2!["@EV87(@9F]R;7,@/2!T:&ES+F-O;G1E;G0N
M9V5T16QE;65N='-">51A9TYA;64H(F9O<FTB*3L*"7)E='5R;B`H9F]R;7,N
M;&5N9W1H(#X@,"D@/R!F;W)M<ULP72`Z(&YU;&P["GT["@I0;W!U<$1I=BYP
M<F]T;W1Y<&4N8V%L;$AA;F1L97(@/2!F=6YC=&EO;B@I('L*"79A<B!T86=S
M(#T@6R)I;G!U="(L(")T97AT87)E82(L(")S96QE8W0B73L*"79A<B!P87)A
M;7,@/2!N97<@3V)J96-T*"D["@EF;W(@*'9A<B!T:2`]('1A9W,N;&5N9W1H
M.R`M+71I(#X](#`[*2!["@D)=F%R('1A9R`]('1A9W-;=&E=.PH)"79A<B!E
M;',@/2!T:&ES+F-O;G1E;G0N9V5T16QE;65N='-">51A9TYA;64H=&%G*3L*
M"0EF;W(@*'9A<B!J(#T@,#L@:B`\(&5L<RYL96YG=&@[("LK:BD@>PH)"0EV
M87(@96P@/2!E;'-;:ET["@D)"7!A<F%M<UME;"YN86UE72`](&5L+G9A;'5E
M.PH)"7T*"7T*"71H:7,N:&%N9&QE<BAT:&ES+"!P87)A;7,I.PH)<F5T=7)N
M(&9A;'-E.PI].PH*4&]P=7!$:78N9V5T06)S;VQU=&50;W,@/2!F=6YC=&EO
M;BAE;"D@>PH)=F%R('(@/2![('@Z(&5L+F]F9G-E=$QE9G0L('DZ(&5L+F]F
M9G-E=%1O<"!].PH):68@*&5L+F]F9G-E=%!A<F5N="D@>PH)"79A<B!T;7`@
M/2!0;W!U<$1I=BYG971!8G-O;'5T95!O<RAE;"YO9F9S971087)E;G0I.PH)
M"7(N>"`K/2!T;7`N>#L*"0ER+GD@*ST@=&UP+GD["@E]"@ER971U<FX@<CL*
M?3L*"E!O<'5P1&EV+F=E=%=I;F1O=U-I>F4@/2!F=6YC=&EO;B@I('L*"6EF
M("AW:6YD;W<N:6YN97)(96EG:'0I('L*"0ER971U<FX@>R!Y.B!W:6YD;W<N
M:6YN97)(96EG:'0L('@Z('=I;F1O=RYI;FYE<E=I9'1H('T["@E]"@EI9B`H
M=&AI<RYD;V,N8F]D>2YC;&EE;G1(96EG:'0I('L*"0ER971U<FX@>R!Y.B!T
M:&ES+F1O8RYB;V1Y+F-L:65N=$AE:6=H="P@>#H@=&AI<RYD;V,N8F]D>2YC
M;&EE;G17:61T:"!].PH)?0H)<F5T=7)N('L@>3H@=&AI<RYD;V,N9&]C=6UE
M;G1%;&5M96YT+F-L:65N=$AE:6=H="P@>#H@=&AI<RYD;V,N9&]C=6UE;G1%
M;&5M96YT+F-L:65N=%=I9'1H('T["GT["@I0;W!U<$1I=BYP<F]T;W1Y<&4N
M:&ED95-H;W=#;W9E<F5D(#T@9G5N8W1I;VX@*"D@>PH)=F%R('-E;&8@/2!T
M:&ES.PH)9G5N8W1I;VX@:7-#;VYT86EN960H96PI('L*"0EW:&EL92`H96PI
M('L*"0D):68@*&5L(#T]('-E;&8N96QE;65N="D@>PH)"0D)<F5T=7)N('1R
M=64["@D)"7T*"0D)96P@/2!E;"YP87)E;G1.;V1E.PH)"7T*"0ER971U<FX@
M9F%L<V4["@E].PH)=F%R('1A9W,@/2!N97<@07)R87DH(F%P<&QE="(L(")S
M96QE8W0B*3L*"79A<B!E;"`]('1H:7,N96QE;65N=#L*"@EV87(@<"`](%!O
M<'5P1&EV+F=E=$%B<V]L=71E4&]S*&5L*3L*"79A<B!%6#$@/2!P+G@["@EV
M87(@15@R(#T@96PN;V9F<V5T5VED=&@@*R!%6#$["@EV87(@15DQ(#T@<"YY
M.PH)=F%R($59,B`](&5L+F]F9G-E=$AE:6=H="`K($59,3L*"@EI9B`H96PN
M<W1Y;&4N9&ES<&QA>2`]/2`B;F]N92(I('L*"0E%6#$@/2!%6#(@/2!%63$@
M/2!%63(@/2`P.PH)?0H*"69O<B`H=F%R(&L@/2!T86=S+FQE;F=T:#L@:R`^
M(#`[("D@>PH)"79A<B!A<B`]('1H:7,N9&]C+F=E=$5L96UE;G1S0GE486=.
M86UE*'1A9W-;+2UK72D["@D)=F%R(&-C(#T@;G5L;#L*"@D)9F]R("AV87(@
M:2`](&%R+FQE;F=T:#L@:2`^(#`[*2!["@D)"6-C(#T@87);+2UI73L*"0D)
M:68@*&ES0V]N=&%I;F5D*&-C*2D@>PH)"0D)8V,N<W1Y;&4N=FES:6)I;&ET
M>2`](")V:7-I8FQE(CL*"0D)"6-O;G1I;G5E.PH)"0E]"@H)"0EP(#T@4&]P
M=7!$:78N9V5T06)S;VQU=&50;W,H8V,I.PH)"0EV87(@0U@Q(#T@<"YX.PH)
M"0EV87(@0U@R(#T@8V,N;V9F<V5T5VED=&@@*R!#6#$["@D)"79A<B!#63$@
M/2!P+GD["@D)"79A<B!#63(@/2!C8RYO9F9S971(96EG:'0@*R!#63$["@H)
M"0EI9B`H*$-8,2`^($58,BD@?'P@*$-8,B`\($58,2D@?'P@*$-9,2`^($59
M,BD@?'P@*$-9,B`\($59,2DI('L*"0D)"6-C+G-T>6QE+G9I<VEB:6QI='D@
M/2`B=FES:6)L92(["@D)"7T@96QS92!["@D)"0EC8RYS='EL92YV:7-I8FEL
M:71Y(#T@(FAI9&1E;B(["@D)"7T*"0E]"@E]"GT["@I0;W!U<$1I=BYP<F]T
M;W1Y<&4N7V1R86=3=&%R="`](&9U;F-T:6]N("AE=BD@>PH):68@*'1H:7,N
M9')A9V=I;F<I('L*"0ER971U<FX@9F%L<V4["@E]"@ET:&ES+F1R86=G:6YG
M(#T@=')U93L*"5!O<'5P1&EV+F-U<G)E;G10;W!U<"`]('1H:7,["@EV87(@
M<&]S6"`](&5V+F-L:65N=%@["@EV87(@<&]S62`](&5V+F-L:65N=%D["@EI
M9B`H:7-?:64I('L*"0EP;W-9("L]('1H:7,N9&]C+F)O9'DN<V-R;VQL5&]P
M.PH)"7!O<U@@*ST@=&AI<RYD;V,N8F]D>2YS8W)O;&Q,969T.PH)?2!E;'-E
M('L*"0EP;W-9("L]('=I;F1O=RYS8W)O;&Q9.PH)"7!O<U@@*ST@=VEN9&]W
M+G-C<F]L;%@["@E]"@EV87(@<W0@/2!T:&ES+F5L96UE;G0N<W1Y;&4["@ET
M:&ES+GA/9F9S(#T@<&]S6"`M('!A<G-E26YT*'-T+FQE9G0I.PH)=&AI<RYY
M3V9F<R`]('!O<UD@+2!P87)S94EN="AS="YT;W`I.PH)2%1-3$%R96$N7V%D
M9$5V96YT*'1H:7,N9&]C+"`B;6]U<V5M;W9E(BP@4&]P=7!$:78N9')A9TET
M*3L*"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F1O8RP@(FUO=7-E;W9E<B(L
M($A434Q!<F5A+E]S=&]P179E;G0I.PH)2%1-3$%R96$N7V%D9$5V96YT*'1H
M:7,N9&]C+"`B;6]U<V5U<"(L(%!O<'5P1&EV+F1R86=%;F0I.PH)2%1-3$%R
M96$N7W-T;W!%=F5N="AE=BD["GT["@I0;W!U<$1I=BYD<F%G270@/2!F=6YC
M=&EO;B`H978I('L*"79A<B!P;W!U<"`](%!O<'5P1&EV+F-U<G)E;G10;W!U
M<#L*"6EF("@A*'!O<'5P("8F('!O<'5P+F1R86=G:6YG*2D@>PH)"7)E='5R
M;B!F86QS93L*"7T*"6ES7VEE("8F("AE=B`]('=I;F1O=RYE=F5N="D["@EV
M87(@<&]S6"`](&5V+F-L:65N=%@["@EV87(@<&]S62`](&5V+F-L:65N=%D[
M"@EI9B`H:7-?:64I('L*"0EP;W-9("L]('1H:7,N9&]C+F)O9'DN<V-R;VQL
M5&]P.PH)"7!O<U@@*ST@=&AI<RYD;V,N8F]D>2YS8W)O;&Q,969T.PH)?2!E
M;'-E('L*"0EP;W-9("L]('=I;F1O=RYS8W)O;&Q9.PH)"7!O<U@@*ST@=VEN
M9&]W+G-C<F]L;%@["@E]"@EP;W!U<"YH:61E4VAO=T-O=F5R960H*3L*"79A
M<B!S="`]('!O<'5P+F5L96UE;G0N<W1Y;&4["@ES="YL969T(#T@*'!O<U@@
M+2!P;W!U<"YX3V9F<RD@*R`B<'@B.PH)<W0N=&]P(#T@*'!O<UD@+2!P;W!U
M<"YY3V9F<RD@*R`B<'@B.PH)2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["GT[
M"@I0;W!U<$1I=BYD<F%G16YD(#T@9G5N8W1I;VX@*"D@>PH)=F%R('!O<'5P
M(#T@4&]P=7!$:78N8W5R<F5N=%!O<'5P.PH):68@*"%P;W!U<"D@>PH)"7)E
M='5R;B!F86QS93L*"7T*"7!O<'5P+F1R86=G:6YG(#T@9F%L<V4["@E(5$U,
M07)E82Y?<F5M;W9E179E;G0H<&]P=7`N9&]C+"`B;6]U<V5U<"(L(%!O<'5P
M1&EV+F1R86=%;F0I.PH)2%1-3$%R96$N7W)E;6]V945V96YT*'!O<'5P+F1O
M8RP@(FUO=7-E;W9E<B(L($A434Q!<F5A+E]S=&]P179E;G0I.PH)2%1-3$%R
M96$N7W)E;6]V945V96YT*'!O<'5P+F1O8RP@(FUO=7-E;6]V92(L(%!O<'5P
M1&EV+F1R86=)="D["@EP;W!U<"YH:61E4VAO=T-O=F5R960H*3L*?3L*"E!O
M<'5P1&EV+F-H96-K4&]P=7`@/2!F=6YC=&EO;B`H978I('L*"6ES7VEE("8F
M("AE=B`]('=I;F1O=RYE=F5N="D["@EV87(@96P@/2!I<U]I92`_(&5V+G-R
M8T5L96UE;G0@.B!E=BYT87)G970["@EV87(@8W`@/2!0;W!U<$1I=BYC=7)R
M96YT4&]P=7`["@EF;W(@*#L@*&5L("$](&YU;&PI("8F("AE;"`A/2!C<"YE
M;&5M96YT*3L@96P@/2!E;"YP87)E;G1.;V1E*3L*"6EF("AE;"`]/2!N=6QL
M*2!["@D)8W`N;6]D86P@?'P@978N='EP92`]/2`B;6]U<V5O=F5R(B!\?"!C
M<"YC;&]S92@I.PH)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)?0I].PH*
M4&]P=7!$:78N<')O=&]T>7!E+F%D9$)U='1O;G,@/2!F=6YC=&EO;B@I('L*
M"79A<B!S96QF(#T@=&AI<SL*"79A<B!D:78@/2!T:&ES+F1O8RYC<F5A=&5%
M;&5M96YT*")D:78B*3L*"71H:7,N8V]N=&5N="YA<'!E;F1#:&EL9"AD:78I
M.PH)9&EV+F-L87-S3F%M92`](")B=71T;VYS(CL*"69O<B`H=F%R(&D@/2`P
M.R!I(#P@87)G=6UE;G1S+FQE;F=T:#L@*RMI*2!["@D)=F%R(&)T;B`](&%R
M9W5M96YT<UMI73L*"0EV87(@8G5T=&]N(#T@=&AI<RYD;V,N8W)E871E16QE
M;65N="@B8G5T=&]N(BD["@D)9&EV+F%P<&5N9$-H:6QD*&)U='1O;BD["@D)
M8G5T=&]N+FEN;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN8G5T=&]N<UMB=&Y=
M.PH)"7-W:71C:"`H8G1N*2!["@D)("`@(&-A<V4@(F]K(CH*"0D)8G5T=&]N
M+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*"0D)"7-E;&8N8V%L;$AA;F1L97(H
M*3L*"0D)"7-E;&8N8VQO<V4H*3L*"0D)?3L*"0D)8G)E86L["@D)("`@(&-A
M<V4@(F-A;F-E;"(Z"@D)"6)U='1O;BYO;F-L:6-K(#T@9G5N8W1I;VXH*2![
M"@D)"0ES96QF+F-L;W-E*"D["@D)"7T["@D)"6)R96%K.PH)"7T*"7T*?3L*
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M;&%R96$N:G,`````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,C,W,C,R`#$P-3$U-#,Q,#8T`#`R,S0V,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O+R!H=&UL
M07)E82!V,RXP("T@0V]P>7)I9VAT("AC*2`R,#`S+3(P,#4@9'EN87)C:"YC
M;VT*+R\@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,C`P,BTR,#`S
M(&EN=&5R86-T:79E=&]O;',N8V]M+"!I;F,N"B\O(%1H:7,@8V]P>7)I9VAT
M(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U<V4@*'-E92!L:6-E;G-E
M+G1X="DN"B\O"B\O($$@9G)E92!765-)5UE'(&5D:71O<B!R97!L86-E;65N
M="!F;W(@/'1E>'1A<F5A/B!F:65L9',N"B\O($9O<B!F=6QL('-O=7)C92!C
M;V1E(&%N9"!D;V-S+"!V:7-I="!H='1P.B\O=W=W+FEN=&5R86-T:79E=&]O
M;',N8V]M+PHO+PHO+R!697)S:6]N(#,N,"!D979E;&]P960@8GD@36EH86D@
M0F%Z;VXN"B\O("`@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;R\*+R\*+R\@
M)$ED.B!H=&UL87)E82YJ<RQV(#$N.3<@,C`P-2\P,2\R.2`P,#HT-CHU,2!I
M=&]O;',@17AP("0*"FEF("AT>7!E;V8@7V5D:71O<E]U<FP@/3T@(G-T<FEN
M9R(I('L*"2\O($QE879E(&5X86-T;'D@;VYE(&)A8VMS;&%S:"!A="!T:&4@
M96YD(&]F(%]E9&ET;W)?=7)L"@E?961I=&]R7W5R;"`](%]E9&ET;W)?=7)L
M+G)E<&QA8V4H+UQX,F8J)"\L("<O)RD["GT@96QS92!["@EA;&5R="@B5T%2
M3DE.1SH@7V5D:71O<E]U<FP@:7,@;F]T('-E="$@(%EO=2!S:&]U;&0@<V5T
M('1H:7,@=F%R:6%B;&4@=&\@=&AE(&5D:71O<B!F:6QE<R!P871H.R!I="!S
M:&]U;&0@<')E9F5R86)L>2!B92!A;B!A8G-O;'5T92!P871H+"!L:6ME(&EN
M("<O:'1M;&%R96$O)RP@8G5T(&ET(&-A;B!B92!R96QA=&EV92!I9B!Y;W4@
M<')E9F5R+B`@1G5R=&AE<B!W92!W:6QL('1R>2!T;R!L;V%D('1H92!E9&ET
M;W(@9FEL97,@8V]R<F5C=&QY(&)U="!W92=L;"!P<F]B86)L>2!F86EL+B(I
M.PH)7V5D:71O<E]U<FP@/2`G)SL*?0H*+R\@;6%K92!S=7)E('=E(&AA=F4@
M82!L86YG=6%G90II9B`H='EP96]F(%]E9&ET;W)?;&%N9R`]/2`B<W1R:6YG
M(BD@>PH)7V5D:71O<E]L86YG(#T@7V5D:71O<E]L86YG+G1O3&]W97)#87-E
M*"D["GT@96QS92!["@E?961I=&]R7VQA;F<@/2`B96XB.PI]"@HO+R!B<F]W
M<V5R(&ED96YT:69I8V%T:6]N"DA434Q!<F5A+F%G="`](&YA=FEG871O<BYU
M<V5R06=E;G0N=&],;W=E<D-A<V4H*3L*2%1-3$%R96$N:7-?:64)("`@/2`H
M*$A434Q!<F5A+F%G="YI;F1E>$]F*")M<VEE(BD@(3T@+3$I("8F("A(5$U,
M07)E82YA9W0N:6YD97A/9B@B;W!E<F$B*2`]/2`M,2DI.PI(5$U,07)E82YI
M<U]O<&5R82`@/2`H2%1-3$%R96$N86=T+FEN9&5X3V8H(F]P97)A(BD@(3T@
M+3$I.PI(5$U,07)E82YI<U]M86,)("`@/2`H2%1-3$%R96$N86=T+FEN9&5X
M3V8H(FUA8R(I("$]("TQ*3L*2%1-3$%R96$N:7-?;6%C7VEE(#T@*$A434Q!
M<F5A+FES7VEE("8F($A434Q!<F5A+FES7VUA8RD["DA434Q!<F5A+FES7W=I
M;E]I92`]("A(5$U,07)E82YI<U]I92`F)B`A2%1-3$%R96$N:7-?;6%C*3L*
M2%1-3$%R96$N:7-?9V5C:V\@(#T@*&YA=FEG871O<BYP<F]D=6-T(#T](")'
M96-K;R(I.PH*+R\@0W)E871E<R!A(&YE=R!(5$U,07)E82!O8FIE8W0N("!4
M<FEE<R!T;R!R97!L86-E('1H92!T97AT87)E82!W:71H('1H92!G:79E;@HO
M+R!)1"!W:71H(&ET+@IF=6YC=&EO;B!(5$U,07)E82AT97AT87)E82P@8V]N
M9FEG*2!["B`@("`@("`@:68@*"%(5$U,07)E82Y?:6YI=%]C86QL960I('L*
M"2!A;&5R="@B17)R;W(Z(%EO=2!M=7-T(&-A;&QE9"!(5$U,07)E82YI;FET
M*"D@9FER<W0N("!,:6ME('1H:7,Z7&Y<;B(@*PH)("`@("`@(")(5$U,07)E
M82YI;FET*"D[7&XB("L*"2`@("`@("`B2%1-3$%R96$N;VYL;V%D(#T@9G5N
M8W1I;VXH*2![7&XB("L*"2`@("`@("`B("!V87(@961I=&]R(#T@;F5W($A4
M34Q!<F5A*"=E9&ET;W(G*3M<;B(@*PH)("`@("`@("(@(&5D:71O<BYG96YE
M<F%T92@I.UQN(B`K"@D@("`@("`@(GT[7&XB*3L*"2`@<F5T=7)N.PH)?0H*
M"6EF("A(5$U,07)E82YC:&5C:U-U<'!O<G1E9$)R;W=S97(H*2D@>PH)"6EF
M("AT>7!E;V8@8V]N9FEG(#T](")U;F1E9FEN960B*2!["@D)"71H:7,N8V]N
M9FEG(#T@;F5W($A434Q!<F5A+D-O;F9I9R@I.PH)"7T@96QS92!["@D)"71H
M:7,N8V]N9FEG(#T@8V]N9FEG.PH)"7T*"0ET:&ES+E]H=&UL07)E82`](&YU
M;&P["@D)=&AI<RY?=&5X=$%R96$@/2!T97AT87)E83L*"0ET:&ES+E]E9&ET
M36]D92`](")W>7-I=WEG(CL*"0ET:&ES+G!L=6=I;G,@/2![?3L*"0ET:&ES
M+E]T:6UE<E1O;VQB87(@/2!N=6QL.PH)"71H:7,N7W1I;65R56YD;R`](&YU
M;&P["@D)=&AI<RY?=6YD;U%U975E(#T@;F5W($%R<F%Y*'1H:7,N8V]N9FEG
M+G5N9&]3=&5P<RD["@D)=&AI<RY?=6YD;U!O<R`]("TQ.PH)"71H:7,N7V-U
M<W1O;55N9&\@/2!F86QS93L*"0ET:&ES+E]M9&]C(#T@9&]C=6UE;G0[("\O
M(&-A8VAE('1H92!D;V-U;65N="P@=V4@;F5E9"!I="!I;B!P;'5G:6YS"@D)
M=&AI<RYD;V-T>7!E(#T@)R<["@E]"GT["@I(5$U,07)E82YO;FQO860@/2!F
M=6YC=&EO;B@I>WT["DA434Q!<F5A+E]S8W)I<'1S(#T@6UT["DA434Q!<F5A
M+FQO86138W)I<'0@/2!F=6YC=&EO;BAU<FPL('!L=6=I;BD@>PH):68@*'!L
M=6=I;BD*"0EU<FP@/2!(5$U,07)E82YG9710;'5G:6Y$:7(H<&QU9VEN*2`K
M("<O)R`K('5R;#L*"71H:7,N7W-C<FEP=',N<'5S:"AU<FPI.PI].PH*2%1-
M3$%R96$N:6YI="`](&9U;F-T:6]N*"D@>PH)=F%R(&AE860@/2!D;V-U;65N
M="YG971%;&5M96YT<T)Y5&%G3F%M92@B:&5A9"(I6S!=.PH)=F%R(&-U<G)E
M;G0@/2`P.PH)=F%R('-A=F5T:71L92`](&1O8W5M96YT+G1I=&QE.PH)=F%R
M(&5V="`]($A434Q!<F5A+FES7VEE(#\@(F]N<F5A9'ES=&%T96-H86YG92(@
M.B`B;VYL;V%D(CL*"69U;F-T:6]N(&QO861.97AT4V-R:7!T*"D@>PH)"6EF
M("AC=7)R96YT(#X@,"`F)B!(5$U,07)E82YI<U]I92`F)@H)"2`@("`A+VQO
M861E9'QC;VUP;&5T92\N=&5S="AW:6YD;W<N979E;G0N<W)C16QE;65N="YR
M96%D>5-T871E*2D*"0D)<F5T=7)N.PH)"6EF("AC=7)R96YT(#P@2%1-3$%R
M96$N7W-C<FEP=',N;&5N9W1H*2!["@D)"79A<B!U<FP@/2!(5$U,07)E82Y?
M<V-R:7!T<UMC=7)R96YT*RM=.PH)"0ED;V-U;65N="YT:71L92`](");2%1-
M3$%R96$Z(&QO861I;F<@<V-R:7!T("(@*R!C=7)R96YT("L@(B\B("L@2%1-
M3$%R96$N7W-C<FEP=',N;&5N9W1H("L@(ETB.PH)"0EV87(@<V-R:7!T(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@B<V-R:7!T(BD["@D)"7-C<FEP="YT
M>7!E(#T@(G1E>'0O:F%V87-C<FEP="(["@D)"7-C<FEP="YS<F,@/2!U<FP[
M"@D)"7-C<FEP=%ME=G1=(#T@;&]A9$YE>'138W)I<'0["@D)"6AE860N87!P
M96YD0VAI;&0H<V-R:7!T*3L*"0E](&5L<V4@>PH)"0ED;V-U;65N="YT:71L
M92`]('-A=F5T:71L93L*("`@("`@("`@("`@("`@("`@("`@("`@2%1-3$%R
M96$N7VEN:71?8V%L;&5D(#T@,3L*"0D)2%1-3$%R96$N;VYL;V%D*"D["@D)
M?0H)?3L*"6QO861.97AT4V-R:7!T*"D["@I].PH*2%1-3$%R96$N;&]A9%-C
M<FEP="A?961I=&]R7W5R;"`K(")D:6%L;V<N:G,B*3L*2%1-3$%R96$N;&]A
M9%-C<FEP="A?961I=&]R7W5R;"`K(")P;W!U<'=I;BYJ<R(I.PI(5$U,07)E
M82YL;V%D4V-R:7!T*%]E9&ET;W)?=7)L("L@(FQA;F<O(B`K(%]E9&ET;W)?
M;&%N9R`K("(N:G,B*3L*"B\O(&-A8VAE('-O;64@<F5G97AP<PI(5$U,07)E
M82Y215]T86=.86UE(#T@+R@\7"]\/"E<<RHH6UX@7'1<;CY=*RDO:6<["DA4
M34Q!<F5A+E)%7V1O8W1Y<&4@/2`O*#PA9&]C='EP92@H+GQ<;BDJ/RD^*5QN
M/R]I.PI(5$U,07)E82Y215]H96%D("`@(#T@+SQH96%D/B@H+GQ<;BDJ/RD\
M7"]H96%D/B]I.PI(5$U,07)E82Y215]B;V1Y("`@(#T@+SQB;V1Y/B@H+GQ<
M;BDJ/RD\7"]B;V1Y/B]I.PH*2%1-3$%R96$N0V]N9FEG(#T@9G5N8W1I;VX@
M*"D@>PH)=&AI<RYV97)S:6]N(#T@(C,N,"(["@H)=&AI<RYW:61T:"`](")A
M=71O(CL*"71H:7,N:&5I9VAT(#T@(F%U=&\B.PH*"2\O(&5N86)L92!C<F5A
M=&EO;B!O9B!A('-T871U<R!B87(_"@ET:&ES+G-T871U<T)A<B`]('1R=64[
M"@H)+R\@:6YT97)C97!T(%Y6(&%N9"!U<V4@=&AE($A434Q!<F5A('!A<W1E
M(&-O;6UA;F0*"2\O($EF(&9A;'-E+"!T:&5N('!A<W-E<R!>5B!T:')O=6=H
M('1O(&)R;W=S97(@961I=&]R('=I9&=E=`H)=&AI<RYH=&UL87)E85!A<W1E
M(#T@9F%L<V4["@H)+R\@;6%X:6UU;2!S:7IE(&]F('1H92!U;F1O('%U975E
M"@ET:&ES+G5N9&]3=&5P<R`](#(P.PH*"2\O('1H92!T:6UE(&EN=&5R=F%L
M(&%T('=H:6-H('5N9&\@<V%M<&QE<R!A<F4@=&%K96X*"71H:7,N=6YD;U1I
M;65O=70@/2`U,#`["2\O(#$O,B!S96,N"@H)+R\@=&AE(&YE>'0@<&%R86UE
M=&5R('-P96-I9FEE<R!W:&5T:&5R('1H92!T;V]L8F%R('-H;W5L9"!B92!I
M;F-L=61E9`H)+R\@:6X@=&AE('-I>F4@;W(@;F]T+@H)=&AI<RYS:7IE26YC
M;'5D97-4;V]L8F%R(#T@=')U93L*"@DO+R!I9B!T<G5E('1H96X@2%1-3$%R
M96$@=VEL;"!R971R:65V92!T:&4@9G5L;"!(5$U,+"!S=&%R=&EN9R!W:71H
M('1H90H)+R\@/$A434P^('1A9RX*"71H:7,N9G5L;%!A9V4@/2!F86QS93L*
M"@DO+R!S='EL92!I;F-L=61E9"!I;B!T:&4@:69R86UE(&1O8W5M96YT"@ET
M:&ES+G!A9V53='EL92`]("(B.PH*"2\O('-E="!T;R!T<G5E(&EF('EO=2!W
M86YT(%=O<F0@8V]D92!T;R!B92!C;&5A;F5D('5P;VX@4&%S=&4*"71H:7,N
M:VEL;%=O<F1/;E!A<W1E(#T@=')U93L*"@DO+R!E;F%B;&4@=&AE("=487)G
M970G(&9I96QD(&EN('1H92!-86ME($QI;FL@9&EA;&]G"@ET:&ES+FUA:V5,
M:6YK4VAO=W-487)G970@/2!T<G5E.PH*"2\O($)A<V554DP@:6YC;'5D960@
M:6X@=&AE(&EF<F%M92!D;V-U;65N=`H)=&AI<RYB87-E55),(#T@9&]C=6UE
M;G0N8F%S955222!\?"!D;V-U;65N="Y54DP["@EI9B`H=&AI<RYB87-E55),
M("8F('1H:7,N8F%S95523"YM871C:"@O*"XJ*5PO*%M>7"]=*RDO*2D*"0ET
M:&ES+F)A<V554DP@/2!296=%>'`N)#$@*R`B+R(["@H)+R\@55),+7,*"71H
M:7,N:6UG55),(#T@(FEM86=E<R\B.PH)=&AI<RYP;W!U<%523"`](")P;W!U
M<',O(CL*"@DO+R!R96UO=F4@=&%G<R`H=&AE<V4@:&%V92!T;R!B92!A(')E
M9V5X<"P@;W(@;G5L;"!I9B!T:&ES(&9U;F-T:6]N86QI='D@:7,@;F]T(&1E
M<VER960I"@ET:&ES+FAT;6Q296UO=F5486=S(#T@;G5L;#L*"@DO*BH@0U53
M5$]-25I)3D<@5$A%(%1/3TQ"05(*"2`J("TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*"2`J"@D@*B!)="!I<R!R96-O;6UE;F1E9"!T:&%T('EO=2!C=7-T
M;VUI>F4@=&AE('1O;VQB87(@8V]N=&5N=',@:6X@86X*"2`J(&5X=&5R;F%L
M(&9I;&4@*&DN92X@=&AE(&]N92!C86QL:6YG($A434Q!<F5A*2!A;F0@;&5A
M=F4@=&AI<R!O;F4*"2`J('5N8VAA;F=E9"X@(%1H870G<R!B96-A=7-E('=H
M96X@=V4@*$EN=&5R86-T:79E5&]O;',N8V]M*2!R96QE87-E(&$*"2`J(&YE
M=R!O9F9I8VEA;"!V97)S:6]N+"!I="=S(&QE<W,@;&EK96QY('1H870@>6]U
M('=I;&P@:&%V92!P<F]B;&5M<PH)("H@=7!G<F%D:6YG($A434Q!<F5A+@H)
M("HO"@ET:&ES+G1O;VQB87(@/2!;"@D)6R`B9F]N=&YA;64B+"`B<W!A8V4B
M+`H)"2`@(F9O;G1S:7IE(BP@(G-P86-E(BP*"0D@(")F;W)M871B;&]C:R(L
M(")S<&%C92(L"@D)("`B8F]L9"(L(")I=&%L:6,B+"`B=6YD97)L:6YE(BP@
M(G-T<FEK971H<F]U9V@B+"`B<V5P87)A=&]R(BP*"0D@(")S=6)S8W)I<'0B
M+"`B<W5P97)S8W)I<'0B+"`B<V5P87)A=&]R(BP*"0D@(")C;W!Y(BP@(F-U
M="(L(")P87-T92(L(")S<&%C92(L(")U;F1O(BP@(G)E9&\B+"`B<W!A8V4B
M+"`B<F5M;W9E9F]R;6%T(BP@(FMI;&QW;W)D(B!=+`H*"0E;(")J=7-T:69Y
M;&5F="(L(")J=7-T:69Y8V5N=&5R(BP@(FIU<W1I9GER:6=H="(L(")J=7-T
M:69Y9G5L;"(L(")S97!A<F%T;W(B+`H)"2`@(FQE9G1T;W)I9VAT(BP@(G)I
M9VAT=&]L969T(BP@(G-E<&%R871O<B(L"@D)("`B;W)D97)E9&QI<W0B+"`B
M=6YO<F1E<F5D;&ES="(L(")O=71D96YT(BP@(FEN9&5N="(L(")S97!A<F%T
M;W(B+`H)"2`@(F9O<F5C;VQO<B(L(")H:6QI=&5C;VQO<B(L(")S97!A<F%T
M;W(B+`H)"2`@(FEN<V5R=&AO<FEZ;VYT86QR=6QE(BP@(F-R96%T96QI;FLB
M+"`B:6YS97)T:6UA9V4B+"`B:6YS97)T=&%B;&4B+"`B:'1M;&UO9&4B+"`B
M<V5P87)A=&]R(BP*"0D@(")P;W!U<&5D:71O<B(L(")S97!A<F%T;W(B+"`B
M<VAO=VAE;'`B+"`B86)O=70B(%T*"5T["@H)=&AI<RYF;VYT;F%M92`]('L*
M"0DB)FUD87-H.R!F;VYT("9M9&%S:#LB.B`@("`@("`@("<G+`H)"2)!<FEA
M;"(Z"2`@("=A<FEA;"QH96QV971I8V$L<V%N<RUS97)I9B<L"@D)(D-O=7)I
M97(@3F5W(CH)("`@)V-O=7)I97(@;F5W+&-O=7)I97(L;6]N;W-P86-E)RP*
M"0DB1V5O<F=I82(Z"2`@("=G96]R9VEA+'1I;65S(&YE=R!R;VUA;BQT:6UE
M<RQS97)I9B<L"@D)(E1A:&]M82(Z"2`@("=T86AO;6$L87)I86PL:&5L=F5T
M:6-A+'-A;G,M<V5R:68G+`H)"2)4:6UE<R!.97<@4F]M86XB.B`G=&EM97,@
M;F5W(')O;6%N+'1I;65S+'-E<FEF)RP*"0DB5F5R9&%N82(Z"2`@("=V97)D
M86YA+&%R:6%L+&AE;'9E=&EC82QS86YS+7-E<FEF)RP*"0DB:6UP86-T(CH)
M("`@)VEM<&%C="<L"@D)(E=I;F=$:6YG<R(Z"2`@("=W:6YG9&EN9W,G"@E]
M.PH*"71H:7,N9F]N='-I>F4@/2!["@D)(B9M9&%S:#L@<VEZ92`F;61A<V@[
M(B`@.B`B(BP*"0DB,2`H."!P="DB(#H@(C$B+`H)"2(R("@Q,"!P="DB.B`B
M,B(L"@D)(C,@*#$R('!T*2(Z("(S(BP*"0DB-"`H,30@<'0I(CH@(C0B+`H)
M"2(U("@Q."!P="DB.B`B-2(L"@D)(C8@*#(T('!T*2(Z("(V(BP*"0DB-R`H
M,S8@<'0I(CH@(C<B"@E].PH*"71H:7,N9F]R;6%T8FQO8VL@/2!["@D)(B9M
M9&%S:#L@9F]R;6%T("9M9&%S:#LB("`Z("(B+`H)"2)(96%D:6YG(#$B.B`B
M:#$B+`H)"2)(96%D:6YG(#(B.B`B:#(B+`H)"2)(96%D:6YG(#,B.B`B:#,B
M+`H)"2)(96%D:6YG(#0B.B`B:#0B+`H)"2)(96%D:6YG(#4B.B`B:#4B+`H)
M"2)(96%D:6YG(#8B.B`B:#8B+`H)"2).;W)M86PB("`@.B`B<"(L"@D)(D%D
M9')E<W,B("`Z(")A9&1R97-S(BP*"0DB1F]R;6%T=&5D(CH@(G!R92(*"7T[
M"@H)=&AI<RYC=7-T;VU396QE8W1S(#T@>WT["@H)9G5N8W1I;VX@8W5T7V-O
M<'E?<&%S=&4H92P@8VUD+"!O8FHI('L*"0EE+F5X96-#;VUM86YD*&-M9"D[
M"@E].PH*"71H:7,N9&5B=6<@/2!T<G5E.PH*"2\O($%$1$E.1R!#55-43TT@
M0E545$].4SH@<&QE87-E(')E860@8F5L;W<A"@DO+R!F;W)M870@;V8@=&AE
M(&)T;DQI<W0@96QE;65N=',@:7,@(DE$.B!;(%1O;VQ4:7`L($EC;VXL($5N
M86)L960@:6X@=&5X="!M;V1E/RP@04-424].(%TB"@DO+R`@("`M($E$.B!U
M;FEQ=64@240@9F]R('1H92!B=71T;VXN("!)9B!T:&4@8G5T=&]N(&-A;&QS
M(&1O8W5M96YT+F5X96-#;VUM86YD"@DO+PD@("`@:70G<R!W:7-E('1O(&=I
M=F4@:70@=&AE('-A;64@;F%M92!A<R!T:&4@8V%L;&5D(&-O;6UA;F0N"@DO
M+R`@("`M($%#5$E/3CH@9G5N8W1I;VX@=&AA="!G971S(&-A;&QE9"!W:&5N
M('1H92!B=71T;VX@:7,@8VQI8VME9"X*"2\O("`@("`@("`@("`@("!I="!H
M87,@=&AE(&9O;&QO=VEN9R!P<F]T;W1Y<&4Z"@DO+R`@("`@("`@("`@("`@
M("`@9G5N8W1I;VXH961I=&]R+"!B=71T;VY.86UE*0H)+R\@("`@("`@("`@
M("`@("T@961I=&]R(&ES('1H92!(5$U,07)E82!O8FIE8W0@=&AA="!T<FEG
M9V5R960@=&AE(&-A;&P*"2\O("`@("`@("`@("`@("`M(&)U='1O;DYA;64@
M:7,@=&AE($E$(&]F('1H92!C;&EC:V5D(&)U='1O;@H)+R\@("`@("`@("`@
M("`@(%1H97-E(#(@<&%R86UE=&5R<R!M86ME<R!I="!P;W-S:6)L92!F;W(@
M>6]U('1O('5S92!T:&4@<V%M90H)+R\@("`@("`@("`@("`@(&AA;F1L97(@
M9F]R(&UO<F4@2%1-3$%R96$@;V)J96-T<R!O<B!F;W(@;6]R92!D:69F97)E
M;G0@8G5T=&]N<RX*"2\O("`@("T@5&]O;%1I<#H@9&5F875L="!T;V]L=&EP
M+"!F;W(@8V%S97,@=VAE;B!I="!I<R!N;W0@9&5F:6YE9"!I;B!T:&4@+6QA
M;F<M(&9I;&4@*$A434Q!<F5A+DDQ.$XI"@DO+R`@("`M($EC;VXZ('!A=&@@
M=&\@86X@:6-O;B!I;6%G92!F:6QE(&9O<B!T:&4@8G5T=&]N("A43T1/.B!U
M<V4@;VYE(&EM86=E(&9O<B!A;&P@8G5T=&]N<R$I"@DO+R`@("`M($5N86)L
M960@:6X@=&5X="!M;V1E.B!I9B!F86QS92!T:&4@8G5T=&]N(&=E=',@9&ES
M86)L960@9F]R('1E>'0M;VYL>2!M;V1E.R!O=&AE<G=I<V4@96YA8FQE9"!A
M;&P@=&AE('1I;64N"@ET:&ES+F)T;DQI<W0@/2!["@D)8F]L9#H@6R`B0F]L
M9"(L(")E9%]F;W)M871?8F]L9"YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@
M>V4N97AE8T-O;6UA;F0H(F)O;&0B*3M](%TL"@D):71A;&EC.B!;("))=&%L
M:6,B+"`B961?9F]R;6%T7VET86QI8RYG:68B+"!F86QS92P@9G5N8W1I;VXH
M92D@>V4N97AE8T-O;6UA;F0H(FET86QI8R(I.WT@72P*"0EU;F1E<FQI;F4Z
M(%L@(E5N9&5R;&EN92(L(")E9%]F;W)M871?=6YD97)L:6YE+F=I9B(L(&9A
M;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B=6YD97)L:6YE(BD[
M?2!=+`H)"7-T<FEK971H<F]U9V@Z(%L@(E-T<FEK971H<F]U9V@B+"`B961?
M9F]R;6%T7W-T<FEK92YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE
M8T-O;6UA;F0H(G-T<FEK971H<F]U9V@B*3M](%TL"@D)<W5B<V-R:7!T.B!;
M(")3=6)S8W)I<'0B+"`B961?9F]R;6%T7W-U8BYG:68B+"!F86QS92P@9G5N
M8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G-U8G-C<FEP="(I.WT@72P*"0ES
M=7!E<G-C<FEP=#H@6R`B4W5P97)S8W)I<'0B+"`B961?9F]R;6%T7W-U<"YG
M:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G-U<&5R
M<V-R:7!T(BD[?2!=+`H)"6IU<W1I9GEL969T.B!;(")*=7-T:69Y($QE9G0B
M+"`B961?86QI9VY?;&5F="YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N
M97AE8T-O;6UA;F0H(FIU<W1I9GEL969T(BD[?2!=+`H)"6IU<W1I9GEC96YT
M97(Z(%L@(DIU<W1I9GD@0V5N=&5R(BP@(F5D7V%L:6=N7V-E;G1E<BYG:68B
M+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(FIU<W1I9GEC
M96YT97(B*3M](%TL"@D):G5S=&EF>7)I9VAT.B!;(")*=7-T:69Y(%)I9VAT
M(BP@(F5D7V%L:6=N7W)I9VAT+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![
M92YE>&5C0V]M;6%N9"@B:G5S=&EF>7)I9VAT(BD[?2!=+`H)"6IU<W1I9GEF
M=6QL.B!;(")*=7-T:69Y($9U;&PB+"`B961?86QI9VY?:G5S=&EF>2YG:68B
M+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(FIU<W1I9GEF
M=6QL(BD[?2!=+`H)"6]R9&5R961L:7-T.B!;(")/<F1E<F5D($QI<W0B+"`B
M961?;&ES=%]N=6TN9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#
M;VUM86YD*")I;G-E<G1O<F1E<F5D;&ES="(I.WT@72P*"0EU;F]R9&5R961L
M:7-T.B!;(")"=6QL971E9"!,:7-T(BP@(F5D7VQI<W1?8G5L;&5T+F=I9B(L
M(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:6YS97)T=6YO
M<F1E<F5D;&ES="(I.WT@72P*"0EO=71D96YT.B!;(")$96-R96%S92!);F1E
M;G0B+"`B961?:6YD96YT7VQE<W,N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I
M('ME+F5X96-#;VUM86YD*")O=71D96YT(BD[?2!=+`H)"6EN9&5N=#H@6R`B
M26YC<F5A<V4@26YD96YT(BP@(F5D7VEN9&5N=%]M;W)E+F=I9B(L(&9A;'-E
M+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:6YD96YT(BD[?2!=+`H)
M"69O<F5C;VQO<CH@6R`B1F]N="!#;VQO<B(L(")E9%]C;VQO<E]F9RYG:68B
M+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(F9O<F5C;VQO
M<B(I.WT@72P*"0EH:6QI=&5C;VQO<CH@6R`B0F%C:V=R;W5N9"!#;VQO<B(L
M(")E9%]C;VQO<E]B9RYG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE
M8T-O;6UA;F0H(FAI;&ET96-O;&]R(BD[?2!=+`H)"6EN<V5R=&AO<FEZ;VYT
M86QR=6QE.B!;(")(;W)I>F]N=&%L(%)U;&4B+"`B961?:'(N9VEF(BP@9F%L
M<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")I;G-E<G1H;W)I>F]N
M=&%L<G5L92(I.WT@72P*"0EC<F5A=&5L:6YK.B!;("));G-E<G0@5V5B($QI
M;FLB+"`B961?;&EN:RYG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE
M8T-O;6UA;F0H(F-R96%T96QI;FLB+"!T<G5E*3M](%TL"@D):6YS97)T:6UA
M9V4Z(%L@(DEN<V5R="]-;V1I9GD@26UA9V4B+"`B961?:6UA9V4N9VEF(BP@
M9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")I;G-E<G1I;6%G
M92(I.WT@72P*"0EI;G-E<G1T86)L93H@6R`B26YS97)T(%1A8FQE(BP@(FEN
M<V5R=%]T86)L92YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O
M;6UA;F0H(FEN<V5R='1A8FQE(BD[?2!=+`H)"6AT;6QM;V1E.B!;(")4;V=G
M;&4@2%1-3"!3;W5R8V4B+"`B961?:'1M;"YG:68B+"!T<G5E+"!F=6YC=&EO
M;BAE*2![92YE>&5C0V]M;6%N9"@B:'1M;&UO9&4B*3M](%TL"@D)<&]P=7!E
M9&ET;W(Z(%L@(D5N;&%R9V4@161I=&]R(BP@(F9U;&QS8W)E96Y?;6%X:6UI
M>F4N9VEF(BP@=')U92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G!O
M<'5P961I=&]R(BD[?2!=+`H)"6%B;W5T.B!;(")!8F]U="!T:&ES(&5D:71O
M<B(L(")E9%]A8F]U="YG:68B+"!T<G5E+"!F=6YC=&EO;BAE*2![92YE>&5C
M0V]M;6%N9"@B86)O=70B*3M](%TL"@D)<VAO=VAE;'`Z(%L@(DAE;'`@=7-I
M;F<@961I=&]R(BP@(F5D7VAE;'`N9VEF(BP@=')U92P@9G5N8W1I;VXH92D@
M>V4N97AE8T-O;6UA;F0H(G-H;W=H96QP(BD[?2!=+`H)"75N9&\Z(%L@(E5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(BP@(F5D7W5N9&\N9VEF(BP@9F%L<V4L
M(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")U;F1O(BD[?2!=+`H)"7)E
M9&\Z(%L@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(BP@(F5D7W)E9&\N9VEF
M(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")R961O(BD[
M?2!=+`H)"6-U=#H@6R`B0W5T('-E;&5C=&EO;B(L(")E9%]C=70N9VEF(BP@
M9F%L<V4L(&-U=%]C;W!Y7W!A<W1E(%TL"@D)8V]P>3H@6R`B0V]P>2!S96QE
M8W1I;VXB+"`B961?8V]P>2YG:68B+"!F86QS92P@8W5T7V-O<'E?<&%S=&4@
M72P*"0EP87-T93H@6R`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B+"`B961?<&%S
M=&4N9VEF(BP@9F%L<V4L(&-U=%]C;W!Y7W!A<W1E(%TL"@D);&5F='1O<FEG
M:'0Z(%L@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(BP@(F5D7VQE9G1?=&]?
M<FEG:'0N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD
M*")L969T=&]R:6=H="(I.WT@72P*"0ER:6=H='1O;&5F=#H@6R`B1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0B+"`B961?<FEG:'1?=&]?;&5F="YG:68B+"!F
M86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G)I9VAT=&]L969T
M(BD[?2!=+`H)"7)E;6]V969O<FUA=#H@6R`B4F5M;W9E(&9O<FUA='1I;F<B
M+"`B961?<FUF;W)M870N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X
M96-#;VUM86YD*")R96UO=F5F;W)M870B*3M](%TL"@D)<')I;G0Z(%L@(E!R
M:6YT(&1O8W5M96YT(BP@(F5D7W!R:6YT+F=I9B(L(&9A;'-E+"!F=6YC=&EO
M;BAE*2![92Y?:69R86UE+F-O;G1E;G17:6YD;W<N<')I;G0H*3M](%TL"@D)
M:VEL;'=O<F0Z(%L@(D-L96%R($U33V9F:6-E('1A9W,B+"`B961?:VEL;'=O
M<F0N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")K
M:6QL=V]R9"(I.WT@70H)?3L*"2\J($%$1$E.1R!#55-43TT@0E545$].4PH)
M("H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@D@*@H)("H@270@:7,@<F5C;VUM
M96YD960@=&AA="!Y;W4@861D('1H92!C=7-T;VT@8G5T=&]N<R!I;B!A;B!E
M>'1E<FYA;`H)("H@9FEL92!A;F0@;&5A=F4@=&AI<R!O;F4@=6YC:&%N9V5D
M+B`@5&AA="=S(&)E8V%U<V4@=VAE;B!W90H)("H@*$EN=&5R86-T:79E5&]O
M;',N8V]M*2!R96QE87-E(&$@;F5W(&]F9FEC:6%L('9E<G-I;VXL(&ET)W,@
M;&5S<PH)("H@;&EK96QY('1H870@>6]U('=I;&P@:&%V92!P<F]B;&5M<R!U
M<&=R861I;F<@2%1-3$%R96$N"@D@*@H)("H@17AA;7!L92!O;B!H;W<@=&\@
M861D(&$@8W5S=&]M(&)U='1O;B!W:&5N('EO=2!C;VYS=')U8W0@=&AE($A4
M34Q!<F5A.@H)("H*"2`J("`@=F%R(&5D:71O<B`](&YE=R!(5$U,07)E82@B
M>6]U<E]T97AT7V%R96%?:60B*3L*"2`J("`@=F%R(&-F9R`](&5D:71O<BYC
M;VYF:6<[("\O('1H:7,@:7,@=&AE(&1E9F%U;'0@8V]N9FEG=7)A=&EO;@H)
M("H@("!C9F<N8G1N3&ES=%LB;7DM:&EL:71E(ET@/0H)("H)6R!F=6YC=&EO
M;BAE9&ET;W(I('L@961I=&]R+G-U<G)O=6YD2%1-3"@G/'-P86X@<W1Y;&4]
M(F)A8VMG<F]U;F0Z>65L;&]W(CXG+"`G/"]S<&%N/B<I.R!]+"`O+R!A8W1I
M;VX*"2`J"2`@(DAI9VAL:6=H="!S96QE8W1I;VXB+"`O+R!T;V]L=&EP"@D@
M*@D@(")M>5]H:6QI=&4N9VEF(BP@+R\@:6UA9V4*"2`J"2`@9F%L<V4@+R\@
M9&ES86)L960@:6X@=&5X="!M;V1E"@D@*@E=.PH)("H@("!C9F<N=&]O;&)A
M<BYP=7-H*%LB;&EN96)R96%K(BP@(FUY+6AI;&ET92)=*3L@+R\@861D('1H
M92!N97<@8G5T=&]N('1O('1H92!T;V]L8F%R"@D@*@H)("H@06X@86QT97)N
M871E("AA;'-O(&UO<F4@8V]N=F5N:65N="!A;F0@<F5C;VUM96YD960I('=A
M>2!T;PH)("H@86-C;VUP;&ES:"!T:&ES(&ES('1O('5S92!T:&4@<F5G:7-T
M97)"=71T;VX@9G5N8W1I;VX@8F5L;W<N"@D@*B\*"2\O(&EN:71I86QI>F4@
M=&]O;'1I<',@9G)O;2!T:&4@23$X3B!M;V1U;&4@86YD(&=E;F5R871E(&-O
M<G)E8W0@:6UA9V4@<&%T:`H)9F]R("AV87(@:2!I;B!T:&ES+F)T;DQI<W0I
M('L*"0EV87(@8G1N(#T@=&AI<RYB=&Y,:7-T6VE=.PH)"6)T;ELQ72`](%]E
M9&ET;W)?=7)L("L@=&AI<RYI;6=54DP@*R!B=&Y;,5T["@D):68@*'1Y<&5O
M9B!(5$U,07)E82Y),3A.+G1O;VQT:7!S6VE=("$](")U;F1E9FEN960B*2![
M"@D)"6)T;ELP72`]($A434Q!<F5A+DDQ.$XN=&]O;'1I<'-;:5T["@D)?0H)
M?0I].PH*+RHJ($AE;'!E<B!F=6YC=&EO;CH@<F5G:7-T97(@82!N97<@8G5T
M=&]N('=I=&@@=&AE(&-O;F9I9W5R871I;VXN("!)="!C86X@8F4*("H@8V%L
M;&5D('=I=&@@86QL(#4@87)G=6UE;G1S+"!O<B!W:71H(&]N;'D@;VYE("AF
M:7)S="!O;F4I+B`@5VAE;B!C86QL960@=VET:`H@*B!O;FQY(&]N92!A<F=U
M;65N="!I="!M=7-T(&)E(&%N(&]B:F5C="!W:71H('1H92!F;VQL;W=I;F<@
M<')O<&5R=&EE<SH@:60L"B`J('1O;VQT:7`L(&EM86=E+"!T97AT36]D92P@
M86-T:6]N+B`@17AA;7!L97,Z"B`J"B`J(#$N(&-O;F9I9RYR96=I<W1E<D)U
M='1O;B@B;7DM:&EL:71E(BP@(DAI;&ET92!T97AT(BP@(FUY+6AI;&ET92YG
M:68B+"!F86QS92P@9G5N8W1I;VXH961I=&]R*2![+BXN?2D["B`J(#(N(&-O
M;F9I9RYR96=I<W1E<D)U='1O;BA["B`J("`@("`@:60@("`@("`@.B`B;7DM
M:&EL:71E(BP@("`@("`O+R!T:&4@240@;V8@>6]U<B!B=71T;VX*("H@("`@
M("!T;V]L=&EP("`Z(")(:6QI=&4@=&5X="(L("`@("\O('1H92!T;V]L=&EP
M"B`J("`@("`@:6UA9V4@("`@.B`B;7DM:&EL:71E+F=I9B(L("`O+R!I;6%G
M92!T;R!B92!D:7-P;&%Y960@:6X@=&AE('1O;VQB87(*("H@("`@("!T97AT
M36]D92`Z(&9A;'-E+"`@("`@("`@("`@("\O(&1I<V%B;&5D(&EN('1E>'0@
M;6]D90H@*B`@("`@(&%C=&EO;B`@(#H@9G5N8W1I;VXH961I=&]R*2![("\O
M(&-A;&QE9"!W:&5N('1H92!B=71T;VX@:7,@8VQI8VME9`H@*B`@("`@("`@
M("`@("`@("`@("!E9&ET;W(N<W5R<F]U;F1(5$U,*"<\<W!A;B!C;&%S<STB
M:&EL:71E(CXG+"`G/"]S<&%N/B<I.PH@*B`@("`@("`@("`@("`@("`@?2P*
M("H@("`@("!C;VYT97AT("`Z(")P(B`@("`@("`@("`@("`@("\O('=I;&P@
M8F4@9&ES86)L960@:68@;W5T<VED92!A(#QP/B!E;&5M96YT"B`J("`@('TI
M.PH@*B\*2%1-3$%R96$N0V]N9FEG+G!R;W1O='EP92YR96=I<W1E<D)U='1O
M;B`](&9U;F-T:6]N*&ED+"!T;V]L=&EP+"!I;6%G92P@=&5X=$UO9&4L(&%C
M=&EO;BP@8V]N=&5X="D@>PH)=F%R('1H95]I9#L*"6EF("AT>7!E;V8@:60@
M/3T@(G-T<FEN9R(I('L*"0ET:&5?:60@/2!I9#L*"7T@96QS92!I9B`H='EP
M96]F(&ED(#T](")O8FIE8W0B*2!["@D)=&AE7VED(#T@:60N:60["@E](&5L
M<V4@>PH)"6%L97)T*")%4E)/4B!;2%1-3$%R96$N0V]N9FEG.CIR96=I<W1E
M<D)U='1O;ETZ7&YI;G9A;&ED(&%R9W5M96YT<R(I.PH)"7)E='5R;B!F86QS
M93L*"7T*"2\O(&-H96-K(&9O<B!E>&ES=&EN9R!I9`H):68@*'1Y<&5O9B!T
M:&ES+F-U<W1O;5-E;&5C='-;=&AE7VED72`A/2`B=6YD969I;F5D(BD@>PH)
M"2\O(&%L97)T*")705).24Y'(%M(5$U,07)E82Y#;VYF:6<Z.G)E9VES=&5R
M1')O<&1O=VY=.EQN02!D<F]P9&]W;B!W:71H('1H92!S86UE($E$(&%L<F5A
M9'D@97AI<W1S+B(I.PH)?0H):68@*'1Y<&5O9B!T:&ES+F)T;DQI<W1;=&AE
M7VED72`A/2`B=6YD969I;F5D(BD@>PH)"2\O(&%L97)T*")705).24Y'(%M(
M5$U,07)E82Y#;VYF:6<Z.G)E9VES=&5R1')O<&1O=VY=.EQN02!B=71T;VX@
M=VET:"!T:&4@<V%M92!)1"!A;')E861Y(&5X:7-T<RXB*3L*"7T*"7-W:71C
M:"`H='EP96]F(&ED*2!["@D@("`@8V%S92`B<W1R:6YG(CH@=&AI<RYB=&Y,
M:7-T6VED72`](%L@=&]O;'1I<"P@:6UA9V4L('1E>'1-;V1E+"!A8W1I;VXL
M(&-O;G1E>'0@73L@8G)E86L["@D@("`@8V%S92`B;V)J96-T(CH@=&AI<RYB
M=&Y,:7-T6VED+FED72`](%L@:60N=&]O;'1I<"P@:60N:6UA9V4L(&ED+G1E
M>'1-;V1E+"!I9"YA8W1I;VXL(&ED+F-O;G1E>'0@73L@8G)E86L["@E]"GT[
M"@HO*BH@5&AE(&9O;&QO=VEN9R!H96QP97(@9G5N8W1I;VX@<F5G:7-T97)S
M(&$@9')O<&1O=VX@8F]X('=I=&@@=&AE(&5D:71O<@H@*B!C;VYF:6=U<F%T
M:6]N+B`@66]U('-T:6QL(&AA=F4@=&\@861D(&ET('1O('1H92!T;V]L8F%R
M+"!S86UE(&%S('=I=&@@=&AE"B`J(&)U='1O;G,N("!#86QL(&ET(&QI:V4@
M=&AI<SH*("H*("H@1DE8344Z(&%D9"!E>&%M<&QE"B`J+PI(5$U,07)E82Y#
M;VYF:6<N<')O=&]T>7!E+G)E9VES=&5R1')O<&1O=VX@/2!F=6YC=&EO;BAO
M8FIE8W0I('L*"2\O(&-H96-K(&9O<B!E>&ES=&EN9R!I9`H):68@*'1Y<&5O
M9B!T:&ES+F-U<W1O;5-E;&5C='-;;V)J96-T+FED72`A/2`B=6YD969I;F5D
M(BD@>PH)"2\O(&%L97)T*")705).24Y'(%M(5$U,07)E82Y#;VYF:6<Z.G)E
M9VES=&5R1')O<&1O=VY=.EQN02!D<F]P9&]W;B!W:71H('1H92!S86UE($E$
M(&%L<F5A9'D@97AI<W1S+B(I.PH)?0H):68@*'1Y<&5O9B!T:&ES+F)T;DQI
M<W1;;V)J96-T+FED72`A/2`B=6YD969I;F5D(BD@>PH)"2\O(&%L97)T*")7
M05).24Y'(%M(5$U,07)E82Y#;VYF:6<Z.G)E9VES=&5R1')O<&1O=VY=.EQN
M02!B=71T;VX@=VET:"!T:&4@<V%M92!)1"!A;')E861Y(&5X:7-T<RXB*3L*
M"7T*"71H:7,N8W5S=&]M4V5L96-T<UMO8FIE8W0N:61=(#T@;V)J96-T.PI]
M.PH*+RHJ($-A;&P@=&AI<R!F=6YC=&EO;B!T;R!R96UO=F4@<V]M92!B=71T
M;VYS+V1R;W`M9&]W;B!B;WAE<R!F<F]M('1H92!T;V]L8F%R+@H@*B!087-S
M(&%S('1H92!O;FQY('!A<F%M971E<B!A('-T<FEN9R!C;VYT86EN:6YG(&)U
M='1O;B]D<F]P+61O=VX@;F%M97,*("H@9&5L:6UI=&5D(&)Y('-P86-E<RX@
M($YO=&4@=&AA="!T:&4@<W1R:6YG('-H;W5L9"!A;'-O(&)E9VEN('=I=&@@
M82!S<&%C90H@*B!A;F0@96YD('=I=&@@82!S<&%C92X@($5X86UP;&4Z"B`J
M"B`J("`@8V]N9FEG+FAI9&53;VUE0G5T=&]N<R@B(&9O;G1N86UE(&9O;G1S
M:7IE('1E>'1I;F1I8V%T;W(@(BD["B`J"B`J($ET)W,@=7-E9G5L(&)E8V%U
M<V4@:70G<R!E87-I97(@=&\@<F5M;W9E('-T=69F(&9R;VT@=&AE(&1E9F%U
M;"!T;V]L8F%R('1H86X*("H@8W)E871E(&$@8G)A;F0@;F5W('1O;VQB87(@
M.RTI"B`J+PI(5$U,07)E82Y#;VYF:6<N<')O=&]T>7!E+FAI9&53;VUE0G5T
M=&]N<R`](&9U;F-T:6]N*')E;6]V92D@>PH)=F%R('1O;VQB87(@/2!T:&ES
M+G1O;VQB87(["@EF;W(@*'9A<B!I(#T@=&]O;&)A<BYL96YG=&@[("TM:2`^
M/2`P.RD@>PH)"79A<B!L:6YE(#T@=&]O;&)A<EMI73L*"0EF;W(@*'9A<B!J
M(#T@;&EN92YL96YG=&@[("TM:B`^/2`P.R`I('L*"0D):68@*')E;6]V92YI
M;F1E>$]F*"(@(B`K(&QI;F5;:ET@*R`B("(I(#X](#`I('L*"0D)"79A<B!L
M96X@/2`Q.PH)"0D):68@*"]S97!A<F%T;W)\<W!A8V4O+G1E<W0H;&EN95MJ
M("L@,5TI*2!["@D)"0D);&5N(#T@,CL*"0D)"7T*"0D)"6QI;F4N<W!L:6-E
M*&HL(&QE;BD["@D)"7T*"0E]"@E]"GT["@HO*BH@2&5L<&5R(&9U;F-T:6]N
M.B!R97!L86-E(&%L;"!415A405)%02US(&EN('1H92!D;V-U;65N="!W:71H
M($A434Q!<F5A+7,N("HO"DA434Q!<F5A+G)E<&QA8V5!;&P@/2!F=6YC=&EO
M;BAC;VYF:6<I('L*"79A<B!T87,@/2!D;V-U;65N="YG971%;&5M96YT<T)Y
M5&%G3F%M92@B=&5X=&%R96$B*3L*"69O<B`H=F%R(&D@/2!T87,N;&5N9W1H
M.R!I(#X@,#L@*&YE=R!(5$U,07)E82AT87-;+2UI72P@8V]N9FEG*2DN9V5N
M97)A=&4H*2D["GT["@HO*BH@2&5L<&5R(&9U;F-T:6]N.B!R97!L86-E<R!T
M:&4@5$585$%214$@=VET:"!T:&4@9VEV96X@240@=VET:"!(5$U,07)E82X@
M*B\*2%1-3$%R96$N<F5P;&%C92`](&9U;F-T:6]N*&ED+"!C;VYF:6<I('L*
M"79A<B!T82`]($A434Q!<F5A+F=E=$5L96UE;G1">4ED*")T97AT87)E82(L
M(&ED*3L*"7)E='5R;B!T82`_("AN97<@2%1-3$%R96$H=&$L(&-O;F9I9RDI
M+F=E;F5R871E*"D@.B!N=6QL.PI].PH*+R\@0W)E871E<R!T:&4@=&]O;&)A
M<B!A;F0@87!P96YD<R!I="!T;R!T:&4@7VAT;6QA<F5A"DA434Q!<F5A+G!R
M;W1O='EP92Y?8W)E871E5&]O;&)A<B`](&9U;F-T:6]N("@I('L*"79A<B!E
M9&ET;W(@/2!T:&ES.PDO+R!T;R!A8V-E<W,@=&AI<R!I;B!N97-T960@9G5N
M8W1I;VYS"@H)=F%R('1O;VQB87(@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*")D:78B*3L*"71H:7,N7W1O;VQB87(@/2!T;V]L8F%R.PH)=&]O;&)A<BYC
M;&%S<TYA;64@/2`B=&]O;&)A<B(["@ET;V]L8F%R+G5N<V5L96-T86)L92`]
M("(Q(CL*"79A<B!T8E]R;W<@/2!N=6QL.PH)=F%R('1B7V]B:F5C=',@/2!N
M97<@3V)J96-T*"D["@ET:&ES+E]T;V]L8F%R3V)J96-T<R`]('1B7V]B:F5C
M=',["@H)+R\@8W)E871E<R!A(&YE=R!L:6YE(&EN('1H92!T;V]L8F%R"@EF
M=6YC=&EO;B!N97=,:6YE*"D@>PH)"79A<B!T86)L92`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H(G1A8FQE(BD["@D)=&%B;&4N8F]R9&5R(#T@(C!P>"([
M"@D)=&%B;&4N8V5L;%-P86-I;F<@/2`B,'!X(CL*"0ET86)L92YC96QL4&%D
M9&EN9R`]("(P<'@B.PH)"71O;VQB87(N87!P96YD0VAI;&0H=&%B;&4I.PH)
M"2\O(%1"3T19(&ES(')E<75I<F5D(&9O<B!)12P@;W1H97)W:7-E('EO=2!D
M;VXG="!S964@86YY=&AI;F<*"0DO+R!I;B!T:&4@5$%"3$4N"@D)=F%R('1B
M7V)O9'D@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")T8F]D>2(I.PH)"71A
M8FQE+F%P<&5N9$-H:6QD*'1B7V)O9'DI.PH)"71B7W)O=R`](&1O8W5M96YT
M+F-R96%T945L96UE;G0H(G1R(BD["@D)=&)?8F]D>2YA<'!E;F1#:&EL9"AT
M8E]R;W<I.PH)?3L@+R\@14Y$(&]F(&9U;F-T:6]N.B!N97=,:6YE"@DO+R!I
M;FET(&9I<G-T(&QI;F4*"6YE=TQI;F4H*3L*"@DO+R!U<&1A=&5S('1H92!S
M=&%T92!O9B!A('1O;VQB87(@96QE;65N="X@(%1H:7,@9G5N8W1I;VX@:7,@
M;65M8F5R(&]F"@DO+R!A('1O;VQB87(@96QE;65N="!O8FIE8W0@*'5N;F%M
M960@;V)J96-T<R!C<F5A=&5D(&)Y(&-R96%T94)U='1O;B!O<@H)+R\@8W)E
M871E4V5L96-T(&9U;F-T:6]N<R!B96QO=RDN"@EF=6YC=&EO;B!S971"=71T
M;VY3=&%T=7,H:60L(&YE=W9A;"D@>PH)"79A<B!O;&1V86P@/2!T:&ES6VED
M73L*"0EV87(@96P@/2!T:&ES+F5L96UE;G0["@D):68@*&]L9'9A;"`A/2!N
M97=V86PI('L*"0D)<W=I=&-H("AI9"D@>PH)"0D@("`@8V%S92`B96YA8FQE
M9"(Z"@D)"0EI9B`H;F5W=F%L*2!["@D)"0D)2%1-3$%R96$N7W)E;6]V94-L
M87-S*&5L+"`B8G5T=&]N1&ES86)L960B*3L*"0D)"0EE;"YD:7-A8FQE9"`]
M(&9A;'-E.PH)"0D)?2!E;'-E('L*"0D)"0E(5$U,07)E82Y?861D0VQA<W,H
M96PL(")B=71T;VY$:7-A8FQE9"(I.PH)"0D)"65L+F1I<V%B;&5D(#T@=')U
M93L*"0D)"7T*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B86-T:79E(CH*"0D)
M"6EF("AN97=V86PI('L*"0D)"0E(5$U,07)E82Y?861D0VQA<W,H96PL(")B
M=71T;VY0<F5S<V5D(BD["@D)"0E](&5L<V4@>PH)"0D)"4A434Q!<F5A+E]R
M96UO=F5#;&%S<RAE;"P@(F)U='1O;E!R97-S960B*3L*"0D)"7T*"0D)"6)R
M96%K.PH)"0E]"@D)"71H:7-;:61=(#T@;F5W=F%L.PH)"7T*"7T[("\O($5.
M1"!O9B!F=6YC=&EO;CH@<V5T0G5T=&]N4W1A='5S"@H)+R\@=&AI<R!F=6YC
M=&EO;B!W:6QL(&AA;F1L92!C<F5A=&EO;B!O9B!C;VUB;R!B;WAE<RX@(%)E
M8V5I=F5S(&%S"@DO+R!P87)A;65T97(@=&AE(&YA;64@;V8@82!B=71T;VX@
M87,@9&5F:6YE9"!I;B!T:&4@=&]O;$)A<B!C;VYF:6<N"@DO+R!4:&ES(&9U
M;F-T:6]N(&ES(&-A;&QE9"!F<F]M(&-R96%T94)U='1O;BP@86)O=F4L(&EF
M('1H92!G:79E;B`B='AT(@H)+R\@9&]E<VXG="!M871C:"!A(&)U='1O;BX*
M"69U;F-T:6]N(&-R96%T95-E;&5C="AT>'0I('L*"0EV87(@;W!T:6]N<R`]
M(&YU;&P["@D)=F%R(&5L(#T@;G5L;#L*"0EV87(@8VUD(#T@;G5L;#L*"0EV
M87(@8W5S=&]M4V5L96-T<R`](&5D:71O<BYC;VYF:6<N8W5S=&]M4V5L96-T
M<SL*"0EV87(@8V]N=&5X="`](&YU;&P["@D)=F%R('1O;VQT:7`@/2`B(CL*
M"0ES=VET8V@@*'1X="D@>PH)"2`@("!C87-E(")F;VYT<VEZ92(Z"@D)("`@
M(&-A<V4@(F9O;G1N86UE(CH*"0D@("`@8V%S92`B9F]R;6%T8FQO8VLB.@H)
M"0DO+R!T:&4@9F]L;&]W:6YG(&QI;F4@<F5T<FEE=F5S('1H92!C;W)R96-T
M"@D)"2\O(&-O;F9I9W5R871I;VX@;W!T:6]N(&)E8V%U<V4@=&AE('9A<FEA
M8FQE(&YA;64*"0D)+R\@:6YS:61E('1H92!#;VYF:6<@;V)J96-T(&ES(&YA
M;65D('1H92!S86UE(&%S('1H90H)"0DO+R!B=71T;VXO<V5L96-T(&EN('1H
M92!T;V]L8F%R+B`@1F]R(&EN<W1A;F-E+"!I9B!T>'0*"0D)+R\@/3T@(F9O
M<FUA=&)L;V-K(B!W92!R971R:65V92!C;VYF:6<N9F]R;6%T8FQO8VL@*&]R
M"@D)"2\O(&$@9&EF9F5R96YT('=A>2!T;R!W<FET92!I="!I;B!*4R!I<PH)
M"0DO+R!C;VYF:6=;(F9O<FUA=&)L;V-K(ETN"@D)"6]P=&EO;G,@/2!E9&ET
M;W(N8V]N9FEG6W1X=%T["@D)"6-M9"`]('1X=#L*"0D)8G)E86L["@D)("`@
M(&1E9F%U;'0Z"@D)"2\O('1R>2!T;R!F971C:"!I="!F<F]M('1H92!L:7-T
M(&]F(')E9VES=&5R960@<V5L96-T<PH)"0EC;60@/2!T>'0["@D)"79A<B!D
M<F]P9&]W;B`](&-U<W1O;5-E;&5C='-;8VUD73L*"0D):68@*'1Y<&5O9B!D
M<F]P9&]W;B`A/2`B=6YD969I;F5D(BD@>PH)"0D);W!T:6]N<R`](&1R;W!D
M;W=N+F]P=&EO;G,["@D)"0EC;VYT97AT(#T@9')O<&1O=VXN8V]N=&5X=#L*
M"0D)"6EF("AT>7!E;V8@9')O<&1O=VXN=&]O;'1I<"`A/2`B=6YD969I;F5D
M(BD@>PH)"0D)"71O;VQT:7`@/2!D<F]P9&]W;BYT;V]L=&EP.PH)"0D)?0H)
M"0E](&5L<V4@>PH)"0D)86QE<G0H(D524D]2(%MC<F5A=&5396QE8W1=.EQN
M0V%N)W0@9FEN9"!T:&4@<F5Q=65S=&5D(&1R;W!D;W=N(&1E9FEN:71I;VXB
M*3L*"0D)?0H)"0EB<F5A:SL*"0E]"@D):68@*&]P=&EO;G,I('L*"0D)96P@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*"0D)96PN=&ET
M;&4@/2!T;V]L=&EP.PH)"0EV87(@;V)J(#T@>PH)"0D);F%M90DZ('1X="P@
M+R\@9FEE;&0@;F%M90H)"0D)96QE;65N="`Z(&5L+`DO+R!T:&4@54D@96QE
M;65N="`H4T5,14-4*0H)"0D)96YA8FQE9"`Z('1R=64L("\O(&ES(&ET(&5N
M86)L960_"@D)"0ET97AT"3H@9F%L<V4L("\O(&5N86)L960@:6X@=&5X="!M
M;V1E/PH)"0D)8VUD"3H@8VUD+"`O+R!C;VUM86YD($E$"@D)"0ES=&%T90DZ
M('-E=$)U='1O;E-T871U<RP@+R\@9F]R(&-H86YG:6YG('-T871E"@D)"0EC
M;VYT97AT(#H@8V]N=&5X=`H)"0E].PH)"0ET8E]O8FIE8W1S6W1X=%T@/2!O
M8FH["@D)"69O<B`H=F%R(&D@:6X@;W!T:6]N<RD@>PH)"0D)=F%R(&]P(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@B;W!T:6]N(BD["@D)"0EO<"YI;FYE
M<DA434P@/2!I.PH)"0D);W`N=F%L=64@/2!O<'1I;VYS6VE=.PH)"0D)96PN
M87!P96YD0VAI;&0H;W`I.PH)"0E]"@D)"4A434Q!<F5A+E]A9&1%=F5N="AE
M;"P@(F-H86YG92(L(&9U;F-T:6]N("@I('L*"0D)"65D:71O<BY?8V]M8F]3
M96QE8W1E9"AE;"P@='AT*3L*"0D)?2D["@D)?0H)"7)E='5R;B!E;#L*"7T[
M("\O($5.1"!O9B!F=6YC=&EO;CH@8W)E871E4V5L96-T"@H)+R\@87!P96YD
M<R!A(&YE=R!B=71T;VX@=&\@=&]O;&)A<@H)9G5N8W1I;VX@8W)E871E0G5T
M=&]N*'1X="D@>PH)"2\O('1H92!E;&5M96YT('1H870@=VEL;"!B92!C<F5A
M=&5D"@D)=F%R(&5L(#T@;G5L;#L*"0EV87(@8G1N(#T@;G5L;#L*"0ES=VET
M8V@@*'1X="D@>PH)"2`@("!C87-E(")S97!A<F%T;W(B.@H)"0EE;"`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H(F1I=B(I.PH)"0EE;"YC;&%S<TYA;64@
M/2`B<V5P87)A=&]R(CL*"0D)8G)E86L["@D)("`@(&-A<V4@(G-P86-E(CH*
M"0D)96P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")D:78B*3L*"0D)96PN
M8VQA<W-.86UE(#T@(G-P86-E(CL*"0D)8G)E86L["@D)("`@(&-A<V4@(FQI
M;F5B<F5A:R(Z"@D)"6YE=TQI;F4H*3L*"0D)<F5T=7)N(&9A;'-E.PH)"2`@
M("!C87-E(")T97AT:6YD:6-A=&]R(CH*"0D)96P@/2!D;V-U;65N="YC<F5A
M=&5%;&5M96YT*")D:78B*3L*"0D)96PN87!P96YD0VAI;&0H9&]C=6UE;G0N
M8W)E871E5&5X=$YO9&4H(D$B*2D["@D)"65L+F-L87-S3F%M92`](")I;F1I
M8V%T;W(B.PH)"0EE;"YT:71L92`]($A434Q!<F5A+DDQ.$XN=&]O;'1I<',N
M=&5X=&EN9&EC871O<CL*"0D)=F%R(&]B:B`]('L*"0D)"6YA;64).B!T>'0L
M("\O('1H92!B=71T;VX@;F%M92`H:2YE+B`G8F]L9"<I"@D)"0EE;&5M96YT
M(#H@96PL("\O('1H92!522!E;&5M96YT("A$258I"@D)"0EE;F%B;&5D(#H@
M=')U92P@+R\@:7,@:70@96YA8FQE9#\*"0D)"6%C=&EV90DZ(&9A;'-E+"`O
M+R!I<R!I="!P<F5S<V5D/PH)"0D)=&5X=`DZ(&9A;'-E+"`O+R!E;F%B;&5D
M(&EN('1E>'0@;6]D93\*"0D)"6-M9`DZ(")T97AT:6YD:6-A=&]R(BP@+R\@
M=&AE(&-O;6UA;F0@240*"0D)"7-T871E"3H@<V5T0G5T=&]N4W1A='5S("\O
M(&9O<B!C:&%N9VEN9R!S=&%T90H)"0E].PH)"0ET8E]O8FIE8W1S6W1X=%T@
M/2!O8FH["@D)"6)R96%K.PH)"2`@("!D969A=6QT.@H)"0EB=&X@/2!E9&ET
M;W(N8V]N9FEG+F)T;DQI<W1;='AT73L*"0E]"@D):68@*"%E;"`F)B!B=&XI
M('L*"0D)96P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")D:78B*3L*"0D)
M96PN=&ET;&4@/2!B=&Y;,%T["@D)"65L+F-L87-S3F%M92`](")B=71T;VXB
M.PH)"0DO+R!L970G<R!J=7-T('!R971E;F0@=V4@:&%V92!A(&)U='1O;B!O
M8FIE8W0L(&%N9`H)"0DO+R!A<W-I9VX@86QL('1H92!N965D960@:6YF;W)M
M871I;VX@=&\@:70N"@D)"79A<B!O8FH@/2!["@D)"0EN86UE"3H@='AT+"`O
M+R!T:&4@8G5T=&]N(&YA;64@*&DN92X@)V)O;&0G*0H)"0D)96QE;65N="`Z
M(&5L+"`O+R!T:&4@54D@96QE;65N="`H1$E6*0H)"0D)96YA8FQE9"`Z('1R
M=64L("\O(&ES(&ET(&5N86)L960_"@D)"0EA8W1I=F4).B!F86QS92P@+R\@
M:7,@:70@<')E<W-E9#\*"0D)"71E>'0).B!B=&Y;,ETL("\O(&5N86)L960@
M:6X@=&5X="!M;V1E/PH)"0D)8VUD"3H@8G1N6S-=+"`O+R!T:&4@8V]M;6%N
M9"!)1`H)"0D)<W1A=&4).B!S971"=71T;VY3=&%T=7,L("\O(&9O<B!C:&%N
M9VEN9R!S=&%T90H)"0D)8V]N=&5X="`Z(&)T;ELT72!\?"!N=6QL("\O(&5N
M86)L960@:6X@82!C97)T86EN(&-O;G1E>'0_"@D)"7T["@D)"71B7V]B:F5C
M='-;='AT72`](&]B:CL*"0D)+R\@:&%N9&QE<G,@=&\@96UU;&%T92!N:6-E
M(&9L870@=&]O;&)A<B!B=71T;VYS"@D)"4A434Q!<F5A+E]A9&1%=F5N="AE
M;"P@(FUO=7-E;W9E<B(L(&9U;F-T:6]N("@I('L*"0D)"6EF("AO8FHN96YA
M8FQE9"D@>PH)"0D)"4A434Q!<F5A+E]A9&1#;&%S<RAE;"P@(F)U='1O;DAO
M=F5R(BD["@D)"0E]"@D)"7TI.PH)"0E(5$U,07)E82Y?861D179E;G0H96PL
M(")M;W5S96]U="(L(&9U;F-T:6]N("@I('L*"0D)"6EF("AO8FHN96YA8FQE
M9"D@=VET:"`H2%1-3$%R96$I('L*"0D)"0E?<F5M;W9E0VQA<W,H96PL(")B
M=71T;VY(;W9E<B(I.PH)"0D)"5]R96UO=F5#;&%S<RAE;"P@(F)U='1O;D%C
M=&EV92(I.PH)"0D)"2AO8FHN86-T:79E*2`F)B!?861D0VQA<W,H96PL(")B
M=71T;VY0<F5S<V5D(BD["@D)"0E]"@D)"7TI.PH)"0E(5$U,07)E82Y?861D
M179E;G0H96PL(")M;W5S961O=VXB+"!F=6YC=&EO;B`H978I('L*"0D)"6EF
M("AO8FHN96YA8FQE9"D@=VET:"`H2%1-3$%R96$I('L*"0D)"0E?861D0VQA
M<W,H96PL(")B=71T;VY!8W1I=F4B*3L*"0D)"0E?<F5M;W9E0VQA<W,H96PL
M(")B=71T;VY0<F5S<V5D(BD["@D)"0D)7W-T;W!%=F5N="AI<U]I92`_('=I
M;F1O=RYE=F5N="`Z(&5V*3L*"0D)"7T*"0D)?2D["@D)"2\O('=H96X@8VQI
M8VME9"P@9&\@=&AE(&9O;&QO=VEN9SH*"0D)2%1-3$%R96$N7V%D9$5V96YT
M*&5L+"`B8VQI8VLB+"!F=6YC=&EO;B`H978I('L*"0D)"6EF("AO8FHN96YA
M8FQE9"D@=VET:"`H2%1-3$%R96$I('L*"0D)"0E?<F5M;W9E0VQA<W,H96PL
M(")B=71T;VY!8W1I=F4B*3L*"0D)"0E?<F5M;W9E0VQA<W,H96PL(")B=71T
M;VY(;W9E<B(I.PH)"0D)"6]B:BYC;60H961I=&]R+"!O8FHN;F%M92P@;V)J
M*3L*"0D)"0E?<W1O<$5V96YT*&ES7VEE(#\@=VEN9&]W+F5V96YT(#H@978I
M.PH)"0D)?0H)"0E]*3L*"0D)=F%R(&EM9R`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H(FEM9R(I.PH)"0EI;6<N<W)C(#T@8G1N6S%=.PH)"0EI;6<N<W1Y
M;&4N=VED=&@@/2`B,3AP>"(["@D)"6EM9RYS='EL92YH96EG:'0@/2`B,3AP
M>"(["@D)"65L+F%P<&5N9$-H:6QD*&EM9RD["@D)?2!E;'-E(&EF("@A96PI
M('L*"0D)96P@/2!C<F5A=&5396QE8W0H='AT*3L*"0E]"@D):68@*&5L*2![
M"@D)"79A<B!T8E]C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B=&0B
M*3L*"0D)=&)?<F]W+F%P<&5N9$-H:6QD*'1B7V-E;&PI.PH)"0ET8E]C96QL
M+F%P<&5N9$-H:6QD*&5L*3L*"0E](&5L<V4@>PH)"0EA;&5R="@B1DE8344Z
M(%5N:VYO=VX@=&]O;&)A<B!I=&5M.B`B("L@='AT*3L*"0E]"@D)<F5T=7)N
M(&5L.PH)?3L*"@EV87(@9FER<W0@/2!T<G5E.PH)9F]R("AV87(@:2`](#`[
M(&D@/"!T:&ES+F-O;F9I9RYT;V]L8F%R+FQE;F=T:#L@*RMI*2!["@D):68@
M*"%F:7)S="D@>PH)"0EC<F5A=&5"=71T;VXH(FQI;F5B<F5A:R(I.PH)"7T@
M96QS92!["@D)"69I<G-T(#T@9F%L<V4["@D)?0H)"79A<B!G<F]U<"`]('1H
M:7,N8V]N9FEG+G1O;VQB87);:5T["@D)9F]R("AV87(@:B`](#`[(&H@/"!G
M<F]U<"YL96YG=&@[("LK:BD@>PH)"0EV87(@8V]D92`](&=R;W5P6VI=.PH)
M"0EI9B`H+UXH6TE472E<6R@N*C\I7%TO+G1E<W0H8V]D92DI('L*"0D)"2\O
M('-P96-I86P@8V%S92P@8W)E871E('1E>'0@;&%B96P*"0D)"79A<B!L-V5D
M(#T@4F5G17AP+B0Q(#T]("))(CL@+R\@;&]C86QI>F5D/PH)"0D)=F%R(&QA
M8F5L(#T@4F5G17AP+B0R.PH)"0D):68@*&PW960I('L*"0D)"0EL86)E;"`]
M($A434Q!<F5A+DDQ.$XN8W5S=&]M6VQA8F5L73L*"0D)"7T*"0D)"79A<B!T
M8E]C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B=&0B*3L*"0D)"71B
M7W)O=RYA<'!E;F1#:&EL9"AT8E]C96QL*3L*"0D)"71B7V-E;&PN8VQA<W-.
M86UE(#T@(FQA8F5L(CL*"0D)"71B7V-E;&PN:6YN97)(5$U,(#T@;&%B96P[
M"@D)"7T@96QS92!["@D)"0EC<F5A=&5"=71T;VXH8V]D92D["@D)"7T*"0E]
M"@E]"@H)=&AI<RY?:'1M;$%R96$N87!P96YD0VAI;&0H=&]O;&)A<BD["GT[
M"@I(5$U,07)E82YP<F]T;W1Y<&4N7V-R96%T95-T871U<T)A<B`](&9U;F-T
M:6]N*"D@>PH)=F%R('-T871U<V)A<B`](&1O8W5M96YT+F-R96%T945L96UE
M;G0H(F1I=B(I.PH)<W1A='5S8F%R+F-L87-S3F%M92`](")S=&%T=7-"87(B
M.PH)=&AI<RY?:'1M;$%R96$N87!P96YD0VAI;&0H<W1A='5S8F%R*3L*"71H
M:7,N7W-T871U<T)A<B`]('-T871U<V)A<CL*"2\O('-T871U<V)A<BYA<'!E
M;F1#:&EL9"AD;V-U;65N="YC<F5A=&5497AT3F]D92A(5$U,07)E82Y),3A.
M+FUS9ULB4&%T:")=("L@(CH@(BDI.PH)+R\@8W)E871E<R!A(&AO;&1E<B!F
M;W(@=&AE('!A=&@@=FEE=PH)9&EV(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@B<W!A;B(I.PH)9&EV+F-L87-S3F%M92`](")S=&%T=7-"87)4<F5E(CL*
M"61I=BYI;FYE<DA434P@/2!(5$U,07)E82Y),3A.+FUS9ULB4&%T:")=("L@
M(CH@(CL*"71H:7,N7W-T871U<T)A<E1R964@/2!D:78["@ET:&ES+E]S=&%T
M=7-"87(N87!P96YD0VAI;&0H9&EV*3L*"6EF("@A=&AI<RYC;VYF:6<N<W1A
M='5S0F%R*2!["@D)+R\@9&ES86)L92!I="XN+@H)"7-T871U<V)A<BYS='EL
M92YD:7-P;&%Y(#T@(FYO;F4B.PH)?0I].PH*+R\@0W)E871E<R!T:&4@2%1-
M3$%R96$@;V)J96-T(&%N9"!R97!L86-E<R!T:&4@=&5X=&%R96$@=VET:"!I
M="X*2%1-3$%R96$N<')O=&]T>7!E+F=E;F5R871E(#T@9G5N8W1I;VX@*"D@
M>PH)=F%R(&5D:71O<B`]('1H:7,["2\O('=E)VQL(&YE960@(G1H:7,B(&EN
M('-O;64@;F5S=&5D(&9U;F-T:6]N<PH)+R\@9V5T('1H92!T97AT87)E80H)
M=F%R('1E>'1A<F5A(#T@=&AI<RY?=&5X=$%R96$["@EI9B`H='EP96]F('1E
M>'1A<F5A(#T](")S=')I;F<B*2!["@D)+R\@:70G<R!N;W0@96QE;65N="!B
M=70@240*"0ET:&ES+E]T97AT07)E82`]('1E>'1A<F5A(#T@2%1-3$%R96$N
M9V5T16QE;65N=$)Y260H(G1E>'1A<F5A(BP@=&5X=&%R96$I.PH)?0H)=&AI
M<RY?=&%?<VEZ92`]('L*"0EW.B!T97AT87)E82YO9F9S9717:61T:"P*"0EH
M.B!T97AT87)E82YO9F9S971(96EG:'0*"7T["@ET97AT87)E82YS='EL92YD
M:7-P;&%Y(#T@(FYO;F4B.PH*"2\O(&-R96%T92!T:&4@961I=&]R(&9R86UE
M=V]R:PH)=F%R(&AT;6QA<F5A(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B
M9&EV(BD["@EH=&UL87)E82YC;&%S<TYA;64@/2`B:'1M;&%R96$B.PH)=&AI
M<RY?:'1M;$%R96$@/2!H=&UL87)E83L*"@DO+R!I;G-E<G0@=&AE(&5D:71O
M<B!B969O<F4@=&AE('1E>'1A<F5A+@H)=&5X=&%R96$N<&%R96YT3F]D92YI
M;G-E<G1"969O<F4H:'1M;&%R96$L('1E>'1A<F5A*3L*"@EI9B`H=&5X=&%R
M96$N9F]R;2D@>PH)"2\O('=E(&AA=F4@82!F;W)M+"!O;B!S=6)M:70@9V5T
M('1H92!(5$U,07)E82!C;VYT96YT(&%N9`H)"2\O('5P9&%T92!O<FEG:6YA
M;"!T97AT87)E82X*"0EV87(@9B`]('1E>'1A<F5A+F9O<FT["@D):68@*'1Y
M<&5O9B!F+F]N<W5B;6ET(#T](")F=6YC=&EO;B(I('L*"0D)=F%R(&9U;F-R
M968@/2!F+F]N<W5B;6ET.PH)"0EI9B`H='EP96]F(&8N7U]M<VA?<')E=D]N
M4W5B;6ET(#T](")U;F1E9FEN960B*2!["@D)"0EF+E]?;7-H7W!R979/;E-U
M8FUI="`](%M=.PH)"0E]"@D)"68N7U]M<VA?<')E=D]N4W5B;6ET+G!U<V@H
M9G5N8W)E9BD["@D)?0H)"68N;VYS=6)M:70@/2!F=6YC=&EO;B@I('L*"0D)
M961I=&]R+E]T97AT07)E82YV86QU92`](&5D:71O<BYG971(5$U,*"D["@D)
M"79A<B!A(#T@=&AI<RY?7VUS:%]P<F5V3VY3=6)M:70["@D)"2\O(&-A;&P@
M<')E=FEO=7,@<W5B;6ET(&UE=&AO9',@:68@=&AE>2!W97)E('1H97)E+@H)
M"0EI9B`H='EP96]F(&$@(3T@(G5N9&5F:6YE9"(I('L*"0D)"69O<B`H=F%R
M(&D@/2!A+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)"0D)85MI72@I.PH)"0D)
M?0H)"0E]"@D)?3L*"0EI9B`H='EP96]F(&8N;VYR97-E="`]/2`B9G5N8W1I
M;VXB*2!["@D)"79A<B!F=6YC<F5F(#T@9BYO;G)E<V5T.PH)"0EI9B`H='EP
M96]F(&8N7U]M<VA?<')E=D]N4F5S970@/3T@(G5N9&5F:6YE9"(I('L*"0D)
M"68N7U]M<VA?<')E=D]N4F5S970@/2!;73L*"0D)?0H)"0EF+E]?;7-H7W!R
M979/;E)E<V5T+G!U<V@H9G5N8W)E9BD["@D)?0H)"68N;VYR97-E="`](&9U
M;F-T:6]N*"D@>PH)"0EE9&ET;W(N<V5T2%1-3"AE9&ET;W(N7W1E>'1!<F5A
M+G9A;'5E*3L*"0D)961I=&]R+G5P9&%T951O;VQB87(H*3L*"0D)=F%R(&$@
M/2!T:&ES+E]?;7-H7W!R979/;E)E<V5T.PH)"0DO+R!C86QL('!R979I;W5S
M(')E<V5T(&UE=&AO9',@:68@=&AE>2!W97)E('1H97)E+@H)"0EI9B`H='EP
M96]F(&$@(3T@(G5N9&5F:6YE9"(I('L*"0D)"69O<B`H=F%R(&D@/2!A+FQE
M;F=T:#L@+2UI(#X](#`[*2!["@D)"0D)85MI72@I.PH)"0D)?0H)"0E]"@D)
M?3L*"7T*"@DO+R!A9&0@82!H86YD;&5R(&9O<B!T:&4@(F)A8VLO9F]R=V%R
M9"(@8V%S92`M+2!O;B!B;V1Y+G5N;&]A9"!W92!S879E"@DO+R!T:&4@2%1-
M3"!C;VYT96YT(&EN=&\@=&AE(&]R:6=I;F%L('1E>'1A<F5A+@H)=')Y('L*
M"0EW:6YD;W<N;VYU;FQO860@/2!F=6YC=&EO;B@I('L*"0D)961I=&]R+E]T
M97AT07)E82YV86QU92`](&5D:71O<BYG971(5$U,*"D["@D)?3L*"7T@8V%T
M8V@H92D@>WT["@H)+R\@8W)E871E<R`F(&%P<&5N9',@=&AE('1O;VQB87(*
M"71H:7,N7V-R96%T951O;VQB87(H*3L*"@DO+R!C<F5A=&4@=&AE($E&4D%-
M10H)=F%R(&EF<F%M92`](&1O8W5M96YT+F-R96%T945L96UE;G0H(FEF<F%M
M92(I.PH*"2\O('=O<FMA<F]U;F0@9F]R('1H92!(5%104R!P<F]B;&5M"@DO
M+R!I9G)A;64N<V5T071T<FEB=71E*")S<F,B+"`B:F%V87-C<FEP=#IV;VED
M*#`I.R(I.PH):69R86UE+G-R8R`](%]E9&ET;W)?=7)L("L@(G!O<'5P<R]B
M;&%N:RYH=&UL(CL*"@EH=&UL87)E82YA<'!E;F1#:&EL9"AI9G)A;64I.PH*
M"71H:7,N7VEF<F%M92`](&EF<F%M93L*"@DO+R!C<F5A=&5S("8@87!P96YD
M<R!T:&4@<W1A='5S(&)A<BP@:68@=&AE(&-A<V4*"71H:7,N7V-R96%T95-T
M871U<T)A<B@I.PH*"2\O(')E;6]V92!T:&4@9&5F875L="!B;W)D97(@87,@
M:70@:V5E<',@=7,@9G)O;2!C;VUP=71I;F<@8V]R<F5C=&QY"@DO+R!T:&4@
M<VEZ97,N("`H<V]M96)O9'D@=&5L;"!M92!W:'D@9&]E<VXG="!T:&ES('=O
M<FL@:6X@244I"@H):68@*"%(5$U,07)E82YI<U]I92D@>PH)"6EF<F%M92YS
M='EL92YB;W)D97)7:61T:"`]("(Q<'@B.PH)+R\@:69R86UE+F9R86UE0F]R
M9&5R(#T@(C$B.PH)+R\@:69R86UE+FUA<F=I;DAE:6=H="`]("(P(CL*"2\O
M(&EF<F%M92YM87)G:6Y7:61T:"`]("(P(CL*"7T*"@DO+R!S:7IE('1H92!)
M1E)!344@86-C;W)D:6YG('1O('5S97(G<R!P<F5F<R!O<B!I;FET:6%L('1E
M>'1A<F5A"@EV87(@:&5I9VAT(#T@*'1H:7,N8V]N9FEG+FAE:6=H="`]/2`B
M875T;R(@/R`H=&AI<RY?=&%?<VEZ92YH("L@(G!X(BD@.B!T:&ES+F-O;F9I
M9RYH96EG:'0I.PH):&5I9VAT(#T@<&%R<V5);G0H:&5I9VAT*3L*"79A<B!W
M:61T:"`]("AT:&ES+F-O;F9I9RYW:61T:"`]/2`B875T;R(@/R`H=&AI<RY?
M=&%?<VEZ92YW("L@(G!X(BD@.B!T:&ES+F-O;F9I9RYW:61T:"D["@EW:61T
M:"`]('!A<G-E26YT*'=I9'1H*3L*"@EI9B`H(4A434Q!<F5A+FES7VEE*2![
M"@D):&5I9VAT("T](#(["@D)=VED=&@@+3T@,CL*"7T*"@EI9G)A;64N<W1Y
M;&4N=VED=&@@/2!W:61T:"`K(")P>"(["@EI9B`H=&AI<RYC;VYF:6<N<VEZ
M94EN8VQU9&5S5&]O;&)A<BD@>PH)"2\O('-U8G-T<F%C="!T;V]L8F%R(&AE
M:6=H=`H)"6AE:6=H="`M/2!T:&ES+E]T;V]L8F%R+F]F9G-E=$AE:6=H=#L*
M"0EH96EG:'0@+3T@=&AI<RY?<W1A='5S0F%R+F]F9G-E=$AE:6=H=#L*"7T*
M"6EF("AH96EG:'0@/"`P*2!["@D):&5I9VAT(#T@,#L*"7T*"6EF<F%M92YS
M='EL92YH96EG:'0@/2!H96EG:'0@*R`B<'@B.PH*"2\O('1H92!E9&ET;W(@
M:6YC;'5D:6YG('1H92!T;V]L8F%R(&YO=R!H879E('1H92!S86UE('-I>F4@
M87,@=&AE"@DO+R!O<FEG:6YA;"!T97AT87)E82XN('=H:6-H(&UE86YS('1H
M870@=V4@;F5E9"!T;R!R961U8V4@=&AA="!A(&)I="X*"71E>'1A<F5A+G-T
M>6QE+G=I9'1H(#T@:69R86UE+G-T>6QE+G=I9'1H.PH@"71E>'1A<F5A+G-T
M>6QE+FAE:6=H="`](&EF<F%M92YS='EL92YH96EG:'0["@H)+R\@24U03U)4
M04Y4.B!W92!H879E('1O(&%L;&]W($UO>FEL;&$@82!S:&]R="!T:6UE('1O
M(')E8V]G;FEZ92!T:&4*"2\O(&YE=R!F<F%M92X@($]T:&5R=VES92!W92!G
M970@82!S='5P:60@97AC97!T:6]N+@H)9G5N8W1I;VX@:6YI=$EF<F%M92@I
M('L*"0EV87(@9&]C(#T@961I=&]R+E]I9G)A;64N8V]N=&5N=%=I;F1O=RYD
M;V-U;65N=#L*"0EI9B`H(61O8RD@>PH)"0DO+R!4<GD@86=A:6XN+@H)"0DO
M+R!&25A-13H@9&]N)W0@:VYO=R!W:&%T(&5L<V4@=&\@9&\@:&5R92X@($YO
M<FUA;&QY"@D)"2\O('=E)VQL(&YE=F5R(')E86-H('1H:7,@<&]I;G0N"@D)
M"6EF("A(5$U,07)E82YI<U]G96-K;RD@>PH)"0D)<V5T5&EM96]U="AI;FET
M269R86UE+"`Q,#`I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E](&5L<V4@>PH)
M"0D)86QE<G0H(D524D]2.B!)1E)!344@8V%N)W0@8F4@:6YI=&EA;&EZ960N
M(BD["@D)"7T*"0E]"@D):68@*$A434Q!<F5A+FES7V=E8VMO*2!["@D)"2\O
M(&5N86)L92!E9&ET86)L92!M;V1E(&9O<B!-;WII;&QA"@D)"61O8RYD97-I
M9VY-;V1E(#T@(F]N(CL*"0E]"@D)961I=&]R+E]D;V,@/2!D;V,["@D):68@
M*"%E9&ET;W(N8V]N9FEG+F9U;&Q086=E*2!["@D)"61O8RYO<&5N*"D["@D)
M"79A<B!H=&UL(#T@(CQH=&UL/EQN(CL*"0D):'1M;"`K/2`B/&AE860^7&XB
M.PH)"0EI9B`H961I=&]R+F-O;F9I9RYB87-E55),*0H)"0D):'1M;"`K/2`G
M/&)A<V4@:')E9CTB)R`K(&5D:71O<BYC;VYF:6<N8F%S95523"`K("<B("\^
M)SL*"0D):'1M;"`K/2`B/'-T>6QE/B(@*R!E9&ET;W(N8V]N9FEG+G!A9V53
M='EL92`K"@D)"0DB(&AT;6PL8F]D>2![(&)O<F1E<CH@,'!X.R!]/"]S='EL
M93Y<;B(["@D)"6AT;6P@*ST@(CPO:&5A9#Y<;B(["@D)"6AT;6P@*ST@(CQB
M;V1Y/EQN(CL*"0D):'1M;"`K/2!E9&ET;W(N7W1E>'1!<F5A+G9A;'5E.PH)
M"0EH=&UL("L]("(\+V)O9'D^7&XB.PH)"0EH=&UL("L]("(\+VAT;6P^(CL*
M"0D)9&]C+G=R:71E*&AT;6PI.PH)"0ED;V,N8VQO<V4H*3L*"0E](&5L<V4@
M>PH)"0EV87(@:'1M;"`](&5D:71O<BY?=&5X=$%R96$N=F%L=64["@D)"6EF
M("AH=&UL+FUA=&-H*$A434Q!<F5A+E)%7V1O8W1Y<&4I*2!["@D)"0EE9&ET
M;W(N<V5T1&]C='EP92A296=%>'`N)#$I.PH)"0D):'1M;"`](&AT;6PN<F5P
M;&%C92A(5$U,07)E82Y215]D;V-T>7!E+"`B(BD["@D)"7T*"0D)9&]C+F]P
M96XH*3L*"0D)9&]C+G=R:71E*&AT;6PI.PH)"0ED;V,N8VQO<V4H*3L*"0E]
M"@H)"6EF("A(5$U,07)E82YI<U]I92D@>PH)"0DO+R!E;F%B;&4@961I=&%B
M;&4@;6]D92!F;W(@244N"2!&;W(@<V]M92!R96%S;VX@=&AI<PH)"0DO+R!D
M;V5S;B=T('=O<FL@:68@9&]N92!I;B!T:&4@<V%M92!P;&%C92!A<R!F;W(@
M1V5C:V\*"0D)+R\@*&%B;W9E*2X*"0D)9&]C+F)O9'DN8V]N=&5N=$5D:71A
M8FQE(#T@=')U93L*"0E]"@H)"65D:71O<BYF;V-U<T5D:71O<B@I.PH)"2\O
M(&EN=&5R8V5P="!S;VUE(&5V96YT<SL@9F]R('5P9&%T:6YG('1H92!T;V]L
M8F%R("8@:V5Y8F]A<F0@:&%N9&QE<G,*"0E(5$U,07)E82Y?861D179E;G1S
M"@D)"2AD;V,L(%LB:V5Y9&]W;B(L(")K97EP<F5S<R(L(")M;W5S961O=VXB
M+"`B;6]U<V5U<"(L(")D<F%G(ETL"@D)"2!F=6YC=&EO;B`H979E;G0I('L*
M"0D)"2!R971U<FX@961I=&]R+E]E9&ET;W)%=F5N="A(5$U,07)E82YI<U]I
M92`_(&5D:71O<BY?:69R86UE+F-O;G1E;G17:6YD;W<N979E;G0@.B!E=F5N
M="D["@D)"2!]*3L*"@D)+R\@8VAE8VL@:68@86YY('!L=6=I;G,@:&%V92!R
M96=I<W1E<F5D(')E9G)E<V@@:&%N9&QE<G,*"0EF;W(@*'9A<B!I(&EN(&5D
M:71O<BYP;'5G:6YS*2!["@D)"79A<B!P;'5G:6X@/2!E9&ET;W(N<&QU9VEN
M<UMI72YI;G-T86YC93L*"0D):68@*'1Y<&5O9B!P;'5G:6XN;VY'96YE<F%T
M92`]/2`B9G5N8W1I;VXB*0H)"0D)<&QU9VEN+F]N1V5N97)A=&4H*3L*"0D)
M:68@*'1Y<&5O9B!P;'5G:6XN;VY'96YE<F%T94]N8V4@/3T@(F9U;F-T:6]N
M(BD@>PH)"0D)<&QU9VEN+F]N1V5N97)A=&5/;F-E*"D["@D)"0EP;'5G:6XN
M;VY'96YE<F%T94]N8V4@/2!N=6QL.PH)"0E]"@D)?0H*"0ES9714:6UE;W5T
M*&9U;F-T:6]N*"D@>PH)"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"7TL
M(#(U,"D["@H)"6EF("AT>7!E;V8@961I=&]R+F]N1V5N97)A=&4@/3T@(F9U
M;F-T:6]N(BD*"0D)961I=&]R+F]N1V5N97)A=&4H*3L*"7T["@ES9714:6UE
M;W5T*&EN:71)9G)A;64L(#$P,"D["@ER971U<FX@=&AI<SL*?3L*"B\O(%-W
M:71C:&5S(&5D:71O<B!M;V1E.R!P87)A;65T97(@8V%N(&)E(")T97AT;6]D
M92(@;W(@(G=Y<VEW>6<B+B`@268@;F\*+R\@<&%R86UE=&5R('=A<R!P87-S
M960@=&AI<R!F=6YC=&EO;B!T;V=G;&5S(&)E='=E96X@;6]D97,N"DA434Q!
M<F5A+G!R;W1O='EP92YS971-;V1E(#T@9G5N8W1I;VXH;6]D92D@>PH):68@
M*'1Y<&5O9B!M;V1E(#T](")U;F1E9FEN960B*2!["@D);6]D92`]("@H=&AI
M<RY?961I=$UO9&4@/3T@(G1E>'1M;V1E(BD@/R`B=WES:7=Y9R(@.B`B=&5X
M=&UO9&4B*3L*"7T*"7-W:71C:"`H;6]D92D@>PH)("`@(&-A<V4@(G1E>'1M
M;V1E(CH*"0ET:&ES+E]T97AT07)E82YV86QU92`]('1H:7,N9V5T2%1-3"@I
M.PH)"71H:7,N7VEF<F%M92YS='EL92YD:7-P;&%Y(#T@(FYO;F4B.PH)"71H
M:7,N7W1E>'1!<F5A+G-T>6QE+F1I<W!L87D@/2`B8FQO8VLB.PH)"6EF("AT
M:&ES+F-O;F9I9RYS=&%T=7-"87(I('L*"0D)=&AI<RY?<W1A='5S0F%R+FEN
M;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN;7-G6R)415A47TU/1$4B73L*"0E]
M"@D)8G)E86L["@D@("`@8V%S92`B=WES:7=Y9R(Z"@D):68@*$A434Q!<F5A
M+FES7V=E8VMO*2!["@D)"2\O(&1I<V%B;&4@9&5S:6=N(&UO9&4@8F5F;W)E
M(&-H86YG:6YG(&EN;F5R2%1-3`H)"0ET<GD@>PH)"0D)=&AI<RY?9&]C+F1E
M<VEG;DUO9&4@/2`B;V9F(CL*"0D)?2!C871C:"AE*2![?3L*"0E]"@D):68@
M*"%T:&ES+F-O;F9I9RYF=6QL4&%G92D*"0D)=&AI<RY?9&]C+F)O9'DN:6YN
M97)(5$U,(#T@=&AI<RYG971(5$U,*"D["@D)96QS90H)"0ET:&ES+G-E=$9U
M;&Q(5$U,*'1H:7,N9V5T2%1-3"@I*3L*"0ET:&ES+E]I9G)A;64N<W1Y;&4N
M9&ES<&QA>2`](")B;&]C:R(["@D)=&AI<RY?=&5X=$%R96$N<W1Y;&4N9&ES
M<&QA>2`](")N;VYE(CL*"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\I('L*"0D)
M+R\@=V4@;F5E9"!T;R!R969R97-H('1H870@:6YF;R!F;W(@36]Z+3$N,V$*
M"0D)=')Y('L*"0D)"71H:7,N7V1O8RYD97-I9VY-;V1E(#T@(F]N(CL*"0D)
M?2!C871C:"AE*2![?3L*"0E]"@D):68@*'1H:7,N8V]N9FEG+G-T871U<T)A
M<BD@>PH)"0ET:&ES+E]S=&%T=7-"87(N:6YN97)(5$U,(#T@)R<["@D)"2\O
M('1H:7,N7W-T871U<T)A<BYA<'!E;F1#:&EL9"AD;V-U;65N="YC<F5A=&54
M97AT3F]D92A(5$U,07)E82Y),3A.+FUS9ULB4&%T:")=("L@(CH@(BDI.PH)
M"0ET:&ES+E]S=&%T=7-"87(N87!P96YD0VAI;&0H=&AI<RY?<W1A='5S0F%R
M5')E92D["@D)?0H)"6)R96%K.PH)("`@(&1E9F%U;'0Z"@D)86QE<G0H(DUO
M9&4@/"(@*R!M;V1E("L@(CX@;F]T(&1E9FEN960A(BD["@D)<F5T=7)N(&9A
M;'-E.PH)?0H)=&AI<RY?961I=$UO9&4@/2!M;V1E.PH)=&AI<RYF;V-U<T5D
M:71O<B@I.PH*"69O<B`H=F%R(&D@:6X@=&AI<RYP;'5G:6YS*2!["@D)=F%R
M('!L=6=I;B`]('1H:7,N<&QU9VEN<UMI72YI;G-T86YC93L*"0EI9B`H='EP
M96]F('!L=6=I;BYO;DUO9&4@/3T@(F9U;F-T:6]N(BD@<&QU9VEN+F]N36]D
M92AM;V1E*3L*"7T*?3L*"DA434Q!<F5A+G!R;W1O='EP92YS971&=6QL2%1-
M3"`](&9U;F-T:6]N*&AT;6PI('L*"79A<B!S879E7VUU;'1I;&EN92`](%)E
M9T5X<"YM=6QT:6QI;F4["@E296=%>'`N;75L=&EL:6YE(#T@=')U93L*"6EF
M("AH=&UL+FUA=&-H*$A434Q!<F5A+E)%7V1O8W1Y<&4I*2!["@D)=&AI<RYS
M971$;V-T>7!E*%)E9T5X<"XD,2D["@D):'1M;"`](&AT;6PN<F5P;&%C92A(
M5$U,07)E82Y215]D;V-T>7!E+"`B(BD["@E]"@E296=%>'`N;75L=&EL:6YE
M(#T@<V%V95]M=6QT:6QI;F4["@EI9B`H(4A434Q!<F5A+FES7VEE*2!["@D)
M:68@*&AT;6PN;6%T8V@H2%1-3$%R96$N4D5?:&5A9"DI"@D)"71H:7,N7V1O
M8RYG971%;&5M96YT<T)Y5&%G3F%M92@B:&5A9"(I6S!=+FEN;F5R2%1-3"`]
M(%)E9T5X<"XD,3L*"0EI9B`H:'1M;"YM871C:"A(5$U,07)E82Y215]B;V1Y
M*2D*"0D)=&AI<RY?9&]C+F=E=$5L96UE;G1S0GE486=.86UE*")B;V1Y(BE;
M,%TN:6YN97)(5$U,(#T@4F5G17AP+B0Q.PH)?2!E;'-E('L*"0EV87(@:'1M
M;%]R92`]("\\:'1M;#XH*"Y\7&XI*C\I/%PO:'1M;#XO:3L*"0EH=&UL(#T@
M:'1M;"YR97!L86-E*&AT;6Q?<F4L("(D,2(I.PH)"71H:7,N7V1O8RYO<&5N
M*"D["@D)=&AI<RY?9&]C+G=R:71E*&AT;6PI.PH)"71H:7,N7V1O8RYC;&]S
M92@I.PH)"71H:7,N7V1O8RYB;V1Y+F-O;G1E;G1%9&ET86)L92`]('1R=64[
M"@D)<F5T=7)N('1R=64["@E]"GT["@HO*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"B`J("!#871E9V]R>3H@
M4$Q51TE.4PH@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ+PH*+R\@0W)E871E('1H92!S<&5C:69I960@<&QU
M9VEN(&%N9"!R96=I<W1E<B!I="!W:71H('1H:7,@2%1-3$%R96$*2%1-3$%R
M96$N<')O=&]T>7!E+G)E9VES=&5R4&QU9VEN(#T@9G5N8W1I;VXH*2!["@EV
M87(@<&QU9VEN(#T@87)G=6UE;G1S6S!=.PH)=F%R(&%R9W,@/2!;73L*"69O
M<B`H=F%R(&D@/2`Q.R!I(#P@87)G=6UE;G1S+FQE;F=T:#L@*RMI*0H)"6%R
M9W,N<'5S:"AA<F=U;65N='-;:5TI.PH)=&AI<RYR96=I<W1E<E!L=6=I;C(H
M<&QU9VEN+"!A<F=S*3L*?3L*"B\O('1H:7,@:7,@=&AE('9A<FEA;G0@;V8@
M=&AE(&9U;F-T:6]N(&%B;W9E('=H97)E('1H92!P;'5G:6X@87)G=6UE;G1S
M(&%R90HO+R!A;')E861Y('!A8VME9"!I;B!A;B!A<G)A>2X@($5X=&5R;F%L
M;'DL(&ET('-H;W5L9"!B92!O;FQY('5S960@:6X@=&AE"B\O(&9U;&PM<V-R
M965N(&5D:71O<B!C;V1E+"!I;B!O<F1E<B!T;R!I;FET:6%L:7IE('!L=6=I
M;G,@=VET:"!T:&4@<V%M90HO+R!P87)A;65T97)S(&%S(&EN('1H92!O<&5N
M97(@=VEN9&]W+@I(5$U,07)E82YP<F]T;W1Y<&4N<F5G:7-T97)0;'5G:6XR
M(#T@9G5N8W1I;VXH<&QU9VEN+"!A<F=S*2!["@EI9B`H='EP96]F('!L=6=I
M;B`]/2`B<W1R:6YG(BD*"0EP;'5G:6X@/2!E=F%L*'!L=6=I;BD["@EI9B`H
M='EP96]F('!L=6=I;B`]/2`B=6YD969I;F5D(BD@>PH)"2\J($9)6$U%.B!4
M:&ES('-H;W5L9"!N979E<B!H87!P96XN($)U="!W:'D@9&]E<R!I="!D;S\@
M*B\*"0ER971U<FX@9F%L<V4["@E]"@EV87(@;V)J(#T@;F5W('!L=6=I;BAT
M:&ES+"!A<F=S*3L*"6EF("AO8FHI('L*"0EV87(@8VQO;F4@/2![?3L*"0EV
M87(@:6YF;R`]('!L=6=I;BY?<&QU9VEN26YF;SL*"0EF;W(@*'9A<B!I(&EN
M(&EN9F\I"@D)"6-L;VYE6VE=(#T@:6YF;UMI73L*"0EC;&]N92YI;G-T86YC
M92`](&]B:CL*"0EC;&]N92YA<F=S(#T@87)G<SL*"0ET:&ES+G!L=6=I;G-;
M<&QU9VEN+E]P;'5G:6Y);F9O+FYA;65=(#T@8VQO;F4["@E](&5L<V4*"0EA
M;&5R="@B0V%N)W0@<F5G:7-T97(@<&QU9VEN("(@*R!P;'5G:6XN=&]3=')I
M;F<H*2`K("(N(BD["GT["@HO+R!S=&%T:6,@9G5N8W1I;VX@=&AA="!L;V%D
M<R!T:&4@<F5Q=6ER960@<&QU9VEN(&%N9"!L86YG(&9I;&4L(&)A<V5D(&]N
M('1H90HO+R!L86YG=6%G92!L;V%D960@86QR96%D>2!F;W(@2%1-3$%R96$N
M("!9;W4@8F5T=&5R(&UA:V4@<W5R92!T:&%T('1H92!P;'5G:6X*+R\@7VAA
M<U\@=&AA="!L86YG=6%G92P@;W1H97)W:7-E('-H:70@;6EG:'0@:&%P<&5N
M(#LM*0I(5$U,07)E82YG9710;'5G:6Y$:7(@/2!F=6YC=&EO;BAP;'5G:6Y.
M86UE*2!["@ER971U<FX@7V5D:71O<E]U<FP@*R`B<&QU9VEN<R\B("L@<&QU
M9VEN3F%M93L*?3L*"DA434Q!<F5A+FQO8610;'5G:6X@/2!F=6YC=&EO;BAP
M;'5G:6Y.86UE*2!["@EV87(@9&ER(#T@=&AI<RYG9710;'5G:6Y$:7(H<&QU
M9VEN3F%M92D["@EV87(@<&QU9VEN(#T@<&QU9VEN3F%M92YR97!L86-E*"\H
M6V$M>ETI*%M!+5I=*2A;82UZ72DO9RP*"0D)"0EF=6YC=&EO;B`H<W1R+"!L
M,2P@;#(L(&PS*2!["@D)"0D)"7)E='5R;B!L,2`K("(M(B`K(&PR+G1O3&]W
M97)#87-E*"D@*R!L,SL*"0D)"0E]*2YT;TQO=V5R0V%S92@I("L@(BYJ<R([
M"@EV87(@<&QU9VEN7V9I;&4@/2!D:7(@*R`B+R(@*R!P;'5G:6X["@EV87(@
M<&QU9VEN7VQA;F<@/2!D:7(@*R`B+VQA;F<O(B`K(%]E9&ET;W)?;&%N9R`K
M("(N:G,B.PH)+R]D;V-U;65N="YW<FET92@B/'-C<FEP="!T>7!E/2=T97AT
M+VIA=F%S8W)I<'0G('-R8STG(B`K('!L=6=I;E]F:6QE("L@(B<^/"]S8W)I
M<'0^(BD["@DO+V1O8W5M96YT+G=R:71E*"(\<V-R:7!T('1Y<&4])W1E>'0O
M:F%V87-C<FEP="<@<W)C/2<B("L@<&QU9VEN7VQA;F<@*R`B)SX\+W-C<FEP
M=#XB*3L*"71H:7,N;&]A9%-C<FEP="AP;'5G:6Y?9FEL92D["@ET:&ES+FQO
M86138W)I<'0H<&QU9VEN7VQA;F<I.PI].PH*2%1-3$%R96$N;&]A9%-T>6QE
M(#T@9G5N8W1I;VXH<W1Y;&4L('!L=6=I;BD@>PH)=F%R('5R;"`](%]E9&ET
M;W)?=7)L('Q\("<G.PH):68@*'1Y<&5O9B!P;'5G:6X@(3T@(G5N9&5F:6YE
M9"(I('L*"0EU<FP@*ST@(G!L=6=I;G,O(B`K('!L=6=I;B`K("(O(CL*"7T*
M"75R;"`K/2!S='EL93L*"6EF("@O7EPO+RYT97-T*'-T>6QE*2D*"0EU<FP@
M/2!S='EL93L*"79A<B!H96%D(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A
M9TYA;64H(FAE860B*5LP73L*"79A<B!L:6YK(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@B;&EN:R(I.PH);&EN:RYR96P@/2`B<W1Y;&5S:&5E="(["@EL
M:6YK+FAR968@/2!U<FP["@EH96%D+F%P<&5N9$-H:6QD*&QI;FLI.PH)+R]D
M;V-U;65N="YW<FET92@B/'-T>6QE('1Y<&4])W1E>'0O8W-S)SY`:6UP;W)T
M('5R;"@B("L@=7)L("L@(BD[/"]S='EL93XB*3L*?3L*2%1-3$%R96$N;&]A
M9%-T>6QE*'1Y<&5O9B!?961I=&]R7V-S<R`]/2`B<W1R:6YG(B`_(%]E9&ET
M;W)?8W-S(#H@(FAT;6QA<F5A+F-S<R(I.PH*+RHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@*B`@0V%T96=O
M<GDZ($5$251/4B!55$E,251)15,*("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B\*"DA434Q!<F5A+G!R;W1O
M='EP92YD96)U9U1R964@/2!F=6YC=&EO;B@I('L*"79A<B!T82`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H(G1E>'1A<F5A(BD["@ET82YS='EL92YW:61T
M:"`]("(Q,#`E(CL*"71A+G-T>6QE+FAE:6=H="`]("(R,&5M(CL*"71A+G9A
M;'5E(#T@(B(["@EF=6YC=&EO;B!D96)U9RAI;F1E;G0L('-T<BD@>PH)"69O
M<B`H.R`M+6EN9&5N="`^/2`P.RD*"0D)=&$N=F%L=64@*ST@(B`B.PH)"71A
M+G9A;'5E("L]('-T<B`K(")<;B(["@E].PH)9G5N8W1I;VX@7V1T*')O;W0L
M(&QE=F5L*2!["@D)=F%R('1A9R`](')O;W0N=&%G3F%M92YT;TQO=V5R0V%S
M92@I+"!I.PH)"79A<B!N<R`]($A434Q!<F5A+FES7VEE(#\@<F]O="YS8V]P
M94YA;64@.B!R;V]T+G!R969I>#L*"0ED96)U9RAL979E;"P@(BT@(B`K('1A
M9R`K("(@6R(@*R!N<R`K(")=(BD["@D)9F]R("AI(#T@<F]O="YF:7)S=$-H
M:6QD.R!I.R!I(#T@:2YN97AT4VEB;&EN9RD*"0D):68@*&DN;F]D951Y<&4@
M/3T@,2D*"0D)"5]D="AI+"!L979E;"`K(#(I.PH)?3L*"5]D="AT:&ES+E]D
M;V,N8F]D>2P@,"D["@ED;V-U;65N="YB;V1Y+F%P<&5N9$-H:6QD*'1A*3L*
M?3L*"DA434Q!<F5A+F=E=$EN;F5R5&5X="`](&9U;F-T:6]N*&5L*2!["@EV
M87(@='AT(#T@)R<L(&D["@EF;W(@*&D@/2!E;"YF:7)S=$-H:6QD.R!I.R!I
M(#T@:2YN97AT4VEB;&EN9RD@>PH)"6EF("AI+FYO9&54>7!E(#T](#,I"@D)
M"71X="`K/2!I+F1A=&$["@D)96QS92!I9B`H:2YN;V1E5'EP92`]/2`Q*0H)
M"0ET>'0@*ST@2%1-3$%R96$N9V5T26YN97)497AT*&DI.PH)?0H)<F5T=7)N
M('1X=#L*?3L*"DA434Q!<F5A+G!R;W1O='EP92Y?=V]R9$-L96%N(#T@9G5N
M8W1I;VXH*2!["@EV87(*"0EE9&ET;W(@/2!T:&ES+`H)"7-T871S(#T@>PH)
M"0EE;7!T>5]T86=S(#H@,"P*"0D);7-O7V-L87-S("`Z(#`L"@D)"6US;U]S
M='EL92`@.B`P+`H)"0EM<V]?>&UL96P@(#H@,"P*"0D);W)I9U]L96X@("`Z
M('1H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"YL96YG=&@L"@D)"50@("`@("`@
M("`@.B`H;F5W($1A=&4H*2DN9V5T5&EM92@I"@D)?2P*"0ES=&%T<U]T>'0@
M/2!["@D)"65M<'1Y7W1A9W,@.B`B16UP='D@=&%G<R!R96UO=F5D.B`B+`H)
M"0EM<V]?8VQA<W,@(#H@(DU33R!C;&%S<R!N86UE<R!R96UO=F5D.B`B+`H)
M"0EM<V]?<W1Y;&4@(#H@(DU33R!I;FQI;F4@<W1Y;&4@<F5M;W9E9#H@(BP*
M"0D);7-O7WAM;&5L("`Z(")-4T\@6$U,(&5L96UE;G1S('-T<FEP<&5D.B`B
M"@D)?3L*"69U;F-T:6]N('-H;W=3=&%T<R@I('L*"0EV87(@='AT(#T@(DA4
M34Q!<F5A('=O<F0@8VQE86YE<B!S=&%T<SH@7&Y<;B(["@D)9F]R("AV87(@
M:2!I;B!S=&%T<RD*"0D):68@*'-T871S7W1X=%MI72D*"0D)"71X="`K/2!S
M=&%T<U]T>'1;:5T@*R!S=&%T<UMI72`K(")<;B(["@D)='AT("L](")<;DEN
M:71I86P@9&]C=6UE;G0@;&5N9W1H.B`B("L@<W1A=',N;W)I9U]L96X@*R`B
M7&XB.PH)"71X="`K/2`B1FEN86P@9&]C=6UE;G0@;&5N9W1H.B`B("L@961I
M=&]R+E]D;V,N8F]D>2YI;FYE<DA434PN;&5N9W1H("L@(EQN(CL*"0ET>'0@
M*ST@(D-L96%N+75P('1O;VL@(B`K("@H*&YE=R!$871E*"DI+F=E=%1I;64H
M*2`M('-T871S+E0I("\@,3`P,"D@*R`B('-E8V]N9',B.PH)"6%L97)T*'1X
M="D["@E].PH)9G5N8W1I;VX@8VQE87)#;&%S<RAN;V1E*2!["@D)=F%R(&YE
M=V,@/2!N;V1E+F-L87-S3F%M92YR97!L86-E*"\H7GQ<<REM<V\N*C\H7'-\
M)"DO:6<L("<@)RD["@D):68@*&YE=V,@(3T@;F]D92YC;&%S<TYA;64I('L*
M"0D);F]D92YC;&%S<TYA;64@/2!N97=C.PH)"0EI9B`H(2]<4R\N=&5S="AN
M;V1E+F-L87-S3F%M92DI('L*"0D)"6YO9&4N<F5M;W9E071T<FEB=71E*")C
M;&%S<TYA;64B*3L*"0D)"2LK<W1A=',N;7-O7V-L87-S.PH)"0E]"@D)?0H)
M?3L*"69U;F-T:6]N(&-L96%R4W1Y;&4H;F]D92D@>PH@"0EV87(@9&5C;&%R
M871I;VYS(#T@;F]D92YS='EL92YC<W-497AT+G-P;&ET*"]<<RH[7',J+RD[
M"@D)9F]R("AV87(@:2`](&1E8VQA<F%T:6]N<RYL96YG=&@[("TM:2`^/2`P
M.RD*"0D):68@*"]>;7-O?%YT86(M<W1O<',O:2YT97-T*&1E8VQA<F%T:6]N
M<UMI72D@?'P*"0D)("`@("]>;6%R9VEN7',J.EQS*C`N+EQS*S`N+EQS*S`N
M+B]I+G1E<W0H9&5C;&%R871I;VYS6VE=*2D@>PH)"0D)*RMS=&%T<RYM<V]?
M<W1Y;&4["@D)"0ED96-L87)A=&EO;G,N<W!L:6-E*&DL(#$I.PH)"0E]"@D)
M;F]D92YS='EL92YC<W-497AT(#T@9&5C;&%R871I;VYS+FIO:6XH(CL@(BD[
M"@E].PH)9G5N8W1I;VX@<W1R:7!486<H96PI('L*"0EI9B`H2%1-3$%R96$N
M:7-?:64I"@D)"65L+F]U=&5R2%1-3"`]($A434Q!<F5A+FAT;6Q%;F-O9&4H
M96PN:6YN97)497AT*3L*"0EE;'-E('L*"0D)=F%R('1X="`](&1O8W5M96YT
M+F-R96%T951E>'1.;V1E*$A434Q!<F5A+F=E=$EN;F5R5&5X="AE;"DI.PH)
M"0EE;"YP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AT>'0L(&5L*3L*"0D)96PN
M<&%R96YT3F]D92YR96UO=F5#:&EL9"AE;"D["@D)?0H)"2LK<W1A=',N;7-O
M7WAM;&5L.PH)?3L*"69U;F-T:6]N(&-H96-K16UP='DH96PI('L*"0EI9B`H
M+UXH87QS<&%N?&)\<W1R;VYG?&E\96U\9F]N="DD+VDN=&5S="AE;"YT86=.
M86UE*2`F)@H)"2`@("`A96PN9FER<W1#:&EL9"D@>PH)"0EE;"YP87)E;G1.
M;V1E+G)E;6]V94-H:6QD*&5L*3L*"0D)*RMS=&%T<RYE;7!T>5]T86=S.PH)
M"7T*"7T["@EF=6YC=&EO;B!P87)S951R964H<F]O="D@>PH)"79A<B!T86<@
M/2!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*2P@:2P@;F5X=#L*"0EI9B`H
M*$A434Q!<F5A+FES7VEE("8F(')O;W0N<V-O<&5.86UE("$]("=(5$U,)RD@
M?'P@*"%(5$U,07)E82YI<U]I92`F)B`O.B\N=&5S="AT86<I*2D@>PH)"0ES
M=')I<%1A9RAR;V]T*3L*"0D)<F5T=7)N(&9A;'-E.PH)"7T@96QS92!["@D)
M"6-L96%R0VQA<W,H<F]O="D["@D)"6-L96%R4W1Y;&4H<F]O="D["@D)"69O
M<B`H:2`](')O;W0N9FER<W1#:&EL9#L@:3L@:2`](&YE>'0I('L*"0D)"6YE
M>'0@/2!I+FYE>'13:6)L:6YG.PH)"0D):68@*&DN;F]D951Y<&4@/3T@,2`F
M)B!P87)S951R964H:2DI"@D)"0D)8VAE8VM%;7!T>2AI*3L*"0D)?0H)"7T*
M"0ER971U<FX@=')U93L*"7T["@EP87)S951R964H=&AI<RY?9&]C+F)O9'DI
M.PH)+R\@<VAO=U-T871S*"D["@DO+R!T:&ES+F1E8G5G5')E92@I.PH)+R\@
M=&AI<RYS971(5$U,*'1H:7,N9V5T2%1-3"@I*3L*"2\O('1H:7,N<V5T2%1-
M3"AT:&ES+F=E=$EN;F5R2%1-3"@I*3L*"2\O('1H:7,N9F]R8V52961R87<H
M*3L*"71H:7,N=7!D871E5&]O;&)A<B@I.PI].PH*2%1-3$%R96$N<')O=&]T
M>7!E+F9O<F-E4F5D<F%W(#T@9G5N8W1I;VXH*2!["@ET:&ES+E]D;V,N8F]D
M>2YS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E;B(["@ET:&ES+E]D;V,N8F]D
M>2YS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB;&4B.PH)+R\@=&AI<RY?9&]C
M+F)O9'DN:6YN97)(5$U,(#T@=&AI<RYG971);FYE<DA434PH*3L*?3L*"B\O
M(&9O8W5S97,@=&AE(&EF<F%M92!W:6YD;W<N("!R971U<FYS(&$@<F5F97)E
M;F-E('1O('1H92!E9&ET;W(@9&]C=6UE;G0N"DA434Q!<F5A+G!R;W1O='EP
M92YF;V-U<T5D:71O<B`](&9U;F-T:6]N*"D@>PH)<W=I=&-H("AT:&ES+E]E
M9&ET36]D92D@>PH)("`@("\O(&YO=&EC92!T:&4@=')Y('L@+BXN('T@8V%T
M8V@@8FQO8VL@=&\@879O:60@<V]M92!R87)E(&5X8V5P=&EO;G,@:6X@1FER
M949O>`H)("`@("\O("AP97)H87!S(&%L<V\@:6X@;W1H97(@1V5C:V\@8G)O
M=W-E<G,I+B!-86YU86P@9F]C=7,@8GD@=7-E<B!I<R!R97%U:7)E9"!I;@H@
M("`@("`@("\O(&-A<V4@;V8@86X@97)R;W(N(%-O;65B;V1Y(&AA<R!A;B!I
M9&5A/PH)("`@(&-A<V4@(G=Y<VEW>6<B(#H@=')Y('L@=&AI<RY?:69R86UE
M+F-O;G1E;G17:6YD;W<N9F]C=7,H*2!](&-A=&-H("AE*2![?2!B<F5A:SL*
M"2`@("!C87-E(")T97AT;6]D92(Z('1R>2![('1H:7,N7W1E>'1!<F5A+F9O
M8W5S*"D@?2!C871C:"`H92D@>WT@8G)E86L["@D@("`@9&5F875L=`D@("`Z
M(&%L97)T*")%4E)/4CH@;6]D92`B("L@=&AI<RY?961I=$UO9&4@*R`B(&ES
M(&YO="!D969I;F5D(BD["@E]"@ER971U<FX@=&AI<RY?9&]C.PI].PH*+R\@
M=&%K97,@82!S;F%P<VAO="!O9B!T:&4@8W5R<F5N="!T97AT("AF;W(@=6YD
M;RD*2%1-3$%R96$N<')O=&]T>7!E+E]U;F1O5&%K95-N87!S:&]T(#T@9G5N
M8W1I;VXH*2!["@DK*W1H:7,N7W5N9&]0;W,["@EI9B`H=&AI<RY?=6YD;U!O
M<R`^/2!T:&ES+F-O;F9I9RYU;F1O4W1E<',I('L*"0DO+R!R96UO=F4@=&AE
M(&9I<G-T(&5L96UE;G0*"0ET:&ES+E]U;F1O475E=64N<VAI9G0H*3L*"0DM
M+71H:7,N7W5N9&]0;W,["@E]"@DO+R!U<V4@=&AE(&9A<W1E9"!M971H;V0@
M*&=E=$EN;F5R2%1-3"D["@EV87(@=&%K92`]('1R=64["@EV87(@='AT(#T@
M=&AI<RYG971);FYE<DA434PH*3L*"6EF("AT:&ES+E]U;F1O4&]S(#X@,"D*
M"0ET86ME(#T@*'1H:7,N7W5N9&]1=65U95MT:&ES+E]U;F1O4&]S("T@,5T@
M(3T@='AT*3L*"6EF("AT86ME*2!["@D)=&AI<RY?=6YD;U%U975E6W1H:7,N
M7W5N9&]0;W-=(#T@='AT.PH)?2!E;'-E('L*"0ET:&ES+E]U;F1O4&]S+2T[
M"@E]"GT["@I(5$U,07)E82YP<F]T;W1Y<&4N=6YD;R`](&9U;F-T:6]N*"D@
M>PH):68@*'1H:7,N7W5N9&]0;W,@/B`P*2!["@D)=F%R('1X="`]('1H:7,N
M7W5N9&]1=65U95LM+71H:7,N7W5N9&]0;W-=.PH)"6EF("AT>'0I('1H:7,N
M<V5T2%1-3"AT>'0I.PH)"65L<V4@*RMT:&ES+E]U;F1O4&]S.PH)?0I].PH*
M2%1-3$%R96$N<')O=&]T>7!E+G)E9&\@/2!F=6YC=&EO;B@I('L*"6EF("AT
M:&ES+E]U;F1O4&]S(#P@=&AI<RY?=6YD;U%U975E+FQE;F=T:"`M(#$I('L*
M"0EV87(@='AT(#T@=&AI<RY?=6YD;U%U975E6RLK=&AI<RY?=6YD;U!O<UT[
M"@D):68@*'1X="D@=&AI<RYS971(5$U,*'1X="D["@D)96QS92`M+71H:7,N
M7W5N9&]0;W,["@E]"GT["@HO+R!U<&1A=&5S(&5N86)L960O9&ES86)L92]A
M8W1I=F4@<W1A=&4@;V8@=&AE('1O;VQB87(@96QE;65N=',*2%1-3$%R96$N
M<')O=&]T>7!E+G5P9&%T951O;VQB87(@/2!F=6YC=&EO;BAN;U-T871U<RD@
M>PH)=F%R(&1O8R`]('1H:7,N7V1O8SL*"79A<B!T97AT(#T@*'1H:7,N7V5D
M:71-;V1E(#T](")T97AT;6]D92(I.PH)=F%R(&%N8V5S=&]R<R`](&YU;&P[
M"@EI9B`H(71E>'0I('L*"0EA;F-E<W1O<G,@/2!T:&ES+F=E=$%L;$%N8V5S
M=&]R<R@I.PH)"6EF("AT:&ES+F-O;F9I9RYS=&%T=7-"87(@)B8@(6YO4W1A
M='5S*2!["@D)"71H:7,N7W-T871U<T)A<E1R964N:6YN97)(5$U,(#T@2%1-
M3$%R96$N23$X3BYM<V=;(E!A=&@B72`K("(Z("([("\O(&-L96%R"@D)"69O
M<B`H=F%R(&D@/2!A;F-E<W1O<G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)
M"79A<B!E;"`](&%N8V5S=&]R<UMI73L*"0D)"6EF("@A96PI('L*"0D)"0DO
M+R!H96QL(&MN;W=S('=H>2!W92!G970@:&5R93L@=&AI<PH)"0D)"2\O(&-O
M=6QD(&)E(&$@8VQA<W-I8R!E>&%M<&QE(&]F('=H>0H)"0D)"2\O(&ET)W,@
M9V]O9"!T;R!C:&5C:R!F;W(@8V]N9&ET:6]N<PH)"0D)"2\O('1H870@87)E
M(&EM<&]S<VEB;&4@=&\@:&%P<&5N(#LM*0H)"0D)"6-O;G1I;G5E.PH)"0D)
M?0H)"0D)=F%R(&$@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")A(BD["@D)
M"0EA+FAR968@/2`B(R(["@D)"0EA+F5L(#T@96P["@D)"0EA+F5D:71O<B`]
M('1H:7,["@D)"0EA+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*"0D)"0ET:&ES
M+F)L=7(H*3L*"0D)"0ET:&ES+F5D:71O<BYS96QE8W1.;V1E0V]N=&5N=',H
M=&AI<RYE;"D["@D)"0D)=&AI<RYE9&ET;W(N=7!D871E5&]O;&)A<BAT<G5E
M*3L*"0D)"0ER971U<FX@9F%L<V4["@D)"0E].PH)"0D)82YO;F-O;G1E>'1M
M96YU(#T@9G5N8W1I;VXH*2!["@D)"0D)+R\@5$]$3SH@861D(&-O;G1E>'0@
M;65N=2!H97)E"@D)"0D)=&AI<RYB;'5R*"D["@D)"0D)=F%R(&EN9F\@/2`B
M26YL:6YE('-T>6QE.EQN7&XB.PH)"0D)"6EN9F\@*ST@=&AI<RYE;"YS='EL
M92YC<W-497AT+G-P;&ET*"\[7',J+RDN:F]I;B@B.UQN(BD["@D)"0D)86QE
M<G0H:6YF;RD["@D)"0D)<F5T=7)N(&9A;'-E.PH)"0D)?3L*"0D)"79A<B!T
M>'0@/2!E;"YT86=.86UE+G1O3&]W97)#87-E*"D["@D)"0EA+G1I=&QE(#T@
M96PN<W1Y;&4N8W-S5&5X=#L*"0D)"6EF("AE;"YI9"D@>PH)"0D)"71X="`K
M/2`B(R(@*R!E;"YI9#L*"0D)"7T*"0D)"6EF("AE;"YC;&%S<TYA;64I('L*
M"0D)"0ET>'0@*ST@(BXB("L@96PN8VQA<W-.86UE.PH)"0D)?0H)"0D)82YA
M<'!E;F1#:&EL9"AD;V-U;65N="YC<F5A=&5497AT3F]D92AT>'0I*3L*"0D)
M"71H:7,N7W-T871U<T)A<E1R964N87!P96YD0VAI;&0H82D["@D)"0EI9B`H
M:2`A/2`P*2!["@D)"0D)=&AI<RY?<W1A='5S0F%R5')E92YA<'!E;F1#:&EL
M9"AD;V-U;65N="YC<F5A=&5497AT3F]D92A3=')I;F<N9G)O;4-H87)#;V1E
M*#!X8F(I*2D["@D)"0E]"@D)"7T*"0E]"@E]"@H)9F]R("AV87(@:2!I;B!T
M:&ES+E]T;V]L8F%R3V)J96-T<RD@>PH)"79A<B!B=&X@/2!T:&ES+E]T;V]L
M8F%R3V)J96-T<UMI73L*"0EV87(@8VUD(#T@:3L*"0EV87(@:6Y#;VYT97AT
M(#T@=')U93L*"0EI9B`H8G1N+F-O;G1E>'0@)B8@(71E>'0I('L*"0D):6Y#
M;VYT97AT(#T@9F%L<V4["@D)"79A<B!C;VYT97AT(#T@8G1N+F-O;G1E>'0[
M"@D)"79A<B!A='1R<R`](%M=.PH)"0EI9B`H+R@N*BE<6R@N*C\I7%TO+G1E
M<W0H8V]N=&5X="DI('L*"0D)"6-O;G1E>'0@/2!296=%>'`N)#$["@D)"0EA
M='1R<R`](%)E9T5X<"XD,BYS<&QI="@B+"(I.PH)"0E]"@D)"6-O;G1E>'0@
M/2!C;VYT97AT+G1O3&]W97)#87-E*"D["@D)"79A<B!M871C:"`]("AC;VYT
M97AT(#T]("(J(BD["@D)"69O<B`H=F%R(&L@/2`P.R!K(#P@86YC97-T;W)S
M+FQE;F=T:#L@*RMK*2!["@D)"0EI9B`H(6%N8V5S=&]R<UMK72D@>PH)"0D)
M"2\O('1H92!I;7!O<W-I8FQE(')E86QL>2!H87!P96YS+@H)"0D)"6-O;G1I
M;G5E.PH)"0D)?0H)"0D):68@*&UA=&-H('Q\("AA;F-E<W1O<G-;:UTN=&%G
M3F%M92YT;TQO=V5R0V%S92@I(#T](&-O;G1E>'0I*2!["@D)"0D):6Y#;VYT
M97AT(#T@=')U93L*"0D)"0EF;W(@*'9A<B!K82`](#`[(&MA(#P@871T<G,N
M;&5N9W1H.R`K*VMA*2!["@D)"0D)"6EF("@A979A;"@B86YC97-T;W)S6VM=
M+B(@*R!A='1R<UMK85TI*2!["@D)"0D)"0EI;D-O;G1E>'0@/2!F86QS93L*
M"0D)"0D)"6)R96%K.PH)"0D)"0E]"@D)"0D)?0H)"0D)"6EF("AI;D-O;G1E
M>'0I('L*"0D)"0D)8G)E86L["@D)"0D)?0H)"0D)?0H)"0E]"@D)?0H)"6)T
M;BYS=&%T92@B96YA8FQE9"(L("@A=&5X="!\?"!B=&XN=&5X="D@)B8@:6Y#
M;VYT97AT*3L*"0EI9B`H='EP96]F(&-M9"`]/2`B9G5N8W1I;VXB*2!["@D)
M"6-O;G1I;G5E.PH)"7T*"0DO+R!L;V]K+6ET+75P(&EN('1H92!C=7-T;VT@
M9')O<&1O=VX@8F]X97,*"0EV87(@9')O<&1O=VX@/2!T:&ES+F-O;F9I9RYC
M=7-T;VU396QE8W1S6V-M9%T["@D):68@*"@A=&5X="!\?"!B=&XN=&5X="D@
M)B8@*'1Y<&5O9B!D<F]P9&]W;B`A/2`B=6YD969I;F5D(BDI('L*"0D)9')O
M<&1O=VXN<F5F<F5S:"AT:&ES*3L*"0D)8V]N=&EN=64["@D)?0H)"7-W:71C
M:"`H8VUD*2!["@D)("`@(&-A<V4@(F9O;G1N86UE(CH*"0D@("`@8V%S92`B
M9F]N='-I>F4B.@H)"2`@("!C87-E(")F;W)M871B;&]C:R(Z"@D)"6EF("@A
M=&5X="D@=')Y('L*"0D)"79A<B!V86QU92`]("@B(B`K(&1O8RYQ=65R>4-O
M;6UA;F1686QU92AC;60I*2YT;TQO=V5R0V%S92@I.PH)"0D):68@*"%V86QU
M92D@>PH)"0D)"6)T;BYE;&5M96YT+G-E;&5C=&5D26YD97@@/2`P.PH)"0D)
M"6)R96%K.PH)"0D)?0H)"0D)+R\@2$%#2R`M+2!R971R:65V92!T:&4@8V]N
M9FEG(&]P=&EO;B!F;W(@=&AI<PH)"0D)+R\@8V]M8F\@8F]X+B`@5V4@<F5L
M>2!O;B!T:&4@9F%C="!T:&%T('1H90H)"0D)+R\@=F%R:6%B;&4@:6X@8V]N
M9FEG(&AA<R!T:&4@<V%M92!N86UE(&%S"@D)"0DO+R!B=71T;VX@;F%M92!I
M;B!T:&4@=&]O;&)A<BX*"0D)"79A<B!O<'1I;VYS(#T@=&AI<RYC;VYF:6=;
M8VUD73L*"0D)"79A<B!K(#T@,#L*"0D)"69O<B`H=F%R(&H@:6X@;W!T:6]N
M<RD@>PH)"0D)"2\O($9)6$U%.B!T:&4@9F]L;&]W:6YG(&QI;F4@:7,@<V-A
M<GDN"@D)"0D):68@*"AJ+G1O3&]W97)#87-E*"D@/3T@=F%L=64I('Q\"@D)
M"0D)("`@("AO<'1I;VYS6VI=+G-U8G-T<B@P+"!V86QU92YL96YG=&@I+G1O
M3&]W97)#87-E*"D@/3T@=F%L=64I*2!["@D)"0D)"6)T;BYE;&5M96YT+G-E
M;&5C=&5D26YD97@@/2!K.PH)"0D)"0ET:')O=R`B;VLB.PH)"0D)"7T*"0D)
M"0DK*VL["@D)"0E]"@D)"0EB=&XN96QE;65N="YS96QE8W1E9$EN9&5X(#T@
M,#L*"0D)?2!C871C:"AE*2![?3L*"0D)8G)E86L["@D)("`@(&-A<V4@(G1E
M>'1I;F1I8V%T;W(B.@H)"0EI9B`H(71E>'0I('L*"0D)"71R>2![=VET:"`H
M8G1N+F5L96UE;G0N<W1Y;&4I('L*"0D)"0EB86-K9W)O=6YD0V]L;W(@/2!(
M5$U,07)E82Y?;6%K94-O;&]R*`H)"0D)"0ED;V,N<75E<GE#;VUM86YD5F%L
M=64H2%1-3$%R96$N:7-?:64@/R`B8F%C:V-O;&]R(B`Z(")H:6QI=&5C;VQO
M<B(I*3L*"0D)"0EI9B`H+W1R86YS<&%R96YT+VDN=&5S="AB86-K9W)O=6YD
M0V]L;W(I*2!["@D)"0D)"2\O($UO>FEL;&$*"0D)"0D)8F%C:V=R;W5N9$-O
M;&]R(#T@2%1-3$%R96$N7VUA:V5#;VQO<BAD;V,N<75E<GE#;VUM86YD5F%L
M=64H(F)A8VMC;VQO<B(I*3L*"0D)"0E]"@D)"0D)8V]L;W(@/2!(5$U,07)E
M82Y?;6%K94-O;&]R*&1O8RYQ=65R>4-O;6UA;F1686QU92@B9F]R96-O;&]R
M(BDI.PH)"0D)"69O;G1&86UI;'D@/2!D;V,N<75E<GE#;VUM86YD5F%L=64H
M(F9O;G1N86UE(BD["@D)"0D)9F]N=%=E:6=H="`](&1O8RYQ=65R>4-O;6UA
M;F13=&%T92@B8F]L9"(I(#\@(F)O;&0B(#H@(FYO<FUA;"(["@D)"0D)9F]N
M=%-T>6QE(#T@9&]C+G%U97)Y0V]M;6%N9%-T871E*")I=&%L:6,B*2`_(")I
M=&%L:6,B(#H@(FYO<FUA;"(["@D)"0E]?2!C871C:"`H92D@>PH)"0D)"2\O
M(&%L97)T*&4@*R`B7&Y<;B(@*R!C;60I.PH)"0D)?0H)"0E]"@D)"6)R96%K
M.PH)"2`@("!C87-E(")H=&UL;6]D92(Z(&)T;BYS=&%T92@B86-T:79E(BP@
M=&5X="D[(&)R96%K.PH)"2`@("!C87-E(")L969T=&]R:6=H="(Z"@D)("`@
M(&-A<V4@(G)I9VAT=&]L969T(CH*"0D)=F%R(&5L(#T@=&AI<RYG971087)E
M;G1%;&5M96YT*"D["@D)"7=H:6QE("AE;"`F)B`A2%1-3$%R96$N:7-";&]C
M:T5L96UE;G0H96PI*0H)"0D)96P@/2!E;"YP87)E;G1.;V1E.PH)"0EI9B`H
M96PI"@D)"0EB=&XN<W1A=&4H(F%C=&EV92(L("AE;"YS='EL92YD:7)E8W1I
M;VX@/3T@*"AC;60@/3T@(G)I9VAT=&]L969T(BD@/R`B<G1L(B`Z(")L='(B
M*2DI.PH)"0EB<F5A:SL*"0D@("`@9&5F875L=#H*"0D)8VUD(#T@8VUD+G)E
M<&QA8V4H+RAU;BD_;W)D97)E9&QI<W0O:2P@(FEN<V5R="0Q;W)D97)E9&QI
M<W0B*3L*"0D)=')Y('L*"0D)"6)T;BYS=&%T92@B86-T:79E(BP@*"%T97AT
M("8F(&1O8RYQ=65R>4-O;6UA;F13=&%T92AC;60I*2D["@D)"7T@8V%T8V@@
M*&4I('M]"@D)?0H)?0H)+R\@=&%K92!U;F1O('-N87!S:&]T<PH):68@*'1H
M:7,N7V-U<W1O;55N9&\@)B8@(71H:7,N7W1I;65R56YD;RD@>PH)"71H:7,N
M7W5N9&]486ME4VYA<'-H;W0H*3L*"0EV87(@961I=&]R(#T@=&AI<SL*"0ET
M:&ES+E]T:6UE<E5N9&\@/2!S9714:6UE;W5T*&9U;F-T:6]N*"D@>PH)"0EE
M9&ET;W(N7W1I;65R56YD;R`](&YU;&P["@D)?2P@=&AI<RYC;VYF:6<N=6YD
M;U1I;65O=70I.PH)?0H*"2\O(&-H96-K(&EF(&%N>2!P;'5G:6YS(&AA=F4@
M<F5G:7-T97)E9"!R969R97-H(&AA;F1L97)S"@EF;W(@*'9A<B!I(&EN('1H
M:7,N<&QU9VEN<RD@>PH)"79A<B!P;'5G:6X@/2!T:&ES+G!L=6=I;G-;:5TN
M:6YS=&%N8V4["@D):68@*'1Y<&5O9B!P;'5G:6XN;VY5<&1A=&54;V]L8F%R
M(#T](")F=6YC=&EO;B(I"@D)"7!L=6=I;BYO;E5P9&%T951O;VQB87(H*3L*
M"7T*?3L*"B\J*B!2971U<FYS(&$@;F]D92!A9G1E<B!W:&EC:"!W92!C86X@
M:6YS97)T(&]T:&5R(&YO9&5S+"!I;B!T:&4@8W5R<F5N=`H@*B!S96QE8W1I
M;VXN("!4:&4@<V5L96-T:6]N(&ES(')E;6]V960N("!)="!S<&QI=',@82!T
M97AT(&YO9&4L(&EF(&YE961E9"X*("HO"DA434Q!<F5A+G!R;W1O='EP92YI
M;G-E<G1.;V1E071396QE8W1I;VX@/2!F=6YC=&EO;BAT;T)E26YS97)T960I
M('L*"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0EV87(@<V5L(#T@=&AI<RY?
M9V5T4V5L96-T:6]N*"D["@D)=F%R(')A;F=E(#T@=&AI<RY?8W)E871E4F%N
M9V4H<V5L*3L*"0DO+R!R96UO=F4@=&AE(&-U<G)E;G0@<V5L96-T:6]N"@D)
M<V5L+G)E;6]V94%L;%)A;F=E<R@I.PH)"7)A;F=E+F1E;&5T94-O;G1E;G1S
M*"D["@D)=F%R(&YO9&4@/2!R86YG92YS=&%R=$-O;G1A:6YE<CL*"0EV87(@
M<&]S(#T@<F%N9V4N<W1A<G1/9F9S970["@D)<W=I=&-H("AN;V1E+FYO9&54
M>7!E*2!["@D)("`@(&-A<V4@,SH@+R\@3F]D92Y415A47TY/1$4*"0D)+R\@
M=V4@:&%V92!T;R!S<&QI="!I="!A="!T:&4@8V%R970@<&]S:71I;VXN"@D)
M"6EF("AT;T)E26YS97)T960N;F]D951Y<&4@/3T@,RD@>PH)"0D)+R\@9&\@
M;W!T:6UI>F5D(&EN<V5R=&EO;@H)"0D);F]D92YI;G-E<G1$871A*'!O<RP@
M=&]"94EN<V5R=&5D+F1A=&$I.PH)"0D)<F%N9V4@/2!T:&ES+E]C<F5A=&52
M86YG92@I.PH)"0D)<F%N9V4N<V5T16YD*&YO9&4L('!O<R`K('1O0F5);G-E
M<G1E9"YL96YG=&@I.PH)"0D)<F%N9V4N<V5T4W1A<G0H;F]D92P@<&]S("L@
M=&]"94EN<V5R=&5D+FQE;F=T:"D["@D)"0ES96PN861D4F%N9V4H<F%N9V4I
M.PH)"0E](&5L<V4@>PH)"0D);F]D92`](&YO9&4N<W!L:71497AT*'!O<RD[
M"@D)"0EV87(@<V5L;F]D92`]('1O0F5);G-E<G1E9#L*"0D)"6EF("AT;T)E
M26YS97)T960N;F]D951Y<&4@/3T@,3$@+RH@3F]D92Y$3T-5345.5%]&4D%'
M345.5%].3T1%("HO*2!["@D)"0D)<V5L;F]D92`]('-E;&YO9&4N9FER<W1#
M:&EL9#L*"0D)"7T*"0D)"6YO9&4N<&%R96YT3F]D92YI;G-E<G1"969O<F4H
M=&]"94EN<V5R=&5D+"!N;V1E*3L*"0D)"71H:7,N<V5L96-T3F]D94-O;G1E
M;G1S*'-E;&YO9&4I.PH)"0D)=&AI<RYU<&1A=&54;V]L8F%R*"D["@D)"7T*
M"0D)8G)E86L["@D)("`@(&-A<V4@,3H@+R\@3F]D92Y%3$5-14Y47TY/1$4*
M"0D)=F%R('-E;&YO9&4@/2!T;T)E26YS97)T960["@D)"6EF("AT;T)E26YS
M97)T960N;F]D951Y<&4@/3T@,3$@+RH@3F]D92Y$3T-5345.5%]&4D%'345.
M5%].3T1%("HO*2!["@D)"0ES96QN;V1E(#T@<V5L;F]D92YF:7)S=$-H:6QD
M.PH)"0E]"@D)"6YO9&4N:6YS97)T0F5F;W)E*'1O0F5);G-E<G1E9"P@;F]D
M92YC:&EL9$YO9&5S6W!O<UTI.PH)"0ET:&ES+G-E;&5C=$YO9&5#;VYT96YT
M<RAS96QN;V1E*3L*"0D)=&AI<RYU<&1A=&54;V]L8F%R*"D["@D)"6)R96%K
M.PH)"7T*"7T@96QS92!["@D)<F5T=7)N(&YU;&P["2\O('1H:7,@9G5N8W1I
M;VX@;F]T('EE="!U<V5D(&9O<B!)12`\1DE8344^"@E]"GT["@HO+R!2971U
M<FYS('1H92!D965P97-T(&YO9&4@=&AA="!C;VYT86EN<R!B;W1H(&5N9'!O
M:6YT<R!O9B!T:&4@<V5L96-T:6]N+@I(5$U,07)E82YP<F]T;W1Y<&4N9V5T
M4&%R96YT16QE;65N="`](&9U;F-T:6]N*"D@>PH)=F%R('-E;"`]('1H:7,N
M7V=E=%-E;&5C=&EO;B@I.PH)=F%R(')A;F=E(#T@=&AI<RY?8W)E871E4F%N
M9V4H<V5L*3L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7-W:71C:"`H<V5L
M+G1Y<&4I('L*"0D@("`@8V%S92`B5&5X="(Z"@D)("`@(&-A<V4@(DYO;F4B
M.@H)"0DO+R!)="!S965M<R!T:&%T(&5V96X@9F]R('-E;&5C=&EO;B!O9B!T
M>7!E(").;VYE(BP*"0D)+R\@=&AE<F4@7VES7R!A('!A<F5N="!E;&5M96YT
M(&%N9"!I="=S('9A;'5E(&ES(&YO=`H)"0DO+R!O;FQY(&-O<G)E8W0L(&)U
M="!V97)Y(&EM<&]R=&%N="!T;R!U<RX@($U3244@:7,*"0D)+R\@8V5R=&%I
M;FQY('1H92!B=6=G:65S="!B<F]W<V5R(&EN('1H92!W;W)L9"!A;F0@20H)
M"0DO+R!W;VYD97(L($=O9"P@:&]W(&-A;B!%87)T:"!S=&%N9"!I=#\*"0D)
M<F5T=7)N(')A;F=E+G!A<F5N=$5L96UE;G0H*3L*"0D@("`@8V%S92`B0V]N
M=')O;"(Z"@D)"7)E='5R;B!R86YG92YI=&5M*#`I.PH)"2`@("!D969A=6QT
M.@H)"0ER971U<FX@=&AI<RY?9&]C+F)O9'D["@D)?0H)?2!E;'-E('1R>2![
M"@D)=F%R('`@/2!R86YG92YC;VUM;VY!;F-E<W1O<D-O;G1A:6YE<CL*"0EI
M9B`H(7)A;F=E+F-O;&QA<'-E9"`F)B!R86YG92YS=&%R=$-O;G1A:6YE<B`]
M/2!R86YG92YE;F1#;VYT86EN97(@)B8*"0D@("`@<F%N9V4N<W1A<G1/9F9S
M970@+2!R86YG92YE;F1/9F9S970@/#T@,2`F)B!R86YG92YS=&%R=$-O;G1A
M:6YE<BYH87-#:&EL9$YO9&5S*"DI"@D)"7`@/2!R86YG92YS=&%R=$-O;G1A
M:6YE<BYC:&EL9$YO9&5S6W)A;F=E+G-T87)T3V9F<V5T73L*"0DO*@H)"6%L
M97)T*')A;F=E+G-T87)T0V]N=&%I;F5R("L@(CHB("L@<F%N9V4N<W1A<G1/
M9F9S970@*R`B7&XB("L*"0D@("`@("!R86YG92YE;F1#;VYT86EN97(@*R`B
M.B(@*R!R86YG92YE;F1/9F9S970I.PH)"2HO"@D)=VAI;&4@*'`N;F]D951Y
M<&4@/3T@,RD@>PH)"0EP(#T@<"YP87)E;G1.;V1E.PH)"7T*"0ER971U<FX@
M<#L*"7T@8V%T8V@@*&4I('L*"0ER971U<FX@;G5L;#L*"7T*?3L*"B\O(%)E
M='5R;G,@86X@87)R87D@=VET:"!A;&P@=&AE(&%N8V5S=&]R(&YO9&5S(&]F
M('1H92!S96QE8W1I;VXN"DA434Q!<F5A+G!R;W1O='EP92YG971!;&Q!;F-E
M<W1O<G,@/2!F=6YC=&EO;B@I('L*"79A<B!P(#T@=&AI<RYG971087)E;G1%
M;&5M96YT*"D["@EV87(@82`](%M=.PH)=VAI;&4@*'`@)B8@*'`N;F]D951Y
M<&4@/3T@,2D@)B8@*'`N=&%G3F%M92YT;TQO=V5R0V%S92@I("$]("=B;V1Y
M)RDI('L*"0EA+G!U<V@H<"D["@D)<"`]('`N<&%R96YT3F]D93L*"7T*"6$N
M<'5S:"AT:&ES+E]D;V,N8F]D>2D["@ER971U<FX@83L*?3L*"B\O(%-E;&5C
M=',@=&AE(&-O;G1E;G1S(&EN<VED92!T:&4@9VEV96X@;F]D90I(5$U,07)E
M82YP<F]T;W1Y<&4N<V5L96-T3F]D94-O;G1E;G1S(#T@9G5N8W1I;VXH;F]D
M92P@<&]S*2!["@ET:&ES+F9O8W5S161I=&]R*"D["@ET:&ES+F9O<F-E4F5D
M<F%W*"D["@EV87(@<F%N9V4["@EV87(@8V]L;&%P<V5D(#T@*'1Y<&5O9B!P
M;W,@(3T@(G5N9&5F:6YE9"(I.PH):68@*$A434Q!<F5A+FES7VEE*2!["@D)
M<F%N9V4@/2!T:&ES+E]D;V,N8F]D>2YC<F5A=&5497AT4F%N9V4H*3L*"0ER
M86YG92YM;W9E5&]%;&5M96YT5&5X="AN;V1E*3L*"0DH8V]L;&%P<V5D*2`F
M)B!R86YG92YC;VQL87!S92AP;W,I.PH)"7)A;F=E+G-E;&5C="@I.PH)?2!E
M;'-E('L*"0EV87(@<V5L(#T@=&AI<RY?9V5T4V5L96-T:6]N*"D["@D)<F%N
M9V4@/2!T:&ES+E]D;V,N8W)E871E4F%N9V4H*3L*"0ER86YG92YS96QE8W1.
M;V1E0V]N=&5N=',H;F]D92D["@D)*&-O;&QA<'-E9"D@)B8@<F%N9V4N8V]L
M;&%P<V4H<&]S*3L*"0ES96PN<F5M;W9E06QL4F%N9V5S*"D["@D)<V5L+F%D
M9%)A;F=E*')A;F=E*3L*"7T*?3L*"B\J*B!#86QL('1H:7,@9G5N8W1I;VX@
M=&\@:6YS97)T($A434P@8V]D92!A="!T:&4@8W5R<F5N="!P;W-I=&EO;BX@
M($ET(&1E;&5T97,*("H@=&AE('-E;&5C=&EO;BP@:68@86YY+@H@*B\*2%1-
M3$%R96$N<')O=&]T>7!E+FEN<V5R=$A434P@/2!F=6YC=&EO;BAH=&UL*2![
M"@EV87(@<V5L(#T@=&AI<RY?9V5T4V5L96-T:6]N*"D["@EV87(@<F%N9V4@
M/2!T:&ES+E]C<F5A=&5286YG92AS96PI.PH):68@*$A434Q!<F5A+FES7VEE
M*2!["@D)<F%N9V4N<&%S=&5(5$U,*&AT;6PI.PH)?2!E;'-E('L*"0DO+R!C
M;VYS=')U8W0@82!N97<@9&]C=6UE;G0@9G)A9VUE;G0@=VET:"!T:&4@9VEV
M96X@2%1-3`H)"79A<B!F<F%G;65N="`]('1H:7,N7V1O8RYC<F5A=&5$;V-U
M;65N=$9R86=M96YT*"D["@D)=F%R(&1I=B`]('1H:7,N7V1O8RYC<F5A=&5%
M;&5M96YT*")D:78B*3L*"0ED:78N:6YN97)(5$U,(#T@:'1M;#L*"0EW:&EL
M92`H9&EV+F9I<G-T0VAI;&0I('L*"0D)+R\@=&AE(&9O;&QO=VEN9R!C86QL
M(&%L<V\@<F5M;W9E<R!T:&4@;F]D92!F<F]M(&1I=@H)"0EF<F%G;65N="YA
M<'!E;F1#:&EL9"AD:78N9FER<W1#:&EL9"D["@D)?0H)"2\O('1H:7,@86QS
M;R!R96UO=F5S('1H92!S96QE8W1I;VX*"0EV87(@;F]D92`]('1H:7,N:6YS
M97)T3F]D94%T4V5L96-T:6]N*&9R86=M96YT*3L*"7T*?3L*"B\J*@H@*B`@
M0V%L;"!T:&ES(&9U;F-T:6]N('1O('-U<G)O=6YD('1H92!E>&ES=&EN9R!(
M5$U,(&-O9&4@:6X@=&AE('-E;&5C=&EO;B!W:71H"B`J("!Y;W5R('1A9W,N
M("!&25A-13H@8G5G9WDA("!4:&ES(&9U;F-T:6]N('=I;&P@8F4@9&5P<F5C
M871E9"`B<V]O;B(N"B`J+PI(5$U,07)E82YP<F]T;W1Y<&4N<W5R<F]U;F1(
M5$U,(#T@9G5N8W1I;VXH<W1A<G1486<L(&5N9%1A9RD@>PH)=F%R(&AT;6P@
M/2!T:&ES+F=E=%-E;&5C=&5D2%1-3"@I.PH)+R\@=&AE(&9O;&QO=VEN9R!A
M;'-O(&1E;&5T97,@=&AE('-E;&5C=&EO;@H)=&AI<RYI;G-E<G1(5$U,*'-T
M87)T5&%G("L@:'1M;"`K(&5N9%1A9RD["GT["@HO+R\@4F5T<FEE=F4@=&AE
M('-E;&5C=&5D(&)L;V-K"DA434Q!<F5A+G!R;W1O='EP92YG971396QE8W1E
M9$A434P@/2!F=6YC=&EO;B@I('L*"79A<B!S96P@/2!T:&ES+E]G971396QE
M8W1I;VXH*3L*"79A<B!R86YG92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D[
M"@EV87(@97AI<W1I;F<@/2!N=6QL.PH):68@*$A434Q!<F5A+FES7VEE*2![
M"@D)97AI<W1I;F<@/2!R86YG92YH=&UL5&5X=#L*"7T@96QS92!["@D)97AI
M<W1I;F<@/2!(5$U,07)E82YG971(5$U,*')A;F=E+F-L;VYE0V]N=&5N=',H
M*2P@9F%L<V4L('1H:7,I.PH)?0H)<F5T=7)N(&5X:7-T:6YG.PI].PH*+R\O
M(%)E='5R;B!T<G5E(&EF('=E(&AA=F4@<V]M92!S96QE8W1I;VX*2%1-3$%R
M96$N<')O=&]T>7!E+FAA<U-E;&5C=&5D5&5X="`](&9U;F-T:6]N*"D@>PH)
M+R\@1DE8344Z(&-O;64@7V]N7R!M:7-H;V\L('EO=2!C86X@9&\@8F5T=&5R
M('1H86X@=&AI<R`[+2D*"7)E='5R;B!T:&ES+F=E=%-E;&5C=&5D2%1-3"@I
M("$]("<G.PI].PH*2%1-3$%R96$N<')O=&]T>7!E+E]C<F5A=&5,:6YK(#T@
M9G5N8W1I;VXH;&EN:RD@>PH)=F%R(&5D:71O<B`]('1H:7,["@EV87(@;W5T
M<&%R86T@/2!N=6QL.PH):68@*'1Y<&5O9B!L:6YK(#T](")U;F1E9FEN960B
M*2!["@D);&EN:R`]('1H:7,N9V5T4&%R96YT16QE;65N="@I.PH)"6EF("AL
M:6YK*2!["@D)"6EF("@O7FEM9R0O:2YT97-T*&QI;FLN=&%G3F%M92DI"@D)
M"0EL:6YK(#T@;&EN:RYP87)E;G1.;V1E.PH)"0EI9B`H(2]>820O:2YT97-T
M*&QI;FLN=&%G3F%M92DI"@D)"0EL:6YK(#T@;G5L;#L*"0E]"@E]"@EI9B`H
M(6QI;FLI('L*"0EV87(@<V5L(#T@961I=&]R+E]G971396QE8W1I;VXH*3L*
M"0EV87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A;F=E*'-E;"D["@D)=F%R
M(&-O;7!A<F4@/2`P.PH)"6EF("A(5$U,07)E82YI<U]I92D@>PH)"0EC;VUP
M87)E(#T@<F%N9V4N8V]M<&%R945N9%!O:6YT<R@B4W1A<G14;T5N9"(L(')A
M;F=E*3L*"0E](&5L<V4@>PH)"0EC;VUP87)E(#T@<F%N9V4N8V]M<&%R94)O
M=6YD87)Y4&]I;G1S*')A;F=E+E-405)47U1/7T5.1"P@<F%N9V4I.PH)"7T*
M"0EI9B`H8V]M<&%R92`]/2`P*2!["@D)"6%L97)T*")9;W4@;F5E9"!T;R!S
M96QE8W0@<V]M92!T97AT(&)E9F]R92!C<F5A=&EN9R!A(&QI;FLB*3L*"0D)
M<F5T=7)N.PH)"7T*"0EO=71P87)A;2`]('L*"0D)9E]H<F5F(#H@)R<L"@D)
M"69?=&ET;&4@.B`G)RP*"0D)9E]T87)G970@.B`G)RP*"0D)9E]U<V5T87)G
M970@.B!E9&ET;W(N8V]N9FEG+FUA:V5,:6YK4VAO=W-487)G970*"0E].PH)
M?2!E;'-E"@D);W5T<&%R86T@/2!["@D)"69?:')E9B`@(#H@2%1-3$%R96$N
M:7-?:64@/R!E9&ET;W(N<W1R:7!"87-E55),*&QI;FLN:')E9BD@.B!L:6YK
M+F=E=$%T=')I8G5T92@B:')E9B(I+`H)"0EF7W1I=&QE("`Z(&QI;FLN=&ET
M;&4L"@D)"69?=&%R9V5T(#H@;&EN:RYT87)G970L"@D)"69?=7-E=&%R9V5T
M(#H@961I=&]R+F-O;F9I9RYM86ME3&EN:U-H;W=S5&%R9V5T"@D)?3L*"71H
M:7,N7W!O<'5P1&EA;&]G*")L:6YK+FAT;6PB+"!F=6YC=&EO;BAP87)A;2D@
M>PH)"6EF("@A<&%R86TI"@D)"7)E='5R;B!F86QS93L*"0EV87(@82`](&QI
M;FL["@D):68@*"%A*2!T<GD@>PH)"0EE9&ET;W(N7V1O8RYE>&5C0V]M;6%N
M9"@B8W)E871E;&EN:R(L(&9A;'-E+"!P87)A;2YF7VAR968I.PH)"0EA(#T@
M961I=&]R+F=E=%!A<F5N=$5L96UE;G0H*3L*"0D)=F%R('-E;"`](&5D:71O
M<BY?9V5T4V5L96-T:6]N*"D["@D)"79A<B!R86YG92`](&5D:71O<BY?8W)E
M871E4F%N9V4H<V5L*3L*"0D):68@*"%(5$U,07)E82YI<U]I92D@>PH)"0D)
M82`](')A;F=E+G-T87)T0V]N=&%I;F5R.PH)"0D):68@*"$O7F$D+VDN=&5S
M="AA+G1A9TYA;64I*2!["@D)"0D)82`](&$N;F5X=%-I8FQI;F<["@D)"0D)
M:68@*&$@/3T@;G5L;"D*"0D)"0D)82`](')A;F=E+G-T87)T0V]N=&%I;F5R
M+G!A<F5N=$YO9&4["@D)"0E]"@D)"7T*"0E](&-A=&-H*&4I('M]"@D)96QS
M92!["@D)"79A<B!H<F5F(#T@<&%R86TN9E]H<F5F+G1R:6TH*3L*"0D)961I
M=&]R+G-E;&5C=$YO9&5#;VYT96YT<RAA*3L*"0D):68@*&AR968@/3T@(B(I
M('L*"0D)"65D:71O<BY?9&]C+F5X96-#;VUM86YD*")U;FQI;FLB+"!F86QS
M92P@;G5L;"D["@D)"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"0D)<F5T
M=7)N(&9A;'-E.PH)"0E]"@D)"65L<V4@>PH)"0D)82YH<F5F(#T@:')E9CL*
M"0D)?0H)"7T*"0EI9B`H(2AA("8F("]>820O:2YT97-T*&$N=&%G3F%M92DI
M*0H)"0ER971U<FX@9F%L<V4["@D)82YT87)G970@/2!P87)A;2YF7W1A<F=E
M="YT<FEM*"D["@D)82YT:71L92`]('!A<F%M+F9?=&ET;&4N=')I;2@I.PH)
M"65D:71O<BYS96QE8W1.;V1E0V]N=&5N=',H82D["@D)961I=&]R+G5P9&%T
M951O;VQB87(H*3L*"7TL(&]U='!A<F%M*3L*?3L*"B\O($-A;&QE9"!W:&5N
M('1H92!U<V5R(&-L:6-K<R!O;B`B26YS97)T26UA9V4B(&)U='1O;BX@($EF
M(&%N(&EM86=E(&ES(&%L<F5A9'D*+R\@=&AE<F4L(&ET('=I;&P@:G5S="!M
M;V1I9GD@:70G<R!P<F]P97)T:65S+@I(5$U,07)E82YP<F]T;W1Y<&4N7VEN
M<V5R=$EM86=E(#T@9G5N8W1I;VXH:6UA9V4I('L*"79A<B!E9&ET;W(@/2!T
M:&ES.PDO+R!F;W(@;F5S=&5D(&9U;F-T:6]N<PH)=F%R(&]U='!A<F%M(#T@
M;G5L;#L*"6EF("AT>7!E;V8@:6UA9V4@/3T@(G5N9&5F:6YE9"(I('L*"0EI
M;6%G92`]('1H:7,N9V5T4&%R96YT16QE;65N="@I.PH)"6EF("AI;6%G92`F
M)B`A+UYI;6<D+VDN=&5S="AI;6%G92YT86=.86UE*2D*"0D):6UA9V4@/2!N
M=6QL.PH)?0H):68@*&EM86=E*2!O=71P87)A;2`]('L*"0EF7V)A<V4@("`Z
M(&5D:71O<BYC;VYF:6<N8F%S95523"P*"0EF7W5R;"`@("`Z($A434Q!<F5A
M+FES7VEE(#\@961I=&]R+G-T<FEP0F%S95523"AI;6%G92YS<F,I(#H@:6UA
M9V4N9V5T071T<FEB=71E*")S<F,B*2P*"0EF7V%L="`@("`Z(&EM86=E+F%L
M="P*"0EF7V)O<F1E<B`Z(&EM86=E+F)O<F1E<BP*"0EF7V%L:6=N("`Z(&EM
M86=E+F%L:6=N+`H)"69?=F5R="`@(#H@:6UA9V4N=G-P86-E+`H)"69?:&]R
M:7H@(#H@:6UA9V4N:'-P86-E"@E].PH)=&AI<RY?<&]P=7!$:6%L;V<H(FEN
M<V5R=%]I;6%G92YH=&UL(BP@9G5N8W1I;VXH<&%R86TI('L*"0EI9B`H(7!A
M<F%M*2!["2\O('5S97(@;75S="!H879E('!R97-S960@0V%N8V5L"@D)"7)E
M='5R;B!F86QS93L*"0E]"@D)=F%R(&EM9R`](&EM86=E.PH)"6EF("@A:6UG
M*2!["@D)"79A<B!S96P@/2!E9&ET;W(N7V=E=%-E;&5C=&EO;B@I.PH)"0EV
M87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A;F=E*'-E;"D["@D)"65D:71O
M<BY?9&]C+F5X96-#;VUM86YD*")I;G-E<G1I;6%G92(L(&9A;'-E+"!P87)A
M;2YF7W5R;"D["@D)"6EF("A(5$U,07)E82YI<U]I92D@>PH)"0D):6UG(#T@
M<F%N9V4N<&%R96YT16QE;65N="@I.PH)"0D)+R\@=V]N9&5R(&EF('1H:7,@
M=V]R:W,N+BX*"0D)"6EF("AI;6<N=&%G3F%M92YT;TQO=V5R0V%S92@I("$]
M(")I;6<B*2!["@D)"0D):6UG(#T@:6UG+G!R979I;W5S4VEB;&EN9SL*"0D)
M"7T*"0D)?2!E;'-E('L*"0D)"6EM9R`](')A;F=E+G-T87)T0V]N=&%I;F5R
M+G!R979I;W5S4VEB;&EN9SL*"0D)?0H)"7T@96QS92!["@D)"6EM9RYS<F,@
M/2!P87)A;2YF7W5R;#L*"0E]"@H)"69O<B`H=F%R(&9I96QD(&EN('!A<F%M
M*2!["@D)"79A<B!V86QU92`]('!A<F%M6V9I96QD73L*"0D)<W=I=&-H("AF
M:65L9"D@>PH)"0D@("`@8V%S92`B9E]A;'0B("`@(#H@:6UG+F%L=`D@/2!V
M86QU93L@8G)E86L["@D)"2`@("!C87-E(")F7V)O<F1E<B(@.B!I;6<N8F]R
M9&5R(#T@<&%R<V5);G0H=F%L=64@?'P@(C`B*3L@8G)E86L["@D)"2`@("!C
M87-E(")F7V%L:6=N(B`@.B!I;6<N86QI9VX)(#T@=F%L=64[(&)R96%K.PH)
M"0D@("`@8V%S92`B9E]V97)T(B`@(#H@:6UG+G9S<&%C92`]('!A<G-E26YT
M*'9A;'5E('Q\("(P(BD[(&)R96%K.PH)"0D@("`@8V%S92`B9E]H;W)I>B(@
M(#H@:6UG+FAS<&%C92`]('!A<G-E26YT*'9A;'5E('Q\("(P(BD[(&)R96%K
M.PH)"0E]"@D)?0H)?2P@;W5T<&%R86TI.PI].PH*+R\@0V%L;&5D('=H96X@
M=&AE('5S97(@8VQI8VMS('1H92!);G-E<G0@5&%B;&4@8G5T=&]N"DA434Q!
M<F5A+G!R;W1O='EP92Y?:6YS97)T5&%B;&4@/2!F=6YC=&EO;B@I('L*"79A
M<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*"79A<B!R86YG92`]('1H
M:7,N7V-R96%T95)A;F=E*'-E;"D["@EV87(@961I=&]R(#T@=&AI<SL)+R\@
M9F]R(&YE<W1E9"!F=6YC=&EO;G,*"71H:7,N7W!O<'5P1&EA;&]G*")I;G-E
M<G1?=&%B;&4N:'1M;"(L(&9U;F-T:6]N*'!A<F%M*2!["@D):68@*"%P87)A
M;2D@>PDO+R!U<V5R(&UU<W0@:&%V92!P<F5S<V5D($-A;F-E;`H)"0ER971U
M<FX@9F%L<V4["@D)?0H)"79A<B!D;V,@/2!E9&ET;W(N7V1O8SL*"0DO+R!C
M<F5A=&4@=&AE('1A8FQE(&5L96UE;G0*"0EV87(@=&%B;&4@/2!D;V,N8W)E
M871E16QE;65N="@B=&%B;&4B*3L*"0DO+R!A<W-I9VX@=&AE(&=I=F5N(&%R
M9W5M96YT<PH*"0EF;W(@*'9A<B!F:65L9"!I;B!P87)A;2D@>PH)"0EV87(@
M=F%L=64@/2!P87)A;5MF:65L9%T["@D)"6EF("@A=F%L=64I('L*"0D)"6-O
M;G1I;G5E.PH)"0E]"@D)"7-W:71C:"`H9FEE;&0I('L*"0D)("`@(&-A<V4@
M(F9?=VED=&@B("`@.B!T86)L92YS='EL92YW:61T:"`]('9A;'5E("L@<&%R
M86U;(F9?=6YI=")=.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?86QI9VXB("`@
M.B!T86)L92YA;&EG;@D@/2!V86QU93L@8G)E86L["@D)"2`@("!C87-E(")F
M7V)O<F1E<B(@(#H@=&%B;&4N8F]R9&5R"2`]('!A<G-E26YT*'9A;'5E*3L@
M8G)E86L["@D)"2`@("!C87-E(")F7W-P86-I;F<B(#H@=&%B;&4N8V5L;%-P
M86-I;F<@/2!P87)S94EN="AV86QU92D[(&)R96%K.PH)"0D@("`@8V%S92`B
M9E]P861D:6YG(B`Z('1A8FQE+F-E;&Q0861D:6YG(#T@<&%R<V5);G0H=F%L
M=64I.R!B<F5A:SL*"0D)?0H)"7T*"0EV87(@8V5L;'=I9'1H(#T@,#L*"0EI
M9B`H<&%R86TN9E]F:7AE9"D*"0D)8V5L;'=I9'1H(#T@36%T:"YF;&]O<B@Q
M,#`@+R!P87)S94EN="AP87)A;2YF7V-O;',I*3L*"0EV87(@=&)O9'D@/2!D
M;V,N8W)E871E16QE;65N="@B=&)O9'DB*3L*"0ET86)L92YA<'!E;F1#:&EL
M9"AT8F]D>2D["@D)9F]R("AV87(@:2`](#`[(&D@/"!P87)A;5LB9E]R;W=S
M(ET[("LK:2D@>PH)"0EV87(@='(@/2!D;V,N8W)E871E16QE;65N="@B='(B
M*3L*"0D)=&)O9'DN87!P96YD0VAI;&0H='(I.PH)"0EF;W(@*'9A<B!J(#T@
M,#L@:B`\('!A<F%M6R)F7V-O;',B73L@*RMJ*2!["@D)"0EV87(@=&0@/2!D
M;V,N8W)E871E16QE;65N="@B=&0B*3L*"0D)"6EF("AC96QL=VED=&@I"@D)
M"0D)=&0N<W1Y;&4N=VED=&@@/2!C96QL=VED=&@@*R`B)2(["@D)"0ET<BYA
M<'!E;F1#:&EL9"AT9"D["@D)"0DO+R!-;WII;&QA(&QI:V5S('1O('-E92!S
M;VUE=&AI;F<@:6YS:61E('1H92!C96QL+@H)"0D)*$A434Q!<F5A+FES7V=E
M8VMO*2`F)B!T9"YA<'!E;F1#:&EL9"AD;V,N8W)E871E16QE;65N="@B8G(B
M*2D["@D)"7T*"0E]"@D):68@*$A434Q!<F5A+FES7VEE*2!["@D)"7)A;F=E
M+G!A<W1E2%1-3"AT86)L92YO=71E<DA434PI.PH)"7T@96QS92!["@D)"2\O
M(&EN<V5R="!T:&4@=&%B;&4*"0D)961I=&]R+FEN<V5R=$YO9&5!=%-E;&5C
M=&EO;BAT86)L92D["@D)?0H)"7)E='5R;B!T<G5E.PH)?2P@;G5L;"D["GT[
M"@HO*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ"B`J("!#871E9V]R>3H@159%3E0@2$%.1$Q%4E,*("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*B\*"B\O(&5L(&ES(')E9F5R96YC92!T;R!T:&4@4T5,14-4(&]B:F5C=`HO
M+R!T>'0@:7,@=&AE(&YA;64@;V8@=&AE('-E;&5C="!F:65L9"P@87,@:6X@
M8V]N9FEG+G1O;VQB87(*2%1-3$%R96$N<')O=&]T>7!E+E]C;VUB;U-E;&5C
M=&5D(#T@9G5N8W1I;VXH96PL('1X="D@>PH)=&AI<RYF;V-U<T5D:71O<B@I
M.PH)=F%R('9A;'5E(#T@96PN;W!T:6]N<UME;"YS96QE8W1E9$EN9&5X72YV
M86QU93L*"7-W:71C:"`H='AT*2!["@D@("`@8V%S92`B9F]N=&YA;64B.@H)
M("`@(&-A<V4@(F9O;G1S:7IE(CH@=&AI<RYE>&5C0V]M;6%N9"AT>'0L(&9A
M;'-E+"!V86QU92D[(&)R96%K.PH)("`@(&-A<V4@(F9O<FUA=&)L;V-K(CH*
M"0DH2%1-3$%R96$N:7-?:64I("8F("AV86QU92`]("(\(B`K('9A;'5E("L@
M(CXB*3L*"0ET:&ES+F5X96-#;VUM86YD*'1X="P@9F%L<V4L('9A;'5E*3L*
M"0EB<F5A:SL*"2`@("!D969A=6QT.@H)"2\O('1R>2!T;R!L;V]K(&ET('5P
M(&EN('1H92!R96=I<W1E<F5D(&1R;W!D;W=N<PH)"79A<B!D<F]P9&]W;B`]
M('1H:7,N8V]N9FEG+F-U<W1O;5-E;&5C='-;='AT73L*"0EI9B`H='EP96]F
M(&1R;W!D;W=N("$](")U;F1E9FEN960B*2!["@D)"61R;W!D;W=N+F%C=&EO
M;BAT:&ES*3L*"0E](&5L<V4@>PH)"0EA;&5R="@B1DE8344Z(&-O;6)O(&)O
M>"`B("L@='AT("L@(B!N;W0@:6UP;&5M96YT960B*3L*"0E]"@E]"GT["@HO
M+R!T:&4@97AE8T-O;6UA;F0@9G5N8W1I;VX@*&EN=&5R8V5P=',@<V]M92!C
M;VUM86YD<R!A;F0@<F5P;&%C97,@=&AE;2!W:71H"B\O(&]U<B!O=VX@:6UP
M;&5M96YT871I;VXI"DA434Q!<F5A+G!R;W1O='EP92YE>&5C0V]M;6%N9"`]
M(&9U;F-T:6]N*&-M9$E$+"!522P@<&%R86TI('L*"79A<B!E9&ET;W(@/2!T
M:&ES.PDO+R!F;W(@;F5S=&5D(&9U;F-T:6]N<PH)=&AI<RYF;V-U<T5D:71O
M<B@I.PH)8VUD240@/2!C;61)1"YT;TQO=V5R0V%S92@I.PH):68@*$A434Q!
M<F5A+FES7V=E8VMO*2!T<GD@>R!T:&ES+E]D;V,N97AE8T-O;6UA;F0H)W5S
M94-34R<L(&9A;'-E+"!T<G5E*3L@?2!C871C:"`H92D@>WT["@ES=VET8V@@
M*&-M9$E$*2!["@D@("`@8V%S92`B:'1M;&UO9&4B(#H@=&AI<RYS971-;V1E
M*"D[(&)R96%K.PH)("`@(&-A<V4@(FAI;&ET96-O;&]R(CH*"0DH2%1-3$%R
M96$N:7-?:64I("8F("AC;61)1"`](")B86-K8V]L;W(B*3L*"2`@("!C87-E
M(")F;W)E8V]L;W(B.@H)"71H:7,N7W!O<'5P1&EA;&]G*")S96QE8W1?8V]L
M;W(N:'1M;"(L(&9U;F-T:6]N*&-O;&]R*2!["@D)"6EF("AC;VQO<BD@>R`O
M+R!S96QE8W1I;VX@;F]T(&-A;F-E;&5D"@D)"0EE9&ET;W(N7V1O8RYE>&5C
M0V]M;6%N9"AC;61)1"P@9F%L<V4L("(C(B`K(&-O;&]R*3L*"0D)?0H)"7TL
M($A434Q!<F5A+E]C;VQO<E1O4F=B*'1H:7,N7V1O8RYQ=65R>4-O;6UA;F16
M86QU92AC;61)1"DI*3L*"0EB<F5A:SL*"2`@("!C87-E(")C<F5A=&5L:6YK
M(CH*"0ET:&ES+E]C<F5A=&5,:6YK*"D["@D)8G)E86L["@D@("`@8V%S92`B
M<&]P=7!E9&ET;W(B.@H)"2\O('1H:7,@;V)J96-T('=I;&P@8F4@<&%S<V5D
M('1O('1H92!N97=L>2!O<&5N960@=VEN9&]W"@D)2%1-3$%R96$N7V]B:F5C
M="`]('1H:7,["@D):68@*$A434Q!<F5A+FES7VEE*2!["@D)"2\O:68@*&-O
M;F9I<FTH2%1-3$%R96$N23$X3BYM<V=;(DE%+7-U8VMS+69U;&PM<V-R965N
M(ETI*0H)"0E["@D)"0EW:6YD;W<N;W!E;BAT:&ES+G!O<'5P55),*")F=6QL
M<V-R965N+FAT;6PB*2P@(FAA7V9U;&QS8W)E96XB+`H)"0D)"2`@("`B=&]O
M;&)A<CUN;RQL;V-A=&EO;CUN;RQD:7)E8W1O<FEE<SUN;RQS=&%T=7,];F\L
M;65N=6)A<CUN;RPB("L*"0D)"0D@("`@(G-C<F]L;&)A<G,];F\L<F5S:7IA
M8FQE/7EE<RQW:61T:#TV-#`L:&5I9VAT/30X,"(I.PH)"0E]"@D)?2!E;'-E
M('L*"0D)=VEN9&]W+F]P96XH=&AI<RYP;W!U<%523"@B9G5L;'-C<F5E;BYH
M=&UL(BDL(")H85]F=6QL<V-R965N(BP*"0D)"2`@("`B=&]O;&)A<CUN;RQM
M96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO+'=I9'1H/38T,"QH96EG:'0]-#@P
M+"(@*PH)"0D)("`@(")S8W)O;&QB87)S/6YO+')E<VEZ86)L93UY97,B*3L*
M"0E]"@D)8G)E86L["@D@("`@8V%S92`B=6YD;R(Z"@D@("`@8V%S92`B<F5D
M;R(Z"@D):68@*'1H:7,N7V-U<W1O;55N9&\I"@D)"71H:7-;8VUD241=*"D[
M"@D)96QS90H)"0ET:&ES+E]D;V,N97AE8T-O;6UA;F0H8VUD240L(%5)+"!P
M87)A;2D["@D)8G)E86L["@D@("`@8V%S92`B:6YS97)T=&%B;&4B.B!T:&ES
M+E]I;G-E<G1486)L92@I.R!B<F5A:SL*"2`@("!C87-E(")I;G-E<G1I;6%G
M92(Z('1H:7,N7VEN<V5R=$EM86=E*"D[(&)R96%K.PH)("`@(&-A<V4@(F%B
M;W5T(B`@("`Z('1H:7,N7W!O<'5P1&EA;&]G*")A8F]U="YH=&UL(BP@;G5L
M;"P@=&AI<RD[(&)R96%K.PH)("`@(&-A<V4@(G-H;W=H96QP(B`Z('=I;F1O
M=RYO<&5N*%]E9&ET;W)?=7)L("L@(G)E9F5R96YC92YH=&UL(BP@(FAA7VAE
M;'`B*3L@8G)E86L["@H)("`@(&-A<V4@(FMI;&QW;W)D(CH@=&AI<RY?=V]R
M9$-L96%N*"D[(&)R96%K.PH*"2`@("!C87-E(")C=70B.@H)("`@(&-A<V4@
M(F-O<'DB.@H)("`@(&-A<V4@(G!A<W1E(CH*"0ET<GD@>PH)"0ET:&ES+E]D
M;V,N97AE8T-O;6UA;F0H8VUD240L(%5)+"!P87)A;2D["@D)"6EF("AT:&ES
M+F-O;F9I9RYK:6QL5V]R9$]N4&%S=&4I"@D)"0ET:&ES+E]W;W)D0VQE86XH
M*3L*"0E](&-A=&-H("AE*2!["@D)"6EF("A(5$U,07)E82YI<U]G96-K;RD@
M>PH)"0D):68@*'1Y<&5O9B!(5$U,07)E82Y),3A.+FUS9ULB36]Z+4-L:7!B
M;V%R9")=(#T](")U;F1E9FEN960B*2!["@D)"0D)2%1-3$%R96$N23$X3BYM
M<V=;(DUO>BU#;&EP8F]A<F0B72`]"@D)"0D)"2)5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2`B("L*"0D)"0D)(F9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@(B`K
M"@D)"0D)"2)W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+EQN7&XB("L*"0D)"0D)(EM&25A-
M13H@<&QE87-E('1R86YS;&%T92!T:&ES(&UE<W-A9V4@:6X@>6]U<B!L86YG
M=6%G92!D969I;FET:6]N(&9I;&4N72(["@D)"0E]"@D)"0EI9B`H8V]N9FER
M;2A(5$U,07)E82Y),3A.+FUS9ULB36]Z+4-L:7!B;V%R9")=*2D*"0D)"0EW
M:6YD;W<N;W!E;B@B:'1T<#HO+VUO>FEL;&$N;W)G+V5D:71O<B]M:61A<V1E
M;6\O<V5C=7)I='EP<F5F<RYH=&UL(BD["@D)"7T*"0E]"@D)8G)E86L["@D@
M("`@8V%S92`B;&5F='1O<FEG:'0B.@H)("`@(&-A<V4@(G)I9VAT=&]L969T
M(CH*"0EV87(@9&ER(#T@*&-M9$E$(#T](")R:6=H='1O;&5F="(I(#\@(G)T
M;"(@.B`B;'1R(CL*"0EV87(@96P@/2!T:&ES+F=E=%!A<F5N=$5L96UE;G0H
M*3L*"0EW:&EL92`H96P@)B8@(4A434Q!<F5A+FES0FQO8VM%;&5M96YT*&5L
M*2D*"0D)96P@/2!E;"YP87)E;G1.;V1E.PH)"6EF("AE;"D@>PH)"0EI9B`H
M96PN<W1Y;&4N9&ER96-T:6]N(#T](&1I<BD*"0D)"65L+G-T>6QE+F1I<F5C
M=&EO;B`]("(B.PH)"0EE;'-E"@D)"0EE;"YS='EL92YD:7)E8W1I;VX@/2!D
M:7(["@D)?0H)"6)R96%K.PH)("`@(&1E9F%U;'0Z('1R>2![('1H:7,N7V1O
M8RYE>&5C0V]M;6%N9"AC;61)1"P@54DL('!A<F%M*3L@?0H)"6-A=&-H*&4I
M('L@:68@*'1H:7,N8V]N9FEG+F1E8G5G*2![(&%L97)T*&4@*R`B7&Y<;F)Y
M(&5X96-#;VUM86YD*"(@*R!C;61)1"`K("(I.R(I.R!]('T*"7T*"71H:7,N
M=7!D871E5&]O;&)A<B@I.PH)<F5T=7)N(&9A;'-E.PI].PH*+RHJ($$@9V5N
M97)I8R!E=F5N="!H86YD;&5R(&9O<B!T:&EN9W,@=&AA="!H87!P96X@:6X@
M=&AE($E&4D%-12=S(&1O8W5M96YT+@H@*B!4:&ES(&9U;F-T:6]N(&%L<V\@
M:&%N9&QE<R!K97D@8FEN9&EN9W,N("HO"DA434Q!<F5A+G!R;W1O='EP92Y?
M961I=&]R179E;G0@/2!F=6YC=&EO;BAE=BD@>PH)=F%R(&5D:71O<B`]('1H
M:7,["@EV87(@:V5Y179E;G0@/2`H2%1-3$%R96$N:7-?:64@)B8@978N='EP
M92`]/2`B:V5Y9&]W;B(I('Q\("@A2%1-3$%R96$N:7-?:64@)B8@978N='EP
M92`]/2`B:V5Y<')E<W,B*3L*"@EI9B`H:V5Y179E;G0I"@D)9F]R("AV87(@
M:2!I;B!E9&ET;W(N<&QU9VEN<RD@>PH)"0EV87(@<&QU9VEN(#T@961I=&]R
M+G!L=6=I;G-;:5TN:6YS=&%N8V4["@D)"6EF("AT>7!E;V8@<&QU9VEN+F]N
M2V5Y4')E<W,@/3T@(F9U;F-T:6]N(BD*"0D)"6EF("AP;'5G:6XN;VY+97E0
M<F5S<RAE=BDI"@D)"0D)<F5T=7)N(&9A;'-E.PH)"7T*"6EF("AK97E%=F5N
M="`F)B!E=BYC=')L2V5Y("8F("%E=BYA;'1+97DI('L*"0EV87(@<V5L(#T@
M;G5L;#L*"0EV87(@<F%N9V4@/2!N=6QL.PH)"79A<B!K97D@/2!3=')I;F<N
M9G)O;4-H87)#;V1E*$A434Q!<F5A+FES7VEE(#\@978N:V5Y0V]D92`Z(&5V
M+F-H87)#;V1E*2YT;TQO=V5R0V%S92@I.PH)"79A<B!C;60@/2!N=6QL.PH)
M"79A<B!V86QU92`](&YU;&P["@D)<W=I=&-H("AK97DI('L*"0D@("`@8V%S
M92`G82<Z"@D)"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0D)"2\O($M%62!S
M96QE8W0@86QL"@D)"0ES96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*"0D)
M"7-E;"YR96UO=F5!;&Q286YG97,H*3L*"0D)"7)A;F=E(#T@=&AI<RY?8W)E
M871E4F%N9V4H*3L*"0D)"7)A;F=E+G-E;&5C=$YO9&5#;VYT96YT<RAT:&ES
M+E]D;V,N8F]D>2D["@D)"0ES96PN861D4F%N9V4H<F%N9V4I.PH)"0D)2%1-
M3$%R96$N7W-T;W!%=F5N="AE=BD["@D)"7T*"0D)8G)E86L["@H)"0DO+R!S
M:6UP;&4@:V5Y(&-O;6UA;F1S(&9O;&QO=PH*"0D@("`@8V%S92`G8B<Z(&-M
M9"`](")B;VQD(CL@8G)E86L["@D)("`@(&-A<V4@)VDG.B!C;60@/2`B:71A
M;&EC(CL@8G)E86L["@D)("`@(&-A<V4@)W4G.B!C;60@/2`B=6YD97)L:6YE
M(CL@8G)E86L["@D)("`@(&-A<V4@)W,G.B!C;60@/2`B<W1R:6ME=&AR;W5G
M:"([(&)R96%K.PH)"2`@("!C87-E("=L)SH@8VUD(#T@(FIU<W1I9GEL969T
M(CL@8G)E86L["@D)("`@(&-A<V4@)V4G.B!C;60@/2`B:G5S=&EF>6-E;G1E
M<B([(&)R96%K.PH)"2`@("!C87-E("=R)SH@8VUD(#T@(FIU<W1I9GER:6=H
M="([(&)R96%K.PH)"2`@("!C87-E("=J)SH@8VUD(#T@(FIU<W1I9GEF=6QL
M(CL@8G)E86L["@D)("`@(&-A<V4@)WHG.B!C;60@/2`B=6YD;R([(&)R96%K
M.PH)"2`@("!C87-E("=Y)SH@8VUD(#T@(G)E9&\B.R!B<F5A:SL*"0D@("`@
M8V%S92`G=B<Z(&EF("A(5$U,07)E82YI<U]I92!\?"!E9&ET;W(N8V]N9FEG
M+FAT;6QA<F5A4&%S=&4I('L@8VUD(#T@(G!A<W1E(CL@?2!B<F5A:SL*"0D@
M("`@8V%S92`G;B<Z(&-M9"`](")F;W)M871B;&]C:R([('9A;'5E(#T@2%1-
M3$%R96$N:7-?:64@/R`B/'`^(B`Z(")P(CL@8G)E86L["@H)"2`@("!C87-E
M("<P)SH@8VUD(#T@(FMI;&QW;W)D(CL@8G)E86L["@H)"0DO+R!H96%D:6YG
M<PH)"2`@("!C87-E("<Q)SH*"0D@("`@8V%S92`G,B<Z"@D)("`@(&-A<V4@
M)S,G.@H)"2`@("!C87-E("<T)SH*"0D@("`@8V%S92`G-2<Z"@D)("`@(&-A
M<V4@)S8G.@H)"0EC;60@/2`B9F]R;6%T8FQO8VLB.PH)"0EV86QU92`](")H
M(B`K(&ME>3L*"0D):68@*$A434Q!<F5A+FES7VEE*0H)"0D)=F%L=64@/2`B
M/"(@*R!V86QU92`K("(^(CL*"0D)8G)E86L["@D)?0H)"6EF("AC;60I('L*
M"0D)+R\@97AE8W5T92!S:6UP;&4@8V]M;6%N9`H)"0ET:&ES+F5X96-#;VUM
M86YD*&-M9"P@9F%L<V4L('9A;'5E*3L*"0D)2%1-3$%R96$N7W-T;W!%=F5N
M="AE=BD["@D)?0H)?0H)96QS92!I9B`H:V5Y179E;G0I('L*"0DO+R!O=&AE
M<B!K97ES(&AE<F4*"0ES=VET8V@@*&5V+FME>4-O9&4I('L*"0D@("`@8V%S
M92`Q,SH@+R\@2T59(&5N=&5R"@D)"6EF("A(5$U,07)E82YI<U]G96-K;R`F
M)B`A978N<VAI9G1+97DI('L*"0D)"71H:7,N9&]M7V-H96-K26YS97)T4"@I
M.PH)"0D)2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["@D)"7T*"0D)8G)E86L[
M"@D)("`@(&-A<V4@.#H@+R\@2T59(&)A8VMS<&%C90H)"2`@("!C87-E(#0V
M.B`O+R!+15D@9&5L971E"@D)"6EF("A(5$U,07)E82YI<U]G96-K;R`F)B`A
M978N<VAI9G1+97DI('L*"0D)"6EF("AT:&ES+F1O;5]C:&5C:T)A8VMS<&%C
M92@I*0H)"0D)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"0E](&5L<V4@
M:68@*$A434Q!<F5A+FES7VEE*2!["@D)"0EI9B`H=&AI<RYI95]C:&5C:T)A
M8VMS<&%C92@I*0H)"0D)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"0E]
M"@D)"6)R96%K.PH)"7T*"7T*"@DO+R!U<&1A=&4@=&AE('1O;VQB87(@<W1A
M=&4@869T97(@<V]M92!T:6UE"@EI9B`H961I=&]R+E]T:6UE<E1O;VQB87(I
M('L*"0EC;&5A<E1I;65O=70H961I=&]R+E]T:6UE<E1O;VQB87(I.PH)?0H)
M961I=&]R+E]T:6UE<E1O;VQB87(@/2!S9714:6UE;W5T*&9U;F-T:6]N*"D@
M>PH)"65D:71O<BYU<&1A=&54;V]L8F%R*"D["@D)961I=&]R+E]T:6UE<E1O
M;VQB87(@/2!N=6QL.PH)?2P@-3`I.PI].PH*2%1-3$%R96$N<')O=&]T>7!E
M+G-C<F]L;%1O0V%R970@/2!F=6YC=&EO;B@I('L*"79A<@H)"64@/2!T:&ES
M+F=E=%!A<F5N=$5L96UE;G0H*2P*"0EW(#T@=&AI<RY?:69R86UE+F-O;G1E
M;G17:6YD;W<L"@D):"`]('<N:6YN97)(96EG:'0@?'P@=RYH96EG:'0L"@D)
M9"`]('1H:7,N7V1O8RP*"0ET(#T@9"YD;V-U;65N=$5L96UE;G0N<V-R;VQL
M5&]P('Q\(&0N8F]D>2YS8W)O;&Q4;W`["@EI9B`H='EP96]F(&@@/3T@(G5N
M9&5F:6YE9"(I"@D)<F5T=7)N(&9A;'-E.PH):68@*&4N;V9F<V5T5&]P(#X@
M:"`K('0I"@D)=RYS8W)O;&Q4;RAE+F]F9G-E=$QE9G0L(&4N;V9F<V5T5&]P
M("T@:"`K(&4N;V9F<V5T2&5I9VAT*3L*?3L*"DA434Q!<F5A+G!R;W1O='EP
M92YC;VYV97)T3F]D92`](&9U;F-T:6]N*&5L+"!N97=486=.86UE*2!["@EV
M87(@;F5W96P@/2!T:&ES+E]D;V,N8W)E871E16QE;65N="AN97=486=.86UE
M*2P@<"`](&5L+G!A<F5N=$YO9&4["@EW:&EL92`H96PN9FER<W1#:&EL9"D*
M"0EN97=E;"YA<'!E;F1#:&EL9"AE;"YF:7)S=$-H:6QD*3L*"7`N:6YS97)T
M0F5F;W)E*&YE=V5L+"!E;"D["@EP+G)E;6]V94-H:6QD*&5L*3L*"7)E='5R
M;B!N97=E;#L*?3L*"DA434Q!<F5A+G!R;W1O='EP92YI95]C:&5C:T)A8VMS
M<&%C92`](&9U;F-T:6]N*"D@>PH)=F%R('-E;"`]('1H:7,N7V=E=%-E;&5C
M=&EO;B@I.PH)=F%R(')A;F=E(#T@=&AI<RY?8W)E871E4F%N9V4H<V5L*3L*
M"79A<B!R,B`](')A;F=E+F1U<&QI8V%T92@I.PH)<C(N;6]V95-T87)T*")C
M:&%R86-T97(B+"`M,2D["@EV87(@82`]('(R+G!A<F5N=$5L96UE;G0H*3L*
M"6EF("AA("$](')A;F=E+G!A<F5N=$5L96UE;G0H*2`F)@H)("`@("]>820O
M:2YT97-T*&$N=&%G3F%M92DI('L*"0ER,BYC;VQL87!S92AT<G5E*3L*"0ER
M,BYM;W9E16YD*")C:&%R86-T97(B+"`Q*3L*"0ER,BYP87-T94A434PH)R<I
M.PH)"7(R+G-E;&5C="@I.PH)"7)E='5R;B!T<G5E.PH)?0I].PH*2%1-3$%R
M96$N<')O=&]T>7!E+F1O;5]C:&5C:T)A8VMS<&%C92`](&9U;F-T:6]N*"D@
M>PH)=F%R('-E;&8@/2!T:&ES.PH)<V5T5&EM96]U="AF=6YC=&EO;B@I('L*
M"0EV87(@<V5L(#T@<V5L9BY?9V5T4V5L96-T:6]N*"D["@D)=F%R(')A;F=E
M(#T@<V5L9BY?8W)E871E4F%N9V4H<V5L*3L*"0EV87(@4T,@/2!R86YG92YS
M=&%R=$-O;G1A:6YE<CL*"0EV87(@4T\@/2!R86YG92YS=&%R=$]F9G-E=#L*
M"0EV87(@14,@/2!R86YG92YE;F1#;VYT86EN97(["@D)=F%R($5/(#T@<F%N
M9V4N96YD3V9F<V5T.PH)"79A<B!N97=R(#T@4T,N;F5X=%-I8FQI;F<["@D)
M:68@*%-#+FYO9&54>7!E(#T](#,I"@D)"5-#(#T@4T,N<&%R96YT3F]D93L*
M"0EI9B`H(2]<4R\N=&5S="A30RYT86=.86UE*2D@>PH)"0EV87(@<"`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H(G`B*3L*"0D)=VAI;&4@*%-#+F9I<G-T
M0VAI;&0I"@D)"0EP+F%P<&5N9$-H:6QD*%-#+F9I<G-T0VAI;&0I.PH)"0E3
M0RYP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AP+"!30RD["@D)"5-#+G!A<F5N
M=$YO9&4N<F5M;W9E0VAI;&0H4T,I.PH)"0EV87(@<B`](')A;F=E+F-L;VYE
M4F%N9V4H*3L*"0D)<BYS9713=&%R=$)E9F]R92AN97=R*3L*"0D)<BYS971%
M;F1!9G1E<BAN97=R*3L*"0D)<BYE>'1R86-T0V]N=&5N=',H*3L*"0D)<V5L
M+G)E;6]V94%L;%)A;F=E<R@I.PH)"0ES96PN861D4F%N9V4H<BD["@D)?0H)
M?2P@,3`I.PI].PH*2%1-3$%R96$N<')O=&]T>7!E+F1O;5]C:&5C:TEN<V5R
M=%`@/2!F=6YC=&EO;B@I('L*"79A<B!I+"!30RP@;&5F="P@<FEG:'0L('(R
M+`H)"7-E;"`@(#T@=&AI<RY?9V5T4V5L96-T:6]N*"DL"@D)<B`@("`@/2!T
M:&ES+E]C<F5A=&5286YG92AS96PI+`H)"7`@("`@(#T@=&AI<RYG971!;&Q!
M;F-E<W1O<G,H*2P*"0EB;&]C:R`](&YU;&PL"@D)9&]C("`@/2!T:&ES+E]D
M;V,L"@D)8F]D>2`@/2!D;V,N8F]D>3L*"@EF;W(@*&D@/2`P.R!I(#P@<"YL
M96YG=&@[("LK:2D*"0EI9B`H2%1-3$%R96$N:7-";&]C:T5L96UE;G0H<%MI
M72D@)B8@(2]B;V1Y?&AT;6PO:2YT97-T*'!;:5TN=&%G3F%M92DI('L*"0D)
M8FQO8VL@/2!P6VE=.PH)"0EB<F5A:SL*"0E]"@H):68@*"%R+F-O;&QA<'-E
M9"D*"0ER+F1E;&5T94-O;G1E;G1S*"D["@ES96PN<F5M;W9E06QL4F%N9V5S
M*"D["@E30R`]('(N<W1A<G1#;VYT86EN97(["@H):68@*"%B;&]C:RD@>PH)
M"6QE9G0@/2!30SL*"0EF;W(@*&D@/2!30SL@:2`F)B!I("$](&)O9'D@)B8@
M(4A434Q!<F5A+FES0FQO8VM%;&5M96YT*&DI.R!I(#T@2%1-3$%R96$N9V5T
M4')E=DYO9&4H:2DI"@D)"6QE9G0@/2!I.PH)"7)I9VAT(#T@4T,["@D)9F]R
M("AI(#T@4T,[(&D@)B8@:2`A/2!B;V1Y("8F("%(5$U,07)E82YI<T)L;V-K
M16QE;65N="AI*3L@:2`]($A434Q!<F5A+F=E=$YE>'1.;V1E*&DI*0H)"0ER
M:6=H="`](&D["@D):68@*&QE9G0@(3T@8F]D>2`F)B!R:6=H="`A/2!B;V1Y
M*2!["@D)"7(R(#T@<BYC;&]N95)A;F=E*"D["@D)"7(R+G-E=%-T87)T0F5F
M;W)E*&QE9G0I.PH)"0ER,BYS=7)R;W5N9$-O;G1E;G1S*&)L;V-K(#T@9&]C
M+F-R96%T945L96UE;G0H(G`B*2D["@D)"6EF("@A+UQ3+RYT97-T*$A434Q!
M<F5A+F=E=$EN;F5R5&5X="AB;&]C:RDI*0H)"0D)8FQO8VLN:6YN97)(5$U,
M(#T@(CQB<B`O/B(["@D)"6)L;V-K+FYO<FUA;&EZ92@I.PH)"0ER+G-E=$5N
M9$%F=&5R*')I9VAT*3L*"0D)<BYS=7)R;W5N9$-O;G1E;G1S*&)L;V-K(#T@
M9&]C+F-R96%T945L96UE;G0H(G`B*2D["@D)"6EF("@A+UQ3+RYT97-T*$A4
M34Q!<F5A+F=E=$EN;F5R5&5X="AB;&]C:RDI*0H)"0D)8FQO8VLN:6YN97)(
M5$U,(#T@(CQB<B`O/B(["@D)"6)L;V-K+FYO<FUA;&EZ92@I.PH)"7T@96QS
M92!["@D)"7(@/2!D;V,N8W)E871E4F%N9V4H*3L*"0D)<BYS9713=&%R="AB
M;V1Y+"`P*3L*"0D)<BYS971%;F0H8F]D>2P@,"D["@D)"7(N:6YS97)T3F]D
M92AB;&]C:R`](&1O8RYC<F5A=&5%;&5M96YT*")P(BDI.PH)"0EB;&]C:RYI
M;FYE<DA434P@/2`B/&)R("\^(CL*"0E]"@D)<BYS96QE8W1.;V1E0V]N=&5N
M=',H8FQO8VLI.PH)?2!E;'-E('L*"0ER+G-E=$5N9$%F=&5R*&)L;V-K*3L*
M"0EV87(@9&8@/2!R+F5X=')A8W1#;VYT96YT<R@I+"!L969T7V5M<'1Y(#T@
M9F%L<V4["@D):68@*"$O7%,O+G1E<W0H8FQO8VLN:6YN97)(5$U,*2D@>PH)
M"0EB;&]C:RYI;FYE<DA434P@/2`B/&)R("\^(CL*"0D);&5F=%]E;7!T>2`]
M('1R=64["@D)?0H)"7`@/2!D9BYF:7)S=$-H:6QD.PH)"6EF("AP*2!["@D)
M"6EF("@A+UQ3+RYT97-T*$A434Q!<F5A+F=E=$EN;F5R5&5X="AP*2DI('L*
M(`D)"0EI9B`H+UYH6S$M-ETD+VDN=&5S="AP+G1A9TYA;64I*0H@"0D)"0EP
M(#T@=&AI<RYC;VYV97)T3F]D92AP+"`B<"(I.PH)"0D)<"YI;FYE<DA434P@
M/2`B/&)R("\^(CL*"0D)?0H)"0EI9B`H+UYL:20O:2YT97-T*'`N=&%G3F%M
M92D@)B8@;&5F=%]E;7!T>2`F)B`A8FQO8VLN;F5X=%-I8FQI;F<I('L*"0D)
M"6QE9G0@/2!B;&]C:RYP87)E;G1.;V1E.PH)"0D);&5F="YR96UO=F5#:&EL
M9"AB;&]C:RD["@D)"0ER+G-E=$5N9$%F=&5R*&QE9G0I.PH)"0D)<BYC;VQL
M87!S92AF86QS92D["@D)"0EP(#T@=&AI<RYC;VYV97)T3F]D92AP+"`O7EMU
M;UUL)"]I+G1E<W0H;&5F="YP87)E;G1.;V1E+G1A9TYA;64I(#\@(FQI(B`Z
M(")P(BD["@D)"7T*"0D)<BYI;G-E<G1.;V1E*&1F*3L*"0D)<BYS96QE8W1.
M;V1E0V]N=&5N=',H<"D["@D)?0H)?0H)<BYC;VQL87!S92AT<G5E*3L*"7-E
M;"YA9&1286YG92AR*3L*"71H:7,N9F]R8V52961R87<H*3L*"71H:7,N<V-R
M;VQL5&]#87)E="@I.PI].PH*+R\@<F5T<FEE=F4@=&AE($A434P*2%1-3$%R
M96$N<')O=&]T>7!E+F=E=$A434P@/2!F=6YC=&EO;B@I('L*"7-W:71C:"`H
M=&AI<RY?961I=$UO9&4I('L*"2`@("!C87-E(")W>7-I=WEG(B`@.@H)"6EF
M("@A=&AI<RYC;VYF:6<N9G5L;%!A9V4I('L*"0D)<F5T=7)N($A434Q!<F5A
M+F=E=$A434PH=&AI<RY?9&]C+F)O9'DL(&9A;'-E+"!T:&ES*3L*"0E](&5L
M<V4*"0D)<F5T=7)N('1H:7,N9&]C='EP92`K(")<;B(@*R!(5$U,07)E82YG
M971(5$U,*'1H:7,N7V1O8RYD;V-U;65N=$5L96UE;G0L('1R=64L('1H:7,I
M.PH)("`@(&-A<V4@(G1E>'1M;V1E(B`Z(')E='5R;B!T:&ES+E]T97AT07)E
M82YV86QU93L*"2`@("!D969A=6QT"2`@("`Z(&%L97)T*")-;V1E(#PB("L@
M;6]D92`K("(^(&YO="!D969I;F5D(2(I.PH)?0H)<F5T=7)N(&9A;'-E.PI]
M.PH*+R\@<F5T<FEE=F4@=&AE($A434P@*&9A<W1E<W0@=F5R<VEO;BP@8G5T
M('5S97,@:6YN97)(5$U,*0I(5$U,07)E82YP<F]T;W1Y<&4N9V5T26YN97)(
M5$U,(#T@9G5N8W1I;VXH*2!["@ES=VET8V@@*'1H:7,N7V5D:71-;V1E*2![
M"@D@("`@8V%S92`B=WES:7=Y9R(@(#H*"0EI9B`H(71H:7,N8V]N9FEG+F9U
M;&Q086=E*0H)"0ER971U<FX@=&AI<RY?9&]C+F)O9'DN:6YN97)(5$U,.PH)
M"65L<V4*"0D)<F5T=7)N('1H:7,N9&]C='EP92`K(")<;B(@*R!T:&ES+E]D
M;V,N9&]C=6UE;G1%;&5M96YT+FEN;F5R2%1-3#L*"2`@("!C87-E(")T97AT
M;6]D92(@.B!R971U<FX@=&AI<RY?=&5X=$%R96$N=F%L=64["@D@("`@9&5F
M875L=`D@("`@.B!A;&5R="@B36]D92`\(B`K(&UO9&4@*R`B/B!N;W0@9&5F
M:6YE9"$B*3L*"7T*"7)E='5R;B!F86QS93L*?3L*"B\O(&-O;7!L971E;'D@
M8VAA;F=E('1H92!(5$U,(&EN<VED90I(5$U,07)E82YP<F]T;W1Y<&4N<V5T
M2%1-3"`](&9U;F-T:6]N*&AT;6PI('L*"7-W:71C:"`H=&AI<RY?961I=$UO
M9&4I('L*"2`@("!C87-E(")W>7-I=WEG(B`@.@H)"6EF("@A=&AI<RYC;VYF
M:6<N9G5L;%!A9V4I"@D)"71H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"`](&AT
M;6P["@D)96QS90H)"0DO+R!T:&ES+E]D;V,N9&]C=6UE;G1%;&5M96YT+FEN
M;F5R2%1-3"`](&AT;6P["@D)"71H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"`]
M(&AT;6P["@D)8G)E86L["@D@("`@8V%S92`B=&5X=&UO9&4B(#H@=&AI<RY?
M=&5X=$%R96$N=F%L=64@/2!H=&UL.R!B<F5A:SL*"2`@("!D969A=6QT"2`@
M("`Z(&%L97)T*")-;V1E(#PB("L@;6]D92`K("(^(&YO="!D969I;F5D(2(I
M.PH)?0H)<F5T=7)N(&9A;'-E.PI].PH*+R\@<V5T<R!T:&4@9VEV96X@9&]C
M='EP92`H=7-E9G5L('=H96X@8V]N9FEG+F9U;&Q086=E(&ES('1R=64I"DA4
M34Q!<F5A+G!R;W1O='EP92YS971$;V-T>7!E(#T@9G5N8W1I;VXH9&]C='EP
M92D@>PH)=&AI<RYD;V-T>7!E(#T@9&]C='EP93L*?3L*"B\J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH*("H@
M($-A=&5G;W)Y.B!55$E,2519($953D-424].4PH@*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ+PH*+R\@=F%R
M:6%B;&4@=7-E9"!T;R!P87-S('1H92!O8FIE8W0@=&\@=&AE('!O<'5P(&5D
M:71O<B!W:6YD;W<N"DA434Q!<F5A+E]O8FIE8W0@/2!N=6QL.PH*+R\@9G5N
M8W1I;VX@=&AA="!R971U<FYS(&$@8VQO;F4@;V8@=&AE(&=I=F5N(&]B:F5C
M=`I(5$U,07)E82YC;&]N94]B:F5C="`](&9U;F-T:6]N*&]B:BD@>PH):68@
M*"%O8FHI(')E='5R;B!N=6QL.PH)=F%R(&YE=T]B:B`](&YE=R!/8FIE8W0[
M"@H)+R\@8VAE8VL@9F]R(&%R<F%Y(&]B:F5C=',*"6EF("AO8FHN8V]N<W1R
M=6-T;W(N=&]3=')I;F<H*2YI;F1E>$]F*")F=6YC=&EO;B!!<G)A>2@B*2`]
M/2`Q*2!["@D);F5W3V)J(#T@;V)J+F-O;G-T<G5C=&]R*"D["@E]"@H)+R\@
M8VAE8VL@9F]R(&9U;F-T:6]N(&]B:F5C=',@*&%S('5S=6%L+"!)12!I<R!F
M=6-K960@=7`I"@EI9B`H;V)J+F-O;G-T<G5C=&]R+G1O4W1R:6YG*"DN:6YD
M97A/9B@B9G5N8W1I;VX@1G5N8W1I;VXH(BD@/3T@,2D@>PH)"6YE=T]B:B`]
M(&]B:CL@+R\@:G5S="!C;W!Y(')E9F5R96YC92!T;R!I=`H)?2!E;'-E(&9O
M<B`H=F%R(&X@:6X@;V)J*2!["@D)=F%R(&YO9&4@/2!O8FI;;ET["@D):68@
M*'1Y<&5O9B!N;V1E(#T]("=O8FIE8W0G*2![(&YE=T]B:EMN72`]($A434Q!
M<F5A+F-L;VYE3V)J96-T*&YO9&4I.R!]"@D)96QS92`@("`@("`@("`@("`@
M("`@("`@("`@("![(&YE=T]B:EMN72`](&YO9&4[('T*"7T*"@ER971U<FX@
M;F5W3V)J.PI].PH*+R\@1DE8344A(2$@=&AI<R!S:&]U;&0@<F5T=7)N(&9A
M;'-E(&9O<B!)12`\(#4N-0I(5$U,07)E82YC:&5C:U-U<'!O<G1E9$)R;W=S
M97(@/2!F=6YC=&EO;B@I('L*"6EF("A(5$U,07)E82YI<U]G96-K;RD@>PH)
M"6EF("AN879I9V%T;W(N<')O9'5C=%-U8B`\(#(P,#(Q,C`Q*2!["@D)"6%L
M97)T*")9;W4@;F5E9"!A="!L96%S="!-;WII;&QA+3$N,R!!;'!H82Y<;B(@
M*PH)"0D@("`@("`B4V]R<GDL('EO=7(@1V5C:V\@:7,@;F]T('-U<'!O<G1E
M9"XB*3L*"0D)<F5T=7)N(&9A;'-E.PH)"7T*"0EI9B`H;F%V:6=A=&]R+G!R
M;V1U8W13=6(@/"`R,#`S,#(Q,"D@>PH)"0EA;&5R="@B36]Z:6QL82`\(#$N
M,R!"971A(&ES(&YO="!S=7!P;W)T960A7&XB("L*"0D)("`@("`@(DDG;&P@
M=')Y+"!T:&]U9V@L(&)U="!I="!M:6=H="!N;W0@=V]R:RXB*3L*"0E]"@E]
M"@ER971U<FX@2%1-3$%R96$N:7-?9V5C:V\@?'P@2%1-3$%R96$N:7-?:64[
M"GT["@HO+R!S96QE8W1I;VX@)B!R86YG97,*"B\O(')E='5R;G,@=&AE(&-U
M<G)E;G0@<V5L96-T:6]N(&]B:F5C=`I(5$U,07)E82YP<F]T;W1Y<&4N7V=E
M=%-E;&5C=&EO;B`](&9U;F-T:6]N*"D@>PH):68@*$A434Q!<F5A+FES7VEE
M*2!["@D)<F5T=7)N('1H:7,N7V1O8RYS96QE8W1I;VX["@E](&5L<V4@>PH)
M"7)E='5R;B!T:&ES+E]I9G)A;64N8V]N=&5N=%=I;F1O=RYG971396QE8W1I
M;VXH*3L*"7T*?3L*"B\O(')E='5R;G,@82!R86YG92!F;W(@=&AE(&-U<G)E
M;G0@<V5L96-T:6]N"DA434Q!<F5A+G!R;W1O='EP92Y?8W)E871E4F%N9V4@
M/2!F=6YC=&EO;BAS96PI('L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7)E
M='5R;B!S96PN8W)E871E4F%N9V4H*3L*"7T@96QS92!["@D)=&AI<RYF;V-U
M<T5D:71O<B@I.PH)"6EF("AT>7!E;V8@<V5L("$](")U;F1E9FEN960B*2![
M"@D)"71R>2!["@D)"0ER971U<FX@<V5L+F=E=%)A;F=E070H,"D["@D)"7T@
M8V%T8V@H92D@>PH)"0D)<F5T=7)N('1H:7,N7V1O8RYC<F5A=&5286YG92@I
M.PH)"0E]"@D)?2!E;'-E('L*"0D)<F5T=7)N('1H:7,N7V1O8RYC<F5A=&52
M86YG92@I.PH)"7T*"7T*?3L*"B\O(&5V96YT(&AA;F1L:6YG"@I(5$U,07)E
M82Y?861D179E;G0@/2!F=6YC=&EO;BAE;"P@979N86UE+"!F=6YC*2!["@EI
M9B`H2%1-3$%R96$N:7-?:64I('L*"0EE;"YA='1A8VA%=F5N="@B;VXB("L@
M979N86UE+"!F=6YC*3L*"7T@96QS92!["@D)96PN861D179E;G1,:7-T96YE
M<BAE=FYA;64L(&9U;F,L('1R=64I.PH)?0I].PH*2%1-3$%R96$N7V%D9$5V
M96YT<R`](&9U;F-T:6]N*&5L+"!E=G,L(&9U;F,I('L*"69O<B`H=F%R(&D@
M/2!E=G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0E(5$U,07)E82Y?861D179E
M;G0H96PL(&5V<UMI72P@9G5N8RD["@E]"GT["@I(5$U,07)E82Y?<F5M;W9E
M179E;G0@/2!F=6YC=&EO;BAE;"P@979N86UE+"!F=6YC*2!["@EI9B`H2%1-
M3$%R96$N:7-?:64I('L*"0EE;"YD971A8VA%=F5N="@B;VXB("L@979N86UE
M+"!F=6YC*3L*"7T@96QS92!["@D)96PN<F5M;W9E179E;G1,:7-T96YE<BAE
M=FYA;64L(&9U;F,L('1R=64I.PH)?0I].PH*2%1-3$%R96$N7W)E;6]V945V
M96YT<R`](&9U;F-T:6]N*&5L+"!E=G,L(&9U;F,I('L*"69O<B`H=F%R(&D@
M/2!E=G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0E(5$U,07)E82Y?<F5M;W9E
M179E;G0H96PL(&5V<UMI72P@9G5N8RD["@E]"GT["@I(5$U,07)E82Y?<W1O
M<$5V96YT(#T@9G5N8W1I;VXH978I('L*"6EF("A(5$U,07)E82YI<U]I92D@
M>PH)"65V+F-A;F-E;$)U8F)L92`]('1R=64["@D)978N<F5T=7)N5F%L=64@
M/2!F86QS93L*"7T@96QS92!["@D)978N<')E=F5N=$1E9F%U;'0H*3L*"0EE
M=BYS=&]P4')O<&%G871I;VXH*3L*"7T*?3L*"DA434Q!<F5A+E]R96UO=F5#
M;&%S<R`](&9U;F-T:6]N*&5L+"!C;&%S<TYA;64I('L*"6EF("@A*&5L("8F
M(&5L+F-L87-S3F%M92DI('L*"0ER971U<FX["@E]"@EV87(@8VQS(#T@96PN
M8VQA<W-.86UE+G-P;&ET*"(@(BD["@EV87(@87(@/2!N97<@07)R87DH*3L*
M"69O<B`H=F%R(&D@/2!C;',N;&5N9W1H.R!I(#X@,#LI('L*"0EI9B`H8VQS
M6RTM:5T@(3T@8VQA<W-.86UE*2!["@D)"6%R6V%R+FQE;F=T:%T@/2!C;'-;
M:5T["@D)?0H)?0H)96PN8VQA<W-.86UE(#T@87(N:F]I;B@B("(I.PI].PH*
M2%1-3$%R96$N7V%D9$-L87-S(#T@9G5N8W1I;VXH96PL(&-L87-S3F%M92D@
M>PH)+R\@<F5M;W9E('1H92!C;&%S<R!F:7)S="P@:68@86QR96%D>2!T:&5R
M90H)2%1-3$%R96$N7W)E;6]V94-L87-S*&5L+"!C;&%S<TYA;64I.PH)96PN
M8VQA<W-.86UE("L]("(@(B`K(&-L87-S3F%M93L*?3L*"DA434Q!<F5A+E]H
M87-#;&%S<R`](&9U;F-T:6]N*&5L+"!C;&%S<TYA;64I('L*"6EF("@A*&5L
M("8F(&5L+F-L87-S3F%M92DI('L*"0ER971U<FX@9F%L<V4["@E]"@EV87(@
M8VQS(#T@96PN8VQA<W-.86UE+G-P;&ET*"(@(BD["@EF;W(@*'9A<B!I(#T@
M8VQS+FQE;F=T:#L@:2`^(#`[*2!["@D):68@*&-L<ULM+6E=(#T](&-L87-S
M3F%M92D@>PH)"0ER971U<FX@=')U93L*"0E]"@E]"@ER971U<FX@9F%L<V4[
M"GT["@I(5$U,07)E82Y?8FQO8VM486=S(#T@(B!B;V1Y(&9O<FT@=&5X=&%R
M96$@9FEE;&1S970@=6P@;VP@9&P@;&D@9&EV("(@*PHB<"!H,2!H,B!H,R!H
M-"!H-2!H-B!Q=6]T92!P<F4@=&%B;&4@=&AE860@(B`K"B)T8F]D>2!T9F]O
M="!T<B!T9"!I9G)A;64@861D<F5S<R`B.PI(5$U,07)E82YI<T)L;V-K16QE
M;65N="`](&9U;F-T:6]N*&5L*2!["@ER971U<FX@96P@)B8@96PN;F]D951Y
M<&4@/3T@,2`F)B`H2%1-3$%R96$N7V)L;V-K5&%G<RYI;F1E>$]F*"(@(B`K
M(&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*2`K("(@(BD@(3T@+3$I.PI].PH*
M2%1-3$%R96$N7V-L;W-I;F=486=S(#T@(B!H96%D('-C<FEP="!S='EL92!D
M:78@<W!A;B!T<B!T9"!T8F]D>2!T86)L92!E;2!S=')O;F<@8B!I(&-O9&4@
M8VET92!D9FX@86)B<B!A8W)O;GEM(&9O;G0@82!T:71L92`B.PI(5$U,07)E
M82YN965D<T-L;W-I;F=486<@/2!F=6YC=&EO;BAE;"D@>PH)<F5T=7)N(&5L
M("8F(&5L+FYO9&54>7!E(#T](#$@)B8@*$A434Q!<F5A+E]C;&]S:6YG5&%G
M<RYI;F1E>$]F*"(@(B`K(&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*2`K("(@
M(BD@(3T@+3$I.PI].PH*+R\@<&5R9F]R;7,@2%1-3"!E;F-O9&EN9R!O9B!S
M;VUE(&=I=F5N('-T<FEN9PI(5$U,07)E82YH=&UL16YC;V1E(#T@9G5N8W1I
M;VXH<W1R*2!["@DO+R!W92!D;VXG="!N965D(')E9V5X<"!F;W(@=&AA="P@
M8G5T+BX@<V\@8F4@:70@9F]R(&YO=RX*"7-T<B`]('-T<BYR97!L86-E*"\F
M+VEG+"`B)F%M<#LB*3L*"7-T<B`]('-T<BYR97!L86-E*"\\+VEG+"`B)FQT
M.R(I.PH)<W1R(#T@<W1R+G)E<&QA8V4H+SXO:6<L("(F9W0[(BD["@ES='(@
M/2!S='(N<F5P;&%C92@O7'@R,B]I9RP@(B9Q=6]T.R(I.PH)+R\@7'@R,B!M
M96%N<R`G(B<@+2T@=V4@=7-E(&AE>"!R97!R97IE;G1A=&EO;B!S;R!T:&%T
M('=E(&1O;B=T(&1I<W1U<F(*"2\O($I3(&-O;7!R97-S;W)S("AW96QL+"!A
M="!L96%S="!M:6YE(&9A:6QS+BX@.RD*"7)E='5R;B!S='(["GT["@HO+R!2
M971R:65V97,@=&AE($A434P@8V]D92!F<F]M('1H92!G:79E;B!N;V1E+@D@
M5&AI<R!I<R!A(')E<&QA8V5M96YT(&9O<@HO+R!G971T:6YG(&EN;F5R2%1-
M3"P@=7-I;F<@<W1A;F1A<F0@1$]-(&-A;&QS+@HO+R!7<F%P<&5R(&-A=&-H
M(&$@36]Z:6QL82U%>&-E<'1I;VX@=VET:"!N;VX@=V5L;"!F;W)M960@:'1M
M;"!S;W5R8V4@8V]D90I(5$U,07)E82YG971(5$U,(#T@9G5N8W1I;VXH<F]O
M="P@;W5T<'5T4F]O="P@961I=&]R*7L*("`@('1R>7L*("`@("`@("!R971U
M<FX@2%1-3$%R96$N9V5T2%1-3%=R87!P97(H<F]O="QO=71P=712;V]T+&5D
M:71O<BD["B`@("!]"B`@("!C871C:"AE*7L*("`@("`@("!A;&5R="@G66]U
M<B!$;V-U;65N="!I<R!N;W0@=V5L;"!F;W)M960N($-H96-K($IA=F%38W)I
M<'0@8V]N<V]L92!F;W(@9&5T86EL<RXG*3L*("`@("`@("!R971U<FX@961I
M=&]R+E]I9G)A;64N8V]N=&5N=%=I;F1O=RYD;V-U;65N="YB;V1Y+FEN;F5R
M2%1-3#L*("`@('T*?0H*2%1-3$%R96$N9V5T2%1-3%=R87!P97(@/2!F=6YC
M=&EO;BAR;V]T+"!O=71P=712;V]T+"!E9&ET;W(I('L*"79A<B!H=&UL(#T@
M(B(["@ES=VET8V@@*')O;W0N;F]D951Y<&4I('L*"2`@("!C87-E(#$Z("\O
M($YO9&4N14Q%345.5%].3T1%"@D@("`@8V%S92`Q,3H@+R\@3F]D92Y$3T-5
M345.5%]&4D%'345.5%].3T1%"@D)=F%R(&-L;W-E9#L*"0EV87(@:3L*"0EV
M87(@<F]O=%]T86<@/2`H<F]O="YN;V1E5'EP92`]/2`Q*2`_(')O;W0N=&%G
M3F%M92YT;TQO=V5R0V%S92@I(#H@)R<["@D):68@*')O;W1?=&%G(#T]("=B
M<B<@)B8@(7)O;W0N;F5X=%-I8FQI;F<I"@D)"6)R96%K.PH)"6EF("AO=71P
M=712;V]T*0H)"0EO=71P=712;V]T(#T@(2AE9&ET;W(N8V]N9FEG+FAT;6Q2
M96UO=F5486=S("8F(&5D:71O<BYC;VYF:6<N:'1M;%)E;6]V951A9W,N=&5S
M="AR;V]T7W1A9RDI.PH)"6EF("A(5$U,07)E82YI<U]I92`F)B!R;V]T7W1A
M9R`]/2`B:&5A9"(I('L*"0D):68@*&]U='!U=%)O;W0I"@D)"0EH=&UL("L]
M("(\:&5A9#XB.PH)"0DO+R!L;W=E<F-A<VEZ90H)"0EV87(@<V%V95]M=6QT
M:6QI;F4@/2!296=%>'`N;75L=&EL:6YE.PH)"0E296=%>'`N;75L=&EL:6YE
M(#T@=')U93L*"0D)=F%R('1X="`](')O;W0N:6YN97)(5$U,+G)E<&QA8V4H
M2%1-3$%R96$N4D5?=&%G3F%M92P@9G5N8W1I;VXH<W1R+"!P,2P@<#(I('L*
M"0D)"7)E='5R;B!P,2`K('`R+G1O3&]W97)#87-E*"D["@D)"7TI.PH)"0E2
M96=%>'`N;75L=&EL:6YE(#T@<V%V95]M=6QT:6QI;F4["@D)"6AT;6P@*ST@
M='AT.PH)"0EI9B`H;W5T<'5T4F]O="D*"0D)"6AT;6P@*ST@(CPO:&5A9#XB
M.PH)"0EB<F5A:SL*"0E](&5L<V4@:68@*&]U='!U=%)O;W0I('L*"0D)8VQO
M<V5D(#T@*"$H<F]O="YH87-#:&EL9$YO9&5S*"D@?'P@2%1-3$%R96$N;F5E
M9'-#;&]S:6YG5&%G*')O;W0I*2D["@D)"6AT;6P@/2`B/"(@*R!R;V]T+G1A
M9TYA;64N=&],;W=E<D-A<V4H*3L*"0D)=F%R(&%T=')S(#T@<F]O="YA='1R
M:6)U=&5S.PH)"0EF;W(@*&D@/2`P.R!I(#P@871T<G,N;&5N9W1H.R`K*VDI
M('L*"0D)"79A<B!A(#T@871T<G,N:71E;2AI*3L*"0D)"6EF("@A82YS<&5C
M:69I960I('L*"0D)"0EC;VYT:6YU93L*"0D)"7T*"0D)"79A<B!N86UE(#T@
M82YN;V1E3F%M92YT;TQO=V5R0V%S92@I.PH)"0D):68@*"]?;6]Z7V5D:71O
M<E]B;V=U<U]N;V1E+RYT97-T*&YA;64I*2!["@D)"0D):'1M;"`]("(B.PH)
M"0D)"6)R96%K.PH)"0D)?0H)"0D):68@*"]?;6]Z?&-O;G1E;G1E9&ET86)L
M97Q?;7-H+RYT97-T*&YA;64I*2!["@D)"0D)+R\@879O:60@8V5R=&%I;B!A
M='1R:6)U=&5S"@D)"0D)8V]N=&EN=64["@D)"0E]"@D)"0EV87(@=F%L=64[
M"@D)"0EI9B`H;F%M92`A/2`B<W1Y;&4B*2!["@D)"0D)+R\@244U+C4@<F5P
M;W)T<R`R-2!W:&5N(&-E;&Q3<&%C:6YG(&ES"@D)"0D)+R\@,3L@;W1H97(@
M=F%L=65S(&UI9VAT(&)E(&1O;VUE9"!T;V\N"@D)"0D)+R\@1F]R('1H:7,@
M<F5A<V]N('=E(&5X=')A8W0@=&AE"@D)"0D)+R\@=F%L=65S(&1I<F5C=&QY
M(&9R;VT@=&AE(')O;W0@;F]D92X*"0D)"0DO+R!))VT@<W1A<G1I;F<@=&\@
M2$%412!*879A4V-R:7!T"@D)"0D)+R\@9&5V96QO<&UE;G0N("!"<F]W<V5R
M(&1I9F9E<F5N8V5S"@D)"0D)+R\@<W5C:RX*"0D)"0DO+PH)"0D)"2\O(%5S
M:6YG($=E8VMO('1H92!V86QU97,@;V8@:')E9B!A;F0@<W)C(&%R92!C;VYV
M97)T960@=&\@86)S;VQU=&4@;&EN:W,*"0D)"0DO+R!U;FQE<W,@=V4@9V5T
M('1H96T@=7-I;F<@;F]D959A;'5E*"D*"0D)"0EI9B`H='EP96]F(')O;W1;
M82YN;V1E3F%M95T@(3T@(G5N9&5F:6YE9"(@)B8@;F%M92`A/2`B:')E9B(@
M)B8@;F%M92`A/2`B<W)C(B`F)B`A+UYO;B\N=&5S="AN86UE*2D@>PH)"0D)
M"0EV86QU92`](')O;W1;82YN;V1E3F%M95T["@D)"0D)?2!E;'-E('L*"0D)
M"0D)=F%L=64@/2!A+FYO9&5686QU93L*"0D)"0D)+R\@244@<V5E;7,@;F]T
M('=I;&QI;F<@=&\@<F5T=7)N('1H92!O<FEG:6YA;"!V86QU97,@+2!I="!C
M;VYV97)T<R!T;R!A8G-O;'5T90H)"0D)"0DO+R!L:6YK<R!U<VEN9R!A+FYO
M9&5686QU92P@82YV86QU92P@82YS=')I;F=686QU92P@<F]O="YG971!='1R
M:6)U=&4H(FAR968B*0H)"0D)"0DO+R!3;R!W92!H879E('1O('-T<FEP('1H
M92!B87-E=7)L(&UA;G5A;&QY(#HM+PH)"0D)"0EI9B`H2%1-3$%R96$N:7-?
M:64@)B8@*&YA;64@/3T@(FAR968B('Q\(&YA;64@/3T@(G-R8R(I*2!["@D)
M"0D)"0EV86QU92`](&5D:71O<BYS=')I<$)A<V554DPH=F%L=64I.PH)"0D)
M"0E]"@D)"0D)?0H)"0D)?2!E;'-E('L@+R\@244@9F%I;',@=&\@<'5T('-T
M>6QE(&EN(&%T=')I8G5T97,@;&ES=`H)"0D)"2\O($9)6$U%.B!C<W-497AT
M(')E<&]R=&5D(&)Y($E%(&ES(%504$520T%310H)"0D)"79A;'5E(#T@<F]O
M="YS='EL92YC<W-497AT.PH)"0D)?0H)"0D):68@*"\H7VUO>GQ>)"DO+G1E
M<W0H=F%L=64I*2!["@D)"0D)+R\@36]Z:6QL82!R97!O<G1S('-O;64@<W!E
M8VEA;"!T86=S"@D)"0D)+R\@:&5R93L@=V4@9&]N)W0@;F5E9"!T:&5M+@H)
M"0D)"6-O;G1I;G5E.PH)"0D)?0H)"0D):'1M;"`K/2`B("(@*R!N86UE("L@
M)STB)R`K('9A;'5E("L@)R(G.PH)"0E]"@D)"6EF("AH=&UL("$]("(B*2![
M"@D)"0EH=&UL("L](&-L;W-E9"`_("(@+SXB(#H@(CXB.PH)"0E]"@D)?0H)
M"69O<B`H:2`](')O;W0N9FER<W1#:&EL9#L@:3L@:2`](&DN;F5X=%-I8FQI
M;F<I('L*"0D):'1M;"`K/2!(5$U,07)E82YG971(5$U,5W)A<'!E<BAI+"!T
M<G5E+"!E9&ET;W(I.PH)"7T*"0EI9B`H;W5T<'5T4F]O="`F)B`A8VQO<V5D
M*2!["@D)"6AT;6P@*ST@(CPO(B`K(')O;W0N=&%G3F%M92YT;TQO=V5R0V%S
M92@I("L@(CXB.PH)"7T*"0EB<F5A:SL*"2`@("!C87-E(#,Z("\O($YO9&4N
M5$585%].3T1%"@D)+R\@268@82!T97AT(&YO9&4@:7,@86QO;F4@:6X@86X@
M96QE;65N="!A;F0@86QL('-P86-E<RP@<F5P;&%C92!I="!W:71H(&%N(&YO
M;B!B<F5A:VEN9R!O;F4*"0DO+R!4:&ES('!A<G1I86QL>2!U;F1O97,@=&AE
M(&1A;6%G92!D;VYE(&)Y(&UO>BP@=VAI8V@@=')A;G-L871E<R`G)FYB<W`[
M)W,@:6YT;R!S<&%C97,@:6X@=&AE(&1A=&$@96QE;65N=`H)"2\J(&EF("@@
M(7)O;W0N<')E=FEO=7-3:6)L:6YG("8F("%R;V]T+FYE>'13:6)L:6YG("8F
M(')O;W0N9&%T82YM871C:"@O7EQS*B0O:2D@*2!H=&UL(#T@)R9N8G-P.R<[
M"@D)("`@96QS92`J+PH)"6AT;6P@/2`O7G-C<FEP='QS='EL920O:2YT97-T
M*')O;W0N<&%R96YT3F]D92YT86=.86UE*2`_(')O;W0N9&%T82`Z($A434Q!
M<F5A+FAT;6Q%;F-O9&4H<F]O="YD871A*3L*"0EB<F5A:SL*"2`@("!C87-E
M(#0Z("\O($YO9&4N0T1!5$%?4T5#5$E/3E].3T1%"@D)+R\@1DE8344Z(&ET
M('-E96US('=E(&YE=F5R(&=E="!H97)E+"!B=70@22!B96QI979E('=E('-H
M;W5L9"XN"@D)+R\@("`@("`@(&UA>6)E(&$@8G)O=W-E<B!P<F]B;&5M/RTM
M0T1!5$$@<V5C=&EO;G,@87)E(&-O;G9E<G1E9"!T;R!P;&%I;B!T97AT(&YO
M9&5S(&%N9"!N;W)M86QI>F5D"@D)+R\@0T1!5$$@<V5C=&EO;G,@<VAO=6QD
M(&=O(")A<R!I<R(@=VET:&]U="!F=7)T:&5R(&5N8V]D:6YG"@D):'1M;"`]
M("(\(5M#1$%405LB("L@<F]O="YD871A("L@(EU=/B(["@D)8G)E86L["@D@
M("`@8V%S92`X.B`O+R!.;V1E+D-/34U%3E1?3D]$10H)"6AT;6P@/2`B/"$M
M+2(@*R!R;V]T+F1A=&$@*R`B+2T^(CL*"0EB<F5A:SL)"2\O('-K:7`@8V]M
M;65N=',L(&9O<B!N;W<N"@E]"@ER971U<FX@:'1M;#L*?3L*"DA434Q!<F5A
M+F=E=%!R979.;V1E(#T@9G5N8W1I;VXH;F]D92D@>PH):68@*"%N;V1E*2`@
M("`@("`@("`@("`@("!R971U<FX@;G5L;#L*"6EF("AN;V1E+G!R979I;W5S
M4VEB;&EN9RD@<F5T=7)N(&YO9&4N<')E=FEO=7-3:6)L:6YG.PH):68@*&YO
M9&4N<&%R96YT3F]D92D@("`@("!R971U<FX@;F]D92YP87)E;G1.;V1E.PH)
M<F5T=7)N(&YU;&P["GT["@I(5$U,07)E82YG971.97AT3F]D92`](&9U;F-T
M:6]N*&YO9&4I('L*"6EF("@A;F]D92D@("`@("`@("`@("!R971U<FX@;G5L
M;#L*"6EF("AN;V1E+FYE>'13:6)L:6YG*2!R971U<FX@;F]D92YN97AT4VEB
M;&EN9SL*"6EF("AN;V1E+G!A<F5N=$YO9&4I("!R971U<FX@;F]D92YP87)E
M;G1.;V1E.PH)<F5T=7)N(&YU;&P["GT["@I(5$U,07)E82YP<F]T;W1Y<&4N
M<W1R:7!"87-E55),(#T@9G5N8W1I;VXH<W1R:6YG*2!["@EV87(@8F%S975R
M;"`]('1H:7,N8V]N9FEG+F)A<V554DP["@H)+R\@<W1R:7`@=&\@;&%S="!D
M:7)E8W1O<GD@:6X@8V%S92!B87-E=7)L('!O:6YT<R!T;R!A(&9I;&4*"6)A
M<V5U<FP@/2!B87-E=7)L+G)E<&QA8V4H+UM>7"]=*R0O+"`G)RD["@EV87(@
M8F%S97)E(#T@;F5W(%)E9T5X<"AB87-E=7)L*3L*"7-T<FEN9R`]('-T<FEN
M9RYR97!L86-E*&)A<V5R92P@(B(I.PH*"2\O('-T<FEP(&AO<W0M<&%R="!O
M9B!54DP@=VAI8V@@:7,@861D960@8GD@35-)12!T;R!L:6YK<R!R96QA=&EV
M92!T;R!S97)V97(@<F]O=`H)8F%S975R;"`](&)A<V5U<FPN<F5P;&%C92@O
M7BAH='1P<S\Z7"]<+UM>7"]=*RDH+BHI)"\L("<D,2<I.PH)8F%S97)E(#T@
M;F5W(%)E9T5X<"AB87-E=7)L*3L*"7)E='5R;B!S=')I;F<N<F5P;&%C92AB
M87-E<F4L("(B*3L*?3L*"E-T<FEN9RYP<F]T;W1Y<&4N=')I;2`](&9U;F-T
M:6]N*"D@>PH)<F5T=7)N('1H:7,N<F5P;&%C92@O7EQS*R\L("<G*2YR97!L
M86-E*"]<<RLD+RP@)R<I.PI].PH*+R\@8W)E871E<R!A(')G8BUS='EL92!C
M;VQO<B!F<F]M(&$@;G5M8F5R"DA434Q!<F5A+E]M86ME0V]L;W(@/2!F=6YC
M=&EO;BAV*2!["@EI9B`H='EP96]F('8@(3T@(FYU;6)E<B(I('L*"0DO+R!A
M;')E861Y(&EN(')G8B`H:&]P969U;&QY*3L@244@9&]E<VXG="!G970@:&5R
M92X*"0ER971U<FX@=CL*"7T*"2\O($E%('-E;F1S(&YU;6)E<CL@8V]N=F5R
M="!T;R!R9V(N"@EV87(@<B`]('8@)B`P>$9&.PH)=F%R(&<@/2`H=B`^/B`X
M*2`F(#!X1D8["@EV87(@8B`]("AV(#X^(#$V*2`F(#!X1D8["@ER971U<FX@
M(G)G8B@B("L@<B`K("(L(B`K(&<@*R`B+"(@*R!B("L@(BDB.PI].PH*+R\@
M<F5T=7)N<R!H97AA9&5C:6UA;"!C;VQO<B!R97!R97-E;G1A=&EO;B!F<F]M
M(&$@;G5M8F5R(&]R(&$@<F=B+7-T>6QE(&-O;&]R+@I(5$U,07)E82Y?8V]L
M;W)4;U)G8B`](&9U;F-T:6]N*'8I('L*"6EF("@A=BD*"0ER971U<FX@)R<[
M"@H)+R\@<F5T=7)N<R!T:&4@:&5X(')E<')E<V5N=&%T:6]N(&]F(&]N92!B
M>71E("@R(&1I9VET<RD*"69U;F-T:6]N(&AE>"AD*2!["@D)<F5T=7)N("AD
M(#P@,38I(#\@*"(P(B`K(&0N=&]3=')I;F<H,38I*2`Z(&0N=&]3=')I;F<H
M,38I.PH)?3L*"@EI9B`H='EP96]F('8@/3T@(FYU;6)E<B(I('L*"0DO+R!W
M92=R92!T86QK:6YG('1O($E%(&AE<F4*"0EV87(@<B`]('8@)B`P>$9&.PH)
M"79A<B!G(#T@*'8@/CX@."D@)B`P>$9&.PH)"79A<B!B(#T@*'8@/CX@,38I
M("8@,'A&1CL*"0ER971U<FX@(B,B("L@:&5X*'(I("L@:&5X*&<I("L@:&5X
M*&(I.PH)?0H*"6EF("AV+G-U8G-T<B@P+"`S*2`]/2`B<F=B(BD@>PH)"2\O
M(&EN(')G8B@N+BXI(&9O<FT@+2T@36]Z:6QL80H)"79A<B!R92`]("]R9V)<
M<RI<*%QS*BA;,"TY72LI7',J+%QS*BA;,"TY72LI7',J+%QS*BA;,"TY72LI
M7',J7"DO.PH)"6EF("AV+FUA=&-H*')E*2D@>PH)"0EV87(@<B`]('!A<G-E
M26YT*%)E9T5X<"XD,2D["@D)"79A<B!G(#T@<&%R<V5);G0H4F5G17AP+B0R
M*3L*"0D)=F%R(&(@/2!P87)S94EN="A296=%>'`N)#,I.PH)"0ER971U<FX@
M(B,B("L@:&5X*'(I("L@:&5X*&<I("L@:&5X*&(I.PH)"7T*"0DO+R!D;V5S
M;B=T(&UA=&-H(%)%/R$@(&UA>6)E('5S97,@<&5R8V5N=&%G97,@;W(@9FQO
M870@;G5M8F5R<PH)"2\O("TM($9)6$U%.B!N;W0@>65T(&EM<&QE;65N=&5D
M+@H)"7)E='5R;B!N=6QL.PH)?0H*"6EF("AV+G-U8G-T<B@P+"`Q*2`]/2`B
M(R(I('L*"0DO+R!A;')E861Y(&AE>"!R9V(@*&AO<&5F=6QL>2`Z1"`I"@D)
M<F5T=7)N('8["@E]"@H)+R\@:68@979E<GET:&EN9R!E;'-E(&9A:6QS(#LI
M"@ER971U<FX@;G5L;#L*?3L*"B\O(&UO9&%L(&1I86QO9W,@9F]R($UO>FEL
M;&$@*&9O<B!)12!W92=R92!U<VEN9R!T:&4@<VAO=TUO9&%L1&EA;&]G*"D@
M8V%L;"DN"@HO+R!R96-E:79E<R!A;B!54DP@=&\@=&AE('!O<'5P(&1I86QO
M9R!A;F0@82!F=6YC=&EO;B!T:&%T(')E8V5I=F5S(&]N92!V86QU93L*+R\@
M=&AI<R!F=6YC=&EO;B!W:6QL(&=E="!C86QL960@869T97(@=&AE(&1I86QO
M9R!I<R!C;&]S960L('=I=&@@=&AE(')E='5R;@HO+R!V86QU92!O9B!T:&4@
M9&EA;&]G+@I(5$U,07)E82YP<F]T;W1Y<&4N7W!O<'5P1&EA;&]G(#T@9G5N
M8W1I;VXH=7)L+"!A8W1I;VXL(&EN:70I('L*"41I86QO9RAT:&ES+G!O<'5P
M55),*'5R;"DL(&%C=&EO;BP@:6YI="D["GT["@HO+R!P871H<PH*2%1-3$%R
M96$N<')O=&]T>7!E+FEM9U523"`](&9U;F-T:6]N*&9I;&4L('!L=6=I;BD@
M>PH):68@*'1Y<&5O9B!P;'5G:6X@/3T@(G5N9&5F:6YE9"(I"@D)<F5T=7)N
M(%]E9&ET;W)?=7)L("L@9FEL93L*"65L<V4*"0ER971U<FX@7V5D:71O<E]U
M<FP@*R`B<&QU9VEN<R\B("L@<&QU9VEN("L@(B]I;6<O(B`K(&9I;&4["GT[
M"@I(5$U,07)E82YP<F]T;W1Y<&4N<&]P=7!54DP@/2!F=6YC=&EO;BAF:6QE
M*2!["@EV87(@=7)L(#T@(B(["@EI9B`H9FEL92YM871C:"@O7G!L=6=I;CI<
M+UPO*"XJ/RE<+R@N*BDO*2D@>PH)"79A<B!P;'5G:6X@/2!296=%>'`N)#$[
M"@D)=F%R('!O<'5P(#T@4F5G17AP+B0R.PH)"6EF("@A+UPN:'1M;"0O+G1E
M<W0H<&]P=7`I*0H)"0EP;W!U<"`K/2`B+FAT;6PB.PH)"75R;"`](%]E9&ET
M;W)?=7)L("L@(G!L=6=I;G,O(B`K('!L=6=I;B`K("(O<&]P=7!S+R(@*R!P
M;W!U<#L*"7T@96QS90H)"75R;"`](%]E9&ET;W)?=7)L("L@=&AI<RYC;VYF
M:6<N<&]P=7!54DP@*R!F:6QE.PH)<F5T=7)N('5R;#L*?3L*"B\J*@H@*B!&
M25@Z($EN=&5R;F5T($5X<&QO<F5R(')E='5R;G,@86X@:71E;2!H879I;F<@
M=&AE(%]N86UE7R!E<75A;"!T;R!T:&4@9VEV96X*("H@:60L(&5V96X@:68@
M:70G<R!N;W0@:&%V:6YG(&%N>2!I9"X@(%1H:7,@=V%Y(&ET(&-A;B!R971U
M<FX@82!D:69F97)E;G0@9F]R;0H@*B!F:65L9"!E=F5N(&EF(&ET)W,@;F]T
M(&$@=&5X=&%R96$N("!4:&ES('=O<FMA<F]U;F1S('1H92!P<F]B;&5M(&)Y
M"B`J('-P96-I9FEC86QL>2!L;V]K:6YG('1O('-E87)C:"!O;FQY(&5L96UE
M;G1S(&AA=FEN9R!A(&-E<G1A:6X@=&%G(&YA;64N"B`J+PI(5$U,07)E82YG
M971%;&5M96YT0GE)9"`](&9U;F-T:6]N*'1A9RP@:60I('L*"79A<B!E;"P@
M:2P@;V)J<R`](&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*'1A9RD[
M"@EF;W(@*&D@/2!O8FIS+FQE;F=T:#L@+2UI(#X](#`@)B8@*&5L(#T@;V)J
M<UMI72D[*0H)"6EF("AE;"YI9"`]/2!I9"D*"0D)<F5T=7)N(&5L.PH)<F5T
M=7)N(&YU;&P["GT["@H*"B\O($5/1@HO+R!,;V-A;"!V87)I86)L97,Z("\O
M"B\O(&,M8F%S:6,M;V9F<V5T.C@@+R\*+R\@:6YD96YT+71A8G,M;6]D93IT
M("\O"B\O($5N9#H@+R\*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VAT;6QA<F5A+F-S<P``````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,#`W,@`Q,#4Q-30S,3`V-``P,C,V,C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+FAT;6QA<F5A('L@8F%C
M:V=R;W5N9#H@(V9F9CL@?0H*+FAT;6QA<F5A("YT;V]L8F%R('L*("!C=7)S
M;W(Z(&1E9F%U;'0["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*("!P861D
M:6YG.B`S<'@["B`@8F]R9&5R.B`Q<'@@<V]L:60["B`@8F]R9&5R+6-O;&]R
M.B!"=71T;VY(:6=H;&EG:'0@0G5T=&]N4VAA9&]W($)U='1O;E-H861O=R!"
M=71T;VY(:6=H;&EG:'0["GT*+FAT;6QA<F5A("YT;V]L8F%R('1A8FQE('L@
M9F]N="UF86UI;'DZ('1A:&]M82QV97)D86YA+'-A;G,M<V5R:68[(&9O;G0M
M<VEZ93H@,3%P>#L@?0HN:'1M;&%R96$@+G1O;VQB87(@:6UG('L@8F]R9&5R
M.B!N;VYE.R!]"BYH=&UL87)E82`N=&]O;&)A<B`N;&%B96P@>R!P861D:6YG
M.B`P<'@@,W!X.R!]"@HN:'1M;&%R96$@+G1O;VQB87(@+F)U='1O;B!["B`@
M8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*("!C;VQO<CH@0G5T=&]N5&5X=#L*
M("!B;W)D97(Z(#%P>"!S;VQI9"!"=71T;VY&86-E.PH@('!A9&1I;F<Z(#%P
M>#L*("!M87)G:6XZ(#!P>#L*("!W:61T:#H@,3AP>#L*("!H96EG:'0Z(#$X
M<'@["GT*+FAT;6QA<F5A("YT;V]L8F%R("YB=71T;VY(;W9E<B!["B`@8F]R
M9&5R.B`Q<'@@<V]L:60["B`@8F]R9&5R+6-O;&]R.B!"=71T;VY(:6=H;&EG
M:'0@0G5T=&]N4VAA9&]W($)U='1O;E-H861O=R!"=71T;VY(:6=H;&EG:'0[
M"GT*+FAT;6QA<F5A("YT;V]L8F%R("YB=71T;VY!8W1I=F4L("YH=&UL87)E
M82`N=&]O;&)A<B`N8G5T=&]N4')E<W-E9"!["B`@<&%D9&EN9SH@,G!X(#!P
M>"`P<'@@,G!X.PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@(&)O<F1E<BUC;VQO
M<CH@0G5T=&]N4VAA9&]W($)U='1O;DAI9VAL:6=H="!"=71T;VY(:6=H;&EG
M:'0@0G5T=&]N4VAA9&]W.PI]"BYH=&UL87)E82`N=&]O;&)A<B`N8G5T=&]N
M4')E<W-E9"!["B`@8F%C:V=R;W5N9#H@0G5T=&]N2&EG:&QI9VAT.PI]"BYH
M=&UL87)E82`N=&]O;&)A<B`N:6YD:6-A=&]R('L*("!P861D:6YG.B`P<'@@
M,W!X.PH@(&]V97)F;&]W.B!H:61D96X["B`@=VED=&@Z(#(P<'@["B`@=&5X
M="UA;&EG;CH@8V5N=&5R.PH@(&-U<G-O<CH@9&5F875L=#L*("!B;W)D97(Z
M(#%P>"!S;VQI9"!"=71T;VY3:&%D;W<["GT*"BYH=&UL87)E82`N=&]O;&)A
M<B`N8G5T=&]N1&ES86)L960@:6UG('L*("!F:6QT97(Z(&=R87DH*2!A;'!H
M82AO<&%C:71Y(#T@,C4I.PH@("UM;WHM;W!A8VET>3H@,"XR-3L*?0H*+FAT
M;6QA<F5A("YT;V]L8F%R("YS97!A<F%T;W(@>PH@('!O<VET:6]N.B!R96QA
M=&EV93L*("!M87)G:6XZ(#-P>#L*("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M($)U='1O;E-H861O=SL*("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"!"=71T
M;VY(:6=H;&EG:'0["B`@=VED=&@Z(#!P>#L*("!H96EG:'0Z(#$V<'@["B`@
M<&%D9&EN9SH@,'!X.PI]"@HN:'1M;&%R96$@+G1O;VQB87(@+G-P86-E('L@
M=VED=&@Z(#5P>#L@?0H*+FAT;6QA<F5A("YT;V]L8F%R('-E;&5C="![(&9O
M;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL@?0H*+FAT;6QA
M<F5A("YT;V]L8F%R('-E;&5C="P*+FAT;6QA<F5A("YT;V]L8F%R('-E;&5C
M=#IH;W9E<BP*+FAT;6QA<F5A("YT;V]L8F%R('-E;&5C=#IA8W1I=F4@>R!B
M86-K9W)O=6YD.B!&:65L9$9A8V4[(&-O;&]R.B!"=71T;VY497AT.R!]"@HN
M:'1M;&%R96$@+G-T871U<T)A<B!["B`@8F]R9&5R.B`Q<'@@<V]L:60["B`@
M8F]R9&5R+6-O;&]R.B!"=71T;VY3:&%D;W<@0G5T=&]N2&EG:&QI9VAT($)U
M='1O;DAI9VAL:6=H="!"=71T;VY3:&%D;W<["B`@<&%D9&EN9SH@,G!X(#1P
M>#L*("!B86-K9W)O=6YD+6-O;&]R.B!"=71T;VY&86-E.PH@(&-O;&]R.B!"
M=71T;VY497AT.PH@(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS
M97)I9CL*?0H*+FAT;6QA<F5A("YS=&%T=7-"87(@+G-T871U<T)A<E1R964@
M82!["B`@<&%D9&EN9SH@,G!X(#5P>#L*("!C;VQO<CH@(S`P9CL*?0H*+FAT
M;6QA<F5A("YS=&%T=7-"87(@+G-T871U<T)A<E1R964@83IV:7-I=&5D('L@
M8V]L;W(Z(",P,&8[('T*+FAT;6QA<F5A("YS=&%T=7-"87(@+G-T871U<T)A
M<E1R964@83IH;W9E<B!["B`@8F%C:V=R;W5N9"UC;VQO<CH@2&EG:&QI9VAT
M.PH@(&-O;&]R.B!(:6=H;&EG:'1497AT.PH@('!A9&1I;F<Z(#%P>"`T<'@[
M"B`@8F]R9&5R.B`Q<'@@<V]L:60@2&EG:&QI9VAT5&5X=#L*?0H*"B\J($AI
M9&1E;B!$258@<&]P=7`@9&EA;&]G<R`H4&]P=7!$:78I("HO"@HN9&EA;&]G
M('L*("!C;VQO<CH@0G5T=&]N5&5X=#L*("!B86-K9W)O=6YD.B!"=71T;VY&
M86-E.PI]"@HN9&EA;&]G("YC;VYT96YT('L@<&%D9&EN9SH@,G!X.R!]"@HN
M9&EA;&]G+"`N9&EA;&]G(&)U='1O;BP@+F1I86QO9R!I;G!U="P@+F1I86QO
M9R!S96QE8W0L("YD:6%L;V<@=&5X=&%R96$L("YD:6%L;V<@=&%B;&4@>PH@
M(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*?0H*+F1I
M86QO9R!T86)L92![(&)O<F1E<BUC;VQL87!S93H@8V]L;&%P<V4[('T*"BYD
M:6%L;V<@+G1I=&QE('L*("!B86-K9W)O=6YD.B`C,#`X.PH@(&-O;&]R.B`C
M9F8X.PH@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P.PH@('!A9&1I
M;F<Z(#%P>"`P<'@@,G!X(#5P>#L*("!F;VYT+7-I>F4Z(#$R<'@["B`@9F]N
M="UW96EG:'0Z(&)O;&0["B`@8W5R<V]R.B!D969A=6QT.PI]"@HN9&EA;&]G
M("YT:71L92`N8G5T=&]N('L*("!F;&]A=#H@<FEG:'0["B`@8F]R9&5R.B`Q
M<'@@<V]L:60@(S8V83L*("!P861D:6YG.B`P<'@@,7!X(#!P>"`R<'@["B`@
M;6%R9VEN+7)I9VAT.B`Q<'@["B`@8V]L;W(Z("-F9F8["B`@=&5X="UA;&EG
M;CH@8V5N=&5R.PI]"@HN9&EA;&]G("YT:71L92`N8G5T=&]N+6AI;&ET92![
M(&)O<F1E<BUC;VQO<CH@(S@X9CL@8F%C:V=R;W5N9#H@(S0T8SL@?0H*+F1I
M86QO9R!B=71T;VX@>PH@('=I9'1H.B`U96T["B`@<&%D9&EN9SH@,'!X.PI]
M"@HN9&EA;&]G("YB=71T;VY#;VQO<B!["B`@<&%D9&EN9SH@,7!X.PH@(&-U
M<G-O<CH@9&5F875L=#L*("!B;W)D97(Z(#%P>"!S;VQI9#L*("!B;W)D97(M
M8V]L;W(Z($)U='1O;DAI9VAL:6=H="!"=71T;VY3:&%D;W<@0G5T=&]N4VAA
M9&]W($)U='1O;DAI9VAL:6=H=#L*?0H*+F1I86QO9R`N8G5T=&]N0V]L;W(M
M:&EL:71E('L*("!B;W)D97(M8V]L;W(Z(",P,#`["GT*"BYD:6%L;V<@+F)U
M='1O;D-O;&]R("YC:&]O<V5R+"`N9&EA;&]G("YB=71T;VY#;VQO<B`N;F]C
M;VQO<B!["B`@:&5I9VAT.B`P+C9E;3L*("!B;W)D97(Z(#%P>"!S;VQI9#L*
M("!P861D:6YG.B`P<'@@,65M.PH@(&)O<F1E<BUC;VQO<CH@0G5T=&]N4VAA
M9&]W($)U='1O;DAI9VAL:6=H="!"=71T;VY(:6=H;&EG:'0@0G5T=&]N4VAA
M9&]W.PI]"@HN9&EA;&]G("YB=71T;VY#;VQO<B`N;F]C;VQO<B![('!A9&1I
M;F<Z(#!P>#L@?0HN9&EA;&]G("YB=71T;VY#;VQO<B`N;F]C;VQO<BUH:6QI
M=&4@>R!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.R!C;VQO<CH@(V8P,#L@?0H*
M+F1I86QO9R`N;&%B96P@>R!T97AT+6%L:6=N.B!R:6=H=#L@=VED=&@Z(#9E
M;3L@?0HN9&EA;&]G("YV86QU92!I;G!U="![('=I9'1H.B`Q,#`E.R!]"BYD
M:6%L;V<@+F)U='1O;G,@>R!T97AT+6%L:6=N.B!R:6=H=#L@<&%D9&EN9SH@
M,G!X(#1P>"`P<'@@-'!X.R!]"@HN9&EA;&]G(&QE9V5N9"![(&9O;G0M=V5I
M9VAT.B!B;VQD.R!]"BYD:6%L;V<@9FEE;&1S970@=&%B;&4@>R!M87)G:6XZ
M(#)P>"`P<'@[('T*"BYP;W!U<&1I=B!["B`@8F]R9&5R.B`R<'@@<V]L:60[
M"B`@8F]R9&5R+6-O;&]R.B!"=71T;VY(:6=H;&EG:'0@0G5T=&]N4VAA9&]W
M($)U='1O;E-H861O=R!"=71T;VY(:6=H;&EG:'0["GT*"BYP;W!U<'=I;B![
M"B`@<&%D9&EN9SH@,'!X.PH@(&UA<F=I;CH@,'!X.PI]"@HN<&]P=7!W:6X@
M+G1I=&QE('L*("!B86-K9W)O=6YD.B`C9F9F.PH@(&-O;&]R.B`C,#`P.PH@
M(&9O;G0M=V5I9VAT.B!B;VQD.PH@(&9O;G0M<VEZ93H@,3(P)3L*("!P861D
M:6YG.B`S<'@@,3!P>#L*("!M87)G:6XM8F]T=&]M.B`Q,'!X.PH@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"!B;&%C:SL*("!L971T97(M<W!A8VEN9SH@
M,G!X.PI]"@IF;W)M('L@;6%R9VEN.B`P<'@[(&)O<F1E<CH@;F]N93L@?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO
M````````````````````````````````````````````````````````````
M`````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,Q,#8T`#`Q-S4S-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<```````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,Q,C<`,3`U,34T,S$P-C0`,#(Q,3<U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<"QV
M(#$N-#0N."XU(#(P,#8O,#,O,#@@,3@Z,#`Z-38@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN
M<&AP)SL*"FEF("@A075T:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*("`@($AO
M<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HO+R!'
M970@9G5L;"!N86UE(&9O<B!T:71L92X*)&ED96YT:71Y(#T@)DED96YT:71Y
M.CIS:6YG;&5T;VXH*3L*)&9U;&QN86UE(#T@)&ED96YT:71Y+3YG971686QU
M92@G9G5L;&YA;64G*3L*:68@*&5M<'1Y*"1F=6QL;F%M92DI('L*("`@("1F
M=6QL;F%M92`]($%U=&@Z.F=E=$%U=&@H*3L*?0H*+R\@26YS=&%N=&EA=&4@
M=&AE(&)L;V-K<R!O8FIE8W1S+@HD8FQO8VMS(#T@)DAO<F1E7T)L;V-K7T-O
M;&QE8W1I;VXZ.G-I;F=L971O;B@G<&]R=&%L)RD["B1L87EO=70@/2`F2&]R
M9&5?0FQO8VM?3&%Y;W5T7TUA;F%G97(Z.G-I;F=L971O;B@G<&]R=&%L)RP@
M)&)L;V-K<RP@)'!R969S+3YG971686QU92@G<&]R=&%L7VQA>6]U="<I*3L*
M"B\O($AA;F1L92!R97%U97-T960@86-T:6]N<RX*)&QA>6]U="T^:&%N9&QE
M*%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VXG*2P*("`@("`@("`@("`@("`@
M("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)W)O=R<I+`H@("`@("`@("`@("`@
M("`@*&EN="E5=&EL.CIG971&;W)M1&%T82@G8V]L)RDI.PII9B`H)&QA>6]U
M="T^=7!D871E9"@I*2!["B`@("`D<')E9G,M/G-E=%9A;'5E*"=P;W)T86Q?
M;&%Y;W5T)RP@)&QA>6]U="T^<V5R:6%L:7IE*"DI.PI]"@HD=&ET;&4@/2!?
M*")->2!0;W)T86P@3&%Y;W5T(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]P;W)T86PO;65N=2YI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I
M9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+W!O<G1A;"]E9&ET+FEN8R<["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<```````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-3<P`#$P-3$U-#,Q,#8T`#`R,34R,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<"QV(#(N
M,34N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%
M)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC
M92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+TED96YT:71Y+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O36]B
M:6QE+G!H<"<["@II9B`H(4%U=&@Z.F=E=$%U=&@H*2D@>PH@("`@:&5A9&5R
M*"=,;V-A=&EO;CH@)R`N(%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ87!P
M;&EC871I;VY5<FPH)VQO9VEN+G!H<"<L('1R=64I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7)L)RP@2&]R9&4Z
M.G-E;&95<FPH*2P@9F%L<V4I*3L*("`@(&5X:70["GT*"B1I9&5N=&ET>2`]
M("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B1F=6QL;F%M92`]("1I9&5N=&ET
M>2T^9V5T5F%L=64H)V9U;&QN86UE)RD["FEF("AE;7!T>2@D9G5L;&YA;64I
M*2!["B`@("`D9G5L;&YA;64@/2!!=71H.CIG971!=71H*"D["GT*"B1M(#T@
M)FYE=R!(;W)D95]-;V)I;&4H7R@B5V5L8V]M92(I*3L*)&TM/F%D9"AN97<@
M2&]R9&5?36]B:6QE7W1E>'0H<W!R:6YT9BA?*")796QC;VUE+"`E<R(I+"`D
M9G5L;&YA;64I*2D["@HO+R!-97-S>2!W87D@;V8@;&EN:VEN9R!T;R!A8W1I
M=F4@87!P<R!T:&%T('-U<'!O<G0@;6]B:6QE"B\O(&1E=FEC97,N(%-H;W5L
M9"!B92!M861E(&UO<F4@96QE9V%N="!A="!S;VUE('!O:6YT+@II9B`H(65M
M<'1Y*"1R96=I<W1R>2T^87!P;&EC871I;VYS6R=M:6UP)UU;)W-T871U<R==
M*2`F)@H@("`@)')E9VES=')Y+3YA<'!L:6-A=&EO;G-;)VUI;7`G75LG<W1A
M='5S)UT@(3T@)VEN86-T:79E)RD@>PH@("`@)&TM/F%D9"AN97<@2&]R9&5?
M36]B:6QE7VQI;FLH)')E9VES=')Y+3YG970H)VYA;64G+"`G;6EM<"<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.G5R;"@D
M<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=M:6UP)RD@+B`G+R<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E9VES=')Y+3YG970H
M)VYA;64G+"`G;6EM<"<I*2D["GT*"B1M+3YD:7-P;&%Y*"D["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8Q-#(`,3`U,34T
M,S$P-C0`,#(Q-38Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP+'8@,BXR-BXV+C,@,C`P-B\P,2\P,2`R,3HR
M.3HQ-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]24$,N<&AP)SL*"FEF("@A075T
M:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*("`@($AO<F1E.CIA=71H96YT:6-A
M=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HD<G!C7W-E<G9E<G,@/2!`=6YS
M97)I86QI>F4H)'!R969S+3YG971686QU92@G<F5M;W1E7W-U;6UA<FEE<R<I
M*3L*:68@*"%I<U]A<G)A>2@D<G!C7W-E<G9E<G,I*2!["B`@("`D<G!C7W-E
M<G9E<G,@/2!A<G)A>2@I.PI]"@HD86-T:6]N240@/2!5=&EL.CIG971&;W)M
M1&%T82@G86-T:6]N240G*3L*"B\O($AA;F1L92!C;&EE;G1S('=I=&AO=70@
M:F%V87-C<FEP="X*:68@*&ES7VYU;&PH)&%C=&EO;DE$*2D@>PH@("`@:68@
M*%5T:6PZ.F=E=%!O<W0H)V5D:70G*2D@>PH@("`@("`@("1A8W1I;VY)1"`]
M("=E9&ET)SL*("`@('T@96QS96EF("A5=&EL.CIG9710;W-T*"=S879E)RDI
M('L*("`@("`@("`D86-T:6]N240@/2`G<V%V92<["B`@("!](&5L<V5I9B`H
M571I;#HZ9V5T4&]S="@G9&5L971E)RDI('L*("`@("`@("`D86-T:6]N240@
M/2`G9&5L971E)SL*("`@('T*?0H*+RH@4G5N('1H<F]U9V@@=&AE(&%C=&EO
M;B!H86YD;&5R<R`J+PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=S879E
M)SH*("`@(&EF("@H)'1O7V5D:70@/2!5=&EL.CIG971&;W)M1&%T82@G961I
M=%]S97)V97(G*2D@/3T@;G5L;"D@>PH@("`@("`@("1T;U]E9&ET(#T@8V]U
M;G0H)')P8U]S97)V97)S*3L*("`@("`@("`D<G!C7W-E<G9E<G-;72`](&%R
M<F%Y*"D["B`@("!]"B`@("`D<G!C7W-E<G9E<G-;)'1O7V5D:71=6R=U<FPG
M72`@("`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*3L*("`@("1R<&-?<V5R
M=F5R<ULD=&]?961I=%U;)W5S97(G72`@(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W5S97(G*3L*("`@("1R<&-?<V5R=F5R<ULD=&]?961I=%U;)W!A<W-W9"==
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W!A<W-W9"<I.PH@("`@)'!R969S+3YS
M971686QU92@G<F5M;W1E7W-U;6UA<FEE<R<L('-E<FEA;&EZ92@D<G!C7W-E
M<G9E<G,I*3L*("`@("1P<F5F<RT^<W1O<F4H*3L*("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!S879E9"XB*2P@)')P8U]S97)V97)S6R1T;U]E9&ET75LG=7)L)UTI+"`G
M:&]R9&4N<W5C8V5S<R<I.PH@("`@8G)E86L["@IC87-E("=D96QE=&4G.@H@
M("`@)'1O7V1E;&5T92`](%5T:6PZ.F=E=$9O<FU$871A*"=S97)V97(G*3L*
M("`@(&EF("@D=&]?9&5L971E("$]("TQ*2!["B`@("`@("`@)&1E;&5T961?
M<V5R=F5R(#T@)')P8U]S97)V97)S6R1T;U]D96QE=&5=6R=U<FPG73L*("`@
M("`@("`D<V5R=F5R7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1R<&-?<V5R=F5R<RD[("1I*RLI('L*("`@("`@
M("`@("`@:68@*"1I(#T]("1T;U]D96QE=&4I('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S97)V97)?
M;&ES=%M=(#T@)')P8U]S97)V97)S6R1I73L*("`@("`@("!]"B`@("`@("`@
M)'!R969S+3YS971686QU92@G<F5M;W1E7W-U;6UA<FEE<R<L('-E<FEA;&EZ
M92@D<V5R=F5R7VQI<W0I*3L*("`@("`@("`D8VAO<V5N0V]L=6UN<R`](&5X
M<&QO9&4H)SLG+"`D<')E9G,M/F=E=%9A;'5E*"=S:&]W7W-U;6UA<FEE<R<I
M*3L*("`@("`@("!I9B`H)&-H;W-E;D-O;'5M;G,@(3T@87)R87DH)R<I*2![
M"B`@("`@("`@("`@("1N97=#;VQU;6YS(#T@87)R87DH*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&-H;W-E;D-O;'5M;G,@87,@)&-H;W-E;D-O;'5M;BD@
M>PH@("`@("`@("`@("`@("`@)&-H;W-E;D-O;'5M;B`](&5X<&QO9&4H)RPG
M+"`D8VAO<V5N0V]L=6UN*3L*("`@("`@("`@("`@("`@("1R96UO=&4@/2!E
M>'!L;V1E*"=\)RP@)&-H;W-E;D-O;'5M;ELP72D["B`@("`@("`@("`@("`@
M("!I9B`H8V]U;G0H)')E;6]T92D@(3T@,R!\?"`D<F5M;W1E6S)=(#T]("1D
M96QE=&5D7W-E<G9E<BD@>PH@("`@("`@("`@("`@("`@("`@("1N97=#;VQU
M;6YS6UT@/2!I;7!L;V1E*"<L)RP@)&-H;W-E;D-O;'5M;BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!R969S+3YS
M971686QU92@G<VAO=U]S=6UM87)I97,G+"!I;7!L;V1E*"<[)RP@)&YE=T-O
M;'5M;G,I*3L*("`@("`@("!]"B`@("`@("`@)'!R969S+3YS=&]R92@I.PH@
M("`@("`@("1R<&-?<V5R=F5R<R`]("1S97)V97)?;&ES=#L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB*2P@)&1E;&5T961?<V5R=F5R*2P@)VAO
M<F1E+G-U8V-E<W,G*3L*("`@('T@96QS92!["B`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"A?*")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N(BDL("=H;W)D92YW87)N:6YG)RD["B`@("!]"B`@("!B<F5A
M:SL*?0H*+RH@4VAO=R!T:&4@:&5A9&5R+B`J+PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U!R969S+U5)+G!H<"<["G)E<75I<F4@2$]21$5?0D%312`N("<O8V]N
M9FEG+W!R969S+G!H<"<["B1A<'`@/2`G:&]R9&4G.PI0<F5F<U]523HZ9V5N
M97)A=&5(96%D97(H)W)E;6]T92<I.PH*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+W)P8W-U;2]R<&-S=6TN:6YC)SL*<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'``````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U,C,T`#$P-3$U
M-#,Q,#8T`#`R,38V-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`L=B`Q+C0N,BXQ,R`R,#`V+S`S+S(P(#$U
M.C`P.C`V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%!A=VQO=W-K>2`\;6IP87=L
M;W=S:WE`>6%H;V\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*+RHJ"B`J($1E
M=&5R;6EN92!I9B!T:&4@8W5R<F5N="!U<V5R(&-A;B!S964@86X@87!P;&EC
M871I;VXN"B`J"B`J($!P87)A;2!S=')I;F<@("1A<'`@("`@("`@("`@5&AE
M(&%P<&QI8V%T:6]N(&YA;64N"B`J($!P87)A;2!A<G)A>2`@("1P87)A;7,@
M("`@("`@5&AE(&%P<&QI8V%T:6]N)W,@<&%R86UE=&5R<RX*("H@0'!A<F%M
M(&%R<F%Y("`F)&AA<T-H:6QD<F5N("!2969E<F5N8V4@=&\@86X@87)R87D@
M=&\@<V5T(&-H:6QD<F5N(&9L86=S(&EN+@H@*B\*9G5N8W1I;VX@8V%N4V5E
M*"1A<'`L("1P87)A;7,L("8D:&%S0VAI;&1R96XI"GL*("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@<W1A=&EC("1C86-H92`](&%R<F%Y*"D["B`@("!S
M=&%T:6,@)&ES061M:6X["B`@("!S=&%T:6,@)'5S97(["@H@("`@+R\@268@
M=V4@:&%V92!A(&-A8VAE9"!V86QU92!F;W(@=&AI<R!A<'!L:6-A=&EO;BP@
M<F5T=7)N(&ET(&YO=RX*("`@(&EF("AI<W-E="@D8V%C:&5;)&%P<%TI*2![
M"B`@("`@("`@<F5T=7)N("1C86-H95LD87!P73L*("`@('T*"B`@("`O+R!)
M;FET:6%L:7IE('9A<FEA8FQE<R!W92=L;"!K965P('5S:6YG(&EN('-U8V-E
M<W-I=F4@8V%L;',@;VX*("`@("\O('1H92!F:7)S="!C86QL+@H@("`@:68@
M*&ES7VYU;&PH)&ES061M:6XI*2!["B`@("`@("`@)&ES061M:6X@/2!!=71H
M.CII<T%D;6EN*"D["B`@("`@("`@)'5S97(@/2!!=71H.CIG971!=71H*"D[
M"B`@("!]"@H@("`@+R\@0VAE8VL@:68@=&AE(&-U<G)E;G0@=7-E<B!H87,@
M<&5R;6ES<V]N('1O('-E92!T:&ES(&%P<&QI8V%T:6]N+"!A;F0@:68*("`@
M("\O('1H92!A<'!L:6-A=&EO;B!I<R!A8W1I=F4N($AE861I;F=S(&%R92!V
M:7-I8FQE('1O(&5V97)Y;VYE("AB=70@9V5T"B`@("`O+R!F:6QT97)E9"!O
M=70@;&%T97(@:68@=&AE>2!H879E(&YO(&-H:6QD<F5N*2X@061M:6YI<W1R
M871O<G,@86QW87ES('-E90H@("`@+R\@86QL(&%P<&QI8V%T:6]N<R!E>&-E
M<'0@=&AO<V4@;6%R:V5D("=I;F%C=&EV92<N($%N>6]N92!W:71H(%-(3U<*
M("`@("\O('!E<FUI<W-I;VYS(&-A;B!S964@86X@87!P;&EC871I;VXL(&)U
M="!214%$(&ES(&YE961E9"!T;R!A8W1U86QL>2!U<V4*("`@("\O('1H92!A
M<'!L:6-A=&EO;BX@66]U(&-A;B!U<V4@=&AI<R!D:7-T:6YC=&EO;B!T;R!S
M:&]W(&%P<&QI8V%T:6]N<R!T;PH@("`@+R\@9W5E<W1S('1H870@=&AE>2!N
M965D('1O(&QO9R!I;B!T;R!U<V4N($EF('EO=2!D;VXG="!W86YT('1H96T@
M=&\@<V5E"B`@("`O+R!A<'!S('1H97D@8V%N)W0@=7-E+"!T:&5N(&1O;B=T
M(&=I=F4@9W5E<W1S(%-(3U<@<&5R;6ES<VEO;G,@=&\*("`@("\O(&%N>71H
M:6YG+@H@("`@:68@*"\O($1O;B=T('-H;W<@87!P;&EC871I;VYS('1H870@
M87)E;B=T(&EN<W1A;&QE9"P@979E;B!I9B!T:&5Y)W)E"B`@("`@("`@+R\@
M8V]N9FEG=7)E9"X*("`@("`@("`H:7-S970H)'!A<F%M<ULG9FEL97)O;W0G
M72D@)B8@(6ES7V1I<B@D<&%R86US6R=F:6QE<F]O="==*2D@?'P*"B`@("`@
M("`@+R\@1&]N)W0@<VAO=R!B;&]C:W,@;V8@87!P;&EC871I;VYS('1H870@
M87)E;B=T(&EN<W1A;&QE9"X*("`@("`@("`H)'!A<F%M<ULG<W1A='5S)UT@
M/3T@)V)L;V-K)R`F)@H@("`@("`@("`A:7-?9&ER*"1R96=I<W1R>2T^9V5T
M*"=F:6QE<F]O="<L("1P87)A;7-;)V%P<"==*2DI('Q\"@H@("`@("`@("\O
M($9I;'1E<B!O=70@96YT<FEE<R!T:&%T(&%R92!D:7-A8FQE9"P@:&ED9&5N
M(&]R('-H;W5L9&XG="!S:&]W('5P"B`@("`@("`@+R\@:6X@=&AE(&UE;G4N
M"B`@("`@("`@)'!A<F%M<ULG<W1A='5S)UT@/3T@)VYO=&]O;&)A<B<@?'P@
M)'!A<F%M<ULG<W1A='5S)UT@/3T@)VAI9&1E;B<@?'P*("`@("`@("`D<&%R
M86US6R=S=&%T=7,G72`]/2`G:6YA8W1I=F4G*2!["@H@("`@("`@("1C86-H
M95LD87!P72`](&9A;'-E.PH*("`@('T@96QS96EF("@O+R!(96%D:6YG<R!C
M86X@86QW87ES(&)E('-E96XN"B`@("`@("`@("`@("`@*"1P87)A;7-;)W-T
M871U<R==(#T]("=H96%D:6YG)RD@?'P*"B`@("`@("`@("`@("`@+R\@061M
M:6YS('-E92!E=F5R>71H:6YG('1H870@;6%K97,@:70@=&\@=&AI<R!P;VEN
M="X*("`@("`@("`@("`@("`H)&ES061M:6X@?'P*"B`@("`@("`@("`@("`@
M("\O(%5S97)S('=H;R!H879E(%-(3U<@<&5R;6ES<VEO;G,@=&\@86-T:79E
M(&]R(&)L;V-K(&5N=')I97,*("`@("`@("`@("`@("`@+R\@<V5E('1H96TN
M"B`@("`@("`@("`@("`@("@D<F5G:7-T<GDM/FAA<U!E<FUI<W-I;VXH)&%P
M<"P@4$5235-?4TA/5RD@)B8*("`@("`@("`@("`@("`@("@D<&%R86US6R=S
M=&%T=7,G72`]/2`G86-T:79E)R!\?`H@("`@("`@("`@("`@("`@("1P87)A
M;7-;)W-T871U<R==(#T]("=B;&]C:R<I*2DI('L*"B`@("`@("`@)&-A8VAE
M6R1A<'!=(#T@=')U93L*"B`@("`@("`@+R\@3F]T92!T:&%T('1H92!P87)E
M;G0@;F]D92P@:68@86YY+"!H87,@8VAI;&1R96XN"B`@("`@("`@:68@*&ES
M<V5T*"1P87)A;7-;)VUE;G5?<&%R96YT)UTI*2!["B`@("`@("`@("`@("1H
M87-#:&EL9')E;ELD<&%R86US6R=M96YU7W!A<F5N="==72`]('1R=64["B`@
M("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!#871C:"!A;GET:&EN
M9R!T:&%T(&9E;&P@=&AR;W5G:"P@86YD(&1O;B=T('-H;W<@:70N"B`@("`@
M("`@)&-A8VAE6R1A<'!=(#T@9F%L<V4["B`@("!]"@H@("`@<F5T=7)N("1C
M86-H95LD87!P73L*?0H*+RHJ"B`J($)U:6QD<R!T:&4@;65N=2!S=')U8W1U
M<F4@9&5P96YD:6YG(&]N(&%P<&QI8V%T:6]N('!E<FUI<W-I;VYS+@H@*B\*
M9G5N8W1I;VX@8G5I;&1-96YU*"D*>PH@("`@9VQO8F%L("1C;VYF+"`D<F5G
M:7-T<GD["@H@("`@)&%P<',@/2!A<G)A>2@I.PH@("`@)&-H:6QD<F5N(#T@
M87)R87DH*3L*("`@(&9O<F5A8V@@*"1R96=I<W1R>2T^87!P;&EC871I;VYS
M(&%S("1A<'`@/3X@)'!A<F%M<RD@>PH@("`@("`@(&EF("AC86Y3964H)&%P
M<"P@)'!A<F%M<RP@)&-H:6QD<F5N*2D@>PH@("`@("`@("`@("`D87!P<ULD
M87!P72`]("1P87)A;7,["B`@("`@("`@?0H@("`@?0H*("`@("1M96YU(#T@
M87)R87DH*3L*("`@(&9O<F5A8V@@*"1A<'!S(&%S("1A<'`@/3X@)'!A<F%M
M<RD@>PH@("`@("`@("\O($9I;'1E<B!O=70@86QL(&AE861I;F=S('=I=&AO
M=70@8VAI;&1R96XN"B`@("`@("`@:68@*"1P87)A;7-;)W-T871U<R==(#T]
M("=H96%D:6YG)R`F)B!E;7!T>2@D8VAI;&1R96Y;)&%P<%TI*2!["B`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE;G5;)&%P
M<%T@/2`D<&%R86US.PH@("`@?0H*("`@("\O($%D9"!T:&4@861M:6YI<W1R
M871I;VX@;65N=2!I9B!T:&4@=7-E<B!I<R!A;B!A9&UI;BX*("`@(&EF("A!
M=71H.CII<T%D;6EN*"DI('L*("`@("`@("`D;65N=5LG861M:6YI<W1R871I
M;VXG72`](&%R<F%Y*"=N86UE)R`]/B!?*")!9&UI;FES=')A=&EO;B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VXG
M(#T^("1R96=I<W1R>2T^9V5T26UA9V5$:7(H*2`N("<O861M:6YI<W1R871I
M;VXN<&YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=S=&%T=7,G(#T^("=H96%D:6YG)RD["@H@("`@("`@(&9O<F5A8V@@
M*"1R96=I<W1R>2T^;&ES=$%P<',H*2!A<R`D87!P*2!["B`@("`@("`@("`@
M(&EF("@A)')E9VES=')Y+3YH87--971H;V0H)V%D;6EN7VQI<W0G+"`D87!P
M*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1L:7-T(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E
M*"1A<'`L("=A9&UI;E]L:7-T)RD["B`@("`@("`@("`@(&EF("AI<U]A*"1L
M:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&QI<W0@
M87,@)&UE=&AO9"`]/B`D=F%L<RD@>PH@("`@("`@("`@("`@("`@:68@*"1A
M<'`@(3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1V86QS6R=N86UE)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1N86UE("X]("<@)R`N("1V86QS6R=N86UE)UT["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D;F%M92`]($AO<F1E.CIS=')I<$%C8V5S
M<TME>2@D=F%L<ULG;F%M92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1I8V]N(#T@:7-S970H)'9A;'-;)VEC;VXG72D@/R`D<F5G
M:7-T<GDM/F=E=$EM86=E1&ER*"1A<'`I("X@)R\G("X@)'9A;'-;)VEC;VXG
M72`Z("1R96=I<W1R>2T^9V5T*"=I8V]N)RP@)&%P<"D["@H@("`@("`@("`@
M("`@("`@)&UE;G5;)V%D;6EN:7-T<F%T:6]N7R<@+B`D87!P("X@)U\G("X@
M)&UE=&AO9%T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G;F%M92<@
M/3X@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("1I8V]N
M+`H@("`@("`@("`@("`@("`@("`@("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@
M("`@("`@("`@("`@("`@("`@("=M96YU7W!A<F5N="<@/3X@)V%D;6EN:7-T
M<F%T:6]N)RP*("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ
M=7)L*"1R96=I<W1R>2T^87!P;&EC871I;VY796)0871H*"1V86QS6R=L:6YK
M)UTL("1A<'`I*2P*("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@(&EF("A(;W)D93HZ<VAO=U-E<G9I
M8V4H)V]P=&EO;G,G*2`F)@H@("`@("`@("1C;VYF6R=P<F5F<R==6R=D<FEV
M97(G72`A/2`G)R`F)B`D8V]N9ELG<')E9G,G75LG9')I=F5R)UT@(3T@)VYO
M;F4G*2!["B`@("`@("`@)&UE;G5;)V]P=&EO;G,G72`](&%R<F%Y*"=N86UE
M)R`]/B!?*")/<'1I;VYS(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG971);6%G
M941I<B@I("X@)R]P<F5F<RYP;F<G*3L*"B`@("`@("`@+RH@1V5T(&$@;&ES
M="!O9B!C;VYF:6=U<F%B;&4@87!P;&EC871I;VYS+B`J+PH@("`@("`@("1P
M<F5F<U]A<'!S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<F5G:7-T
M<GDM/F%P<&QI8V%T:6]N<R!A<R`D87!P;&EC871I;VX@/3X@)'!A<F%M<RD@
M>PH@("`@("`@("`@("!I9B`H)'!A<F%M<ULG<W1A='5S)UT@/3T@)VAE861I
M;F<G('Q\"B`@("`@("`@("`@("`@("`D<&%R86US6R=S=&%T=7,G72`]/2`G
M8FQO8VLG('Q\"B`@("`@("`@("`@("`@("`A9FEL95]E>&ES=',H)')E9VES
M=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<&QI8V%T:6]N*2`N("<O8V]N9FEG
M+W!R969S+G!H<"<I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0VAE8VL@:68@=&AE(&-U<G)E
M;G0@=7-E<B!H87,@<&5R;6ES<VEO;B!T;R!S964@=&AI<PH@("`@("`@("`@
M("`@*B!A<'!L:6-A=&EO;BP@86YD(&EF('1H92!A<'!L:6-A=&EO;B!I<R!A
M8W1I=F4N"B`@("`@("`@("`@("`J($%D;6EN:7-T<F%T;W)S(&%L=V%Y<R!S
M964@86QL(&%P<&QI8V%T:6]N<RX@*B\*("`@("`@("`@("`@:68@*"A!=71H
M.CII<T%D;6EN*"D@)B8@)'!A<F%M<ULG<W1A='5S)UT@(3T@)VEN86-T:79E
M)RD@?'P*("`@("`@("`@("`@("`@("@D<F5G:7-T<GDM/FAA<U!E<FUI<W-I
M;VXH)&%P<&QI8V%T:6]N*2`F)@H@("`@("`@("`@("`@("`@("@D<&%R86US
M6R=S=&%T=7,G72`]/2`G86-T:79E)RDI*2!["B`@("`@("`@("`@("`@("`D
M<')E9G-?87!P<ULD87!P;&EC871I;VY=(#T@7R@D<&%R86US6R=N86UE)UTI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1P<F5F<U]A<'!S6R=H;W)D92==*2D@>PH@("`@("`@("`@("`D;65N=5LG
M;W!T:6]N<U\G("X@)VAO<F1E)UT@/2!A<G)A>2@G;F%M92<@/3X@7R@B1VQO
M8F%L($]P=&EO;G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M96YU7W!A<F5N="<@/3X@)V]P=&EO;G,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)')E9VES
M=')Y+3YG970H)VEC;VXG+"`G:&]R9&4G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P<F5F<RYP:'`_87!P/6AO<F1E
M)RDI.PH@("`@("`@("`@("!U;G-E="@D<')E9G-?87!P<ULG:&]R9&4G72D[
M"B`@("`@("`@?0H*("`@("`@("!A<V]R="@D<')E9G-?87!P<RD["B`@("`@
M("`@9F]R96%C:"`H)'!R969S7V%P<',@87,@)&%P<"`]/B`D;F%M92D@>PH@
M("`@("`@("`@("`D;65N=5LG;W!T:6]N<U\G("X@)&%P<%T@/2!A<G)A>2@G
M;F%M92<@/3X@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65N=5]P
M87)E;G0G(#T^("=O<'1I;VYS)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("1R96=I<W1R>2T^9V5T
M*"=I8V]N)RP@)&%P<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=U<FPG(#T^($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G<V5R=FEC97,O<')E9G,N<&AP/V%P<#TG("X@)&%P<"DI.PH@("`@("`@
M('T*("`@('T*"B`@("!I9B`H075T:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*
M("`@("`@("`D;65N=5LG;&]G;W5T)UT@/2!A<G)A>2@G;F%M92<@/3X@7R@B
M3&]G(&]U="(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S
M=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=I8V]N)R`]/B`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"D@+B`G
M+VQO9V]U="YP;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=U<FPG(#T^($AO<F1E.CIG971397)V:6-E3&EN:R@G;&]G;W5T)RP@)VAO
M<F1E)RP@=')U92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1A<F=E="<@/3X@)U]P87)E;G0G*3L*("`@('T@96QS92!["B`@("`@("`@
M)&UE;G5;)VQO9VEN)UT@/2!A<G)A>2@G;F%M92<@/3X@7R@B3&]G(&EN(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1A='5S)R`]/B`G
M86-T:79E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N
M)R`]/B`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"D@+B`G+VQO9VEN+G!N9R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B!(;W)D
M93HZ9V5T4V5R=FEC94QI;FLH)VQO9VEN)RP@)VAO<F1E)RP@=')U92P@9F%L
M<V4I*3L*("`@('T*"B`@("!R971U<FX@)&UE;G4["GT*"D!D969I;F4H)T%5
M5$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$
M15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+U1R964N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:RYP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*"FEF
M("@A075T:#HZ9V5T075T:"@I("8F("$D8V]N9ELG;65N=2==6R=A;'=A>7,G
M72D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T
M*"D["GT*"B1I<U]M;WIB87(@/2`H8F]O;"E5=&EL.CIG971&;W)M1&%T82@G
M;6]Z8F%R)RD["@HO+R!3970@=7`@=&AE('1R964N"B1T<F5E(#T@)DAO<F1E
M7U1R964Z.G-I;F=L971O;B@G:&]R9&5?;65N=2<L("=J879A<V-R:7!T)RD[
M"B1T<F5E+3YS971/<'1I;VXH87)R87DH)W1A<F=E="<@/3X@)&ES7VUO>F)A
M<B`_("=?8V]N=&5N="<@.B`G:&]R9&5?;6%I;B<I*3L*"B1M96YU(#T@8G5I
M;&1-96YU*"D["F9O<F5A8V@@*"1M96YU(&%S("1A<'`@/3X@)'!A<F%M<RD@
M>PH@("`@:68@*"1P87)A;7-;)W-T871U<R==(#T]("=B;&]C:R<I('L*("`@
M("`@("`D8FQO8VL@/2`F2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ9V5T0FQO
M8VLH)'!A<F%M<ULG87!P)UTL("1P87)A;7-;)V)L;V-K;F%M92==*3L*("`@
M("`@("!I9B`H:7-?82@D8FQO8VLL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@2&]R9&4Z.F9A=&%L*"1B;&]C:RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"B`@("`@("`@)&)L;V-K+3YB=6EL9%1R964H)'1R964L
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)'!A<F%M<ULG
M;65N=5]P87)E;G0G72D@/R`D<&%R86US6R=M96YU7W!A<F5N="==(#H@;G5L
M;"D["B`@("!](&5L<V4@>PH@("`@("`@("\O($YE960@=&\@<G5N('1H92!N
M86UE('1H<F]U9V@@9V5T=&5X="!S:6YC92!T:&4@=7-E<B=S"B`@("`@("`@
M+R\@;&]C86QE(&UA>2!N;W0@:&%V92!B965N(&QO861E9"!W:&5N(')E9VES
M=')Y+G!H<"!W87,*("`@("`@("`O+R!P87)S960N"B`@("`@("`@)&YA;64@
M/2!?*"1P87)A;7-;)VYA;64G72D["@H@("`@("`@("\O($AE861I;F=S(&AA
M=F4@;F\@=V5B<F]O=#L@=&AE>2=R92!J=7-T(&-O;G1A:6YE<G,@9F]R(&]T
M:&5R"B`@("`@("`@+R\@;65N=2!I=&5M<RX*("`@("`@("!I9B`H:7-S970H
M)'!A<F%M<ULG=7)L)UTI*2!["B`@("`@("`@("`@("1U<FP@/2`D<&%R86US
M6R=U<FPG73L*("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG<W1A='5S)UT@
M/3T@)VAE861I;F<G('Q\("%I<W-E="@D<&%R86US6R=W96)R;V]T)UTI*2![
M"B`@("`@("`@("`@("1U<FP@/2!N=6QL.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1P87)A;7-;)W=E8G)O;W0G
M72`N("<O)R`N("AI<W-E="@D<&%R86US6R=I;FET:6%L7W!A9V4G72D@/R`D
M<&%R86US6R=I;FET:6%L7W!A9V4G72`Z("<G*2D["B`@("`@("`@?0H*("`@
M("`@("`D;F]D95]P87)A;7,@/2!A<G)A>2@G=7)L)R`]/B`D=7)L+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T87)G970G(#T^(&ES<V5T*"1P
M87)A;7-;)W1A<F=E="==*2`_("1P87)A;7-;)W1A<F=E="==(#H@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@:7-S970H
M)'!A<F%M<ULG:6-O;B==*2`_("1P87)A;7-;)VEC;VXG72`Z("1R96=I<W1R
M>2T^9V5T*"=I8V]N)RP@)&%P<"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VEC;VYD:7(G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@)'1R964M/F%D9$YO9&4H)&%P<"P@(65M<'1Y
M*"1P87)A;7-;)VUE;G5?<&%R96YT)UTI(#\@)'!A<F%M<ULG;65N=5]P87)E
M;G0G72`Z(&YU;&PL("1N86UE+"`P+"!F86QS92P@)&YO9&5?<&%R86US*3L*
M("`@('T*?0H*+R\@268@=V4G<F4@<V5R=FEN9R!A(')E<75E<W0@=&\@=&AE
M($I3('5P9&%T92!C;&EE;G0L(&IU<W0@<F5N9&5R('1H90HO+R!U<&1A=&5D
M(&YO9&4@:F%V87-C<FEP="X*:68@*%5T:6PZ.F=E=$9O<FU$871A*"=H='1P
M8VQI96YT)RDI('L*("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+VIA
M=F%S8W)I<'0[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@
M($AO<F1E.CII;FQI;F538W)I<'1&:6QE<R@I.PH@("`@96-H;R`D=')E92T^
M<F5N9&5R3F]D941E9FEN:71I;VYS*"D["B`@("!E>&ET.PI]"@HD<G1L(#T@
M:7-S970H)&YL<ULG<G1L)UU;)&QA;F=U86=E72D["B1B;V1Y0VQA<W,@/2`G
M<VED96)A<B<["FEF("@D8G)O=W-E<BT^:&%S475I<FLH)W-C<F]L;&)A<E]I
M;E]W87DG*2D@>PH@("`@)&)O9'E#;&%S<R`N/2`G('-C<F]L;&)A<BUQ=6ER
M:R<["GT*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAT='!C;&EE;G0N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAI9&5A8FQE
M+FIS)RP@)VAO<F1E)RP@=')U92D["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]P;W)T86PO<VED96)A<BYI;F,G.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<```````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`Q,``Q,#4Q-30S,3`V-``P,C$S-#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<"QV(#$N,SDN,3`N-R`R,#`V+S`S+S`X(#$X.C`P.C4V(&-H=6-K($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E
M9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N
M+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH*:68@*"%!=71H
M.CII<T%U=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T
M:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\O($=E="!F=6QL(&YA;64@9F]R
M('1I=&QE"B1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B1F
M=6QL;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN86UE)RD["FEF
M("AE;7!T>2@D9G5L;&YA;64I*2!["B`@("`D9G5L;&YA;64@/2!!=71H.CIG
M971!=71H*"D["GT*"B\O($=E="!R969R97-H(&EN=&5R=F%L+@II9B`H)'!R
M969S+3YG971686QU92@G<W5M;6%R>5]R969R97-H7W1I;64G*2D@>PH@("`@
M)')E9G)E<VA?=&EM92`]("1P<F5F<RT^9V5T5F%L=64H)W-U;6UA<GE?<F5F
M<F5S:%]T:6UE)RD["B`@("`D<F5F<F5S:%]U<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"\G*3L*?0H*+R\@3&]A9"!L87EO
M=70@9G)O;2!P<F5F97)E;F-E<RX*)&QA>6]U=%]P<F5F(#T@)'!R969S+3YG
M971686QU92@G<&]R=&%L7VQA>6]U="<I.PII9B`H(21L87EO=71?<')E9BD@
M>PH@("`@)&QA>6]U=%]P<F5F(#T@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ
M9V5T1FEX961";&]C:W,H*3L*?0HD=FEE=R`](&YE=R!(;W)D95]";&]C:U],
M87EO=71?5FEE=R@D;&%Y;W5T7W!R968I.PHD;&%Y;W5T7VAT;6P@/2`D=FEE
M=RT^=&](=&UL*"D["B1C<W-!<'!S(#T@)'9I97<M/F=E=$%P<&QI8V%T:6]N
M<R@I.PHD;&EN:U1A9W,@/2`D=FEE=RT^9V5T3&EN:U1A9W,H*3L*"B1T:71L
M92`](%\H(DUY(%!O<G1A;"(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O<&]R=&%L+VUE;G4N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y
M*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["F5C:&\@)&QA>6]U
M=%]H=&UL.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O
M;W1E<BYI;F,G.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,C(U,#0`,3`U,34T,S$P-C0`,#(Q-34U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M+'8@,2XS+C(N-B`R,#`V+S`U+S(Y(#$V.C0P.C0Y(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T
M96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!L;V%D
M0V%T96=O<FEE<R@D9&5V:6-E*0I["B`@("!G;&]B86P@)&1T+"`D8V%T96=O
M<FEE<TUA<"P@)&UI<W-I;F=397)V97)#871E9V]R:65S.PH@("`@)&UA<"`]
M("1D="T^9V5T3V)J96-T*"1D979I8V4*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G.F-A=&5G;W)I97,G*3L*("`@(&EF("AI<U]A*"1M87`L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@)&-A=&5G;W)I97--87`@/2`D;6%P+3YG970H)VUA<"<I.PH@("`@)&UI
M<W-I;F=397)V97)#871E9V]R:65S(#T@)&UA<"T^9V5T*"=M:7-S:6YG4V5R
M=F5R0V%T96=O<FEE<R<I.PH*("`@(')E='5R;B!T<G5E.PI]"@IF=6YC=&EO
M;B!S=&]R94-A=&5G;W)I97,H)&1E=FEC92D*>PH@("`@9VQO8F%L("1D="P@
M)&-A=&5G;W)I97--87`L("1M:7-S:6YG4V5R=F5R0V%T96=O<FEE<SL*"B`@
M("!I9B`H(6ES7V%R<F%Y*"1C871E9V]R:65S36%P*2D@>PH@("`@("`@(')E
M='5R;CL@+R\@;F]T:&EN9R!T;R!D;PH@("`@?0H*("`@("1M87`@/2`F;F5W
M($1A=&%4<F5E3V)J96-T*"1D979I8V4@+B`G.F-A=&5G;W)I97,G*3L*("`@
M("1M87`M/G-E="@G;6%P)RP@)&-A=&5G;W)I97--87`I.PH@("`@)&UA<"T^
M<V5T*"=M:7-S:6YG4V5R=F5R0V%T96=O<FEE<R<L("1M:7-S:6YG4V5R=F5R
M0V%T96=O<FEE<RD["@H@("`@)'(@/2`D9'0M/F%D9"@D;6%P*3L*("`@(&EF
M("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@+R\@3V)J96-T
M(&%L<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`D<B`]
M("1D="T^=7!D871E1&%T82@D;6%P*3L*("`@('T*?0H*0&1E9FEN92@G2$]2
M1$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]0<F5F<R]522YP:'`G.PH*:68@*"%!=71H.CII<T%U
M=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I
M;'5R95)E9&ER96-T*"D["GT*"B1D<FEV97(@/2`D1TQ/0D%,4ULG8V]N9B==
M6R=D871A=')E92==6R=D<FEV97(G73L*)'!A<F%M<R`]($AO<F1E.CIG971$
M<FEV97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BD["B1P87)A;7,@/2!A
M<G)A>5]M97)G92@D<&%R86US+"!A<G)A>2@@)V=R;W5P)R`]/B`G<WEN8VUL
M)R`I*3L*"B1D="`]("9$871A5')E93HZ<VEN9VQE=&]N*"1D<FEV97(L("1P
M87)A;7,I.PH*+RH@57-E<FYA;64@:7,@=7-E9"!A<R!R;V]T(&9O<B!S>6YC
M;6P@9&%T871R964N("`H1F]R(&AI<W1O<FEC"B`J(')E87-O;G,N*2`J+PHD
M=7-E<FYA;64@/2!!=71H.CIG971!=71H*"D["B1G<F]U<"`]("=S>6YC;6PG
M.R`O+R!P<F5F97)E;F-E(&=R;W5P"@HD86-T:6]N240@/2!5=&EL.CIG971&
M;W)M1&%T82@G86-T:6]N240G*3L*<W=I=&-H("@D86-T:6]N240I('L*8V%S
M92`G9&5L971E86YC:&]R)SH*("`@("1D979I8V5I9"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=D979I8V5I9"<I.PH@("`@)&1B(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V1B)RD["B`@("`D:60@/2`D=7-E<FYA;64@+B`G.B<@+B`D9&5V:6-E
M:60@+B`G.G-U;6UA<GDZ)R`N("1D8CL*("`@("1I9"`]("1D="T^<F5M;W9E
M*"1I9"QF86QS92D["B`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(BDL("1I9"T^9V5T365S<V%G
M92@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YE<G)O
M<B<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(B1I9"!3>6YC(&%N8VAO<B!F;W(@9&5V:6-E("<D9&5V:6-E:60G(&1A
M=&%B87-E("<D9&(G(&1E;&5T960N(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?0H@("`@8G)E86L["@IC
M87-E("=D96QE=&5L;V<G.@H@("`@)&ED(#T@)&1T+3YR96UO=F4H)W!R979I
M;W5S4WEN8TQO9R<L(&9A;'-E*3L*("`@(&EF("AI<U]A*"1I9"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B*2P@)&ED+3YG971-
M97-S86=E*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E
M+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H7R@B4WEN8R!L;V<@9&5L971E9"(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T*("`@(&)R96%K
M.PH*(&-A<V4@)W5P9&%T95]C871E9V]R:65S)SH*("`@("1D979I8V4@/2!5
M=&EL.CIG971&;W)M1&%T82@G9&5V:6-E)RD["B`@("!L;V%D0V%T96=O<FEE
M<R@D9&5V:6-E*3L*"B`@("!F;W)E86-H("@D7U!/4U0@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("!I9B`H<W5B<W1R*"1K97DL(#`L(#DI(#T]("=C
M871E9V]R>3HG*2!["B`@("`@("`@("`@("1C871E9V]R>2`]('-U8G-T<B@D
M:V5Y+#DI.PH@("`@("`@("`@("!L:7-T*"PD8V%T96=O<GDI(#T@97AP;&]D
M92@G.B<L("1K97DL,BD["B`@("`@("`@("`@("1V86QU92`](%5T:6PZ.F=E
M=$9O<FU$871A*"1K97DI.PH@("`@("`@("`@("`D8V%T96=O<FEE<TUA<%LD
M8V%T96=O<GE=(#T@)'9A;'5E.PH@("`@("`@("`@("!U;G-E="@D;6ES<VEN
M9U-E<G9E<D-A=&5G;W)I97-;)'9A;'5E72D["B`@("`@("`@?0H@("`@?0H@
M("`@<W1O<F5#871E9V]R:65S*"1D979I8V4I.PH@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"A?*")-87!P:6YG<R!S=&]R960N(BDI.PH*("`@(&)R96%K.PI]
M"@HO*B!3:&]W('1H92!H96%D97(N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O
M4')E9G,O54DN<&AP)SL*<F5Q=6ER92!(3U)$15]"05-%("X@)R]C;VYF:6<O
M<')E9G,N<&AP)SL*)&%P<"`]("=H;W)D92<["@I0<F5F<U]523HZ:&%N9&QE
M1F]R;2@D9W)O=7`L("1P<F5F<RD["E!R969S7U5).CIG96YE<F%T94AE861E
M<B@D9W)O=7`I.PH*+R\@0'1O9&\Z(&UO=F4@=&AI<R!T;R!T96UP;&%T90H_
M/@H*/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)P<F5F<R(@86-T:6]N/2(\
M/W!H<"!E8VAO($AO<F1E.CI!<'!L:6-A=&EO;E523"@G+W-E<G9I8V5S+W!R
M969S+G!H<"<I(#\^(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T
M:6]N240B('9A;'5E/2)U<&1A=&5?<')E9G,B("\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](F=R;W5P(B!V86QU93TB/#]P:'`@96-H;R`D9W)O=7`@
M/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%P<"(@=F%L=64]
M(FAO<F1E(B`O/@I3;W)R>2P@;F\@8V]N9FEG=7)A8FQE(&]P=&EO;G,@>65T
M+@I3964@/&$@:')E9CTB:'1T<#HO+W=I:VDN:&]R9&4N;W)G+U-Y;F-(;W=4
M;R(^4WEN8R!(;W=4;SPO83X@9F]R(&9U<G1H97(@:6YF;W)M871I;VXN"CP_
M<&AP("\J("1H96QP;&EN:STG)SL@)'!R968])W-Y;F-M;%]C<F5A=&5?;&]G
M)SL@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E
M)RD@+B`G+W!R969S+V-H96-K8F]X+FEN8R<@*B\@/SX*"CQP(&-L87-S/2)N
M;W=R87`B/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@
M=F%L=64](E-A=F4@3W!T:6]N<R(@+SX*(#QI;G!U="!T>7!E/2)R97-E="(@
M8VQA<W,](F)U='1O;B(@=F%L=64](E5N9&\@0VAA;F=E<R(@+SX*(#QI;G!U
M="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2)2971U<FX@
M=&\@3W!T:6]N<R(@;VYC;&EC:STB9&]C=6UE;G0N<')E9G,N86-T:6]N240N
M=F%L=64],#L@9&]C=6UE;G0N<')E9G,N9W)O=7`N=F%L=64])R<[(&1O8W5M
M96YT+G!R969S+G-U8FUI="@I.R(@+SX*/"]P/@H\+V9O<FT^"CP_<&AP"B1I
M9"`]("1D="T^9V5T260H)'5S97)N86UE*3L*)&1E=FEC97,@/2`D9'0M/F=E
M=$)Y260H1$%40512145?1D]234%47T9,050L("1I9"P@=')U92P@1$%40512
M145?4D]/5"P@,2D["FEF("AI<U]A<G)A>2@D9&5V:6-E<RD@)B8@8V]U;G0H
M)&1E=FEC97,I(#X@,2D@>PH@("`@87)R87E?<VAI9G0H)&1E=FEC97,I.PH*
M+R\@0'1O9&\Z(&UO=F4@=&\@=&5M<&QA=&4*/SX*/&1I=B!C;&%S<STB:&5A
M9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH2&]R9&4Z.G-E;&954DPH
M*2P@7R@B4F5F<F5S:"(I*2`N($AO<F1E.CII;6<H)W)E;&]A9"YP;F<G+"!?
M*")296QO860B*2P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI(#\^/"]A/@H@5&EM97-T86UP<R!O9B!S=6-C97-S9G5L('-Y;F,@<V5S
M<VEO;G,*/"]D:78^"CQT86)L92!C;&%S<STB<W1R:7!E9"(@/@H@/'1R/@H@
M(#QT:#Y$979I8V4\+W1H/CQT:#Y$871A8F%S93PO=&@^/'1H/E-E<G9E<BU4
M4SPO=&@^/'1H/D-L:65N="U44SPO=&@^"B`@/'1H/D1E;&5T93PO=&@^"B`\
M+W1R/@H*/#]P:'`*("`@(&9O<F5A8V@@*"1D979I8V5S(&%S("1D979I8V4I
M('L*("`@("`@("`D=&UP(#T@97AP;&]D92@G.B<L("1D979I8V4I.PH@("`@
M("`@("1D979I8V5?;F%M92`](&%R<F%Y7W!O<"@D=&UP*3L*"B`@("`@("`@
M)&ED(#T@)&1T+3YG971)9"@D9&5V:6-E("X@)SIS=6UM87)Y)RD["B`@("`@
M("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D<W5M;6%R:65S(#T@)&1T
M+3YG971">4ED*$1!5$%44D5%7T9/4DU!5%]44D5%+"`D:60L(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$%40512145?4D]/
M5"P@,BD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D<W5M;6%R:65S6R1I9%TI
M*2!["B`@("`@("`@("`@("1O(#T@)B`D9'0M/F=E=$]B:F5C=',H87)R87E?
M:V5Y<R@D<W5M;6%R:65S6R1I9%TI*3L*"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1O(&%S("1O;RD@>PH@("`@("`@("`@("`@("`@)'0@/2!E>'!L;V1E*"<Z
M)RP@)&]O+3YG971.86UE*"DI.PH@("`@("`@("`@("`@("`@)&1B(#T@87)R
M87E?<&]P*"1T*3L*("`@("`@("`@("`@("`@("1S82`]("1O;RT^9V5T*"=3
M97)V97)!;F-H;W(G*3L*("`@("`@("`@("`@("`@("1C82`]("1O;RT^9V5T
M*")#;&EE;G1!;F-H;W(B*3L*"B`@("`@("`@("`@("`@("`O+R!`=&]D;SH@
M;6]V92!T;R!T96UP;&%T90H@("`@("`@("`@("`@("`@96-H;R`G/'1R/CQT
M9#XG("X@)&1E=FEC95]N86UE("X@)SPO=&0^/'1D/B<@+B`D9&(@+B`G/"]T
M9#X\=&0^)R`N"B`@("`@("`@("`@("`@("`@("`@<W1R9G1I;64H)'!R969S
M+3YG971686QU92@G9&%T95]F;W)M870G*2`N("<@)4@Z)4TG+"!A<G)A>5]P
M;W`H)'-A*2D@+@H@("`@("`@("`@("`@("`@("`@("<\+W1D/CQT9#XG("X@
M87)R87E?<&]P*"1C82D@+B`G/"]T9#X\=&0^)R`N"B`@("`@("`@("`@("`@
M("`@("`@)SQF;W)M(&UE=&AO9#TB<&]S="(^/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB9&5V:6-E:60B('9A;'5E/2(G("X*("`@("`@("`@("`@("`@
M("`@("`D9&5V:6-E7VYA;64@+B`G(B\^)R`N"B`@("`@("`@("`@("`@("`@
M("`@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU
M93TB9&5L971E86YC:&]R(B`O/B<@+@H@("`@("`@("`@("`@("`@("`@("<\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)D8B(@=F%L=64](B<@+B`D9&(@
M+B`G(B`O/B<@+@H@("`@("`@("`@("`@("`@("`@("<\:6YP=70@='EP93TB
M<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB1&5L971E(B`O/CPO9F]R
M;3XG("X*("`@("`@("`@("`@("`@("`@("`G/"]T9#X\+W1R/B<["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("!E8VAO("<\+W1A8FQE/B<[
M"GT*"B\O($-A=&5G;W)Y(&AA;F1L:6YG+@IR97%U:7)E7V]N8V4@)TAO<F1E
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`G.PHD8TUA;F%G97(@/2`F;F5W
M(%!R969S7T-A=&5G;W)Y36%N86=E<B@I.PH*9F]R96%C:"`H)&1E=FEC97,@
M87,@)&1E=FEC92D@>PH@("`@)'1M<"`](&5X<&QO9&4H)SHG+"`D9&5V:6-E
M*3L*("`@("1D979I8V5?;F%M92`](&%R<F%Y7W!O<"@D=&UP*3L*"B`@("!I
M9B`H(6QO861#871E9V]R:65S*"1D979I8V4I*2!["B`@("`@("`@8V]N=&EN
M=64["B`@("!]"B\O=F%R7V1U;7`H)&-L:65N"B`@("`D:2`](#`["B\O($!T
M;V1O.B!M;W9E('1O('1E;7!L871E"C\^"CQF;W)M(&UE=&AO9#TB<&]S="(@
M;F%M93TB<')E9G,B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E52
M3"@I(#\^(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B
M('9A;'5E/2)U<&1A=&5?8V%T96=O<FEE<R(@+SX*/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB9&5V:6-E(B!V86QU93TB/#]P:'`@96-H;R`D9&5V:6-E
M(#\^(B`O/@H*/&1I=B!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R
M9&4Z.FQI;FLH2&]R9&4Z.G-E;&954DPH*2P@7R@B4F5F<F5S:"(I*2`N($AO
M<F1E.CII;6<H)W)E;&]A9"YP;F<G+"!?*")296QO860B*2P@)R<L("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@36%P<&EN9R!O
M9B!#871E9V]R:65S(&9O<B!$979I8V4@/#]P:'`@96-H;R`D9&5V:6-E7VYA
M;64@/SX*/"]D:78^"CQT86)L92!C;&%S<STB<W1R:7!E9"(@/@H\='(^/'1H
M/D1E=FEC92!#871E9V]R>3PO=&@^/'1H/DAO<F1E($-A=&5G;W)Y/"]T:#X*
M/'1H/E-U;6UA<GD@;V8@;&%S="!E;F-O=6YT97)E9"!E;G1R>3PO=&@^/"]T
M<CX*/#]P:'`*("`@(&9O<F5A8V@@*"1C871E9V]R:65S36%P(&%S("1K97D@
M/3X@)'9A;'5E*2!["B`@("`@("`@96-H;R`B/'1R(&-L87-S/5PB:71E;2(@
M+B`H*RLD:2`E(#(I("X@(EPB/CQT9#XB"B`@("`@("`@+B`D:V5Y+B`G/"]T
M9#X\=&0^)SL*("`@("`@("`D=B`](&ES7V%R<F%Y*"1V86QU92D@/R`G)R`Z
M("1V86QU93L*("`@("`@("!E8VAO("1C36%N86=E<BT^9V5T4V5L96-T*"=C
M871E9V]R>3HG("X@)&ME>2P@)'8I.PH@("`@("`@(&5C:&\@)SPO=&0^/'1D
M/B<["B`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@
M("`@96-H;R`D=F%L=65;,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@96-H;R`B)FYB<W`[(CL*("`@("`@("!]"B`@("`@("`@96-H;R`G/"]T
M9#X\+W1R/B<["@H@("`@?0H@("`@9F]R96%C:"`H)&UI<W-I;F=397)V97)#
M871E9V]R:65S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@96-H;R`G
M/'1R/CQT9#X\96T^=&\@8F4@9&5F:6YE9#PO96T^/"]T9#X\=&0^)R`N("1K
M97D@+B`G/"]T9#X\=&0^)R`N("1V86QU92`N("<\+W1D/CPO='(^)SL*("`@
M('T*"B`@("!E8VAO("(\+W1A8FQE/EQN(CL*("`@(&5C:&\@)SQI;G!U="!T
M>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2)5<&1A=&4@0V%T
M96=O<FEE<R(@+SX\+V9O<FT^)SL*?0H*+RH@1&ES<&QA>2!L;V<@;V8@<')E
M=FEO=7,@<WEN8RX@*B\*)&YA;64@/2`G<')E=FEO=7-3>6YC3&]G)SL*)&EN
M9F\@/2`F)&1T+3YG971/8FIE8W0H)&YA;64I.PH*:68@*"%I<U]A*"1I;F9O
M+"`G4$5!4E]%<G)O<B<I("8F(&ES7V%R<F%Y*"1L;V<@/2`D:6YF;RT^9V5T
M*"=L;V<G*2DI('L*("`@("\O($!T;V1O(&UO=F4@=&\@=&5M<&QA=&4*/SX*
M/&1I=B!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@7R@B3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;B(I(#\^"B`\/W!H<"!E8VAO($AO<F1E.CIL
M:6YK*$AO<F1E.CIS96QF55),*"DL(%\H(E)E9G)E<V@B*2D@+B!(;W)D93HZ
M:6UG*"=R96QO860N<&YG)RP@7R@B4F5F<F5S:"(I*2`_/CPO83X*(#QF;W)M
M(&UE=&AO9#TB<&]S="(^"B`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M86-T:6]N240B('9A;'5E/2)D96QE=&5L;V<B("\^"B`@/&EN<'5T('1Y<&4]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M1&5L971E($QO9R(I(#\^(B`O/@H@/"]F;W)M/@H\+V1I=CX*"CQT86)L92!C
M;&%S<STB<W1R:7!E9"(@=VED=&@](C$P,"4B/@H@/'1R(&-L87-S/2)N;W=R
M87`B/@H@(#QT:"!W:61T:#TB-24B/CP_<&AP(&5C:&\@7R@B5&EM92(I(#\^
M/"]T:#X\=&@^/#]P:'`@96-H;R!?*"),979E;"(I(#\^/"]T:#X\=&@^/#]P
M:'`@96-H;R!?*")&:6QE(BD@/SX\+W1H/CQT:#X\/W!H<"!E8VAO(%\H(DUE
M<W-A9V4B*2`_/CPO=&@^"B`\+W1R/@H\/W!H<"!F;W)E86-H("@D;&]G(&%S
M("1L;V=E;G1R>2DZ(#\^"B`\='(^"B`@/'1D/@H@("`\/W!H<"!E8VAO('-T
M<F9T:6UE*"1P<F5F<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RD@+B`G("5(
M.B5-.B53)RP@)&QO9V5N=')Y6R=T<R==*2`_/@H@(#PO=&0^"B`@/'1D/@H@
M("`\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&QO9V5N=')Y6R=L979E
M;"==*2`_/@H@(#PO=&0^"B`@/'1D/@H@(#P_<&AP"B`@:68@*'!R96=?;6%T
M8V@H)R]<+U-Y;F--3%PN<&AP)"\G+"`D;&]G96YT<GE;)V9I;&4G72DI('L*
M("`@("`@)&9I;&4@/2`G9G)A;65W;W)K+U-Y;F--3"]3>6YC34PN<&AP)SL*
M("!](&5L<V4@>PH@("`@("`D9FEL92`]('!R96=?<F5P;&%C92@G+UXN*EPO
M4WEN8TU,7"\H+BHI)"\G+"`G9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO)#$G
M+"`D;&]G96YT<GE;)V9I;&4G72D["B`@?0H@(&5C:&\@2&]R9&4Z.FQI;FLH
M)VAT='`Z+R]C=G,N:&]R9&4N;W)G+V-O+G!H<"\G"B`@("`@("`@("`@("`@
M("`@("`N("1F:6QE("`N("<_<CU(14%$(R<@+B!T<FEM*"1L;V=E;G1R>5LG
M;&EN92==*2P@)R<L("<G+"`G8W9S)RD*("`@("`@+B!P<F5G7W)E<&QA8V4H
M)R]>+BI<+RA;7EPO72HI)"\G+"`G)#$G+"`D;&]G96YT<GE;)V9I;&4G72D*
M("`@("`@+B`G.B<@+B!T<FEM*"1L;V=E;G1R>5LG;&EN92==*0H@(#\^"B`@
M/"]T9#X*("`\=&0^"B`@(#P_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M;&]G96YT<GE;)VUE<W-A9V4G72D@/SX*("`\+W1D/@H@/"]T<CX*/#]P:'`@
M96YD9F]R96%C:#L@/SX*/"]T86)L93X*"CP_<&AP"GT*"G)E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]S:&%R97,O````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#8T`#`Q-S4R,P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<```````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C,Q,#<`,3`U,34T,S$P-C0`,#(Q,38Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<"QV(#$N
M,C8N,3`N."`R,#`V+S`U+S`Q(#(Q.C$V.C0Q(&-H=6-K($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HD9FEE;&1S3&ES=%LG<VAO
M=R==(#T@,#L*)&9I96QD<TQI<W1;)W)E860G72`](#$["B1F:65L9'-,:7-T
M6R=E9&ET)UT@/2`R.PHD9FEE;&1S3&ES=%LG9&5L971E)UT@/2`S.PH*0&1E
M9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N
M+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O4VAA<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U
M<"YP:'`G.PH*)&%P<"`](%5T:6PZ.F=E=$9O<FU$871A*"=A<'`G*3L*)'-H
M87)E<R`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1A<'`I.PHD9W)O=7!S
M(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*)&%U=&@@/2`F075T:#HZ<VEN9VQE
M=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*"B1F;W)M(#T@;G5L;#L*
M)')E;&]A9"`](&9A;'-E.PHD86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T
M82@G86-T:6]N240G+"`G961I="<I.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC
M87-E("=E9&ET)SH*("`@("1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R94)Y
M260H571I;#HZ9V5T1F]R;41A=&$H)V-I9"<I*3L*("`@(&EF("@A:7-?82@D
M<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`D9F]R;2`]("=E9&ET
M+FEN8R<["B`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N
M*"D["B`@("!](&5L<V5I9B`H*"1C871E9V]R>2`](%5T:6PZ.F=E=$9O<FU$
M871A*"=S:&%R92<I*2`A/3T@;G5L;"D@>PH@("`@("`@("1S:&%R92`]("8D
M<VAA<F5S+3YG9713:&%R92@D8V%T96=O<GDI.PH@("`@("`@(&EF("@A:7-?
M82@D<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&9O<FT@
M/2`G961I="YI;F,G.PH@("`@("`@("`@("`D<&5R;2`]("8D<VAA<F4M/F=E
M=%!E<FUI<W-I;VXH*3L*("`@("`@("!]"B`@("!]"B`@("!I9B`H:7-?82@D
M<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*"1S:&%R92P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V5I9B`H
M:7-S970H)'-H87)E*2`F)B!!=71H.CIG971!=71H*"D@(3T@)'-H87)E+3YG
M970H)V]W;F5R)RDI('L*("`@("`@("!E>&ET*"=P97)M:7-S:6]N(&1E;FEE
M9"<I.PH@("`@?0H@("`@8G)E86L["@IC87-E("=E9&ET9F]R;2<Z"B`@("`D
M<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F5">4ED*%5T:6PZ.F=E=$9O<FU$
M871A*"=C:60G*2D["B`@("!I9B`H:7-?82@D<VAA<F4L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("!](&5L<V4@>PH@("`@("`@(&EF("A!=71H.CIG971!=71H*"D@
M(3T@)'-H87)E+3YG970H)V]W;F5R)RDI('L*("`@("`@("`@("`@97AI="@G
M<&5R;6ES<VEO;B!D96YI960G*3L*("`@("`@("!]"B`@("`@("`@)'!E<FT@
M/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["@H@("`@("`@("\O(%!R;V-E
M<W,@;W=N97(@86YD(&]W;F5R('!E<FUI<W-I;VYS+@H@("`@("`@("1O;&1?
M;W=N97(@/2`D<VAA<F4M/F=E="@G;W=N97(G*3L*("`@("`@("`D;F5W7V]W
M;F5R(#T@571I;#HZ9V5T1F]R;41A=&$H)V]W;F5R)RP@)&]L9%]O=VYE<BD[
M"B`@("`@("`@:68@*"1O;&1?;W=N97(@(3T]("1N97=?;W=N97(@)B8@(65M
M<'1Y*"1N97=?;W=N97(I*2!["B`@("`@("`@("`@(&EF("@D;VQD7V]W;F5R
M("$]($%U=&@Z.F=E=$%U=&@H*2`F)B`A075T:#HZ:7-!9&UI;B@I*2!["B`@
M("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'-H87)E+3YS970H)V]W;F5R)RP@)&YE=U]O=VYE<BD["B`@("`@
M("`@("`@("`@("`D<VAA<F4M/G-A=F4H*3L*("`@("`@("`@("`@("`@(&EF
M("A5=&EL.CIG971&;W)M1&%T82@G;W=N97)?<VAO=R<I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1N97=?;W=N
M97(L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V955S97)097)M
M:7-S:6]N*"1N97=?;W=N97(L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("A5=&EL.CIG971&;W)M
M1&%T82@G;W=N97)?<F5A9"<I*2!["B`@("`@("`@("`@("`@("`@("`@)'!E
M<FTM/F%D9%5S97)097)M:7-S:6]N*"1N97=?;W=N97(L(%!%4DU37U)%040L
M(&9A;'-E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)'!E<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1N97=?;W=N
M97(L(%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G;W=N97)?961I
M="<I*2!["B`@("`@("`@("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M
M:7-S:6]N*"1N97=?;W=N97(L(%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!E<FTM
M/G)E;6]V955S97)097)M:7-S:6]N*"1N97=?;W=N97(L(%!%4DU37T5$250L
M(&9A;'-E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("A5=&EL.CIG971&;W)M1&%T82@G;W=N97)?9&5L971E)RDI('L*("`@("`@
M("`@("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)&YE=U]O
M=VYE<BP@4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R
M4&5R;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@4')O8V5S<R!D969A=6QT('!E<FUI<W-I;VYS+@H@("`@("`@
M(&EF("A5=&EL.CIG971&;W)M1&%T82@G9&5F875L=%]S:&]W)RDI('L*("`@
M("`@("`@("`@)'!E<FTM/F%D9$1E9F%U;'1097)M:7-S:6]N*%!%4DU37U-(
M3U<L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R
M;2T^<F5M;W9E1&5F875L=%!E<FUI<W-I;VXH4$5235-?4TA/5RP@9F%L<V4I
M.PH@("`@("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V1E
M9F%U;'1?<F5A9"<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1$969A=6QT
M4&5R;6ES<VEO;BA015)-4U]214%$+"!F86QS92D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'!E<FTM/G)E;6]V941E9F%U;'1097)M:7-S:6]N
M*%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:68@*%5T
M:6PZ.F=E=$9O<FU$871A*"=D969A=6QT7V5D:70G*2D@>PH@("`@("`@("`@
M("`D<&5R;2T^861D1&5F875L=%!E<FUI<W-I;VXH4$5235-?141)5"P@9F%L
M<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO
M=F5$969A=6QT4&5R;6ES<VEO;BA015)-4U]%1$E4+"!F86QS92D["B`@("`@
M("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G9&5F875L=%]D
M96QE=&4G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1&5F875L=%!E<FUI
M<W-I;VXH4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!E<FTM/G)E;6]V941E9F%U;'1097)M:7-S:6]N*%!%
M4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@+R\@4')O
M8V5S<R!G=65S="!P97)M:7-S:6]N<RX*("`@("`@("!I9B`H571I;#HZ9V5T
M1F]R;41A=&$H)V=U97-T7W-H;W<G*2D@>PH@("`@("`@("`@("`D<&5R;2T^
M861D1W5E<W1097)M:7-S:6]N*%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W5E<W1097)M
M:7-S:6]N*%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@
M:68@*%5T:6PZ.F=E=$9O<FU$871A*"=G=65S=%]R96%D)RDI('L*("`@("`@
M("`@("`@)'!E<FTM/F%D9$=U97-T4&5R;6ES<VEO;BA015)-4U]214%$+"!F
M86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E
M;6]V94=U97-T4&5R;6ES<VEO;BA015)-4U]214%$+"!F86QS92D["B`@("`@
M("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G9W5E<W1?961I
M="<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1'=65S=%!E<FUI<W-I;VXH
M4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1P97)M+3YR96UO=F5'=65S=%!E<FUI<W-I;VXH4$5235-?141)5"P@
M9F%L<V4I.PH@("`@("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A
M=&$H)V=U97-T7V1E;&5T92<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1'
M=65S=%!E<FUI<W-I;VXH4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E;6]V94=U97-T4&5R;6ES
M<VEO;BA015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%!R;V-E<W,@8W)E871O<B!P97)M:7-S:6]N<RX*("`@("`@("!I9B`H
M571I;#HZ9V5T1F]R;41A=&$H)V-R96%T;W)?<VAO=R<I*2!["B`@("`@("`@
M("`@("1P97)M+3YA9&1#<F5A=&]R4&5R;6ES<VEO;BA015)-4U]32$]7+"!F
M86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E
M;6]V94-R96%T;W)097)M:7-S:6]N*%!%4DU37U-(3U<L(&9A;'-E*3L*("`@
M("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=C<F5A=&]R
M7W)E860G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D0W)E871O<E!E<FUI
M<W-I;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1P97)M+3YR96UO=F5#<F5A=&]R4&5R;6ES<VEO;BA015)-
M4U]214%$+"!F86QS92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG
M971&;W)M1&%T82@G8W)E871O<E]E9&ET)RDI('L*("`@("`@("`@("`@)'!E
M<FTM/F%D9$-R96%T;W)097)M:7-S:6]N*%!%4DU37T5$250L(&9A;'-E*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E0W)E
M871O<E!E<FUI<W-I;VXH4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@('T*
M("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V-R96%T;W)?9&5L971E
M)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$-R96%T;W)097)M:7-S:6]N
M*%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1P97)M+3YR96UO=F5#<F5A=&]R4&5R;6ES<VEO;BA015)-4U]$
M14Q%5$4L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E<W,@
M=7-E<B!P97)M:7-S:6]N<RX*("`@("`@("`D=5]N86UE<R`](%5T:6PZ.F=E
M=$9O<FU$871A*"=U7VYA;65S)RD["B`@("`@("`@)'5?<VAO=R`](%5T:6PZ
M.F=E=$9O<FU$871A*"=U7W-H;W<G*3L*("`@("`@("`D=5]R96%D(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W5?<F5A9"<I.PH@("`@("`@("1U7V5D:70@/2!5
M=&EL.CIG971&;W)M1&%T82@G=5]E9&ET)RD["B`@("`@("`@)'5?9&5L971E
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5?9&5L971E)RD["@H@("`@("`@(&9O
M<F5A8V@@*"1U7VYA;65S(&%S("1K97D@/3X@)'5S97(I('L*("`@("`@("`@
M("`@+R\@268@=&AE('5S97(@:7,@96UP='DL(&]R('=E)W9E(&%L<F5A9'D@
M<V5T('!E<FUI<W-I;VYS"B`@("`@("`@("`@("\O('9I82!T:&4@;W=N97)?
M(&]P=&EO;G,L(&1O;B=T(&1O(&%N>71H:6YG(&AE<F4N"B`@("`@("`@("`@
M(&EF("AE;7!T>2@D=7-E<BD@?'P@)'5S97(@/3T@)&YE=U]O=VYE<BD@>PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@A96UP='DH)'5?<VAO=ULD:V5Y72DI('L*("`@("`@("`@
M("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?
M4TA/5RP@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'!E<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R+"!015)-
M4U]32$]7+"!F86QS92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=5]R96%D6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'!E
M<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R+"!015)-4U]214%$+"!F86QS
M92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&5R
M;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37U)%040L(&9A
M;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1U
M7V5D:71;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^861D57-E
M<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55
M<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?141)5"P@9F%L<V4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)'5?9&5L971E6R1K
M97E=*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S
M:6]N*"1U<V5R+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R
M;6ES<VEO;B@D=7-E<BP@4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E<W,@9W)O=7`@<&5R
M;6ES<VEO;G,N"B`@("`@("`@)&=?;F%M97,@/2!5=&EL.CIG971&;W)M1&%T
M82@G9U]N86UE<R<I.PH@("`@("`@("1G7W-H;W<@/2!5=&EL.CIG971&;W)M
M1&%T82@G9U]S:&]W)RD["B`@("`@("`@)&=?<F5A9"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=G7W)E860G*3L*("`@("`@("`D9U]E9&ET(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V=?961I="<I.PH@("`@("`@("1G7V1E;&5T92`](%5T:6PZ
M.F=E=$9O<FU$871A*"=G7V1E;&5T92<I.PH*("`@("`@("!F;W)E86-H("@D
M9U]N86UE<R!A<R`D:V5Y(#T^("1G<F]U<"D@>PH@("`@("`@("`@("!I9B`H
M96UP='DH)&=R;W5P*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)&=?<VAO=ULD
M:V5Y72DI('L*("`@("`@("`@("`@("`@("1P97)M+3YA9&1'<F]U<%!E<FUI
M<W-I;VXH)&=R;W5P+"!015)-4U]32$]7+"!F86QS92D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!0
M97)M:7-S:6]N*"1G<F]U<"P@4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&=?<F5A9%LD:V5Y72DI
M('L*("`@("`@("`@("`@("`@("1P97)M+3YA9&1'<F]U<%!E<FUI<W-I;VXH
M)&=R;W5P+"!015)-4U]214%$+"!F86QS92D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!097)M:7-S
M:6]N*"1G<F]U<"P@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@A96UP='DH)&=?961I=%LD:V5Y72DI('L*("`@
M("`@("`@("`@("`@("1P97)M+3YA9&1'<F]U<%!E<FUI<W-I;VXH)&=R;W5P
M+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!097)M:7-S:6]N*"1G
M<F]U<"P@4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A96UP='DH)&=?9&5L971E6R1K97E=*2D@>PH@("`@("`@
M("`@("`@("`@)'!E<FTM/F%D9$=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L(%!%
M4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O
M=7`L(%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D<VAA<F4M/G-E=%!E<FUI<W-I;VXH)'!E<FTL(&9A
M;'-E*3L*("`@("`@("`D<VAA<F4M/G-A=F4H*3L*("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B57!D871E9"!<(B5S7"(N(BDL("1S
M:&%R92T^9V5T*"=N86UE)RDI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@
M("1F;W)M(#T@)V5D:70N:6YC)SL*("`@('T*("`@(&)R96%K.PI]"@II9B`H
M:7-?82@D<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("1T:71L92`](%\H
M(D5D:70@4&5R;6ES<VEO;G,B*3L*?2!E;'-E('L*("`@("1T:71L92`]('-P
M<FEN=&8H7R@B161I="!097)M:7-S:6]N<R!F;W(@)7,B*2P@)'-H87)E+3YG
M970H)VYA;64G*2D["GT*"FEF("@D875T:"T^:&%S0V%P86)I;&ET>2@G;&ES
M="<I*2!["B`@("`D=7-E<DQI<W0@/2`D875T:"T^;&ES=%5S97)S*"D["B`@
M("!I9B`H:7-?82@D=7-E<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@D=7-E<DQI<W0L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`D=7-E<DQI<W0@/2!A<G)A
M>2@I.PH@("`@?0H@("`@<V]R="@D=7-E<DQI<W0I.PI](&5L<V4@>PH@("`@
M)'5S97),:7-T(#T@87)R87DH*3L*?0H*)&=R;W5P3&ES="`]("1G<F]U<',M
M/F=E=$=R;W5P365M8F5R<VAI<',H075T:#HZ9V5T075T:"@I+"!T<G5E*3L*
M:68@*&ES7V$H)&=R;W5P3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)&=R;W5P3&ES="P@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U].3U1)0T4I.PH@("`@)&=R;W5P3&ES="`](&%R<F%Y*"D[
M"GT*87-O<G0H)&=R;W5P3&ES="D["@IR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I
M9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*:68@*"%E;7!T
M>2@D9F]R;2DI('L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]S
M:&%R97,O)R`N("1F;W)M.PI]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V1O=VYL;V%D+P``````````````````````````````````````````
M````````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C0`,#(P,#0U`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O9&]W;FQO860O:6YD97@N<&AP````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,R,``Q,#4Q-30S,3`V-``P
M,C$V-38`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O9&]W;FQO
M860O:6YD97@N<&AP+'8@,2XY+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HQ,2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8V]R92YP:'`G.PH*)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG
M;&5T;VXH2$]21$5?4T534TE/3E]214%$3TY,62D["@II9B`H(2@D;6]D=6QE
M(#T@571I;#HZ9V5T1F]R;41A=&$H)VUO9'5L92<I*2!\?`H@("`@(69I;&5?
M97AI<W1S*"1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1M;V1U;&4I*2D@
M>PH@("`@2&]R9&4Z.F9A=&%L*"=$;R!N;W0@8V%L;"!T:&ES('-C<FEP="!D
M:7)E8W1L>2XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"FEN8VQU9&4@)')E
M9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&UO9'5L92D@+B`G+W9I97<N<&AP
M)SL*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O;V)R;W=S97(O````````````
M````````````````````````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`V-``P,C`Q,#``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'``````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`V,#4U`#$P-3$U-#,Q,#8T`#`R,3<R,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`L=B`Q+C8N,3`N
M-2`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G
M+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E
M($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O5&5M<&QA=&4N<&AP)SL*"B1P871H(#T@571I;#HZ9V5T1F]R;41A
M=&$H)W!A=&@G*3L*"FEF("AE;7!T>2@D<&%T:"DI('L*("`@("1L:7-T(#T@
M87)R87DH*3L*("`@("1A<'!S(#T@)')E9VES=')Y+3YL:7-T07!P<RAN=6QL
M+"!F86QS92P@4$5235-?4D5!1"D["B`@("!F;W)E86-H("@D87!P<R!A<R`D
M87!P*2!["B`@("`@("`@:68@*"1R96=I<W1R>2T^:&%S365T:&]D*"=B<F]W
M<V4G+"`D87!P*2D@>PH@("`@("`@("`@("`D;&ES=%LD87!P72`](&%R<F%Y
M*"=N86UE)R`]/B`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G:7-T
M<GDM/F=E="@G:6-O;B<L("1A<'`I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=B<F]W<V5A8FQE)R`]/B!T<G5E*3L*("`@("`@("!]"B`@
M("!]"GT@96QS92!["B`@("`D<&EE8V5S(#T@97AP;&]D92@G+R<L("1P871H
M*3L*("`@("1L:7-T(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E*"1P:65C
M97-;,%TL("=B<F]W<V4G+"!A<G)A>2@G<&%T:"<@/3X@)'!A=&@I*3L*?0H*
M:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*("`@($AO<F1E.CIF
M871A;"@D;&ES="P@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0II9B`H(6-O=6YT
M*"1L:7-T*2D@>PH@("`@2&]R9&4Z.F9A=&%L*%\H(DYO=&AI;F<@=&\@8G)O
M=W-E+"!G;R!B86-K+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"@HD='!L
M(#T@/#P\5%!,"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*9G5N
M8W1I;VX@8VAO;W-E3V)J96-T*&]I9"D*>PH@("`@:68@*"%W:6YD;W<N;W!E
M;F5R('Q\("%W:6YD;W<N;W!E;F5R+F]B<F]W<V5R0V%L;&)A8VLI('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@=F%R(')E<W5L="`]('=I
M;F1O=RYO<&5N97(N;V)R;W=S97)#86QL8F%C:RAW:6YD;W<N;F%M92P@;VED
M*3L*("`@(&EF("@A<F5S=6QT*2!["B`@("`@("`@=VEN9&]W+F-L;W-E*"D[
M"B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&%L97)T*')E<W5L="D["B`@
M("!R971U<FX@9F%L<V4["GT*/"]S8W)I<'0^"@H\9&EV(&-L87-S/2)H96%D
M97(B/@H@/'-P86X@8VQA<W,](G)I9VAT1FQO870B/CQT86<Z8VQO<V4@+SX\
M+W-P86X^"B`\9V5T=&5X=#Y/8FIE8W0@0G)O=W-E<CPO9V5T=&5X=#X*/"]D
M:78^"CQD:78@8VQA<W,](FAE861E<F)O>"(^"B`\=&%B;&4@8VQA<W,](G-T
M<FEP960B(&-E;&QS<&%C:6YG/2(P(B!S='EL93TB=VED=&@Z,3`P)2(^"B`\
M;&]O<#IR;W=S/@H@(#QT<CX*("`@/'1D/@H@("`@/'1A9SIR;W=S+FEC;VX@
M+SX*("`@(#QT86<Z<F]W<RYN86UE("\^"B`@(#PO=&0^"B`@/"]T<CX*(#PO
M;&]O<#IR;W=S/@H@/"]T86)L93X*/"]D:78^"E103#L*"B1R;W=S(#T@87)R
M87DH*3L*9F]R96%C:"`H)&QI<W0@87,@)'!A=&@@/3X@)'9A;'5E<RD@>PH@
M("`@)')O=R`](&%R<F%Y*"D["@H@("`@+R\@4V5T('1H92!I8V]N+@H@("`@
M:68@*"%E;7!T>2@D=F%L=65S6R=I8V]N)UTI*2!["B`@("`@("`@)')O=ULG
M:6-O;B==(#T@2&]R9&4Z.FEM9R@D=F%L=65S6R=I8V]N)UTL("1V86QU97-;
M)VYA;64G72P@)R<L("<G*3L*("`@('T@96QS96EF("@A96UP='DH)'9A;'5E
M<ULG8G)O=W-E86)L92==*2D@>PH@("`@("`@("1R;W=;)VEC;VXG72`]($AO
M<F1E.CII;6<H)W1R964O9F]L9&5R+G!N9R<I.PH@("`@?2!E;'-E('L*("`@
M("`@("`D<F]W6R=I8V]N)UT@/2!(;W)D93HZ:6UG*"=T<F5E+VQE868N<&YG
M)RD["B`@("!]"@H@("`@+R\@4V5T('1H92!N86UE+VQI;FLN"B`@("!I9B`H
M(65M<'1Y*"1V86QU97-;)V)R;W=S96%B;&4G72DI('L*("`@("`@("`D=7)L
M(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]O8G)O=W-E<B\G
M*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=P
M871H)RP@)'!A=&@I.PH@("`@("`@("1R;W=;)VYA;64G72`]($AO<F1E.CIL
M:6YK*"1U<FPI("X@)'9A;'5E<ULG;F%M92==("X@)SPO83XG.PH@("`@?2!E
M;'-E('L*("`@("`@("`D:G,@/2`B<F5T=7)N(&-H;V]S94]B:F5C="@G(B`N
M(&%D9'-L87-H97,H)'!A=&@I("X@(B<I.R(["B`@("`@("`@)')O=ULG;F%M
M92==(#T@2&]R9&4Z.FQI;FLH)R,G+"!S<')I;G1F*%\H(D-H;V]S92`E<R(I
M+"`D=F%L=65S6R=N86UE)UTI+"`G)RP@)R<L("1J<RD@+B`D=F%L=65S6R=N
M86UE)UT@+B`G/"]A/B<["B`@("!]"@H@("`@)')O=W-;72`]("1R;W<["GT*
M"B1T96UP;&%T92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*)'1E;7!L871E
M+3YS971/<'1I;VXH)V=E='1E>'0G+"!T<G5E*3L*)'1E;7!L871E+3YS970H
M)W)O=W,G+"`D<F]W<RD["B1T96UP;&%T92T^<V5T*"=C;&]S92<L("<\82!H
M<F5F/2(C(B!O;F-L:6-K/2)W:6YD;W<N8VQO<V4H*3L@<F5T=7)N(&9A;'-E
M.R(^)R`N($AO<F1E.CII;6<H)V-L;W-E+G!N9R<I("X@)SPO83XG*3L*"DAO
M<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G+"`G:&]R9&4G+"!T<G5E
M*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N
M:6YC)SL*96-H;R`D=&5M<&QA=&4M/G!A<G-E*"1T<&PI.PIR97%U:7)E($A/
M4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M:6UA9V5S+P``````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,3<U,#,`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-#$S`#$P-3$U-#,Q,#8T`#`R,C4S
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP+'8@,2XQ.2XQ,"XT(#(P,#8O,#$O,#$@,C$Z,CDZ,30@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI
M8B]B87-E+G!H<"<["@HD=&ET;&4@/2!?*")#;VQO<B!0:6-K97(B*3L*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*
M"B1F;W)M(#T@571I;#HZ9V5T1F]R;41A=&$H)V9O<FTG*3L*)'1A<F=E="`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=T87)G970G*3L*"F5C:&\@2&]R9&4Z.FEM
M9R@G8V]L;W)S8V%L92YP;F<G+"`G)RP@)VED/2)C;VQO<G!I8VME<B(@;VYC
M;&EC:STB8VAA;F=E0V]L;W(H9V5T0V]L;W(H979E;G0I*3L@<F5T=7)N(&9A
M;'-E.R(@;VYM;W5S96UO=F4](F1E;6]#;VQO<BAG971#;VQO<BAE=F5N="DI
M.R!R971U<FX@9F%L<V4[(B!S='EL93TB8W5R<V]R.F-R;W-S:&%I<CMB86-K
M9W)O=6YD+6-O;&]R.G=H:71E.W!A9&1I;F<Z,7!X(B<I.PH_/@H*/&1I=B!I
M9#TB8V]L;W)$96UO(B!S='EL93TB8F%C:V=R;W5N9"UC;VQO<CIW:&ET93MW
M:61T:#HQ,#!P>#MH96EG:'0Z,C!P>#MP861D:6YG.C%P>"(^/"]D:78^"CQS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!C
M:&%N9V5#;VQO<BAC;VQO<BD*>PH@("`@:68@*'!A<F5N="YO<&5N97(N8VQO
M<V5D*2!["B`@("`@("`@86QE<G0H(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB*2D@
M/SXB*3L*("`@("`@("!T:&ES+F-L;W-E*"D["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H*("`@(&EF("@A<&%R96YT+F]P96YE<BYD;V-U;65N="X\/W!H<"!E
M8VAO("1F;W)M(#\^*2!["B`@("`@("`@86QE<G0H(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N
M($]P=&EO;G,@=VEN9&]W(BDI(#\^(BD["B`@("`@("`@=&AI<RYC;&]S92@I
M.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!P87)E;G0N;W!E;F5R+F1O
M8W5M96YT+CP_<&AP(&5C:&\@)&9O<FT@/SY;(CP_<&AP(&5C:&\@)'1A<F=E
M="`_/B)=+G9A;'5E(#T@8V]L;W(["B`@("!P87)E;G0N;W!E;F5R+F1O8W5M
M96YT+CP_<&AP(&5C:&\@)&9O<FT@/SY;(CP_<&AP(&5C:&\@)'1A<F=E="`_
M/B)=+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`](&-O;&]R.PH@("`@<&%R96YT
M+F]P96YE<BYD;V-U;65N="X\/W!H<"!E8VAO("1F;W)M(#\^6R(\/W!H<"!E
M8VAO("1T87)G970@/SXB72YS='EL92YC;VQO<B`](&)R:6=H=&YE<W,H8V]L
M;W(I(#P@,3(X(#\@)W=H:71E)R`Z("=B;&%C:R<["@H@("`@=&AI<RYC;&]S
M92@I.PI]"@IF=6YC=&EO;B!D96UO0V]L;W(H8V]L;W(I"GL*("`@('9A<B!T
M87)G970@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G8V]L;W)$96UO)RD[
M"B`@("!T87)G970N<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@8V]L;W(["B`@
M("!T87)G970N<W1Y;&4N8V]L;W(@/2!B<FEG:'1N97-S*&-O;&]R*2`\(#$R
M."`_("=W:&ET92<@.B`G8FQA8VLG.PH@("`@=&%R9V5T+FEN;F5R2%1-3"`]
M(&-O;&]R.PI]"@IF=6YC=&EO;B!G971#;VQO<BAE=F5N="D*>PH@("`@=F%R
M(&EM9R`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C;VQO<G!I8VME<B<I
M.PH*("`@('9A<B!X(#T@979E;G0N8VQI96YT6"`M(#$P.PH@("`@=F%R('D@
M/2!E=F5N="YC;&EE;G19("T@,3`["@H@("`@=F%R(')M87@@/2`P.PH@("`@
M=F%R(&=M87@@/2`P.PH@("`@=F%R(&)M87@@/2`P.PH*("`@(&EF("AY(#P]
M(#,R*2!["B`@("`@("`@<FUA>"`](#(U-3L*("`@("`@("!G;6%X(#T@*'D@
M+R`S,BXP*2`J(#(U-3L*("`@("`@("!B;6%X(#T@,#L*("`@('T@96QS92!I
M9B`H>2`\/2`V-"D@>PH@("`@("`@('D@/2!Y("T@,S(["B`@("`@("`@<FUA
M>"`](#(U-2`M("AY("\@,S(N,"D@*B`R-34["B`@("`@("`@9VUA>"`](#(U
M-3L*("`@("`@("!B;6%X(#T@,#L*("`@('T@96QS92!I9B`H>2`\/2`Y-BD@
M>PH@("`@("`@('D@/2!Y("T@-C0["B`@("`@("`@<FUA>"`](#`["B`@("`@
M("`@9VUA>"`](#(U-3L*("`@("`@("!B;6%X(#T@*'D@+R`S,BXP*2`J(#(U
M-3L*("`@('T@96QS92!I9B`H>2`\/2`Q,C@I('L*("`@("`@("!Y(#T@>2`M
M(#DV.PH@("`@("`@(')M87@@/2`P.PH@("`@("`@(&=M87@@/2`R-34@+2`H
M>2`O(#,R+C`I("H@,C4U.PH@("`@("`@(&)M87@@/2`R-34["B`@("!](&5L
M<V4@:68@*'D@/#T@,38P*2!["B`@("`@("`@>2`]('D@+2`Q,C@["B`@("`@
M("`@<FUA>"`]("AY("\@,S(N,"D@*B`R-34["B`@("`@("`@9VUA>"`](#`[
M"B`@("`@("`@8FUA>"`](#(U-3L*("`@('T@96QS92!["B`@("`@("`@>2`]
M('D@+2`Q-C`["B`@("`@("`@<FUA>"`](#(U-3L*("`@("`@("!G;6%X(#T@
M,#L*("`@("`@("!B;6%X(#T@,C4U("T@*'D@+R`S,BXP*2`J(#(U-3L*("`@
M('T*"B`@("!I9B`H>"`\/2`U,"D@>PH@("`@("`@('9A<B!R(#T@36%T:"YA
M8G,H36%T:"YF;&]O<BAR;6%X("H@>"`O(#4P+C`I*3L*("`@("`@("!V87(@
M9R`]($UA=&@N86)S*$UA=&@N9FQO;W(H9VUA>"`J('@@+R`U,"XP*2D["B`@
M("`@("`@=F%R(&(@/2!-871H+F%B<RA-871H+F9L;V]R*&)M87@@*B!X("\@
M-3`N,"DI.PH@("`@?2!E;'-E('L*("`@("`@("!X("T](#4P.PH@("`@("`@
M('9A<B!R(#T@36%T:"YA8G,H36%T:"YF;&]O<BAR;6%X("L@*'@@+R`U,"XP
M*2`J("@R-34@+2!R;6%X*2DI.PH@("`@("`@('9A<B!G(#T@36%T:"YA8G,H
M36%T:"YF;&]O<BAG;6%X("L@*'@@+R`U,"XP*2`J("@R-34@+2!G;6%X*2DI
M.PH@("`@("`@('9A<B!B(#T@36%T:"YA8G,H36%T:"YF;&]O<BAB;6%X("L@
M*'@@+R`U,"XP*2`J("@R-34@+2!B;6%X*2DI.PH@("`@?0H*("`@(')E='5R
M;B!M86ME0V]L;W(H<BP@9RP@8BD["GT*"F9U;F-T:6]N(&UA:V5#;VQO<BAR
M+"!G+"!B*0I["B`@("!C;VQO<B`]("<C)SL*("`@(&-O;&]R("L](&AE>"A-
M871H+F9L;V]R*'(@+R`Q-BDI.PH@("`@8V]L;W(@*ST@:&5X*'(@)2`Q-BD[
M"B`@("!C;VQO<B`K/2!H97@H36%T:"YF;&]O<BAG("\@,38I*3L*("`@(&-O
M;&]R("L](&AE>"AG("4@,38I.PH@("`@8V]L;W(@*ST@:&5X*$UA=&@N9FQO
M;W(H8B`O(#$V*2D["B`@("!C;VQO<B`K/2!H97@H8B`E(#$V*3L*("`@(')E
M='5R;B!C;VQO<CL*?0H*9G5N8W1I;VX@8G)I9VAT;F5S<RAC;VQO<BD*>PH@
M("`@=F%R('(@/2!N97<@3G5M8F5R*"(P>"(@*R!C;VQO<BYS=6)S='(H,2P@
M,BDI.PH@("`@=F%R(&<@/2!N97<@3G5M8F5R*"(P>"(@*R!C;VQO<BYS=6)S
M='(H,RP@,BDI.PH@("`@=F%R(&(@/2!N97<@3G5M8F5R*"(P>"(@*R!C;VQO
M<BYS=6)S='(H-2P@,BDI.PH@("`@<F5T=7)N("@H<B`J(#(Y.2D@*R`H9R`J
M(#4X-RD@*R`H8B`J(#$Q-"DI("\@,3`P,#L*?0H*9G5N8W1I;VX@:&5X*&1E
M8RD*>PH@("`@<F5T=7)N("AD96,I+G1O4W1R:6YG*#$V*3L*?0HO+RTM/@H\
M+W-C<FEP=#X*/"]B;V1Y/@H\+VAT;6P^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]I;6%G97,O<&EX
M96PN<&AP````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3<U
M`#$P-3$U-#,Q,#8T`#`R,3,S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S
M97)V:6-E<R]I;6%G97,O<&EX96PN<&AP+'8@,2XQ-"XQ,"XS(#(P,#8O,#$O
M,#$@,C$Z,CDZ,30@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8V]R92YP:'`G.PH*:&5A9&5R*"=#;VYT96YT+71Y<&4Z(&EM86=E
M+V=I9B<I.PIH96%D97(H)T5X<&ER97,Z(%=E9"P@,C$@075G(#$Y-CD@,3$Z
M,3$Z,3$@1TU4)RD["FAE861E<B@G0V%C:&4M0V]N=')O;#H@;F\M8V%C:&4G
M*3L*:&5A9&5R*"=#86-H92U#;VYT<F]L.B!M=7-T+7)E=F%L:61A=&4G*3L*
M"B1R9V(@/2!S=')?<F5P;&%C92@G(R<L("<G+"!5=&EL.CIG971&;W)M1&%T
M82@G8R<I*3L*"B1R(#T@:&5X9&5C*'-U8G-T<B@D<F=B+"`P+"`R*2D["B1G
M(#T@:&5X9&5C*'-U8G-T<B@D<F=B+"`R+"`R*2D["B1B(#T@:&5X9&5C*'-U
M8G-T<B@D<F=B+"`T+"`R*2D["@II9B`H)')G8BD@>PH@("`@<')I;G1F*"<E
M8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)RP*("`@("`@("`@("`W,2PW,RPW
M,"PU-BPU-RPY-RPQ+#`L,2PP+#$R."PP+#`L)'(L)&<L)&(L,"PP+#`L-#0L
M,"PP+#`L,"PQ+#`L,2PP+#`L,BPR+#8X+#$L,"PU.2D["GT@96QS92!["B`@
M("!P<FEN=&8H)R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E
M8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R4G+`H@("`@("`@("`@(#<Q+#<S+#<P+#4V+#4W+#DW+#$L,"PQ+#`L
M,3(X+#(U-2PP+#$Y,BPQ.3(L,3DR+#`L,"PP+#,S+#(T.2PT+#$L,"PP+#`L
M,"PT-"PP+#`L,"PP+#$L,"PQ+#`L,"PR+#(L-C@L,2PP+#4Y*3L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+VEM86=E<R]V:65W+G!H<```````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#<U-C0`,3`U,34T,S$P-C0`,#(Q,3<W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!$:7-P;&%Y<R!A;B!I;6%G92!A;F0@86QL;W=S(&UO9&EF:6-A
M=&EO;G,@:68@<F5Q=6ER960N"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:6UA9V5S+W9I97<N<&AP+'8@
M,2XR,"XQ,"XV(#(P,#8O,#4O,C0@,#(Z,C(Z,#,@<V5L<VMY($5X<"`D"B`J
M"B`J($!A=71H;W(@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S
M92YP:'`G.PH*+RH@1V5T(&9I;&4@:6YF;RX@5&AE(&9O;&QO=VEN9R!P87)A
M;65T97)S(&%R92!A=F%I;&%B;&4Z"B`J("`G9B<@+2!T:&4@9FEL96YA;64N
M"B`J("`G<R<@+2!T:&4@<V]U<F-E+"!E:71H97(@=&AE("=T;7`G(&1I<F5C
M=&]R>2!O<B!61E,N"B`J("`G8R<@+2!W:&EC:"!A<'`G<R!C;VYF:6<@=&\@
M=7-E(&9O<B!61E,L(&1E9F%U;'1S('1O($AO<F1E+@H@*B`@)W`G("T@=&AE
M(&1I<F5C=&]R>2!O9B!T:&4@9FEL92X*("H@("=N)R`M('1H92!N86UE('1O
M('-E="!T;R!T:&4@9FEL96YA;64@;W(@9&5F875L="!T;R!S86UE(&%S(&9I
M;&5N86UE+@H@*B`@)V$G("T@<&5R9F]R;2!S;VUE(&%C=&EO;B!O;B!T:&4@
M:6UA9V4L('-U8V@@87,@<V-A;&EN9RX@*B\*)&9I;&4@/2!B87-E;F%M92A5
M=&EL.CIG971&;W)M1&%T82@G9B<I*3L*)'-O=7)C92`]('-T<G1O;&]W97(H
M571I;#HZ9V5T1F]R;41A=&$H)W,G+"`G=&UP)RDI.PHD87!P7V-O;F8@/2!S
M=')T;VQO=V5R*%5T:6PZ.F=E=$9O<FU$871A*"=C)RP@)VAO<F1E)RDI.PHD
M;F%M92`](%5T:6PZ.F=E=$9O<FU$871A*"=N)RP@)&9I;&4I.PHD86-T:6]N
M(#T@<W1R=&]L;W=E<BA5=&EL.CIG971&;W)M1&%T82@G82<I*3L*"G-W:71C
M:"`H)'-O=7)C92D@>PIC87-E("=V9G,G.@H@("`@+RH@0VAA;F=E(&%P<"!I
M9B!N965D960@=&\@9V5T('1H92!R:6=H="!61E,@8V]N9FEG+B`J+PH@("`@
M)&-H86YG961?8V]N9B`]("1R96=I<W1R>2T^<'5S:$%P<"@D87!P7V-O;F8I
M.PH*("`@("\J($=E='1I;F<@82!F:6QE(&9R;VT@2&]R9&4G<R!61E,N("HO
M"B`@("!R97%U:7)E7V]N8V4@)U9&4RYP:'`G.PH@("`@)'9F<R`]("961E,Z
M.G-I;F=L971O;B@D8V]N9ELG=F9S)UU;)W1Y<&4G72P@2&]R9&4Z.F=E=$1R
M:79E<D-O;F9I9R@G=F9S)RP@)&-O;F9;)W9F<R==6R=T>7!E)UTI*3L*("`@
M("1P871H(#T@571I;#HZ9V5T1F]R;41A=&$H)W`G*3L*("`@("1F:6QE7V1A
M=&$@/2`D=F9S+3YR96%D*"1P871H+"`D9FEL92D["B`@("!I9B`H:7-?82@D
M9FEL95]D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H<W!R:6YT9B@G17)R;W(@9&ES<&QA>6EN9R!I;6%G92!;)7-=
M.B`E<R<L("1P871H("X@)R\G("X@)&9I;&4L("1F:6QE7V1A=&$M/F=E=$UE
M<W-A9V4H*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("!E>&ET.PH@("`@?0H*("`@("\J(%)E='5R;B!T:&4@;W)I9VEN
M86P@87!P(&EF(&-H86YG960@<')E=FEO=7-L>2X@*B\*("`@(&EF("@D8VAA
M;F=E9%]C;VYF*2!["B`@("`@("`@)')E9VES=')Y+3YP;W!!<'`H)&%P<%]C
M;VYF*3L*("`@('T*("`@(&)R96%K.PH*8V%S92`G=&UP)SH*("`@("\J($=E
M='1I;F<@82!F:6QE(&9R;VT@2&]R9&4G<R!T96UP(&1I<BX@*B\*("`@("1T
M;7!D:7(@/2!(;W)D93HZ9V5T5&5M<$1I<B@I.PH@("`@:68@*&5M<'1Y*"1A
M8W1I;VXI('Q\("1A8W1I;VX@/3T@)W)E<VEZ92<I('L*("`@("`@("`O*B!5
M<V4@;W)I9VEN86P@:68@;F\@86-T:6]N(&]R(&EF(')E<VEZ:6YG+B`J+PH@
M("`@("`@("1F:6QE7VYA;64@/2`D=&UP9&ER("X@)R\G("X@)&9I;&4["B`@
M("!](&5L<V4@>PH@("`@("`@("1F:6QE7VYA;64@/2`D=&UP9&ER("X@)R]M
M;V1?)R`N("1F:6QE.PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&5?
M;F%M92DI('L*("`@("`@("`@("`@8V]P>2@D=&UP9&ER("X@)R\G("X@)&9I
M;&4L("1F:6QE7VYA;64I.PH@("`@("`@('T*("`@('T*("`@(&EF("@A9FEL
M95]E>&ES=',H)&9I;&5?;F%M92DI('L*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92AS<')I;G1F*"=);6%G92!N;W0@9F]U;F0@6R5S72<L("1F:6QE7VYA
M;64I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@
M("`@97AI=#L*("`@('T*("`@("1F:6QE7V1A=&$@/2!F:6QE7V=E=%]C;VYT
M96YT<R@D9FEL95]N86UE*3L*("`@(&)R96%K.PI]"@HO*B!,;V%D('1H92!I
M;6%G92!O8FIE8W0N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O26UA9V4N<&AP
M)SL*)'!A<F%M<R`](&%R<F%Y*"=T96UP)R`]/B!(;W)D93HZ9V5T5&5M<$1I
M<B@I*3L*:68@*"%E;7!T>2@D8V]N9ELG:6UA9V4G75LG8V]N=F5R="==*2D@
M>PH@("`@)&EM86=E(#T@)DAO<F1E7TEM86=E.CIS:6YG;&5T;VXH)VEM)RP@
M)'!A<F%M<RD["GT@96QS92!["B`@("`D:6UA9V4@/2`F2&]R9&5?26UA9V4Z
M.G-I;F=L971O;B@G9V0G+"`D<&%R86US*3L*?0HD:6UA9V4M/FQO8613=')I
M;F<H)&9I;&4L("1F:6QE7V1A=&$I.PH*+RH@0VAE8VL@:68@;F\@961I=&EN
M9R!A8W1I;VX@<F5Q=6ER960@86YD('-E;F0@=&AE(&EM86=E('1O(&)R;W=S
M97(N("HO"FEF("AE;7!T>2@D86-T:6]N*2D@>PH@("`@)&EM86=E+3YD:7-P
M;&%Y*"D["B`@("!E>&ET.PI]"@HO*B!);6%G92!E9&ET:6YG(')E<75I<F5D
M+B`J+PIS=VET8V@@*"1A8W1I;VXI('L*8V%S92`G<F]T871E)SH*("`@("1I
M;6%G92T^<F]T871E*%5T:6PZ.F=E=$9O<FU$871A*"=V)RDI.PH@("`@8G)E
M86L["@IC87-E("=F;&EP)SH*("`@("1I;6%G92T^9FQI<"@I.PH@("`@8G)E
M86L["@IC87-E("=M:7)R;W(G.@H@("`@)&EM86=E+3YM:7)R;W(H*3L*("`@
M(&)R96%K.PH*8V%S92`G9W)A>7-C86QE)SH*("`@("1I;6%G92T^9W)A>7-C
M86QE*"D["B`@("!B<F5A:SL*"F-A<V4@)W)E<VEZ92<Z"B`@("!L:7-T*"1W
M:61T:"P@)&AE:6=H="P@)')A=&EO*2`](&5X<&QO9&4H)RXG+"!5=&EL.CIG
M971&;W)M1&%T82@G=B<I*3L*"B`@("`O*B!)9B!N;R!W:61T:"!O<B!H96EG
M:'0@:&%S(&)E96X@<&%S<V5D+"!G970@=&AE(&]R:6=I;F%L"B`@("`@*B!O
M;F5S+B`J+PH@("`@:68@*&5M<'1Y*"1W:61T:"D@?'P@96UP='DH)&AE:6=H
M="DI('L*("`@("`@("`D;W)I9R`]("1I;6%G92T^9V5T1&EM96YS:6]N<R@I
M.PH@("`@?0H@("`@:68@*&5M<'1Y*"1W:61T:"DI('L*("`@("`@("`D=VED
M=&@@/2`D;W)I9ULG=VED=&@G73L*("`@('T*("`@(&EF("AE;7!T>2@D:&5I
M9VAT*2D@>PH@("`@("`@("1H96EG:'0@/2`D;W)I9ULG:&5I9VAT)UT["B`@
M("!]"@H@("`@)&EM86=E+3YR97-I>F4H)'=I9'1H+"`D:&5I9VAT+"`D<F%T
M:6\I.PH*("`@("\J(%-I;F-E('1H92!O<FEG:6YA;"!I<R!A;'=A>7,@=7-E
M9"!F;W(@<F5S:7II;F<@;6%K92!S=7)E('1H90H@("`@("H@=W)I=&4@:7,@
M=&\@)VUO9%\G+B`J+PH@("`@)&9I;&5?;F%M92`]("1T;7!D:7(@+B`G+VUO
M9%\G("X@)&9I;&4["B`@("!B<F5A:SL*?0H*+RH@5W)I=&4@;W5T(&%N>2!C
M:&%N9V5S('1O('1H92!T96UP;W)A<GD@9FEL92X@*B\*)&9P(#T@0&9O<&5N
M*"1F:6QE7VYA;64L("=W8B<I.PIF=W)I=&4H)&9P+"`D:6UA9V4M/G)A=R@I
M*3L*9F-L;W-E*"1F<"D["@HD:6UA9V4M/F1I<W!L87DH*3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VAE;'`O````````````
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C0`,#$W,38V`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'``````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C4T-0`Q,#4Q-30S,3`V-``P,C$P,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`L=B`R+C@P+C$P
M+CD@,C`P-B\P-R\P-B`R,CHR.#HP,B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*0&1E9FEN92@G05542%](04Y$3$52
M)RP@=')U92D["@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<["@HD=&ET
M;&4@/2!?*")(96QP(BD["B1S:&]W(#T@4W1R:6YG.CIL;W=E<BA5=&EL.CIG
M971&;W)M1&%T82@G<VAO=R<L("=I;F1E>"<I*3L*)&UO9'5L92`](%-T<FEN
M9SHZ;&]W97(H<')E9U]R97!L86-E*"<O7%<O)RP@)R<L(%5T:6PZ.F=E=$9O
M<FU$871A*"=M;V1U;&4G+"`G:&]R9&4G*2DI.PHD=&]P:6,@/2!5=&EL.CIG
M971&;W)M1&%T82@G=&]P:6,G*3L*"FEF("@D;6]D=6QE(#T]("=A9&UI;B<I
M('L*("`@("1F:6QE<F]O="`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<I
M.PH@("`@)&AE;'!?9FEL92`]("1F:6QE<F]O="`N("(O861M:6XO;&]C86QE
M+R1L86YG=6%G92]H96QP+GAM;"(["B`@("`D:&5L<%]F:6QE7V9A;&QB86-K
M(#T@)&9I;&5R;V]T("X@)R]A9&UI;B]L;V-A;&4O96Y?55,O:&5L<"YX;6PG
M.PI](&5L<V4@>PH@("`@)&9I;&5R;V]T(#T@)')E9VES=')Y+3YG970H)V9I
M;&5R;V]T)RP@)&UO9'5L92D["B`@("`D:&5L<%]F:6QE(#T@)&9I;&5R;V]T
M("X@(B]L;V-A;&4O)&QA;F=U86=E+VAE;'`N>&UL(CL*("`@("1H96QP7V9I
M;&5?9F%L;&)A8VL@/2`D9FEL97)O;W0@+B`G+VQO8V%L92]E;E]54R]H96QP
M+GAM;"<["GT*"FEF("@D<VAO=R`]/2`G:6YD97@G*2!["B`@("`D8F%S95]U
M<FP@/2`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S
M97)V:6-E<R]H96QP+R<["B`@("`D;6%I;E]U<FP@/2!(;W)D93HZ=7)L*"1B
M87-E7W5R;"D["B`@("`D;6%I;E]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M)&UA:6Y?=7)L+"!A<G)A>2@G<VAO=R<@/3X@)V5N=')Y)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M;V1U;&4G(#T^("1M;V1U;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=&]P:6,G(#T^("1T;W!I8RDI
M.PH@("`@)&UE;G5?=7)L(#T@2&]R9&4Z.G5R;"@D8F%S95]U<FPI.PH@("`@
M)&UE;G5?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1M96YU7W5R;"P@87)R
M87DH)VUO9'5L92<@/3X@)&UO9'5L92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S:&]W)R`]/B`G;65N
M=2<I*3L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]H96QP+VEN
M9&5X+FEN8R<["B`@("!E>&ET.PI]"@HD8F]D>4-L87-S(#T@)VAE;'`G.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G
M.PII9B`H)'-H;W<@/3T@)VUE;G4G*2!["B`@("`O*B!3970@=7`@=7)L<RX@
M*B\*("`@("1U<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R
M;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VAE;'`O)RD["B`@("`D=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=M;V1U;&4G+"`D;6]D=6QE
M*3L*("`@("1T;W!I8W-?;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G<VAO=R<L("=T;W!I8W,G*3L*("`@("1T;W!I8W-?;&EN:R`]($AO<F1E
M.CIL:6YK*"1T;W!I8W-?;&EN:RP@;G5L;"P@)VAE861E<B<L("=H96QP7VUA
M:6XG*2`N(%\H(DQI<W0@2&5L<"!4;W!I8W,B*2`N("<\+V$^)SL*("`@("1A
M8F]U=%]L:6YK(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=S:&]W)RP@
M)V%B;W5T)RD["B`@("`D86)O=71?;&EN:R`]($AO<F1E.CIL:6YK*"1A8F]U
M=%]L:6YK+"!N=6QL+"`G:&5A9&5R)RP@)VAE;'!?;6%I;B<I("X@7R@B06)O
M=70N+BXB*2`N("<\+V$^)SL*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]H96QP+VUE;G4N:6YC)SL*?2!E;'-E:68@*"1S:&]W(#T]("=A8F]U
M="<I('L*("`@(')E<75I<F4@)&9I;&5R;V]T("X@)R]L:6(O=F5R<VEO;BYP
M:'`G.PH@("`@)&UO9%]V97)S:6]N7V-O;G-T86YT(#T@4W1R:6YG.CIU<'!E
M<B@D;6]D=6QE*2`N("=?5D524TE/3B<["B`@("!I9B`H(61E9FEN960H)&UO
M9%]V97)S:6]N7V-O;G-T86YT*2D@>PH@("`@("`@(&5X:70["B`@("!]"B`@
M("`D=F5R<VEO;B`](%-T<FEN9SHZ=6-F:7)S="@D;6]D=6QE*2`N("<@)R`N
M(&-O;G-T86YT*"1M;V1?=F5R<VEO;E]C;VYS=&%N="D["B`@("`D8W)E9&ET
M<R`](%5T:6PZ.F)U9F9E<D]U='!U="@G:6YC;'5D92<L("1F:6QE<F]O="`N
M("<O9&]C<R]#4D5$2513)RD["B`@("`D8W)E9&ET<R`](%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)&-R961I=',L("=I<V\M.#@U.2TQ)RP@3DQ3.CIG971#
M:&%R<V5T*"DI.PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+VAE
M;'`O86)O=70N:6YC)SL*?2!E;'-E('L*("`@("1H96QP(#T@)FYE=R!(96QP
M*$A%3%!?4T]54D-%7T9)3$4L(&%R<F%Y*"1H96QP7V9I;&4L("1H96QP7V9I
M;&5?9F%L;&)A8VLI*3L*("`@(&EF("@H)'-H;W<@/3T@)V5N=')Y)RD@)B8@
M(65M<'1Y*"1T;W!I8RDI('L*("`@("`@("`D:&5L<"T^;&]O:W5P*"1T;W!I
M8RD["B`@("`@("`@)&AE;'`M/F1I<W!L87DH*3L*("`@('T@96QS92!["B`@
M("`@("`@)'1O<&EC<R`]("1H96QP+3YT;W!I8W,H*3L*("`@("`@("!F;W)E
M86-H("@D=&]P:6-S(&%S("1I9"`]/B`D=&ET;&4I('L*("`@("`@("`@("`@
M)&QI;FL@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@
M)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VAE;'`O)RD["B`@("`@("`@("`@("1L
M:6YK(#T@571I;#HZ861D4&%R86UE=&5R*"1L:6YK+"!A<G)A>2@G<VAO=R<@
M/3X@)V5N=')Y)RP@)VUO9'5L92<@/3X@)&UO9'5L92P@)W1O<&EC)R`]/B`D
M:60I*3L*("`@("`@("`@("`@96-H;R!(;W)D93HZ;&EN:R@D;&EN:RD["B`@
M("`@("`@("`@(&5C:&\@)'1I=&QE("X@(CPO83X\8G(@+SY<;B(["B`@("`@
M("`@?0H@("`@?0H@("`@)&AE;'`M/F-L96%N=7`H*3L*?0H*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<```````````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#8U-#<`,3`U,34T,S$P-C0`,#(Q,C0R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<"QV(#$N,S$N
M,BXS(#(P,#8O,#$O,#$@,C$Z,CDZ,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`Q+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H87)L
M97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H
M="`R,#`Q+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O36%I;G1E;F%N
M8V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]496UP;&%T92YP:'`G.PH*
M+RH@36%K92!S=7)E('1H97)E(&ES(&$@=7-E<B!L;V=G960@:6XN("HO"FEF
M("@A075T:#HZ9V5T075T:"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I
M;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+RH@268@;F\@)VUO9'5L92<@<&%R
M86UE=&5R('!A<W-E9"!I;BP@9&EE('=I=&@@86X@97)R;W(N("HO"FEF("@A
M*"1M;V1U;&4@/2!B87-E;F%M92A5=&EL.CIG971&;W)M1&%T82@G;6]D=6QE
M)RDI*2D@>PH@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H7R@B
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B*2DL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["GT*)&%P<%]N86UE(#T@)')E9VES=')Y+3YG
M970H)VYA;64G+"`D;6]D=6QE*3L*"B\J($QO860@=&AE(&UO9'5L92!S<&5C
M:69I8R!M86EN=&5N86YC92!C;&%S<R!N;W<N("HO"FEF("@A*"1M86EN="`]
M("9-86EN=&5N86YC93HZ9F%C=&]R>2@D;6]D=6QE*2DI('L*("`@($AO<F1E
M.CIF871A;"A014%2.CIR86ES945R<F]R*%\H(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB*2DL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["GT*"B\J($-R96%T92!T:&4@2&]R9&5?5&5M<&QA=&4@
M:71E;2X@*B\*)'1E;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I.PHD
M=&5M<&QA=&4M/G-E="@G:F%V87-C<FEP="<L("1B<F]W<V5R+3YH87-&96%T
M=7)E*"=J879A<V-R:7!T)RDL('1R=64I.PH*+RH@2&%V92!T:&4@;6%I;G1E
M;F%N8V4@;6]D=6QE(&1O(&%L;"!N96-E<W-A<GD@<')O8V5S<VEN9RX@*B\*
M;&ES="@D86-T:6]N+"`D=&%S:VQI<W0I(#T@)&UA:6YT+3YR=6Y-86EN=&5N
M86YC95!A9V4H*3L*"G-W:71C:"`H)&%C=&EO;BD@>PIC87-E($U!24Y414Y!
M3D-%7T]55%!55%]#3TY&25)-.@H@("`@+RH@0V]N9FER;6%T:6]N+7-T>6QE
M(&]U='!U="X@*B\*("`@("1T96UP;&%T92T^<V5T*"=C;VYF:7)M)RP@=')U
M92P@=')U92D["B`@("`D=&5M<&QA=&4M/G-E="@G86=R964G+"!F86QS92P@
M=')U92D["B`@("`D=&5M<&QA=&4M/G-E="@G;F]T:6-E)RP@9F%L<V4L('1R
M=64I.PH*("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*"(E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(BDL("1A
M<'!?;F%M92DL("=H;W)D92YM97-S86=E)RD["B`@("`D=&5M<&QA=&4M/G-E
M="@G:&5A9&5R)RP@<W!R:6YT9BA?*"(E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N(BDL("1A<'!?;F%M92DI.PH@("`@8G)E86L[
M"@IC87-E($U!24Y414Y!3D-%7T]55%!55%]!1U)%13H*("`@("\J($%G<F5E
M;65N="US='EL92!O=71P=70N("HO"B`@("`D=&5M<&QA=&4M/G-E="@G8V]N
M9FER;2<L(&9A;'-E+"!T<G5E*3L*("`@("1T96UP;&%T92T^<V5T*"=A9W)E
M92<L('1R=64L('1R=64I.PH@("`@)'1E;7!L871E+3YS970H)VYO=&EC92<L
M(&9A;'-E+"!T<G5E*3L*"B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN(BDL("=H;W)D92YM
M97-S86=E)RD["B`@("`D=&5M<&QA=&4M/G-E="@G:&5A9&5R)RP@<W!R:6YT
M9BA?*"(E<R!497)M<R!O9B!!9W)E96UE;G0B*2P@)&%P<%]N86UE*2D["B`@
M("!B<F5A:SL*"F-A<V4@34%)3E1%3D%.0T5?3U544%547TY/5$E#13H*("`@
M("\J($YO=&EC92US='EL92!O=71P=70N("HO"B`@("`D=&5M<&QA=&4M/G-E
M="@G8V]N9FER;2<L(&9A;'-E+"!T<G5E*3L*("`@("1T96UP;&%T92T^<V5T
M*"=A9W)E92<L(&9A;'-E+"!T<G5E*3L*("`@("1T96UP;&%T92T^<V5T*"=N
M;W1I8V4G+"!T<G5E+"!T<G5E*3L*"B`@("`D=&5M<&QA=&4M/G-E="@G:&5A
M9&5R)RP@<W!R:6YT9BA?*"(E<R`M($YO=&EC92(I+"`D87!P7VYA;64I*3L*
M("`@(&)R96%K.PI]"@HO*B!-86ME('9A<FEA8FQE(&%R<F%Y(&YE961E9"!F
M;W(@=&5M<&QA=&5S+B`J+PHD=&%S:W,@/2!A<G)A>2@I.PIF;W)E86-H("@D
M=&%S:VQI<W0@87,@)'!R968I('L*("`@(&QI<W0H)&1E<V-R:7`L("1C:&5C
M:V5D*2`]("1M86EN="T^:6YF;TUA:6YT96YA;F-E*"1P<F5F*3L*("`@("1T
M87-K<UM=(#T@87)R87DH)W!R968G(#T^("1P<F5F+"`G9&5S8W)I<"<@/3X@
M)&1E<V-R:7`L("=C:&5C:V5D)R`]/B`D8VAE8VME9"`_("<@8VAE8VME9#TB
M8VAE8VME9"(G(#H@)R<I.PI]"@HD=&5M<&QA=&4M/G-E=$]P=&EO;B@G9V5T
M=&5X="<L('1R=64I.PHD=&5M<&QA=&4M/G-E="@G=&%S:W,G+"`D=&%S:W,I
M.PHD=&5M<&QA=&4M/G-E="@G;6%I;G1?=7)L)RP@)&UA:6YT+3YG971-86EN
M=&5N86YC949O<FU54DPH*2D["B1T96UP;&%T92T^<V5T*"=M86EN=%]P;W-T
M9&%T82<L("1M86EN="T^9V5T4&]S=$1A=&$H*2D["B1T96UP;&%T92T^<V5T
M*"=N;W1I9GDG+"!5=&EL.CIB=69F97)/=71P=70H87)R87DH)&YO=&EF:6-A
M=&EO;BP@)VYO=&EF>2<I+"!A<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S
M)RDI*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["F5C:&\@)'1E;7!L871E+3YF971C:"A(3U)$15]414U03$%4
M15,@+B`G+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PG*3L*<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]L86YG=6%G92YP:'``````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,S4W`#$P-3$U-#,Q,#8T`#`R,#4S-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M4V-R:7!T('1O('-E="!T:&4@;F5W(&QA;F=U86=E+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+W-E<G9I8V5S+VQA;F=U86=E+G!H<"QV(#$N-2XQ,BXS(#(P,#8O
M,#$O,#$@,C$Z,CDZ,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*"B\J(%-E="!T:&4@;&%N9W5A9V4N("HO"B1?4T534TE/
M3ELG:&]R9&5?;&%N9W5A9V4G72`]($Y,4SHZ<V5L96-T*"D["B1P<F5F<RT^
M<V5T5F%L=64H)VQA;F=U86=E)RP@)%]315-324].6R=H;W)D95]L86YG=6%G
M92==*3L*"B\J(%)E9&ER96-T('1O('1H92!U<FP@;W(@;&]G:6X@<&%G92!I
M9B!N;VYE(&=I=F5N+B`J+PHD=7)L(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R
M;"<I.PII9B`H96UP='DH)'5R;"DI('L*("`@("1U<FP@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)VEN9&5X+G!H<"<L('1R=64I.PI]"FAE861E<B@G3&]C
M871I;VXZ("<@+B`D=7)L*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'``````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`W,C4V`#$P-3$U-#,Q,#8T`#`R,3<V-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`L=B`Q+C$N,BXR(#(P,#8O,#$O,#$@,C$Z,CDZ,3`@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO
M+W=W=RYC<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+T9O<FTO4F5N9&5R97(N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]687)I
M86)L97,N<&AP)SL*"FEF("@A075T:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*
M("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]
M"@HO+R!-86ME('-U<F4@875T:"!B86-K96YD(&%L;&]W<R!P87-S=V]R9',@
M=&\@8F4@<F5S970N"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG
M875T:"==6R=D<FEV97(G72D["FEF("@A)&%U=&@M/FAA<T-A<&%B:6QI='DH
M)W5P9&%T92<I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-H86YG
M:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C
M=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("!H96%D97(H)TQO8V%T:6]N
M.B`G("X@075T:#HZ9V5T3&]G:6Y38W)E96XH)R<L(%5T:6PZ.F=E=$9O<FU$
M871A*"=U<FPG*2DI.PH@("`@97AI=#L*?0H*)'9A<G,@/2`F5F%R:6%B;&5S
M.CIG971$969A=6QT5F%R:6%B;&5S*"D["@HD=&ET;&4@/2!?*")#:&%N9V4@
M66]U<B!087-S=V]R9"(I.PHD9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T
M;VXH)TAO<F1E4VEG;G5P1F]R;2<L("1V87)S+"`D=&ET;&4I.PHD9F]R;2T^
M<V5T0G5T=&]N<RA?*")#;VYT:6YU92(I*3L*"B1F;W)M+3YA9&1(:61D96XH
M)R<L("=R971U<FY?=&\G+"`G=&5X="<L(&9A;'-E*3L*)&9O<FTM/F%D9%9A
M<FEA8FQE*%\H(D]L9"!P87-S=V]R9"(I+"`G;VQD7W!A<W-W;W)D)RP@)W!A
M<W-W;W)D)RP@=')U92D["B1F;W)M+3YA9&1687)I86)L92A?*").97<@<&%S
M<W=O<F0B*2P@)W!A<W-W;W)D7S$G+"`G<&%S<W=O<F0G+"!T<G5E*3L*)&9O
M<FTM/F%D9%9A<FEA8FQE*%\H(E)E='EP92!N97<@<&%S<W=O<F0B*2P@)W!A
M<W-W;W)D7S(G+"`G<&%S<W=O<F0G+"!T<G5E*3L*"FEF("@D=F%R<RT^97AI
M<W1S*"=F;W)M;F%M92<I*2!["B`@("`D9F]R;2T^=F%L:61A=&4H)'9A<G,I
M.PH@("`@:68@*"1F;W)M+3YI<U9A;&ED*"DI('L*("`@("`@("`D9F]R;2T^
M9V5T26YF;R@D=F%R<RP@)&EN9F\I.PH@("`@("`@(&1O('L*("`@("`@("`@
M("`@:68@*"1A=71H+3YG971#<F5D96YT:6%L*"=P87-S=V]R9"<I("$]("1I
M;F9O6R=O;&1?<&%S<W=O<F0G72D@>PH@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@D:6YF;ULG<&%S<W=O<F1?,2==("$]("1I
M;F9O6R=P87-S=V]R9%\R)UTI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H7R@B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1I;F9O6R=O;&1?<&%S<W=O<F0G72`]/2`D:6YF
M;ULG<&%S<W=O<F1?,2==*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*%\H(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@1DE8344Z($YE
M960@=&\@8VQE86X@=7`@<&%S<W=O<F0@<&]L:6-Y('!A=&-H(&%N9"!C;VUM
M:70@8F5F;W)E"B`@("`@("`@("`@("`J(&5N86)L:6YG('1H:7,N+BX@+4I-
M1@H*("`@("`@("`@("`@)')E<R`]($%U=&@Z.G1E<W1087-S=V]R9%-T<F5N
M9W1H*"1I;F9O6R=P87-S=V]R9%\Q)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9ELG875T:"==6R=P87-S
M=V]R9%]P;VQI8WDG72D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H)')E<RT^9V5T365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("HO"@H@("`@("`@("`@("`D<F5S(#T@)&%U=&@M/G5P9&%T955S97(H075T
M:#HZ9V5T075T:"@I+"!!=71H.CIG971!=71H*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%S<W=O<F0G(#T^("1I
M;F9O6R=P87-S=V]R9%\Q)UTI*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"AS<')I;G1F*%\H(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D
M.B`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R97,M/F=E=$UE<W-A9V4H*2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E
M+G-U8V-E<W,G*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG<F5T
M=7)N7W1O)UTI*2!["B`@("`@("`@("`@("`@("!H96%D97(H)TQO8V%T:6]N
M.B`G("X@)&EN9F];)W)E='5R;E]T;R==*3L*("`@("`@("`@("`@("`@(&5X
M:70["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?2!W:&EL92`H9F%L<V4I.PH@("`@?0I]"@HD=F%R<RT^<F5M;W9E*"=O;&1?
M<&%S<W=O<F0G*3L*)'9A<G,M/G)E;6]V92@G<&%S<W=O<F1?,2<I.PHD=F%R
M<RT^<F5M;W9E*"=P87-S=V]R9%\R)RD["@IR97%U:7)E($A/4D1%7U1%35!,
M051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN
M;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*)')E;F1E
M<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B1F;W)M+3YR96YD
M97)!8W1I=F4H)')E;F1E<F5R+"`D=F%R<RP@)V-H86YG97!A<W-W;W)D+G!H
M<"<L("=P;W-T)RD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM
M;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]J879A<V-R:7!T+G!H<```
M````````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#8R`#$P-3$U
M-#,Q,#8T`#`R,3$Q-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E
M<R]J879A<V-R:7!T+G!H<"QV(#$N,S<N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(Y
M.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H87)L
M97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C
M;W)E+G!H<"<["@HD<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;BA(
M3U)$15]315-324].7U)%041/3DQ9*3L*"B\O($9I9W5R92!O=70@:68@=V4G
M=F4@8F5E;B!I;FQI;F5D+"!O<B!C86QL960@9&ER96-T;'DN"B1S96YD7VAE
M861E<G,@/2!S=')S='(H)%]315)615);)U!(4%]314Q&)UTL("=J879A<V-R
M:7!T+G!H<"<I.PH*)&%P<"`](%5T:6PZ.F=E=$9O<FU$871A*"=A<'`G+"!5
M=&EL.CIN;VY);G!U=%9A<B@G87!P)RDI.PHD9FEL92`](%5T:6PZ.F=E=$9O
M<FU$871A*"=F:6QE)RP@571I;#HZ;F]N26YP=71687(H)V9I;&4G*2D["FEF
M("@A96UP='DH)&%P<"D@)B8@(65M<'1Y*"1F:6QE*2`F)B!S=')P;W,H)&9I
M;&4L("<N+B<I(#T]/2!F86QS92D@>PH@("`@)'-C<FEP=%]F:6QE(#T@)')E
M9VES=')Y+3YG970H)W1E;7!L871E<R<L("1A<'`I("X@)R]J879A<V-R:7!T
M+R<@+B`D9FEL93L*("`@(&EF("A`9FEL95]E>&ES=',H)'-C<FEP=%]F:6QE
M*2D@>PH@("`@("`@("1R96=I<W1R>2T^<'5S:$%P<"@D87!P+"!F86QS92D[
M"B`@("`@("`@)'-C<FEP="`](%5T:6PZ.F)U9F9E<D]U='!U="@G<F5Q=6ER
M92<L("1S8W)I<'1?9FEL92D["@H@("`@("`@(&EF("@D<V5N9%]H96%D97)S
M*2!["B`@("`@("`@("`@("\J($-O;7!R97-S('1H92!*4RX@5V4@;F5E9"!T
M:&ES(&5X<&QI8VET(&-A;&P@<VEN8V4@=V4*("`@("`@("`@("`@("H@9&]N
M)W0@:6YC;'5D92!B87-E+G!H<"!I;B!T:&ES(&9I;&4N("HO"B`@("`@("`@
M("`@($AO<F1E.CIC;VUP<F5S<T]U='!U="@I.PH*("`@("`@("`@("`@:&5A
M9&5R*"=#86-H92U#;VYT<F]L.B!N;RUC86-H92<I.PH@("`@("`@("`@("!H
M96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]J879A<V-R:7!T)RD["B`@("`@
M("`@?0H*("`@("`@("!E8VAO("1S8W)I<'0["B`@("!]"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+VME>6)O87)D+G!H<```````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3,U-#<`,3`U,34T,S$P-C0`,#(P-34V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J"B`J
M("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:V5Y8F]A<F0N<&AP+'8@,2XQ,RXQ
M,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`Q+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$
M15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*)'1I=&QE(#T@7R@B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*"C\^"@H\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^"@IV87(@=&%R9V5T.PH*9G5N8W1I;VX@:&%N9&QE
M3&ES=$-H86YG92AT:&5,:7-T*2!["B`@("!V87(@;G5M4V5L96-T960@/2!T
M:&5,:7-T+G-E;&5C=&5D26YD97@["@H@("`@:68@*&YU;5-E;&5C=&5D("$]
M(#`I('L*("`@("`@("!D;V-U;65N="YC:&%R86-T97)S+G1E>'1B;W@N=F%L
M=64@*ST@=&AE3&ES="YO<'1I;VYS6VYU;5-E;&5C=&5D72YV86QU93L*("`@
M("`@("!T:&5,:7-T+G-E;&5C=&5D26YD97@@/2`P.PH@("`@?0I]"CPO<V-R
M:7!T/@H*/&9O<FT@;F%M93TB8VAA<F%C=&5R<R(^"CQT86)L92!C96QL<W!A
M8VEN9STB,"(^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)I=&5M(&QE9G1!;&EG
M;B(^"B`@("`@(#QP/CP_<&AP(&5C:&\@7R@B4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(BD@
M/SX\+W`^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&-L87-S
M/2)L969T06QI9VXB/@H@("`@("`\=&%B;&4@8V5L;'-P86-I;F<](C`B/@H@
M("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@
M("`@("`@("`@/'-E;&5C="!N86UE/2)A(B!O;F-H86YG93TB:&%N9&QE3&ES
M=$-H86YG92AT:&ES*2(^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M82(@<V5L96-T960^(&$@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,Q.3([(CX@)B,Q.3([(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,C(T.R(^("8C,C(T.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$Y,SLB/B`F(S$Y,SL@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,C4[
M(CX@)B,R,C4[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](B8C,3DT.R(^("8C,3DT.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2(F(S(R-CLB/B`F(S(R-CL@/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q.34[(CX@)B,Q.34[(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C(W.R(^("8C
M,C(W.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S$Y-CLB/B`F(S$Y-CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,R,C@[(CX@)B,R,C@[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,3DW.R(^("8C,3DW.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(R.3LB/B`F(S(R.3L@
M/"]O<'1I;VX^"B`@("`@("`@("`@(#PO<V5L96-T/@H@("`@("`@("`@/"]T
M9#X*("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@("`@("`@("`@
M/'-E;&5C="!N86UE/2)E(B!O;F-H86YG93TB:&%N9&QE3&ES=$-H86YG92AT
M:&ES*2(^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB92(@<V5L96-T
M960^(&4@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M)B,R,#`[(CX@)B,R,#`[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](B8C,C,R.R(^("8C,C,R.R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S(P,3LB/B`F(S(P,3L@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S,[(CX@)B,R,S,[
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C`R
M.R(^("8C,C`R.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S(S-#LB/B`F(S(S-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB)B,R,#,[(CX@)B,R,#,[(#PO;W!T:6]N/@H@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C,U.R(^("8C,C,U.R`\+V]P
M=&EO;CX*("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@("`@("`\+W1D/@H@
M("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`@("`@("`\<V5L
M96-T(&YA;64](FDB(&]N8VAA;F=E/2)H86YD;&5,:7-T0VAA;F=E*'1H:7,I
M(CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2)I(B!S96QE8W1E9#X@
M:2`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(P
M-#LB/B`F(S(P-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V
M86QU93TB)B,R,S8[(CX@)B,R,S8[(#PO;W!T:6]N/@H@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](B8C,C`U.R(^("8C,C`U.R`\+V]P=&EO;CX*("`@
M("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S-SLB/B`F(S(S-SL@/"]O
M<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#8[(CX@
M)B,R,#8[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64]
M(B8C,C,X.R(^("8C,C,X.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2(F(S(P-SLB/B`F(S(P-SL@/"]O<'1I;VX^"B`@("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB)B,R,SD[(CX@)B,R,#<[(#PO;W!T:6]N
M/@H@("`@("`@("`@("`\+W-E;&5C=#X*("`@("`@("`@(#PO=&0^"B`@("`@
M("`@("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@("`@("`@(#QS96QE8W0@
M;F%M93TB;R(@;VYC:&%N9V4](FAA;F1L94QI<W1#:&%N9V4H=&AI<RDB/@H@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](F\B('-E;&5C=&5D/B!O(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C$P.R(^
M("8C,C$P.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S(T,CLB/B`F(S(T,CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,R,3$[(CX@)B,R,3$[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C0S.R(^("8C,C0S.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q,CLB/B`F(S(Q
M,CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R
M-#0[(CX@)B,R-#0[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,C$S.R(^("8C,C$S.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S(T-3LB/B`F(S(T-3L@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,30[(CX@)B,R,30[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C0V.R(^
M("8C,C0V.R`\+V]P=&EO;CX*("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@
M("`@("`\+W1D/@H@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@
M("`@("`@("`\<V5L96-T(&YA;64](G4B(&]N8VAA;F=E/2)H86YD;&5,:7-T
M0VAA;F=E*'1H:7,I(CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2)U
M(B!S96QE8W1E9#X@=2`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N
M('9A;'5E/2(F(S(Q-SLB/B`F(S(Q-SL@/"]O<'1I;VX^"B`@("`@("`@("`@
M("`@/&]P=&EO;B!V86QU93TB)B,R-#D[(CX@)B,R-#D[(#PO;W!T:6]N/@H@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C$X.R(^("8C,C$X.R`\
M+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(U,#LB
M/B`F(S(U,#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TB)B,R,3D[(CX@)B,R,3D[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64](B8C,C4Q.R(^("8C,C4Q.R`\+V]P=&EO;CX*("`@("`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(R,#LB/B`F(S(R,#L@/"]O<'1I
M;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-3([(CX@)B,R
M-3([(#PO;W!T:6]N/@H@("`@("`@("`@("`\+W-E;&5C=#X*("`@("`@("`@
M(#PO=&0^"B`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@("`@
M("`@(#QS96QE8W0@;F%M93TB3W1H97(B(&]N8VAA;F=E/2)H86YD;&5,:7-T
M0VAA;F=E*'1H:7,I(CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2)M
M:7-C(B!S96QE8W1E9#X@/#]P:'`@96-H;R!?*")/=&AE<B(I.R`_/CPO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,38R.R(^("8C
M,38R.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S$V,SLB/B`F(S$V,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,Q-C0[(CX@)B,Q-C0[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,38U.R(^("8C,38U.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$Y.#LB/B`F(S$Y.#L@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S`[
M(CX@)B,R,S`[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](B8C,C(S.R(^("8C,C(S.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2(F(S$Y.3LB/B`F(S$Y.3L@/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S$[(CX@)B,R,S$[(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C`Y.R(^("8C
M,C`Y.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S(T,3LB/B`F(S(T,3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,R-3,[(CX@)B,R-3,[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,C4U.R(^("8C,C4U.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$Y,3LB/B`F(S$Y,3L@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q-C$[
M(CX@)B,Q-C$[(#PO;W!T:6]N/@H@("`@("`@("`@("`\+W-E;&5C=#X*("`@
M("`@("`@(#PO=&0^"B`@("`@("`@/"]T<CX*("`@("`@/"]T86)L93X*("`@
M(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@8VQA<W,](F9I>&5D(&QE
M9G1!;&EG;B(^"B`@("`@(#QT97AT87)E82!R;W=S/2(T(B!C;VQS/2(R-2(@
M8VQA<W,](F9I>&5D(B!N86UE/2)T97AT8F]X(CX\+W1E>'1A<F5A/@H@("`@
M/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*
M("`@("`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@;VYC
M;&EC:STB=VEN9&]W+F-L;W-E*"D[(B!N86UE/2)C;&]S92(@=F%L=64](CP_
M<&AP(&5C:&\@7R@B0VQO<V4@5VEN9&]W(BD@/SXB("\^"B`@("`\+W1D/@H@
M(#PO='(^"CPO=&%B;&4^"CPO9F]R;3X*/"]B;V1Y/@H\+VAT;6P^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O8V%C:&5V:65W+G!H<```````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,30W-@`Q,#4Q-30S,3`V-``P,C`W,3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O<V5R=FEC97,O8V%C:&5V:65W+G!H<"QV(#$N.2XQ,"XS
M(#(P,#8O,#$O,#$@,C$Z,CDZ,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0V%C
M:&4N<&AP)SL*"B1C:60@/2!5=&EL.CIG971&;W)M1&%T82@G8VED)RD["FEF
M("AE;7!T>2@D8VED*2D@>PH@("`@97AI=#L*?0H*)&-A8VAE(#T@)DAO<F1E
M7T-A8VAE.CIS:6YG;&5T;VXH)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==+"!(
M;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=C86-H92<L("1C;VYF6R=C86-H92==
M6R=D<FEV97(G72DI.PHD8V1A=&$@/2!`=6YS97)I86QI>F4H)&-A8VAE+3YG
M970H)&-I9"P@)&-O;F9;)V-A8VAE)UU;)V1E9F%U;'1?;&EF971I;64G72DI
M.PII9B`H(21C9&%T82D@>PH@("`@97AI=#L*?0H*)&)R;W=S97(M/F1O=VYL
M;V%D2&5A9&5R<R@G8V%C:&5/8FIE8W0G+"`D8V1A=&%;)V-T>7!E)UTL('1R
M=64L('-T<FQE;B@D8V1A=&%;)V1A=&$G72DI.PIE8VAO("1C9&%T85LG9&%T
M82==.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'``````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,#`R,``Q,#4Q-30S,3`V-``P,C$V-#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`L
M=B`Q+C4N,3`N-R`R,#`V+S`U+S(T(#(R.C0U.C$S(&-H=6-K($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O
M8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$
M3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*+R\@36%K92!S=7)E(&%U=&@@
M8F%C:V5N9"!A;&QO=W,@<&%S<W=O<F1S('1O(&)E(')E<V5T+@HD875T:"`]
M("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PII
M9B`H(21A=71H+3YH87-#87!A8FEL:71Y*"=R97-E='!A<W-W;W)D)RDI('L*
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B0V%N;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@
M+B!!=71H.CIG971,;V=I;E-C<F5E;B@G)RP@571I;#HZ9V5T1F]R;41A=&$H
M)W5R;"<I*2D["B`@("!E>&ET.PI]"@HD=F%R<R`]("9687)I86)L97,Z.F=E
M=$1E9F%U;'1687)I86)L97,H*3L*"B1T:71L92`](%\H(E)E<V5T(%EO=7(@
M4&%S<W=O<F0B*3L*)&9O<FT@/2`F2&]R9&5?1F]R;3HZ<VEN9VQE=&]N*"=(
M;W)D95-I9VYU<$9O<FTG+"`D=F%R<RP@)'1I=&QE*3L*)&9O<FTM/G-E=$)U
M='1O;G,H7R@B0V]N=&EN=64B*2D["@HO*B!3970@=7`@=&AE(&9I96QD<R!F
M;W(@=&AE('5S97)N86UE(&%N9"!A;'1E<FYA=&4@96UA:6PN("HO"B1F;W)M
M+3YA9&1(:61D96XH)R<L("=U<FPG+"`G=&5X="<L(&9A;'-E*3L*)'8@/2`F
M)&9O<FTM/F%D9%9A<FEA8FQE*%\H(E5S97)N86UE(BDL("=U<V5R;F%M92<L
M("=T97AT)RP@=')U92D["B1V+3YS971/<'1I;VXH)W1R86-K8VAA;F=E)RP@
M=')U92D["B1F;W)M+3YA9&1687)I86)L92A?*")!;'1E<FYA=&4@96UA:6P@
M861D<F5S<R(I+"`G96UA:6PG+"`G96UA:6PG+"!T<G5E*3L*)&-A;E]V86QI
M9&%T92`](&9A;'-E.PH*+RH@268@82!U<V5R;F%M92!H87,@8F5E;B!S=7!P
M;&EE9"!T<GD@9F5T8VAI;F<@=&AE('!R969S('-T;W)E9"!I;F9O+B`J+PII
M9B`H)'5S97)N86UE(#T@)'9A<G,M/F=E="@G=7-E<FYA;64G*2D@>PH@("`@
M)'5S97)N86UE(#T@075T:#HZ861D2&]O:R@D=7-E<FYA;64I.PH@("`@)'!R
M969S(#T@)E!R969S.CIS:6YG;&5T;VXH)&-O;F9;)W!R969S)UU;)V1R:79E
M<B==+"`G:&]R9&4G+"`D=7-E<FYA;64L("<G+"!N=6QL+"!F86QS92D["B`@
M("`D<')E9G,M/G)E=')I979E*"D["B`@("`D96UA:6P@/2`D<')E9G,M/F=E
M=%9A;'5E*"=A;'1E<FYA=&5?96UA:6PG*3L*("`@("\J($1O97,@=&AE(&%L
M=&5R;F%T92!E;6%I;"!S=&]R960@:6X@<')E9G,@;6%T8V@@=&AE(&]N92!S
M=6)M:71T960_("HO"B`@("!I9B`H)'9A<G,M/F=E="@G96UA:6PG*2`]/2`D
M96UA:6PI('L*("`@("`@("`D8V%N7W9A;&ED871E(#T@=')U93L*("`@("`@
M("`D9F]R;2T^<V5T0G5T=&]N<RA?*")297-E="!087-S=V]R9"(I*3L*("`@
M("`@("`D<75E<W1I;VX@/2`D<')E9G,M/F=E=%9A;'5E*"=S96-U<FET>5]Q
M=65S=&EO;B<I.PH@("`@("`@("1F;W)M+3YA9&1687)I86)L92@D<75E<W1I
M;VXL("=Q=65S=&EO;B<L("=D97-C<FEP=&EO;B<L(&9A;'-E*3L*("`@("`@
M("`D9F]R;2T^861D5F%R:6%B;&4H7R@B06YS=V5R(BDL("=A;G-W97(G+"`G
M=&5X="<L('1R=64I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*%\H(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("!]"GT*"B\J(%9A;&ED871E('1H92!F;W)M+B`J+PII9B`H)&-A
M;E]V86QI9&%T92`F)B`D9F]R;2T^=F%L:61A=&4H)'9A<G,I*2!["B`@("`D
M9F]R;2T^9V5T26YF;R@D=F%R<RP@)&EN9F\I.PH*("`@("\J($9E=&-H('9A
M;'5E<R!F<F]M('!R969S(&9O<B!S96QE8W1E9"!U<V5R+B`J+PH@("`@)&%N
M<W=E<B`]("1P<F5F<RT^9V5T5F%L=64H)W-E8W5R:71Y7V%N<W=E<B<I.PH*
M("`@("\J($-H96-K('1H92!G:79E;B!V86QU97,@=VET:'0@=&AE('!R969S
M('-T;W)E9"!O;F5S+B`J+PH@("`@:68@*"1E;6%I;"`]/2`D:6YF;ULG96UA
M:6PG72`F)B!3=')I;F<Z.FQO=V5R*"1A;G-W97(I(#T](%-T<FEN9SHZ;&]W
M97(H)&EN9F];)V%N<W=E<B==*2D@>PH@("`@("`@("\J($EN9F\@;6%T8VAE
M<RP@<V\@<F5S970@=&AE('!A<W-W;W)D+B`J+PH@("`@("`@("1P87-S=V]R
M9"`]("1A=71H+3YR97-E=%!A<W-W;W)D*"1I;F9O6R=U<V5R;F%M92==*3L*
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+G!H<"<["B`@("`@("`@)&UA
M:6QE<B`]($UA:6PZ.F9A8W1O<GDH)&-O;F9;)VUA:6QE<B==6R=T>7!E)UTL
M("1C;VYF6R=M86EL97(G75LG<&%R86US)UTI.PH*("`@("`@("`O*B!3970@
M=7`@=&AE(&5M86EL(&AE861E<G,@86YD(&)O9'DN("HO"B`@("`@("`@)&AE
M861E<G-;)T9R;VTG72`]("1E;6%I;#L*("`@("`@("`D:&5A9&5R<ULG5&\G
M72`]("1E;6%I;#L*("`@("`@("`D<F5C:7!I96YT<UM=(#T@)&AE861E<G-;
M)U1O)UT["B`@("`@("`@)&AE861E<G-;)U-U8FIE8W0G72`](%\H(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970B*3L*("`@("`@("`D8F]D>2`]('-P
M<FEN=&8H7R@B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(I+"`D
M<F5G:7-T<GDM/F=E="@G;F%M92<L("=H;W)D92<I+"`D<&%S<W=O<F0I.PH@
M("`@("`@("1M86EL97(M/G-E;F0H)')E8VEP:65N=',L("1H96%D97)S+"`D
M8F]D>2D["@H@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N(BDL("=H;W)D92YS=6-C
M97-S)RD["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($%U=&@Z.F=E
M=$QO9VEN4V-R965N*"<G+"`D:6YF;ULG=7)L)UTI*3L*("`@("`@("!E>&ET
M.PH@("`@?2!E;'-E('L*("`@("`@("`O*B!);F9O('-U8FUI='1E9"!D;V5S
M(&YO="!M871C:"!W:&%T(&ES(&EN('!R969S+"!R961I<F5C="!U<V5R(&)A
M8VL*("`@("`@("`@*B!T;R!L;V=I;BX@*B\*("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*%\H(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R
M('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(I+"`G
M:&]R9&4N97)R;W(G*3L*("`@('T*?0H*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T
M:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["G)E<75I<F5?
M;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PHD<F5N9&5R97(@/2`F
M;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H*3L*)&9O<FTM/G)E;F1E<D%C=&EV
M92@D<F5N9&5R97(L("1V87)S+"`G<F5S971P87-S=V]R9"YP:'`G+"`G<&]S
M="<I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E
M<BYI;F,G.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P
M<F5F<RYP:'``````````````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$P-#4T`#$P-3$U-#,Q,#8T`#`R,#`V-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]S97)V:6-E<R]P<F5F<RYP:'`L=B`Q+C$Y+C(N,3`@,C`P-B\P
M,B\P-R`R,SHU,#HP,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+U!R969S+U5)+G!H<"<["@HD<F5G:7-T<GD@/2`F4F5G:7-T
M<GDZ.G-I;F=L971O;B@I.PH*+RH@1FEG=7)E(&]U="!W:&EC:"!A<'!L:6-A
M=&EO;B!W92=R92!S971T:6YG('!R969E<F5N8V5S(&9O<BX@*B\*)&%P<"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=A<'`G+"!0<F5F<U]523HZ9V5T1&5F875L
M=$%P<"@I*3L*)&%P<&)A<V4@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`D87!P*3L*"B\J(%-E92!I9B!W92!H879E(&$@<')E9F5R96YC97,@9W)O
M=7`@<V5T+B`J+PHD9W)O=7`@/2!5=&EL.CIG971&;W)M1&%T82@G9W)O=7`G
M*3L*"B\J($QO860@)&%P<"=S(&)A<V4@96YV:7)O;FUE;G0L(&)U="!D;VXG
M="!R97%U97-T('1H870@=&AE(&%P<"!P97)F;W)M"B`J(&%U=&AE;G1I8V%T
M:6]N(&)E>6]N9"!(;W)D92=S+B`J+PHD875T:&5N=&EC871I;VX@/2`G;F]N
M92<["G)E<75I<F5?;VYC92`D87!P8F%S92`N("<O;&EB+V)A<V4N<&AP)SL*
M"B\J(%-E="!T:71L92X@*B\*)'1I=&QE(#T@<W!R:6YT9BA?*")/<'1I;VYS
M(&9O<B`E<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*3L*"B\J(%-P96-I
M86P@8V%S92!W:&5R92!W92!N965D('1H92!)9&5N=&ET>2!O8FIE8W0@:6X@
M2&]R9&4G<R!P<F5F<RYP:'`N("HO"FEF("@D9W)O=7`@/3T@)VED96YT:71I
M97,G("8F("1A<'`@/3T@)VAO<F1E)RD@>PH@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92])9&5N=&ET>2YP:'`G.PH@("`@)&ED96YT:71Y(#T@)DED96YT:71Y
M.CIS:6YG;&5T;VXH)&%P<"`]/2`G:&]R9&4G(#\@;G5L;"`Z(&%R<F%Y*"1A
M<'`L("1A<'`I*3L*?0H*+RH@3&]A9"`D87!P)W,@<')E9F5R96YC97,L(&EF
M(&%N>2X@*B\*)'!R969'<F]U<',@/2!A<G)A>2@I.PII9B`H9FEL95]E>&ES
M=',H)&%P<&)A<V4@+B`G+V-O;F9I9R]P<F5F<RYP:'`G*2D@>PH@("`@<F5Q
M=6ER92`D87!P8F%S92`N("<O8V]N9FEG+W!R969S+G!H<"<["GT*"B\J($QO
M860@8W5S=&]M('!R969E<F5N8V4@:&%N9&QE<G,@9F]R("1A<'`L(&EF('!R
M97-E;G0N("HO"FEF("AF:6QE7V5X:7-T<R@D87!P8F%S92`N("<O;&EB+W!R
M969S+G!H<"<I*2!["B`@("!R97%U:7)E7V]N8V4@)&%P<&)A<V4@+B`G+VQI
M8B]P<F5F<RYP:'`G.PI]"@HO*B!)9B!T:&5R92=S(&]N;'D@;VYE('!R969'
M<F]U<"P@:G5S="!S:&]W(&ET+B`J+PII9B`H96UP='DH)&=R;W5P*2`F)B!C
M;W5N="@D<')E9D=R;W5P<RD@/3T@,2D@>PH@("`@)&=R;W5P(#T@87)R87E?
M:V5Y<R@D<')E9D=R;W5P<RD["B`@("`D9W)O=7`@/2!A<G)A>5]P;W`H)&=R
M;W5P*3L*?0H*:68@*"1G<F]U<"`]/2`G:61E;G1I=&EE<R<I('L*("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("1I9&5N=&ET
M>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"1A<'`@/3T@)VAO<F1E)R`_(&YU
M;&P@.B!A<G)A>2@D87!P+"`D87!P*2D["B`@("!I9B`H)&%P<"`A/2`G:&]R
M9&4G*2!["B`@("`@("`@:68@*%5T:6PZ.FYO;DEN<'5T5F%R*"=P<F5F1W)O
M=7!S)RDI('L*("`@("`@("`@("`@)&ME97!0<F5F1W)O=7!S(#T@)'!R969'
M<F]U<',["B`@("`@("`@("`@('5N<V5T*"1P<F5F1W)O=7!S*3L*("`@("`@
M("!]"B`@("`@("`@<F5Q=6ER92!(3U)$15]"05-%("X@)R]C;VYF:6<O<')E
M9G,N<&AP)SL*("`@("`@("`D:&]R9&5?;65M8F5R<R`]("1P<F5F1W)O=7!S
M6R=I9&5N=&ET:65S)UU;)VUE;6)E<G,G73L*("`@("`@("!I9B`H571I;#HZ
M;F]N26YP=71687(H)VME97!0<F5F1W)O=7!S)RDI('L*("`@("`@("`@("`@
M)'!R969'<F]U<',@/2`D:V5E<%!R969'<F]U<',["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@=6YS970H)'!R969'<F]U<',I.PH@("`@("`@('T*
M("`@('T*"B`@("!I9B`H:7-S970H)&AO<F1E7VUE;6)E<G,I*2!["B`@("`@
M("`@)'!R969'<F]U<'-;)VED96YT:71I97,G75LG;65M8F5R<R==(#T@87)R
M87E?;65R9V4H)&AO<F1E7VUE;6)E<G,L("1P<F5F1W)O=7!S6R=I9&5N=&ET
M:65S)UU;)VUE;6)E<G,G72D["B`@("!]"@H@("`@<W=I=&-H("A5=&EL.CIG
M971&;W)M1&%T82@G86-T:6]N240G*2D@>PH@("`@8V%S92`G=7!D871E7W!R
M969S)SH*("`@("`@("!I9B`H)'!R969S+3YI<TQO8VME9"@G9&5F875L=%]I
M9&5N=&ET>2<I*2!["B`@("`@("`@("`@("1D969A=6QT(#T@)&ED96YT:71Y
M+3YG971$969A=6QT*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&1E9F%U;'0@/2!5=&EL.CIG9710;W-T*"=D969A=6QT7VED96YT:71Y)RD[
M"B`@("`@("`@("`@("1I9"`](%5T:6PZ.F=E=%!O<W0H)VED96YT:71Y)RD[
M"B`@("`@("`@("`@(&EF("@D:60@/3T@+3$I('L*("`@("`@("`@("`@("`@
M("1I9"`]("1I9&5N=&ET>2T^861D*"D["B`@("`@("`@("`@('T@96QS96EF
M("@D:60@/3T@+3(I('L*("`@("`@("`@("`@("`@("1P<F5F1W)O=7!S6R=I
M9&5N=&ET:65S)UU;)VUE;6)E<G,G72`](&%R<F%Y*"=D969A=6QT7VED96YT
M:71Y)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&ED96YT:71Y+3YS
M971$969A=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(&EF("A0<F5F<U]5
M23HZ:&%N9&QE1F]R;2@D9W)O=7`L("1I9&5N=&ET>2DI('L*("`@("`@("`@
M("`@)')E<W5L="`]("1I9&5N=&ET>2T^=F5R:69Y*"D["B`@("`@("`@("`@
M("1I9&5N=&ET>2T^<V5T1&5F875L="@D9&5F875L="D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="P@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M:61E;G1I='DM/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1I9&5N=&ET>2T^<V5T1&5F875L="@D9&5F875L
M="D["B`@("`@("`@("`@("1I9&5N=&ET>2T^<V%V92@I.PH@("`@("`@('T*
M("`@("`@("!U;G-E="@D<')E9D=R;W5P<RD["B`@("`@("`@<F5Q=6ER92`D
M87!P8F%S92`N("<O8V]N9FEG+W!R969S+G!H<"<["B`@("`@("`@8G)E86L[
M"@H@("`@8V%S92`G9&5L971E7VED96YT:71Y)SH*("`@("`@("`D:60@/2`H
M:6YT*55T:6PZ.F=E=$9O<FU$871A*"=I9"<I.PH@("`@("`@("1D96QE=&5D
M7VED96YT:71Y(#T@)&ED96YT:71Y+3YD96QE=&4H)&ED*3L*("`@("`@("!U
M;G-E="@D7W!R969S6R=D969A=6QT7VED96YT:71Y)UU;)V5N=6TG75LD:61=
M*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE
M(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(I+"`D9&5L971E
M9%]I9&5N=&ET>5LP75LG:60G72DL("=H;W)D92YS=6-C97-S)RD["B`@("`@
M("`@8G)E86L["@H@("`@8V%S92`G8VAA;F=E7V1E9F%U;'1?:61E;G1I='DG
M.@H@("`@("`@("1D969A=6QT7VED96YT:71Y(#T@)&ED96YT:71Y+3YS971$
M969A=6QT*%5T:6PZ.F=E=$9O<FU$871A*"=I9"<I*3L*("`@("`@("`D:61E
M;G1I='DM/G-A=F4H*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H
M(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@("`@("!B<F5A:SL*("`@('T*?2!E;'-E:68@*%!R969S7U5).CIH86YD
M;&5&;W)M*"1G<F]U<"P@)'!R969S*2D@>PH@("`@<F5Q=6ER92`D87!P8F%S
M92`N("<O8V]N9FEG+W!R969S+G!H<"<["GT*"B\J(%-H;W<@=&AE(%5)+B`J
M+PI0<F5F<U]523HZ9V5N97)A=&5522@D9W)O=7`I.PH*<F5Q=6ER92`D<F5G
M:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF
M;V]T97(N:6YC)SL*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V=O+G!H<```````
M````````````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4V-3``
M,3`U,34T,S$P-C0`,#$W,S4W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!!('-C<FEP="!T;R!R961I
M<F5C="!T;R!A(&=I=F5N(%523"P@=7-E9"!F;W(@97AA;7!L92!I;B!)35`@
M=&\@:&ED92!A;GD*("H@<F5F97)R97(@9&%T82!B96EN9R!P87-S960@=&\@
M=&AE(')E;6]T92!S97)V97(@86YD('!O=&5N=&EA;&QY(&5X<&]S:6YG"B`J
M(&%N>2!S97-S:6]N($E$<RX*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]G;RYP:'`L=B`Q+C8N,BXQ-B`R
M,#`V+S`V+S(R(#`R.C0S.C(T(&-H=6-K($5X<"`D"B`J"B`J($!A=71H;W(@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("HO"@II9B`H96UP='DH
M)%]'151;)W5R;"==*2D@>PH@("`@97AI=#L*?0H*)'5R;"`]('1R:6TH)%]'
M151;)W5R;"==*3L*:68@*'!R96=?;6%T8V@H)R\[7',J=7)L7',J/2]I)RP@
M)'5R;"DI('L*("`@("\J($E%('=I;&P@<')O8V5S<R!T:&4@;&%S="`[55),
M/2!S=')I;F<L(&YO="!T:&4@9FER<W0L(&%L;&]W:6YG"B`@("`@*B!P<F]T
M;V-O;',@=&AA="!S:&]U;&1N)W0@8F4@;&5T('1H<F]U9V@N("HO"B`@("!E
M>&ET.PI]"@II9B`H9V5T7VUA9VEC7W%U;W1E<U]G<&,H*2D@>PH@("`@)'!A
M<G-E9%]U<FP@/2!`<&%R<V5?=7)L*'-T<FEP<VQA<VAE<R@D=7)L*2D["GT@
M96QS92!["B`@("`D<&%R<V5D7W5R;"`]($!P87)S95]U<FPH)'5R;"D["GT*
M"FEF("AE;7!T>2@D<&%R<V5D7W5R;"D@?'P@96UP='DH)'!A<G-E9%]U<FQ;
M)VAO<W0G72DI('L*("`@(&5X:70["GT*:68@*&5M<'1Y*"1P87)S961?=7)L
M6R=P871H)UTI*2!["B`@("`D<&%R<V5D7W5R;%LG<&%T:"==(#T@9F%L<V4[
M"GT*"B\O($1O(&$@;&ET=&QE(&1U92!D:6QI9V5N8V4@;VX@=&AE('1A<F=E
M="!54DPN($EF(&ET)W,@;VX@=&AE('-A;64@<V5R=F5R"B\O('1H870@=V4G
M<F4@86QR96%D>2!O;BP@9&ES<&QA>2!A;B!I;G1E<FUE9&EA=&4@<&%G92!A
M<VMI;F<@<&5O<&QE(&EF"B\O('1H97DG<F4@<W5R92!T:&5Y('=A;G0@=&\@
M8VQI8VL@=&AR;W5G:"X*:68@*'-U8G-T<BAP:'!?<V%P:5]N86UE*"DL(#`L
M(#,I(#T]("=C9VDG*2!["B`@("`O+R!7:&5N('5S:6YG($-'22!02%`L(%-#
M4DE05%].04U%(&UA>2!C;VYT86EN('1H92!P871H('1O('1H92!02%`@8FEN
M87)Y"B`@("`O+R!I;G-T96%D(&]F('1H92!S8W)I<'0@8F5I;F<@<G5N.R!U
M<V4@4$A07U-%3$8@:6YS=&5A9"X*("`@("1M>75R;"`]("1?4T525D526R=0
M2%!?4T5,1B==.PI](&5L<V4@>PH@("`@)&UY=7)L(#T@:7-S970H)%]315)6
M15);)U-#4DE05%].04U%)UTI(#\*("`@("`@("`D7U-%4E9%4ELG4T-225!4
M7TY!344G72`Z"B`@("`@("`@)%]315)615);)U!(4%]314Q&)UT["GT*+R\@
M,38@:7,@=&AE(&QE;F=T:"!O9B`B+W-E<G9I8V5S+V=O+G!H<"(N"B1W96)R
M;V]T(#T@<W5B<W1R*"1M>75R;"P@,"P@+3$V*3L*"B\O($)U:6QD(&$@;&ES
M="!O9B!H;W-T<R!C;VYS:61E<F5D(&1A;F=E<F]U<R`H;&]C86P@:&]S=',L
M('1H92!U<V5R)W,*+R\@:&]S="P@971C*2X*)&1A;F=E<F]U<U]H;W-T<R`]
M(&%R<F%Y*"=L;V-A;&AO<W0G+"`G;&]C86QH;W-T+FQO8V%L9&]M86EN)RP@
M)S$R-RXP+C`N,2<I.PII9B`H(65M<'1Y*"1?4T525D526R=315)615)?3D%-
M12==*2D@>PH@("`@)&1A;F=E<F]U<U]H;W-T<UM=(#T@)%]315)615);)U-%
M4E9%4E].04U%)UT["GT*:68@*"%E;7!T>2@D7U-%4E9%4ELG2%144%](3U-4
M)UTI*2!["B`@("`D9&%N9V5R;W5S7VAO<W1S6UT@/2`D7U-%4E9%4ELG2%14
M4%](3U-4)UT["GT*"B\O($QI<W0@;V8@86QL;W=E9"!S97)V:6-E<RX*)&%L
M;&]W961?=7)I<R`](&%R<F%Y*"D["@HO+R!#:&5C:R!A9V%I;G-T(&]U<B!L
M:7-T<RX*:68@*"AE;7!T>2@D=V5B<F]O="D@?'P@<W1R<&]S*"1P87)S961?
M=7)L6R=P871H)UTL("1W96)R;V]T*2`]/3T@,"D@)B8*("`@("%E;7!T>2@D
M<&%R<V5D7W5R;%LG<75E<GDG72D@)B8*("`@("%I;E]A<G)A>2@D<&%R<V5D
M7W5R;%LG<&%T:"==+"`D86QL;W=E9%]U<FES*2`F)@H@("`@:6Y?87)R87DH
M)'!A<G-E9%]U<FQ;)VAO<W0G72P@)&1A;F=E<F]U<U]H;W-T<RDI('L*/SX*
M/&AT;6P^"CQH96%D/@H\=&ET;&4^4&]T96YT:6%L;'D@1&%N9V5R;W5S(%52
M3#PO=&ET;&4^"CPO:&5A9#X*/&)O9'D^"B`\:#$^4&]T96YT:6%L;'D@1&%N
M9V5R;W5S(%523#PO:#$^"@H@/'`^"B`@02!R969E<G)I;F<@<VET92P@86X@
M96UA:6P@>6]U('=E<F4@<F5A9&EN9RP@;W(@<V]M92!O=&AE<@H@('!O=&5N
M=&EA;&QY('5N=')U<W1E9"!S;W5R8V4@:&%S(&%T=&5M<'1E9"!T;R!S96YD
M('EO=2!T;R`\/W!H<"!E8VAO"B`@:'1M;'-P96-I86QC:&%R<R@D=7)L*2`_
M/BX@5&AI<R!M87D@8F4@86X@871T96UP="!T;PH@(&1E;&5T92!D871A(&]R
M(&-H86YG92!S971T:6YG<R!W:71H;W5T('EO=7(@:VYO=VQE9&=E+B!)9@H@
M('EO=2!H879E(&%N>2!C;VYC97)N<R!A8F]U="!T:&ES(%523"P@<&QE87-E
M(&-O;G1A8W0@>6]U<@H@(%-Y<W1E;2!!9&UI;FES=')A=&]R+B!)9B!Y;W4@
M87)E(&-O;F9I9&5N="!T:&%T(&ET(&ES('-A9F4L"B`@>6]U(&UA>2!F;VQL
M;W<@=&AE(&QI;FL@8GD@8VQI8VMI;F<@8F5L;W<N"B`\+W`^"@H@/'`^"B`@
M/&$@:')E9CTB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<FPI(#\^
M(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5R;"D@/SX\+V$^"B`\
M+W`^"@H\+V)O9'D^"CPO:'1M;#X*/#]P:'`*("`@(&5X:70["GT*"FAE861E
M<B@G4F5F<F5S:#H@,#L@55),/2<@+B`D=7)L*3L*````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O<')O8FQE;2YP:'``````````````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C4V-@`Q,#4Q-30S,3`V-``P,C`T
M,38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<')O8FQE;2YP
M:'`L=B`R+C$Q-"XX+C@@,C`P-B\P,2\Q-B`Q-#HR-#HP,R!C:'5C:R!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M+RH@4V5N9"!T:&4@8G)O=W-E<B!B86-K('1O('1H92!C;W)R96-T('!A9V4N
M("HO"F9U;F-T:6]N(%]R971U<FY4;U!A9V4H*0I["B`@("`D=7)L(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W)E='5R;E]U<FPG+"!(;W)D93HZ=7)L*"1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O
M;&]G:6XN<&AP)RP@=')U92DI.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M('-T<E]R97!L86-E*"<F86UP.R<L("<F)RP@)'5R;"DI.PH@("`@97AI=#L*
M?0H*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/
M4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O=F5R<VEO;BYP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["@II9B`H(4AO<F1E.CIS:&]W
M4V5R=FEC92@G<')O8FQE;2<I*2!["B`@("!?<F5T=7)N5&]086=E*"D["GT*
M"B1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B1E;6%I;"`]
M("1I9&5N=&ET>2T^9V5T5F%L=64H)V9R;VU?861D<B<I.PII9B`H(21E;6%I
M;"D@>PH@("`@)&5M86EL(#T@571I;#HZ9V5T1F]R;41A=&$H)V5M86EL)RP@
M075T:#HZ9V5T075T:"@I*3L*?0HD;65S<V%G92`](%5T:6PZ.F=E=$9O<FU$
M871A*"=M97-S86=E)RP@)R<I.PHD;F%M92`](%5T:6PZ.F=E=$9O<FU$871A
M*"=N86UE)RP@)&ED96YT:71Y+3YG971686QU92@G9G5L;&YA;64G*2D["B1S
M=6)J96-T(#T@571I;#HZ9V5T1F]R;41A=&$H)W-U8FIE8W0G+"`G)RD["@HD
M86-T:6]N240@/2!5=&EL.CIG971&;W)M1&%T82@G86-T:6]N240G*3L*<W=I
M=&-H("@D86-T:6]N240I('L*8V%S92`G<V5N9%]P<F]B;&5M7W)E<&]R="<Z
M"B`@("!I9B`H)'-U8FIE8W0@)B8@)&UE<W-A9V4I('L*("`@("`@("`O+R!4
M:&ES(&ES(&YO="!A(&=E='1E>'0@<W1R:6YG(&]N('!U<G!O<V4N"B`@("`@
M("`@)')E;6]T92`]("@A96UP='DH)%]315)615);)U)%34]415](3U-4)UTI
M*2`_("1?4T525D526R=214U/5$5?2$]35"==(#H@)%]315)615);)U)%34]4
M15]!1$12)UT["B`@("`@("`@)'5S97)?86=E;G0@/2`D7U-%4E9%4ELG2%14
M4%]54T527T%'14Y4)UT["B`@("`@("`@)&)O9'D@/2`B5&AI<R!P<F]B;&5M
M(')E<&]R="!W87,@<F5C96EV960@9G)O;2`D<F5M;W1E+B`B("X*("`@("`@
M("`@("`@(E1H92!U<V5R(&-L:6-K960@=&AE('!R;V)L96T@<F5P;W)T(&QI
M;FL@9G)O;2!T:&4@9F]L;&]W:6YG(&QO8V%T:6]N.EQN(B`N"B`@("`@("`@
M("`@(%5T:6PZ.F=E=$9O<FU$871A*"=R971U<FY?=7)L)RP@)TYO(')E<75E
M<W1I;F<@<&%G92<I("X*("`@("`@("`@("`@(EQN86YD(&ES('5S:6YG('1H
M92!F;VQL;W=I;F<@8G)O=W-E<CI<;B1U<V5R7V%G96YT7&Y<;B(@+@H@("`@
M("`@("`@("!S=')?<F5P;&%C92@B7')<;B(L(")<;B(L("1M97-S86=E*3L*
M"B`@("`@("`@+R\@1&5F875L="!T;R!A(')E;&%T:79E;'D@<F5A<V]N86)L
M92!E;6%I;"!A9&1R97-S+@H@("`@("`@(&EF("@A)&5M86EL*2!["B`@("`@
M("`@("`@("1E;6%I;"`]("=H;W)D92UP<F]B;&5M0"<@+B`D8V]N9ELG<')O
M8FQE;7,G75LG;6%I;&1O;6%I;B==.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%E;7!T>2@D8V]N9ELG<')O8FQE;7,G75LG=&EC:V5T<R==*2`F)@H@("`@
M("`@("`@("`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G=&EC:V5T<R]A9&14:6-K
M970G*2D@>PH@("`@("`@("`@("`D:6YF;R`](&%R<F%Y7VUE<F=E*"1C;VYF
M6R=P<F]B;&5M<R==6R=T:6-K971?<&%R86US)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)W-U;6UA<GDG(#T^("1S=6)J96-T
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VUM
M96YT)R`]/B`D8F]D>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=7-E<E]E;6%I;"<@/3X@)&5M86EL*2D["B`@("`@("`@("`@
M("1R97-U;'0@/2`D<F5G:7-T<GDM/F-A;&PH)W1I8VME=',O861D5&EC:V5T
M)RP@87)R87DH)&EN9F\I*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"@D<F5S=6QT*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(%]R971U<FY4;U!A9V4H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O34E-12YP:'`G.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+TU)344O2&5A9&5R<RYP:'`G.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TU)344O365S<V%G92YP:'`G.PH*("`@("`@("`@("`@+R\@061D
M('5S97(G<R!N86UE('1O('1H92!E;6%I;"!A9&1R97-S(&EF('!R;W9I9&5D
M+@H@("`@("`@("`@("!I9B`H)&YA;64I('L*("`@("`@("`@("`@("`@($!L
M:7-T*"1M86EL8F]X+"`D:&]S="D@/2!`97AP;&]D92@G0"<L("1E;6%I;"P@
M,BD["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&AO<W0I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&AO<W0@/2`D8V]N9ELG<')O8FQE;7,G75LG;6%I
M;&1O;6%I;B==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&5M86EL(#T@34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S*"1M86EL8F]X+"`D
M:&]S="P@)&YA;64I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;7-G
M7VAE861E<G,@/2`F;F5W($U)345?2&5A9&5R<R@I.PH@("`@("`@("`@("`D
M;7-G7VAE861E<G,M/F%D9%)E8V5I=F5D2&5A9&5R*"D["B`@("`@("`@("`@
M("1M<V=?:&5A9&5R<RT^861D365S<V%G94ED2&5A9&5R*"D["B`@("`@("`@
M("`@("1M<V=?:&5A9&5R<RT^861D06=E;G1(96%D97(H*3L*("`@("`@("`@
M("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H)T1A=&4G+"!D871E*"=R)RDI
M.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@G5&\G+"`D
M8V]N9ELG<')O8FQE;7,G75LG96UA:6PG72D["B`@("`@("`@("`@("1M<V=?
M:&5A9&5R<RT^861D2&5A9&5R*"=3=6)J96-T)RP@7R@B6U!R;V)L96T@4F5P
M;W)T72(I("X@)R`G("X@)'-U8FIE8W0I.PH@("`@("`@("`@("`D;7-G7VAE
M861E<G,M/F%D9$AE861E<B@G1G)O;2<L("1E;6%I;"D["B`@("`@("`@("`@
M("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=396YD97(G+"`G:&]R9&4M<')O
M8FQE;4`G("X@)&-O;F9;)W!R;V)L96US)UU;)VUA:6QD;VUA:6XG72D["@H@
M("`@("`@("`@("`D;6EM92`]("9N97<@34E-15]-97-S86=E*"D["B`@("`@
M("`@("`@("1M:6UE+3YA9&1087)T*&YE=R!-24U%7U!A<G0H)W1E>'0O<&QA
M:6XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%-T<FEN9SHZ=W)A<"@D8F]D>2P@.#`L(")<;B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E="@I
M*2D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D34E-14AE861E<G,H
M)&UI;64I.PH*("`@("`@("`@("`@)&UA:6Q?9')I=F5R(#T@)&-O;F9;)VUA
M:6QE<B==6R=T>7!E)UT["B`@("`@("`@("`@("1M86EL7W!A<F%M<R`]("1C
M;VYF6R=M86EL97(G75LG<&%R86US)UT["B`@("`@("`@("`@(&EF("@D;6%I
M;%]D<FEV97(@/3T@)W-M='`G("8F("1M86EL7W!A<F%M<ULG875T:"==("8F
M"B`@("`@("`@("`@("`@("!E;7!T>2@D;6%I;%]P87)A;7-;)W5S97)N86UE
M)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H075T:#HZ9V5T075T:"@I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&UA:6Q?<&%R86US6R=U<V5R;F%M92==
M(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@("`@("`@("`@("`@("1M86EL
M7W!A<F%M<ULG<&%S<W=O<F0G72`]($%U=&@Z.F=E=$-R961E;G1I86PH)W!A
M<W-W;W)D)RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1C
M;VYF6R=P<F]B;&5M<R==6R=U<V5R;F%M92==*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("%E;7!T>2@D8V]N9ELG<')O8FQE;7,G75LG<&%S<W=O
M<F0G72DI('L*("`@("`@("`@("`@("`@("`@("`D;6%I;%]P87)A;7-;)W5S
M97)N86UE)UT@/2`D8V]N9ELG<')O8FQE;7,G75LG=7-E<FYA;64G73L*("`@
M("`@("`@("`@("`@("`@("`D;6%I;%]P87)A;7-;)W!A<W-W;W)D)UT@/2`D
M8V]N9ELG<')O8FQE;7,G75LG<&%S<W=O<F0G73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<U]A*"1S96YT
M(#T@)&UI;64M/G-E;F0H)&-O;F9;)W!R;V)L96US)UU;)V5M86EL)UTL("1M
M<V=?:&5A9&5R<RP@)&UA:6Q?9')I=F5R+"`D;6%I;%]P87)A;7,I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`O*B!792!S=6-C965D960N
M(%)E='5R;B!T;R!P<F5V:6]U<R!P86=E(&%N9"!E>&ET('1H:7,@<V-R:7!T
M+B`J+PH@("`@("`@("`@("`@("`@7W)E='5R;E1O4&%G92@I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"@D<V5N="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@
M("!B<F5A:SL*"F-A<V4@)V-A;F-E;%]P<F]B;&5M7W)E<&]R="<Z"B`@("!?
M<F5T=7)N5&]086=E*"D["GT*"B1T:71L92`](%\H(E!R;V)L96T@1&5S8W)I
M<'1I;VXB*3L*)&UE;G4@/2`F;F5W($UE;G4H2$]21$5?345.55]-05-+7T%,
M3"`F('Y(3U)$15]-14Y57TU!4TM?4%)%1E,I.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O;65N=2]M96YU+FEN8R<["B1N;W1I9FEC871I;VXM
M/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PIR97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O<')O8FQE;2]P<F]B;&5M+FEN8R<[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN
M8R<["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+P``
M````````````````````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,3`V-0`P,38T,3(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O;&]G:6XO````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8T`#`Q-S4R,0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC````````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-3(`,3`U
M,34T,S$P-C0`,#(Q-#4W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@HD;2`]("9N97<@2&]R9&5?36]B:6QE*%\H
M(DQO9R!I;B(I*3L*)&TM/F%D9"AN97<@2&]R9&5?36]B:6QE7W1E>'0H<W!R
M:6YT9BA?*")796QC;VUE('1O("5S(BDL("1R96=I<W1R>2T^9V5T*"=N86UE
M)RDI*2D["@HD9B`]("9N97<@2&]R9&5?36]B:6QE7V9O<FTH)VQO9VEN+G!H
M<"<I.PHD9BT^861D*&YE=R!(;W)D95]-;V)I;&5?:&ED9&5N*"=U<FPG+"!5
M=&EL.CIG971&;W)M1&%T82@G=7)L)RP@)R<I*2D["B1F+3YA9&0H;F5W($AO
M<F1E7TUO8FEL95]I;G!U="@G:&]R9&5?=7-E<B<L("<G+"!?*")5<V5R;F%M
M93H@(BDI*3L*"B\O($%D9"!A('!A<W-W;W)D(&EN<'5T+"!A;F0@<V5T('1H
M92!T>7!E(&%C8V]R9&EN9VQY+@HD<"`]("8D9BT^861D*&YE=R!(;W)D95]-
M;V)I;&5?:6YP=70H)VAO<F1E7W!A<W,G+"`G)RP@7R@B4&%S<W=O<F0Z("(I
M*2D["B1P+3YS970H)W1Y<&4G+"`G<&%S<W=O<F0G*3L*"B\O(%-U8FUI="!B
M=71T;VXN"B1F+3YA9&0H;F5W($AO<F1E7TUO8FEL95]S=6)M:70H7R@B3&]G
M(&EN(BDI*3L*"B\O($%D9"!T:&4@9F]R;2!T;R!T:&4@<&%G92X*)&TM/F%D
M9"@D9BD["@HO+R!$:7-P;&%Y(&5V97)Y=&AI;F<N"B1M+3YD:7-P;&%Y*"D[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,`````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(R
M-S8`,3`U,34T,S$P-C0`,#(Q,S,Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B1R:6=H=$%L:6=N(#T@96UP='DH
M)&YL<ULG<G1L)UU;)&QA;F=U86=E72D@/R`G<FEG:'0G(#H@)VQE9G0G.PHD
M;&5F=$%L:6=N(#T@96UP='DH)&YL<ULG<G1L)UU;)&QA;F=U86=E72D@/R`G
M;&5F="<@.B`G<FEG:'0G.PH_/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C
M<FEP="(^"CPA+2T*9G5N8W1I;VX@<V5T1F]C=7,H*0I["B`@("!I9B`H9&]C
M=6UE;G0N:&]R9&5?;&]G:6XN:&]R9&5?=7-E<BYV86QU92`]/2`B(BD@>PH@
M("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W5S97(N9F]C=7,H
M*3L*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN
M:&]R9&5?<&%S<RYF;V-U<R@I.PH@("`@?0I]"F9U;F-T:6]N('-U8FUI=%]L
M;V=I;BAE*0I["B`@("!I9B`H='EP96]F(&4@(3T@)W5N9&5F:6YE9"<@)B8@
M(65N=&5R7VME>5]T<F%P*&4I*2!["B`@("`@("`@<F5T=7)N.PH@("`@?0H*
M("`@(&EF("AD;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]U<V5R+G9A;'5E
M(#T]("(B*2!["B`@("`@("`@86QE<G0H(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9"(I*2`_/B(I.PH@("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E
M7W5S97(N9F]C=7,H*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!](&5L
M<V4@:68@*&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W!A<W,N=F%L=64@
M/3T@(B(I('L*("`@("`@("!A;&5R="@B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M(BDI(#\^(BD["B`@("`@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN:&]R9&5?
M<&%S<RYF;V-U<R@I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T@96QS
M92!["B`@("`@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN;&]G:6Y"=71T;VXN
M9&ES86)L960@/2!T<G5E.PH\/W!H<"!I9B`H(65M<'1Y*"1I95]C;&EE;G1C
M87!S*2DZ(#\^"B`@("`@("`@=')Y('L*("`@("`@("`@("`@9&]C=6UE;G0N
M:&]R9&5?;&]G:6XN:65?=F5R<VEO;BYV86QU92`](&]B:D-#87!S+F=E=$-O
M;7!O;F5N=%9E<G-I;VXH(GLX.3@R,#(P,"U%0T)$+3$Q0T8M.$(X-2TP,$%!
M,#`U0C0S.#-](BP@(F-O;7!O;F5N=&ED(BD["B`@("`@("`@?2!C871C:"`H
M92D@>PH@("`@("`@('T*/#]P:'`@96YD:68[(#\^"B`@("`@("`@9&]C=6UE
M;G0N:&]R9&5?;&]G:6XN<W5B;6ET*"D["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"GT*+R\M+3X*/"]S8W)I<'0^"@H\9F]R;2!N86UE/2)H;W)D95]L
M;V=I;B(@;65T:&]D/2)P;W-T(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z
M.G-E;&95<FPH9F%L<V4L('1R=64L(&9A;'-E+"!T<G5E*2`_/B(\/W!H<"!E
M8VAO("1C;VYF6R=M96YU)UU;)V%L=V%Y<R==(#\@)R!T87)G970](E]P87)E
M;G0B)R`Z("<G(#\^/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)U<FPB
M('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T
M1F]R;41A=&$H)W5R;"<I*2`_/B(@+SX*/#]P:'`@:68@*"%E;7!T>2@D:65?
M8VQI96YT8V%P<RDI.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I
M95]V97)S:6]N(B!V86QU93TB(B`O/@H\/W!H<"!E;F1I9CL@/SX*"CQD:78@
M:60](FUE;G4B/@H\/W!H<`HD;65N=2`]("9N97<@365N=2A(3U)$15]-14Y5
M7TU!4TM?3D].12D["B1H;65N=2`]("1M96YU+3YR96YD97(H*3L*:68@*"1H
M;65N=2DZ(#\^"B`\<W!A;B!S='EL93TB9FQO870Z/#]P:'`@96-H;R`D<FEG
M:'1!;&EG;B`_/B(^/#]P:'`@96-H;R`D:&UE;G4@/SX\+W-P86X^"CP_<&AP
M(&5N9&EF.R`_/@H@/&@Q('-T>6QE/2)T97AT+6%L:6=N.F-E;G1E<B(^/#]P
M:'`@<')I;G1F*%\H(E=E;&-O;64@=&\@)7,B*2P@)')E9VES=')Y+3YG970H
M)VYA;64G*2D@/SX\+V@Q/@H\+V1I=CX*"CQB<B!C;&%S<STB<W!A8V5R(B`O
M/@H\/W!H<"`D;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R
M<R<@/3X@)W-T871U<R<I*2`_/@H*/'1A8FQE('=I9'1H/2(Q,#`E(CX\='(^
M/'1D(&%L:6=N/2)C96YT97(B/CQT86)L92!W:61T:#TB,S`P(B!A;&EG;CTB
M8V5N=&5R(CX*"CP_<&AP(&EF("@A96UP='DH)')E87-O;BDI.B`_/@H\='(^
M"B`@/'1D(&-O;'-P86X](C(B(&-L87-S/2)N;W1I8V4B/CP_<&AP(&5C:&\@
M)')E87-O;B`_/CPO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/'1R/@H@
M("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1R:6=H=$%L:6=N(#\^(B!C;&%S
M<STB;&EG:'0B/CQS=')O;F<^/#]P:'`@96-H;R!?*")5<V5R;F%M92(I(#\^
M/"]S=')O;F<^)FYB<W`[/"]T9#X*("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H
M;R`D;&5F=$%L:6=N(#\^(CX\:6YP=70@8VQA<W,](F9I>&5D(B!T>7!E/2)T
M97AT(B!N86UE/2)H;W)D95]U<V5R(B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*%5T:6PZ.F=E=$9O<FU$871A*"=H;W)D95]U<V5R)RDI
M(#\^(B!S='EL93TB9&ER96-T:6]N.FQT<B(@+SX\+W1D/@H\+W1R/@H*/'1R
M/@H@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1R:6=H=$%L:6=N(#\^(B!C
M;&%S<STB;&EG:'0B/CQS=')O;F<^/#]P:'`@96-H;R!?*")087-S=V]R9"(I
M(#\^/"]S=')O;F<^)FYB<W`[/"]T9#X*("`@(#QT9"!A;&EG;CTB/#]P:'`@
M96-H;R`D;&5F=$%L:6=N(#\^(CX\:6YP=70@8VQA<W,](F9I>&5D(B!T>7!E
M/2)P87-S=V]R9"(@;F%M93TB:&]R9&5?<&%S<R(@=F%L=64](B(@<W1Y;&4]
M(F1I<F5C=&EO;CIL='(B("\^/"]T9#X*/"]T<CX*"CP_<&AP(&EF("@A)'!R
M969S+3YI<TQO8VME9"@G;&%N9W5A9V4G*2DZ(#\^"CQT<CX*("`@(#QT9"!A
M;&EG;CTB/#]P:'`@96-H;R`D<FEG:'1!;&EG;B`_/B(@8VQA<W,](FQI9VAT
M(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B3&%N9W5A9V4B*2`_/CPO<W1R;VYG
M/CPO=&0^"B`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_
M/B(@8VQA<W,](FQI9VAT(B!S='EL93TB9&ER96-T:6]N.FQT<B(^/#]P:'`@
M96-H;R`D;&%N9W,@/SX\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*"CQT
M<CX*("`@(#QT9#XF;F)S<#L\+W1D/@H@("`@/'1D(&%L:6=N/2(\/W!H<"!E
M8VAO("1L969T06QI9VX@/SXB(&-L87-S/2)L:6=H="(^/&EN<'5T(&YA;64]
M(FQO9VEN0G5T=&]N(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H
M;R!?*"),;V<@:6XB*2`_/B(@='EP93TB<W5B;6ET(B!O;F-L:6-K/2)R971U
M<FX@<W5B;6ET7VQO9VEN*"D[(B`O/CPO=&0^"CPO='(^"@H\/W!H<"!I9B`H
M(65M<'1Y*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72D@)B8@)&%U=&@M/FAA
M<T-A<&%B:6QI='DH)V%D9"<I*3H@/SX*/'1R/@H@("`@/'1D/B9N8G-P.SPO
M=&0^"B`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(@
M8VQA<W,](FQI9VAT(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D
M9%!A<F%M971E<BA(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T
M)RP@)VAO<F1E)RD@+B`G+W-I9VYU<"YP:'`G*2P@)W5R;"<L(%5T:6PZ.F=E
M=$9O<FU$871A*"=U<FPG*2DL(%\H(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB*2P@)VQI9VAT)RD@+B!?*")$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N(BD@/SX\+V$^/"]T9#X*/"]T<CX*/#]P:'`@96YD:68[
M(#\^"CP_<&AP(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G<F5S971P87-S
M=V]R9"<I*3H@/SX*/'1R/@H@("`@/'1D/B9N8G-P.SPO=&0^"B`@("`\=&0@
M8VQA<W,](FQI9VAT(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D
M9%!A<F%M971E<BA(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T
M)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP)RDL
M("=U<FPG+"!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI+"!?*")&;W)G;W0@
M>6]U<B!P87-S=V]R9#\B*2P@)VQI9VAT)RD@+B!?*")&;W)G;W0@>6]U<B!P
M87-S=V]R9#\B*2`_/CPO83X\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*
M"CPO=&%B;&4^/"]T9#X\+W1R/CPO=&%B;&4^"CPO9F]R;3X*"CP_<&AP(&EF
M("A`:7-?<F5A9&%B;&4H2$]21$5?0D%312`N("<O8V]N9FEG+VUO=&0N<&AP
M)RDI(')E<75I<F4@2$]21$5?0D%312`N("<O8V]N9FEG+VUO=&0N<&AP)SL@
M/SX*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H\/W!H
M<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)VQA;F=U86=E)RDI.@H@("`@)&QA
M;F=?=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L;V=I;BYP:'`G+"!T
M<G5E*3L*("`@(&EF("@H)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG
M*2DI('L*("`@("`@("`D;&%N9U]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M)&QA;F=?=7)L+"`G=7)L)RP@)'5R;"P@9F%L<V4I.PH@("`@?0H@("`@)&QA
M;F=?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1L86YG7W5R;"P@)VYE=U]L
M86YG)RP@)R<L(&9A;'-E*3L*/SX*9G5N8W1I;VX@<V5L96-T3&%N9R@I"GL*
M("`@("\O(%=E(&YE960@=&\@<F5L;V%D('1H92!L;V=I;B!P86=E(&AE<F4L
M(&)U="!O;FQY(&EF('1H92!U<V5R"B`@("`O+R!H87-N)W0@86QR96%D>2!E
M;G1E<F5D(&$@=7-E<FYA;64@86YD('!A<W-W;W)D+@H@("`@:68@*&1O8W5M
M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W5S97(N=F%L=64@/3T@)R<@)B8*("`@
M("`@("!D;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]P87-S+G9A;'5E(#T]
M("<G*2!["B`@("`@("`@=F%R(&QA;F=?<&%G92`]("<\/W!H<"!E8VAO("1L
M86YG7W5R;"`_/B<@*R!D;V-U;65N="YH;W)D95]L;V=I;BYN97=?;&%N9UMD
M;V-U;65N="YH;W)D95]L;V=I;BYN97=?;&%N9RYS96QE8W1E9$EN9&5X72YV
M86QU93L*("`@("`@("!S96QF+FQO8V%T:6]N(#T@;&%N9U]P86=E.PH@("`@
M?0I]"CP_<&AP(&5N9&EF.R`_/@H*:68@*'!A<F5N="YF<F%M97,N:&]R9&5?
M;6%I;BD@>PH@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN=&%R9V5T(#T@)U]P
M87)E;G0G.PI]"@HO+R!3970@=7`@=&AE(&5N=&5R(&ME>71R87`@8V]D92X*
M:68@*'1Y<&5O9B!D;V-U;65N="YC87!T=7)E179E;G1S("$]("=U;F1E9FEN
M960G*2!["B`@("!D;V-U;65N="YC87!T=7)E179E;G1S*$5V96YT+DM%65!2
M15-3*3L*("`@(&1O8W5M96YT+F]N:V5Y<')E<W,@/2!S=6)M:71?;&]G:6X[
M"GT*+R\M+3X*/"]S8W)I<'0^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]H96QP+P``````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C0`,#$W,S0Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VAE;'`O;65N=2YI
M;F,`````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q,``Q
M,#4Q-30S,3`V-``P,C`W-S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/&1I=B!C;&%S<STB:&5A9&5R(CX*(#QS<&%N(&-L
M87-S/2)L969T1FQO870B/@H@(#P_<&AP(&5C:&\@)'1O<&EC<U]L:6YK(#\^
M"B`\+W-P86X^"CP_<&AP(&EF("@D8V]N9ELG;65N=2==6R=L:6YK<R==6R=H
M96QP7V%B;W5T)UTI.B`_/@H@/'-P86X@8VQA<W,](G)I9VAT1FQO870B/@H@
M(#P_<&AP(&5C:&\@)&%B;W5T7VQI;FL@/SX*(#PO<W!A;CX*/#]P:'`@96YD
M:68[(#\^"B`\<W!A;B!S='EL93TB8VQE87(Z8F]T:"(^)FYB<W`[/"]S<&%N
M/@H\+V1I=CX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]H96QP+VEN9&5X+FEN8P``````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W,#0`,3`U,34T,S$P-C0`
M,#(Q,30Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#PA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@
M,2XP($9R86UE<V5T+R]%3B(@(D141"]X:'1M;#$M9G)A;65S970N9'1D(CX*
M/&AT;6P^"CQH96%D/@H@/'1I=&QE/CP_<&AP(&5C:&\@7R@B2&5L<"(I(#\^
M/"]T:71L93X*/"]H96%D/@H*/&9R86UE<V5T(')O=W,](C,P+"HB(&9R86UE
M8F]R9&5R/2)N;R(@8F]R9&5R/2(P(B!F<F%M97-P86-I;F<](C`B/@H@/&9R
M86UE(&YA;64](FAE;'!?;65N=2(@<V-R;VQL:6YG/2)N;R(@;6%R9VEN:&5I
M9VAT/2(P(B!M87)G:6YW:61T:#TB,"(@<W)C/2(\/W!H<"!E8VAO("1M96YU
M7W5R;"`_/B(@+SX*(#QF<F%M92!N86UE/2)H96QP7VUA:6XB(')E<VEZ96%B
M;&4](GEE<R(@;6%R9VEN:&5I9VAT/2(R(B!M87)G:6YW:61T:#TB,B(@<W)C
M/2(\/W!H<"!E8VAO("1M86EN7W5R;"`_/B(@+SX*/"]F<F%M97-E=#X*"CPO
M:'1M;#X*````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O:&5L<"]A8F]U="YI;F,`````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C$V`#$P-3$U-#,Q,#8T`#`R,3$T,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\:#(@86QI
M9VX](F-E;G1E<B(^/#]P:'`@<')I;G1F*%\H(E1H:7,@:7,@)7,N(BDL("1V
M97)S:6]N*2`_/CPO:#(^"CQP<F4@<W1Y;&4](F1I<F5C=&EO;CIL='(B/CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8W)E9&ET<RD@/SX\+W!R93X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VUE;G4O````````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,3<S-34`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T96UP;&%T97,O;65N=2]M96YU+FEN8P``````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3,P`#$P-3$U-#,Q,#8T`#`R,3`P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M9&EV(&ED/2)M96YU(CX*(#QD:78@8VQA<W,](FQE9G1&;&]A="(^"B`@/#]P
M:'`@96-H;R`D;65N=2T^<F5N9&5R*"D@/SX*(#PO9&EV/@H\+V1I=CX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W1E<W0O````````````````````````````````````````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,3<S-S``(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]V97)S:6]N+FEN8P``````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,38T`#$P-3$U-#,Q,#8T
M`#`R,34T-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\:#$^/#]P:'`@96-H;R`D;6]D=6QE(#\^(%9E<G-I;VX\+V@Q/@H\
M=6P^"B`@("`\;&D^/#]P:'`@96-H;R`D;6]D=6QE(#\^.B`\/W!H<"!E8VAO
M("1M;V1U;&5?=F5R<VEO;B`_/CPO;&D^"CPO=6P^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+W1E<W0O<&AP7W9E<G-I;VXN:6YC````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,3<V,@`Q,#4Q-30S,3`V-``P,C(T,C(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&@Q/E!(
M4"!697)S:6]N/"]H,3X*/'5L/@H@("`@/&QI/CQA(&AR968](CP_<&AP(&5C
M:&\@)'!H<%]I;F9O+3YP:'!I;F9O(#\^(CY6:65W('!H<&EN9F\H*2!S8W)E
M96X\+V$^/"]L:3X*("`@(#QL:3X\82!H<F5F/2(\/W!H<"!E8VAO("1P:'!?
M:6YF;RT^97AT96YS:6]N<R`_/B(^5FEE=R!L;V%D960@97AT96YS:6]N<SPO
M83X\+VQI/@H@("`@/&QI/E!(4"!697)S:6]N.B`\/W!H<"!E8VAO("1P:'!?
M:6YF;RT^=F5R<VEO;B`_/CPO;&D^"B`@("`\;&D^4$A0($UA:F]R(%9E<G-I
M;VXZ(#P_<&AP(&5C:&\@)'!H<%]I;F9O+3YM86IO<B`_/CPO;&D^"CP_<&AP
M(&EF("AI<W-E="@D<&AP7VEN9F\M/FUI;F]R*2DZ(#\^"B`@("`\;&D^4$A0
M($UI;F]R(%9E<G-I;VXZ(#P_<&AP(&5C:&\@)'!H<%]I;F9O+3YM:6YO<B`_
M/CPO;&D^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H:7-S970H)'!H<%]I
M;F9O+3YS=6)M:6YO<BDI.B`_/@H@("`@/&QI/E!(4"!3=6)M:6YO<B!697)S
M:6]N.B`\/W!H<"!E8VAO("1P:'!?:6YF;RT^<W5B;6EN;W(@/SX\+VQI/@H\
M/W!H<"!E;F1I9CL@/SX*("`@(#QL:3Y02%`@5F5R<VEO;B!#;&%S<VEF:6-A
M=&EO;CH@/#]P:'`@96-H;R`D<&AP7VEN9F\M/F-L87-S(#\^/"]L:3X*("`@
M(#QL:2!S='EL93TB8V]L;W(Z/#]P:'`@96-H;R`D<&AP7VEN9F\M/G-T871U
M<U]C;VQO<B`_/B(^/'-T<F]N9SX\/W!H<"!E8VAO("1P:'!?:6YF;RT^<W1A
M='5S(#\^/"]S=')O;F<^/"]L:3X*/#]P:'`@:68@*&ES<V5T*"1P:'!?:6YF
M;RT^=F5R<VEO;E]C:&5C:RDI.B`_/@H@("`@/&QI/CP_<&AP(&5C:&\@)'!H
M<%]I;F9O+3YV97)S:6]N7V-H96-K(#\^/"]L:3X*/#]P:'`@96YD:68[(#\^
M"CP_<&AP(&EF("AI<W-E="@D<&AP7VEN9F\M/FEN<V5C=7)E*2DZ(#\^"B`@
M("`\;&D@<W1Y;&4](F-O;&]R.F]R86YG92(^/'-T<F]N9SX\/W!H<"!E8VAO
M("1P:'!?:6YF;RT^:6YS96-U<F4@/SX\<W1R;VYG/CPO;&D^"CP_<&AP(&5N
M9&EF.R`_/@H\+W5L/@H``````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O97AT96YS:6]N<RYI;F,`````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#(S,0`Q,#4Q-30S,3`V-``P,C(R
M-3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&AT;6P^"CQH96%D/@H\=&ET;&4^4$A0($5X=&5N<VEO;G,\+W1I=&QE/@H\
M<W1Y;&4^"F)O9'D@>R!B86-K9W)O=6YD+6-O;&]R.B!W:&ET93L@;6%R9VEN
M+71O<#H@,#L@;6%R9VEN+6QE9G0Z(#(P.R!M87)G:6XM<FEG:'0Z(#(P.R!]
M"G1A8FQE('L@9F]N="UF86UI;'DZ($%R:6%L+"!(96QV971I8V$L('-A;G,M
M<V5R:68[(&9O;G0M<VEZ93H@,3)P>#L@;6%R9VEN+71O<#H@,#L@;6%R9VEN
M+6QE9G0Z(#`[('T*82![('1E>'0M9&5C;W)A=&EO;CH@;F]N93L@9F]N="UF
M86UI;'DZ($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68[(&9O;G0M<VEZ
M93H@,3)P>#L@;6%R9VEN+71O<#H@,#L@;6%R9VEN+6QE9G0Z(#`[('T*83IA
M8W1I=F4@>R!C;VQO<CH@(S(T-3=F9CL@?0IA.FAO=F5R('L@8V]L;W(Z(",R
M-#4W9F8[('1E>'0M9&5C;W)A=&EO;CH@=6YD97)L:6YE.R!]"F$Z;&EN:R![
M(&-O;&]R.B`C,C0U-V9F.R!]"F$Z=FES:71E9"![(&-O;&]R.B`C,C0U-V9F
M.R!]"BYB;&%C:R![(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`P,#`[(&-O;&]R
M.B`C9F9F9F9F.R!]"CPO<W1Y;&4^"CPO:&5A9#X*/&)O9'D^"CQA(&AR968]
M(CP_<&AP(&5C:&\@:7-S970H)%]'151;)W5R;"==*2`_(&AT;6QS<&5C:6%L
M8VAA<G,H)%]'151;)W5R;"==*2`Z("=T97-T+G!H<"<@/SX_;6]D93UT97-T
M(CXF;'0[)FQT.R!"86-K('1O('1E<W0N<&AP/"]A/@H\8G(@+SX*/'1A8FQE
M('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^/'1R/CQT9"!C;VQS<&%N
M/2(R(CX\=&%B;&4^"CQT<CX\=&0^<&AP('9E<G-I;VXZ/"]T9#X\=&0^/'-T
M<F]N9SX\/W!H<"!E8VAO('!H<'9E<G-I;VXH*2`_/CPO<W1R;VYG/CPO=&0^
M/"]T<CX*/'1R/CQT9#YS97)V97(@87!I.CPO=&0^/'1D/CQS=')O;F<^/#]P
M:'`@96-H;R!`<&AP7W-A<&E?;F%M92@I(#\^/"]S=')O;F<^/"]T9#X\+W1R
M/@H\='(^/'1D/FQO861E9"!E>'1E;G-I;VYS.CPO=&0^/'1D/CQS=')O;F<^
M/#]P:'`@)&5X=&5N<VEO;G,@/2!`9V5T7VQO861E9%]E>'1E;G-I;VYS*"D[
M(&5C:&\@8V]U;G0H)&5X=&5N<VEO;G,I.R`_/CPO<W1R;VYG/CPO=&0^/"]T
M<CX*/'1R/CQT9#YS>7-T96TZ/"]T9#X\=&0^/'-T<F]N9SX\/W!H<"!E8VAO
M($!P:'!?=6YA;64H*2`_/CPO<W1R;VYG/CPO=&0^/"]T<CX*/"]T86)L93X\
M8G(@+SX\+W1D/CPO='(^"CQT<B!C;&%S<STB8FQA8VLB/@H\=&0^/'-T<F]N
M9SYA8W1I=F%T960@97AT96YS:6]N<SH\+W-T<F]N9SX\+W1D/@H\=&0^/'-T
M<F]N9SX\/W!H<"!E8VAO(&ES<V5T*"1?1T546R=E>'0G72D@/R`D7T=%5%LG
M97AT)UT@.B`G)R`_/B!F=6YC=&EO;B!L:7-T.CPO<W1R;VYG/CPO=&0^"CPO
M='(^"CQT<CX\=&0@=F%L:6=N/2)T;W`B('=I9'1H/2(U,"4B/CQT86)L92!W
M:61T:#TB,3`P)2(^"CP_<&AP"B`@("!`<V]R="@D97AT96YS:6]N<RD["B`@
M("!F;W)E86-H("@D97AT96YS:6]N<R!A<R`D97AT96YS:6]N*2!["B`@("`@
M("`@96-H;R`G/'1R/CQT9"!W:61T:#TB,S`E(CXG("X@)&5X=&5N<VEO;B`N
M("<\+W1D/CQT9#X\82!H<F5F/2(_;6]D93UE>'1E;G-I;VYS)F%M<#ME>'0]
M)R`N("1E>'1E;G-I;VX@+B`G)F%M<#MU<FP])R`N('5R;&5N8V]D92AI<W-E
M="@D7T=%5%LG=7)L)UTI(#\@)%]'151;)W5R;"==(#H@)R<I("X@)R(^9G5N
M8W1I;VX@;&ES=#PO83X\+W1D/CPO='(^)SL*("`@('T*/SX*/"]T86)L93X\
M+W1D/CQT9"!V86QI9VX](G1O<"(@=VED=&@](C4P)2(^/'1A8FQE/@H\/W!H
M<`H@("`@:68@*&ES<V5T*"1?1T546R=E>'0G72DI('L*("`@("`@("`D9G5N
M8W1I;VYS(#T@0&=E=%]E>'1E;G-I;VY?9G5N8W,H)%]'151;)V5X="==*3L*
M("`@("`@("!I9B`H:7-?87)R87DH)&9U;F-T:6]N<RDI('L*("`@("`@("`@
M("`@<V]R="@D9G5N8W1I;VYS*3L*("`@("`@("`@("`@9F]R96%C:"`H)&9U
M;F-T:6]N<R!A<R`D9G5N8W1I;VXI('L*("`@("`@("`@("`@("`@(&5C:&\@
M(CQT<CX\=&0^/&$@:')E9CU<(FAT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO
M9G5N8W1I;VXN(B`N('-T<E]R97!L86-E*"=?)RP@)RTG+"`D9G5N8W1I;VXI
M("X@(BYP:'!<(B!T87)G970]7")?8FQA;FM<(CXD9G5N8W1I;VX\+V$^/"]T
M9#X\+W1R/EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*/SX*
M/"]T86)L93X\+W1D/CPO='(^/"]T86)L93X\+V)O9'D^/"]H=&UL/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O9F]O=&5R+FEN
M8P``````````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`R,``Q,#4Q
M-30S,3`V-``P,C$S-#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/"]B;V1Y/@H\+VAT;6P^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]T97-T+VAE861E<BYI;F,`````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-C(`,3`U,34T,S$P-C0`,#(Q
M,S$U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#PA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP
M(%1R86YS:71I;VYA;"\O14XB(")$5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD
M=&0B/@H\:'1M;#X*/&AE860^"CQT:71L93X\/W!H<"!E8VAO("1M;V1U;&4@
M/SXZ(%-Y<W1E;2!#87!A8FEL:71I97,@5&5S=#PO=&ET;&4^"CQS='EL92!T
M>7!E/2)T97AT+V-S<R(^"CPA+2T*8F]D>2![(&9O;G0M9F%M:6QY.B!'96YE
M=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,3!P
M=#L@?0IT9"![(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T:6-A
M+'-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,3!P=#L@?6@Q('L@9F]N="US:7IE
M.B`Q,G!T.R!C;VQO<CH@8FQA8VL[(&9O;G0M9F%M:6QY.B!697)D86YA+$=E
M;F5V82Q!<FEA;"Q(96QV971I8V$L"G-A;G,M<V5R:68[('T*+2T^"CPO<W1Y
M;&4^"CPO:&5A9#X*"CQB;V1Y(&)G8V]L;W(](G=H:71E(B!T97AT/2)B;&%C
M:R(^"@``````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O;6%I;G1E;F%N8V4O````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8T`#`R,#8W,P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P,38`,3`U,34T,S$P
M-C0`,#(T,#0Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#QD:78@:60](FUE;G4B/CQH,3XF;F)S<#L\=&%G.FAE861E<B`O
M/CPO:#$^/"]D:78^"@H\9F]R;2!M971H;V0](G!O<W0B(&%C=&EO;CTB/'1A
M9SIM86EN=%]U<FP@+SXB(&YA;64](FUA:6YT7V-O;F9I<FTB/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)L;V%D7V9R86UE<V5T(B!V86QU93TB(B`O
M/@H\=&%G.FUA:6YT7W!O<W1D871A("\^"@H\:68Z:F%V87-C<FEP=#X*/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"F9U;F-T:6]N('5N
M8VAE8VM!;&PH*0I["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&1O8W5M96YT
M+FUA:6YT7V-O;F9I<FTN96QE;65N=',N;&5N9W1H.R!I*RLI('L*("`@("`@
M("!D;V-U;65N="YM86EN=%]C;VYF:7)M+F5L96UE;G1S6VE=+F-H96-K960@
M/2!F86QS93L*("`@('T*?0HO+RTM/@H\+W-C<FEP=#X*/"]I9CIJ879A<V-R
M:7!T/@H*/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,B(^"B`\
M='(^"B`@/'1D/CQT86<Z;F]T:69Y("\^/"]T9#X*(#PO='(^"@H\;&]O<#IT
M87-K<SX*(#QT<CX*("`\=&0@8VQA<W,](FQI9VAT(CX*/&EF.F-O;F9I<FT^
M"B`@(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB/'1A9SIT87-K<RYP
M<F5F("\^7V-O;F9I<FTB/'1A9SIT87-K<RYC:&5C:V5D("\^/B9N8G-P.R9N
M8G-P.PH\+VEF.F-O;F9I<FT^"CQI9CIA9W)E93X*("`@/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB/'1A9SIT87-K<RYP<F5F("\^7V-O;F9I<FTB('9A
M;'5E/2(Q(B`O/@H\+VEF.F%G<F5E/@H\:68Z;F]T:6-E/@H@("`\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2(\=&%G.G1A<VMS+G!R968@+SY?8V]N9FER
M;2(@=F%L=64](C$B("\^"CPO:68Z;F]T:6-E/@H@("`\=&%G.G1A<VMS+F1E
M<V-R:7`@+SX*("`\+W1D/@H@/"]T<CX*/"]L;V]P.G1A<VMS/@H*(#QT<CX*
M("`\=&0^)FYB<W`[/"]T9#X*(#PO='(^"@H@/'1R/@H@(#QT9#X*/&EF.F-O
M;F9I<FT^"B`@(#QI;G!U="!N86UE/2)O:R(@='EP93TB<W5B;6ET(B!C;&%S
M<STB8G5T=&]N(B!V86QU93TB/&=E='1E>'0^4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS/"]G971T97AT/B(@;VYC;&EC:STB9&]C=6UE;G0N;6%I
M;G1?8V]N9FER;2YS=6)M:70H*3LB("\^"CQI9CIJ879A<V-R:7!T/@H@("`F
M;F)S<#LF;F)S<#L*("`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U
M='1O;B(@=F%L=64](CQG971T97AT/E-K:7`@36%I;G1E;F%N8V4\+V=E='1E
M>'0^(B!O;F-L:6-K/2)U;F-H96-K06QL*"D[(&1O8W5M96YT+FUA:6YT7V-O
M;F9I<FTN<W5B;6ET*"D[(B`O/@H\+VEF.FIA=F%S8W)I<'0^"CPO:68Z8V]N
M9FER;3X*/&EF.F%G<F5E/@H@("`\:6YP=70@;F%M93TB;VLB('1Y<&4](G-U
M8FUI="(@;F%M93TB86=R964B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\9V5T
M=&5X=#Y997,L($D@06=R964\+V=E='1E>'0^(B!O;F-L:6-K/2)D;V-U;65N
M="YM86EN=%]C;VYF:7)M+G-U8FUI="@I.R(@+SX*("`@/&EN<'5T('1Y<&4]
M(G-U8FUI="(@;F%M93TB;F]T7V%G<F5E(B!C;&%S<STB8G5T=&]N(B!V86QU
M93TB/&=E='1E>'0^3D\L($D@1&\@3D]4($%G<F5E/"]G971T97AT/B(@;VYC
M;&EC:STB9&]C=6UE;G0N;6%I;G1?8V]N9FER;2YS=6)M:70H*3LB("\^"CPO
M:68Z86=R964^"CQI9CIN;W1I8V4^"B`@(#QI;G!U="!N86UE/2)O:R(@='EP
M93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/&=E='1E>'0^0VQI
M8VL@=&\@0V]N=&EN=64\+V=E='1E>'0^(B!O;F-L:6-K/2)D;V-U;65N="YM
M86EN=%]C;VYF:7)M+G-U8FUI="@I.R(@+SX*/"]I9CIN;W1I8V4^"B`@/"]T
M9#X*(#PO='(^"CPO=&%B;&4^"@H\+V9O<FT^"@H\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^"CPA+2T*9&]C=6UE;G0N;6%I;G1?8V]N9FER;2YO
M:RYF;V-U<R@I.PII9B`H='EP96]F('=I;F1O=RYP87)E;G0N9G)A;65S+FAO
M<F1E7VUE;G4@/3T@)W5N9&5F:6YE9"<I(&1O8W5M96YT+FUA:6YT7V-O;F9I
M<FTN;&]A9%]F<F%M97-E="YV86QU92`](#$["B\O+2T^"CPO<V-R:7!T/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B\`
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C0`,#$W-3`Q`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+V%D;6EN+W5S97(O````````````````````````````````
M```````````````````````````````````````P,#0P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-``P,C`T-3<`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B]A9&0N:6YC
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<T`#$P-3$U-#,Q
M,#8T`#`R,3<P,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HD<F5N9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N
M9&5R97(H*3L*)&%D9$9O<FTM/G)E;F1E<D%C=&EV92@D<F5N9&5R97(L("1V
M87)S+"!(;W)D93HZ<V5L9E5R;"@I+"`G<&]S="<I.PH_/@H\8G(@+SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,`````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4W-0`Q,#4Q-30S,3`V-``P,C(V,S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&@Q
M(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")096YD:6YG(%-I9VYU
M<',Z(BD@/SX*/"]H,3X*"CP_<&AP("1A;&Q1=65U960@/2`D<VEG;G5P+3YG
M9711=65U9613:6=N=7!S*"D[(&EF("@A8V]U;G0H)&%L;%%U975E9"DI.B`_
M/@H\9&EV(&-L87-S/2)T97AT(CX\96T^/#]P:'`@96-H;R!?*").;R!P96YD
M:6YG('-I9VYU<',N(BD@/SX\+V5M/CPO9&EV/@H\/W!H<"!E;'-E.B`_/@H\
M=&%B;&4@8VQA<W,](G-T<FEP960B('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN
M9STB,"(^"B`\='(@8VQA<W,](FET96TB/@H@(#QT:#XF;F)S<#L\+W1H/@H@
M(#QT:#XF;F)S<#L\+W1H/@H@(#QT:#X\/W!H<"!E8VAO(%\H(E5S97)N86UE
M(BD@/SX\+W1H/@H@(#QT:"!W:61T:#TB,3`P)2(^/#]P:'`@96-H;R!?*")$
M871E(%)E8V5I=F5D(BD@/SX\+W1H/@H@/"]T<CX*/#]P:'`@9F]R96%C:"`H
M)&%L;%%U975E9"!A<R`D<VEG;G5P*3H@:68@*"1S:6=N=7`M/F=E=$YA;64H
M*2`A/2!$051!5%)%15]23T]4*3H@)&1A=&$@/2`D<VEG;G5P+3YG971$871A
M*"D[(#\^"B`\='(^"B`@/'1D/@H@("`\9F]R;2!M971H;V0](G!O<W0B(&%C
M=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(CX*("`@(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5S97)?;F%M92(@=F%L=64](CP_
M<&AP(&5C:&\@)'-I9VYU<"T^9V5T3F%M92@I(#\^(B`O/@H@("`@/&EN<'5T
M('1Y<&4](FAI9&1E;B(@;F%M93TB9F]R;2(@=F%L=64](F%P<')O=F5?9B(@
M+SX*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A
M;'5E/2(\/W!H<"!E8VAO(%\H(D%P<')O=F4B*2`_/B(@+SX*("`@/"]F;W)M
M/@H@(#PO=&0^"B`@/'1D/@H@("`\9F]R;2!M971H;V0](G!O<W0B(&%C=&EO
M;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(CX*("`@(#QI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](G5S97)?;F%M92(@=F%L=64](CP_<&AP
M(&5C:&\@)'-I9VYU<"T^9V5T3F%M92@I(#\^(B`O/@H@("`@/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB9F]R;2(@=F%L=64](G)E;6]V97%U975E9%]F
M(B`O/@H@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@
M=F%L=64](CP_<&AP(&5C:&\@7R@B4F5M;W9E(BD@/SXB("\^"B`@(#PO9F]R
M;3X*("`\+W1D/@H@(#QT9#X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'-I9VYU<"T^9V5T3F%M92@I*2`_/CPO=&0^"B`@/'1D/CP_<&AP(&5C:&\@
M9&%T92@G62U-+60@2#II.G,G+"`D9&%T85LG9&%T95)E8V5I=F5D)UTI(#\^
M/"]T9#X*(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!E;F1F;W)E86-H
M.R`_/@H\+W1A8FQE/@H\/W!H<"!E;F1I9CL@/SX*/&)R(&-L87-S/2)S<&%C
M97(B("\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,`````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,#(R`#$P-3$U-#,Q,#8T`#`R,C(S,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\9F]R;2!N86UE/2)C;&5A<G5S97(B(&UE
M=&AO9#TB<&]S="(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O<FTB
M('9A;'5E/2)C;&5A<B(@+SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP
M('!R:6YT9BA?*")#;&5A<B!O=70@=7-E<CH@)7,B*2P@)&9?=7-E<E]N86UE
M*2`_/@H\+V@Q/@H\<"!C;&%S<STB:71E;2(^"B`\<W1R;VYG/CP_<&AP('!R
M:6YT9BA?*")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB*2P@)&9?=7-E<E]N
M86UE*2`_/CPO<W1R;VYG/@H\+W`^"CQP(&-L87-S/2)C;VYT<F]L(CX*(#QI
M;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64](G-U8FUI
M="(@=F%L=64](CP_<&AP(&5C:&\@7R@B0VQE87(@=7-E<B(I(#\^(B`O/@H@
M/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB<W5B
M;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*")#86YC96PB*2`_/B(@+SX*/"]P
M/@H\+V9O<FT^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`T-#0P`#$P-3$U-#,Q,#8T`#`R,C0S,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(^"CPA+2T*"F9U;F-T:6]N('9A;&ED871E7W5P9&%T92@I
M"GL*("`@(&EF("AD;V-U;65N="YU<&1A=&5U<V5R+G5S97)?;F%M92YV86QU
M92`]/2`B(BD@>PH@("`@("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]N
M86UE+F9O8W5S*"D["B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M(BDI(#\^)RD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E(&EF
M("AD;V-U;65N="YU<&1A=&5U<V5R+G5S97)?<&%S<U\Q("8F"B`@("`@("`@
M("`@("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S$N=F%L=64@
M(3T@9&]C=6UE;G0N=7!D871E=7-E<BYU<V5R7W!A<W-?,BYV86QU92D@>PH@
M("`@("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S$N=F%L=64@
M/2`B(CL*("`@("`@("!D;V-U;65N="YU<&1A=&5U<V5R+G5S97)?<&%S<U\R
M+G9A;'5E(#T@(B(["B`@("`@("`@9&]C=6UE;G0N=7!D871E=7-E<BYU<V5R
M7W!A<W-?,2YF;V-U<R@I.PH@("`@("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(BDI(#\^)RD["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(')E='5R;B!T<G5E.PI]
M"@HO+RTM/@H\+W-C<FEP=#X*"CQF;W)M(&YA;64](G5P9&%T975S97(B(&UE
M=&AO9#TB<&]S="(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O<FTB
M('9A;'5E/2)U<&1A=&4B/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)U
M<V5R7VYA;64B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&9?=7-E<E]N86UE*2`_/B(@+SX*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P
M:'`@<')I;G1F*%\H(E5P9&%T92`E<R(I+"`D9E]U<V5R7VYA;64I(#\^"CPO
M:#$^"CQT86)L92!C;&%S<STB<W1R:7!E9"!N;W=R87`B(&-E;&QS<&%C:6YG
M/2(P(B!W:61T:#TB,3`P)2(^"CP_<&AP(&EF("@D875T:"T^:&%S0V%P86)I
M;&ET>2@G=7!D871E)RDI.B`_/@H@/'1R/@H@(#QT9"!W:61T:#TB,24B(&-L
M87-S/2)L:6=H="!R:6=H=$%L:6=N(CX*("`@/#]P:'`@96-H;R!?*").97<@
M57-E<FYA;64@*&]P=&EO;F%L*2(I(#\^"B`@/"]T9#X*("`\=&0^"B`@(#QI
M;G!U="!T>7!E/2)T97AT(B!N86UE/2)U<V5R7VYA;64R(B!V86QU93TB/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1F7W5S97)?;F%M92D@/SXB("\^
M"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H=$%L:6=N
M(CX*("`@/#]P:'`@96-H;R!?*")087-S=V]R9"(I(#\^"B`@/"]T9#X*("`\
M=&0^"B`@(#QI;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB=7-E<E]P87-S
M7S$B("\^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H
M=$%L:6=N(CX*("`@/#]P:'`@96-H;R!?*")#;VYF:7)M(%!A<W-W;W)D(BD@
M/SX*("`\+W1D/@H@(#QT9#X*("`@/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N
M86UE/2)U<V5R7W!A<W-?,B(@+SX*("`\+W1D/@H@/"]T<CX*/#]P:'`@96YD
M:68[(#\^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*("`@/#]P
M:'`@96-H;R!?*")&=6QL($YA;64B*2`_/@H@(#PO=&0^"B`@/'1D/@H@("`\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB=7-E<E]F=6QL;F%M92(@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:61E;G1I='DM/F=E=%9A
M;'5E*"=F=6QL;F%M92<I*2`_/B(@+SX*("`\+W1D/@H@/"]T<CX*(#QT<CX*
M("`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@("`\/W!H<"!E8VAO(%\H(D5M
M86EL($%D9')E<W,B*2`_/@H@(#PO=&0^"B`@/'1D/@H@("`\:6YP=70@='EP
M93TB=&5X="(@;F%M93TB=7-E<E]E;6%I;"(@('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&ED96YT:71Y+3YG971686QU92@G9G)O;5]A
M9&1R)RDI(#\^(B`O/@H@(#PO=&0^"B`\+W1R/@H@/'1R/@H@(#QT9"!C;&%S
M<STB8V]N=')O;"!L969T06QI9VXB(&-O;'-P86X](C(B/@H@("`\:6YP=70@
M='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)S=6)M:70B(&]N
M8VQI8VL](G)E='5R;B!V86QI9&%T95]U<&1A=&4H*3LB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(E5P9&%T92!U<V5R(BD@/SXB("\^"B`@(#QI;G!U="!T>7!E
M/2)R97-E="(@8VQA<W,](F)U='1O;B(@;F%M93TB<F5S970B('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(E)E<V5T(BD@/SXB("\^"B`@/"]T9#X*(#PO='(^"CPO
M=&%B;&4^"CPO9F]R;3X*/&)R("\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,#`Q`#$P-3$U-#,Q,#8T`#`R,S8T-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\9F]R;2!M
M971H;V0](G!O<W0B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R
M;"@I(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](F9O<FTB('9A;'5E/2)R96UO=F5Q=65U960B
M("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5S97)?;F%M92(@=F%L
M=64](CP_<&AP(&5C:&\@)&9?=7-E<E]N86UE(#\^(B`O/@H*/&@Q(&-L87-S
M/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")096YD:6YG(%-I9VYU<',Z(BD@
M/SX*/"]H,3X*/'`@8VQA<W,](FET96TB/@H@/#]P:'`@<')I;G1F*%\H(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_(BDL("1F7W5S97)?;F%M92D@/SX*/"]P/@H\<"!C;&%S
M<STB8V]N=')O;"(^"B`@/&EN<'5T(&-L87-S/2)B=71T;VXB('1Y<&4](G-U
M8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5M;W9E(BD@/SXB("\^"CPO
M<#X*/"]F;W)M/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S<W`#$P-3$U-#,Q,#8T`#`R,C0U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M9F]R;2!N86UE/2)R96UO=F5U<V5R(B!M971H;V0](G!O<W0B/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)F;W)M(B!V86QU93TB<F5M;W9E(B`O/@H*
M/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F*%\H(E)E;6]V92!U
M<V5R.B`E<R(I+"`D9E]U<V5R7VYA;64I(#\^"CPO:#$^"CQP(&-L87-S/2)I
M=&5M(CX*(#QS=')O;F<^/#]P:'`@<')I;G1F*%\H(E)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(BDL("1F7W5S
M97)?;F%M92D@/SX\+W-T<F]N9SX*/"]P/@H\<"!C;&%S<STB8V]N=')O;"(^
M"B`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)S
M=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E;6]V92!U<V5R(BD@/SXB
M("\^"B`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE
M/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"(I(#\^(B`O
M/@H\+W`^"CPO9F]R;3X*`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#0R-P`Q,#4Q-30S,3`V-``P,C(R,S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&@Q(&-L87-S/2)H
M96%D97(B/@H@/#]P:'`@96-H;R!?*")!9&1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(BD@/SX*/"]H,3X*/'`@8VQA<W,](F-O;G1R;VPB/@H@/#]P:'`@96-H
M;R!?*")9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T
M;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I
M9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+B(I(#\^"CPO<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,`````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`S-3(`,3`U,34T,S$P-C0`,#(R-#4W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QH,2!C;&%S<STB:&5A9&5R(CX*(#P_
M<&AP(&5C:&\@7R@B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB*2`_/@H\
M+V@Q/@H\<"!C;&%S<STB8V]N=')O;"(^"B`\/W!H<"!E8VAO(%\H(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BXB*2`_/@H\+W`^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8P``````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S`P`#$P-3$U
M-#,Q,#8T`#`R,C$Q-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(%\H
M(E5S97)S(&EN('1H92!S>7-T96TZ(BD@/SX*(#P_<&AP(&EF("@D;G5M:71E
M;2DZ(#\^"B`@/'-M86QL/EL\/W!H<"!P<FEN=&8H7R@B)7,@=&\@)7,@;V8@
M)7,B*2P@)'-T87)T+"`D96YD+"`D;G5M:71E;2D@/SY=/"]S;6%L;#X*(#P_
M<&AP(&5N9&EF.R`_/@H\+V@Q/@H*/&1I=B!C;&%S<STB:&5A9&5R8F]X(CX*
M"CQD:78@8VQA<W,](F-O;G1R;VPB/@H@/&9O<FT@;65T:&]D/2)P;W-T(B!N
M86UE/2)S96%R8V@B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R
M;"@I(#\^(CX*(#P_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](G!A9V4B('9A;'5E/2(P(CX*(#QS
M=')O;F<^/#]P:'`@96-H;R!?*")396%R8V@B*2`_/CH\+W-T<F]N9SXF;F)S
M<#L*(#QI;G!U="!N86UE/2)S96%R8VA?<&%T=&5R;B(@='EP93TB=&5X="(@
M=F%L=64](B(@<VEZ93TB-3`B(&UA>&QE;F=T:#TB,3`P(B`O/@H@/&EN<'5T
M('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B4V5A<F-H(BD@/SXB("\^"B`\+V9O<FT^"CPO9&EV/@H*/'1A8FQE
M(&-L87-S/2)S=')I<&5D(B!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B
M/@H\/W!H<`HD<F5M;W9E(#T@)&%U=&@M/FAA<T-A<&%B:6QI='DH)W)E;6]V
M92<I.PHD=&]T86P@/2`P.PIF;W)E86-H("@D=7-E<G,@87,@)'5S97(I.@H@
M("`@:68@*"1T;W1A;"LK(#P@)&UI;B!\?"`D=&]T86P@/B`D;6%X*2!["B`@
M("`@("`@8V]N=&EN=64["B`@("!]"C\^"B`\='(^"CP_<&AP(&EF("@D<F5M
M;W9E*3H@/SX*("`\=&0@=VED=&@](C$E(CX\/W!H<"!E8VAO($AO<F1E.CIL
M:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO=7-E<BYP:'`_9F]R
M;3UR96UO=F5?9B9U<V5R7VYA;64])R`N("1U<V5R*2P@7R@B1&5L971E(BDI
M("X@2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<L(%\H(D1E;&5T92(I*2`_/CPO
M83X\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`\=&0@=VED=&@](C$E(CX\/W!H
M<"!E8VAO($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M
M:6XO=7-E<BYP:'`_9F]R;3UU<&1A=&5?9B9U<V5R7VYA;64])R`N("1U<V5R
M*2P@7R@B57!D871E(BDI("X@($AO<F1E.CII;6<H)V5D:70N<&YG)RP@7R@B
M57!D871E(BDI(#\^/"]A/CPO=&0^"B`@/'1D('=I9'1H/2(Q)2(^/#]P:'`@
M96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN
M+W5S97(N<&AP/V9O<FT]8VQE87)?9B9U<V5R7VYA;64])R`N("1U<V5R*2P@
M7R@B0VQE87(@=7-E<B!D871A(BDI("X@($AO<F1E.CII;6<H)W)E;&]A9"YP
M;F<G+"!?*")#;&5A<B!U<V5R(&1A=&$B*2D@/SX\+V$^/"]T9#X*("`\=&0@
M8VQA<W,](FQE9G1!;&EG;B(^/#]P:'`@96-H;R`D=7-E<B`_/CPO=&0^"B`\
M+W1R/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H\/W!H<`II9B`H
M)&YU;6ET96TI('L*("`@("1P86=E<B`]("9N97<@2&]R9&5?54E?4&%G97(H
M)W!A9V4G+"`D=F%R<RP@87)R87DH)VYU;2<@/3X@)'1O=&%L+"`G=7)L)R`]
M/B`D=FEE=W5R;"P@)W!A9V5?8V]U;G0G(#T^(#$P+"`G<&5R<&%G92<@/3X@
M)'!E<G!A9V4I*3L*("`@(&5C:&\@)'!A9V5R+3YR96YD97(H)'!A9V4L("1T
M;W1A;"P@)'9I97=U<FPI.PI]"C\^"CPO9&EV/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W-E='5P+P``````````
M```````````````````````````````````````````````````````````P
M,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V
M-``P,C`V-#$`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;```````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#8S`#$P-3$U-#,Q,#8T`#`R,C8S-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\=&%G.FYO=&EF>2`O/@H*/'1A8FQE
M(&-L87-S/2)S=')I<&5D(B!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B
M/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB:&5A9&5R(CX*("`@("`@/&=E='1E
M>'0^07!P;&EC871I;VX\+V=E='1E>'0^"B`@("`\+W1D/@H@("`@/'1D(&-L
M87-S/2)H96%D97(B/@H@("`@("`F;F)S<#L*("`@(#PO=&0^"B`@("`\=&0@
M8VQA<W,](FAE861E<B(^"B`@("`@(#QG971T97AT/E-T871U<SPO9V5T=&5X
M=#X*("`@(#PO=&0^"B`@/"]T<CX*("`\;&]O<#IA<'!S/@H@(#QT<CX*("`@
M(#QT9#X*("`@("`@/'1A9SIA<'!S+FYA;64@+SX*("`@("`@/'1A9SIA<'!S
M+G9E<G-I;VX@+SX*("`@(#PO=&0^"B`@("`\=&0@86QI9VX](F-E;G1E<B(^
M"B`@("`@(#QT86<Z87!P<RYC;VYF("\^"B`@("`\+W1D/@H@("`@/'1D/@H@
M("`@("`\=&%G.F%P<',N<W1A='5S("\^"B`@("`\+W1D/@H@(#PO='(^"B`@
M/"]L;V]P.F%P<',^"CPO=&%B;&4^"CQB<B`O/@H*/'1A8FQE(&ED/2)U<&1A
M=&4B(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@/'1R('9A;&EG
M;CTB=&]P(CX*("`@(#QT9"!W:61T:#TB-3`E(CX*("`@("`@/&EF.F%C=&EO
M;G,^"B`@("`@(#QH,2!C;&%S<STB:&5A9&5R(CX*("`@("`@(#QG971T97AT
M/E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4\+V=E='1E>'0^"B`@
M("`@(#PO:#$^"B`@("`@(#QT86)L92!C;&%S<STB<W1R:7!E9"(@8V5L;'-P
M86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@("`@(#QL;V]P.F%C=&EO;G,^
M"B`@("`@("`@/'1R/@H@("`@("`@("`\=&0^"B`@("`@("`@("`\=&%G.F%C
M=&EO;G,N:6-O;B`O/B`\=&%G.F%C=&EO;G,N;&EN:R`O/@H@("`@("`@("`\
M+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`\+VQO;W`Z86-T:6]N<SX*("`@
M("`@/"]T86)L93X*("`@("`@/"]I9CIA8W1I;VYS/@H@("`@/"]T9#X*("`@
M(#QT9"!W:61T:#TB-3`E(CX*("`@("`@/&EF.F9T<&9O<FT^"B`@("`@("`@
M/'1A9SIF='!F;W)M("\^"B`@("`@(#PO:68Z9G1P9F]R;3X*("`@(#PO=&0^
M"B`@/"]T<CX*/"]T86)L93X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;```
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,S(`,3`U,34T,S$P-C0`,#(R
M-S8W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QT86<Z;F]T:69Y("\^"@H\=&%G.F9O<FT@+SX*"CQI9CIP:'`^"CQB<B`O
M/@H\:#$@8VQA<W,](FAE861E<B(^"B`\9V5T=&5X=#Y'96YE<F%T960@0V]D
M93PO9V5T=&5X=#X*(#QS;6%L;#Y;(#QT86<Z9&EF9E]P;W!U<"`O/B!=/"]S
M;6%L;#X*/"]H,3X*/'1E>'1A<F5A('-T>6QE/2)W:61T:#HQ,#`E(B!R;W=S
M/2(R,"(^/'1A9SIP:'`@+SX\+W1E>'1A<F5A/@H\+VEF.G!H<#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-3$W`#$P-3$U-#,Q,#8T`#`R,C0S-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\:68Z9&EF9G,^
M"CQL;V]P.F1I9F9S/@H\:#$@8VQA<W,](FAE861E<B(@:60](CQT86<Z9&EF
M9G,N87!P("\^(CX*(#QT86<Z9&EF9G,N87!P("\^(#QS;6%L;#Y;(#QT86<Z
M9&EF9G,N=&]G9VQE7W)E;F1E<F5R("\^(%T\+W-M86QL/@H\+V@Q/@H\<')E
M(&-L87-S/2)T97AT(CX\=&%G.F1I9F9S+F1I9F8@+SX\+W!R93X*/"]L;V]P
M.F1I9F9S/@H\96QS93ID:69F<SX*/'`@8VQA<W,](FYO=&EC92(^/&=E='1E
M>'0^3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BX\+V=E='1E>'0^/"]P/@H\+V5L<V4Z9&EF9G,^"CPO
M:68Z9&EF9G,^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R\`````````````````````````````````````````````
M```````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,3`V-``P,C$P,C``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C`W`#$P-3$U-#,Q,#8T`#`R,C0T,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\9F]R
M;2!N86UE/2)E9&ET7V=R;W5P(B!M971H;V0](G!O<W0B(&%C=&EO;CTB9W)O
M=7!S+G!H<"(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$
M(B!V86QU93TB961I=&9O<FTB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](F-I9"(@=F%L=64](CP_<&AP(&5C:&\@)&=R;W5P+3YG971)9"@I(#\^
M(B`O/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*"CQH,2!C;&%S<STB
M:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G=7-E<BYP;F<G*2`N
M("<@)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P+3YG9713:&]R=$YA;64H
M*2D@/SX*/"]H,3X*"CQL86)E;"!F;W(](F5M86EL(CX\/W!H<"!E8VAO(%\H
M(D5M86EL($%D9')E<W,B*2`_/CPO;&%B96P^"CQI;G!U="!T>7!E/2)T97AT
M(B!N86UE/2)E;6%I;"(@:60](F5M86EL(B!S:7IE/2(U,"(@=F%L=64](CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`M/F=E="@G96UA:6PG
M*2D@/SXB("\^"CQB<B`O/@H\8G(@+SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*
M(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G9W)O=7`N<&YG)RD@+B`G("<@+B!?
M*")-96UB97)S(BD@/SX*/"]H,3X*"CQT86)L92!C;&%S<STB;&EN9612;W<@
M;F]W<F%P(B!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B/@H@/'1R(&-L
M87-S/2)C;VYT<F]L(CX*("`\=&@@=VED=&@](C$P)2(@8VQA<W,](FQE9G1!
M;&EG;B(^/#]P:'`@96-H;R!?*")5<V5R(BD@/SX\+W1H/@H@(#QT:"!W:61T
M:#TB.3`E(B!C;&%S<STB;&5F=$%L:6=N(CX\/W!H<"!E8VAO(%\H(E)E;6]V
M92(I(#\^/"]T:#X*(#PO='(^"CP_<&AP(&9O<F5A8V@@*"1U<V5R<R!A<R`D
M=7-E<BDZ(#\^"B`\='(^"B`@/'1D/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D=7-E<BD@/SX\+W1D/@H@(#QT9#X\:6YP=70@='EP93TB8VAE8VMB
M;W@B(&YA;64](G)E;6]V95L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'5S97(I(#\^72(@+SX\+W1D/@H@/"]T<CX*/#]P:'`@96YD9F]R96%C:#L@
M/SX*/"]T86)L93X*/&)R("\^"@H\/W!H<"!I9B`H8V]U;G0H)&EN:&5R:71E
M9%]U<V5R<RDI.B`_/@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO
M($AO<F1E.CII;6<H)V=R;W5P+G!N9R<I("X@)R`G("X@7R@B26YH97)I=&5D
M($UE;6)E<G,B*2`_/@H\+V@Q/@H\=6P^"CP_<&AP(&9O<F5A8V@@*"1I;FAE
M<FET961?=7-E<G,@87,@)'5S97(I.B`_/@H@/&QI/CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D=7-E<BD@/SX\+VQI/@H\/W!H<"!E;F1F;W)E86-H
M.R`_/@H\+W5L/@H\8G(@+SX*/#]P:'`@96YD:68[(#\^"@H\:#$@8VQA<W,]
M(FAE861E<B(^"B`\/W!H<"!E8VAO($AO<F1E.CII;6<H)W5S97(N<&YG)RD@
M+B`G("<@+B!?*")!9&0@365M8F5R<R(I(#\^"CPO:#$^"CP_<&AP(&EF("@D
M875T:"T^:&%S0V%P86)I;&ET>2@G;&ES="<I*3H@/SX*/'-E;&5C="!N86UE
M/2)N97=?=7-E<EM=(B!M=6QT:7!L93TB;75L=&EP;&4B/@H\/W!H<"!F;W)E
M86-H("@D=7-E<E]L:7-T(&%S("1U<V5R*2![(&EF("@A:6Y?87)R87DH)'5S
M97(L("1A;&Q?=7-E<G,I*2![(#\^"B`\;W!T:6]N('9A;'5E/2(\/W!H<"!E
M8VAO("1U<V5R(#\^(CX\/W!H<"!E8VAO("1U<V5R(#\^/"]O<'1I;VX^"CP_
M<&AP('T@?2`_/@H\+W-E;&5C=#X*/#]P:'`@96QS93H@/SX*/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](FYE=U]U<V5R(B`O/@H\/W!H<"!E;F1I9CL@/SX*
M/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_
M<&AP('!R:6YT9BAH=&UL<W!E8VEA;&-H87)S*%\H(E-A=F4@7"(E<UPB(BDL
M($5.5%]#3TU0050L($Y,4SHZ9V5T0VAA<G-E="@I*2P@)&=R;W5P+3YG9713
M:&]R=$YA;64H*2D@/SXB("\^"CQB<B`O/@H\8G(@+SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,`````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#<Q,P`Q,#4Q-30S,3`V-``P,C,R-#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/&9O<FT@;F%M
M93TB861D7V-H:6QD(B!M971H;V0](G!O<W0B(&%C=&EO;CTB9W)O=7!S+G!H
M<"(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU
M93TB861D8VAI;&1F;W)M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)C:60B('9A;'5E/2(\/W!H<"!E8VAO("1C:60@/SXB("\^"CP_<&AP(%5T
M:6PZ.G!F;W)M26YP=70H*2`_/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P
M:'`@96-H;R!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G*2`_/B9N8G-P.SP_<&AP
M('!R:6YT9BA?*")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B*2P@)&=N
M86UE*2`_/@H\+V@Q/@H*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F-H:6QD
M(B`O/@H\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU
M93TB/#]P:'`@96-H;R!?*")!9&0B*2`_/B(@+SX*/"]F;W)M/@H\8G(@+SX*
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8P``````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$Q,#<`,3`U,34T,S$P-C0`,#(R-S4Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QF;W)M(&YA;64](F1E;&5T92(@
M;65T:&]D/2)P;W-T(B!A8W1I;VX](F=R;W5P<RYP:'`B/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F1E;&5T969O<FTB
M("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F-I9"(@=F%L=64](CP_
M<&AP(&5C:&\@)&=R;W5P+3YG971)9"@I(#\^(B`O/@H\/W!H<"!5=&EL.CIP
M9F]R;4EN<'5T*"D@/SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C
M:&\@2&]R9&4Z.FEM9R@G9W)O=7`N<&YG)RD@/SXF;F)S<#L\/W!H<"!P<FEN
M=&8H7R@B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@
M86YD(&%N>2!S=6(M9W)O=7!S/R(I+"`D9W)O=7`M/F=E=%-H;W)T3F%M92@I
M*2`_/@H\+V@Q/@H*/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O
M;B(@;F%M93TB8V]N9FER;2(@=F%L=64](CP_<&AP(&5C:&\@7R@B1&5L971E
M(BD@/SXB("\^"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB
M(&YA;64](F-O;F9I<FTB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"(I
M(#\^(B`O/@H\+V9O<FT^"CQB<B`O/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8P``````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$W,C,`,3`U,34T,S$P-C0`,#(R-S$R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QD:78@:60](FUE;G4B
M/@H@/'-P86X@8VQA<W,](FQE9G1&;&]A="(^"CP_<&AP"B1M96YU(#T@)FYE
M=R!-96YU*"D["B1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S
M97)V:6-E<R]P;W)T86PO)RDL(%\H(DAO7VUE(BDL("=H;W)D92YP;F<G*3L*
M9F]R96%C:"`H)')E9VES=')Y+3YL:7-T07!P<R@I(&%S("1A<'`I('L*("`@
M(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G861M:6Y?;&ES="<L("1A<'`I
M*2!["B`@("`@("`@)&QI<W0@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H
M)&%P<"P@)V%D;6EN7VQI<W0G*3L*("`@("`@("!I9B`H:7-?82@D;&ES="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1V86QS*2!["B`@("`@
M("`@("`@(&EF("@D87!P("$]("=H;W)D92<I('L*("`@("`@("`@("`@("`@
M("1N86UE(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*3L*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)'9A;'-;)VYA;64G72DI('L*("`@("`@
M("`@("`@("`@("`@("`D;F%M92`N/2`G("<@+B`D=F%L<ULG;F%M92==.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&YA;64@/2`D=F%L<ULG;F%M92==.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1I;6<@/2!I<W-E="@D=F%L<ULG:6-O;B==*2`_("1R
M96=I<W1R>2T^9V5T26UA9V5$:7(H)&%P<"D@+B`G+R<@+B`D=F%L<ULG:6-O
M;B==(#H@)')E9VES=')Y+3YG970H)VEC;VXG+"`D87!P*3L*("`@("`@("`@
M("`@)&UE;G4M/F%D9"A(;W)D93HZ=7)L*"1R96=I<W1R>2T^87!P;&EC871I
M;VY796)0871H*"1V86QS6R=L:6YK)UTL("1A<'`I*2P@)&YA;64L("1I;6<L
M("<G*3L*("`@("`@("!]"B`@("!]"GT*96-H;R`D;65N=2T^<F5N9&5R*"D[
M"C\^"B`\+W-P86X^"CPO9&EV/@H`````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]I;F1E>"\`````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C0`,#$W-3(P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VEN9&5X+V9R86UE<U]I;F1E
M>"YI;F,`````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(U,P`Q,#4Q-30S
M,3`V-``P,C(V-38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`@)')T;"`](&ES<V5T*"1N;'-;)W)T;"==6R1L86YG
M=6%G95TI(#\^"CPA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@
M6$A434P@,2XP($9R86UE<V5T+R]%3B(@(D141"]X:'1M;#$M9G)A;65S970N
M9'1D(CX*/&AT;6P^"CQH96%D/@H@/&QI;FL@<F5L/2)32$]25$-55"!)0T].
M(B!H<F5F/2(\/W!H<"!E8VAO("1R96=I<W1R>2T^9V5T26UA9V5$:7(H*2`_
M/B]F879I8V]N+FEC;R(@+SX*(#QT:71L93X\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)')E9VES=')Y+3YG970H)VYA;64G*2D@/SX\+W1I=&QE/@H\
M+VAE860^"@H\9G)A;65S970@:60](FAF(B!C;VQS/2(\/W!H<"!E8VAO("@D
M<G1L(#\@)RHL)R`Z("<G*2`N("AI<W-E="@D<')E9G,I(#\@)'!R969S+3YG
M971686QU92@G<VED96)A<E]W:61T:"<I(#H@,34P*2`N("@D<G1L(#\@)R<@
M.B`G+"HG*2`_/B(@9G)A;65S<&%C:6YG/2(P(B!F<F%M96)O<F1E<CTB,"(^
M"CP_<&AP(&EF("@D<G1L*3H@/SX*("`\9G)A;64@;F%M93TB:&]R9&5?;6%I
M;B(@<W)C/2(\/W!H<"!E8VAO(%5T:6PZ.F%D9%!A<F%M971E<BAH=&UL<W!E
M8VEA;&-H87)S*"1M86EN7W!A9V4I+"`G9G)A;65S971?;&]A9&5D)RP@,2D@
M/SXB('-C<F]L;&EN9STB/#]P:'`@96-H;R`D<V-R;VQL8F%R(#\^(B!N;W)E
M<VEZ93TB;F]R97-I>F4B("\^"B`@/&9R86UE(&YA;64](FAO<F1E7VUE;G4B
M('-R8STB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<"<I(#\^(B!S8W)O;&QI;F<](F%U=&\B
M(&YO<F5S:7IE/2)N;W)E<VEZ92(@+SX*/#]P:'`@96QS93H@/SX*("`\9G)A
M;64@;F%M93TB:&]R9&5?;65N=2(@<W)C/2(\/W!H<"!E8VAO($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP)RD@
M/SXB('-C<F]L;&EN9STB875T;R(@;F]R97-I>F4](FYO<F5S:7IE(B`O/@H@
M(#QF<F%M92!N86UE/2)H;W)D95]M86EN(B!S<F,](CP_<&AP(&5C:&\@571I
M;#HZ861D4&%R86UE=&5R*&AT;6QS<&5C:6%L8VAA<G,H)&UA:6Y?<&%G92DL
M("=F<F%M97-E=%]L;V%D960G+"`Q*2`_/B(@<V-R;VQL:6YG/2(\/W!H<"!E
M8VAO("1S8W)O;&QB87(@/SXB(&YO<F5S:7IE/2)N;W)E<VEZ92(@+SX*/#]P
M:'`@96YD:68[(#\^"CPO9G)A;65S970^"@H\+VAT;6P^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP
M;&%T97,O<VAA<F5S+P``````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8T`#`Q-S8W-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]S:&%R97,O961I="YI;F,`````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C8U,C<`,3`U,34T,S$P-C0`
M,#(Q,S(W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QF;W)M(&YA;64](F5D:70B(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)%]315)615);)U!(4%]314Q&
M)UTI(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB961I=&9O<FTB
M("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F-I9"(@=F%L=64](CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<VAA<F4M/F=E=$ED*"DI(#\^
M(B`O/@H\/W!H<"!I9B`H(65M<'1Y*"1A<'`I*3H@/SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB87!P(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1A<'`I(#\^(B`O/@H\/W!H<"!E;F1I9CL@/SX*/'1A8FQE
M('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^"CQT<B!V86QI9VX](FUI
M9&1L92(^"B`@/'1D('=I9'1H/2(Q,#`E(B!C;VQS<&%N/2(V(B!C;&%S<STB
M:&5A9&5R(CX*("`@(#QS<&%N(&-L87-S/2)R:6=H=$9L;V%T(CX*("`@("`@
M/&$@:')E9CTB(R(@;VYC;&EC:STB:F%V87-C<FEP=#IW:6YD;W<N8VQO<V4H
M*3LB('-T>6QE/2)C=7)S;W(Z<&]I;G1E<B(^/#]P:'`@96-H;R!(;W)D93HZ
M:6UG*"=C;&]S92YP;F<G+"!?*")#;&]S92!7:6YD;W<B*2P@)R<L("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@("`@/"]S<&%N
M/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=P97)M<RYP;F<G+"`G)RP@
M)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^)FYB<W`[
M/#]P:'`@<')I;G1F*%\H(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(BDL(&AT
M;6QS<&5C:6%L8VAA<G,H)'-H87)E+3YG970H)VYA;64G*2DI(#\^"B`@/"]T
M9#X*/"]T<CX*/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^"@H\/W!H<"`D;W=N
M97(@/2`D<VAA<F4M/F=E="@G;W=N97(G*3L@/SX*/#]P:'`@)'5S97)P97)M
M<R`]("1P97)M+3YG9715<V5R4&5R;6ES<VEO;G,H*3L@/SX*"CPA+2T@3W=N
M97)S:&EP("TM/@H\/W!H<`II9B`H:7-S970H)'5S97)P97)M<ULD;W=N97)=
M*2D@>PH@("`@)&]P97)M(#T@)'5S97)P97)M<ULD;W=N97)=.PI](&5L<V4@
M>PH@("`@)&]P97)M(#T@4$5235-?4TA/5R!\(%!%4DU37U)%040@?"!015)-
M4U]%1$E4('P@4$5235-?1$5,151%.PI]"C\^"CQT<B!V86QI9VX](FUI9&1L
M92(^"B`@/'1D(&-L87-S/2)H96%D97(@;&5F=$%L:6=N(B!W:61T:#TB-34E
M(CX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@)R<L
M("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S
M<#LG("X@7R@B3W=N97(@4&5R;6ES<VEO;G,B*2`_/@H@(#PO=&0^"B`@/'1D
M(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B('=I9'1H/2(Q)2(^/#]P
M:'`@96-H;R!?*")3:&]W(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(B!A;&EG;CTB8V5N=&5R(B!W:61T:#TB,24B/CP_<&AP(&5C:&\@7R@B4F5A
M9"(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E
M<B(@=VED=&@](C$E(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO=&0^"B`@
M/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B('=I9'1H/2(Q)2(^
M/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H
M96%D97(@<FEG:'1!;&EG;B(@=VED=&@](C0P)2(^)FYB<W`[/"]T9#X*/"]T
M<CX*/'1R/@H\/W!H<"!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G
M*2DZ(#\^"B`@/'1D(&-L87-S/2)L:6=H="(^"B`@("`\<V5L96-T(&YA;64]
M(F]W;F5R(CX*("`@("`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H
M(E-E;&5C="!A(&YE=R!O=VYE<B(I("X@)SHG(#\^/"]O<'1I;VX^"B`@("`@
M(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M;W=N97(I(#\^(B!S96QE8W1E9#TB<V5L96-T960B/CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<RA!=71H.CIR96UO=F5(;V]K*"1O=VYE<BDI(#\^/"]O
M<'1I;VX^"B`@("`\/W!H<"!F;W)E86-H("@D=7-E<DQI<W0@87,@)'5S97(I
M('L@:68@*"1U<V5R("$]("1O=VYE<BD@>R`_/@H@("`@("`\;W!T:6]N('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H075T:#HZ<F5M;W9E2&]O:R@D
M=7-E<BDI(#\^/"]O<'1I;VX^"B`@("`\/W!H<"!]('T@/SX*("`@(#PO<V5L
M96-T/@H@(#PO=&0^"CP_<&AP(&5L<V4Z(#\^"B`@/'1D(&-L87-S/2)L:6=H
M="(^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F]W;F5R(B!V86QU93TB/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1O=VYE<BD@/SXB("\^/"]T9#X*
M/#]P:'`@96YD:68[(#\^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T
M>7!E/2)C:&5C:V)O>"(@;F%M93TB;W=N97)?<VAO=R(\/W!H<"!E8VAO("@D
M;W!E<FT@)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@
M)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP
M93TB8VAE8VMB;W@B(&YA;64](F]W;F5R7W)E860B/#]P:'`@96-H;R`H)&]P
M97)M("8@4$5235-?4D5!1"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G
M(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4]
M(F-H96-K8F]X(B!N86UE/2)O=VYE<E]E9&ET(CP_<&AP(&5C:&\@*"1O<&5R
M;2`F(%!%4DU37T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_
M/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C
M:&5C:V)O>"(@;F%M93TB;W=N97)?9&5L971E(CP_<&AP(&5C:&\@*"1O<&5R
M;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G
M(#\^("\^/"]T9#X*/"]T<CX*"CPA+2T@4W!A8V5R("TM/@H\='(^/'1D/B9N
M8G-P.SPO=&0^/"]T<CX*"CPA+2T@1&5F875L="!097)M:7-S:6]N<R`M+3X*
M/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,](FAE861E<B!L969T
M06QI9VXB/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=P97)M<RYP;F<G
M+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@
M)R9N8G-P.R<@+B!?*")!;&P@075T:&5N=&EC871E9"!5<V5R<R(I(#\^"B`@
M/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P
M:'`@96-H;R!?*")3:&]W(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^
M"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C
M:&\@7R@B161I="(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI
M9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@
M/'1D(&-L87-S/2)H96%D97(@<FEG:'1!;&EG;B(^)FYB<W`[/"]T9#X*/"]T
M<CX*/#]P:'`@)&1P97)M(#T@)'!E<FTM/F=E=$1E9F%U;'1097)M:7-S:6]N
M<R@I.R`_/@H\='(^"B`@/'1D(&-L87-S/2)L:6=H="(^)FYB<W`[/"]T9#X*
M("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N
M86UE/2)D969A=6QT7W-H;W<B/#]P:'`@96-H;R`H)&1P97)M("8@4$5235-?
M4TA/5RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*
M("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N
M86UE/2)D969A=6QT7W)E860B/#]P:'`@96-H;R`H)&1P97)M("8@4$5235-?
M4D5!1"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*
M("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N
M86UE/2)D969A=6QT7V5D:70B/#]P:'`@96-H;R`H)&1P97)M("8@4$5235-?
M141)5"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*
M("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N
M86UE/2)D969A=6QT7V1E;&5T92(\/W!H<"!E8VAO("@D9'!E<FT@)B!015)-
M4U]$14Q%5$4I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO
M=&0^"CPO='(^"@H\(2TM(%-P86-E<B`M+3X*/'1R/CQT9#XF;F)S<#L\+W1D
M/CPO='(^"@H\(2TM($=U97-T(%!E<FUI<W-I;VYS("TM/@H\='(@=F%L:6=N
M/2)M:61D;&4B/@H@(#QT9"!C;&%S<STB:&5A9&5R(&QE9G1!;&EG;B(^"B`@
M("`\/W!H<"!E8VAO(%\H(D=U97-T(%!E<FUI<W-I;VYS(BD@/SX*("`\+W1D
M/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E
M8VAO(%\H(E-H;W<B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L
M:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4F5A9"(I(#\^/"]T9#X*("`\
M=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?
M*")%9&ET(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^/"]T9#X*("`\=&0@
M8VQA<W,](FAE861E<B!R:6=H=$%L:6=N(CXF;F)S<#L\+W1D/@H\+W1R/@H\
M/W!H<"`D9W!E<FT@/2`D<&5R;2T^9V5T1W5E<W1097)M:7-S:6]N<R@I.R`_
M/@H\='(^"B`@/'1D(&-L87-S/2)L:6=H="(^)FYB<W`[/"]T9#X*("`\=&0@
M86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G
M=65S=%]S:&]W(CP_<&AP(&5C:&\@*"1G<&5R;2`F(%!%4DU37U-(3U<I(#\@
M)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L
M:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9W5E
M<W1?<F5A9"(\/W!H<"!E8VAO("@D9W!E<FT@)B!015)-4U]214%$*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=U97-T
M7V5D:70B/#]P:'`@96-H;R`H)&=P97)M("8@4$5235-?141)5"D@/R`G(&-H
M96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX]
M(F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G=65S=%]D
M96QE=&4B/#]P:'`@96-H;R`H)&=P97)M("8@4$5235-?1$5,151%*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H\+W1R/@H*/"$M
M+2!3<&%C97(@+2T^"CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/@H*/"$M+2!#
M<F5A=&]R(%!E<FUI<W-I;VYS("TM/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@
M(#QT9"!C;&%S<STB:&5A9&5R(&QE9G1!;&EG;B(^"B`@("`\/W!H<"!E8VAO
M($AO<F1E.CII;6<H)W5S97(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E
M=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S<#LG("X@7R@B3V)J96-T($-R
M96%T;W(B*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N
M/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4VAO=R(I(#\^/"]T9#X*("`\=&0@
M8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")2
M96%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N
M=&5R(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO=&0^"B`@/'1D(&-L87-S
M/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B1&5L971E
M(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB/CPO
M=&0^"CPO='(^"CP_<&AP("1C<&5R;2`]("1P97)M+3YG971#<F5A=&]R4&5R
M;6ES<VEO;G,H*3L@/SX*/'1R/@H@(#QT9"!C;&%S<STB;&EG:'0B/B9N8G-P
M.SPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB8W)E871O<E]S:&]W(CP_<&AP(&5C:&\@*"1C<&5R;2`F
M(%!%4DU37U-(3U<I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB8W)E871O<E]R96%D(CP_<&AP(&5C:&\@*"1C<&5R;2`F
M(%!%4DU37U)%040I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB8W)E871O<E]E9&ET(CP_<&AP(&5C:&\@*"1C<&5R;2`F
M(%!%4DU37T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB8W)E871O<E]D96QE=&4B/#]P:'`@96-H;R`H)&-P97)M
M("8@4$5235-?1$5,151%*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@
M/SX@+SX\+W1D/@H\+W1R/@H*/"$M+2!3<&%C97(@+2T^"CQT<CX\=&0^)FYB
M<W`[/"]T9#X\+W1R/@H*/"$M+2!5<V5R(%!E<FUI<W-I;VYS("TM/@H\='(@
M=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!C;&%S<STB:&5A9&5R(&QE9G1!;&EG
M;B(^"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)W5S97(N<&YG)RP@)R<L
M("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S
M<#LG("X@7R@B26YD:79I9'5A;"!5<V5R<R(I(#\^"B`@/"]T9#X*("`\=&0@
M8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")3
M:&]W(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N
M=&5R(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D(&-L87-S
M/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B161I="(I
M(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^
M/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H
M96%D97(@<FEG:'1!;&EG;B(^/"]T9#X*/"]T<CX*/#]P:'`@9F]R96%C:"`H
M)'5S97)P97)M<R!A<R`D=7-E<B`]/B`D=7!E<FTI('L@:68@*"1U<V5R("$]
M("1O=VYE<BD@>R`_/@H\='(^"B`@/'1D(&-L87-S/2)L:6=H="(^/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*$%U=&@Z.G)E;6]V94AO;VLH)'5S97(I
M*2`_/CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5?;F%M97-;/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/ETB('9A;'5E/2(\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^(B`O/CPO=&0^"B`@
M/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M
M93TB=5]S:&]W6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@
M/SY=(CP_<&AP(&5C:&\@*"1U<&5R;2`F(%!%4DU37U-(3U<I(#\@)R!C:&5C
M:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C
M96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB=5]R96%D6SP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SY=(CP_<&AP(&5C
M:&\@*"1U<&5R;2`F(%!%4DU37U)%040I(#\@)R!C:&5C:V5D/2)C:&5C:V5D
M(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U
M="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB=5]E9&ET6SP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D=7-E<BD@/SY=(CP_<&AP(&5C:&\@*"1U<&5R;2`F
M(%!%4DU37T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB=5]D96QE=&5;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1U<V5R*2`_/ETB/#]P:'`@96-H;R`H)'5P97)M("8@4$5235-?1$5,
M151%*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H\
M+W1R/@H\/W!H<"!]('T@/SX*/"$M+2!.97<@=7-E<B!R;W<@+2T^"CQT<CX*
M/#]P:'`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RDI.B`_/@H@
M(#QT9"!C;&%S<STB;&EG:'0B/@H@("`@/'-E;&5C="!N86UE/2)U7VYA;65S
M6WQ\;F5W72(^"B`@("`@(#QO<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?
M*")396QE8W0@82!U<V5R('1O(&%D9"(I("X@)SHG(#\^/"]O<'1I;VX^"B`@
M("`\/W!H<"!F;W)E86-H("@D=7-E<DQI<W0@87,@)'5S97(I('L@:68@*"%I
M<W-E="@D=7-E<G!E<FUS6R1U<V5R72DI('L@/SX*("`@("`@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/B(^
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*$%U=&@Z.G)E;6]V94AO;VLH
M)'5S97(I*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@?2!](#\^"B`@("`\+W-E
M;&5C=#X*("`\+W1D/@H\/W!H<"!E;'-E.B`_/@H@(#QT9"!C;&%S<STB;&EG
M:'0B/CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)U7VYA;65S6WQ\;F5W72(@
M+SX\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`\=&0@86QI9VX](F-E;G1E<B(^
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)U7W-H;W=;?'QN97==(B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB=5]R96%D6WQ\;F5W72(@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?961I
M=%M\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T
M('1Y<&4](F-H96-K8F]X(B!N86UE/2)U7V1E;&5T95M\?&YE=UTB("\^/"]T
M9#X*/"]T<CX*"CPA+2T@4W!A8V5R("TM/@H\='(^/'1D/B9N8G-P.SPO=&0^
M/"]T<CX*"CPA+2T@1W)O=7`@4&5R;6ES<VEO;G,@+2T^"CQT<B!V86QI9VX]
M(FUI9&1L92(^"B`@/'1D(&-L87-S/2)H96%D97(@;&5F=$%L:6=N(CX*("`@
M(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G9W)O=7`N<&YG)RP@)R<L("<G+"`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S<#LG("X@
M7R@B1W)O=7!S(BD@/SX*("`\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A
M;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E-H;W<B*2`_/CPO=&0^"B`@
M/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@
M7R@B4F5A9"(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX]
M(F-E;G1E<B(^/#]P:'`@96-H;R!?*")%9&ET(BD@/SX\+W1D/@H@(#QT9"!C
M;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D1E
M;&5T92(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B!R:6=H=$%L:6=N
M(CXF;F)S<#L\+W1D/@H\+W1R/@H\/W!H<"`D9W)O=7!P97)M<R`]("1P97)M
M+3YG971'<F]U<%!E<FUI<W-I;VYS*"D[(&9O<F5A8V@@*"1G<F]U<'!E<FUS
M(&%S("1G<F]U<"`]/B`D9W!E<FTI.B!I9B`H(21G<F]U<',M/F5X:7-T<R@D
M9W)O=7!S+3YG971'<F]U<$YA;64H)&=R;W5P*2DI(&-O;G1I;G5E.R`_/@H\
M='(^"B`@/'1D(&-L87-S/2)L:6=H="(^/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1G<F]U<',M/F=E=$=R;W5P3F%M92@D9W)O=7`I*2`_/CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F=?;F%M97-;/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1G<F]U<"D@/SY=(B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@/SXB("\^/"]T9#X*("`\=&0@86QI
M9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G7W-H
M;W=;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@/SY=(CP_
M<&AP(&5C:&\@*"1G<&5R;2`F(%!%4DU37U-(3U<I(#\@)R!C:&5C:V5D/2)C
M:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B
M/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]R96%D6SP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^72(\/W!H<"!E8VAO("@D
M9W!E<FT@)B!015)-4U]214%$*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@
M)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP
M93TB8VAE8VMB;W@B(&YA;64](F=?961I=%L\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&=R;W5P*2`_/ETB/#]P:'`@96-H;R`H)&=P97)M("8@4$52
M35-?141)5"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T
M9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X
M(B!N86UE/2)G7V1E;&5T95L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&=R;W5P*2`_/ETB/#]P:'`@96-H;R`H)&=P97)M("8@4$5235-?1$5,151%
M*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H\+W1R
M/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\(2TM($YE=R!G<F]U<"!R;W<@+2T^
M"CQT<CX*("`\=&0@8VQA<W,](FQI9VAT(CX*("`@(#QS96QE8W0@;F%M93TB
M9U]N86UE<UM\?&YE=UTB/@H@("`@("`\;W!T:6]N('9A;'5E/2(B/CP_<&AP
M(&5C:&\@7R@B4V5L96-T(&$@9W)O=7`@=&\@861D(BD@+B`G.B<@/SX\+V]P
M=&EO;CX*("`@(#P_<&AP(&9O<F5A8V@@*"1G<F]U<$QI<W0@87,@)&=I9"`]
M/B`D9W)O=7`I('L@:68@*&5M<'1Y*"1G<F]U<'!E<FUS6R1G:61=*2D@>R`_
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&=I9"D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M9W)O=7`I(#\^/"]O<'1I;VX^"B`@("`\/W!H<"!]('T@/SX*("`@(#PO<V5L
M96-T/@H@(#PO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@;F%M93TB9U]S:&]W6WQ\;F5W72(@+SX\+W1D/@H@(#QT
M9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64]
M(F=?<F5A9%M\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G7V5D:71;?'QN97==(B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB9U]D96QE=&5;?'QN97==(B`O/CPO=&0^"CPO='(^"@H\
M='(^"B`\=&0^)FYB<W`[/"]T9#X*/"]T<CX*"CQT<CX*(#QT9"!C;VQS<&%N
M/2(W(CX*("`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V
M86QU93TB/#]P:'`@<')I;G1F*%\H(E-A=F4@)7,B*2P@:'1M;'-P96-I86QC
M:&%R<R@D<VAA<F4M/F=E="@G;F%M92<I*2D@/SXB("\^"CP_<&AP(&EF("A`
M8V]U;G0H)&-H:6QD<F5N*2DZ(#\^"B`@/&EN<'5T('1Y<&4](G-U8FUI="(@
M8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N961I="YA8W1I;VY)
M1"YV86QU92`]("=E9&ET9F]R;6EN:&5R:70G.R(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B07!P;'D@=&\@0VAI;&0@4VAA<F5S(BD@/SXB("\^"CP_<&AP(&5N
M9&EF.R`_/@H@/"]T9#X*/"]T<CX*"CPO=&%B;&4^"CPO9F]R;3X*/&)R("\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R\`````````````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P
M-C0`,#$W-3,P`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R
M969S+VUU;'1I96YU;2YI;F,`````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3`T-P`Q,#4Q-30S,3`V-``P,C(R-#$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`@96-H;R!(;W)D93HZ;&%B
M96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C)UTI(#\^)FYB<W`[/#]P
M:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/'-E;&5C="!I9#TB/#]P:'`@
M96-H;R`D<')E9B`_/B(@;75L=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(\/W!H
M<"!E8VAO(&UI;B@T+"!C;W5N="@D7W!R969S6R1P<F5F75LG96YU;2==*2D@
M/SXB(&YA;64](CP_<&AP(&5C:&\@)'!R968@/SY;72(^"CP_<&AP("1S96QE
M8W1E9"`]($!U;G-E<FEA;&EZ92@D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2D[
M(&9O<F5A8V@@*"1?<')E9G-;)'!R969=6R=E;G5M)UT@87,@)&ME>2`]/B`D
M=F%L*3H@/SX*/&]P=&EO;CP_<&AP(&5C:&\@:6Y?87)R87DH)&ME>2P@)'-E
M;&5C=&5D*2`_("<@<V5L96-T960](G-E;&5C=&5D(B`G(#H@)R<@/SX@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(^/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1V86PI(#\^/"]O<'1I;VX^"CP_
M<&AP(&5N9&9O<F5A8V@@/SX*/"]S96QE8W0^"CQB<B`O/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,`````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,38Q,P`Q,#4Q-30S,3`V-``P,C0P-S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@H\(2TM"F9U;F-T:6]N(')E;6]V92AC871E9V]R
M>2D*>PH@("`@9&]C=6UE;G0N<')E9G,N8T%C=&EO;BYV86QU92`]("=R96UO
M=F4G.PH@("`@9&]C=6UE;G0N<')E9G,N8V%T96=O<GDN=F%L=64@/2!C871E
M9V]R>3L*("`@(&1O8W5M96YT+G!R969S+G-U8FUI="@I.PI]"@IF=6YC=&EO
M;B!A9&0H*0I["B`@("!V87(@8V%T96=O<GD@/2!W:6YD;W<N<')O;7!T*"<\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!C871E9V]R>3HB*2D@/SXG+"`G)RD["B`@("!I9B`H8V%T
M96=O<GD@(3T@;G5L;"`F)B!C871E9V]R>2`A/2`G)RD@>PH@("`@("`@(&1O
M8W5M96YT+G!R969S+F-!8W1I;VXN=F%L=64@/2`G861D)SL*("`@("`@("!D
M;V-U;65N="YP<F5F<RYC871E9V]R>2YV86QU92`](&-A=&5G;W)Y.PH@("`@
M("`@(&1O8W5M96YT+G!R969S+G-U8FUI="@I.PH@("`@?0I]"B\O+2T^"CPO
M<V-R:7!T/@H\:6YP=70@;F%M93TB8T%C=&EO;B(@=F%L=64](B(@='EP93TB
M:&ED9&5N(B`O/@H\:6YP=70@;F%M93TB8V%T96=O<GDB('9A;'5E/2(B('1Y
M<&4](FAI9&1E;B(@+SX*/'1A8FQE/@H@/'1R/@H@(#QT9"!C;VQS<&%N/2(R
M(CX*("`@/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@=F%L
M=64](CP_<&AP(&5C:&\@7R@B3F5W($-A=&5G;W)Y(BD@/SXB(&]N8VQI8VL]
M(F%D9"@I.R(@+SX*("`\+W1D/@H@/"]T<CX*/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<"<["B1C36%N86=E
M<B`]("9N97<@4')E9G-?0V%T96=O<GE-86YA9V5R*"D["B1C871E9V]R:65S
M(#T@)&--86YA9V5R+3YG970H*3L*)&-O;&]R<R`]("1C36%N86=E<BT^8V]L
M;W)S*"D["B1F9V-O;&]R<R`]("1C36%N86=E<BT^9F=#;VQO<G,H*3L*)'5R
M;"`]($AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R
M9&4G*2`N("<O<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<"<I.PHD
M=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=F;W)M)RP@)W!R969S
M)RD["@HO+R!$969A=6QT($-O;&]R"B1C;VQO<B`](&ES<V5T*"1C;VQO<G-;
M)U]D969A=6QT7R==*2`_("1C;VQO<G-;)U]D969A=6QT7R==(#H@)R-&1D9&
M1D8G.PHD9F=C;VQO<B`](&ES<V5T*"1F9V-O;&]R<ULG7V1E9F%U;'1?)UTI
M(#\@)&9G8V]L;W)S6R=?9&5F875L=%\G72`Z("<C,#`P,#`P)SL*)&-?=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=T87)G970G+"`G8V]L;W)?
M)R`N(&)A<V4V-%]E;F-O9&4H)U]D969A=6QT7R<I*3L*/SX*(#QT<CX*("`\
M=&0@<W1Y;&4](F)A8VMG<F]U;F0Z/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1C;VQO<BD@/SX[(&-O;&]R.CP_<&AP(&5C:&\@)&9G8V]L;W(@/SXB
M/CQS=')O;F<^/#]P:'`@96-H;R!?*")$969A=6QT($-O;&]R(BD@/SX\+W-T
M<F]N9SX\+W1D/@H@(#QT9#X*("`@/#]P:'`@:68@*"$D<')E9G,M/FES3&]C
M:V5D*"=C871E9V]R>5]C;VQO<G,G*2DZ(#\^"B`@("`\:6YP=70@8VQA<W,]
M(F9I>&5D(B!S:7IE/2(W(B!S='EL93TB8F%C:V=R;W5N9#H\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&-O;&]R*2`_/CL@8V]L;W(Z/#]P:'`@96-H
M;R`D9F=C;VQO<B`_/B(@;F%M93TB8V]L;W)?/#]P:'`@96-H;R!B87-E-C1?
M96YC;V1E*"=?9&5F875L=%\G*2`_/B(@=F%L=64](CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^(B`O/@H@("`@/&$@:')E9CTB/#]P
M:'`@96-H;R`D8U]U<FP@/SXB(&]N8VQI8VL](G=I;F1O=RYO<&5N*"<\/W!H
M<"!E8VAO("1C7W5R;"`_/B<L("=C;VQO<G!I8VME<B<L("=T;V]L8F%R/6YO
M+&QO8V%T:6]N/6YO+'-T871U<SUN;RQS8W)O;&QB87)S/6YO+')E<VEZ86)L
M93UN;RQW:61T:#TQ,C`L:&5I9VAT/3(U,"QL969T/3$P,"QT;W`],3`P)RD[
M(')E='5R;B!F86QS93LB(&]N;6]U<V5O=70](G=I;F1O=RYS=&%T=7,])R<[
M(B!O;FUO=7-E;W9E<CTB=VEN9&]W+G-T871U<STG/#]P:'`@96-H;R!?*")#
M;VQO<B!0:6-K97(B*2`_/B<[(')E='5R;B!T<G5E.R(@8VQA<W,](G=I9&=E
M="(@=&%R9V5T/2)C;VQO<G!I8VME<B(^"B`@("`\/W!H<"!E8VAO($AO<F1E
M.CII;6<H)V-O;&]R<&EC:V5R+G!N9R<L(%\H(D-O;&]R(%!I8VME<B(I+"`G
M:&5I9VAT/2(Q-B(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2`_/CPO83X*("`@/#]P:'`@96YD:68[(#\^"B`@/"]T9#X*(#PO='(^"CP_
M<&AP"B\O(%5N9FEL960@0V]L;W(*)&-O;&]R(#T@:7-S970H)&-O;&]R<ULG
M7W5N9FEL961?)UTI(#\@)&-O;&]R<ULG7W5N9FEL961?)UT@.B`G(T9&1D9&
M1B<["B1F9V-O;&]R(#T@:7-S970H)&9G8V]L;W)S6R=?=6YF:6QE9%\G72D@
M/R`D9F=C;VQO<G-;)U]U;F9I;&5D7R==(#H@)R,P,#`P,#`G.PHD8U]U<FP@
M/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W1A<F=E="<L("=C;VQO<E\G
M("X@8F%S938T7V5N8V]D92@G7W5N9FEL961?)RDI.PH_/@H@/'1R/@H@(#QT
M9"!S='EL93TB8F%C:V=R;W5N9#H\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&-O;&]R*2`_/CL@8V]L;W(Z/#]P:'`@96-H;R`D9F=C;VQO<B`_/B(^
M/'-T<F]N9SX\/W!H<"!E8VAO(%\H(E5N9FEL960B*2`_/CPO<W1R;VYG/CPO
M=&0^"B`@/'1D/@H@("`\/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)V-A
M=&5G;W)Y7V-O;&]R<R<I*3H@/SX*("`@(#QI;G!U="!C;&%S<STB9FEX960B
M('-I>F4](C<B('-T>6QE/2)B86-K9W)O=6YD.CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D8V]L;W(I(#\^.R!C;VQO<CH\/W!H<"!E8VAO("1F9V-O
M;&]R(#\^(B!N86UE/2)C;VQO<E\\/W!H<"!E8VAO(&)A<V4V-%]E;F-O9&4H
M)U]U;F9I;&5D7R<I(#\^(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1C;VQO<BD@/SXB("\^"B`@("`\82!H<F5F/2(\/W!H<"!E8VAO
M("1C7W5R;"`_/B(@;VYC;&EC:STB=VEN9&]W+F]P96XH)SP_<&AP(&5C:&\@
M)&-?=7)L(#\^)RP@)V-O;&]R<&EC:V5R)RP@)W1O;VQB87(];F\L;&]C871I
M;VX];F\L<W1A='5S/6YO+'-C<F]L;&)A<G,];F\L<F5S:7IA8FQE/6YO+'=I
M9'1H/3$R,"QH96EG:'0],C4P+&QE9G0],3`P+'1O<#TQ,#`G*3L@<F5T=7)N
M(&9A;'-E.R(@;VYM;W5S96]U=#TB=VEN9&]W+G-T871U<STG)SLB(&]N;6]U
M<V5O=F5R/2)W:6YD;W<N<W1A='5S/2<\/W!H<"!E8VAO(%\H(D-O;&]R(%!I
M8VME<B(I(#\^)SL@<F5T=7)N('1R=64[(B!C;&%S<STB=VED9V5T(B!T87)G
M970](F-O;&]R<&EC:V5R(CX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G
M8V]L;W)P:6-K97(N<&YG)RP@7R@B0V]L;W(@4&EC:V5R(BDL("=H96EG:'0]
M(C$V(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A
M/@H@("`\/W!H<"!E;F1I9CL@/SX*("`\+W1D/@H@/"]T<CX*/#]P:'`*9F]R
M96%C:"`H)&-A=&5G;W)I97,@87,@)&YA;64I.@H@("`@)&-O;&]R(#T@:7-S
M970H)&-O;&]R<ULD;F%M95TI(#\@)&-O;&]R<ULD;F%M95T@.B`G(T9&1D9&
M1B<["B`@("`D9F=C;VQO<B`](&ES<V5T*"1F9V-O;&]R<ULD;F%M95TI(#\@
M)&9G8V]L;W)S6R1N86UE72`Z("<C,#`P,#`P)SL*("`@("1C7W5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G=&%R9V5T)RP@)V-O;&]R7R<@+B!B
M87-E-C1?96YC;V1E*"1N86UE*2D["C\^"B`\='(^"B`@/'1D('-T>6QE/2)B
M86-K9W)O=6YD.CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I
M(#\^.R!C;VQO<CH\/W!H<"!E8VAO("1F9V-O;&]R(#\^(CX\<W1R;VYG/CP_
M<&AP(&5C:&\@*"1N86UE(#T]("=?9&5F875L=%\G(#\@7R@B1&5F875L="!#
M;VQO<B(I(#H@:'1M;'-P96-I86QC:&%R<R@D;F%M92DI(#\^/"]S=')O;F<^
M/"]T9#X*("`\=&0^"B`@(#P_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G
M8V%T96=O<GE?8V]L;W)S)RDI.B`_/@H@("`@/&EN<'5T(&-L87-S/2)F:7AE
M9"(@<VEZ93TB-R(@<W1Y;&4](F)A8VMG<F]U;F0Z/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1C;VQO<BD@/SX[(&-O;&]R.CP_<&AP(&5C:&\@)&9G
M8V]L;W(@/SXB(&YA;64](F-O;&]R7SP_<&AP(&5C:&\@8F%S938T7V5N8V]D
M92@D;F%M92D@/SXB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&-O;&]R*2`_/B(@+SX*("`@(#QA(&AR968](CP_<&AP(&5C:&\@)&-?
M=7)L(#\^(B!O;F-L:6-K/2)W:6YD;W<N;W!E;B@G/#]P:'`@96-H;R`D8U]U
M<FP@/SXG+"`G8V]L;W)P:6-K97(G+"`G=&]O;&)A<CUN;RQL;V-A=&EO;CUN
M;RQS=&%T=7,];F\L<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4];F\L=VED=&@]
M,3(P+&AE:6=H=#TR-3`L;&5F=#TQ,#`L=&]P/3$P,"<I.R!R971U<FX@9F%L
M<V4[(B!O;FUO=7-E;W5T/2)W:6YD;W<N<W1A='5S/2<G.R(@;VYM;W5S96]V
M97(](G=I;F1O=RYS=&%T=7,])SP_<&AP(&5C:&\@7R@B0V]L;W(@4&EC:V5R
M(BD@/SXG.R!R971U<FX@=')U93LB(&-L87-S/2)W:61G970B('1A<F=E=#TB
M8V]L;W)P:6-K97(B/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=C;VQO
M<G!I8VME<BYP;F<G+"!?*")#;VQO<B!0:6-K97(B*2P@)VAE:6=H=#TB,38B
M)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\+V$^"B`@
M("`\/W!H<"!E;F1I9CL@/SX*("`@(#QA(&AR968](B,B(&]N8VQI8VL](G)E
M;6]V92AD96-O9&554DE#;VUP;VYE;G0H)SP_<&AP(&5C:&\@<F%W=7)L96YC
M;V1E*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&YA;64L($Y,4SHZ9V5T0VAA
M<G-E="@I+"`G551&+3@G*2D@/SXG*2D[(')E='5R;B!F86QS93LB/CP_<&AP
M(&5C:&\@2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<I(#\^/"]A/@H@(#PO=&0^
M"B`\+W1R/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]P<F5F<R]P87-S=V]R9"YI;F,`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`T,S``,3`U,34T,S$P-C0`,#(R,#4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP(&5C
M:&\@2&]R9&4Z.FQA8F5L*"1P<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==
M*2`_/B9N8G-P.SP_<&AP(&5C:&\@)&AE;'!L:6YK(#\^/&)R("\^"CQI;G!U
M="!T>7!E/2)P87-S=V]R9"(@:60](CP_<&AP(&5C:&\@)'!R968@/SXB(&YA
M;64](CP_<&AP(&5C:&\@)'!R968@/SXB('-I>F4](C,P(B!M87AL96YG=&@]
M(C8P(B!C;&%S<STB9FEX960B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'!R969S+3YG971686QU92@D<')E9BDI(#\^(B`O/CQB<B`O
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M<')E9G,O96YD+FEN8P``````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P-S,Q`#$P-3$U-#,Q,#8T`#`R,#<V-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\+V1I=CX*"CQB<B!C;&%S<STB
M<W!A8V5R(B`O/@H\9&EV(&-L87-S/2)N;W=R87`B/@H@/&EN<'5T('1Y<&4]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M4V%V92!/<'1I;VYS(BD@/SXB("\^)FYB<W`["B`\:6YP=70@='EP93TB<F5S
M970B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E5N9&\@
M0VAA;F=E<R(I(#\^(B`O/B9N8G-P.PH@/#]P:'`@:68@*&-O=6YT*"1P<F5F
M1W)O=7!S*2`^(#$I.B`_/CQI;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B
M=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E='5R;B!T;R!/<'1I;VYS
M(BD@/SXB(&]N8VQI8VL](F1O8W5M96YT+G!R969S+F%C=&EO;DE$+G9A;'5E
M/3`[(&1O8W5M96YT+G!R969S+F=R;W5P+G9A;'5E/2<G.R!D;V-U;65N="YP
M<F5F<RYS=6)M:70H*3LB("\^/#]P:'`@96YD:68[(#\^"CPO9&EV/@H\+V9O
M<FT^"@```````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V]V97)V
M:65W+FEN8P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,34Q-@`Q
M,#4Q-30S,3`V-``P,C(P-S$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/&1I=B!C;&%S<STB<')E9G-/=F5R=FEE=R(^"CP_
M<&AP(&9O<F5A8V@@*"1C;VQU;6YS(&%S("1K97D@/3X@)&-O;'5M;BDZ(#\^
M"B`\9&EV('-T>6QE/2)W:61T:#H\/W!H<"!E8VAO("1S<&%N("T@,2`_/B4B
M/@H@(#QD:78^"B`@(#QH,CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&ME>2D@/SX\+V@R/@H*("`@/&1L/@H@("`\/W!H<"!F;W)E86-H("@D8V]L
M=6UN(&%S("1G<F]U<"`]/B`D9W9A;',I.B`_/@H@("`@/#]P:'`@:68@*%!R
M969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2DZ(#\^"B`@("`@/#]P
M:'`@:68@*"%E;7!T>2@D9W9A;'-;)W5R;"==*2DZ(#\^"B`@("`@(#QD=#X\
M/W!H<"!E8VAO($AO<F1E.CIW:61G970H2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"1G=F%L<ULG=7)L)UTL("1A<'`I+"`D9W9A;'-;)VQA8F5L)UTL("<G+"`G
M)RP@)R<L("1G=F%L<ULG;&%B96PG72D@/SX\+V1T/@H@("`@(#P_<&AP(&5L
M<V4Z(#\^"B`@("`@(#QD=#X\/W!H<"!E8VAO($AO<F1E.CIW:61G970H571I
M;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*"DL(&%R<F%Y*"=G<F]U
M<"<@/3X@)&=R;W5P+"`G87!P)R`]/B`D1TQ/0D%,4ULG87!P)UTI*2P@)&=V
M86QS6R=L86)E;"==+"`G)RP@)R<L("<G+"`D9W9A;'-;)VQA8F5L)UTI(#\^
M/"]D=#X*("`@("`\/W!H<"!E;F1I9CL@/SX*("`@("`\9&0^/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1G=F%L<ULG9&5S8R==*2`_/CPO9&0^"B`@
M("`\/W!H<"!E;F1I9CL@/SX*("`@/#]P:'`@96YD9F]R96%C:#L@/SX*("`@
M/"]D;#X*("`\+V1I=CX*(#PO9&EV/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\
M+V1I=CX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S
M+W-E;&5C="YI;F,`````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3(P,``Q,#4Q-30S,3`V-``P,C$T-S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH
M)'!R968L("1?<')E9G-;)'!R969=6R=D97-C)UTI(#\^)FYB<W`[/#]P:'`@
M96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/'-E;&5C="!I9#TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F*2`_/B(@;F%M93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F*2`_/B(^"CP_<&AP("1E<V,@/2`A
M96UP='DH)%]P<F5F<ULD<')E9EU;)V5S8V%P960G72D[("1C=7)V86P@/2`D
M<')E9G,M/F=E=%9A;'5E*"1P<F5F*3L@)'-E;&5C=%]V87(@/2!5=&EL.CIN
M;VY);G!U=%9A<B@D<')E9B`N("=?;W!T:6]N<R<I.R!F;W)E86-H("@D<V5L
M96-T7W9A<B!A<R`D<V5L96-T7VME>2`]/B`D<V5L96-T7W9A;"DZ(#\^"B`\
M;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1E<V,@/R`D<V5L96-T7VME>2`Z
M(&AT;6QS<&5C:6%L8VAA<G,H)'-E;&5C=%]K97DI(#\^(CP_<&AP(&EF("@D
M<V5L96-T7VME>2`]/2`D8W5R=F%L*2!E8VAO("<@<V5L96-T960](G-E;&5C
M=&5D(B<@/SX^/#]P:'`@96-H;R`D97-C(#\@)'-E;&5C=%]V86P@.B!H=&UL
M<W!E8VEA;&-H87)S*"1S96QE8W1?=F%L*2`_/CPO;W!T:6]N/@H\/W!H<"!E
M;F1F;W)E86-H.R`_/@H\+W-E;&5C=#X*/&)R("\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+W!R969S+W1E>'0N:6YC````````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#0Q,``Q,#4Q-30S,3`V-``P,C$Q-S<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`@96-H;R!(;W)D93HZ
M;&%B96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C)UTI(#\^)FYB<W`[
M/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/&EN<'5T(&ED/2(\/W!H
M<"!E8VAO("1P<F5F(#\^(B!N86UE/2(\/W!H<"!E8VAO("1P<F5F(#\^(B!S
M:7IE/2(S,"(@;6%X;&5N9W1H/2(V,"(@8VQA<W,](F9I>&5D(B!V86QU93TB
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F<RT^9V5T5F%L=64H
M)'!R968I*2`_/B(@+SX\8G(@+SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]N=6UB
M97(N:6YC````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-S8`
M,3`U,34T,S$P-C0`,#(Q-3$V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QI;G!U="!T>7!E/2)T97AT(B!I9#TB/#]P:'`@
M96-H;R`D<')E9B`_/B(@;F%M93TB/#]P:'`@96-H;R`D<')E9B`_/B(@<VEZ
M93TB,R(@;6%X;&5N9W1H/2(S(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1P<F5F<RT^9V5T5F%L=64H)'!R968I*2`_/B(@+SX*/#]P
M:'`@96-H;R!(;W)D93HZ;&%B96PH)'!R968L("1?<')E9G-;)'!R969=6R=D
M97-C)UTI(#\^)FYB<W`[/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC`````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,3,S`#$P-3$U-#,Q,#8T
M`#`R,S(S,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)V1E9F%U;'1?:61E
M;G1I='DG*2DZ(#\^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M/"$M+0IF=6YC=&EO;B!D96QE=&5)9&5N=&ET>2@I"GL*("`@('9A<B!I;F1E
M>"`](&1O8W5M96YT+G!R969S+FED96YT:71Y+G-E;&5C=&5D26YD97@["B`@
M("!V87(@:60@/2!D;V-U;65N="YP<F5F<RYI9&5N=&ET>2YO<'1I;VYS6VEN
M9&5X72YV86QU93L*("`@(&EF("AI9"`^/2`P*2!["B`@("`@("`@9&]C=6UE
M;G0N;&]C871I;VXN:')E9B`]("(\/W!H<"!E8VAO('-T<E]R97!L86-E*"<F
M86UP.R<L("<F)RP@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS96QF57)L
M*'1R=64I+"!A<G)A>2@G86-T:6]N240G(#T^("=D96QE=&5?:61E;G1I='DG
M+"`G:60G(#T^("<G*2DI(#\^(B`K(&ED.PH@("`@?0I]"B\O+2T^"CPO<V-R
M:7!T/@H\8G(@+SX*/&EN<'5T('1Y<&4](F)U='1O;B(@;VYC;&EC:STB9&5L
M971E261E;G1I='DH*2(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(BD@/SXB("\^/&)R("\^
M/&)R("\^"CP_<&AP(&5N9&EF.R`_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O=&5X=&%R96$N
M:6YC````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#4T`#$P-3$U
M-#,Q,#8T`#`R,C`T,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E9BP@)%]P
M<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO("1H96QP
M;&EN:R`_/CQB<B`O/@H\9&EV(&-L87-S/2)F:7AE9"(^"CQT97AT87)E82!W
M<F%P/2)H87)D(B!I9#TB/#]P:'`@96-H;R`D<')E9B`_/B(@;F%M93TB/#]P
M:'`@96-H;R`D<')E9B`_/B(@<F]W<STB-B(@8V]L<STB.#`B(&-L87-S/2)F
M:7AE9"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F<RT^9V5T
M5F%L=64H)'!R968I*2`_/CPO=&5X=&%R96$^/&)R("\^"CPO9&EV/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V-H96-K8F]X+FEN8P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,W-@`Q,#4Q-30S,3`V-``P,C(P
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C;&%S<STB8VAE8VMB;W@B(&ED/2(\
M/W!H<"!E8VAO("1P<F5F(#\^(B!N86UE/2(\/W!H<"!E8VAO("1P<F5F(#\^
M(CP_<&AP(&5C:&\@)'!R969S+3YG971686QU92@D<')E9BD@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G(#\^("\^"CP_<&AP(&5C:&\@2&]R9&4Z.FQA
M8F5L*"1P<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_
M<&AP(&5C:&\@)&AE;'!L:6YK(#\^"CQB<B`O/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]P<F5F<R]E;G5M+FEN8P``````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$P-#4`,3`U,34T,S$P-C0`,#(Q,38T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP(&5C:&\@
M2&]R9&4Z.FQA8F5L*"1P<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==*2`_
M/B9N8G-P.SP_<&AP(&5C:&\@)&AE;'!L:6YK(#\^/&)R("\^"CQS96QE8W0@
M:60](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9BD@/SXB(&YA
M;64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9BD@/SXB/@H\
M/W!H<"`D97-C(#T@(65M<'1Y*"1?<')E9G-;)'!R969=6R=E<V-A<&5D)UTI
M.R`D8W5R=F%L(#T@)'!R969S+3YG971686QU92@D<')E9BD[(&9O<F5A8V@@
M*"1?<')E9G-;)'!R969=6R=E;G5M)UT@87,@)&ME>2`]/B`D=F%L*3H@/SX*
M/&]P=&EO;CP_<&AP(&5C:&\@)&-U<G9A;"`]/2`D:V5Y(#\@)R!S96QE8W1E
M9#TB<V5L96-T960B)R`Z("<G(#\^('9A;'5E/2(\/W!H<"!E8VAO("1E<V,@
M/R`D:V5Y(#H@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(^/#]P:'`@96-H
M;R`D97-C(#\@)'9A;"`Z(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P
M=&EO;CX*/#]P:'`@96YD9F]R96%C:"`_/@H\+W-E;&5C=#X*/&)R("\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]P<F5F<R]B96=I;BYI;F,`````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`W-S<`,3`U,34T,S$P-C0`,#(Q,S$W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QF;W)M
M(&UE=&AO9#TB<&]S="(@;F%M93TB<')E9G,B(&%C=&EO;CTB/#]P:'`@96-H
M;R!(;W)D93HZ<V5L9E5R;"@I(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U
M="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V
M86QU93TB=7!D871E7W!R969S(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)G<F]U<"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D9W)O=7`I(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A
M<'`B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&%P<"D@
M/SXB("\^"@H\9&EV(&-L87-S/2)H96%D97(B/@H@/#]P:'`@4')E9G-?54DZ
M.F=E;F5R871E3F%V:6=A=&EO;D-E;&PH)&=R;W5P*2`_/@H@/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F1W)O=7!S6R1G<F]U<%U;)VQA8F5L
M)UTI(#\^"B`\8G(@8VQA<W,](F-L96%R(B`O/@H\+V1I=CX*"CQD:78@8VQA
M<W,](FET96TB/@H`+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O<')E9G,O87!P+FEN8P``````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,3,U`#$P-3$U-#,Q,#8T`#`R,3`P,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\9F]R;2!M971H;V0](F=E
M="(@;F%M93TB87!P<W=I=&-H(B!A8W1I;VX](CP_<&AP(&5C:&\@)')E9VES
M=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O<')E
M9G,N<&AP)R`_/B(^"CP_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*
M/&1I=B!C;&%S<STB:&5A9&5R(CX*(#QS<&%N(&-L87-S/2)S;6%L;&AE861E
M<B!R:6=H=$9L;V%T(CX*("`\/W!H<"!E8VAO(%\H(D5D:70@;W!T:6]N<R!F
M;W(Z(BD@/SX*("`\<V5L96-T(&YA;64](F%P<"(@;VYC:&%N9V4](F1O8W5M
M96YT+F%P<'-W:71C:"YS=6)M:70H*3LB/@H@("`@/&]P=&EO;B!V86QU93TB
M(CX\/W!H<"!E8VAO(%\H(D-H;V]S92!!<'!L:6-A=&EO;CHB*2`_/CPO;W!T
M:6]N/@H\/W!H<"!I9B`H(65M<'1Y*"1A<'!S6R=H;W)D92==*2DZ(#\^"B`@
M("`\;W!T:6]N('9A;'5E/2(B/BTM+2T\+V]P=&EO;CX*("`@(#QO<'1I;VX@
M=F%L=64](FAO<F1E(CX\/W!H<"!E8VAO(%\H(D=L;V)A;"!/<'1I;VYS(BD@
M/SX\+V]P=&EO;CX*("`@(#QO<'1I;VX@=F%L=64](B(^+2TM+3PO;W!T:6]N
M/@H\/W!H<"!E;F1I9CL@/SX*("`@/#]P:'`@9F]R96%C:"`H)&%P<',@87,@
M)&ME>2`]/B`D=F%L*3H@:68@*"1K97D@/3T@)VAO<F1E)RD@8V]N=&EN=64[
M(#\^"B`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M=F%L*2`_/CPO;W!T:6]N/@H@("`\/W!H<"!E;F1F;W)E86-H.R`_/@H@(#PO
M<V5L96-T/@H@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)S=6)M:70B
M(&]N8VQI8VL](G)E='5R;B!D;V-U;65N="YA<'!S=VET8V@N87!P+G-E;&5C
M=&5D26YD97@@(3T@,#LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D=O(BD@/SXB
M("\^"B`\+W-P86X^"B`\/W!H<"!I9B`H)')E9VES=')Y+3YG971!<'`H*2`]
M/2`G:&]R9&4G*2!E8VAO(%\H(D=L;V)A;"!/<'1I;VYS(BD[(&5L<V4@<')I
M;G1F*%\H(D]P=&EO;G,@9F]R("5S(BDL("1R96=I<W1R>2T^9V5T*"=N86UE
M)RDI(#\^"B`\8G(@8VQA<W,](F-L96%R(B`O/@H\+V1I=CX*/"]F;W)M/@H\
M8G(@8VQA<W,](G-P86-E<B(@+SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]L:6YK+FEN8P``````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,C,`,3`U,34T,S$P
M-C0`,#(Q,34U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#QA(&AR968](CP_<&AP(&5C:&\@*&ES<V5T*"1?<')E9G-;)'!R
M969=6R=U<FPG72DI(#\*2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1?<')E9G-;
M)'!R969=6R=U<FPG72D@.B`D7W!R969S6R1P<F5F75LG>'5R;"=="C\^(CX\
M/W!H<"!I9B`H:7-S970H)%]P<F5F<ULD<')E9EU;)VEM9R==*2D@96-H;PI(
M;W)D93HZ:6UG*"1?<')E9G-;)'!R969=6R=I;6<G72P@)%]P<F5F<ULD<')E
M9EU;)V1E<V,G72P@)VAS<&%C93TB,R(G*0H_/CQS=')O;F<^/#]P:'`@96-H
M;R`D7W!R969S6R1P<F5F75LG9&5S8R==(#\^/"]S=')O;F<^/"]A/B9N8G-P
M.SP_<&AP(&5C:&\*)&AE;'!L:6YK(#\^/&)R("\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S,R`#$P-3$U-#,Q,#8T`#`R,S(V,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<"!I9B`H)'!R969S+3YI<TQO8VME9"@G9&5F875L=%]I9&5N=&ET>2<I*3H@
M/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:61E;G1I='DB('9A;'5E
M/2(\/W!H<"!E8VAO("AI;G0I)$=,3T)!3%-;)VED96YT:71Y)UTM/F=E=$1E
M9F%U;'0H*2`_/B(@+SX*/#]P:'`@96QS93H@/SX*/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IV87(@:61E;G1I=&EE<R`](&YE=R!!
M<G)A>2@I.PH\/W!H<`IG;&]B86P@)&ED96YT:71Y.PHD:61E;G1I=&EE<R`]
M("1I9&5N=&ET>2T^9V5T06QL*"=I9"<I.PHD9&5F875L=%]I9&5N=&ET>2`]
M("1I9&5N=&ET>2T^9V5T1&5F875L="@I.PHD;65M8F5R<R`]("1P<F5F1W)O
M=7!S6R=I9&5N=&ET:65S)UU;)VUE;6)E<G,G73L*9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)&ED96YT:71I97,I.R`K*R1I*3H*/SX*:61E;G1I=&EE<UL\
M/W!H<"!E8VAO("1I(#\^72`](&YE=R!!<G)A>2@I.PH\/W!H<`HD:R`](#`[
M"F9O<F5A8V@@*"1M96UB97)S(&%S("1M96UB97(I.@H@("`@:68@*"1M96UB
M97(@/3T@)V1E9F%U;'1?:61E;G1I='DG('Q\"B`@("`@("`@(65M<'1Y*"1?
M<')E9G-;)&UE;6)E<EU;)VQO8VME9"==*2!\?`H@("`@("`@("1?<')E9G-;
M)&UE;6)E<EU;)W1Y<&4G72`]/2`G<W!E8VEA;"<@?'P*("`@("`@("`D7W!R
M969S6R1M96UB97)=6R=T>7!E)UT@/3T@)VQI;FLG*2!["B`@("`@("`@8V]N
M=&EN=64["B`@("!]"C\^"FED96YT:71I97-;/#]P:'`@96-H;R`D:2`_/EU;
M/#]P:'`@96-H;R`D:RLK(#\^72`](&YE=R!!<G)A>2@B/#]P:'`@96-H;R`D
M;65M8F5R(#\^(BP@(CP_<&AP(&5C:&\@)%]P<F5F<ULD;65M8F5R75LG='EP
M92==(#\^(BP@/#]P:'`*)'9A;"`]("1I9&5N=&ET>2T^9V5T5F%L=64H)&UE
M;6)E<BP@)&DI.PIS=VET8V@@*"1?<')E9G-;)&UE;6)E<EU;)W1Y<&4G72D@
M>PIC87-E("=C:&5C:V)O>"<Z"B`@("!E8VAO("1V86P@/R`G=')U92<@.B`G
M9F%L<V4G.PH@("`@8G)E86L["@IC87-E("=N=6UB97(G.@H@("`@96-H;R`H
M:6YT*21V86P["B`@("!B<F5A:SL*"F-A<V4@)W1E>'1A<F5A)SH*("`@(&EF
M("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("1V86P@/2!I;7!L;V1E*")<
M;B(L("1V86PI.PH@("`@?0H@("`@)'9A;"`](%-T<FEN9SHZ8V]N=F5R=$-H
M87)S970H)'9A;"P@3DQ3.CIG971#:&%R<V5T*"DL("=55$8M."<I.PH@("`@
M96-H;R`G9&5C;V1E55))0V]M<&]N96YT*"(G("X@<F%W=7)L96YC;V1E*"1V
M86PI("X@)R(I)SL*("`@(&)R96%K.PH*9&5F875L=#H*("`@("1V86P@/2!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86PL($Y,4SHZ9V5T0VAA<G-E="@I
M+"`G551&+3@G*3L*("`@(&5C:&\@)V1E8V]D955224-O;7!O;F5N="@B)R`N
M(')A=W5R;&5N8V]D92@D=F%L*2`N("<B*2<["GT*/SXI.PH\/W!H<"!E;F1F
M;W)E86-H.R!E;F1F;W([(#\^"@IF=6YC=&EO;B!N97=#:&]I8V4H*0I["B`@
M("!V87(@9FEE;&0L('9A;#L*("`@('9A<B!I;F1E>"`](&1O8W5M96YT+G!R
M969S+FED96YT:71Y+G-E;&5C=&5D26YD97@["B`@("!V87(@:60@/2!D;V-U
M;65N="YP<F5F<RYI9&5N=&ET>2YO<'1I;VYS6VEN9&5X72YV86QU93L*("`@
M(&EF("AI9"`\(#`I('L*("`@("`@("!D;V-U;65N="YP<F5F<RYR97-E="@I
M.PH@("`@("`@(&1O8W5M96YT+G!R969S+FED96YT:71Y+G-E;&5C=&5D26YD
M97@@/2!I;F1E>#L*("`@("`@("!R971U<FX["B`@("!]"B`@("!F;W(@*'9A
M<B!I(#T@,#L@:2`\(&ED96YT:71I97-;:61=+FQE;F=T:#L@:2LK*2!["B`@
M("`@("`@9FEE;&0@/2!D;V-U;65N="YP<F5F<UMI9&5N=&ET:65S6VED75MI
M75LP75T["B`@("`@("`@=F%L(#T@:61E;G1I=&EE<UMI9%U;:5U;,ET["B`@
M("`@("`@<W=I=&-H("AI9&5N=&ET:65S6VED75MI75LQ72D@>PH@("`@("`@
M(&-A<V4@(F5N=6TB.@H@("`@("`@("`@("!F;W(@*'9A<B!J(#T@,#L@:B`\
M(&9I96QD+F]P=&EO;G,N;&5N9W1H.R!J*RLI('L*("`@("`@("`@("`@("`@
M(&EF("AF:65L9"YO<'1I;VYS6VI=+G9A;'5E(#T]('9A;"D@>PH@("`@("`@
M("`@("`@("`@("`@(&9I96QD+G-E;&5C=&5D26YD97@@/2!J.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(")C:&5C
M:V)O>"(Z"B`@("`@("`@("`@(&9I96QD+F-H96-K960@/2!V86P["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(")I;7!L:6-I="(Z"B`@("`@
M("`@("`@(&5V86PH(FYE=T-H;VEC95\B("L@:61E;G1I=&EE<UMI9%U;:5U;
M,%T@*R`B*'9A;"DB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@(&9I96QD+G9A;'5E(#T@=F%L.PH@("`@("`@
M('T*("`@('T*?0H*+R\M+3X*/"]S8W)I<'0^"CQB<B`O/@H\/W!H<"!E8VAO
M($AO<F1E.CIL86)E;"@G:61E;G1I='DG+"!?*")396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93HB*2D@/SX\8G(@+SX*/'-E;&5C="!N
M86UE/2)I9&5N=&ET>2(@:60](FED96YT:71Y(B!O;F-H86YG93TB:F%V87-C
M<FEP=#IN97=#:&]I8V4H*2(^"B`@/&]P=&EO;B!V86QU93TB+3(B('-E;&5C
M=&5D/2)S96QE8W1E9"(*/CP_<&AP(&5C:&\@7R@B3F]N92(I(#\^/"]O<'1I
M;VX^"B`@/&]P=&EO;B!V86QU93TB+3$B/CP_<&AP(&5C:&\@7R@B0W)E871E
M(&$@;F5W(&]N92(I(#\^/"]O<'1I;VX^"CP_<&AP(&9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1I9&5N=&ET:65S*3L@)&DK*RDZ(#\^"B`@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R`D:2`_/B(\/W!H<"!I9B`H)&D@/3T@)&1E9F%U
M;'1?:61E;G1I='DI(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ED96YT:71I97-;)&E=*2`_
M/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W([(#\^"CPO<V5L96-T/CQB<B`O/@H\
M/W!H<"!E;F1I9CL@/SX*````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]D
M871A+P``````````````````````````````````````````````````````
M````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S$P-C0`,#$W,S(R`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8P``````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C8U,``Q,#4Q-30S,3`V-``P,C$S,#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"F9U;F-T:6]N(')E
M<V5T2&ED9&5N*"D*>PH@("`@=F%R(&9O<FT@/2!D;V-U;65N="YM87!F;W)M
M.PH@("`@=F%R('1M<"`]("<G.PH@("`@9F]R("AI(#T@,#L@:2`\(&9O<FTN
M<V5L96-T1&%T82YL96YG=&@[(&DK*RD@>PH@("`@("`@('1M<"`K/2!F;W)M
M+G-E;&5C=$1A=&%;:5TN=F%L=64["B`@("`@("`@:68@*&D@/"!F;W)M+G-E
M;&5C=$1A=&$N;&5N9W1H("T@,2D*("`@("`@("`@("`@=&UP("L](")<="([
M"B`@("!]"B`@("!F;W)M+F1A=&%+97ES+G9A;'5E(#T@=&UP.PH@("`@=&UP
M(#T@)R<["B`@("!F;W(@*&D@/2`P.R!I(#P@9F]R;2YS96QE8W1!<'`N;&5N
M9W1H.R!I*RLI('L*("`@("`@("!T;7`@*ST@9F]R;2YS96QE8W1!<'!;:5TN
M=F%L=64["B`@("`@("`@:68@*&D@/"!F;W)M+G-E;&5C=$%P<"YL96YG=&@@
M+2`Q*0H@("`@("`@("`@("!T;7`@*ST@(EQT(CL*("`@('T*("`@(&9O<FTN
M87!P2V5Y<RYV86QU92`]('1M<#L*?0H*9G5N8W1I;VX@861D4&%I<B@I"GL*
M("`@('9A<B!F;W)M(#T@9&]C=6UE;G0N;6%P9F]R;3L*("`@(&EF("AF;W)M
M+G-E;&5C=#$N<V5L96-T961);F1E>"`^/2`P("8F(&9O<FTN<V5L96-T,BYS
M96QE8W1E9$EN9&5X(#X](#`I('L*("`@("`@("!F;W)M+G-E;&5C=$1A=&%;
M9F]R;2YS96QE8W1$871A+FQE;F=T:%T@/2!N97<@3W!T:6]N*&9O<FTN<V5L
M96-T,5MF;W)M+G-E;&5C=#$N<V5L96-T961);F1E>%TN=&5X="P@9F]R;2YS
M96QE8W0Q6V9O<FTN<V5L96-T,2YS96QE8W1E9$EN9&5X72YV86QU92D["B`@
M("`@("`@9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!<'`N;&5N9W1H72`]
M(&YE=R!/<'1I;VXH9F]R;2YS96QE8W0R6V9O<FTN<V5L96-T,BYS96QE8W1E
M9$EN9&5X72YT97AT+"!F;W)M+G-E;&5C=#);9F]R;2YS96QE8W0R+G-E;&5C
M=&5D26YD97A=+G9A;'5E*3L*("`@("`@("!F;W)M+G-E;&5C=#%;9F]R;2YS
M96QE8W0Q+G-E;&5C=&5D26YD97A=(#T@;G5L;#L*("`@("`@("!F;W)M+G-E
M;&5C=#);9F]R;2YS96QE8W0R+G-E;&5C=&5D26YD97A=(#T@;G5L;#L*("`@
M('T*("`@(')E<V5T2&ED9&5N*"D["GT*"F9U;F-T:6]N(')E;6]V95!A:7(H
M*0I["B`@("!V87(@9F]R;2`](&1O8W5M96YT+FUA<&9O<FT["B`@("!I9B`H
M9F]R;2YS96QE8W1$871A+G-E;&5C=&5D26YD97@@/CT@,"!\?"!F;W)M+G-E
M;&5C=$%P<"YS96QE8W1E9$EN9&5X(#X](#`I('L*("`@("`@("!F;W)M+G-E
M;&5C=#%;9F]R;2YS96QE8W0Q+FQE;F=T:%T@/2!N97<@3W!T:6]N*&9O<FTN
M<V5L96-T1&%T85MF;W)M+G-E;&5C=$1A=&$N<V5L96-T961);F1E>%TN=&5X
M="P@9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T82YS96QE8W1E9$EN
M9&5X72YV86QU92D["B`@("`@("`@9F]R;2YS96QE8W0R6V9O<FTN<V5L96-T
M,BYL96YG=&A=(#T@;F5W($]P=&EO;BAF;W)M+G-E;&5C=$%P<%MF;W)M+G-E
M;&5C=$%P<"YS96QE8W1E9$EN9&5X72YT97AT+"!F;W)M+G-E;&5C=$%P<%MF
M;W)M+G-E;&5C=$%P<"YS96QE8W1E9$EN9&5X72YV86QU92D["B`@("`@("`@
M9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T82YS96QE8W1E9$EN9&5X
M72`](&YU;&P["B`@("`@("`@9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!
M<'`N<V5L96-T961);F1E>%T@/2!N=6QL.PH@("`@?0H@("`@<F5S971(:61D
M96XH*3L*?0HO+RTM/@H\+W-C<FEP=#X*"CQF;W)M(&UE=&AO9#TB<&]S="(@
M;F%M93TB;6%P9F]R;2(@86-T:6]N/2)D871A+G!H<"(^"CP_<&AP(&5C:&\@
M571I;#HZ9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB86-T:6]N240B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&YE>'1?<W1E
M<"`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T7V9O
M<FUA="(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL
M.CIG971&;W)M1&%T82@G:6UP;W)T7V9O<FUA="<I*2`_/B(@+SX*/&EN<'5T
M('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T7W-T97`B('9A;'5E/2(\/W!H
M<"!E8VAO("AI;G0I)&EM<&]R=%]S=&5P(#\^(B`O/@H\:#$@8VQA<W,](FAE
M861E<B(^"B`\/W!H<"!P<FEN=&8H7R@B26UP;W)T+"!3=&5P("5D(BDL("AI
M;G0I)&EM<&]R=%]S=&5P*2`_/@H\+V@Q/@H\<"!C;&%S<STB8V]N=')O;"(^
M"B`\/W!H<"!E8VAO(%\H(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(I
M(#\^"CPO<#X*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^
M"B`\='(^"B`@/'1D(&-L87-S/2)I=&5M(CX*("`\=&%B;&4^/'1R/CQT9#X*
M("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(^/'1R/@H@("`@("`\=&0^"B`@
M("`@("`@/#]P:'`@96-H;R!?*"));7!O<G1E9"!F:65L9',Z(BD@/SX\8G(@
M+SX*("`@("`@("`\<V5L96-T(&YA;64](G-E;&5C=#$B('-I>F4](C$P(CX*
M/#]P:'`@9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A
M)UU;,%T@87,@)&ME>2`]/B`D=F%L=64I.@H@("`@("!I9B`H(6ES<V5T*"1A
M<'!?9FEE;&1S6R1K97E=*2DZ(#\^"B`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP
M(&5C:&\@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTI(#\@
M:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`Z(&AT;6QS<&5C:6%L8VAA<G,H)'9A
M;'5E*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1I9CL*("`@("`@96YD9F]R96%C
M:#L@/SX*("`@("`@("`\+W-E;&5C=#X*("`@("`@/"]T9#X*("`@("`@/'1D
M/@H@("`@("`@(#P_<&AP(&5C:&\@7R@B079A:6QA8FQE(&9I96QD<SHB*2`_
M/CQB<B`O/@H@("`@("`@(#QS96QE8W0@;F%M93TB<V5L96-T,B(@<VEZ93TB
M,3`B/@H\/W!H<"!F;W)E86-H("@D87!P7V9I96QD<R!A<R`D:V5Y(#T^("1V
M86QU92DZ"B`@("`@(&EF("@A:7-S970H)%]315-324].6R=I;7!O<G1?9&%T
M82==6R=D871A)UU;,%U;)&ME>5TI*3H@/SX*("`@("`@/#]P:'`@:68@*"@D
M:V5Y(#T]("=A;&%R;5]T:6UE)RD@?'P@*"1K97D@/3T@)V%L87)M7V1A=&4G
M*2DZ(#\^"B`@("`@("`@("`@(#P_<&AP(&EF("@A:7-S970H)%]315-324].
M6R=I;7!O<G1?9&%T82==6R=D871A)UU;,%U;)V%L87)M)UTI*3H@/SX*("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'9A;'5E*2`_/CPO;W!T:6]N/@H@("`@("`@("`@("`\/W!H<"!E;F1I9CL@
M/SX*("`@("`@/#]P:'`@96QS96EF("@D:V5Y(#T]("=A;&%R;2<I.B`_/@H@
M("`@("`@("`@("`\/W!H<"!I9B`H(2AI<W-E="@D7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)V1A=&$G75LP75LG86QA<FU?=&EM92==*2`F)B!I<W-E="@D
M7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G75LP75LG86QA<FU?9&%T
M92==*2DI.B`_/@H@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D=F%L=64I(#\^/"]O<'1I;VX^"B`@("`@("`@("`@
M(#P_<&AP(&5N9&EF.R`_/@H@("`@("`\/W!H<"!E;'-E.B`_/@H@("`@("`\
M;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME
M>2D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=F%L=64I(#\^
M/"]O<'1I;VX^"B`@("`@(#P_<&AP(&5N9&EF.R`_/@H\/W!H<"!E;F1I9CL*
M("`@("`@96YD9F]R96%C:#L@/SX*("`@("`@("`\+W-E;&5C=#X*("`@("`@
M/"]T9#X*("`@(#PO='(^/"]T86)L93X*("`@(#QI;G!U="!T>7!E/2)B=71T
M;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%D9"!P86ER(BD@/SXB(&-L87-S
M/2)B=71T;VXB(&]N8VQI8VL](F%D9%!A:7(H*2(@+SX*("`\+W1D/CPO='(^
M/"]T86)L93X*("`\+W1D"CPO='(^"CQT<CX*("`\=&0^"B`@("`\=&%B;&4@
M8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@(#QT<CX\=&0@8VQA
M<W,](FET96TB/B9N8G-P.SPO=&0^/"]T<CX*("`@(#QT<CX\=&0@8VQA<W,]
M(G-M86QL:&5A9&5R(CX\/W!H<"!E8VAO(%\H(DUA=&-H:6YG(&9I96QD<R(I
M(#\^/"]T9#X\+W1R/@H@("`@/"]T86)L93X*("`\+W1D/@H\+W1R/@H\='(^
M"B`@/'1D(&-L87-S/2)I=&5M(CX*("`\=&%B;&4^/'1R/CQT9#X*("`@(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F1A=&%+97ES(B`O/@H@("`@/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB87!P2V5Y<R(@+SX*("`@(#QI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A;'5E/2)C
M<W8B("\^"B`@("`\<V5L96-T(&YA;64](G-E;&5C=$1A=&$B('-I>F4](C$P
M(B!O;F-H86YG93TB9&]C=6UE;G0N;6%P9F]R;2YS96QE8W1!<'!;=&AI<RYS
M96QE8W1E9$EN9&5X72YS96QE8W1E9#UT<G5E(CX*/#]P:'`*9F]R96%C:"`H
M)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;,%T@87,@)&ME>2`]
M/B`D=F%L=64I.@H@("`@:68@*&ES<V5T*"1A<'!?9FEE;&1S6R1K97E=*2DZ
M"B`@("`@("`@)&UA=&-H:6YG6UT@/2!A<G)A>2@D:V5Y+"`D87!P7V9I96QD
M<ULD:V5Y72D["C\^"B`@("`@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C:&\@*"1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTI(#\@:'1M;'-P96-I
M86QC:&%R<R@D:V5Y*2`Z(&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*2`_/CPO
M;W!T:6]N/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96YD9F]R96%C:#L@/SX*
M("`@(#PO<V5L96-T/@H@("`@/'-E;&5C="!N86UE/2)S96QE8W1!<'`B('-I
M>F4](C$P(B!O;F-H86YG93TB9&]C=6UE;G0N;6%P9F]R;2YS96QE8W1$871A
M6W1H:7,N<V5L96-T961);F1E>%TN<V5L96-T960]=')U92(^"CP_<&AP(&9O
M<F5A8V@@*"1M871C:&EN9R!A<R`D<&%I<BDZ(#\^"B`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!A:7);
M,%TI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!A:7);,5TI
M(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`\+W-E;&5C
M=#X\8G(@+SX*("`@(#QI;G!U="!T>7!E/2)B=71T;VXB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(E)E;6]V92!P86ER(BD@/SXB(&-L87-S/2)B=71T;VXB(&]N
M8VQI8VL](G)E;6]V95!A:7(H*2(@+SX\8G(@+SX\8G(@+SX*("`@(#QI;G!U
M="!T>7!E/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(DYE>'0B*2`_
M/B(@8VQA<W,](F)U='1O;B(@+SX*("`\+W1D/CPO='(^/"]T86)L93X*("`\
M+W1D/@H\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"CQS8W)I<'0@='EP93TB=&5X
M="]J879A<V-R:7!T(CX*/"$M+0IR97-E=$AI9&1E;B@I.PHO+RTM/@H\+W-C
M<FEP=#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,`````````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,38P,0`Q,#4Q-30S,3`V-``P,C$U,#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE
M/2)I;7!O<G1?9F]R;2(@86-T:6]N/2)D871A+G!H<"(^"CP_<&AP(%5T:6PZ
M.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A
M8W1I;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD;F5X=%]S=&5P(#\^
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?9F]R;6%T
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F=E
M=$9O<FU$871A*"=I;7!O<G1?9F]R;6%T)RDI(#\^(B`O/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?<W1E<"(@=F%L=64](CP_<&AP(&5C
M:&\@*&EN="DD:6UP;W)T7W-T97`@/SXB("\^"CQH,2!C;&%S<STB:&5A9&5R
M(CX*(#P_<&AP('!R:6YT9BA?*"));7!O<G0L(%-T97`@)60B*2P@*&EN="DD
M:6UP;W)T7W-T97`I(#\^"CPO:#$^"CQD:78@8VQA<W,](FAE861E<F)O>"(^
M"B`\/W!H<"!E8VAO(%\H(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB*2`_/CQB<B`O/@H@/'!R93X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:7)S=%]L:6YE<R==
M*2`_/CPO<')E/CQB<B`O/@H@/&QA8F5L(&9O<CTB:&5A9&5R(CX\/W!H<"!E
M8VAO(%\H(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB*2`_/CPO;&%B96P^"B`\
M:6YP=70@:60](FAE861E<B(@='EP93TB8VAE8VMB;W@B(&YA;64](FAE861E
M<B(@=F%L=64](C$B("\^/&)R("\^"CPO9&EV/@H\:6YP=70@='EP93TB<W5B
M;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*").97AT(BD@/SXB(&-L87-S/2)B
M=71T;VXB("\^"CPO9F]R;3X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,`````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C<P,@`Q,#4Q-30S,3`V-``P,C$T,C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&9O<FT@;65T:&]D/2)P;W-T
M(B!N86UE/2)D871E9F]R;2(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G9&%T82YP:'`G*2`_/B(^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB/#]P:'`@96-H;R`H:6YT
M*21N97AT7W-T97`@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(FEM<&]R=%]F;W)M870B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)VEM<&]R=%]F;W)M870G*2D@/SXB
M("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]S=&5P(B!V
M86QU93TB/#]P:'`@96-H;R`H:6YT*21I;7!O<G1?<W1E<"`_/B(@+SX*/#]P
M:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQH,2!C;&%S<STB:&5A9&5R(CX*
M(#P_<&AP('!R:6YT9BA?*"));7!O<G0L(%-T97`@)60B*2P@*&EN="DD:6UP
M;W)T7W-T97`I(#\^"CPO:#$^"CQT86)L92!C96QL<W!A8VEN9STB,"(@=VED
M=&@](C$P,"4B/@H\/W!H<"!F;W)E86-H("@D7U-%4U-)3TY;)VEM<&]R=%]D
M871A)UU;)V1A=&5S)UT@87,@)&ME>2`]/B`D9&%T92DZ(#\^"CP_<&AP(&EF
M("AC;W5N="@D9&%T95LG=F%L=65S)UTI*3H@/SX*/'1R/@H@("`@/'1D/@H@
M("`@("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B/@H@
M("`@("`@(#QT<CX\=&0@8VQA<W,](FET96TB/B9N8G-P.SPO=&0^/"]T<CX*
M("`@("`@("`\='(^/'1D(&-L87-S/2)S;6%L;&AE861E<B(^/#]P:'`@<')I
M;G1F*%\H(DEM<&]R=&5D(&9I96QD.B`E<R(I+"!H=&UL<W!E8VEA;&-H87)S
M*"1A<'!?9FEE;&1S6R1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P)UU;
M)&ME>5U=*2D@/SX\+W1D/CPO='(^"B`@("`@("`@/"]T86)L93X*("`@(#PO
M=&0^"CPO='(^"CQT<CX*("`@(#QT9"!C;&%S<STB:71E;2(^"B`@("`\=&%B
M;&4^"B`@("`\='(^"B`@("`@("`@/'1D/CP_<&AP(&5C:&\@7R@B17AA;7!L
M92!V86QU97,Z(BD@/SX\+W1D/@H@("`@("`@(#QT9#X*("`@("`@("`@("`@
M/'-E;&5C=#X*/#]P:'`@9F]R96%C:"`H)&1A=&5;)W9A;'5E<R==(&%S("1V
M86PI.B`_/@H@("`@("`@("`@("`@("`@/&]P=&EO;CX\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R
M96%C:#L@/SX*("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@("`@/"]T9#X*
M("`@(#PO='(^"CP_<&AP(&EN8VQU9&4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+R<@+B!B87-E;F%M92@D9&%T95LG='EP92==*2`N("<N:6YC)R`_/@H@("`@
M/"]T86)L93X*("`@(#PO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H\/W!H
M<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H*/&EN<'5T('1Y<&4](G-U8FUI
M="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B3F5X="(I
M(#\^(B`O/@H\+V9O<FT^"@``````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]D871E+FEN8P``````````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,#$W`#$P-3$U-#,Q,#8T
M`#`R,#<S,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HD:2`](#`["G=H:6QE("@D:2`\(&-O=6YT*"1D871E6R=V
M86QU97,G72D@)B8@96UP='DH)&1A=&5;)W9A;'5E<R==6R1I72DI('L*("`@
M("1I*RL["GT*:68@*'-T<G!O<R@D9&%T95LG=F%L=65S)UU;)&E=+"`G+R<I
M("$]/2!F86QS92D@>PH@("`@)&1E;"`]("<O)SL*?2!E;'-E:68@*'-T<G!O
M<R@D9&%T95LG=F%L=65S)UU;)&E=+"`G+B<I("$]/2!F86QS92D@>PH@("`@
M)&1E;"`]("<N)SL*?2!E;'-E:68@*'-T<G!O<R@D9&%T95LG=F%L=65S)UU;
M)&E=+"`G+2<I("$]/2!F86QS92D@>PH@("`@)&1E;"`]("<M)SL*?2!E;'-E
M('L*("`@("1D96P@/2`G)SL*?0H*+R\@5')Y('1O(&=U97-S('1H92!D871E
M(&9O<FUA="!A<R!M=6-H(&%S('!O<W-I8FQE"B1F;W)M(#T@;G5L;#L*:68@
M*"%E;7!T>2@D9&5L*2`F)B!I<W-E="@D9&%T95LG=F%L=65S)UTI("8F(&ES
M<V5T*"1D871E6R=V86QU97,G75LD:5TI*2!["B`@("`D<&%R=',@/2!E>'!L
M;V1E*"1D96PL("1D871E6R=V86QU97,G75LD:5TI.PH@("`@:68@*&-O=6YT
M*"1P87)T<RD@/CT@,RD@>PH@("`@("`@("1F;W)M(#T@)VUD>2<["B`@("`@
M("`@:68@*"AS=')L96XH)'!A<G1S6S!=*2`]/2`T*2!\?"`H)'!A<G1S6S!=
M(#X@,S$I*2!["B`@("`@("`@("`@("1F;W)M(#T@)WEM9"<["B`@("`@("`@
M("`@(&EF("@D<&%R='-;,5T@/B`Q,BD@>PH@("`@("`@("`@("`@("`@)&9O
M<FT@/2`G>61M)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D
M<&%R='-;,%T@/B`Q,BD@>PH@("`@("`@("`@("`D9F]R;2`]("=D;7DG.PH@
M("`@("`@('T*("`@('T*?0H_/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@7R@B
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB*2`_/CPO=&0^"B`@/'1D/@H@
M("`@/'-E;&5C="!N86UE/2)D96QI;6ET97);/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@=F%L=64](B\B
M/#]P:'`@96-H;R`D9&5L(#T]("<O)R`_("<@<V5L96-T960](G-E;&5C=&5D
M(B<@.B`G)R`_/CXO/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](BXB
M/#]P:'`@96-H;R`D9&5L(#T]("<N)R`_("<@<V5L96-T960](G-E;&5C=&5D
M(B<@.B`G)R`_/CXN/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](BTB
M/#]P:'`@96-H;R`D9&5L(#T]("<M)R`_("<@<V5L96-T960](G-E;&5C=&5D
M(B<@.B`G)R`_/CXM/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\
M+W1R/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@7R@B4V5L96-T('1H92!D871E
M(&9O<FUA=#HB*2`_/CPO=&0^"B`@/'1D/@H@("`@/'-E;&5C="!N86UE/2)F
M;W)M871;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^
M"B`@("`@(#QO<'1I;VX@=F%L=64](FUD87DO;6]N=&@O>65A<B(\/W!H<"!E
M8VAO("1F;W)M(#T]("=D;7DG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z
M("<G(#\^/CP_<&AP(&5C:&\@7R@B1$0B*2`N("1D96P@+B!?*")-32(I("X@
M)&1E;"`N(%\H(EE9(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU
M93TB;6]N=&@O;61A>2]Y96%R(CP_<&AP(&5C:&\@)&9O<FT@/3T@)VUD>2<@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?
M*")-32(I("X@)&1E;"`N(%\H(D1$(BD@+B`D9&5L("X@7R@B65DB*2`_/CPO
M;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)Y96%R+VUO;G1H+VUD87DB
M/#]P:'`@96-H;R`D9F]R;2`]/2`G>6UD)R`_("<@<V5L96-T960](G-E;&5C
M=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(EE9(BD@+B`D9&5L("X@7R@B
M34TB*2`N("1D96P@+B!?*")$1"(I(#\^/"]O<'1I;VX^"B`@("`@(#QO<'1I
M;VX@=F%L=64](GEE87(O;61A>2]M;VYT:"(\/W!H<"!E8VAO("1F;W)M(#T]
M("=Y9&TG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP
M(&5C:&\@7R@B65DB*2`N("1D96P@+B!?*")$1"(I("X@)&1E;"`N(%\H(DU-
M(BD@/SX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]T:6UE
M+FEN8P``````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3,W
M`#$P-3$U-#,Q,#8T`#`R,#<U,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HD:2`](#`["G=H:6QE("@D:2`\/2!C
M;W5N="@D9&%T95LG=F%L=65S)UTI("8F(&5M<'1Y*"1D871E6R=V86QU97,G
M75LD:5TI*2!["B`@("`D:2LK.PI]"FEF("AS=')P;W,H)&1A=&5;)W9A;'5E
M<R==6R1I72P@)SHG*2`A/3T@9F%L<V4I('L*("`@("1D96P@/2`G.B<["GT@
M96QS96EF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)RXG*2`A/3T@
M9F%L<V4I('L*("`@("1D96P@/2`G+B<["GT@96QS92!["B`@("`D9&5L(#T@
M)R<["GT*)&%M<&T@/2`H<W1R<&]S*%-T<FEN9SHZ;&]W97(H)&1A=&5;)W9A
M;'5E<R==6S!=*2P@)V%M)RD@(3T](&9A;'-E('Q\('-T<G!O<RA3=')I;F<Z
M.FQO=V5R*"1D871E6R=V86QU97,G75LP72DL("=P;2<I("$]/2!F86QS92D[
M"C\^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!?*")396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.B(I(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&YA;64]
M(F1E;&EM:71E<EL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@
M/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB.B(\/W!H<"!E8VAO("1D96P@
M/3T@)SHG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CH\+V]P
M=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB+B(\/W!H<"!E8VAO("1D96P@
M/3T@)RXG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/BX\+V]P
M=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CQT<CX*("`\=&0^
M/#]P:'`@96-H;R!?*")396QE8W0@=&AE('1I;64@9F]R;6%T.B(I(#\^/"]T
M9#X*("`\=&0^"B`@("`\<V5L96-T(&YA;64](F9O<FUA=%L\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V
M86QU93TB,C1H<B(\/W!H<"!E8VAO("1A;7!M(#\@)R<@.B`G('-E;&5C=&5D
M/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C:&\@7R@B,C0@:&]U<G,B*2`_/CPO
M;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)A;7!M(CP_<&AP(&5C:&\@
M)&%M<&T@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@
M96-H;R!?*")!32]032(I(#\^/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\
M+W1D/@H\+W1R/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,P-#,`,3`U,34T,S$P-C0`,#(Q-#8Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QF;W)M
M(&UE=&AO9#TB<&]S="(@;F%M93TB:6UP;W)T7V9O<FTB(&%C=&EO;CTB9&%T
M82YP:'`B/@H\/W!H<"!E8VAO(%5T:6PZ.F9O<FU);G!U="@I(#\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB/#]P:'`@
M96-H;R`H:6YT*21N97AT7W-T97`@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A;'5E/2)C<W8B("\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]S=&5P(B!V86QU93TB/#]P
M:'`@96-H;R`H:6YT*21I;7!O<G1?<W1E<"`_/B(@+SX*/&@Q(&-L87-S/2)H
M96%D97(B/@H@/#]P:'`@<')I;G1F*%\H(DEM<&]R="P@4W1E<"`E9"(I+"`H
M:6YT*21I;7!O<G1?<W1E<"D@/SX*/"]H,3X*/&1I=B!C;&%S<STB:&5A9&5R
M8F]X('1E>'0B/@H@("`@/#]P:'`@96-H;R!?*")(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z(BD@/SX\8G(@+SX*("`@(#QP<F4^/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G
M75LG9FER<W1?;&EN97,G72D@/SX\+W!R93X\8G(@+SX*("`@(#QL86)E;"!F
M;W(](FAE861E<B(^/#]P:'`@96-H;R!?*")$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z(BD@/SX\+VQA8F5L/@H@("`@/&EN<'5T(&ED/2)H96%D97(B('1Y<&4]
M(F-H96-K8F]X(B!N86UE/2)H96%D97(B('9A;'5E/2(Q(B!C:&5C:V5D/2)C
M:&5C:V5D(B`O/CQB<B`O/@H@("`@/#]P:'`@96-H;R!?*")7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/R(I(#\^"B`@("`\:6YP=70@='EP93TB
M=&5X="(@;F%M93TB<V5P(B!S:7IE/2(Q(B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG<V5P
M)UTI(#\^(B`O/CQB<B`O/@H@("`@/#]P:'`@:68@*&ES<V5T*"1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG<75O=&4G72DI.B`_/@H@("`@/#]P:'`@96-H
M;R!?*")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(BD@/SX*("`@(#QI
M;G!U="!T>7!E/2)T97AT(B!N86UE/2)Q=6]T92(@<VEZ93TB,2(@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)W%U;W1E)UTI(#\^(B`O/CQB<B`O/@H@("`@/#]P:'`@96YD
M:68[(#\^"B`@("`\/W!H<"!I9B`H:7-S970H)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=F:65L9',G72DI.B`_/@H@("`@/#]P:'`@96-H;R!?*")(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B*2`_/@H@("`@/&EN
M<'5T('1Y<&4](G1E>'0B(&YA;64](F9I96QD<R(@<VEZ93TB,B(@=F%L=64]
M(CP_<&AP(&5C:&\@*&EN="DD7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I
M96QD<R==(#\^(B`O/CQB<B`O/@H@("`@/#]P:'`@96YD:68[(#\^"CPO9&EV
M/@H\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*").
M97AT(BD@/SXB(&-L87-S/2)B=71T;VXB("\^"CPO9F]R;3X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O9&%T82]D871E=&EM92YI;F,`````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$R,3,V`#$P-3$U-#,Q,#8T`#`R,38Q,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HD:2`]
M(#`["G=H:6QE("@D:2`\(&-O=6YT*"1D871E6R=V86QU97,G72D@)B8@96UP
M='DH)&1A=&5;)W9A;'5E<R==6R1I72DI('L*("`@("1I*RL["GT*)&1A>5]D
M96P@/2`D=&EM95]D96P@/2`G)SL*:68@*'-T<G!O<R@D9&%T95LG=F%L=65S
M)UU;)&E=+"`G("<I("$]/2!F86QS92D@>PH@("`@9F]R("@D;W)D97(@/2`P
M.R`H96UP='DH)'1I;65?9&5L*2!\?"!E;7!T>2@D9&%Y7V1E;"DI("8F("1O
M<F1E<B`\/2`Q.R`D;W)D97(K*RD@>PH@("`@("`@(&EF("@D;W)D97(I('L*
M("`@("`@("`@("`@;&ES="@D=&EM92P@)&1A>2D@/2!E>'!L;V1E*"<@)RP@
M)&1A=&5;)W9A;'5E<R==6R1I72P@,BD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@;&ES="@D9&%Y+"`D=&EM92D@/2!E>'!L;V1E*"<@)RP@)&1A
M=&5;)W9A;'5E<R==6R1I72P@,BD["B`@("`@("`@?0H@("`@("`@(&EF("AS
M=')P;W,H)&1A>2P@)R\G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)&1A
M>5]D96P@/2`G+R<["B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D9&%Y+"`G
M+B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D9&%Y7V1E;"`]("<N)SL*
M("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1D87DL("<M)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("1D87E?9&5L(#T@)RTG.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1D87E?9&5L(#T@)R<["B`@("`@("`@?0H@("`@
M("`@(&EF("AS=')P;W,H)'1I;64L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1T:6UE7V1E;"`]("<Z)SL*("`@("`@("!](&5L<V5I9B`H<W1R
M<&]S*"1T:6UE+"`G+B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&EM
M95]D96P@/2`G+B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1I
M;65?9&5L(#T@)R<["B`@("`@("`@?0H@("`@?0H@("`@)&]R9&5R+2T["GT*
M"B\O(%1R>2!T;R!G=65S<R!T:&4@9&%T92!F;W)M870@87,@;75C:"!A<R!P
M;W-S:6)L90HD9F]R;2`](&YU;&P["FEF("@A96UP='DH)&1A>5]D96PI("8F
M(&ES<V5T*"1D871E6R=V86QU97,G72D@)B8@:7-S970H)&1A=&5;)W9A;'5E
M<R==6R1I72DI('L*("`@("1P87)T<R`](&5X<&QO9&4H)&1A>5]D96PL("1D
M871E6R=V86QU97,G75LD:5TI.PH@("`@:68@*&-O=6YT*"1P87)T<RD@/CT@
M,RD@>PH@("`@("`@("1F;W)M(#T@)VUD>2<["B`@("`@("`@:68@*"AS=')L
M96XH)'!A<G1S6S!=*2`]/2`T*2!\?"`H)'!A<G1S6S!=(#X@,S$I*2!["B`@
M("`@("`@("`@("1F;W)M(#T@)WEM9"<["B`@("`@("`@("`@(&EF("@D<&%R
M='-;,5T@/B`Q,BD@>PH@("`@("`@("`@("`@("`@)&9O<FT@/2`G>61M)SL*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D<&%R='-;,%T@/B`Q
M,BD@>PH@("`@("`@("`@("`D9F]R;2`]("=D;7DG.PH@("`@("`@('T*("`@
M('T*?0HD86UP;2`]("AS=')P;W,H4W1R:6YG.CIL;W=E<B@D9&%T95LG=F%L
M=65S)UU;,%TI+"`G86TG*2`A/3T@9F%L<V4@?'P@<W1R<&]S*%-T<FEN9SHZ
M;&]W97(H)&1A=&5;)W9A;'5E<R==6S!=*2P@)W!M)RD@(3T](&9A;'-E*3L*
M"FEF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)R`G*2`]/3T@9F%L
M<V4I.@H_/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=O
M<F1E<E\G("X@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2P@7R@B4V5L96-T('1H
M92!D871E(&%N9"!T:6UE(&9O<FUA=#HB*2D@/SX\+W1D/@H@(#QT9#X*("`@
M(#QS96QE8W0@:60](F]R9&5R7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D:V5Y*2`_/B(@;F%M93TB;W)D97);/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@=F%L=64](BTQ(B!S
M96QE8W1E9#TB<V5L96-T960B/CP_<&AP(&5C:&\@7R@B5&EM97-T86UP(&]R
M('5N:VYO=VXB*2`_/CPO;W!T:6]N/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*
M/"]T<CX*/#]P:'`@96QS93H@/SX*/'1R/@H@(#QT9#X\/W!H<"!E8VAO($AO
M<F1E.CIL86)E;"@G;W)D97)?)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL
M(%\H(E-E;&5C="!T:&4@9&%Y(&%N9"!T:6UE(&]R9&5R.B(I*2`_/CPO=&0^
M"B`@/'1D/@H@("`@/'-E;&5C="!I9#TB;W)D97)?/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1K97DI(#\^(B!N86UE/2)O<F1E<EL\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V
M86QU93TB+3$B/#]P:'`@96-H;R`H)&]R9&5R("8F("AE;7!T>2@D9&%Y7V1E
M;"D@?'P@96UP='DH)'1I;65?9&5L*2DI(#\@)R!S96QE8W1E9#TB<V5L96-T
M960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B5&EM97-T86UP(&]R('5N:VYO
M=VXB*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(P(CP_<&AP
M(&5C:&\@*"$D;W)D97(I(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G
M(#\^/CP_<&AP('!R:6YT9BA?*")$871E.B`E<SL@=&EM93H@)7,B*2P@)&1A
M>2P@)'1I;64I(#\^/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](C$B
M/#]P:'`@96-H;R`D;W)D97(@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@
M)R<@/SX^/#]P:'`@<')I;G1F*%\H(D1A=&4Z("5S.R!T:6UE.B`E<R(I+"`D
M9&%Y+"`D=&EM92D@/SX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^
M"CPO='(^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V1A
M>5]D96QI;6ET97)?)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL(%\H(E-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(BDI(#\^/"]T9#X*("`\=&0^"B`@
M("`\<V5L96-T(&ED/2)D87E?9&5L:6UI=&5R7SP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D:V5Y*2`_/B(@;F%M93TB9&%Y7V1E;&EM:71E<EL\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P
M=&EO;B!V86QU93TB+R(\/W!H<"!E8VAO("1D87E?9&5L(#T]("<O)R`_("<@
M<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CXO/"]O<'1I;VX^"B`@("`@
M(#QO<'1I;VX@=F%L=64](BXB/#]P:'`@96-H;R`D9&%Y7V1E;"`]/2`G+B<@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+CPO;W!T:6]N/@H@
M("`@("`\;W!T:6]N('9A;'5E/2(M(CP_<&AP(&5C:&\@)&1A>5]D96P@/3T@
M)RTG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/BT\+V]P=&EO
M;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CQT<CX*("`\=&0^/#]P
M:'`@96-H;R!(;W)D93HZ;&%B96PH)V1A>5]F;W)M871?)R`N(&AT;6QS<&5C
M:6%L8VAA<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(BDI
M(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&ED/2)D87E?9F]R;6%T7SP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(@;F%M93TB9&%Y
M7V9O<FUA=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=
M(CX*("`@("`@/&]P=&EO;B!V86QU93TB;61A>2]M;VYT:"]Y96%R(CP_<&AP
M(&5C:&\@)&9O<FT@/3T@)V1M>2<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G
M(#H@)R<@/SX^/#]P:'`@96-H;R!?*")$1"(I("X@)&1A>5]D96P@+B!?*")-
M32(I("X@)&1A>5]D96P@+B!?*")962(I(#\^/"]O<'1I;VX^"B`@("`@(#QO
M<'1I;VX@=F%L=64](FUO;G1H+VUD87DO>65A<B(\/W!H<"!E8VAO("1F;W)M
M(#T]("=M9'DG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_
M<&AP(&5C:&\@7R@B34TB*2`N("1D87E?9&5L("X@7R@B1$0B*2`N("1D87E?
M9&5L("X@7R@B65DB*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E
M/2)Y96%R+VUO;G1H+VUD87DB/#]P:'`@96-H;R`D9F]R;2`]/2`G>6UD)R`_
M("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H
M(EE9(BD@+B`D9&%Y7V1E;"`N(%\H(DU-(BD@+B`D9&%Y7V1E;"`N(%\H(D1$
M(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB>65A<B]M9&%Y
M+VUO;G1H(CP_<&AP(&5C:&\@)&9O<FT@/3T@)WED;2<@/R`G('-E;&5C=&5D
M/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?*")962(I("X@)&1A
M>5]D96P@+B!?*")$1"(I("X@)&1A>5]D96P@+B!?*")-32(I(#\^/"]O<'1I
M;VX^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H\='(^"B`@/'1D/CP_
M<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=T:6UE7V1E;&EM:71E<E\G("X@:'1M
M;'-P96-I86QC:&%R<R@D:V5Y*2P@7R@B4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CHB*2D@/SX\+W1D/@H@(#QT9#X*("`@(#QS96QE8W0@:60](G1I;65?
M9&5L:6UI=&5R7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_
M/B(@;F%M93TB=&EM95]D96QI;6ET97);/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@=F%L=64](CHB/#]P
M:'`@96-H;R`D=&EM95]D96P@/3T@)SHG(#\@)R!S96QE8W1E9#TB<V5L96-T
M960B)R`Z("<G(#\^/CH\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB
M+B(\/W!H<"!E8VAO("1T:6UE7V1E;"`]/2`G+B<@/R`G('-E;&5C=&5D/2)S
M96QE8W1E9"(G(#H@)R<@/SX^+CPO;W!T:6]N/@H@("`@/"]S96QE8W0^"B`@
M/"]T9#X*/"]T<CX*/'1R/@H@(#QT9#X\/W!H<"!E8VAO($AO<F1E.CIL86)E
M;"@G=&EM95]F;W)M871?)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL(%\H
M(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(BDI(#\^/"]T9#X*("`\=&0^"B`@
M("`\<V5L96-T(&ED/2)T:6UE7V9O<FUA=%\\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&ME>2D@/SXB(&YA;64](G1I;65?9F]R;6%T6SP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB/@H@("`@("`\;W!T:6]N
M('9A;'5E/2(R-&AR(CP_<&AP(&5C:&\@)&%M<&T@/R`G)R`Z("<@<V5L96-T
M960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!?*"(R-"!H;W5R<R(I(#\^
M/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](F%M<&TB/#]P:'`@96-H
M;R`D86UP;2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H
M<"!E8VAO(%\H(D%-+U!-(BD@/SX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@
M(#PO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O8V]N=&5N=',O````
M````````````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#8T`#`R,#(T-@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]C;VYT96YT<R]O<&5N7W9I97=?=VEN+FIS````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$Q-#8`,3`U,34T,S$P-C0`,#(S-#4S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(CX*/"$M+0H*9G5N8W1I;VX@='(H8F%D=F%L*0I[
M"B`@("!R971V86P@/2`G)SL*("`@('9A;&ED8VAA<G,@/2`G86)C9&5F9VAI
M:FML;6YO<'%R<W1U=G=X>7HP,3(S-#4V-S@Y)SL*"B`@("!B861V86PN=&],
M;W=E<D-A<V4H*3L*("`@(&9O<B`H:2`](#`[(&D@/"!B861V86PN;&5N9W1H
M.R!I*RLI('L*("`@("`@("!I9B`H=F%L:61C:&%R<RYI;F1E>$]F*&)A9'9A
M;"YC:&%R070H:2DI("$]("TQ*2!["B`@("`@("`@("`@(')E='9A;"`K/2!B
M861V86PN8VAA<D%T*&DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='9A;"`K/2`G7R<["B`@("`@("`@?0H@("`@?0H@("`@<F5T=7)N(')E
M='9A;#L*?0H*9G5N8W1I;VX@=FEE=RAU<FPL('!A<G1I9"D*>PH@("`@<&%R
M86T@/2`B;65N=6)A<CUY97,L=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQS=&%T
M=7,];F\L<V-R;VQL8F%R<SUY97,L<F5S:7IA8FQE/7EE<R(["B`@("!W:6YD
M;W<N;W!E;BAU<FPL("<\/W!H<"!E8VAO(&)A<V5?8V]N=F5R="AM:6-R;W1I
M;64H*2P@,3`L(#,V*2`_/B<@*R!T<BAP87)T:60I+"!P87)A;2D["GT*"B\O
M("TM/@H\+W-C<FEP=#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]J879A<V-R:7!T+P``````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C4`,#(P-38P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<W-``Q,#4Q-30S
M,3`V-0`P,C8Q,3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.
M0T]$24Y'.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"
M87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y3
M3$%43U)3.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.
M1D\@24X@5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI
M9"!E;6%I;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%
M(%541BTX($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@
M<&]S<VEB;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T
M:&%T('-T871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I!;G-E
M;$EM86=E+DDQ.$X@/2!["@DO+R!)=&5M<R!T:&%T(&%P<&5A<B!I;B!M96YU
M+B`@4&QE87-E(&YO=&4@=&AA="!A;B!U;F1E<G-C;W)E("A?*0H)+R\@8VAA
M<F%C=&5R(&EN('1H92!T<F%N<VQA=&EO;B`H<FEG:'0@8V]L=6UN*2!W:6QL
M(&-A=7-E('1H92!F;VQL;W=I;F<*"2\O(&QE='1E<B!T;R!B96-O;64@=6YD
M97)L:6YE9"!A;F0@8F4@<VAO<G1C=70@9F]R('1H870@;65N=2!O<'1I;VXN
M"@H)(DEN<V5R="!);6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@
M26UA9V4B*2D@/SXB+`H)(DEM86=E(%523#HB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*"));6%G92!54DPZ(BDI(#\^(BP*"2)%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4B("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B16YT97(@=&AE(&EM86=E(%523"!H97)E(BDI(#\^
M(BP*"2)0<F5V:65W(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4')E=FEE
M=R(I*2`_/B(L"@DB4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M(B`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(I*2`_/B(L"@DB
M06QT97)N871E('1E>'0Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%L=&5R;F%T92!T
M97AT.B(I*2`_/B(L"@DB1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R
M="!I;6%G97,B("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(BDI
M(#\^(BP*"2)0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(B`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(I*2`_/B(L"@DB26UA9V4@4')E=FEE
M=SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E(%!R979I97<Z(BDI(#\^(BP*
M"2)'86QL97)Y.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1V%L;&5R>3HB
M*2D@/SXB+`H)(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(B`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")'
M86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(I*2`_/B(L"@DB26UA9V4@9G)O
M;2!G86QL97)Y.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E(&9R;VT@9V%L;&5R>3HB
M*2D@/SXB+`H)(DEM86=E(&9R;VT@9V%L;&5R>2(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"))
M;6%G92!F<F]M(&=A;&QE<GDB*2D@/SXB"GT["@`````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,`````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,#(`,3`U,34T,S$P-C4`
M,#(U-C0P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\O($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.
M1SH@551&+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL
M(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]2
M4SH*+R\*+R\@("`Q+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.
M(%1(12!!0D]612!,24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA
M:6P@861D<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M
M."!&3U(@14Y#3T1)3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I
M8FQE+"!P;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S
M=&%T97,@=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*3&ES=%1Y<&4N
M23$X3B`]('L*"2)$96-I;6%L(B`@("`@("`@("`@("`@("`Z("`@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B1&5C:6UA;"!N=6UB97)S(BDI(#\^(BP*
M"2),;W=E<B!R;VUA;B(@("`@("`@("`@("`Z("`@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B3&]W97(@<F]M86X@;G5M8F5R<R(I*2`_/B(L"@DB57!P
M97(@<F]M86XB("`@("`@("`@("`@.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E5P<&5R(')O;6%N(&YU;6)E<G,B*2D@/SXB+`H)(DQO=V5R(&QA
M=&EN(B`@("`@("`@("`@(#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*"),;W=E<B!L871I;B!L971T97)S(BDI(#\^(BP*"2)5<'!E<B!L871I;B(@
M("`@("`@("`@("`Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B57!P
M97(@;&%T:6X@;&5T=&5R<R(I*2`_/B(L"@DB3&]W97(@9W)E96LB("`@("`@
M("`@("`@.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQO=V5R(&=R
M965K(&QE='1E<G,B*2D@/SXB+`H)(DQI<W13='EL951O;VQT:7`B("`@("`@
M(#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB*2D@/SXB"GT["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]G;V]G;&5?=VEN+FIS````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C(T-0`Q,#4Q-30S,3`V-0`P,C0R-S``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````9G5N8W1I;VX@;W!E;E]G;V]G
M;&5?=VEN*&%R9W,I"GL*("`@('9A<B!V86PL('5R;"`]("<G.PH*("`@(&9O
M<B`H=F%R(&D@/2`P.R!I(#P@9&]C=6UE;G0N9V]O9VQE+F%R96$N;&5N9W1H
M.R!I*RLI('L*("`@("`@("!I9B`H9&]C=6UE;G0N9V]O9VQE+F%R96%;:5TN
M8VAE8VME9"D@>PH@("`@("`@("`@("!V86P@/2!D;V-U;65N="YG;V]G;&4N
M87)E85MI72YV86QU93L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?0H*("`@('-W:71C:"`H=F%L*2!["@EC87-E("=W96(G.@H@("`@"75R
M;"`]("=H='1P.B\O=W=W+F=O;V=L92YC;VTO<V5A<F-H/R<["@D@("`@8G)E
M86L["@H)8V%S92`G:6UA9V5S)SH*"2`@("!U<FP@/2`G:'1T<#HO+VEM86=E
M<RYG;V]G;&4N8V]M+VEM86=E<S\G.PH@("`@("`@(&)R96%K.PH*"6-A<V4@
M)V=R;W5P<R<Z"@D@("`@=7)L(#T@)VAT='`Z+R]G<F]U<',N9V]O9VQE+F-O
M;2]G<F]U<',_)SL*("`@("`@("!B<F5A:SL*"@EC87-E("=D:7)E8W1O<GDG
M.@H)("`@('5R;"`]("=H='1P.B\O=W=W+F=O;V=L92YC;VTO<V5A<F-H/V-A
M=#UG=V0E,D94;W`F)SL*("`@("`@("!B<F5A:SL*"@EC87-E("=N97=S)SH*
M"2`@("!U<FP@/2`G:'1T<#HO+VYE=W,N9V]O9VQE+F-O;2]N97=S/R<["B`@
M("`@("`@8G)E86L["@H)9&5F875L=#H*("`@(`EU<FP@/2`G:'1T<#HO+W=W
M=RYG;V]G;&4N8V]M+W-E87)C:#\G.PH@("`@?0H@("`@=7)L("L]("=Q/2<[
M"B`@("!I9B`H='EP96]F(&5N8V]D955224-O;7!O;F5N="`]/2`G=6YD969I
M;F5D)RD@>PH@("`@("`@('5R;"`K/2!E<V-A<&4H9&]C=6UE;G0N9V]O9VQE
M+G$N=F%L=64I.PH@("`@?2!E;'-E('L*("`@("`@("!U<FP@*ST@96YC;V1E
M55))0V]M<&]N96YT*&1O8W5M96YT+F=O;V=L92YQ+G9A;'5E*3L*("`@('T*
M"B`@("!V87(@;F%M92`]("=';V]G;&4G.PH@("`@=F%R('!A<F%M(#T@)W1O
M;VQB87(]>65S+&QO8V%T:6]N/7EE<RQS=&%T=7,]>65S+'-C<F]L;&)A<G,]
M>65S+')E<VEZ86)L93UY97,L=VED=&@].#`P+&AE:6=H=#TV,#`L;&5F=#TP
M+'1O<#TP)SL*"B`@("!E=F%L*"=N86UE(#T@=VEN9&]W+F]P96XH=7)L+"!N
M86UE+"!P87)A;2DG*3L*("`@(&EF("@A979A;"@G;F%M92YO<&5N97(G*2D@
M>PH@("`@("`@(&5V86PH)VYA;64N;W!E;F5R(#T@<V5L9B<I.PH@("`@?0I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS`````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-#8S`#$P-3$U-#,Q,#8U
M`#`R-3`W,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)
M3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N
M+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/
M4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)
M3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M
M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@551&
M+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S
M:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H870@
M<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"E1A8FQE3W!E
M<F%T:6]N<RY),3A.(#T@>PH)(D%L:6=N(CH)"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")!;&EG;B(I*2`_/B(L"@DB06QL(&9O=7(@<VED97,B
M.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QL(&9O=7(@<VED
M97,B*2D@/SXB+`H)(D)A8VMG<F]U;F0B.@D)"0D)("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D)A8VMG<F]U;F0B*2D@/SXB+`H)(D)A<V5L:6YE(CH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D)A<V5L:6YE(BDI(#\^(BP*"2)";W)D97(B
M.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)O<F1E<B(I*2`_
M/B(L"@DB0F]R9&5R<R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B0F]R9&5R<R(I*2`_/B(L"@DB0F]T=&]M(CH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0F]T=&]M(BDI(#\^(BP*"2)#4U,@4W1Y;&4B.@D)"0D)("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-T>6QE(%M#4U-=(BDI(#\^(BP*"2)#
M87!T:6]N(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#87!T
M:6]N(BDI(#\^(BP*"2)#96QL(%!R;W!E<G1I97,B.B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#
M96QL(%!R;W!E<G1I97,B*2D@/SXB+`H)(D-E;G1E<B(Z"0D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0V5N=&5R(BDI(#\^(BP*"2)#:&%R(CH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")#:&%R(BDI(#\^(BP*"2)#;VQL87!S
M960@8F]R9&5R<R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")#;VQL87!S960@8F]R9&5R<R(I*2`_
M/B(L"@DB0V]L;W(B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-O;&]R(BDI(#\^(BP*"2)$97-C<FEP=&EO;B(Z"0D)"0D@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B1&5S8W)I<'1I;VXB*2D@/SXB+`H)(D9'($-O
M;&]R(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")&1R!#;VQO
M<B(I*2`_/B(L"@DB1FQO870B.B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1FQO
M870B*2D@/SXB+`H)(D9R86UE<R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B1G)A;65S(BDI(#\^(BP*"2)(96EG:'0B.B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")(96EG:'0B*2D@/SXB+`H)(DAO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(CH@("`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(BDI(#\^(BP*"2)(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(Z("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(I
M*2`_/B(L"@DB26UA9V4@55),(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*"));6%G92!54DPB*2D@/SXB+`H)(DIU<W1I9GDB.B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DIU<W1I9GDB*2D@/SXB+`H)(DQA>6]U="(Z"0D)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&%Y;W5T(BDI(#\^(BP*"2),
M969T(CH)"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&5F="(I
M*2`_/B(L"@DB36%R9VEN(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B36%R9VEN
M(BDI(#\^(BP*"2)-:61D;&4B.B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")-:61D
M;&4B*2D@/SXB+`H)(DYO(')U;&5S(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*").;R!R=6QE<R(I*2`_/B(L"@DB3F\@<VED97,B.@D)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DYO('-I9&5S(BDI(#\^(BP*
M"2).;VYE(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*").;VYE(BDI(#\^(BP*
M"2)0861D:6YG(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0
M861D:6YG(BDI(#\^(BP*"2)0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB
M.B`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB*2D@/SXB+`H)(E)I9VAT
M(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")2:6=H="(I*2`_
M/B(L"@DB4F]W(%!R;W!E<G1I97,B.B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F]W(%!R;W!E
M<G1I97,B*2D@/SXB+`H)(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,B.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M
M;G,B*2D@/SXB+`H)(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(CH)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(BDI(#\^(BP*"2)2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(Z"0D@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'DB*2D@/SXB+`H)(E)U;&5S(CH)"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")2=6QE<R(I*2`_/B(L"@DB4W!A8VEN9R!A;F0@<&%D
M9&EN9R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4W!A8VEN9R!A;F0@<&%D9&EN9R(I*2`_/B(L"@DB
M4W!A8VEN9R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W!A
M8VEN9R(I*2`_/B(L"@DB4W5M;6%R>2(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4W5M;6%R>2(I*2`_/B(L"@DB5$\M8V5L;"UD96QE=&4B
M.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L971E(&-E;&PB
M*2D@/SXB+`H)(E1/+6-E;&PM:6YS97)T+6%F=&5R(CH)"0D)("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!C96QL(&%F=&5R(BDI(#\^(BP*
M"2)43RUC96QL+6EN<V5R="UB969O<F4B.@D)"2`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"));G-E<G0@8V5L;"!B969O<F4B*2D@/SXB+`H)(E1/+6-E
M;&PM;65R9V4B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B365R
M9V4@8V5L;',B*2D@/SXB+`H)(E1/+6-E;&PM<')O<"(Z"0D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0V5L;"!P<F]P97)T:65S(BDI(#\^(BP*
M"2)43RUC96QL+7-P;&ET(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E-P;&ET(&-E;&PB*2D@/SXB+`H)(E1/+6-O;"UD96QE=&4B.@D)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L971E(&-O;'5M;B(I*2`_
M/B(L"@DB5$\M8V]L+6EN<V5R="UA9G1E<B(Z"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*"));G-E<G0@8V]L=6UN(&%F=&5R(BDI(#\^(BP*"2)4
M3RUC;VPM:6YS97)T+6)E9F]R92(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*"));G-E<G0@8V]L=6UN(&)E9F]R92(I*2`_/B(L"@DB5$\M8V]L
M+7-P;&ET(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3<&QI
M="!C;VQU;6XB*2D@/SXB+`H)(E1/+7)O=RUD96QE=&4B.@D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L971E(')O=R(I*2`_/B(L"@DB5$\M
M<F]W+6EN<V5R="UA8F]V92(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*"));G-E<G0@<F]W(&)E9F]R92(I*2`_/B(L"@DB5$\M<F]W+6EN<V5R
M="UU;F1E<B(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E
M<G0@<F]W(&%F=&5R(BDI(#\^(BP*"2)43RUR;W<M<')O<"(Z"0D)"0D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F]W('!R;W!E<G1I97,B*2D@/SXB
M+`H)(E1/+7)O=RUS<&QI="(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B4W!L:70@<F]W(BDI(#\^(BP*"2)43RUT86)L92UP<F]P(CH)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1A8FQE('!R;W!E<G1I97,B
M*2D@/SXB+`H)(E1A8FQE(%!R;W!E<G1I97,B.@D)"0D@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B5&%B;&4@4')O<&5R=&EE<R(I*2`_/B(L"@DB5&5X
M="!A;&EG;B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&5X="!A;&EG;B(I*2`_/B(L
M"@DB5&AE(&)O='1O;2!S:61E(&]N;'DB.@D)"0D@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B5&AE(&)O='1O;2!S:61E(&]N;'DB*2D@/SXB+`H)(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(CH)"0D@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB*2D@/SXB+`H)(E1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(CH)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(I
M*2`_/B(L"@DB5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(CH)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M(BDI(#\^(BP*"2)4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(Z"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'DB*2D@/SXB+`H)(E1H92!T;W`@<VED92!O;FQY(CH)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!T;W`@<VED92!O;FQY
M(BDI(#\^(BP*"2)4;W`B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4;W`B
M*2D@/SXB+`H)(E5N<V5T(&-O;&]R(CH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5N<V5T
M(&-O;&]R(BDI(#\^(BP*"2)697)T:6-A;"!A;&EG;B(Z("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")697)T:6-A;"!A;&EG;B(I*2`_/B(L"@DB5VED=&@B.@D)"0D)("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E=I9'1H(BDI(#\^(BP*"2)N;W0M9&5L
M+6QA<W0M8V5L;"(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB*2D@/SXB+`H)(FYO="UD96PM;&%S="UC;VPB.@D)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(I
M*2`_/B(L"@DB;F]T+61E;"UL87-T+7)O=R(Z"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(BDI(#\^(BP*"2)P97)C96YT
M(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")P97)C96YT(BDI
M(#\^(BP*"2)P:7AE;',B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(G!I>&5L<R(I*2`_/B(*?3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O=')E92YJ<P``````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U,#0T
M-``Q,#4Q-30S,3`V-0`P,C(P-C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+RHJ"B`J($AO<F1E(%1R964@2F%V87-C<FEP
M="!#;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!C;&%S<R!T
M;R!C<F5A=&4@9'EN86UI8R!T<F5E<RX*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O=')E
M92YJ<RQV(#$N-C(N,BXQ,2`R,#`V+S`Q+S`Q(#(Q.C(Y.C$U(&IA;B!%>'`@
M)`H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M
M/@H@*B!`<&%C:V%G92!(;W)D95]4<F5E"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B\*9G5N8W1I;VX@2&]R9&5?5')E92AI;G-T86YC94YA;64I"GL*("`@
M("\J(%-E="!U<"!T:&ES(&-L87-S(&EN<W1A;F-E(&9O<B!F=6YC=&EO;B!C
M86QL<R!F<F]M('1H92!P86=E+B`J+PH@("`@=&AI<RY?:6YS=&%N8V5.86UE
M(#T@:6YS=&%N8V5.86UE.PH*("`@("\J($EM86=E('9A<FEA8FQE<RX@*B\*
M("`@('1H:7,N:6UG1&ER("`@("`@("`@/2`G/#]P:'`@96-H;R`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+W1R964G
M.R`_/B<["B`@("!T:&ES+FEM9T)L86YK("`@("`@(#T@)V)L86YK+G!N9R<[
M"B`@("!T:&ES+FEM9T9O;&1E<B`@("`@(#T@)V9O;&1E<BYP;F<G.PH@("`@
M=&AI<RYI;6=&;VQD97)/<&5N("`]("=F;VQD97)O<&5N+G!N9R<["@H@("`@
M+RH@5F%R:6%B;&5S('1H870@8VAA;F=E(&)A<V5D(&]N('1E>'0@9&ER96-T
M:6]N+B`J+PH\/W!H<"!I9B`H96UP='DH)$=,3T)!3%-;)VYL<R==6R=R=&PG
M75LD1TQ/0D%,4ULG;&%N9W5A9V4G75TI*3H@/SX*("`@('1H:7,N9FQO871$
M:7(@("`@("`@/2`G9FQO870Z;&5F=#LG.PH@("`@=&AI<RYI;6=,:6YE("`@
M("`@("`]("=L:6YE+G!N9R<["B`@("!T:&ES+FEM9TIO:6X@("`@("`@(#T@
M)VIO:6XN<&YG)SL*("`@('1H:7,N:6UG2F]I;D)O='1O;2`@/2`G:F]I;F)O
M='1O;2YP;F<G.PH@("`@=&AI<RYI;6=0;'5S("`@("`@("`]("=P;'5S+G!N
M9R<["B`@("!T:&ES+FEM9U!L=7-";W1T;VT@(#T@)W!L=7-B;W1T;VTN<&YG
M)SL*("`@('1H:7,N:6UG4&QU<T]N;'D@("`@/2`G<&QU<V]N;'DN<&YG)SL*
M("`@('1H:7,N:6UG36EN=7,@("`@("`@/2`G;6EN=7,N<&YG)SL*("`@('1H
M:7,N:6UG36EN=7-";W1T;VT@/2`G;6EN=7-B;W1T;VTN<&YG)SL*("`@('1H
M:7,N:6UG36EN=7-/;FQY("`@/2`G;6EN=7-O;FQY+G!N9R<["B`@("!T:&ES
M+FEM9TYU;&Q/;FQY("`@(#T@)VYU;&QO;FQY+G!N9R<["B`@("!T:&ES+FEM
M9TQE868@("`@("`@(#T@)VQE868N<&YG)SL*/#]P:'`@96QS93H@/SX*("`@
M('1H:7,N9FQO871$:7(@("`@("`@/2`G9FQO870Z<FEG:'0[)SL*("`@('1H
M:7,N:6UG3&EN92`@("`@("`@/2`G<F5V+6QI;F4N<&YG)SL*("`@('1H:7,N
M:6UG2F]I;B`@("`@("`@/2`G<F5V+6IO:6XN<&YG)SL*("`@('1H:7,N:6UG
M2F]I;D)O='1O;2`@/2`G<F5V+6IO:6YB;W1T;VTN<&YG)SL*("`@('1H:7,N
M:6UG4&QU<R`@("`@("`@/2`G<F5V+7!L=7,N<&YG)SL*("`@('1H:7,N:6UG
M4&QU<T)O='1O;2`@/2`G<F5V+7!L=7-B;W1T;VTN<&YG)SL*("`@('1H:7,N
M:6UG4&QU<T]N;'D@("`@/2`G<F5V+7!L=7-O;FQY+G!N9R<["B`@("!T:&ES
M+FEM9TUI;G5S("`@("`@(#T@)W)E=BUM:6YU<RYP;F<G.PH@("`@=&AI<RYI
M;6=-:6YU<T)O='1O;2`]("=R978M;6EN=7-B;W1T;VTN<&YG)SL*("`@('1H
M:7,N:6UG36EN=7-/;FQY("`@/2`G<F5V+6UI;G5S;VYL>2YP;F<G.PH@("`@
M=&AI<RYI;6=.=6QL3VYL>2`@("`]("=R978M;G5L;&]N;'DN<&YG)SL*("`@
M('1H:7,N:6UG3&5A9B`@("`@("`@/2`G<F5V+6QE868N<&YG)SL*/#]P:'`@
M96YD:68[(#\^"@H@("`@+RH@5')E92!B=6EL9&EN9R!V87)I86)L97,N("HO
M"B`@("!T:&ES+G)E;F1E<E-T871I8R`@(#T@9F%L<V4["B`@("!T:&ES+G1A
M<F=E="`@("`@("`@(#T@)R<["B`@("!T:&ES+FAE861E<B`@("`@("`@(#T@
M;F5W($%R<F%Y*"D["B`@("!T:&ES+G)O;W1.;V1E<R`@("`@(#T@;F5W($%R
M<F%Y*"D["B`@("!T:&ES+FYO9&5S("`@("`@("`@(#T@;F5W($%R<F%Y*"D[
M"B`@("!T:&ES+FYO9&5?<&]S("`@("`@(#T@;F5W($%R<F%Y*"D["B`@("!T
M:&ES+F1R;W!L:6YE("`@("`@(#T@;F5W($%R<F%Y*"D["B`@("!T:&ES+F]U
M='!U="`@("`@("`@(#T@)R<["GT*"DAO<F1E7U1R964N<')O=&]T>7!E+G-E
M=$EM9T1I<B`](&9U;F-T:6]N*&EM9T1I<BD*>PH@("`@=&AI<RYI;6=$:7(@
M/2!I;6=$:7(["GT*"DAO<F1E7U1R964N<')O=&]T>7!E+G)E;F1E<E1R964@
M/2!F=6YC=&EO;BAR;V]T3F]D97,L(')E;F1E<E-T871I8RD*>PH@("`@=&AI
M<RYR;V]T3F]D97,@/2!R;V]T3F]D97,["B`@("!T:&ES+G)E;F1E<E-T871I
M8R`](')E;F1E<E-T871I8SL*("`@('1H:7,N;F]D97,@/2!E=F%L*"=N7R<@
M*R!T:&ES+E]I;G-T86YC94YA;64I.PH@("`@=&AI<RYH96%D97(@/2!E=F%L
M*"=H7R<@*R!T:&ES+E]I;G-T86YC94YA;64I.PH@("`@=&AI<RYO<'1I;VYS
M(#T@979A;"@G;U\G("L@=&AI<RY?:6YS=&%N8V5.86UE*3L*("`@('1H:7,N
M=&%R9V5T(#T@)W1?)R`K('1H:7,N7VEN<W1A;F-E3F%M93L*("`@('1H:7,N
M7W)E;F1E<E1R964H*3L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N7W)E;F1E
M<E1R964@/2!F=6YC=&EO;B@I"GL*("`@('1H:7,N;W5T<'5T(#T@)R<["B`@
M("!I9B`H(71H:7,N;W!T:6]N<ULG:&ED94AE861E<G,G72D@>PH@("`@("`@
M('1H:7,N;W5T<'5T(#T@=&AI<RY?8G5I;&1(96%D97(H*3L*("`@('T*("`@
M(&9O<B`H=F%R(&D@/2`P.R!I(#P@=&AI<RYR;V]T3F]D97,N;&5N9W1H.R!I
M*RLI('L*("`@("`@("!T:&ES+F)U:6QD5')E92AT:&ES+G)O;W1.;V1E<UMI
M72D["B`@("!]"B`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"AT:&ES+G1A
M<F=E="DN:6YN97)(5$U,(#T@=&AI<RYO=71P=70["B`@("!T:&ES+E]C;W)R
M96-T5VED=&A&;W)38W)O;&QB87(H*3L*("`@("\O($EF('5S:6YG(&%L=&5R
M;F%T:6YG(')O=R!S:&%D:6YG+"!W;W)K(&]U="!C;W)R96-T('-H861E+@H@
M("`@:68@*'1H:7,N;W!T:6]N<ULG86QT97)N871E)UTI('L*("`@("`@("!T
M:&ES+G-T<FEP92@I.PH@("`@?0I]"@HO*BH*("H@4F5T=7)N<R!T:&4@2%1-
M3"!C;V1E(&9O<B!A(&AE861E<B!R;W<L(&EF(&YE8V5S<V%R>2X*("H*("H@
M0&%C8V5S<R!P<FEV871E"B`J"B`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-
M3"!C;V1E(&]F('1H92!H96%D97(@<F]W(&]R(&%N(&5M<'1Y('-T<FEN9RX*
M("HO"DAO<F1E7U1R964N<')O=&]T>7!E+E]B=6EL9$AE861E<B`](&9U;F-T
M:6]N*"D*>PH@("`@:68@*"%T:&ES+FAE861E<BYL96YG=&@I('L*("`@("`@
M("!R971U<FX@)R<["B`@("!]"@H@("`@=F%R(&AT;6P@/2`G/&1I=CXG.PH@
M("`@9F]R("AV87(@:2`](#`[(&D@/"!T:&ES+FAE861E<BYL96YG=&@[(&DK
M*RD@>PH@("`@("`@(&AT;6P@*ST@)SQD:78G.PH@("`@("`@(&EF("AT:&ES
M+FAE861E<EMI75LG8VQA<W,G72D@>PH@("`@("`@("`@("!H=&UL("L]("<@
M8VQA<W,](B<@*R!T:&ES+FAE861E<EMI75LG8VQA<W,G72`K("<B)SL*("`@
M("`@("!]"@H@("`@("`@('9A<B!S='EL92`]('1H:7,N9FQO871$:7(["B`@
M("`@("`@:68@*'1H:7,N:&5A9&5R6VE=6R=W:61T:"==*2!["B`@("`@("`@
M("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH96%D97);:5U;)W=I9'1H
M)UT@*R`G.R<["B`@("`@("`@?0H@("`@("`@(&EF("AT:&ES+FAE861E<EMI
M75LG86QI9VXG72D@>PH@("`@("`@("`@("!S='EL92`K/2`G=&5X="UA;&EG
M;CHG("L@=&AI<RYH96%D97);:5U;)V%L:6=N)UT@*R`G.R<["B`@("`@("`@
M?0H*("`@("`@("!H=&UL("L]("<@<W1Y;&4](B<@*R!S='EL92`K("<B)SL*
M("`@("`@("!H=&UL("L]("<^)SL*("`@("`@("!H=&UL("L]('1H:7,N:&5A
M9&5R6VE=6R=H=&UL)UT@/R!T:&ES+FAE861E<EMI75LG:'1M;"==(#H@)R9N
M8G-P.R<["B`@("`@("`@:'1M;"`K/2`G/"]D:78^)SL*("`@('T*"B`@("!R
M971U<FX@:'1M;"`K("<\+V1I=CXG.PI]"@HO*BH*("H@4F5C=7)S:79E(&9U
M;F-T:6]N('1O('=A;&L@=&AR;W5G:"!T:&4@=')E92!A<G)A>2!A;F0@8G5I
M;&0*("H@=&AE(&]U='!U="X*("HO"DAO<F1E7U1R964N<')O=&]T>7!E+F)U
M:6QD5')E92`](&9U;F-T:6]N*&YO9&5)9"D*>PH@("`@=&AI<RYO=71P=70@
M*ST@=&AI<RYB=6EL9$QI;F4H;F]D94ED*3L*"B`@("!I9B`H='EP96]F*'1H
M:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG72D@(3T@)W5N9&5F:6YE9"<I
M('L*("`@("`@("!V87(@;G5M4W5B;F]D97,@/2!T:&ES+FYO9&5S6VYO9&5)
M9%U;)V-H:6QD<F5N)UTN;&5N9W1H.PH@("`@("`@(&EF("AN=6U3=6)N;V1E
M<R`^(#`I('L*("`@("`@("`@("`@:68@*'1H:7,N;F]D97-;;F]D94ED75LG
M97AP86YD960G72D@>PH@("`@("`@("`@("`@("`@<F]W4W1Y;&4@/2`G9&ES
M<&QA>3IB;&]C:SLG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F]W4W1Y;&4@/2`G9&ES<&QA>3IN;VYE.R<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@=&AI<RYO=71P=70@*ST@)SQD:78@:60](FYO9&5#
M:&EL9')E;E\G("L@;F]D94ED("L@)R(@<W1Y;&4](B<@*R!R;W=3='EL92`K
M("<B/B<["@H@("`@("`@("`@("!F;W(@*'9A<B!C(#T@,#L@8R`\(&YU;5-U
M8FYO9&5S.R!C*RLI('L*("`@("`@("`@("`@("`@('9A<B!C:&EL9$YO9&5)
M9"`]('1H:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG75MC73L*("`@("`@
M("`@("`@("`@('1H:7,N;F]D95]P;W-;8VAI;&1.;V1E261=(#T@;F5W($%R
M<F%Y*"D["B`@("`@("`@("`@("`@("!T:&ES+FYO9&5?<&]S6V-H:6QD3F]D
M94ED75LG<&]S)UT@/2!C("L@,3L*("`@("`@("`@("`@("`@('1H:7,N;F]D
M95]P;W-;8VAI;&1.;V1E261=6R=C;W5N="==(#T@;G5M4W5B;F]D97,["B`@
M("`@("`@("`@("`@("!T:&ES+F)U:6QD5')E92AC:&EL9$YO9&5)9"D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@('1H:7,N;W5T<'5T("L]("<\+V1I
M=CXG.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@=')U93L*?0H*2&]R
M9&5?5')E92YP<F]T;W1Y<&4N8G5I;&1,:6YE(#T@9G5N8W1I;VXH;F]D94ED
M*0I["B`@("!V87(@<W1Y;&4@/2`G)SL*("`@('9A<B!R;W=#;&%S<R`]("=T
M<F5E4F]W)SL*("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)V-L87-S)UTI
M('L*("`@("`@("!R;W=#;&%S<R`K/2`G("<@*R!T:&ES+FYO9&5S6VYO9&5)
M9%U;)V-L87-S)UT["B`@("!]"@H@("`@=F%R(&QI;F4@/2`G/&1I=B!C;&%S
M<STB)R`K(')O=T-L87-S("L@)R(^)SL*"B`@("`O+R!)9B!W92!H879E(&AE
M861E<G,L('1R86-K('=H:6-H(&QO9VEC86P@(F-O;'5M;B(@=V4G<F4@:6X@
M9F]R"B`@("`O+R!A;GD@9VEV96X@8V5L;"!O9B!C;VYT96YT+@H@("`@=F%R
M(&-O;'5M;B`](#`["@H@("`@:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)
M9%U;)V5X=')A)UTI("$]("=U;F1E9FEN960G("8F"B`@("`@("`@='EP96]F
M*'1H:7,N;F]D97-;;F]D94ED75LG97AT<F$G75LP72D@(3T@)W5N9&5F:6YE
M9"<I('L*("`@("`@("!V87(@97AT<F$@/2!T:&ES+FYO9&5S6VYO9&5)9%U;
M)V5X=')A)UU;,%T["B`@("`@("`@9F]R("AV87(@8R`](#`[(&,@/"!E>'1R
M82YL96YG=&@[(&,K*RD@>PH@("`@("`@("`@("!S='EL92`]('1H:7,N9FQO
M871$:7(["B`@("`@("`@("`@(&EF("AT:&ES+FAE861E<EMC;VQU;6Y=("8F
M('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI('L*("`@("`@("`@("`@
M("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH96%D97);8V]L=6UN75LG
M=VED=&@G72`K("<[)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!L:6YE
M("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G(CXG("L@97AT<F%;8UT@
M*R`G/"]D:78^)SL*("`@("`@("`@("`@8V]L=6UN*RL["B`@("`@("`@?0H@
M("`@("`@(&9O<B`H=F%R(&0@/2!C.R!D(#P@97AT<F%#;VQS3&5F=#L@9"LK
M*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI<RYF;&]A=$1I<CL*("`@("`@
M("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M;ET@)B8@=&AI<RYH96%D97);
M8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@("`@("`@("`@<W1Y;&4@*ST@
M)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==("L@)SLG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI;F4@*ST@)SQD:78@<W1Y
M;&4](B<@*R!S='EL92`K("<B/B9N8G-P.SPO9&EV/B<["B`@("`@("`@("`@
M(&-O;'5M;BLK.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@9F]R
M("AV87(@8R`](#`[(&,@/"!E>'1R84-O;'-,969T.R!C*RLI('L*("`@("`@
M("`@("`@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@("`@("`@("!I9B`H
M=&AI<RYH96%D97);8V]L=6UN72`F)B!T:&ES+FAE861E<EMC;VQU;6Y=6R=W
M:61T:"==*2!["B`@("`@("`@("`@("`@("!S='EL92`K/2`G=VED=&@Z)R`K
M('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@*R`G.R<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@;&EN92`K/2`G/&1I=B!S='EL93TB)R`K('-T
M>6QE("L@)R(^)FYB<W`[/"]D:78^)SL*("`@("`@("`@("`@8V]L=6UN*RL[
M"B`@("`@("`@?0H@("`@?0H*("`@('-T>6QE(#T@=&AI<RYF;&]A=$1I<CL*
M("`@(&EF("AT:&ES+FAE861E<EMC;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O
M;'5M;EU;)W=I9'1H)UTI('L*("`@("`@("!S='EL92`K/2`G=VED=&@Z)R`K
M('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@*R`G.R<["B`@("!]"B`@
M("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G(CXG.PH*("`@
M(&EF("AT:&ES+F]P=&EO;G-;)VUU;'1I;&EN92==*2!["B`@("`@("`@;&EN
M92`K/2`G/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX\='(^/'1D/B<["B`@("!]
M"@H@("`@9F]R("AV87(@:2`]('1H:7,N<F5N9&5R4W1A=&EC(#\@,2`Z(#`[
M(&D@/"!T:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==.R!I*RLI('L*("`@
M("`@("!I9B`H=&AI<RYD<F]P;&EN95MI72`F)B!T:&ES+F]P=&EO;G-;)VQI
M;F5S)UTI('L*("`@("`@("`@("`@;&EN92`K/2`G/&EM9R!S<F,](B<@*R!T
M:&ES+FEM9T1I<B`K("<O)R`K('1H:7,N:6UG3&EN92`K("<B(&%L=#TB?"9N
M8G-P.R9N8G-P.R9N8G-P.R(@:&5I9VAT/2(R,"(@=VED=&@](C(P(B`O/B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&EN92`K/2`G/&EM9R!S
M<F,](B<@*R!T:&ES+FEM9T1I<B`K("<O)R`K('1H:7,N:6UG0FQA;FL@*R`G
M(B!A;'0](B9N8G-P.R9N8G-P.R9N8G-P.R(@:&5I9VAT/2(R,"(@=VED=&@]
M(C(P(B`O/B<["B`@("`@("`@?0H@("`@?0H@("`@;&EN92`K/2!T:&ES+E]S
M971.;V1E5&]G9VQE*&YO9&5)9"D["B`@("!I9B`H=&AI<RYO<'1I;VYS6R=M
M=6QT:6QI;F4G72D@>PH@("`@("`@(&QI;F4@*ST@)SPO=&0^/'1D/B<["B`@
M("!]"B`@("!L:6YE("L]('1H:7,N7W-E=$QA8F5L*&YO9&5)9"D["@H@("`@
M:68@*'1H:7,N;W!T:6]N<ULG;75L=&EL:6YE)UTI('L*("`@("`@("!L:6YE
M("L]("<\+W1D/CPO='(^/"]T86)L93XG.PH@("`@?0H*("`@(&QI;F4@*ST@
M)SPO9&EV/B<["B`@("!C;VQU;6XK*SL*"B`@("!I9B`H='EP96]F*'1H:7,N
M;F]D97-;;F]D94ED75LG97AT<F$G72D@(3T@)W5N9&5F:6YE9"<@)B8*("`@
M("`@("!T>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=E>'1R82==6S%=*2`A
M/2`G=6YD969I;F5D)RD@>PH@("`@("`@('9A<B!E>'1R82`]('1H:7,N;F]D
M97-;;F]D94ED75LG97AT<F$G75LQ73L*("`@("`@("!F;W(@*'9A<B!C(#T@
M,#L@8R`\(&5X=')A+FQE;F=T:#L@8RLK*2!["B`@("`@("`@("`@('-T>6QE
M(#T@=&AI<RYF;&]A=$1I<CL*("`@("`@("`@("`@:68@*'1H:7,N:&5A9&5R
M6V-O;'5M;ET@)B8@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72D@>PH@
M("`@("`@("`@("`@("`@<W1Y;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E
M<EMC;VQU;6Y=6R=W:61T:"==("L@)SLG.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&QI;F4@*ST@)SQD:78@<W1Y;&4](B<@*R!S='EL92`K("<B/B<@
M*R!E>'1R85MC72`K("<\+V1I=CXG.PH@("`@("`@("`@("!C;VQU;6XK*SL*
M("`@("`@("!]"B`@("`@("`@9F]R("AV87(@9"`](&,[(&0@/"!E>'1R84-O
M;'-2:6=H=#L@9"LK*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI<RYF;&]A
M=$1I<CL*("`@("`@("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M;ET@)B8@
M=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@("`@("`@
M("`@<W1Y;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=6R=W
M:61T:"==("L@)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI;F4@
M*ST@)SQD:78@<W1Y;&4](B<@*R!S='EL92`K("<B/B9N8G-P.SPO9&EV/B<[
M"B`@("`@("`@("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@('T@96QS92![
M"B`@("`@("`@9F]R("AV87(@8R`](#`[(&,@/"!E>'1R84-O;'-2:6=H=#L@
M8RLK*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI<RYF;&]A=$1I<CL*("`@
M("`@("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M;ET@)B8@=&AI<RYH96%D
M97);8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@("`@("`@("`@<W1Y;&4@
M*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==("L@
M)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI;F4@*ST@)SQD:78@
M<W1Y;&4](B<@*R!S='EL92`K("<B/B9N8G-P.SPO9&EV/B<["B`@("`@("`@
M("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@('T*("`@(&QI;F4@*ST@)SPO
M9&EV/B<["@H@("`@<F5T=7)N(&QI;F4["GT*"DAO<F1E7U1R964N<')O=&]T
M>7!E+E]S971,86)E;"`](&9U;F-T:6]N*&YO9&5)9"D*>PH@("`@;&%B96P@
M/2!T:&ES+FYO9&5S6VYO9&5)9%U;)VQA8F5L)UT["@H@("`@:68@*'1H:7,N
M;F]D97-;;F]D94ED75LG=7)L)UTI('L*("`@("`@("!V87(@=7)L0VQA<W,@
M/2`G)SL*("`@("`@("!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=U<FQC;&%S
M<R==*2!["B`@("`@("`@("`@('5R;$-L87-S(#T@)R!C;&%S<STB)R`K('1H
M:7,N;F]D97-;;F]D94ED75LG=7)L8VQA<W,G72`K("<B)SL*("`@("`@("!]
M(&5L<V4@:68@*'1H:7,N;W!T:6]N<ULG=7)L8VQA<W,G72D@>PH@("`@("`@
M("`@("!U<FQ#;&%S<R`]("<@8VQA<W,](B<@*R!T:&ES+F]P=&EO;G-;)W5R
M;&-L87-S)UT@*R`G(B<["B`@("`@("`@?0H*("`@("`@("!V87(@=&%R9V5T
M(#T@)R<["B`@("`@("`@:68@*'1H:7,N;F]D97-;;F]D94ED75LG=&%R9V5T
M)UTI('L*("`@("`@("`@("`@=&%R9V5T(#T@)R!T87)G970](B<@*R!T:&ES
M+FYO9&5S6VYO9&5)9%U;)W1A<F=E="==("L@)R(G.PH@("`@("`@('T@96QS
M92!I9B`H=&AI<RYO<'1I;VYS6R=T87)G970G72D@>PH@("`@("`@("`@("!T
M87)G970@/2`G('1A<F=E=#TB)R`K('1H:7,N;W!T:6]N<ULG=&%R9V5T)UT@
M*R`G(B<["B`@("`@("`@?0H*("`@("`@("!V87(@;VYC;&EC:R`]("<G.PH@
M("`@("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)V]N8VQI8VLG72D@>PH@
M("`@("`@("`@("!O;F-L:6-K(#T@)R!O;F-L:6-K/2(G("L@=&AI<RYN;V1E
M<UMN;V1E261=6R=O;F-L:6-K)UT@*R`G(B<["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)SQA)R`K('5R;$-L87-S("L@)R!H<F5F/2(G("L@=&AI<RYN
M;V1E<UMN;V1E261=6R=U<FPG72`K("<B)R`K('1A<F=E="`K(&]N8VQI8VL@
M*R`G/B<@*R!T:&ES+E]S971.;V1E26-O;BAN;V1E260I("L@;&%B96P@*R`G
M/"]A/B<["B`@("!](&5L<V4@>PH@("`@("`@(')E='5R;B`G/'-P86X@8VQA
M<W,](G1O9V=L92(@;VYC;&EC:STB)R`K('1H:7,N7VEN<W1A;F-E3F%M92`K
M("<N=&]G9VQE*%PG)R`K(&YO9&5)9"`K("=<)RDB/B<@*R!T:&ES+E]S971.
M;V1E26-O;BAN;V1E260I("L@;&%B96P@*R`G/"]S<&%N/B<["B`@("!]"GT*
M"DAO<F1E7U1R964N<')O=&]T>7!E+E]S971.;V1E5&]G9VQE(#T@9G5N8W1I
M;VXH;F]D94ED*0I["B`@("!V87(@871T<FEB(#T@)R<["B`@("!I9B`H=&AI
M<RYN;V1E<UMN;V1E261=6R=I;F1E;G0G72`]/2`G,"<@)B8*("`@("`@("!T
M>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL9')E;B==*2`A/2`G=6YD
M969I;F5D)RD@>PH@("`@("`@("\O(%1O<"!L979E;"!W:71H(&-H:6QD<F5N
M+@H@("`@("`@('1H:7,N9')O<&QI;F5;,%T@/2!F86QS93L*("`@("`@("!I
M9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&%T=')I8B`]("<@<W1Y
M;&4](F-U<G-O<CIP;VEN=&5R(B!O;F-L:6-K/2(G("L@=&AI<RY?:6YS=&%N
M8V5.86UE("L@)RYT;V=G;&4H7"<G("L@;F]D94ED("L@)UPG*2(G.PH@("`@
M("`@('T*("`@('T@96QS92!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E
M;G0G72`A/2`G,"<@)B8*("`@("`@("`@("`@("`@='EP96]F*'1H:7,N;F]D
M97-;;F]D94ED75LG8VAI;&1R96XG72D@/3T@)W5N9&5F:6YE9"<I('L*("`@
M("`@("`O+R!.;V1E(&YO(&-H:6QD<F5N+@H@("`@("`@(&EF("AT:&ES+FYO
M9&5?<&]S6VYO9&5)9%U;)W!O<R==(#P@=&AI<RYN;V1E7W!O<UMN;V1E261=
M6R=C;W5N="==*2!["B`@("`@("`@("`@("\O($YO="!L87-T(&YO9&4N"B`@
M("`@("`@("`@('1H:7,N9')O<&QI;F5;=&AI<RYN;V1E<UMN;V1E261=6R=I
M;F1E;G0G75T@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M('1H:7,N9')O<&QI;F5;=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E;G0G75T@
M/2!F86QS93L*("`@("`@("!]"B`@("!](&5L<V4@:68@*'1Y<&5O9BAT:&ES
M+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI("$]("=U;F1E9FEN960G*2![
M"B`@("`@("`@+R\@3F]D92!W:71H(&-H:6QD<F5N+@H@("`@("`@(&EF("AT
M:&ES+FYO9&5?<&]S6VYO9&5)9%U;)W!O<R==(#P@=&AI<RYN;V1E7W!O<UMN
M;V1E261=6R=C;W5N="==*2!["B`@("`@("`@("`@("\O($YO="!L87-T(&YO
M9&4N"B`@("`@("`@("`@('1H:7,N9')O<&QI;F5;=&AI<RYN;V1E<UMN;V1E
M261=6R=I;F1E;G0G75T@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\O($QA<W0@;F]D92X*("`@("`@("`@("`@=&AI<RYD<F]P;&EN
M95MT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==72`](&9A;'-E.PH@("`@
M("`@('T*("`@("`@("!I9B`H(71H:7,N<F5N9&5R4W1A=&EC*2!["B`@("`@
M("`@("`@(&%T=')I8B`]("<@<W1Y;&4](F-U<G-O<CIP;VEN=&5R(B!O;F-L
M:6-K/2(G("L@=&AI<RY?:6YS=&%N8V5.86UE("L@)RYT;V=G;&4H7"<G("L@
M;F]D94ED("L@)UPG*2(G.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@
M("`@+R\@5&]P(&QE=F5L(&YO9&4@=VET:"!N;R!C:&EL9')E;BX*("`@("`@
M("!I9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@('T*("`@("`@("!T:&ES+F1R;W!L:6YE6S!=(#T@9F%L
M<V4["B`@("!]"@H@("`@;F]D951O9V=L92`]('1H:7,N7V=E=$YO9&54;V=G
M;&4H;F]D94ED*3L*("`@(&EM9R`]("<\:6UG(&ED/2)N;V1E5&]G9VQE7R<@
M*R!N;V1E260@*R`G(B!S<F,](B<@*R!T:&ES+FEM9T1I<B`K("<O)R`K(&YO
M9&54;V=G;&5;,%T@*R`G(B`G.PH@("`@:68@*&YO9&54;V=G;&5;,5TI('L*
M("`@("`@("!I;6<@*ST@)V%L=#TB)R`K(&YO9&54;V=G;&5;,5T@*R`G(B`G
M.PH@("`@?0H@("`@:6UG("L](&%T=')I8B`K("<@:&5I9VAT/2(R,"(@=VED
M=&@](C(P(B`O/B<["B`@("!R971U<FX@:6UG.PI]"@I(;W)D95]4<F5E+G!R
M;W1O='EP92Y?9V5T3F]D951O9V=L92`](&9U;F-T:6]N*&YO9&5)9"D*>PH@
M("`@=F%R(&YO9&54;V=G;&4@/2!N97<@07)R87DH)R<L("<G*3L*("`@(&EF
M("AT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==(#T]("<P)R`F)@H@("`@
M("`@('1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI("$]
M("=U;F1E9FEN960G*2!["B`@("`@("`@+R\@5&]P(&QE=F5L('=I=&@@8VAI
M;&1R96XN"B`@("`@("`@:68@*'1H:7,N<F5N9&5R4W1A=&EC*2!["B`@("`@
M("`@("`@(')E='5R;B!N;V1E5&]G9VQE.PH@("`@("`@('T@96QS92!I9B`H
M(71H:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@("`@("`@("`@("!N;V1E5&]G
M9VQE6S!=(#T@=&AI<RYI;6=";&%N:SL*("`@("`@("`@("`@;F]D951O9V=L
M95LQ72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG"B`@("`@("`@?2!E;'-E(&EF
M("AT:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@
M("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG36EN=7-/;FQY.PH@("`@("`@
M("`@("!N;V1E5&]G9VQE6S%=(#T@)RTG.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9U!L=7-/;FQY.PH@
M("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RLG.PH@("`@("`@('T*("`@
M('T@96QS92!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E;G0G72`A/2`G
M,"<@)B8*("`@("`@("!T>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL
M9')E;B==*2`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O($YO9&4@;F\@
M8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N;F]D95]P;W-;;F]D94ED75LG
M<&]S)UT@/"!T:&ES+FYO9&5?<&]S6VYO9&5)9%U;)V-O=6YT)UTI('L*("`@
M("`@("`@("`@+R\@3F]T(&QA<W0@;F]D92X*("`@("`@("`@("`@:68@*'1H
M:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@("`@("`@("`@("`@("`@;F]D951O
M9V=L95LP72`]('1H:7,N:6UG2F]I;CL*("`@("`@("`@("`@("`@(&YO9&54
M;V=G;&5;,5T@/2`G?"TG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG0FQA;FL["B`@("`@
M("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)R9N8G-P.R9N8G-P.R9N8G-P
M.R<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!,87-T(&YO9&4N"B`@("`@("`@("`@(&EF("AT:&ES+F]P=&EO;G-;
M)VQI;F5S)UTI('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T
M:&ES+FEM9TIO:6Y";W1T;VT["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE
M6S%=(#T@)V`M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9T)L86YK.PH@("`@("`@("`@
M("`@("`@;F]D951O9V=L95LQ72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2!E;'-E(&EF("AT>7!E;V8H
M=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL9')E;B==*2`A/2`G=6YD969I;F5D
M)RD@>PH@("`@("`@("\O($YO9&4@=VET:"!C:&EL9')E;BX*("`@("`@("!I
M9B`H=&AI<RYN;V1E7W!O<UMN;V1E261=6R=P;W,G72`\('1H:7,N;F]D95]P
M;W-;;F]D94ED75LG8V]U;G0G72D@>PH@("`@("`@("`@("`O+R!.;W0@;&%S
M="!N;V1E+@H@("`@("`@("`@("!I9B`H(71H:7,N;W!T:6]N<ULG;&EN97,G
M72D@>PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG
M0FQA;FL["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)R9N8G-P
M.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@('T@96QS92!I9B`H=&AI<RYR
M96YD97)3=&%T:6,I('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@
M/2!T:&ES+FEM9TIO:6X["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=
M(#T@)WPM)SL*("`@("`@("`@("`@?2!E;'-E(&EF("AT:&ES+FYO9&5S6VYO
M9&5)9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@("`@(&YO9&54;V=G
M;&5;,%T@/2!T:&ES+FEM9TUI;G5S.PH@("`@("`@("`@("`@("`@;F]D951O
M9V=L95LQ72`]("<M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9U!L=7,["B`@("`@("`@
M("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RLG.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@3&%S="!N;V1E+@H@("`@
M("`@("`@("!I9B`H(71H:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@("`@("`@
M("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG0FQA;FL["B`@("`@
M("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)R9N8G-P.R<["B`@("`@("`@
M("`@('T@96QS92!I9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@
M("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9TIO:6Y";W1T;VT["B`@
M("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)V`M)SL*("`@("`@("`@
M("`@?2!E;'-E(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI
M('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9TUI
M;G5S0F]T=&]M.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<M
M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&YO9&54
M;V=G;&5;,%T@/2!T:&ES+FEM9U!L=7-";W1T;VT["B`@("`@("`@("`@("`@
M("!N;V1E5&]G9VQE6S%=(#T@)RLG.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!4;W`@;&5V96P@;F]D92!W:71H
M(&YO(&-H:6QD<F5N+@H@("`@("`@(&EF("AT:&ES+G)E;F1E<E-T871I8RD@
M>PH@("`@("`@("`@("!R971U<FX@;F]D951O9V=L93L*("`@("`@("!]"B`@
M("`@("`@:68@*'1H:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@("`@("`@("`@
M("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=.=6QL3VYL>3L*("`@("`@("`@
M("`@;F]D951O9V=L95LQ72`]("<F;F)S<#LF;F)S<#LG.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9T)L
M86YK.PH@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)R9N8G-P.R9N8G-P
M.R9N8G-P.R<["B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B!N;V1E5&]G
M9VQE.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?<V5T3F]D94EC;VX@/2!F
M=6YC=&EO;BAN;V1E260I"GL*("`@('9A<B!I;6=$:7(@/2`H='EP96]F*'1H
M:7,N;F]D97-;;F]D94ED75LG:6-O;F1I<B==*2`A/2`G=6YD969I;F5D)RD@
M/PH@("`@("`@('1H:7,N;F]D97-;;F]D94ED75LG:6-O;F1I<B==(#H*("`@
M("`@("!T:&ES+FEM9T1I<CL*("`@(&EF("AI;6=$:7(I('L*("`@("`@("!I
M;6=$:7(@*ST@)R\G.PH@("`@?0H*("`@(&EF("AT>7!E;V8H=&AI<RYN;V1E
M<UMN;V1E261=6R=I8V]N)UTI("$]("=U;F1E9FEN960G*2!["B`@("`@("`@
M+R\@3F]D92!H87,@82!U<V5R(&1E9FEN960@:6-O;BX*("`@("`@("!I9B`H
M(71H:7,N;F]D97-;;F]D94ED75LG:6-O;B==*2!["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"B`@("`@("`@:68@*'1Y<&5O9BAT:&ES+FYO
M9&5S6VYO9&5)9%U;)VEC;VYO<&5N)UTI("$]("=U;F1E9FEN960G("8F('1H
M:7,N;F]D97-;;F]D94ED75LG97AP86YD960G72D@>PH@("`@("`@("`@("!I
M;6<@/2!T:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VYO<&5N)UT["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:6UG(#T@=&AI<RYN;V1E<UMN;V1E261=
M6R=I8V]N)UT["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!5
M<V4@<W1A;F1A<F0@:6-O;B!S970N"B`@("`@("`@:68@*'1Y<&5O9BAT:&ES
M+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI("$]("=U;F1E9FEN960G*2![
M"B`@("`@("`@("`@("\O($YO9&4@=VET:"!C:&EL9')E;BX*("`@("`@("`@
M("`@:6UG(#T@*'1H:7,N;F]D97-;;F]D94ED75LG97AP86YD960G72D@/R!T
M:&ES+FEM9T9O;&1E<D]P96X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B!T:&ES+FEM9T9O;&1E<CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!.;V1E(&YO(&-H:6QD<F5N
M+@H@("`@("`@("`@("!I;6<@/2!T:&ES+FEM9TQE868["B`@("`@("`@?0H@
M("`@?0H*("`@('9A<B!I;6=T>'0@/2`G/&EM9R!S<F,](B<@*R!I;6=$:7(@
M*R!I;6<@*R`G(B<["@H@("`@:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)
M9%U;)VEC;VYA;'0G72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!I;6=T
M>'0@*ST@)R!A;'0](B<@*R!T:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VYA;'0G
M72`K("<B)SL*("`@('T*"B`@("!R971U<FX@:6UG='AT("L@)R`O/B`G.PI]
M"@I(;W)D95]4<F5E+G!R;W1O='EP92YT;V=G;&4@/2!F=6YC=&EO;BAN;V1E
M260I"GL*("`@('1H:7,N;F]D97-;;F]D94ED75LG97AP86YD960G72`]("%T
M:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UT["B`@("!I9B`H=&AI<RYN
M;V1E<UMN;V1E261=6R=E>'!A;F1E9"==*2!["B`@("`@("`@:68@*&YO9&4@
M/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G;F]D94-H:6QD<F5N7R<@*R!N
M;V1E260I*2!["B`@("`@("`@("`@(&YO9&4N<W1Y;&4N9&ES<&QA>2`]("=B
M;&]C:R<["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I9B`H;F]D
M92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=N;V1E0VAI;&1R96Y?)R`K
M(&YO9&5)9"DI('L*("`@("`@("`@("`@;F]D92YS='EL92YD:7-P;&%Y(#T@
M)VYO;F4G.PH@("`@("`@('T*("`@('T*"B`@("`O+R!)9B!U<VEN9R!A;'1E
M<FYA=&EN9R!R;W<@<VAA9&EN9RP@=V]R:R!O=70@8V]R<F5C="!S:&%D92X*
M("`@(&EF("AT:&ES+F]P=&EO;G-;)V%L=&5R;F%T92==*2!["B`@("`@("`@
M=&AI<RYS=')I<&4H*3L*("`@('T*"B`@("!N;V1E5&]G9VQE(#T@=&AI<RY?
M9V5T3F]D951O9V=L92AN;V1E260I.PH@("`@:68@*'1O9V=L92`](&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*"=N;V1E5&]G9VQE7R<@*R!N;V1E260I*2![
M"B`@("`@("`@=&]G9VQE+G-R8R`]('1H:7,N:6UG1&ER("L@)R\G("L@;F]D
M951O9V=L95LP73L*("`@("`@("!T;V=G;&4N86QT(#T@;F]D951O9V=L95LQ
M73L*("`@('T*"B`@("!T:&ES+G-A=F53=&%T92AN;V1E260L('1H:7,N;F]D
M97-;;F]D94ED75LG97AP86YD960G72D*?0H*2&]R9&5?5')E92YP<F]T;W1Y
M<&4N<W1R:7!E(#T@9G5N8W1I;VXH*0I["B`@("`O+R!4:&4@96QE;65N="!T
M;R!S=&%R="!S=')I<&EN9RX*("`@('9A<B!I9"`](&%R9W5M96YT<ULP72`_
M(&%R9W5M96YT<ULP72`Z('1H:7,N=&%R9V5T.PH*("`@("\O(%1H92!F;&%G
M('=E)VQL('5S92!T;R!K965P('1R86-K(&]F('=H971H97(@=&AE(&-U<G)E
M;G0@<F]W(&ES"B`@("`O+R!O9&0@;W(@979E;BX*("`@('9A<B!E=F5N(#T@
M87)G=6UE;G1S6S%=(#\@87)G=6UE;G1S6S%=(#H@9F%L<V4["@H@("`@+R\@
M3V)T86EN(&$@<F5F97)E;F-E('1O('1H92!T<F5E('!A<F5N="!E;&5M96YT
M+@H@("`@=F%R('1R964@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI9"D[
M"B`@("!I9B`H(71R964I('L*("`@("`@("!R971U<FX@979E;CL*("`@('T*
M"B`@("`O+R!)=&5R871E(&]V97(@96%C:"!C:&EL9"!D:78N"B`@("!F;W(@
M*'9A<B!I(#T@,#L@:2`\('1R964N8VAI;&1.;V1E<RYL96YG=&@[(&DK*RD@
M>PH@("`@("`@(&EF("AT<F5E+F-H:6QD3F]D97-;:5TN:60N:6YD97A/9B@G
M;F]D94-H:6QD<F5N)RD@(3T@+3$I('L*("`@("`@("`@("`@:68@*'1H:7,N
M;F]D97-;=')E92YC:&EL9$YO9&5S6VE=+FED+G)E<&QA8V4H)VYO9&5#:&EL
M9')E;E\G+"`G)RE=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@("`@("!E
M=F5N(#T@=&AI<RYS=')I<&4H=')E92YC:&EL9$YO9&5S6VE=+FED+"!E=F5N
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M('1R964N8VAI;&1.;V1E<UMI72YC;&%S<TYA;64@/2!T<F5E+F-H:6QD3F]D
M97-;:5TN8VQA<W-.86UE+G)E<&QA8V4H)R!R;W=%=F5N)RP@)R<I+G)E<&QA
M8V4H)R!R;W=/9&0G+"`G)RD["B`@("`@("`@("`@('1R964N8VAI;&1.;V1E
M<UMI72YC;&%S<TYA;64@*ST@979E;B`_("<@<F]W179E;B<@.B`G(')O=T]D
M9"<["@H@("`@("`@("`@("`O+R!&;&EP(&9R;VT@;V1D('1O(&5V96XL(&]R
M('9I8V4M=F5R<V$N"B`@("`@("`@("`@(&5V96X@/2`A979E;CL*("`@("`@
M("!]"B`@("!]"@H@("`@<F5T=7)N(&5V96X["GT*"DAO<F1E7U1R964N<')O
M=&]T>7!E+G-A=F53=&%T92`](&9U;F-T:6]N*&YO9&5)9"P@97AP86YD960I
M"GL*("`@('9A<B!N97=#;V]K:64@/2`G)SL*("`@('9A<B!O;&1#;V]K:64@
M/2!T:&ES+E]G971#;V]K:64H=&AI<RY?:6YS=&%N8V5.86UE("L@)U]E>'!A
M;F1E9"<I.PH@("`@:68@*&5X<&%N9&5D*2!["B`@("`@("`@+R\@17AP86YD
M(')E<75E<W1E9"!S;R!A9&0@=&\@8V]O:VEE+@H@("`@("`@(&YE=T-O;VMI
M92`]("AO;&1#;V]K:64I(#\@;VQD0V]O:VEE("L@)RPG(#H@)R<["B`@("`@
M("`@;F5W0V]O:VEE(#T@;F5W0V]O:VEE("L@;F]D94ED.PH@("`@?2!E;'-E
M('L*("`@("`@("`O+R!#;VQL87!S92!R97%U97-T960@<V\@<F5M;W9E(&9R
M;VT@8V]O:VEE+@H@("`@("`@('9A<B!N;V1E<R`](&]L9$-O;VMI92YS<&QI
M="@G+"<I.PH@("`@("`@('9A<B!N97=.;V1E<R`](&YE=R!!<G)A>2@I.PH@
M("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@;F]D97,N;&5N9W1H.R!I*RLI
M('L*("`@("`@("`@("`@:68@*&YO9&5S6VE=("$](&YO9&5)9"D@>PH@("`@
M("`@("`@("`@("`@;F5W3F]D97-;;F5W3F]D97,N;&5N9W1H72`](&YO9&5S
M6VE=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&YE=T-O;VMI
M92`](&YE=TYO9&5S+FIO:6XH)RPG*3L*("`@('T*("`@('1H:7,N7W-E=$-O
M;VMI92AT:&ES+E]I;G-T86YC94YA;64@*R`G7V5X<&%N9&5D)RP@;F5W0V]O
M:VEE*3L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N7V=E=$-O;VMI92`](&9U
M;F-T:6]N*&YA;64I"GL*("`@('9A<B!D8R`](&1O8W5M96YT+F-O;VMI93L*
M("`@('9A<B!P<F5F:7@@/2!N86UE("L@)SUE>'`G.PH@("`@=F%R(&)E9VEN
M(#T@9&,N:6YD97A/9B@G.R`G("L@<')E9FEX*3L*("`@(&EF("AB96=I;B`]
M/2`M,2D@>PH@("`@("`@(&)E9VEN(#T@9&,N:6YD97A/9BAP<F5F:7@I.PH@
M("`@("`@(&EF("AB96=I;B`A/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G
M)SL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&)E9VEN("L](#([
M"B`@("!]"B`@("!V87(@96YD(#T@9&]C=6UE;G0N8V]O:VEE+FEN9&5X3V8H
M)SLG+"!B96=I;BD["B`@("!I9B`H96YD(#T]("TQ*2!["B`@("`@("`@96YD
M(#T@9&,N;&5N9W1H.PH@("`@?0H@("`@<F5T=7)N('5N97-C87!E*&1C+G-U
M8G-T<FEN9RAB96=I;B`K('!R969I>"YL96YG=&@L(&5N9"DI.PI]"@I(;W)D
M95]4<F5E+G!R;W1O='EP92Y?<V5T0V]O:VEE(#T@9G5N8W1I;VXH;F%M92P@
M=F%L=64I"GL*("`@('9A<B!C=7)#;V]K:64@/2!N86UE("L@)SUE>'`G("L@
M97-C87!E*'9A;'5E*3L*("`@(&-U<D-O;VMI92`K/2`G.T1/34%)3CT\/W!H
M<"!E8VAO("1'3$]"04Q36R=C;VYF)UU;)V-O;VMI92==6R=D;VUA:6XG73L@
M/SX[4$%42#T\/W!H<"!E8VAO("1'3$]"04Q36R=C;VYF)UU;)V-O;VMI92==
M6R=P871H)UT[(#\^.R<["B`@("!D;V-U;65N="YC;V]K:64@/2!C=7)#;V]K
M:64["GT*"DAO<F1E7U1R964N<')O=&]T>7!E+E]C;W)R96-T5VED=&A&;W)3
M8W)O;&QB87(@/2!F=6YC=&EO;B@I"GL*/#]P:'`@:68@*"1'3$]"04Q36R=B
M<F]W<V5R)UTM/FAA<U%U:7)K*"=S8W)O;&QB87)?:6Y?=V%Y)RDI.B`_/@H@
M("`@+R\@0V]R<F5C="!F;W(@9G)A;64@<V-R;VQL8F%R(&EN($E%(&)Y(&1E
M=&5R;6EN:6YG(&EF(&$@<V-R;VQL8F%R(&ES('!R97-E;G0L"B`@("`O+R!A
M;F0@:68@;F]T(')E861J=7-T:6YG('1H92!M87)G:6Y2:6=H="!P<F]P97)T
M>2!T;R`P"B`@("`O+R!3964@:'1T<#HO+W=W=RYX<S1A;&PN;FPO?G!P:R]J
M<R]D;V-T>7!E<RYH=&UL(&9O<B!W:'D@=&AI<R!W;W)K<PH@("`@:68@*&1O
M8W5M96YT+F1O8W5M96YT16QE;65N="YC;&EE;G1(96EG:'0@/3T@9&]C=6UE
M;G0N9&]C=6UE;G1%;&5M96YT+F]F9G-E=$AE:6=H="D@>PH@("`@("`@("\O
M(&YO('-C<F]L;&)A<B!P<F5S96YT+"!T86ME(&%W87D@97AT<F$@;6%R9VEN
M"B`@("`@("`@9&]C=6UE;G0N8F]D>2YS='EL92YM87)G:6Y2:6=H="`]("<P
M)SL*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE;G0N8F]D>2YS='EL92YM
M87)G:6Y2:6=H="`]("<Q-7!X)SL*("`@('T*/#]P:'`@96YD:68[(#\^"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96$N:G,`````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$U,P`Q,#4Q
M-30S,3`V-0`P,C(W,#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=F%R(%]E9&ET;W)?=7)L(#T@(CP_<&AP(&5C:&\@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I(#\^
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82\B.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,U-C(`,3`U,34T,S$P-C4`,#(R
M,C4U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H*=F%R(&1A
M(#T@*&1O8W5M96YT+F%L;"D@/R`Q(#H@,#L*=F%R('!R(#T@*'=I;F1O=RYP
M<FEN="D@/R`Q(#H@,#L*=F%R(&UA8R`]("AN879I9V%T;W(N=7-E<D%G96YT
M+FEN9&5X3V8H(DUA8R(I("$]("TQ*3L*"FEF("AW:6YD;W<N861D179E;G1,
M:7-T96YE<BD@>PH@("`@=VEN9&]W+F%D9$5V96YT3&ES=&5N97(H)VQO860G
M+"!P<FEN=%=I;BP@9F%L<V4I.PI](&5L<V4@:68@*'=I;F1O=RYA='1A8VA%
M=F5N="D@>PH@("`@=VEN9&]W+F%T=&%C:$5V96YT*"=O;FQO860G+"!P<FEN
M=%=I;BD["GT@96QS92!I9B`H=VEN9&]W+F]N;&]A9"`A/2!N=6QL*2!["B`@
M("!V87(@;VQD3VY,;V%D(#T@=VEN9&]W+F]N;&]A9#L*("`@('=I;F1O=RYO
M;FQO860@/2!F=6YC=&EO;BAE*0H@("`@>PH@("`@("`@(&]L9$]N3&]A9"AE
M*3L*("`@("`@("!P<FEN=%=I;B@I.PH@("`@?3L*?2!E;'-E('L*("`@('=I
M;F1O=RYO;FQO860@/2!P<FEN=%=I;CL*?0H*9G5N8W1I;VX@<')I;G17:6XH
M*0I["B`@("!I9B`H<'(I('L*("`@("`@("`O+R!.4S0K+"!)134K"B`@("`@
M("`@=VEN9&]W+G!R:6YT*"D["B`@("!](&5L<V4@:68@*"%M86,I('L*("`@
M("`@("`O+R!)13,@86YD($E%-"!O;B!00PH@("`@("`@(%9"<')I;G17:6XH
M*3L*("`@('T@96QS92!["B`@("`@("`@+R\@979E<GET:&EN9R!E;'-E"B`@
M("`@("`@:&%N9&QE7V5R<F]R*"D["B`@("!]"GT*"G=I;F1O=RYO;F5R<F]R
M(#T@:&%N9&QE7V5R<F]R.PIW:6YD;W<N;VYA9G1E<G!R:6YT(#T@9G5N8W1I
M;VXH*2![=VEN9&]W+F-L;W-E*"E]"@IF=6YC=&EO;B!H86YD;&5?97)R;W(H
M*0I["B`@("!W:6YD;W<N86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="XB*2D@
M/SXG*3L*("`@(')E='5R;B!T<G5E.PI]"@II9B`H(7!R("8F("%M86,I('L*
M("`@(&EF("AD82D@>PH@("`@("`@("\O(%1H:7,@;75S="!B92!)130@;W(@
M9W)E871E<@H@("`@("`@('=B=F5R<R`]("(X.#4V1CDV,2TS-#!!+3$Q1#`M
M03DV0BTP,$,P-$9$-S`U03(B.PH@("`@?2!E;'-E('L*("`@("`@("`O+R!T
M:&ES(&UU<W0@8F4@244S+G@*("`@("`@("!W8G9E<G,@/2`B14%",C)!0S,M
M,S!#,2TQ,4-&+4$W14(M,#`P,$,P-4)!13!"(CL*("`@('T*"B`@("!D;V-U
M;65N="YW<FET92@B/$]"2D5#5"!)1#U<(E="7"(@5TE$5$@]7"(P7"(@2$5)
M1TA4/5PB,%PB($-,05-3240]7")#3%-)1#HB*3L*("`@(&1O8W5M96YT+G=R
M:71E*'=B=F5R<R`K(")<(CX@/"]/0DI%0U0^(BD["GT*"B\O("TM/@H\+W-C
M<FEP=#X*"CQS8W)I<'0@='EP93TB=&5X="]V8G-C<FEP="(^"CPA+2T*"G-U
M8B!W:6YD;W=?;VYU;FQO860*("`@(&]N(&5R<F]R(')E<W5M92!N97AT"B`@
M("`G($IU<W0@=&ED>2!U<"!W:&5N('=E(&QE879E('1O(&)E('-U<F4@=V4@
M87)E;B=T"B`@("`G(&ME97!I;F<@:6YS=&%N8V5S(&]F('1H92!B<F]W<V5R
M(&-O;G1R;VP@:6X@;65M;W)Y"B`@("!S970@5T(@/2!N;W1H:6YG"F5N9"!S
M=6(*"G-U8B!60G!R:6YT5VEN"B`@("!/3$5#341)1%]04DE.5"`](#8*("`@
M(&]N(&5R<F]R(')E<W5M92!N97AT"@H@("`@)R!)130@;V)J96-T(&AA<R!A
M(&1I9F9E<F5N="!C;VUM86YD('-T<G5C='5R90H@("`@:68@9&$@=&AE;@H@
M("`@("`@(&-A;&P@5T(N17AE8U="*$],14--1$E$7U!224Y4+"`Q*0H@("`@
M96QS90H@("`@("`@(&-A;&P@5T(N24]L94-O;6UA;F1487)G970N17AE8RA/
M3$5#341)1%]04DE.5"P@,2P@(B(L("(B*0H@("`@96YD(&EF"F5N9"!S=6(*
M"B<@+2T^"CPO<V-R:7!T/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7VAT;6Q?:&5L<&5R+FIS
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,30W`#$P-3$U-#,Q,#8U`#`R-#0T-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@2&]R9&4@2'1M;"!(96QP97(@2F%V87-C<FEP="!#;&%S<PH@*@H@*B!0
M<F]V:61E<R!T:&4@:F%V87-C<FEP="!C;&%S<R!I;G-E<G0@:'1M;"!T86=S
M(&)Y(&-L:6-K:6YG(&]N(&EC;VYS+@H@*@H@*B!4:&4@:&5L<&5R<R!A=F%I
M;&%B;&4Z"B`J("`@("`@96UO=&EC;VYS("T@9F]R(&EN<V5R=&EN9R!E;6]T
M:6-O;G,@<W1R:6YG<PH@*@H@*B`D2&]R9&4Z(&AO<F1E+W1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?:'1M;%]H96QP97(N:G,L=B`Q+C$R+C(N-2`R,#`V
M+S`U+S$Q(#$Y.C0Y.C$T(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J($!P86-K86=E(&AO<F1E"B`J($!T;V1O(&%D9"!H86YD;&EN9R!F
M;W(@9F]N="!T86=S+"!T86)L97,L(&5T8RX*("HO"@IV87(@=&%R9V5T16QE
M;65N=#L*"F9U;F-T:6]N(&]P96Y(=&UL2&5L<&5R*'1Y<&4L('1A<F=E="D*
M>PH@("`@=F%R(&QA>2`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=H=&UL
M:&5L<&5R7R<@*R!T87)G970I.PH@("`@=&%R9V5T16QE;65N="`](&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E="D["@H@("`@:68@*&QA>2YS='EL
M92YD:7-P;&%Y(#T]("=B;&]C:R<I('L*("`@("`@("!L87DN<W1Y;&4N9&ES
M<&QA>2`]("=N;VYE)SL*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@:68@*&QA>2YF:7)S=$-H:6QD*2!["B`@("`@("`@;&%Y+G)E;6]V94-H
M:6QD*&QA>2YF:7)S=$-H:6QD*3L*("`@('T*"B`@("!V87(@=&%B;&4@/2!D
M;V-U;65N="YC<F5A=&5%;&5M96YT*"=404),12<I.PH@("`@=F%R('1B;V1Y
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$)/1%DG*3L*("`@('1A8FQE
M+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@('1A8FQE+F-E;&Q3<&%C:6YG(#T@
M,#L*("`@('1A8FQE+F)O<F1E<B`](#`["@H@("`@:68@*'1Y<&4@/3T@)V5M
M;W1I8V]N<R<I('L*("`@("`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=44B<I.PH@("`@("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=41"<I.PH@("`@("`@(#P_<&AP(')E<75I<F5?;VYC92`G2&]R9&4O
M5&5X="]&:6QT97(N<&AP)SL@)&9I;'1E<B`](%1E>'1?1FEL=&5R.CIF86-T
M;W)Y*"=E;6]T:6-O;G,G*3L@)&EC;VYS(#T@87)R87E?9FQI<"@D9FEL=&5R
M+3YG971)8V]N<R@I*3L@9F]R96%C:"`H)&EC;VYS(&%S("1I8V]N(#T^("1S
M=')I;F<I.B`_/@H@("`@("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=!)RD["B`@("`@("`@;&EN:RYH<F5F(#T@)R,G.PH@("`@("`@(&QI
M;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH@("`@("`@("`@("!T87)G971%
M;&5M96YT+G9A;'5E(#T@=&%R9V5T16QE;65N="YV86QU92`K("<\/W!H<"!E
M8VAO("1S=')I;F<@/SXG("L@)R`G.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@("`@(&-E;&PN87!P96YD0VAI;&0H;&EN:RD[
M"B`@("`@("`@:6UG(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G24U')RD*
M("`@("`@("!I;6<N<W)C(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I("X@)R]E;6]T:6-O;G,O)R`N
M("1I8V]N("X@)RYP;F<G(#\^)SL*("`@("`@("!I;6<N86QI9VX@/2`G;6ED
M9&QE)SL*("`@("`@("!I;6<N8F]R9&5R(#T@,#L*("`@("`@("!L:6YK+F%P
M<&5N9$-H:6QD*&EM9RD["B`@("`@("`@/#]P:'`@96YD9F]R96%C:#L@/SX*
M("`@("`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["B`@("`@("`@=&)O9'DN
M87!P96YD0VAI;&0H<F]W*3L*("`@("`@("!T86)L92YA<'!E;F1#:&EL9"AT
M8F]D>2D["B`@("!]"@H@("`@;&%Y+F%P<&5N9$-H:6QD*'1A8FQE*3L*("`@
M(&QA>2YS='EL92YD:7-P;&%Y(#T@)V)L;V-K)SL*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S,C0W`#$P-3$U-#,Q
M,#8U`#`R,S<Q-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!V87(@8W5R<F5N=$1A=&4L(&-U<G)E;G1996%R+"!C=7));6=)
M9"P@8W5R<F5N=%1A<F=E=#L*"F9U;F-T:6]N(&]P96Y#86QE;F1A<BAI;6=)
M9"P@=&%R9V5T+"!C86QL8F%C:RD*>PH@("`@:68@*&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*'1A<F=E="`K("=;>65A<ETG*2YV86QU92`F)B!D;V-U;65N
M="YG971%;&5M96YT0GE)9"AT87)G970@*R`G6VUO;G1H72<I+G9A;'5E("8F
M(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E="`K("=;9&%Y72<I+G9A
M;'5E*2!["B`@("`@("`@=F%R(&0@/2!N97<@1&%T92AD;V-U;65N="YG971%
M;&5M96YT0GE)9"AT87)G970@*R`G6WEE87)=)RDN=F%L=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G
M970@*R`G6VUO;G1H72<I+G9A;'5E("T@,2P*("`@("`@("`@("`@("`@("`@
M("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E="`K("=;9&%Y
M72<I+G9A;'5E*3L*("`@('T@96QS92!["B`@("`@("`@=F%R(&0@/2!N97<@
M1&%T92@I.PH@("`@?0H*("`@(&]P96Y';W1O*&0N9V5T5&EM92@I+"!I;6=)
M9"P@=&%R9V5T+"!C86QL8F%C:RD["GT*"F9U;F-T:6]N(&]P96Y';W1O*'1I
M;65S=&%M<"P@:6UG260L('1A<F=E="P@8V%L;&)A8VLI"GL*("`@('9A<B!R
M;W<L(&-E;&PL(&EM9RP@;&EN:RP@9&%Y<SL*"B`@("!C=7)R96YT5&%R9V5T
M(#T@=&%R9V5T.PH*("`@('9A<B!D(#T@;F5W($1A=&4H=&EM97-T86UP*3L*
M("`@(&-U<G)E;G1$871E(#T@9#L*("`@(&UO;G1H(#T@9"YG971-;VYT:"@I
M.PH@("`@8W5R<F5N=%EE87(@/2!D+F=E=%EE87(H*3L*("`@(&EF("AC=7)R
M96YT665A<B`\(#$Y,#`I('L*("`@("`@("!C=7)R96YT665A<B`K/2`Q.3`P
M.PH@("`@?0H@("`@=F%R(&9I<G-T3V9-;VYT:"`](&YE=R!$871E*&-U<G)E
M;G1996%R+"!M;VYT:"P@,2D["B`@("!V87(@9&EF9B`](&9I<G-T3V9-;VYT
M:"YG971$87DH*2`M(#$["B`@("!I9B`H9&EF9B`]/2`M,2D@>PH@("`@("`@
M(&1I9F8@/2`V.PH@("`@?0H@("`@<W=I=&-H("AM;VYT:"D@>PH@("`@8V%S
M92`S.@H@("`@8V%S92`U.@H@("`@8V%S92`X.@H@("`@8V%S92`Q,#H*("`@
M("`@("!D87ES(#T@,S`["B`@("`@("`@8G)E86L["@H@("`@8V%S92`Q.@H@
M("`@("`@(&EF("AC=7)R96YT665A<B`E(#0@/3T@,"`F)B`H8W5R<F5N=%EE
M87(@)2`Q,#`@(3T@,"!\?"!C=7)R96YT665A<B`E(#0P,"`]/2`P*2D@>PH@
M("`@("`@("`@("!D87ES(#T@,CD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@9&%Y<R`](#(X.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*"B`@
M("!D969A=6QT.@H@("`@("`@(&1A>7,@/2`S,3L*("`@("`@("!B<F5A:SL*
M("`@('T*"B`@("!V87(@=V1A>7,@/2!;"B`@("`@("`@)SP_<&AP(&5C:&\@
M7R@B36\B*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B5'4B*2`_/B<L
M"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B5V4B*2`_/B<L"B`@("`@("`@)SP_
M<&AP(&5C:&\@7R@B5&@B*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B
M1G(B*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B4V$B*2`_/B<L"B`@
M("`@("`@)SP_<&AP(&5C:&\@7R@B4W4B*2`_/B<*("`@(%T["B`@("!V87(@
M;6]N=&AS(#T@6PH@("`@("`@("<\/W!H<"!E8VAO(%\H(DIA;G5A<GDB*2`_
M/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B1F5B<G5A<GDB*2`_/B<L"B`@
M("`@("`@)SP_<&AP(&5C:&\@7R@B36%R8V@B*2`_/B<L"B`@("`@("`@)SP_
M<&AP(&5C:&\@7R@B07!R:6PB*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@
M7R@B36%Y(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(DIU;F4B*2`_
M/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B2G5L>2(I(#\^)RP*("`@("`@
M("`G/#]P:'`@96-H;R!?*")!=6=U<W0B*2`_/B<L"B`@("`@("`@)SP_<&AP
M(&5C:&\@7R@B4V5P=&5M8F5R(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO
M(%\H(D]C=&]B97(B*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B3F]V
M96UB97(B*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B1&5C96UB97(B
M*2`_/B<*("`@(%T["@H@("`@=F%R(&QA>65R(#T@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)V=O=&\G*3L*("`@(&EF("AL87EE<BYF:7)S=$-H:6QD*2![
M"B`@("`@("`@;&%Y97(N<F5M;W9E0VAI;&0H;&%Y97(N9FER<W1#:&EL9"D[
M"B`@("!]"@H@("`@=F%R('1A8FQE(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@G5$%"3$4G*3L*("`@('9A<B!T8F]D>2`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H)U1"3T19)RD["B`@("!T86)L92YA<'!E;F1#:&EL9"AT8F]D>2D[
M"B`@("!T86)L92YC;&%S<TYA;64@/2`G:71E;2<["B`@("!T86)L92YC96QL
M4W!A8VEN9R`](#`["B`@("!T86)L92YC96QL4&%D9&EN9R`](#(["B`@("!T
M86)L92YB;W)D97(@/2`P.PH@("`@=&%B;&4N<W1Y;&4N=VED=&@@/2`G875T
M;R<["@H@("`@+R\@5&ET;&4@8F%R+@H@("`@<F]W(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@G5%(G*3L*("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*"=41"<I.PH@("`@8V5L;"YC;VQ3<&%N(#T@-SL*("`@(&-E;&PN
M86QI9VX@/2`G<FEG:'0G.PH@("`@8V5L;"YC;&%S<TYA;64@/2`G:&5A9&5R
M)SL*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=!)RD["B`@
M("!L:6YK+FAR968@/2`G(R<["B`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO
M;B@I"B`@("!["B`@("`@("`@=F%R(&QA>65R(#T@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)V=O=&\G*3L*("`@("`@("!L87EE<BYS='EL92YV:7-I8FEL
M:71Y(#T@)VAI9&1E;B<["B`@("`@("`@:68@*&QA>65R+F9I<G-T0VAI;&0I
M('L*("`@("`@("`@("`@;&%Y97(N<F5M;W9E0VAI;&0H;&%Y97(N9FER<W1#
M:&EL9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M("`@(&EM9R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("!I
M;6<N<W)C(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M=$EM86=E1&ER*"=H;W)D92<I(#\^+V-L;W-E+G!N9R<["B`@("!I;6<N8F]R
M9&5R(#T@,#L*("`@(&QI;FLN87!P96YD0VAI;&0H:6UG*3L*("`@(&-E;&PN
M87!P96YD0VAI;&0H;&EN:RD["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D[
M"B`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH*("`@("\O(%EE87(N"B`@
M("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=44B<I.PH@("`@8V5L
M;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C96QL+F%L
M:6=N(#T@)VQE9G0G.PH@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE
M;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]("<C)SL*("`@(&QI;FLN;VYC;&EC
M:R`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!N97=$871E(#T@;F5W($1A
M=&4H8W5R<F5N=%EE87(@+2`Q+"!C=7)R96YT1&%T92YG971-;VYT:"@I+"`Q
M*3L*("`@("`@("!O<&5N1V]T;RAN97=$871E+F=E=%1I;64H*2P@:6UG260L
M(&-U<G)E;G1487)G970L(&-A;&QB86-K*3L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"B`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@:6UG
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@
M/2`G/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$
M:7(H)VAO<F1E)RD@/SXO;F%V+VQE9G0N<&YG)SL*("`@(&EM9RYA;&EG;B`]
M("=M:61D;&4G.PH@("`@:6UG+F)O<F1E<B`](#`["B`@("!L:6YK+F%P<&5N
M9$-H:6QD*&EM9RD["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["@H@("`@
M8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C96QL
M+F-O;%-P86X@/2`U.PH@("`@8V5L;"YA;&EG;B`]("=C96YT97(G.PH@("`@
M=F%R('D@/2!D;V-U;65N="YC<F5A=&5497AT3F]D92AC=7)R96YT665A<BD[
M"B`@("!C96QL+F%P<&5N9$-H:6QD*'DI.PH@("`@<F]W+F%P<&5N9$-H:6QD
M*&-E;&PI.PH*("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=4
M1"<I.PH@("`@8V5L;"YA;&EG;B`]("=R:6=H="<["B`@("!L:6YK(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@;&EN:RYH<F5F(#T@)R,G
M.PH@("`@;&EN:RYO;F-L:6-K(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@
M(&YE=T1A=&4@/2!N97<@1&%T92AC=7)R96YT665A<B`K(#$L(&-U<G)E;G1$
M871E+F=E=$UO;G1H*"DL(#$I.PH@("`@("`@(&]P96Y';W1O*&YE=T1A=&4N
M9V5T5&EM92@I+"!I;6=)9"P@8W5R<F5N=%1A<F=E="P@8V%L;&)A8VLI.PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@(&-E;&PN87!P96YD0VAI
M;&0H;&EN:RD["B`@("!I;6<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=)
M34<G*0H@("`@:6UG+G-R8R`]("<\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`_/B]N878O<FEG:'0N<&YG
M)SL*("`@(&EM9RYA;&EG;B`]("=M:61D;&4G.PH@("`@:6UG+F)O<F1E<B`]
M(#`["B`@("!L:6YK+F%P<&5N9$-H:6QD*&EM9RD["B`@("!R;W<N87!P96YD
M0VAI;&0H8V5L;"D["B`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH*("`@
M("\O($UO;G1H(&YA;64N"B`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=44B<I.PH@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M)U1$)RD["B`@("!C96QL+F%L:6=N(#T@)VQE9G0G.PH@("`@;&EN:R`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]("<C
M)SL*("`@(&QI;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D*("`@('L*("`@("`@
M("!V87(@;F5W36]N=&@@/2!C=7)R96YT1&%T92YG971-;VYT:"@I("T@,3L*
M("`@("`@("!V87(@;F5W665A<B`](&-U<G)E;G1996%R.PH@("`@("`@(&EF
M("AN97=-;VYT:"`]/2`M,2D@>PH@("`@("`@("`@("!N97=-;VYT:"`](#$Q
M.PH@("`@("`@("`@("!N97=996%R("T](#$["B`@("`@("`@?0H@("`@("`@
M(&YE=T1A=&4@/2!N97<@1&%T92AN97=996%R+"!N97=-;VYT:"P@,2D["B`@
M("`@("`@;W!E;D=O=&\H;F5W1&%T92YG9714:6UE*"DL(&EM9TED+"!C=7)R
M96YT5&%R9V5T+"!C86QL8F%C:RD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@(&EM9R`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("!I;6<N<W)C(#T@)SP_
M<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H
M;W)D92<I(#\^+VYA=B]L969T+G!N9R<["B`@("!I;6<N86QI9VX@/2`G;6ED
M9&QE)SL*("`@(&EM9RYB;W)D97(@/2`P.PH@("`@;&EN:RYA<'!E;F1#:&EL
M9"AI;6<I.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH*("`@(&-E;&P@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YC;VQ3
M<&%N(#T@-3L*("`@(&-E;&PN86QI9VX@/2`G8V5N=&5R)SL*("`@('9A<B!M
M(#T@9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H;6]N=&AS6VUO;G1H72D["B`@
M("!C96QL+F%P<&5N9$-H:6QD*&TI.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E
M;&PI.PH*("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I
M.PH@("`@8V5L;"YA;&EG;B`]("=R:6=H="<["B`@("!L:6YK(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@G02<I.PH@("`@;&EN:RYH<F5F(#T@)R,G.PH@
M("`@;&EN:RYO;F-L:6-K(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@(&YE
M=T1A=&4@/2!N97<@1&%T92AC=7)R96YT665A<BP@8W5R<F5N=$1A=&4N9V5T
M36]N=&@H*2`K(#$L(#$I.PH@("`@("`@(&]P96Y';W1O*&YE=T1A=&4N9V5T
M5&EM92@I+"!I;6=)9"P@8W5R<F5N=%1A<F=E="P@8V%L;&)A8VLI.PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*("`@(&-E;&PN87!P96YD0VAI;&0H
M;&EN:RD["B`@("!I;6<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=)34<G
M*0H@("`@:6UG+G-R8R`]("<\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG971);6%G941I<B@G:&]R9&4G*2`_/B]N878O<FEG:'0N<&YG)SL*
M("`@(&EM9RYA;&EG;B`]("=M:61D;&4G.PH@("`@:6UG+F)O<F1E<B`](#`[
M"B`@("!L:6YK+F%P<&5N9$-H:6QD*&EM9RD["B`@("!R;W<N87!P96YD0VAI
M;&0H8V5L;"D["B`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH*("`@("\O
M(%=E96MD87ES+@H@("`@<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G
M5%(G*3L*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@-SL@:2LK*2!["B`@("`@
M("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("`@
M("`@=V5E:V1A>2`](&1O8W5M96YT+F-R96%T951E>'1.;V1E*'=D87ES6VE=
M*3L*("`@("`@("!C96QL+F%P<&5N9$-H:6QD*'=E96MD87DI.PH@("`@("`@
M(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@('T*("`@('1B;V1Y+F%P<&5N
M9$-H:6QD*')O=RD["@H@("`@+R\@4F]W<RX*("`@('9A<B!W965K+"!I=&%L
M:6,["B`@("!V87(@8V]U;G0@/2`Q.PH@("`@=F%R('1O9&%Y(#T@;F5W($1A
M=&4H*3L*("`@('9A<B!T:&ES665A<B`]('1O9&%Y+F=E=%EE87(H*3L*("`@
M(&EF("AT:&ES665A<B`\(#$Y,#`I('L*("`@("`@("!T:&ES665A<B`K/2`Q
M.3`P.PH@("`@?0H*("`@('9A<B!O9&0@/2!T<G5E.PH@("`@9F]R("AV87(@
M:2`](#$[(&D@/#T@9&%Y<SL@:2LK*2!["B`@("`@("`@:68@*&-O=6YT(#T]
M(#$I('L*("`@("`@("`@("`@<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@G5%(G*3L*("`@("`@("`@("`@<F]W+F%L:6=N(#T@)W)I9VAT)SL*("`@
M("`@("`@("`@:68@*&]D9"D@>PH@("`@("`@("`@("`@("`@<F]W+F-L87-S
M3F%M92`]("=I=&5M,"<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R;W<N8VQA<W-.86UE(#T@)VET96TQ)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!O9&0@/2`A;V1D.PH@("`@("`@('T*("`@("`@("!I
M9B`H:2`]/2`Q*2!["B`@("`@("`@("`@(&9O<B`H=F%R(&H@/2`P.R!J(#P@
M9&EF9CL@:BLK*2!["B`@("`@("`@("`@("`@("!C96QL(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@G5$0G*3L*("`@("`@("`@("`@("`@(')O=RYA<'!E
M;F1#:&EL9"AC96QL*3L*("`@("`@("`@("`@("`@(&-O=6YT*RL["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@8V5L;"`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H)U1$)RD["B`@("`@("`@:68@*'1H:7-996%R(#T](&-U
M<G)E;G1996%R("8F"B`@("`@("`@("`@('1O9&%Y+F=E=$UO;G1H*"D@/3T@
M;6]N=&@@)B8*("`@("`@("`@("`@=&]D87DN9V5T1&%T92@I(#T](&DI('L*
M("`@("`@("`@("`@8V5L;"YS='EL92YB;W)D97(@/2`G,7!X('-O;&ED(')E
M9"<["B`@("`@("`@?0H*("`@("`@("!L:6YK(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@G02<I.PH@("`@("`@(&-E;&PN87!P96YD0VAI;&0H;&EN:RD[
M"@H@("`@("`@(&QI;FLN:')E9B`](&D["B`@("`@("`@;&EN:RYO;F-L:6-K
M(#T@9G5N8W1I;VXH*0H@("`@("`@('L*("`@("`@("`@("`@=F%R(&1A>2`]
M('1H:7,N:')E9CL*("`@("`@("`@("`@=VAI;&4@*&1A>2YI;F1E>$]F*"<O
M)RD@(3T@+3$I('L*("`@("`@("`@("`@("`@(&1A>2`](&1A>2YS=6)S=')I
M;F<H9&%Y+FEN9&5X3V8H)R\G*2`K(#$I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!S971396QE8W1686QU92AD;V-U;65N="YG971%;&5M96YT0GE)
M9"AC=7)R96YT5&%R9V5T("L@)UMY96%R72<I+"!C=7)R96YT665A<BD["B`@
M("`@("`@("`@('-E=%-E;&5C=%9A;'5E*&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*&-U<G)E;G1487)G970@*R`G6VUO;G1H72<I+"!C=7)R96YT1&%T92YG
M971-;VYT:"@I("L@,2D["B`@("`@("`@("`@('-E=%-E;&5C=%9A;'5E*&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*&-U<G)E;G1487)G970@*R`G6V1A>5TG
M*2P@9&%Y*3L*"B`@("`@("`@("`@('9A<B!L87EE<B`](&1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*"=G;W1O)RD["B`@("`@("`@("`@(&QA>65R+G-T>6QE
M+G9I<VEB:6QI='D@/2`G:&ED9&5N)SL*("`@("`@("`@("`@:68@*&QA>65R
M+F9I<G-T0VAI;&0I('L*("`@("`@("`@("`@("`@(&QA>65R+G)E;6]V94-H
M:6QD*&QA>65R+F9I<G-T0VAI;&0I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H8V%L;&)A8VLI('L*("`@("`@("`@("`@("`@(&5V86PH8V%L
M;&)A8VLI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!D87D@/2!D;V-U;65N="YC<F5A=&54
M97AT3F]D92AI*3L*("`@("`@("!L:6YK+F%P<&5N9$-H:6QD*&1A>2D["@H@
M("`@("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@("`@("!I9B`H8V]U
M;G0@/3T@-RD@>PH@("`@("`@("`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I
M.PH@("`@("`@("`@("!C;W5N="`](#`["B`@("`@("`@?0H@("`@("`@(&-O
M=6YT*RL["B`@("!]"B`@("!I9B`H8V]U;G0@/B`Q*2!["B`@("`@("`@9F]R
M("AI(#T@8V]U;G0[(&D@/#T@-SL@:2LK*2!["B`@("`@("`@("`@(&-E;&P@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@("`@("`@("!R
M;W<N87!P96YD0VAI;&0H8V5L;"D["B`@("`@("`@?0H@("`@("`@('1B;V1Y
M+F%P<&5N9$-H:6QD*')O=RD["B`@("!]"@H@("`@:68@*&-U<DEM9TED("$]
M(&EM9TED*2!["B`@("`@("`@+R\@5V4G<F4@<VAO=VEN9R!T:&ES('!O<'5P
M(&9O<B!T:&4@9FER<W0@=&EM92P@<V\@=')Y('1O"B`@("`@("`@+R\@<&]S
M:71I;VX@:70@;F5X="!T;R!T:&4@:6UA9V4@86YC:&]R+@H@("`@("`@('9A
M<B!E;"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&EM9TED*3L*("`@("`@
M("!V87(@<"`](&=E=$%B<V]L=71E4&]S:71I;VXH96PI.PH*("`@("`@("!L
M87EE<BYS='EL92YL969T(#T@<"YX("L@)W!X)SL*("`@("`@("!L87EE<BYS
M='EL92YT;W`@/2!P+GD@*R`G<'@G.PH@("`@?0H*("`@(&-U<DEM9TED(#T@
M:6UG260["B`@("!L87EE<BYA<'!E;F1#:&EL9"AT86)L92D["@H@("`@;&%Y
M97(N<W1Y;&4N9&ES<&QA>2`]("=B;&]C:R<["B`@("!L87EE<BYS='EL92YV
M:7-I8FEL:71Y(#T@)W9I<VEB;&4G.PI]"@IF=6YC=&EO;B!G971!8G-O;'5T
M95!O<VET:6]N*&5L*0I["B`@("!V87(@<B`]('MX.B!E;"YO9F9S971,969T
M+"!Y.B!E;"YO9F9S9714;W!].PH@("`@:68@*&5L+F]F9G-E=%!A<F5N="D@
M>PH@("`@("`@('9A<B!T;7`@/2!G971!8G-O;'5T95!O<VET:6]N*&5L+F]F
M9G-E=%!A<F5N="D["B`@("`@("`@<BYX("L]('1M<"YX.PH@("`@("`@('(N
M>2`K/2!T;7`N>3L*("`@('T*("`@(')E='5R;B!R.PI]"@IF=6YC=&EO;B!S
M971396QE8W1686QU92AS96QE8W0L('9A;'5E*0I["B`@("!S96QE8W0N=F%L
M=64@/2!V86QU93L*("`@(&EF("AS96QE8W0N=F%L=64@(3T@=F%L=64I('L*
M("`@("`@("!F;W(@*&D@/2`P.R!I(#P@<V5L96-T+F]P=&EO;G,N;&5N9W1H
M.R!I*RLI('L*("`@("`@("`@("`@:68@*'-E;&5C="YO<'1I;VYS6VE=+G9A
M;'5E(#T]('9A;'5E*2!["B`@("`@("`@("`@("`@("!S96QE8W0N<V5L96-T
M961);F1E>"`](&D["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!R971U<FX@9F%L<V4[
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]K97EB:6YD:6YG
M<RYJ<P```````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-S(P`#$P-3$U-#,Q,#8U
M`#`R,S0R-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*BH*("H@2F%V87-C<FEP="!L:6)R87)Y('1O(&AA;F1L92!A('-E
M="!O9B!K97EB:6YD:6YG<RX*("H*("H@5&AE('5S97(@<VAO=6QD(&EN8VQU
M9&4@=&AI<R!S8W)I<'0L(&%N9"!T:&5N(&-A;&P@<V5T2V5Y8FEN9&EN9RAK
M97DL"B`J(&-A;&QB86-K*2!F;W(@96%C:"!K97EB:6YD:6YG('1H870@:7,@
M9&5S:7)E9"X@5&AI<R!S8W)I<'0@=VEL;"!T86ME(&-A<F4*("H@;V8@;&ES
M=&5N:6YG(&9O<B!K97EP<F5S<V5S(&%N9"!M87!P:6YG('1H96T@=&\@=&AE
M(&-A;&QB86-K(&9U;F-T:6]N<RP@;W(*("H@9&]I;F<@;F]T:&EN9R!I9B!N
M;R!C86QL8F%C:R!I<R!S970N"B`J"B`J("1(;W)D93H@:&]R9&4O=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:V5Y8FEN9&EN9W,N:G,L=B`Q+C4N-"XV(#(P,#8O
M,#,O,C0@,38Z,#4Z,C0@8VAU8VL@17AP("0*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!P86-K86=E($AO<F1E"B`J+PH*+RHJ"B`J($$@:&%S:"!O9B!K97EB:6YD
M:6YG<RX*("H*("H@0'9A<B!?:V5Y36%P"B`J+PIV87(@7VME>4UA<"`](&YE
M=R!!<G)A>2@I.PH*+RHJ"B`J(%-E="!U<"!T:&4@:V5Y<')E<W,@;&ES=&5N
M97(N"B`J+PII9B`H='EP96]F(&1O8W5M96YT+F-A<'1U<F5%=F5N=',@(3T@
M)W5N9&5F:6YE9"<I('L*("`@(&1O8W5M96YT+F-A<'1U<F5%=F5N=',H179E
M;G0N2T594%)%4U,I.PH@("`@9&]C=6UE;G0N;VYK97EP<F5S<R`](&ME>4AA
M;F1L97(["GT@96QS92!["B`@("!D;V-U;65N="YO;FME>61O=VX@/2!K97E(
M86YD;&5R.PI]"@HO*BH*("H@4V5T<R!U<"!A(&-A;&QB86-K(&9O<B!A(&ME
M>6-O9&4N"B`J"B`J($!P87)A;2!K97D@("`@("`@5&AE(&ME>6-O9&4@=&\@
M=')I9V=E<B!O;BX*("H@0'!A<F%M(&-A;&QB86-K("!4:&4@9G5N8W1I;VX@
M=&\@8V%L;"!W:&5N(")K97DB(&ES('!R97-S960N(%-H;W5L9"!B92!A"B`J
M("`@("`@("`@("`@("`@("`@9G5N8W1I;VXN($ET(&=E=',@=&AE(&5V96YT
M(&%N9"!T:&4@:V5Y8V]D92!A<R!P87)A;65T97)S+`H@*B`@("`@("`@("`@
M("`@("`@('-O('1H870@>6]U(&-A;B!U<V4@;VYE(&9U;F-T:6]N('1O(&AA
M;F1L92!M=6QT:7!L92!K97ES(&EF"B`J("`@("`@("`@("`@("`@("`@>6]U
M(&QI:V4N"B`J+PIF=6YC=&EO;B!S971+97EB:6YD:6YG*&ME>2P@8V%L;&)A
M8VLI"GL*("`@(&EF("AT>7!E;V8@7VME>4UA<%MK97E=(#T]("=U;F1E9FEN
M960G*2!["B`@("`@("`@7VME>4UA<%MK97E=(#T@6UT["B`@("!]"@H@("`@
M:68@*'1Y<&5O9B!C86QL8F%C:R`]/2`G9G5N8W1I;VXG*2!["B`@("`@("`@
M7VME>4UA<%MK97E=+G!U<V@H8V%L;&)A8VLI.PH@("`@?2!E;'-E('L*("`@
M("`@("!?:V5Y36%P6VME>5TN<'5S:"AN97<@1G5N8W1I;VXH)V4G+"`G:V5Y
M)RP@8V%L;&)A8VL@*R`G*&4L(&ME>2D[)RDI.PH@("`@?0I]"@HO*BH*("H@
M26YV;VME9"!B>2!T:&4@2F%V85-C<FEP="!E=F5N="!M;V1E;"!W:&5N(&$@
M:V5Y(&ES('!R97-S960N($=E=',*("H@=&AE(&ME>6-O9&4@*&%T=&5M<'1S
M('1O(&AA;F1L92!A;&P@8G)O=W-E<G,I(&%N9"!L;V]K<R!T;R!S964@:68*
M("H@=V4@:&%V92!A(&AA;F1L97(@9&5F:6YE9"!F;W(@=&AA="!K97DN($EF
M('-O+"!C86QL(&ET+@H@*@H@*B!`<&%R86T@92`@5&AE(&5V96YT('1O(&AA
M;F1L92X@4VAO=6QD(&)E(&$@:V5Y<')E<W,N"B`J+PIF=6YC=&EO;B!K97E(
M86YD;&5R*&4I"GL*("`@('9A<B!E(#T@92!\?"!W:6YD;W<N979E;G0["@H@
M("`@:68@*&4N:V5Y0V]D92D@>PH@("`@("`@(&ME>2`](&4N:V5Y0V]D93L*
M("`@('T@96QS92!I9B`H92YW:&EC:"D@>PH@("`@("`@(&ME>2`](&4N=VAI
M8V@["B`@("!]"@H@("`@+RH@268@=&AE<F4G<R!A(&AA;F1L97(@9&5F:6YE
M9"!F;W(@=&AE(&ME>2!T:&%T('=A<R!P<F5S<V5D+"!C86QL"B`@("`@*B!I
M="P@<&%S<VEN9R!I;B!T:&4@:V5Y8V]D92!A;F0@=&AE(&5V96YT+B`J+PH@
M("`@:68@*%]K97E-87!;:V5Y72D@>PH@("`@("`@(&9O<B`H=F%R(&D@/2`P
M.R!I(#P@7VME>4UA<%MK97E=+FQE;F=T:#L@*RMI*2!["B`@("`@("`@("`@
M(&EF("A?:V5Y36%P6VME>5U;:5TH92P@:V5Y*2D@>PH@("`@("`@("`@("`@
M("`@92YR971U<FY686QU92`](&9A;'-E.PH@("`@("`@("`@("`@("`@:68@
M*'1Y<&5O9B!E+G!R979E;G1$969A=6QT(#T]("=F=6YC=&EO;B<I('L*("`@
M("`@("`@("`@("`@("`@("!E+G!R979E;G1$969A=6QT*"D["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&4N<F5T=7)N
M5F%L=64@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"GT*````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<P``````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3<V
M`#$P-3$U-#,Q,#8U`#`R,S0Q-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<RQV(#$N-2`R,#`T+S`X+S(V
M(#`P.C`W.C(Y('-L=7-A<GH@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&4*
M("HO"F9U;F-T:6]N('1O9V=L95%U;W1E0FQO8VLH:60L(&QI;F5S*0I["B`@
M("!V87(@8FQO8VL@/2!N97<@2&]R9&5?2&ED96%B;&4H)W%B7R<@*R!I9"D[
M"@H@("`@8FQO8VLN=&]G9VQE*"D["B`@("!T97AT(#T@9&]C=6UE;G0N8W)E
M871E5&5X=$YO9&4H8FQO8VLN<VAO=VXH*2`_"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)SP_<&AP(&5C:&\@7R@B6TAI9&4@475O=&5D
M(%1E>'1=(BD@/SXG(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/#]P:'`@96-H;R!?*");4VAO=R!1=6]T960@5&5X="`M(BD@/SX@
M)R`K(&QI;F5S("L@)R`\/W!H<"!E8VAO(%\H(FQI;F5S72(I(#\^)RD["B`@
M("!L:6YK(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@;&EN
M:RYH<F5F(#T@)R<["B`@("!L:6YK+F-L87-S3F%M92`]("=W:61G970G.PH@
M("`@;&EN:RYS='EL92YF;VYT4VEZ92`]("<W,"4G.PH@("`@;&EN:RYO;F-L
M:6-K(#T@9G5N8W1I;VXH*2!["B`@("`@("`@=&]G9VQE475O=&5";&]C:RAI
M9"P@;&EN97,I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@(&QI
M;FLN87!P96YD0VAI;&0H=&5X="D["@H@("`@=F%R('1O9V=L92`](&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*"=Q=%\G("L@:60I.PH@("`@:68@*'1O9V=L
M92YF:7)S=$-H:6QD*2!["B`@("`@("`@=&]G9VQE+G)E;6]V94-H:6QD*'1O
M9V=L92YF:7)S=$-H:6QD*3L*("`@('T*("`@('1O9V=L92YA<'!E;F1#:&EL
M9"AL:6YK*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(R-34R`#$P-3$U-#,Q,#8U`#`R,S<Q-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!(5$U,07)E82Y),3A.(#T@>PH*"2\O
M('1H92!F;VQL;W=I;F<@<VAO=6QD(&)E('1H92!F:6QE;F%M92!W:71H;W5T
M("YJ<R!E>'1E;G-I;VX*"2\O(&ET('=I;&P@8F4@=7-E9"!F;W(@875T;VUA
M=&EC86QL>2!L;V%D('!L=6=I;B!L86YG=6%G92X*"6QA;F<Z(")E;B(L"@H)
M=&]O;'1I<',Z('L*"0EB;VQD.B`@("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")";VQD(BDI(#\^(BP*"0EI=&%L:6,Z("`@("`@("`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*"))=&%L:6,B*2D@/SXB+`H)"75N9&5R
M;&EN93H@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5N9&5R;&EN
M92(I*2`_/B(L"@D)<W1R:6ME=&AR;W5G:#H@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B4W1R:6ME=&AR;W5G:"(I*2`_/B(L"@D)<W5B<V-R:7!T.B`@
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W5B<V-R:7!T(BDI(#\^
M(BP*"0ES=7!E<G-C<FEP=#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")3=7!E<G-C<FEP="(I*2`_/B(L"@D):G5S=&EF>6QE9G0Z("`@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!,969T(BDI(#\^(BP*"0EJ
M=7-T:69Y8V5N=&5R.B`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T
M:69Y($-E;G1E<B(I*2`_/B(L"@D):G5S=&EF>7)I9VAT.B`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!2:6=H="(I*2`_/B(L"@D):G5S
M=&EF>69U;&PZ("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF
M>2!&=6QL(BDI(#\^(BP*"0EO<F1E<F5D;&ES=#H@("`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")/<F1E<F5D($QI<W0B*2D@/SXB+`H)"75N;W)D97)E
M9&QI<W0Z("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)U;&QE=&5D($QI
M<W0B*2D@/SXB+`H)"6]U=&1E;G0Z("`@("`@("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D1E8W)E87-E($EN9&5N="(I*2`_/B(L"@D):6YD96YT.B`@
M("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YC<F5A<V4@26YD
M96YT(BDI(#\^(BP*"0EF;W)E8V]L;W(Z("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")&;VYT($-O;&]R(BDI(#\^(BP*"0EH:6QI=&5C;VQO<CH@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")"86-K9W)O=6YD($-O;&]R
M(BDI(#\^(BP*"0EI;G-E<G1H;W)I>F]N=&%L<G5L93H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")(;W)I>F]N=&%L(%)U;&4B*2D@/SXB+`H)"6-R96%T
M96QI;FLZ("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!7
M96(@3&EN:R(I*2`_/B(L"@D):6YS97)T:6UA9V4Z("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B26YS97)T+TUO9&EF>2!);6%G92(I*2`_/B(L"@D)
M:6YS97)T=&%B;&4Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS
M97)T(%1A8FQE(BDI(#\^(BP*"0EH=&UL;6]D93H@("`@("`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")4;V=G;&4@2%1-3"!3;W5R8V4B*2D@/SXB+`H)
M"7!O<'5P961I=&]R.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D5N
M;&%R9V4@161I=&]R(BDI(#\^(BP*"0EA8F]U=#H@("`@("`@("`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")!8F]U="!T:&ES(&5D:71O<B(I*2`_/B(L
M"@D)<VAO=VAE;'`Z("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M2&5L<"!U<VEN9R!E9&ET;W(B*2D@/SXB+`H)"71E>'1I;F1I8V%T;W(Z("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-U<G)E;G0@<W1Y;&4B*2D@/SXB
M+`H)"75N9&\Z("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(BDI(#\^(BP*"0ER961O.B`@("`@
M("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")2961O97,@>6]U<B!L
M87-T(&%C=&EO;B(I*2`_/B(L"@D)8W5T.B`@("`@("`@("`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B0W5T('-E;&5C=&EO;B(I*2`_/B(L"@D)8V]P
M>3H@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V]P>2!S
M96QE8W1I;VXB*2D@/SXB+`H)"7!A<W1E.B`@("`@("`@("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E!A<W1E(&9R;VT@8VQI<&)O87)D(BDI(#\^(BP*
M"0EL969T=&]R:6=H=#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H="(I*2`_/B(L"@D)<FEG:'1T;VQE9G0Z
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0B*2D@/SXB+`H)"7)E;6]V969O<FUA=#H@("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E)E;6]V92!F;W)M871T:6YG(BDI(#\^(BP*"0EP
M<FEN=#H@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0<FEN
M="!D;V-U;65N="(I*2`_/B(L"@D):VEL;'=O<F0Z("`@("`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B0VQE87(@35-/9F9I8V4@=&%G<R(I*2`_/B(*
M"7TL"@H)8G5T=&]N<SH@>PH)"2)O:R(Z("`@("`@("`@("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D]+(BDI(#\^(BP*"0DB8V%N8V5L(CH@("`@("`@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#86YC96PB*2D@/SXB"@E]+`H*
M"6US9SH@>PH)"2)0871H(CH@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E!A=&@B*2D@/SXB+`H)"2)415A47TU/1$4B.B`@("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(I
M*2`_/B(L"@H)"2))12US=6-K<RUF=6QL+7-C<F5E;B(@.@H)"2\O('1R86YS
M;&%T92!H97)E"@D)(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N(BDI(#\^(BP*"@D)(DUO>BU#;&EP8F]A<F0B(#H*
M"0DB/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"XB*2D@/SXB"@E]+`H*"61I86QO9W,Z('L*"0DO+R!#;VUM;VX*"0DB3TLB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D]+(BDI(#\^(BP*"0DB
M0V%N8V5L(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-A;F-E;"(I*2`_
M/B(L"@H)"2)!;&EG;FUE;G0Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QI
M9VYM96YT.B(I*2`_/B(L"@D)(DYO="!S970B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*").;W0@<V5T(BDI(#\^(BP*"0DB3&5F="(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(DQE9G0B*2D@/SXB+`H)"2)2:6=H="(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B4FEG:'0B*2D@/SXB+`H)"2)497AT=&]P
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&5X='1O<"(I*2`_/B(L"@D)
M(D%B<VUI9&1L92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")!8G-M:61D;&4B
M*2D@/SXB+`H)"2)"87-E;&EN92(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M0F%S96QI;F4B*2D@/SXB+`H)"2)!8G-B;W1T;VTB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B06)S8F]T=&]M(BDI(#\^(BP*"0DB0F]T=&]M(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D)O='1O;2(I*2`_/B(L"@D)(DUI9&1L92(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")-:61D;&4B*2D@/SXB+`H)"2)4
M;W`B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&]P(BDI(#\^(BP*
M"@D)(DQA>6]U="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),87EO=70B
M*2D@/SXB+`H)"2)3<&%C:6YG(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M4W!A8VEN9R(I*2`_/B(L"@D)(DAO<FEZ;VYT86PZ(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")(;W)I>F]N=&%L.B(I*2`_/B(L"@D)(DAO<FEZ;VYT86P@<&%D
M9&EN9R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")(;W)I>F]N=&%L('!A9&1I;F<B*2D@/SXB
M+`H)"2)697)T:6-A;#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5F5R=&EC
M86PZ(BDI(#\^(BP*"0DB5F5R=&EC86P@<&%D9&EN9R(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E9E<G1I8V%L('!A9&1I;F<B*2D@/SXB+`H)"2)";W)D97(@=&AI8VMN
M97-S.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0F]R9&5R('1H:6-K;F5S<SHB*2D@/SXB
M+`H)"2),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(B`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&5A=F4@
M96UP='D@9F]R(&YO(&)O<F1E<B(I*2`_/B(L"@H)"2\O($EN<V5R="!,:6YK
M"@D)(DEN<V5R="]-;V1I9GD@3&EN:R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0O
M36]D:69Y($QI;FLB*2D@/SXB+`H)"2).;VYE("AU<V4@:6UP;&EC:70I(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B3F]N92`H=7-E(&EM<&QI8VET*2(I*2`_/B(L"@D)(DYE
M=R!W:6YD;W<@*%]B;&%N:RDB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*").97<@=VEN9&]W("A?
M8FQA;FLI(BDI(#\^(BP*"0DB4V%M92!F<F%M92`H7W-E;&8I(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E-A;64@9G)A;64@*%]S96QF*2(I*2`_/B(L"@D)(E1O<"!F<F%M
M92`H7W1O<"DB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4;W`@9G)A;64@*%]T;W`I(BDI
M(#\^(BP*"0DB3W1H97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D]T
M:&5R(BDI(#\^(BP*"0DB5&%R9V5T.B(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E1A<F=E=#HB*2D@/SXB+`H)"2)4:71L92`H=&]O;'1I<"DZ(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B5&ET;&4@*'1O;VQT:7`I.B(I*2`_/B(L"@D)(E523#HB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")54DPZ(BDI(#\^(BP*"0DB
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O(B`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(I*2`_/B(L
M"@D)+R\@26YS97)T(%1A8FQE"@D)(DEN<V5R="!486)L92(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"));G-E<G0@5&%B;&4B*2D@/SXB+`H)"2)2;W=S.B(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F]W<SHB*2D@/SXB+`H)"2).=6UB
M97(@;V8@<F]W<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3G5M8F5R(&]F(')O=W,B
M*2D@/SXB+`H)"2)#;VQS.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M0V]L<SHB*2D@/SXB+`H)"2).=6UB97(@;V8@8V]L=6UN<R(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B3G5M8F5R(&]F(&-O;'5M;G,B*2D@/SXB+`H)"2)7:61T:#HB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5VED=&@Z(BDI(#\^(BP*"0DB5VED
M=&@@;V8@=&AE('1A8FQE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E=I9'1H(&]F('1H92!T
M86)L92(I*2`_/B(L"@D)(E!E<F-E;G0B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")097)C96YT(BDI(#\^(BP*"0DB4&EX96QS(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(E!I>&5L<R(I*2`_/B(L"@D)(D5M(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")%;2(I*2`_/B(L"@D)(E=I9'1H('5N:70B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")7:61T:"!U;FET(BDI(#\^(BP*"0DB
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B*2D@/SXB+`H)"2)#96QL('-P86-I;F<Z(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B0V5L;"!S<&%C:6YG.B(I*2`_/B(L"@D)(E-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',B("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS(BDI(#\^(BP*"0DB0V5L;"!P861D:6YG.B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D-E;&P@<&%D9&EN9SHB*2D@/SXB+`H)"2)3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(B`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(I*2`_/B(L"@D)+R\@26YS97)T($EM
M86=E"@D)(DEN<V5R="!);6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E
M<G0@26UA9V4B*2D@/SXB+`H)"2));6%G92!54DPZ(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B26UA9V4@55),.B(I*2`_/B(L"@D)(D5N=&5R('1H92!I;6%G
M92!54DP@:&5R92(@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B
M*2D@/SXB+`H)"2)0<F5V:65W(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M4')E=FEE=R(I*2`_/B(L"@D)(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=R(@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B*2D@
M/SXB+`H)"2)!;'1E<FYA=&4@=&5X=#HB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QT
M97)N871E('1E>'0Z(BDI(#\^(BP*"0DB1F]R(&)R;W=S97)S('1H870@9&]N
M)W0@<W5P<&]R="!I;6%G97,B("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S(BDI(#\^(BP*"0DB4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B*2D@/SXB+`H)"2))
M;6%G92!0<F5V:65W.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26UA9V4@4')E=FEE
M=SHB*2D@/SXB"@E]"GT["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS```````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#(Q-0`Q,#4Q-30S,3`V-0`P
M,C4T-C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'
M.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@
M:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3
M.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@24X@
M5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I
M;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX
M($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB
M;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T
M871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I#;VYT97AT365N
M=2Y),3A.(#T@>PH)+R\@271E;7,@=&AA="!A<'!E87(@:6X@;65N=2X@(%!L
M96%S92!N;W1E('1H870@86X@=6YD97)S8V]R92`H7RD*"2\O(&-H87)A8W1E
M<B!I;B!T:&4@=')A;G-L871I;VX@*')I9VAT(&-O;'5M;BD@=VEL;"!C875S
M92!T:&4@9F]L;&]W:6YG"@DO+R!L971T97(@=&\@8F5C;VUE('5N9&5R;&EN
M960@86YD(&)E('-H;W)T8W5T(&9O<B!T:&%T(&UE;G4@;W!T:6]N+@H*"2)#
M=70B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-U="(I*2`_
M/B(L"@DB0V]P>2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#
M;W!Y(BDI(#\^(BP*"2)087-T92(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E!A<W1E(BDI(#\^(BP*"2));6%G92!0<F]P97)T:65S(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E]);6%G92!0<F]P97)T:65S+BXN(BDI(#\^(BP*
M"2)-;V1I9GD@3&EN:R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E]-;V1I
M9GD@3&EN:RXN+B(I*2`_/B(L"@DB0VAE8VL@3&EN:R(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")#:&5C7VL@3&EN:RXN+B(I*2`_/B(L"@DB4F5M;W9E
M($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")?4F5M;W9E($QI;FLN
M+BXB*2D@/SXB+`H)(D-E;&P@4')O<&5R=&EE<R(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0U]E;&P@4')O<&5R=&EE<RXN+B(I*2`_/B(L"@DB4F]W(%!R;W!E
M<G1I97,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")2;U]W(%!R;W!E<G1I97,N
M+BXB*2D@/SXB+`H)(DEN<V5R="!2;W<@0F5F;W)E(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B25]N<V5R="!2;W<@0F5F;W)E(BDI(#\^(BP*"2));G-E<G0@4F]W
M($%F=&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN7W-E<G0@4F]W($%F=&5R
M(BDI(#\^(BP*"2)$96QE=&4@4F]W(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E]$96QE=&4@4F]W(BDI(#\^(BP*"2)$96QE=&4@0V5L;"(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D1E;&5T92!#96QL(BDI(#\^(BP*"2)486)L
M92!0<F]P97)T:65S(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E]486)L92!0<F]P
M97)T:65S+BXN(BDI(#\^(BP*"2));G-E<G0@0V]L=6UN($)E9F]R92(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DEN<V5R="!?0V]L=6UN($)E9F]R92(I*2`_/B(L"@DB
M26YS97)T($-O;'5M;B!!9G1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@
M0U]O;'5M;B!!9G1E<B(I*2`_/B(L"@DB1&5L971E($-O;'5M;B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")$95]L971E($-O;'5M;B(I*2`_/B(L"@DB2G5S
M=&EF>2!,969T(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T:69Y($QE
M9G0B*2D@/SXB+`H)(DIU<W1I9GD@0V5N=&5R(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B2G5S=&EF>2!#96YT97(B*2D@/SXB+`H)(DIU<W1I9GD@4FEG:'0B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!2:6=H="(I*2`_/B(L
M"@DB2G5S=&EF>2!&=6QL(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T
M:69Y($9U;&PB*2D@/SXB+`H)(DUA:V4@;&EN:R(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B36%K92!L:6Y?:RXN+B(I*2`_/B(L"@DB4F5M;W9E('1H
M92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")296UO=F4@=&AE(BDI(#\^
M(BP*"2)%;&5M96YT(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D5L
M96UE;G0N+BXB*2D@/SXB+`H)(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B26YS97)T('!A<F%G<F%P:"!B969O<F4B*2D@/SXB+`H)
M(DEN<V5R="!P87)A9W)A<&@@869T97(B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T
M('!A<F%G<F%P:"!A9G1E<B(I*2`_/B(L"@H)+R\@3W1H97(@;&%B96QS("AT
M;V]L=&EP<R!A;F0@86QE<G0O8V]N9FER;2!B;W@@;65S<V%G97,I"@H)(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#HB("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(I
M*2`_/B(L"@DB4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(BDI(#\^(BP*
M"2)(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DAO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(BDI(#\^(BP*"2)3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(BDI(#\^(BP*"2)-;V1I9GD@55),
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DUO9&EF>2!54DPB*2D@/SXB
M+`H)(D-U<G)E;G0@55),(&ES(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0W5R
M<F5N="!54DP@:7,B*2D@/SXB+`H)(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<B("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=R(I*2`_/B(L"@DB4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+B(@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N(BDI(#\^(BP*"2),:6YK('!O:6YT<R!T;SHB("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(DQI;FL@<&]I;G1S('1O.B(I*2`_/B(L"@DB56YL
M:6YK('1H92!C=7)R96YT(&5L96UE;G0B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N="(I*2`_/B(L"@DB4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R(@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(BDI(#\^(BP*"2)3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R(I*2`_/B(L"@DB26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE(B`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B*2D@/SXB+`H)(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE(B`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4B*2D@/SXB+`H)(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B1&5L971E('1H92!C=7)R96YT(')O=R(I*2`_/B(L"@DB4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9R(I*2`_/B(L"@DB26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(B`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B*2D@/SXB+`H)(DEN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(B`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B*2D@/SXB+`H)(D1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6XB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(I*2`_/B(L"@DB0W)E871E(&$@;&EN:R(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")#<F5A=&4@82!L:6YK(BDI(#\^(BP*"2));G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D92(I*2`_/B(L"@DB26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D92(I*2`_/B(*?3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO````
M````````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-C4`,#$W-S$S`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8P``````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3`S,0`Q,#4Q-30S,3`V-0`P,C$S-#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&1I=B!I9#TB;65N
M=2(^"B`\:#$@8VQA<W,](FQE9G1&;&]A="(^/#]P:'`@<')I;G1F*%\H(E=E
M;&-O;64L("5S(BDL(&AT;6QS<&5C:6%L8VAA<G,H)&9U;&QN86UE*2D@/SX\
M+V@Q/@H@/&1I=B!C;&%S<STB<FEG:'1&;&]A="(^"CP_<&AP"B1M96YU(#T@
M)FYE=R!-96YU*"D["B1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"=S97)V:6-E<R]P;W)T86PO)RDL(%\H(DAO7VUE(BDL("=H;W)D92YP;F<G
M*3L*:68@*"$D<')E9G,M/FES3&]C:V5D*"=P;W)T86Q?;&%Y;W5T)RDI('L*
M("`@("1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E
M<R]P;W)T86PO961I="YP:'`G*2P@7R@B3&%?>6]U="(I+"`G;&%Y;W5T+G!N
M9R<I.PI]"FEF("A!=71H.CII<T%D;6EN*"DI('L*("`@("1M96YU+3YA9&0H
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B\G*2P@7R@B7T%D;6EN:7-T
M<F%T:6]N(BDL("=A9&UI;FES=')A=&EO;BYP;F<G*3L*?0IE8VAO("1M96YU
M+3YR96YD97(H*3L*/SX*(#PO9&EV/@H\+V1I=CX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8P``````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S0S,@`Q,#4Q-30S,3`V-0`P,C$S,S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/'1A8FQE
M(&-L87-S/2)N;W!A9&1I;F<B(&-E;&QS<&%C:6YG/2(V(B!W:61T:#TB,3`P
M)2(^"CP_<&AP"B1R;W=S(#T@)&QA>6]U="T^<F]W<R@I.PIL:7-T*"1C=7)R
M96YT7W)O=RP@)&-U<G)E;G1?8V]L*2`]("1L87EO=70M/F=E=$-U<G)E;G1"
M;&]C:R@I.PHD86QL;W=?861D(#T@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG
M<&5R;7-D96YI960G72D@?'P*("`@("`@("`@("`@("!(;W)D93HZ:&%S4&5R
M;6ES<VEO;B@G;6%X7V)L;V-K<R<I(#T]/2!T<G5E('Q\"B`@("`@("`@("`@
M("`@2&]R9&4Z.FAA<U!E<FUI<W-I;VXH)VUA>%]B;&]C:W,G*2`^("1L87EO
M=70M/F-O=6YT*"DI.PHD8V]L=6UN<R`](#`["F9O<B`H)')O=R`](#`[("1R
M;W<@/"`D<F]W<SL@*RLD<F]W*3H*/SX*("`\='(^"CP_<&AP"B1C;VQU;6YS
M(#T@)&QA>6]U="T^8V]L=6UN<R@D<F]W*3L*:68@*&ES7V$H)&-O;'5M;G,L
M("=014%27T5R<F]R)RDI('L*("`@("1C;VQU;6YS(#T@,#L*?0IF;W(@*"1C
M;VP@/2`P.R`D8V]L(#P@)&-O;'5M;G,[("LK)&-O;"DZ"B`@("`D:7-%9&ET
M:6YG(#T@*"1C=7)R96YT7W)O=R`]/3T@)')O=R`F)B`D8W5R<F5N=%]C;VP@
M/3T]("1C;VPI.PH@("`@:68@*"1L87EO=70M/FES0V]V97)E9"@D<F]W+"`D
M8V]L*2DZ"C\^"B`@("`\(2TM(&-O=F5R960@8V5L;"!H97)E("TM/@H\/W!H
M<"!E;'-E.B`_/@H@("`@/'1D(&-L87-S/2(\/W!H<"!E8VAO("1I<T5D:71I
M;F<@/R`G8W5R<F5N=$)L;V-K)R`Z("=H96%D97)B;W@G(#\^(B!V86QI9VX]
M(G1O<"(@=VED=&@](CP_<&AP(&5C:&\@9FQO;W(H,3`P("\@*"1C;VQU;6YS
M("L@,2DI(#\^)2(@<F]W<W!A;CTB/#]P:'`@96-H;R`D;&%Y;W5T+3YG971(
M96EG:'0H)')O=RP@)&-O;"D@/SXB(&-O;'-P86X](CP_<&AP(&5C:&\@)&QA
M>6]U="T^9V5T5VED=&@H)')O=RP@)&-O;"D@/SXB/@H\/W!H<`HD8FQO8VM)
M;F9O(#T@)&QA>6]U="T^9V5T0FQO8VM);F9O*"1R;W<L("1C;VPI.PII9B`H
M(21L87EO=70M/FES16UP='DH)')O=RP@)&-O;"D@)B8@(6ES7V$H)&)L;V-K
M26YF;RP@)U!%05)?17)R;W(G*2D@>PH@("`@:68@*"1I<T5D:71I;F<I('L*
M("`@("`@("`D961I=%]L:6YK(#T@)R9N8G-P.R<["B`@("!](&5L<V4@>PH@
M("`@("`@("1E9&ET7VQI;FL@/2`G/'-M86QL/B<@+B!(;W)D93HZ;&EN:R@D
M;&%Y;W5T+3YG971!8W1I;VY5<FPH)V5D:70G+"`D<F]W+"`D8V]L*2D@+B!?
M*")E9&ET(BD@+B`G/"]A/CPO<VUA;&P^)SL*("`@('T*("`@(')E<75I<F4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+VQA>6]U="YI;F,G.PI](&5L<V4@>PH@
M("`@:68@*"1A;&QO=U]A9&0I('L*("`@("`@("!R97%U:7)E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]A9&0N:6YC)SL*("`@('T*?0H_/@H@("`@/"]T9#X*
M/#]P:'`@96YD:68[(&5N9&9O<CL@:68@*"1A;&QO=U]A9&0I.B`_/@H@("`@
M/'1D('9A;&EG;CTB=&]P(B!C;&%S<STB:&5A9&5R8F]X(CX*("`@("`@/#]P
M:'`@<F5Q=6ER92!D:7)N86UE*%]?1DE,15]?*2`N("<O861D+FEN8R<[(#\^
M"B`@("`\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`\+W1R/@H\/W!H<"!E;F1F
M;W([(&EF("@D86QL;W=?861D*3H@/SX*("`\='(^"CP_<&AP"F9O<B`H)&-O
M;"`](#`[("1C;VP@/#T@)&-O;'5M;G,[("LK)&-O;"DZ"C\^"B`@("`\=&0@
M=F%L:6=N/2)T;W`B(&-L87-S/2)H96%D97)B;W@B/@H@("`@("`\/W!H<"!R
M97%U:7)E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]A9&0N:6YC)SL@/SX*("`@
M(#PO=&0^"CP_<&AP(&5N9&9O<CL@/SX*("`\+W1R/@H\/W!H<"!E;F1I9CL@
M/SX*/"]T86)L93X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,38Q,C8`,3`U,34T,S$P-C4`,#(R,#(R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#QD:78@:60](F5X
M<&%N9&5D4VED96)A<B(@<W1Y;&4](F]V97)F;&]W.FAI9&1E;B(^"B`\9&EV
M(&ED/2)M96YU(B!S='EL93TB;W9E<F9L;W<Z:&ED9&5N(CX*("`\/W!H<"!I
M9B`H(65M<'1Y*"1C;VYF6R=L;V=O)UU;)VEM86=E)UTI('Q\("%5=&EL.CIG
M971&;W)M1&%T82@G;6]Z8F%R)RDI.B`_/@H@(#QS<&%N(&-L87-S/2)L969T
M1FQO870B/#]P:'`@:68@*&5M<'1Y*"1C;VYF6R=L;V=O)UU;)VEM86=E)UTI
M*2!E8VAO("<@:60](G1H96UE;&]G;R(G(#\^/@H@(#P_<&AP"B`@:68@*"%E
M;7!T>2@D8V]N9ELG;&]G;R==6R=I;6%G92==*2D@>PH@("`@("!I9B`H(65M
M<'1Y*"1C;VYF6R=L;V=O)UU;)VQI;FLG72DI('L*("`@("`@("`@(&5C:&\@
M2&]R9&4Z.FQI;FLH)&-O;F9;)VQO9V\G75LG;&EN:R==+"!N=6QL+"!N=6QL
M+"`G7W1O<"<I.PH@("`@("!]"B`@("`@(&5C:&\@2&]R9&4Z.FEM9R@D8V]N
M9ELG;&]G;R==6R=I;6%G92==+"`G)RP@)R<L("<G*3L*("`@("`@:68@*"%E
M;7!T>2@D8V]N9ELG;&]G;R==6R=L:6YK)UTI*2!["B`@("`@("`@("!E8VAO
M("<\+V$^)SL*("`@("`@?0H@('T@96QS92!["B`@("`@(&5C:&\@)R9N8G-P
M.R<["B`@?0H@(#\^"B`@/"]S<&%N/@H@(#QS<&%N(&-L87-S/2)L969T1FQO
M870B(&ED/2)L;V=O<&%D(CXF;F)S<#L\+W-P86X^"B`@/&1I=B!C;&%S<STB
M8VQE87(B/B9N8G-P.SPO9&EV/@H@(#P_<&AP(&5N9&EF.R`_/@H@/"]D:78^
M"B`\<W!A;B!I9#TB97AP86YD0G5T=&]N(B!C;&%S<STB<FEG:'1&;&]A="(^
M/#]P:'`@:68@*"$D:7-?;6]Z8F%R*2!E8VAO($AO<F1E.CIL:6YK*"<C)RP@
M7R@B0V]L;&%P<V4@4VED96)A<B(I+"`G)RP@)R<L("=T;V=G;&5-96YU1G)A
M;64H*3L@<F5T=7)N(&9A;'-E.R<L(%\H(D-O;&QA<'-E(%-I9&5B87(B*2D@
M+B!(;W)D93HZ:6UG*"=H:61E7W!A;F5L+G!N9R<I("X@)SPO83XG(#\^/"]S
M<&%N/@H@/&1I=B!I9#TB<VED96)A<E!A;F5L(CX*("`\/W!H<"`D=')E92T^
M<F5N9&5R5')E92@I(#\^"B`\+V1I=CX*"CPA+2T@;F5W<V9E961S("TM/@H\
M<V-R:7!T(&QA;F=U86=E/2)J879A<V-R:7!T(B!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@ID;V-U;65N="YW<FET92@G/'-C<FEP="!L86YG=6%G93TB:F%V
M87-C<FEP="(@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](FAT='`Z+R\G
M"B`@("`K(&QO8V%T:6]N+FAO<W1N86UE("L@)SHX.#@P+VIA=F%S8W)I<'0O
M;F5W<V9E961S+FIS+G!H<"(^/"\G("L@)W-C<FEP=#Y<;B<I.PH\+W-C<FEP
M=#X*/'-C<FEP="!L86YG=6%G93TB:F%V87-C<FEP="(@='EP93TB=&5X="]J
M879A<V-R:7!T(CX*9G5N8W1I;VX@8W)E871E0V]O:VEE*&YA;64L=F%L=64L
M9&%Y<RD@>PH@(&EF("AD87ES*2!["B`@("!V87(@9&%T92`](&YE=R!$871E
M*"D["B`@("!D871E+G-E=%1I;64H9&%T92YG9714:6UE*"DK*&1A>7,J,C0J
M-C`J-C`J,3`P,"DI.PH@("`@=F%R(&5X<&ER97,@/2`B.R!E>'!I<F5S/2(K
M9&%T92YT;T=-5%-T<FEN9R@I.PH@('T*("!E;'-E('9A<B!E>'!I<F5S(#T@
M(B(["B`@9&]C=6UE;G0N8V]O:VEE(#T@;F%M92LB/2(K=F%L=64K97AP:7)E
M<RLB.R!P871H/2\B.PI]"@IF=6YC=&EO;B!R96%D0V]O:VEE*&YA;64I('L*
M("!V87(@;F%M9451(#T@;F%M92`K("(](CL*("!V87(@8V$@/2!D;V-U;65N
M="YC;V]K:64N<W!L:70H)SLG*3L*("!F;W(H=F%R(&D],#MI(#P@8V$N;&5N
M9W1H.VDK*RD@>PH@("`@=F%R(&,@/2!C85MI73L*("`@('=H:6QE("AC+F-H
M87)!="@P*3T])R`G*2!C(#T@8RYS=6)S=')I;F<H,2QC+FQE;F=T:"D["B`@
M("!I9B`H8RYI;F1E>$]F*&YA;65%42D@/3T@,"D@<F5T=7)N(&,N<W5B<W1R
M:6YG*&YA;65%42YL96YG=&@L8RYL96YG=&@I.PH@('T*("!R971U<FX@;G5L
M;#L*?0H*9G5N8W1I;VX@97)A<V5#;V]K:64H;F%M92D@>PH@(&-R96%T94-O
M;VMI92AN86UE+"(B+"TQ*3L*?0IF=6YC=&EO;B!H87-#;&%S<RAE;&5M96YT
M+"!C;&%S<TYA;64I"GL*("`@('9A<B!C;&%S<V5S(#T@96QE;65N="YC;&%S
M<TYA;64N<W!L:70H)R`G*3L*("!F;W(@*'9A<B!I(&EN(&-L87-S97,I('L*
M("`@(&EF("AC;&%S<V5S6VE=(#T](&-L87-S3F%M92D*("`@("`@<F5T=7)N
M('1R=64["B`@?0H@(')E='5R;B!F86QS93L*?0H*9G5N8W1I;VX@861D0VQA
M<W,H96QE;65N="P@8VQA<W-.86UE*0I["B`@:68@*"%H87-#;&%S<RAE;&5M
M96YT+"!C;&%S<TYA;64I*0H@("`@96QE;65N="YC;&%S<TYA;64@/2`H96QE
M;65N="YC;&%S<TYA;64@/3T@)R<@/R!C;&%S<TYA;64@.B!E;&5M96YT+F-L
M87-S3F%M92`K("<@)R`K(&-L87-S3F%M92D["GT*"F9U;F-T:6]N(')E;6]V
M94-L87-S*&5L96UE;G0L(&-L87-S3F%M92D*>PH@('9A<B!N97=686QU92`]
M("<G.PH@("`@=F%R(&-L87-S97,@/2!E;&5M96YT+F-L87-S3F%M92YS<&QI
M="@G("<I.PH@(&9O<B`H=F%R(&D@:6X@8VQA<W-E<RD@>PH@("`@:68@*&-L
M87-S97-;:5T@(3T@8VQA<W-.86UE*0H@("`@("!N97=686QU92`K/2!N97=6
M86QU92YL96YG=&@@/R`G("<@*R!C;&%S<V5S6VE=(#H@8VQA<W-E<UMI73L*
M("!]"B`@96QE;65N="YC;&%S<TYA;64@/2!N97=686QU93L*?0H*"F9U;F-T
M:6]N($Y&8V]L;&%P<V5,:7-T*"D@>PH@('9A<B!.1F-O;G1E;G0@/2!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@G3D9C;VYT96YT)RD*("!I9B`H=VEN9&]W
M+DY&;W!E;BD@>PH@("`@861D0VQA<W,@*$Y&8V]N=&5N="P@)TY&8VQO<V4G
M*3L*("`@(')E;6]V94-L87-S("A.1F-O;G1E;G0L("=.1F]P96XG*3L*("`@
M(&-R96%T94-O;VMI92@G<&QE<VM?;F5W<V9E961?=FES:6)L92<L("=F86QS
M92<L(#,P*3L*("`@('=I;F1O=RY.1F]P96X@/2!F86QS93L*("!](&5L<V4@
M>PH@("`@:68@*"%W:6YD;W<N87)T:6-L92D*("`@("`@3D9G971,:7-T*"D[
M"B`@("!A9&1#;&%S<R`H3D9C;VYT96YT+"`G3D9O<&5N)RD["B`@("!R96UO
M=F5#;&%S<R`H3D9C;VYT96YT+"`G3D9C;&]S92<I.PH@("`@8W)E871E0V]O
M:VEE*"=P;&5S:U]N97=S9F5E9%]V:7-I8FQE)RP@)W1R=64G+"`S,"D["B`@
M("!W:6YD;W<N3D9O<&5N(#T@=')U93L*("!]"GT*:68@*'=I;F1O=RY.97=S
M1F5E9',I('L*("!W:6YD;W<N3D9O<&5N(#T@*')E861#;V]K:64H)W!L97-K
M7VYE=W-F965D7W9I<VEB;&4G*2`]/2`G9F%L<V4G*2`_(&9A;'-E(#H@=')U
M93L*("!D;V-U;65N="YW<FET92@G/&1I=B!I9#TB3D9C;VYT96YT(B!C;&%S
M<STB<VED96)A<E!A;F5L("<@*R`H3D9O<&5N(#\@)TY&;W!E;B<@.B`G3D9C
M;&]S92<I("LG(CXG*3L*("!D;V-U;65N="YW<FET92@G/'1A8FQE(&-E;&QS
M<&%C:6YG/2(P(B!C96QL<&%D9&EN9STB(B!W:61T:#TB,3`P)2(@8F]R9&5R
M/2(P(B!C;&%S<STB<VED96)A<DAE861E<B(^/'1B;V1Y/B<I.PH@(&1O8W5M
M96YT+G=R:71E*"<\='(^)RD["B`@9&]C=6UE;G0N=W)I=&4H)SQT9"!C;&%S
M<STB:&5A9&5R5&ET;&4B/CP_<&AP(&5C:&\@7R@G5&]P($YE=W,G*3L@/SX\
M+W1D/B<I.PH@(&1O8W5M96YT+G=R:71E*"<\=&0@8VQA<W,](FAE861E<D)U
M='1O;G,B/CQA(&AR968](FIA=F%S8W)I<'0Z3D9G971,:7-T*"D[(B!C;&%S
M<STB8G1N+7)E9G)E<V@B('1I=&QE/2(\/W!H<"!E8VAO(%\H)U)E9G)E<V@G
M*3L@/SXB/CQS<&%N/CP_<&AP(&5C:&\@7R@G4F5F<F5S:"<I.R`_/CPO<W!A
M;CX\+V$^/&$@:')E9CTB:F%V87-C<FEP=#I.1F-O;&QA<'-E3&ES="@I.R(@
M8VQA<W,](F)T;BUO<&5N+6-L;W-E(B!T:71L93TB/#]P:'`@96-H;R!?*"=/
M<&5N+T-L;W-E)RD[(#\^(CX\<W!A;CX\/W!H<"!E8VAO(%\H)T]P96XO0VQO
M<V4G*3L@/SX\+W-P86X^/"]A/CPO=&0^)RD["B`@9&]C=6UE;G0N=W)I=&4H
M)SPO='(^)RD["B`@9&]C=6UE;G0N=W)I=&4H)SPO=&)O9'D^/"]T86)L93XG
M*3L*("!D;V-U;65N="YW<FET92@G/&1I=B!I9#TB;F5W<T9E961S(CX\+V1I
M=CXG*3L*("!D;V-U;65N="YW<FET92@G/"]D:78^)RD["B`@:68@*'=I;F1O
M=RY.1F]P96X@)B8@<F5A9$-O;VMI92@G:&]R9&5?<VED96)A<E]E>'!A;F1E
M9"<I("$]("=F86QS92<I"B`@("!.1F=E=$QI<W0H*3L*?0H\+W-C<FEP=#X*
M/"$M+2`O;F5W<V9E961S("TM/@H\+V1I=CX*"CQD:78@:60](FAI9&1E;E-I
M9&5B87(B/@H@/&1I=B!I9#TB;65N=2(^"B`\+V1I=CX*("`\/W!H<"!E8VAO
M($AO<F1E.CIL:6YK*"<C)RP@)R<L("<G+"`G)RP@)W1O9V=L94UE;G5&<F%M
M92@I.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=S:&]W7W!A;F5L
M+G!N9R<I("X@)SPO83XG(#\^"CPO9&EV/@H*/'-C<FEP="!T>7!E/2)T97AT
M+VIA=F%S8W)I<'0B/@H*=F%R(')T;"`](#P_<&AP(&5C:&\@)')T;"`_("=T
M<G5E)R`Z("=F86QS92<@/SX["G9A<B!E>'!A;F1E9%-I9&5B87(@/2!N97<@
M2&]R9&5?2&ED96%B;&4H)V5X<&%N9&5D4VED96)A<B<I.PIV87(@:&ED9&5N
M4VED96)A<B`](&YE=R!(;W)D95](:61E86)L92@G:&ED9&5N4VED96)A<B<I
M.PIH:61D96Y3:61E8F%R+FAI9&4H*3L*"F9U;F-T:6]N(&=E=$-O;VMI92AN
M86UE+"!D969L="D*>PH@("`@=F%R(&1C(#T@9&]C=6UE;G0N8V]O:VEE.PH@
M("`@=F%R('!R969I>"`](&YA;64@*R`G/2<["B`@("!V87(@8F5G:6X@/2!D
M8RYI;F1E>$]F*"<[("<@*R!P<F5F:7@I.PH@("`@:68@*&)E9VEN(#T]("TQ
M*2!["B`@("`@("`@8F5G:6X@/2!D8RYI;F1E>$]F*'!R969I>"D["B`@("`@
M("`@:68@*&)E9VEN("$](#`I('L*("`@("`@("`@("`@<F5T=7)N(&1E9FQT
M.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@8F5G:6X@*ST@,CL*
M("`@('T*("`@('9A<B!E;F0@/2!D;V-U;65N="YC;V]K:64N:6YD97A/9B@G
M.R<L(&)E9VEN*3L*("`@(&EF("AE;F0@/3T@+3$I('L*("`@("`@("!E;F0@
M/2!D8RYL96YG=&@["B`@("!]"B`@("!R971U<FX@=6YE<V-A<&4H9&,N<W5B
M<W1R:6YG*&)E9VEN("L@<')E9FEX+FQE;F=T:"P@96YD*2D["GT*"F9U;F-T
M:6]N('1O9V=L94UE;G5&<F%M92@I"GL*("`@(&EF("AP87)E;G0@)B8@<&%R
M96YT+F1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=H9B<I*2!["B`@("`@("`@
M:68@*&5X<&%N9&5D4VED96)A<BYS:&]W;B@I*2!["B`@("`@("`@("`@('!A
M<F5N="YD;V-U;65N="YG971%;&5M96YT0GE)9"@G:&8G*2YC;VQS(#T@<G1L
M(#\@)RHL,C`G(#H@)S(P+"HG.PH@("`@("`@("`@("!E>'!A;F1E9%-I9&5B
M87(N:&ED92@I.PH@("`@("`@("`@("!H:61D96Y3:61E8F%R+G-H;W<H*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P87)E;G0N9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)VAF)RDN8V]L<R`]("AR=&P@/R`G*BPG(#H@)R<I
M("L@/#]P:'`@96-H;R`H:7-S970H)'!R969S*2`_("1P<F5F<RT^9V5T5F%L
M=64H)W-I9&5B87)?=VED=&@G*2`Z(#$U,"D@/SX@*R`H<G1L(#\@)R<@.B`G
M+"HG*3L*("`@("`@("`@("`@:68@*'=I;F1O=RY.1F]P96X@)B8@(7=I;F1O
M=RYA<G1I8VQE*0H@("`@("`@("`@("`@($Y&9V5T3&ES="@I.PH@("`@("`@
M("`@("!H:61D96Y3:61E8F%R+FAI9&4H*3L*("`@("`@("`@("`@97AP86YD
M9613:61E8F%R+G-H;W<H*3L*("`@("`@("!]"@H@("`@("`@("\O($5X<&ER
M92!I;B!O;F4@>65A<BX*("`@("`@("!V87(@97AP:7)E<R`](&YE=R!$871E
M*"D["B`@("`@("`@97AP:7)E<RYS9714:6UE*&5X<&ER97,N9V5T5&EM92@I
M("L@,S$U,S8P,#`P,#`I.PH@("`@("`@(&1O8W5M96YT+F-O;VMI92`]("=H
M;W)D95]S:61E8F%R7V5X<&%N9&5D/2<@*R!E>'!A;F1E9%-I9&5B87(N<VAO
M=VXH*2`K("<[1$]-04E./3P_<&AP(&5C:&\@)$=,3T)!3%-;)V-O;F8G75LG
M8V]O:VEE)UU;)V1O;6%I;B==(#\^.U!!5$@]/#]P:'`@96-H;R`D1TQ/0D%,
M4ULG8V]N9B==6R=C;V]K:64G75LG<&%T:"==(#\^.V5X<&ER97,])R`K(&5X
M<&ER97,N=&]'3513=')I;F<H*3L*("`@('T*?0H*:68@*&=E=$-O;VMI92@G
M:&]R9&5?<VED96)A<E]E>'!A;F1E9"<L('1R=64I+G1O4W1R:6YG*"D@(3T@
M97AP86YD9613:61E8F%R+G-H;W=N*"DN=&]3=')I;F<H*2D@>PH@("`@=&]G
M9VQE365N=49R86UE*"D["GT*"G9A<B!-96YU57!D871E2&%N9&QE<B`]('L*
M("`@(&]N3&]A9#H@9G5N8W1I;VXH<F5S=6QT*0H@("`@>PH@("`@("`@("\O
M(%)U;B!T:&4@:F%V87-C<FEP="!W92!G;W0@8F%C:RX*("`@("`@("!E=F%L
M*')E<W5L="D["B`@("!]"GT["@IF=6YC=&EO;B!U<&1A=&4H*0I["B`@("!V
M87(@8VQI96YT(#T@;F5W($A45%!#;&EE;G0H*3L*("`@(&-L:65N="YI;FET
M*"(\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP/VAT='!C;&EE;G0],2<L('1R=64I(#\^(BD[
M"@H@("`@=')Y('L*("`@("`@("!C;&EE;G0N87-Y;F-'150H365N=55P9&%T
M94AA;F1L97(I.PH@("`@?2!C871C:"`H92D@>PH@("`@("`@("\O($1O;B=T
M(&1O(&%N>71H:6YG(&]N(&5R<F]R<SL@<')O8F%B;'D@82!T<F%N<VEE;G0@
M9F%I;'5R92P*("`@("`@("`O+R!A;F0@=V4G;&P@=')Y(&%G86EN(&%F=&5R
M('1H92!N97AT(&EN=&5R=F%L+@H@("`@?0H@("`@=VEN9&]W+G-E=%1I;65O
M=70H)W5P9&%T92@I.R<L(#P_<&AP(&5C:&\@)'!R969S+3YG971686QU92@G
M;65N=5]R969R97-H7W1I;64G*2`_/B`J(#$P,#`I.PI]"@H\/W!H<"!I9B`H
M)'!R969S+3YG971686QU92@G;65N=5]R969R97-H7W1I;64G*2DZ(#\^"B\O
M(%5P9&%T92!T:&4@;65N=2!I9B!S970@:6X@=7-E<B!P<F5F<RX*/#]P:'`@
M:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E871U<F4H)WAM;&AT='!R
M97$G*2DZ(#\^"G=I;F1O=RYS9714:6UE;W5T*"=U<&1A=&4H*3LG+"`\/W!H
M<"!E8VAO("1P<F5F<RT^9V5T5F%L=64H)VUE;G5?<F5F<F5S:%]T:6UE)RD@
M/SX@*B`Q,#`P*3L*/#]P:'`@96QS93H@/SX*=VEN9&]W+G-E=%1I;65O=70H
M)W=I;F1O=RYL;V-A=&EO;BYR96QO860H=')U92D[)RP@/#]P:'`@96-H;R`D
M<')E9G,M/F=E=%9A;'5E*"=M96YU7W)E9G)E<VA?=&EM92<I(#\^("H@,3`P
M,"D["CP_<&AP(&5N9&EF.R!E;F1I9CL@/SX*"CPO<V-R:7!T/@H*/#]P:'`@
M:68@*&ES<V5T*"1'3$]"04Q36R=N;W1I9FEC871I;VXG72DI("1'3$]"04Q3
M6R=N;W1I9FEC871I;VXG72T^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^
M(&%R<F%Y*"=J879A<V-R:7!T)RDI*2`_/@H*/"]B;V1Y/@H\+VAT;6P^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3`W,P`Q,#4Q-30S,3`V-0`P,C$Q,S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`@:68@
M*"1L87EO=70M/FES0VAA;F=E9"@D<F]W+"`D8V]L*2DZ(#\^"CQA(&ED/2)B
M;&]C:R(^/"]A/@H\/W!H<"!E;F1I9CL@/SX*"CQP(&-L87-S/2)H96%D97(B
M/CP_<&AP(&5C:&\@7R@B061D($AE<F4Z(BD@/SX\+W`^"@H\9&EV('-T>6QE
M/2)P861D:6YG.C)P>"(^"B`\9F]R;2!A8W1I;VX](CP_<&AP(&5C:&\@2&]R
M9&4Z.G-E;&95<FPH*2`_/B-B;&]C:R(@;65T:&]D/2)P;W-T(CX*(#P_<&AP
M(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H@/&EN<'5T('1Y<&4](FAI9&1E;B(@
M;F%M93TB<F]W(B!V86QU93TB/#]P:'`@96-H;R`D<F]W(#\^(B`O/@H@/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB8V]L(B!V86QU93TB/#]P:'`@96-H
M;R`D8V]L(#\^(B`O/@H@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T
M:6]N(B!V86QU93TB<V%V92UR97-U;64B("\^"B`\/W!H<"!E8VAO("1B;&]C
M:W,M/F=E=$)L;V-K<U=I9&=E="@I(#\^"B`\:6YP=70@='EP93TB<W5B;6ET
M(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")!9&0B*2`_
M/B(@+SX*(#PO9F]R;3X*/"]D:78^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#$R,0`Q,#4Q-30S,3`V-0`P,C$W,3,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`@:68@*"1L87EO=70M/FES0VAA;F=E9"@D<F]W+"`D8V]L*2DZ(#\^"CQA
M(&ED/2)B;&]C:R(^/"]A/@H\/W!H<"!E;F1I9CL@/SX*"CQT86)L92!C96QL
M<W!A8VEN9STB,"(@8VQA<W,](FAE861E<B(@=VED=&@](C$P,"4B/CQT<CX*
M("`\=&0^"B`@("`\/W!H<"!E8VAO("1R96=I<W1R>2T^9V5T*"=N86UE)RP@
M)&)L;V-K26YF;ULG87!P)UTI("X@)SH@)R`N("1B;&]C:W,M/F=E=$YA;64H
M)&)L;V-K26YF;ULG87!P)UTL("1B;&]C:TEN9F];)V)L;V-K)UTI(#\^"B`@
M/"]T9#X*("`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@("`@)FYB<W`[/#]P
M:'`@96-H;R`D961I=%]L:6YK(#\^"B`@("`\/W!H<"!I9B`H)&QA>6]U="T^
M:7-296UO=F%B;&4H)')O=RP@)&-O;"DI(&5C:&\@2&]R9&4Z.FQI;FLH)&QA
M>6]U="T^9V5T06-T:6]N57)L*"=R96UO=F5";&]C:R<L("1R;W<L("1C;VPI
M+"!?*")296UO=F4@0FQO8VLB*2P@)R<L("<G+"`G)RP@7R@B4F5M;W9E($)L
M;V-K(BDI("X@2&]R9&4Z.FEM9R@G8VQO<V4N<&YG)RP@7R@B4F5M;W9E($)L
M;V-K(BDL("=A;&EG;CTB;6ED9&QE(B<I("X@)SPO83XG(#\^"B`@/"]T9#X*
M/"]T<CX\+W1A8FQE/@H*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!C;&%S<STB
M;F]P861D:6YG(B!W:61T:#TB,3`P)2(^"B`@/'1R/@H@("`@/'1D(&-O;'-P
M86X](C,B(&%L:6=N/2)C96YT97(B/@H@("`@("`\/W!H<"!I9B`H)')O=R`^
M(#`I(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G97AP86YD+W5P)RP@)')O
M=RP@)&-O;"D@/SXF;F)S<#L*("`@("`@/#]P:'`@:68@*"1L87EO=70M/F=E
M=$AE:6=H="@D<F]W+"`D8V]L*2`^(#$I(&5C:&\@)&QA>6]U="T^9V5T0V]N
M=')O;"@G<VAR:6YK+W5P)RP@)')O=RP@)&-O;"D@/SX*("`@(#PO=&0^"B`@
M/"]T<CX*("`\='(^"B`@("`\=&0@8VQA<W,](FQE9G1!;&EG;B(@=VED=&@]
M(C$Q(CX*("`@("`@/#]P:'`@:68@*"1C;VP@/B`P*2!E8VAO("1L87EO=70M
M/F=E=$-O;G1R;VPH)V5X<&%N9"]L969T)RP@)')O=RP@)&-O;"D@/SX*("`@
M("`@/#]P:'`@:68@*"1L87EO=70M/F=E=%=I9'1H*"1R;W<L("1C;VPI(#X@
M,2D@96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=S:')I;FLO;&5F="<L("1R
M;W<L("1C;VPI(#\^"B`@("`\+W1D/@H@("`@/'1D(&%L:6=N/2)C96YT97(B
M/@H@("`@("`\=&%B;&4^"B`@("`@("`@/'1R/@H@("`@("`@("`@/'1D('=I
M9'1H/2(Q,2(^)FYB<W`[/"]T9#X*("`@("`@("`@(#QT9"!W:61T:#TB,3$B
M/CP_<&AP(&5C:&\@)')O=R`^(#`@/R`D;&%Y;W5T+3YG971#;VYT<F]L*"=M
M;W9E+W5P)RP@)')O=RP@)&-O;"D@.B`G)FYB<W`[)R`_/CPO=&0^"B`@("`@
M("`@("`\=&0@=VED=&@](C$Q(CXF;F)S<#L\+W1D/@H@("`@("`@(#PO='(^
M"B`@("`@("`@/'1R/@H@("`@("`@("`@/'1D/CP_<&AP(&5C:&\@)&-O;"`^
M(#`@/R`D;&%Y;W5T+3YG971#;VYT<F]L*"=M;W9E+VQE9G0G+"`D<F]W+"`D
M8V]L*2`Z("<F;F)S<#LG(#\^/"]T9#X*("`@("`@("`@(#QT9#XF;F)S<#L\
M+W1D/@H@("`@("`@("`@/'1D/CP_<&AP(&5C:&\@)&QA>6]U="T^9V5T0V]N
M=')O;"@G;6]V92]R:6=H="<L("1R;W<L("1C;VPI(#\^/"]T9#X*("`@("`@
M("`\+W1R/@H@("`@("`@(#QT<CX*("`@("`@("`@(#QT9#XF;F)S<#L\+W1D
M/@H@("`@("`@("`@/'1D/CP_<&AP(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O
M;"@G;6]V92]D;W=N)RP@)')O=RP@)&-O;"D@/SX\+W1D/@H@("`@("`@("`@
M/'1D/B9N8G-P.SPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@/"]T86)L93X*
M("`@(#PO=&0^"B`@("`\=&0@8VQA<W,](G)I9VAT06QI9VXB('=I9'1H/2(Q
M,2(^"B`@("`@(#P_<&AP(&EF("@D;&%Y;W5T+3YG9717:61T:"@D<F]W+"`D
M8V]L*2`^(#$I(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G<VAR:6YK+W)I
M9VAT)RP@)')O=RP@)&-O;"D@/SX*("`@("`@/#]P:'`@96-H;R`D;&%Y;W5T
M+3YG971#;VYT<F]L*"=E>'!A;F0O<FEG:'0G+"`D<F]W+"`D8V]L*2`_/@H@
M("`@/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!C;VQS<&%N/2(S(B!A
M;&EG;CTB8V5N=&5R(CX*("`@("`@("`\/W!H<"!I9B`H)&QA>6]U="T^9V5T
M2&5I9VAT*"1R;W<L("1C;VPI(#X@,2D@96-H;R`D;&%Y;W5T+3YG971#;VYT
M<F]L*"=S:')I;FLO9&]W;B<L("1R;W<L("1C;VPI(#\^"B`@("`@("`@/#]P
M:'`@96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=E>'!A;F0O9&]W;B<L("1R
M;W<L("1C;VPI(#\^"B`@("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^"@H\/W!H
M<"!I9B`H)&ES161I=&EN9RDZ(#\^"CQA(&ED/2)B;&]C:R(^/"]A/@H\=&%B
M;&4@8VQA<W,](FYO<&%D9&EN9R(@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q
M,#`E(CX*("`\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`\+W1R/@H@(#QT
M<CX*("`@(#QT9"!V86QI9VX](FUI9&1L92(@8VQA<W,](FQE9G1!;&EG;B(@
M=VED=&@](C$P,"4B/@H@("`@("`\9F]R;2!A8W1I;VX](CP_<&AP(&5C:&\@
M2&]R9&4Z.G-E;&95<FPH*2`_/B-B;&]C:R(@;65T:&]D/2)P;W-T(B!N86UE
M/2)B;&]C:V9O<FTB/@H@("`@("`@(#P_<&AP(%5T:6PZ.G!F;W)M26YP=70H
M*2`_/@H@("`@("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G)O=R(@
M=F%L=64](CP_<&AP(&5C:&\@)')O=R`_/B(@+SX*("`@("`@("`\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)C;VPB('9A;'5E/2(\/W!H<"!E8VAO("1C
M;VP@/SXB("\^"B`@("`@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M86-T:6]N(B!V86QU93TB<V%V92(@+SX*("`@("`@("`\=&%B;&4@8V5L;'-P
M86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@("`@("`@(#QT<CX*("`@("`@
M("`@("`@/'1D(&-L87-S/2)S;6%L;&AE861E<B(@8V]L<W!A;CTB,B(^/#]P
M:'`@96-H;R!?*")";&]C:R!4>7!E(BD@/SX\+W1D/@H@("`@("`@("`@/"]T
M<CX*("`@("`@("`@(#QT<CX*("`@("`@("`@("`@/'1D(&-O;'-P86X](C(B
M/@H@("`@("`@("`@("`@(#P_<&AP(&5C:&\@)&)L;V-K<RT^9V5T0FQO8VMS
M5VED9V5T*"1B;&]C:TEN9F];)V%P<"==+"`D8FQO8VM);F9O6R=B;&]C:R==
M+"!T<G5E*2`_/@H@("`@("`@("`@("`\+W1D/@H@("`@("`@("`@/"]T<CX*
M/#]P:'`*:68@*"1B;&]C:W,M/FES161I=&%B;&4H)&)L;V-K26YF;ULG87!P
M)UTL("1B;&]C:TEN9F];)V)L;V-K)UTI*3H*("`@("1B;&]C:R`]("8D;&%Y
M;W5T+3YG971";&]C:R@D<F]W+"`D8V]L*3L*("`@("1D969A=6QT<R`](&%R
M<F%Y*"D["B`@("!F;W)E86-H("@D8FQO8VLM/E]P87)A;7,@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@)&1E9F%U;'1S6R1K97E=(#T@)'9A;#L*("`@
M('T*/SX*("`@("`@("`@(#QT<CX*("`@("`@("`@("`@/'1D(&-O;'-P86X]
M(C(B(&-L87-S/2)S;6%L;&AE861E<B(^/#]P:'`@96-H;R!?*")";&]C:R!3
M971T:6YG<R(I(#\^/"]T9#X*("`@("`@("`@(#PO='(^"CP_<&AP("1I(#T@
M,#L@9F]R96%C:"`H)&)L;V-K<RT^9V5T4&%R86US*"1B;&]C:TEN9F];)V%P
M<"==+"`D8FQO8VM);F9O6R=B;&]C:R==*2!A<R`D:60I.B`D:2LK.R`_/@H@
M("`@("`@("`@/'1R/@H@("`@("`@("`@("`\=&0@8VQA<W,](CP_<&AP(&5C
M:&\@*"1I("4@,BD@/R`G=&5X="<@.B`G:71E;3`G(#\^(')I9VAT06QI9VXB
M('9A;&EG;CTB=&]P(CX\/W!H<"!E8VAO("1B;&]C:W,M/F=E=%!A<F%M3F%M
M92@D8FQO8VM);F9O6R=A<'`G72P@)&)L;V-K26YF;ULG8FQO8VLG72P@)&ED
M*2`_/CHF;F)S<#L\+W1D/@H@("`@("`@("`@("`\=&0@8VQA<W,](CP_<&AP
M(&5C:&\@*"1I("4@,BD@/R`G=&5X="<@.B`G:71E;3`G(#\^(B!V86QI9VX]
M(G1O<"(^/#]P:'`@96-H;R`D8FQO8VMS+3YG971/<'1I;VYS5VED9V5T*"1B
M;&]C:TEN9F];)V%P<"==+"`D8FQO8VM);F9O6R=B;&]C:R==+"`D:60L("1D
M969A=6QT<RD@/SX\+W1D/@H@("`@("`@("`@/"]T<CX*/#]P:'`@96YD9F]R
M96%C:#L@96YD:68[(#\^"B`@("`@("`@/"]T86)L93X*("`@("`@("`\:6YP
M=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@
M96-H;R!?*")3879E(BD@/SXB("\^"B`@("`@(#PO9F]R;3X*("`@(#PO=&0^
M"B`@/"]T<CX*/"]T86)L93X*/#]P:'`@96YD:68[(#\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP
M;&%T97,O<&]R=&%L+V)L;V-K+FEN8P``````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S(W`#$P-3$U-#,Q,#8U`#`R,30W-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\=&0@8VQA<W,](FAE
M861E<F)O>"(@=F%L:6=N/2)T;W`B('-T>6QE/2)W:61T:#H\/W!H<"!E8VAO
M("1W:61T:"`_/B4B(')O=W-P86X](CP_<&AP(&5C:&\@)')O=W-P86X@/SXB
M(&-O;'-P86X](CP_<&AP(&5C:&\@)&-O;'-P86X@/SXB/@H@/&@Q(&-L87-S
M/2)H96%D97(B/CP_<&AP(&5C:&\@)&AE861E<B`_/CPO:#$^"B`\/W!H<"!E
M8VAO("1C;VYT96YT(#\^"CPO=&0^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W)P8W-U
M;2\`````````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,3`V-0`P,3<W,C,`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,`````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`V-3,S`#$P-3$U-#,Q,#8U`#`R,3<S,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\<V-R:7!T
M('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"G9A<B!C86YC96Q3=6)M
M:70@/2!F86QS93L*"G9A<B!F:65L9',@/2!N97<@07)R87DH"CP_<&AP(&9O
M<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1R<&-?<V5R=F5R<RD[("1I*RLI.B`_
M/@H@("`@;F5W($%R<F%Y*`H@("`@("`@("(\/W!H<"!E8VAO(')A=W5R;&5N
M8V]D92@D<G!C7W-E<G9E<G-;)&E=6R=U<FPG72D@/SXB+`H@("`@("`@("(\
M/W!H<"!E8VAO(')A=W5R;&5N8V]D92@D<G!C7W-E<G9E<G-;)&E=6R=U<V5R
M)UTI(#\^(@H@("`@*3P_<&AP(&EF("@D:2`K(#$@/"!C;W5N="@D<G!C7W-E
M<G9E<G,I*2!E8VAO("<L)SL@/SX*"CP_<&AP(&5N9&9O<CL@/SX**3L*"F9U
M;F-T:6]N(&YE=T-H;VEC92@I"GL*("`@('9A<B!A8W1I;VX@/2!D;V-U;65N
M="YP<F5F<RYS97)V97(N;W!T:6]N<UMD;V-U;65N="YP<F5F<RYS97)V97(N
M<V5L96-T961);F1E>%TN=F%L=64["@H@("`@:68@*&%C=&EO;B`]/2`M,2D@
M>PH@("`@("`@(&1O8W5M96YT+G!R969S+G-A=F4N=F%L=64@/2`G/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D-R96%T92(I*2`_/B<["B`@("`@("`@9&]C
M=6UE;G0N<')E9G,N<F5S970H*3L*("`@('T@96QS92!["B`@("`@("`@9&]C
M=6UE;G0N<')E9G,N<V%V92YV86QU92`]("<\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0VAA;F=E(BDI(#\^)SL*("`@("`@("!U<&1A=&5&;W)M*&%C=&EO
M;BD["B`@("!]"GT*"F9U;F-T:6]N('5P9&%T949O<FTH<V5R=F5R*0I["B`@
M("!D;V-U;65N="YP<F5F<RYE9&ET7W-E<G9E<BYV86QU92`]('-E<G9E<CL*
M("`@(&1O8W5M96YT+G!R969S+G5R;"YV86QU92`](&1E8V]D955224-O;7!O
M;F5N="AF:65L9'-;<V5R=F5R75LP72D["B`@("!D;V-U;65N="YP<F5F<RYU
M<V5R+G9A;'5E(#T@9&5C;V1E55))0V]M<&]N96YT*&9I96QD<UMS97)V97)=
M6S%=*3L*?0H*9G5N8W1I;VX@8VQE87)&;W)M*"D*>PH@("`@9&]C=6UE;G0N
M<')E9G,N961I=%]S97)V97(N=F%L=64@/2`G)SL*("`@(&1O8W5M96YT+G!R
M969S+G5R;"YV86QU92`]("!F:65L9'-;<V5R=F5R75LP73L*("`@(&1O8W5M
M96YT+G!R969S+G5S97(N=F%L=64@/2!F:65L9'-;<V5R=F5R75LQ73L*("`@
M(&1O8W5M96YT+G!R969S+G-E<G9E<BYS96QE8W1E9$EN9&5X(#T@,#L*("`@
M(&-A;F-E;%-U8FUI="`]('1R=64["GT*"F9U;F-T:6]N(&-H96-K4W5B;6ET
M*"D*>PH@("`@8V%N8V5L(#T@8V%N8V5L4W5B;6ET.PH@("`@8V%N8V5L4W5B
M;6ET(#T@9F%L<V4["CP_<&AP(&EF("@D8G)O=W-E<BT^9V5T0G)O=W-E<B@I
M(#T]("=M<VEE)R`F)B`D8G)O=W-E<BT^9V5T36%J;W(H*2`^/2`T*3H@/SX*
M("`@('=I;F1O=RYE=F5N="YR971U<FY686QU92`]("%C86YC96P["CP_<&AP
M(&5N9&EF.R`_/@H@("`@<F5T=7)N("%C86YC96P["GT*"B\O+2T^"CPO<V-R
M:7!T/@H*/#]P:'`@96-H;R!?*")9;W5R(')E;6]T92!S97)V97)S.B(I(#\^
M/&)R("\^"CQS96QE8W0@;F%M93TB<V5R=F5R(B!O;F-H86YG93TB:F%V87-C
M<FEP=#IN97=#:&]I8V4H*2(^"B`@/&]P=&EO;B!V86QU93TB+3$B/CP_<&AP
M(&5C:&\@7R@B4V5L96-T(&$@<V5R=F5R(BD@/SX\+V]P=&EO;CX*/#]P:'`@
M9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)')P8U]S97)V97)S*3L@*RLD:2DZ
M(#\^"B`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D:2`_/B(^/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1R<&-?<V5R=F5R<ULD:5U;)W5R;"==
M*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W([(#\^"CPO<V5L96-T/@H\+W1D
M/CPO='(^"@H\;F]S8W)I<'0^"CPO=&%B;&4^/"]T9#X\+W1R/@H\='(^"B`@
M/'1D('9A;&EG;CTB;6ED9&QE(CX*("`@(#QB<B`O/@H@("`@/&EN<'5T('1Y
M<&4](G-U8FUI="(@;F%M93TB961I="(@8VQA<W,](F)U='1O;B(@=F%L=64]
M(CP_<&AP(&5C:&\@7R@B161I="(I(#\^(B`O/@H@("`@/&EN<'5T('1Y<&4]
M(G-U8FUI="(@;F%M93TB9&5L971E(B!C;&%S<STB8G5T=&]N(B!V86QU93TB
M/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/B(@+SX*("`@(#QB<B`O/B9N8G-P
M.PH@(#PO=&0^"CPO='(^"@H\='(^/'1D(&-L87-S/2)I=&5M(CX\=&%B;&4^
M"CPO;F]S8W)I<'0^"@H\='(@=F%L:6=N/2)T;W`B/CQT9"!C;&%S<STB:71E
M;2(^"@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)E9&ET7W-E<G9E<B(@
M=F%L=64](B(@+SX*/#]P:'`@96-H;R!?*")296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB*2`_/CQB<B`O/@H\:6YP=70@='EP
M93TB=&5X="(@;F%M93TB=7)L(B!S:7IE/2(S,"(@;6%X;&5N9W1H/2(V,"(@
M+SX\8G(@+SX*"CP_<&AP(&5C:&\@7R@B57-E<FYA;64Z(BD@/SX\8G(@+SX*
M/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G5S97(B('-I>F4](C,P(B!M87AL
M96YG=&@](C8P(B`O/CQB<B`O/@H*/#]P:'`@96-H;R!?*")087-S=V]R9#HB
M*2`_/CQB<B`O/@H\:6YP=70@='EP93TB<&%S<W=O<F0B(&YA;64](G!A<W-W
M9"(@<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B("\^/&)R("\^"@H\+W1D/CPO
M='(^/"]T86)L93X\+W1D/CPO='(^/"]T86)L93X*"CQP/@H@/&EN<'5T('1Y
M<&4](G-U8FUI="(@;F%M93TB<V%V92(@8VQA<W,](F)U='1O;B(@;VYC;&EC
M:STB9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L=64])W-A=F4G.R!R971U
M<FX@=')U92(@=F%L=64](CP_<&AP(&5C:&\@)&%C=&EO;DE$(#T]("=E9&ET
M)R`_(%\H(D-H86YG92(I(#H@7R@B0W)E871E(BD@/SXB("\^)FYB<W`["CQS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*9&]C=6UE;G0N=W)I=&4H
M)SQI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](F1E;&5T92(@8VQA<W,](F)U
M='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L=64]
M7"=D96QE=&5<)R(@=F%L=64](CP_<&AP(&5C:&\@7R@B1&5L971E(BD@/SXB
M("\^)FYB<W`[)RD["CPO<V-R:7!T/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@
M;F%M93TB;F5W(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)C;&5A<D9O<FTH
M*3MD;V-U;65N="YP<F5F<RYS879E+G9A;'5E/2<\/W!H<"!E8VAO(%\H(D-R
M96%T92(I(#\^)SLB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E<V5T(BD@/SXB
M("\^)FYB<W`["B`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N
M(B!O;F-L:6-K/2)C86YC96Q3=6)M:70]=')U93MD;V-U;65N="YL;V-A=&EO
M;BYH<F5F/2<\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"A5=&EL
M.CIA9&1087)A;65T97(H)W-E<G9I8V5S+W!R969S+G!H<"<L("=A<'`G+"`G
M:&]R9&4G*2P@=')U92D@/SXG(B!V86QU93TB/#]P:'`@96-H;R!?*")2971U
M<FX@=&\@3W!T:6]N<R(I(#\^(B`O/@H\+W`^"@H\+V9O<FT^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+W!R;V)L96TO````````````````````````````````
M```````````````````````````````````````````P,#0P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-0`P,C`P-3(`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8P``````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-#(P`#$P-3$U
M-#,Q,#8U`#`R,C(P,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA
M+2T*+R\@0VAE8VL@86QL(&]F('1H92!M86EN(&9O<FT@9FEE;&1S('1O(&UA
M:V4@<W5R92!T:&5Y(&%R92!F:6QL960@:6X*9G5N8W1I;VX@=F%L:61A=&4H
M*0I["B`@("!I9B`H9&]C=6UE;G0N<')O8FQE;5]R97!O<G0N<W5B:F5C="YV
M86QU92`]/2`G)RD@>PH@("`@("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+B(I*2`_/B<I.PH@("`@("`@(&1O8W5M96YT+G!R;V)L96U?<F5P;W)T
M+G-U8FIE8W0N9F]C=7,H*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M(&5L<V4@:68@*&1O8W5M96YT+G!R;V)L96U?<F5P;W)T+FUE<W-A9V4N=F%L
M=64@/3T@)R<I('L*("`@("`@("!A;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(I*2`_/B<I.PH@("`@
M("`@(&1O8W5M96YT+G!R;V)L96U?<F5P;W)T+FUE<W-A9V4N9F]C=7,H*3L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9&]C=6UE;G0N<')O
M8FQE;5]R97!O<G0N86-T:6]N240N=F%L=64@/2`G<V5N9%]P<F]B;&5M7W)E
M<&]R="<["B`@("!R971U<FX@=')U93L*?0HO+RTM/@H\+W-C<FEP=#X*"CQF
M;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB<')O8FQE;5]R97!O<G0B(&%C=&EO
M;CTB<')O8FQE;2YP:'`B/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)C
M86YC96Q?<')O8FQE;5]R97!O<G0B("\^"CQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](G)E='5R;E]U<FPB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)W)E='5R;E]U<FPG*2D@/SXB
M("\^"@H\=&%B;&4@8V5L;'!A9&1I;F<](C,B(&-E;&QS<&%C:6YG/2(R(B!W
M:61T:#TB,3`P)2(^"CQT<B!C;&%S<STB:&5A9&5R(CX*("`@(#QT9"!C;VQS
M<&%N/2(R(B!C;&%S<STB:&5A9&5R(CX\/W!H<"!E8VAO(%\H(D1E<V-R:6)E
M('1H92!0<F]B;&5M(BD@/SX\+W1D/@H\+W1R/@H*/'1R/@H@("`@/'1D(&-L
M87-S/2)L:6=H="!R:6=H=$%L:6=N(CX\/W!H<"!E8VAO(%\H(EEO=7(@3F%M
M92(I(#\^/"]T9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@=&%B:6YD
M97@](C$B(&YA;64](FYA;64B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&YA;64I(#\^(B!S:7IE/2(W,"(@+SX\+W1D/@H\+W1R/@H*
M/'1R/@H@("`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N(CX\/W!H<"!E
M8VAO(%\H(EEO=7(@16UA:6P@061D<F5S<R(I(#\^/"]T9#X*("`@(#QT9#X\
M:6YP=70@='EP93TB=&5X="(@=&%B:6YD97@](C(B(&YA;64](F5M86EL(B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1E;6%I;"D@/SXB
M('-I>F4](C<P(B`O/CPO=&0^"CPO='(^"@H\='(^"B`@("`\=&0@8VQA<W,]
M(FQI9VAT(')I9VAT06QI9VXB/CP_<&AP(&5C:&\@7R@B4VAO<G0@4W5M;6%R
M>2(I(#\^/"]T9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@=&%B:6YD
M97@](C,B(&YA;64](G-U8FIE8W0B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'-U8FIE8W0I(#\^(B!S:7IE/2(W,"(@+SX\+W1D/@H\
M+W1R/@H*/'1R/@H@("`@/'1D(&-O;'-P86X](C(B(&-L87-S/2)S;6%L;&AE
M861E<B(^/#]P:'`@96-H;R!?*")&=6QL($1E<V-R:7!T:6]N(BD@/SX\+W1D
M/@H\+W1R/@H\='(^"B`@("`\=&0^/"]T9#X*("`@(#QT9#X\=&5X=&%R96$@
M=&%B:6YD97@](C0B(&YA;64](FUE<W-A9V4B(')O=W,](C(P(B!C;VQS/2(X
M,"(@=W)A<#TB:&%R9"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1M
M97-S86=E*2`_/CPO=&5X=&%R96$^/"]T9#X*/"]T<CX*"CQT<CX*("`\=&0^
M/"]T9#X*("`\=&0@8VQA<W,](FQI9VAT(CX*("`@(#QI;G!U="!C;&%S<STB
M8G5T=&]N(B!T>7!E/2)S=6)M:70B(&YA;64](F9O<FUS=6)M:70B(&]N8VQI
M8VL](G)E='5R;B!V86QI9&%T92@I.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M4V5N9"!0<F]B;&5M(%)E<&]R="(I(#\^(B`O/@H@("`@/&EN<'5T(&-L87-S
M/2)B=71T;VXB('1Y<&4](G-U8FUI="(@;F%M93TB9F]R;7-U8FUI="(@=F%L
M=64](CP_<&AP(&5C:&\@7R@B0V%N8V5L(%!R;V)L96T@4F5P;W)T(BD@/SXB
M("\^"B`@/"]T9#X*/"]T<CX*"CPO=&%B;&4^"CPO9F]R;3X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O8V]M
M;6]N+69O;W1E<BYI;F,`````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q,#,S`#$P-3$U-#,Q,#8U`#`R,38V,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\<V-R:7!T(&QA;F=U86=E/2)*879A
M4V-R:7!T,2XU(B!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"G9A<B!?
M<V5T2&]R9&54:71L92`](#$["G1R>2!["B`@("!I9B`H9&]C=6UE;G0N=&ET
M;&4@)B8@<&%R96YT+F9R86UE<RYH;W)D95]M86EN*2!P87)E;G0N9&]C=6UE
M;G0N=&ET;&4@/2!D;V-U;65N="YT:71L93L*?2!C871C:"`H92D@>PI]"B\O
M("TM/@H\+W-C<FEP=#X*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/@H\(2TM"FEF("AT>7!E;V8H7W-E=$AO<F1E5&ET;&4I(#T]("=U;F1E9FEN
M960G("8F(&1O8W5M96YT+G1I=&QE("8F('!A<F5N="YF<F%M97,N:&]R9&5?
M;6%I;BD@<&%R96YT+F1O8W5M96YT+G1I=&QE(#T@9&]C=6UE;G0N=&ET;&4[
M"B\O("TM/@H\+W-C<FEP=#X*/#]P:'`@:68@*&ES<V5T*"1'3$]"04Q36R=N
M;W1I9FEC871I;VXG72DI("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^;F]T
M:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^(&%R<F%Y*"=J879A<V-R:7!T)RDI
M*3L@/SX*/"]B;V1Y/@H\+VAT;6P^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O8V]M;6]N+6AE861E<BYI;F,`````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R-S8V`#$P-3$U-#,Q,#8U`#`R,38S,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`IG;&]B86P@)&QA
M;F=U86=E.PII9B`H:7-S970H)&QA;F=U86=E*2D@>PH@("`@:&5A9&5R*"=#
M;VYT96YT+71Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#
M:&%R<V5T*"DI.PH@("`@:&5A9&5R*"=687)Y.B!!8V-E<'0M3&%N9W5A9V4G
M*3L*?0H_/@H\(41/0U194$4@:'1M;"!054),24,@(BTO+U<S0R\O1%1$(%A(
M5$U,(#$N,"!4<F%N<VET:6]N86PO+T5.(B`B1%1$+WAH=&UL,2UT<F%N<VET
M:6]N86PN9'1D(CX*/"$M+2!(;W)D93H@0V]P>7)I9VAT(#(P,#`M,C`P-BP@
M5&AE($AO<F1E(%!R;VIE8W0N($AO<F1E(&ES('5N9&5R('1H92!,1U!,+B`M
M+3X*/"$M+2`@("`@("`@("`@("`@("`@("`@2&]R9&4@4')O:F5C=#H@:'1T
M<#HO+VAO<F1E+F]R9R\@("`@("`@("`@("`@("`@("`@("`M+3X*/"$M+2`@
M("!'3E4@3&EB<F%R>2!0=6)L:6,@3&EC96YS93H@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"`@("`M+3X*/#]P:'`*96-H;R`H(65M
M<'1Y*"1L86YG=6%G92DI(#\@)SQH=&UL(&QA;F<](B<@+B!S=')T<B@D;&%N
M9W5A9V4L("=?)RP@)RTG*2`N("<B)R`Z("<\:'1M;"<["F5C:&\@*"%E;7!T
M>2@D:65?8VQI96YT8V%P<RDI(#\@)R!X;6QN<SI)13XG(#H@)SXG.PH_/@H\
M:&5A9#X*/#]P:'`*"B1P86=E7W1I=&QE(#T@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G;F%M92<I.PII9B`H(65M<'1Y*"1T:71L92DI("1P86=E7W1I
M=&QE("X]("<@.CH@)R`N("1T:71L93L*:68@*"%E;7!T>2@D<F5F<F5S:%]T
M:6UE*2`F)B`A96UP='DH)')E9G)E<VA?=7)L*2D@>PH@("`@96-H;R`B/&UE
M=&$@:'1T<"UE<75I=CU<(G)E9G)E<VA<(B!C;VYT96YT/5PB)')E9G)E<VA?
M=&EM93MU<FP])')E9G)E<VA?=7)L7"(@+SY<;B(["GT*"DAO<F1E.CII;F-L
M=61E4V-R:7!T1FEL97,H*3L*/SX*/'1I=&QE/CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D<&%G95]T:71L92D@/SX\+W1I=&QE/@H\;&EN:R!H<F5F
M/2(\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I
M<B@I(#\^+V9A=FEC;VXN:6-O(B!R96P](E-(3U)40U54($E#3TXB("\^"CP_
M<&AP(&5C:&\@2&]R9&4Z.G-T>6QE<VAE971,:6YK*%5T:6PZ.FYO;DEN<'5T
M5F%R*"=C<W-!<'!S)RDI(#\^"CP_<&AP(&5C:&\@:6UP;&]D92@B7&XB+"!5
M=&EL.CIN;VY);G!U=%9A<B@G;&EN:U1A9W,G+"!A<G)A>2@I*2D@/SX*/#]P
M:'`@:68@*"%E;7!T>2@D:65?8VQI96YT8V%P<RDI.B`_/CQS='EL93Y)15PZ
M8VQI96YT8V%P<R![8F5H879I;W(Z=7)L*"-D969A=6QT(V-L:65N=&-A<',I
M?3PO<W1Y;&4^/#]P:'`@96YD:68[(#\^"CPO:&5A9#X*"CQB;V1Y/#]P:'`@
M:68@*%5T:6PZ.FYO;DEN<'5T5F%R*"=B;V1Y0VQA<W,G*2D@96-H;R`G(&-L
M87-S/2(G("X@)&)O9'E#;&%S<R`N("<B)SL@/SX^"CP_<&AP(&EF("@A96UP
M='DH)&EE7V-L:65N=&-A<',I*3H@/SX\244Z8VQI96YT8V%P<R!)1#TB;V)J
M0T-A<',B("\^/#]P:'`@96YD:68[(#\^"@`````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R\N:'1A8V-E<W,`````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`U,34T,S$P
M-C4`,#(P,C`R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$1E;GD@9G)O;2!A;&P*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O````````````````````````````````````````````
M`````````````````````````````````````````````#`P-#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`Q-3<P,P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G96YN979I;&QI97)S+P``
M````````````````````````````````````````````````````````````
M````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S$P-C4`,#(P-30W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=E;FYE=FEL;&EE<G,O:6YF;RYP:'``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#<Q-``Q,#4Q-30S,3`V-0`P,C(R,3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M:7,@=&AE;64@87,@8F5E;B!W<FET=&5N(&)Y($%I9&4@1FQO<F5N="`\9F%I
M9&5`86QP:&%C96YT+F-O;3X@86YD"B`J($WI;&%N:64@1V%R96%U(#QM96QA
M;FEE+F=A<F5A=4!V:6QL92UG96YN979I;&QI97)S+F9R/@H@*@H@*B!4:&4@
M=&AE;64@:61E82!W87,@=&\@:6YC;W)P;W)A=&4@<VUO;W1H;'D@:6X@=&AE
M(&EN=')A;F5T+@H@*B!4:&ES('1H96UE(&ES('!U8FQI<VAE9"!U;F1E<B!T
M:&4@<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E+@H@*@H@*B!4
M:&4@;F%M92!C;VUE<R!F<F]M('1H92!C:71Y(&]F($=E;FYE=FEL;&EE<G,@
M:6X@1G)A;F-E"B`J"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V=E;FYE=FEL
M;&EE<G,O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-2!M9&IU
M:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")496%L(BD["@``````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G96YN979I;&QI
M97)S+W-C<F5E;BYC<W,`````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V
M-C4`,3`U,34T,S$P-C4`,#(R-30V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B!4:&ES('1H96UE(&%S(&)E96X@
M=W)I='1E;B!B>2!!:61E($9L;W)E;G0@/&9A:61E0&%L<&AA8V5N="YC;VT^
M(&%N9`H@*B!-PZEL86YI92!'87)E874@/&UE;&%N:64N9V%R96%U0'9I;&QE
M+6=E;FYE=FEL;&EE<G,N9G(^"B`J"B`J(%1H92!T:&5M92!I9&5A('=A<R!T
M;R!I;F-O<G!O<F%T92!S;6]O=&AL>2!I;B!T:&4@:6YT<F%N970N"B`J(%1H
M:7,@=&AE;64@:7,@<'5B;&ES:&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@
M87,@=&AE(&AO<F1E('!A8VMA9V4N"B`J"B`J(%1H92!N86UE(&-O;65S(&9R
M;VT@=&AE(&-I='D@;V8@1V5N;F5V:6QL:65R<R!I;B!&<F%N8V4*("H*("H@
M)$AO<F1E.B!H;W)D92]T:&5M97,O9V5N;F5V:6QL:65R<R]S8W)E96XN8W-S
M+'8@,2XU+C8N,R`R,#`U+S$P+S$X(#$Q.C,T.C$S(&IA;B!%>'`@)`H@*B\*
M"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(S`P-C,V,SL*("`@('-C<F]L;&)A
M<BUB87-E+6-O;&]R.B`C-C-B-6(U.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O
M;&]R.B`C-C-B-6(U.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L
M;W(Z(",V,V(U8C4["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",V,V(U
M8C4["GT*82!["B`@("!C;VQO<CH@(S$R,F5B83L*?0IA.FAO=F5R('L*("`@
M(&-O;&]R.B`C,3(R96)A.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P
M.PI]"F$N=VED9V5T.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PI]"BYH96%D
M97(L("YS;6%L;&AE861E<BP@82YS;6%L;&AE861E<B!["B`@("!C;VQO<CH@
M(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",V,V(U8C4["GT*+F)U='1O;B!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",T,3AE.&4["B`@("!B
M;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED(",V,#4Y-3D["B`@("!B;W)D97(M
M<FEG:'0Z('1H:6X@<V]L:60@(S8P-3DU.3L*("`@(&)O<F1E<BUT;W`Z('1H
M:6X@<V]L:60@(V-E8V5C93L*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED
M("-F9F8["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z(",V,V(U8C4[
M"GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0Z(",V,V(U8C4["GT*(VUE;G4@82!["B`@("!C
M;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N
M9#H@(S0Q.&4X93L*("`@(&-O;&]R.B`C9F9F.PI]"@HO*B!3:61E8F%R('-T
M>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD.B`C-C-B
M-6(U.PI]"B-S:61E8F%R4&%N96P@<W!A;BP@(W-I9&5B87)086YE;"!A('L*
M("`@(&-O;&]R.B`C9F9F.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@
M("!C;VQO<CH@(V9F9CL*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I97<N("HO
M"BYP<F5F<T]V97)V:65W(&@R('L*("`@(&-O;&]R.B`C9F9F.PI]"@``````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V%Z=7(O````````````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-0`P,38V-C(`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O87IU<B]I;F9O+G!H<```
M````````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C4P`#$P
M-3$U-#,Q,#8U`#`R,#,R,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M
M97,O87IU<B]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,S(&UD
M:G5K:6,@17AP("0@/SX*("H*("H@0&%U=&AO<B!*;V]S="!$92!#;V-K(#QJ
M;V]S=$!D96-O8VLN;W)G/@H@*B\*"B1T:&5M95]N86UE(#T@7R@B07IU<B(I
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V%Z=7(O<V-R965N+F-S<P``````````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0W-P`Q,#4Q-30S,3`V-0`P
M,C`V-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+RHJ"B`J($%U=&AO<CH@2F]O<W0@1&4@0V]C:R`\:F]O<W1`9&5C;V-K
M+F]R9SX*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O87IU<B]S8W)E96XN
M8W-S+'8@,2XU+C8N-2`R,#`U+S$Q+S$U(#`V.C0Q.C`R('-E;'-K>2!%>'`@
M)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(S8T83=C.3L*?0IA('L*
M("`@(&-O;&]R.B`C,S,Y.PI]"F$N=VED9V5T.FAO=F5R('L*("`@(&-O;&]R
M.B`C-C8V.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9CL*?0HN:&5A9&5R
M('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S`V.3L*?0HN
M:&5A9&5R(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*+G-M86QL:&5A9&5R('L*
M("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S`V.3L*
M?0IA+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PI]"BYB=71T;VX@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S`V.3L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",R,C0["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C,C(T.PH@("`@8F]R9&5R+71O<#H@,7!X
M('-O;&ED(",Y.6,["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",Y.6,[
M"GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P-CD["GT*(VUE;G4@82!["B`@
M("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R
M;W5N9#H@(S8T83=C.3L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O
M<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$Z:&]V
M97(@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-E964["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+6QE9G0Z
M(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P
M,#`["B`@("!P861D:6YG.B`R<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J
M+PHC<VED96)A<E!A;F5L('L*("`@(&)O<F1E<BUC;VQO<CH@=')A;G-P87)E
M;G0["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8F-D-F4R.PI]"@HO*B!486(@
M<W1Y;&5S+B`J+PHN=&%B<V5T(&QI+F%C=&EV951A8B!A+"`N=&%B<V5T(&QI
M+F%C=&EV951A8B!A.FAO=F5R('L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C,#8Y.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S`V.3L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)E
M>2\`````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#8U`#`Q-C8T-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F5Y+VEN9F\N<&AP````````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-C8`,3`U,34T,S$P-C4`,#(P,S$S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]G<F5Y+VEN9F\N<&AP
M+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*
M"B1T:&5M95]N86UE(#T@7R@B1W)E>2(I.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)E>2]S8W)E96XN8W-S````````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,3(P`#$P-3$U-#,Q,#8U`#`R,#8S,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O9W)E>2]S8W)E96XN8W-S+'8@,2XW+C8N,3,@,C`P
M-2\Q,"\Q."`Q,3HS-#HQ."!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A
M8VMG<F]U;F0Z(",U9#5D-C`["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@
M(S5D-60V,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S5D-60V,#L*
M?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-60U9#8P.PH@
M("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C-60U9#8P.PI]"F$@>PH@("`@
M8V]L;W(Z(",U.34Y-3D["GT*+G=I9&=E="!["B`@("!C;VQO<CH@(S,S,SL*
M("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]"F$N=VED9V5T.FAO=F5R('L*("`@
M(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V1D9#L*("`@('1E>'0M
M9&5C;W)A=&EO;CH@;F]N93L*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9&1D
M.PH@("`@8F%C:V=R;W5N9#H@(S4T-30U-CL*?0HN:&5A9&5R(&$@>PH@("`@
M8V]L;W(Z("-D9&0["GT*82YL:6=H=#IH;W9E<B!["B`@("!C;VQO<CH@(V9F
M9CL*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",Y9CEF83`["B`@("!B
M86-K9W)O=6YD.B`C-30U-#4V.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD.B`C-3$U,38S.PH@("`@8F]R9&5R+6)O='1O
M;3H@=&AI;B!S;VQI9"`C-60U9#8P.PH@("`@8F]R9&5R+7)I9VAT.B!T:&EN
M('-O;&ED(",U9#5D-C`["B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED(",W
M-S<W.#D["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C-S<W-S@Y.PI]
M"BYI=&5M('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V5E
M93L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(V1D9#L*?0H*+RH@
M365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S4T-30U-CL*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C
M9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C-C8V
M.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@
M("!B86-K9W)O=6YD.B`C-C8V.PI]"B-S:61E8F%R4&%N96P@<W!A;BP@(W-I
M9&5B87)086YE;"!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-S:61E8F%R4&%N
M96P@83IH;W9E<B!["B`@("!C;VQO<CH@>65L;&]W.PI]"@HO*B!486(@<W1Y
M;&5S+B`J+PHN=&%B<V5T('L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C-30U-#4V.PI]"BYT86)S970@;&D@82!["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S4T-30U-CL*("`@(&)A8VMG<F]U;F0Z("-E.64Y93D[
M"GT*+G1A8G-E="!L:2YA8W1I=F5486(@82!["B`@("!C;VQO<CH@(V1D9#L*
M("`@(&)A8VMG<F]U;F0Z(",U-#4T-38["B`@("!B;W)D97(M8F]T=&]M.B`Q
M<'@@<V]L:60@(S4T-30U-CL*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A.FAO
M=F5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S4T-30U
M-CL*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I97<N("HO"BYP<F5F<T]V97)V
M:65W(&@R('L*("`@(&-O;&]R.B`C9F9F.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+TYE
M6%1G<F5Y+P``````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V-0`P,3<T,#8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O3F585&=R97DO:6YF;RYP:'``````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<R`#$P-3$U-#,Q,#8U`#`R,3`T
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O3F585&=R97DO:6YF
M;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS,R!M9&IU:VEC($5X<"`D
M"B`J+PH*)'1H96UE7VYA;64@/2!?*").95A4(BD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+TYE6%1G<F5Y+W-C<F5E;BYC<W,`````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C(R,@`Q,#4Q-30S,3`V-0`P,C$S-S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+TYE6%1G<F5Y+W-C<F5E;BYC<W,L=B`Q+C8N-BXS
M(#(P,#4O,3`O,3@@,3$Z,S0Z,3`@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@
M("!B86-K9W)O=6YD.B`C-#0T.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z
M("-A8V$Y86,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z("-A8V$Y86,[
M"GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(V%C83EA8SL*
M("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V%C83EA8SL*?0IA+"!A+F9I
M>&5D('L*("`@(&-O;&]R.B`C,S,Y.PI]"F$N=VED9V5T('L*("`@(&-O;&]R
M.B`C,#`P.PI]"F$N=VED9V5T.FAO=F5R('L*("`@(&-O;&]R.B!W:&ET93L*
M("`@(&)A8VMG<F]U;F0Z("-C8V,["GT*+FAE861E<B!["B`@("!C;VQO<CH@
M(SEF.69A,#L*("`@(&)A8VMG<F]U;F0Z(",P,#`["GT*+FAE861E<B!A('L*
M("`@(&-O;&]R.B`C.68Y9F$P.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO
M<CH@(SEF.69A,#L*("`@(&)A8VMG<F]U;F0Z(",P,#`["GT*+F)U='1O;B![
M"B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-A8V$Y
M86,["B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED(",R,C(["B`@("!B
M;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@(S(R,CL*("`@(&)O<F1E<BUT;W`Z
M('1H:6X@<V]L:60@(V1D9#L*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED
M("-D9&0["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-A
M8V$Y86,["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO
M<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-A8V$Y86,["GT*(VUE
M;G4@:#$@>PH@("`@8V]L;W(Z(",P,#`["GT*(VUE;G4@82!["B`@("!C;VQO
M<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(S@W.#<X-SL*("`@(&-O;&]R.B`C9&1D.PI]"@HO*B!3:61E8F%R
M('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B`C.3DY.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S(R,CL*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,C(R.PI]"B-E>'!A;F1"
M=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q<'@["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V]R;F9L;W=E<B\`````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8U`#`R,#`V,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C
M;W)N9FQO=V5R+V=R87!H:6-S+P``````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-C4`,#(Q-C8Q`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O9W)A<&AI8W,O=&%B7V)O='1O
M;2YG:68````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(P,0`Q,#4Q-30S,3`V-0`P,C0T
M-S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA%``!`(0@`-WCU=OAT_[^_O+T[N;IX-K@TOS\_/7W\OGY]^KMY.#D
MUN7HWN[QZNWPZ>_RZ^+EVOCX]O?W]?/U\.GLX_KZ^/O[^^ONYW=F5>/FV^3G
MW?W]_>SOZ.'DV?'S[N#CV.CKXBP`````%``!```%!N`ECF19A@`[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]C;W)N9FQO=V5R+V=R87!H:6-S+W1A8E]R:6=H="YG:68`````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$W,S``,3`U,34T,S$P-C4`,#(T,S$Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y89`!E@"$
M$`#"RLV]R];"T-K,U]_1W./>YNK>YNOF[?#M\O3Q]OGO]_KR]OGS]_CU]OCU
M]_GS^/O_____________________________________________________
M__________\L`````)`!E@``!?X@((YD:9YHJJYLZ[YP+,]T;=]XKN]O(!`.
MB%!!+!J/R*1RR6PZG]"H=$JM6J_8K';+[48=AD&@($R8S^BT>LUNN]_PN'Q.
MK]OO^+Q^S^_[_W,.@@<!!A`/B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&5
M@H,!#@NHJ:JKK*VNK["QLK.TM;:WN+FZN[R]OK_`P;6D@@,$#,C)RLO,S<[/
MT-'2T]35UM?8V=K;W-W>W^#AU<1@`N+GZ.GJZ^SM[N_PZ.0(`0WV]_CY^OO\
M_?[_``,*'$BPH,&#"!,J7,BPH<.'`\DY"!"OHL6+&#-JW,B1F42*'4.*'$FR
MI,EV'_Y/JES)LJ7+CBE?RIQ)LZ;-:#%OZMS)L^?&G#Z#"AU*5!O0HDB3*AUZ
M=*G3IU!9-HU*M:I5BU.O:MW*U5O6KF##BL4Y<:S9LVB3"0*9MJW;JVO?RIWK
M-"[=NWA]VLW+MZ_,O7X#"R8)>+#APQ<+(U[,6)WBQI`C<WLLN;)E:90O:]Z,
M+#/GSY(]@QZ]6#3ITX)-HUZ=5S7KUW)=PYZ-5C;MVV%MX]ZM53?OWU%]`Q^N
M5#CQXTS+(E\.5SGSYU"-0Y_^USGUZ\G98M_>4SKW[R&]@Q^?43SY\_',HU_/
M3CW[]^?<PY_OU3K]^XGMX]__3C[__V1I!^"`\NA'X('U"?Z(X(+;^,?@@`X^
M^%^$$NY'887W78CA?!IN^%Z''JX'8HCGC4CB>":>^%V**F['8HO7O0CC=#+.
M^%R--BZ'8X['[<CC<#[^^%N00NY&9)&W'8GD;$HN^5J33JX&992G34GE:%9>
M^5F66F[&99>7?0EF96*.&5F99C:&9IJE&<@F>VN^:5B<<J;F9IWDT8EG7WKN
MV=J=?G+79Z!T#4IH;(`>2IVABK;%:*.U)0HI<X]..E:EEN8F::;$8<HI5YY^
MVMNFHO(6:JE5G8IJ<*2N2INJKM;5:JQ/SDJKE+;>6F6NNF+):Z];_@JLE\(.
M&V:QQI*);+)G+LNLFLX^VZ:"TF#B2FVUNUZ+K:_:;AMLM]X2"VZXQXY+KK+F
MGMMLNNI"RVZ[T\++K;R@P4KO2O;>>U*^^I;$;[\C_0MP>-$.G);`!O]4<,)F
M(<PP1@X_C-7"$H,5<<7P7(RQ.QIOW-Y$(0``.P``````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]C;W)N9FQO=V5R+V=R87!H:6-S+W1A8E]L969T+F=I9@``
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`S,#,`,3`U,34T,S$P-C4`,#(T,3(Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M80<`E@#C`P"ZR=3M\O38X>?____&T]S<Y.GS]_C#T-K*UMW>YNOR]O?0V^*^
MS-?CZ>W_______\L``````<`E@``!'APR%$(D(&1%(9BA2(.AV"<1G,HJ+$L
MK8&8+5+$-G[7.YKSNB!PZ.N=?D5ADG@TRIS(IE+*?$ZMU2AVR:5VM]XP>*PM
M0\]7<QJ=97_5[;4\3G^[Q7#[7%_'W\E_>7Y[@WV`A(>&@HE\C86.C(^2D92+
MEH&8B)>:?Q$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M8V]R;F9L;W=E<B]I;F9O+G!H<```````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,C`R`#$P-3$U-#,Q,#8U`#`R,34Q-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]T:&5M97,O8V]R;F9L;W=E<B]I;F9O+G!H<"QV(#$N,2`R
M,#`T+S$P+S$W(#$Y.C,S.C,U(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?
M;F%M92`](%\H(D-O<FYF;&]W97(B*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O
M<V-R965N+F-S<P``````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C4R
M-P`Q,#4Q-30S,3`V-0`P,C(P-C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S
M+V-O<FYF;&]W97(O<V-R965N+F-S<RQV(#$N."XV+C0@,C`P-2\Q,"\Q."`Q
M,3HS-#HQ,R!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z
M("-F9F8["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA
M;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.PI]"F$@>PH@("`@8V]L;W(Z(",S
M,SD["GT*82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0IA+G=I9&=E="![
M"B`@("!C;VQO<CH@(S`P,#L*?0II;G!U="!["B`@("!F;VYT+69A;6EL>3H@
M5F5R9&%N82P@1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF
M.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<CH@,7!X('-O;&ED
M(",V-C8["GT*=&5X=&%R96$@>PH@("`@8V]L;W(Z(",S,S,["B`@("!B86-K
M9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0IS
M96QE8W0L;W!T:6]N('L*("`@(&-O;&]R.B`C,#`P,#,S.PH@("`@8F%C:V=R
M;W5N9#H@(V9C9F-F8SL*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E
M8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P-CL*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`V.PH@("`@8F%C:V=R
M;W5N9#H@(V8S9C=F.#L*?0HC<VED96)A<E!A;F5L(&$@>PH@("`@8F]R9&5R
M.B`Q<'@@<V]L:60@(V8S9C=F.#L*("`@('!A9&1I;F<M;&5F=#H@,7!X.PH@
M("`@<&%D9&EN9RUB;W1T;VTZ(#)P>#L*?0HC<VED96)A<E!A;F5L(&$Z:&]V
M97(@>PH@("`@8F%C:V=R;W5N9#H@(V-C8SL*("`@(&)O<F1E<CH@,7!X('-O
M;&ED(",P,#`["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*(V5X<&%N
M9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*?0H*+RH@365N=2!S
M='EL97,N("HO"B-M96YU('L*("`@(&)A8VMG<F]U;F0Z("-C8V-C934["B`@
M("!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(S`P-CL*("`@(&-O;&]R.B`C
M,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z(",P,#`["B`@("!F;VYT+69A
M;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M
M<VEZ93H@,3%P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P["GT*(VUE;G4@
M83IH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)O<F1E<CH@;F]N93L*
M("`@('!A9&1I;F<Z(#-P>#L*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C
M:V=R;W5N9#H@(V8S9C=F.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C9&1D.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V1D9#L*("`@
M(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z
M(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N
M8W5R<F5N=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@('!A9&1I;F<Z
M(#)P>#L*?0H*+FAE861E<B!["B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG
M<F]U;F0Z("-C8V-C934["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(S,S.3L*?0IA+FAE861E<CIH;W9E<B!["B`@("!C;VQO<CH@(S`S8SL*("`@
M('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0IA+FAE861E<B!["B`@("!B;W)D
M97(M8F]T=&]M.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@;F]N93L*
M("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PI]"BYL:6=H="!["B`@("!C
M;VQO<CH@(S,S,SL*?0HN<VUA;&QH96%D97(@>PH@("`@8F%C:V=R;W5N9"UI
M;6%G93H@;F]N93L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PH@("`@
M8V]L;W(Z(",S,S,["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I
M8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*?0HN<VUA;&QH
M96%D97(@82!["B`@("!C;VQO<CH@(S,S.3L*?0IA+G-M86QL:&5A9&5R.FAO
M=F5R('L*("`@(&-O;&]R.B`C,#-C.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG
M<F]U;F0Z("-D9&0["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE
M.3L*?0HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A<F4@
M9&5P<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K9W)O
M=6YD.B`C965E.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O=6YD
M.B`C9F9F.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K
M9W)O=6YD.B`C8V-C.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",S
M,S,["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R
M9&5R+6QE9G0Z(#%P>"!S;VQI9"`C8S1C-&(X.PH@("`@8F]R9&5R+71O<#H@
M,7!X('-O;&ED("-C-&,T8C@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P
M>#L*?0HN8G5T=&]N.FAO=F5R('L*("`@(&)A8VMG<F]U;F0Z("-C9&8["GT*
M+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z("-C-F0S9F8["GT*"B\J(%1A
M8B!S='EL97,N("HO"BYT86)S970@>PH@("`@8F%C:V=R;W5N9#H@(V9F9B!U
M<FPH(F=R87!H:6-S+W1A8E]B;W1T;VTN9VEF(BD@<F5P96%T+7@@8F]T=&]M
M.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]"BYT86)S970@;&D@>PH@("`@;6%R
M9VEN.B`P.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?<FEG
M:'0N9VEF(BD@;F\M<F5P96%T(')I9VAT('1O<#L*?0HN=&%B<V5T(&QI(&$L
M("YT86)S970@;&D@83IH;W9E<B!["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R
M87!H:6-S+W1A8E]L969T+F=I9B(I(&YO+7)E<&5A="!L969T('1O<#L*("`@
M(&UA<F=I;CH@,#L*("`@('!A9&1I;F<Z(#-P>"`Q-7!X.PH@("`@8V]L;W(Z
M(",W-C4["B`@("!B;W)D97(Z(&YO;F4["B`@("!B;W)D97(M8F]T=&]M.B`Q
M<'@@<V]L:60@(S<V-3L*?0HN=&%B<V5T(&QI(&$Z:&]V97(@>PH@("`@8V]L
M;W(Z(",S,S,["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]L
M969T+F=I9B(I(&YO+7)E<&5A="!L969T('1O<#L*?0HN=&%B<V5T(&QI+F%C
M=&EV951A8B!["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]R
M:6=H="YG:68B*2!N;RUR97!E870@<FEG:'0@=&]P.PI]"BYT86)S970@;&DN
M86-T:79E5&%B(&$@>PH@("`@8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD
M.B!U<FPH(F=R87!H:6-S+W1A8E]L969T+F=I9B(I(&YO+7)E<&5A="!L969T
M('1O<#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9F9F.PI]"BYT
M86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",Y.3D[
M"B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]L969T+F=I9B(I
M(&YO+7)E<&5A="!L969T('1O<#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C9F9F.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B<F]W;B\`````
M````````````````````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C4`,#$W,#,P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V)R;W=N+VEN9F\N<&AP````````````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#$W,``Q,#4Q-30S,3`V-0`P,C`T-C<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)R;W=N+VEN9F\N<&AP+'8@,2XQ
M(#(P,#0O,3`O,3<@,3DZ,S,Z,S0@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M
M95]N86UE(#T@7R@B0G)O=VXB*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B<F]W
M;B]S8W)E96XN8W-S````````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(U,C0`,3`U,34T,S$P-C4`,#(Q,#(Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]B<F]W;B]S8W)E96XN8W-S+'8@,2XV+C8N,B`R,#`V+S`R+S(R
M(#(R.C4U.C`W('-L=7-A<GH@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG
M<F]U;F0Z(",U,#4P-3`["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S4P
M-3`U,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V-F8V9B8CL*?0IH
M=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-3`U,#4P.PH@("`@
M<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C8V9C9F)B.PI]"F$@>PH@("`@8V]L
M;W(Z(",U,#4P-3`["GT*83IH;W9E<B!["B`@("!C;VQO<CH@(S4P-3`U,#L*
M?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S4P-3`U,#L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-E8F5B9#<["GT*+FAE861E<B!["B`@("!C;VQO
M<CH@(S4P-3`U,#L*("`@(&)A8VMG<F]U;F0Z("-B8F$["GT*+G-M86QL:&5A
M9&5R('L*("`@(&-O;&]R.B`C-3`U,#4P.PH@("`@8F%C:V=R;W5N9#H@(V)B
M83L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9&5D96)B.PI]"BYI
M=&5M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E8F5B9#<["GT*+F)U='1O
M;B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-3`U,#4P.PH@("`@8F]R9&5R
M+6)O='1O;3H@=&AI;B!S;VQI9"`C,C(T.PH@("`@8F]R9&5R+7)I9VAT.B!T
M:&EN('-O;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-C
M9F-F8F(["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C9&5D96)B.PH@
M("`@8V]L;W(Z("-F9F8["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-C9&-D8V0["GT*+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-E-F4V9&4["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-B8F$["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*?0HC;65N=2!A+F-U<G)E;G0@
M>PH@("`@8F%C:V=R;W5N9#H@(V)F8F9A83L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@
M(V5E93L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O
M<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X.PI]
M"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED(",P,#`["B`@("!B86-K9W)O=6YD.B`C8F)A.PI]"B-E
M>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q<'@["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R965N+P``````````````````````````
M```````````````````````````````````````````````````````P,#0P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-0`P
M,3<P,#$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)E96XO:6YF
M;RYP:'``````````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,3<P`#$P-3$U-#,Q,#8U`#`R,#0T,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]T:&5M97,O9W)E96XO:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS
M,SHS-2!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")'<F5E
M;B(I.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R965N+W-C<F5E;BYC<W,`````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0R-0`Q,#4Q-30S
M,3`V-0`P,C`W-S(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V=R965N+W-C
M<F5E;BYC<W,L=B`Q+C4N-BXT(#(P,#4O,3`O,3@@,3$Z,S0Z,3<@:F%N($5X
M<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C,3`T931C.PH@("`@
M<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",Q,#1E-&,["B`@("!S8W)O;&QB87(M
M87)R;W<M8V]L;W(Z(",Q,S8X-C4["GT*:'1M;"!["B`@("!S8W)O;&QB87(M
M8F%S92UC;VQO<CH@(S$P-&4T8SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO
M<CH@(S$S-C@V-3L*?0IA('L*("`@(&-O;&]R.B`C,3,V.#8U.PI]"F$Z:&]V
M97(@>PH@("`@8V]L;W(Z("-F8CDQ,#@["GT*+FAE861E<B!["B`@("!C;VQO
M<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",Q,S8X-C4["GT*+FAE861E<B!A
M('L*("`@(&-O;&]R.B`C9F9F.PI]"BYS;6%L;&AE861E<B!["B`@("!B86-K
M9W)O=6YD.B`C,3,V.#8U.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z
M("-F9F0S-C@["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9#H@(V8T9#<Y,SL*
M?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(V9B83(P.#L*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@
M(V8W93!A83L*("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C9C=E,&%A
M.PH@("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C9F9D,S8X.PH@("`@8F]R
M9&5R+6QE9G0Z('1H:6X@<V]L:60@(V9F9#,V.#L*?0HN<V5L96-T960@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V8U8S$T-#L*?0H*+RH@365N=2!S='EL
M97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9#H@(S$S-C@V-3L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M
M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C,C@X.PI]"@HO*B!3
M:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O
M=6YD.B`C,C@X.PI]"B-S:61E8F%R4&%N96P@82!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",R.#@["B`@("!P861D:6YG+6QE
M9G0Z(#%P>#L*("`@('!A9&1I;F<M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)0
M86YE;"!A.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V-C8SL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@
M("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*"B\J(%!R969E<F5N8V5S(&]V
M97)V:65W+B`J+PHN<')E9G-/=F5R=FEE=R!H,B!["B`@("!C;VQO<CH@(V9F
M9CL*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O:61E87,O````````````````````````````````````````````````
M`````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8U`#`Q-C<V-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G<F%P:&EC<R\`````````````
M````````````````````````````````````````````````````````,#`T
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C4`
M,#(P-38V`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S+V=R
M87!H:6-S+V)A8VMG<F]U;F0N<&YG````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0U
M,34V-@`Q,#4Q-30S,3`V-0`P,C,T,S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```KP```'0
M"`8```!#9+G_````!F)+1T0`_P#_`/^@O:>3````"7!(67,``"XC```N(P%X
MI3]V````!W1)344'U0(:"P\).5*(+0``(`!)1$%4>-KLO6EBX\JN-)A!N4[O
M?TF]C]["MX#OVF+T#W$`D$`.E%1E5P'WG5>V17%(YA"(!`+X?_^__\.2EI:6
MEI:6EI:6]I?:DDV0EI:6EI:6EI:6@#<M+2TM+2TM+2TM`6]:6EI:6EI:6EI:
M`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI"7C3TM+2TM+2TM+2$O"FI:6EI:6E
MI:4EX$U+2TM+2TM+2TM+P)N6EI:6EI:6EI:6@#<M+2TM+2TM+2TM`6]:6EI:
M6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI"7C3TM+2TM+2TM(2\*:E
MI:6EI:6EI:4EX$U+2TM+2TM+2TM+P)N6EI:6EI:6EI:6@#<M+2TM+2TM+2TM
M`6]:6EI:6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EIO\>039"6@#<M+2TM
M+2WM3X%/-/Z&QO?1^*XU9K.G?5/[R"9(2TM+2TO[WL"5SK\MT`GSW1&@BD'0
MW#N_=UQQ[CGZ/2TM`6]:6EI:6MH/`JFCGZ,!/!D`S=:Y9P`N!Z[=`Z@6C+,!
M8MGY/2TM`6]:6EI:6MH/,`Y\C@`8>@"7G>L@`*FMOY6+X'D_E[PW[YY'V\AC
MKM/2$O"FI:6EI:7]$/.87(^I98F9V1E`.OHW7'R6WKEPX7RETQX)C-->89FT
MEI:6EI:6]@0`M(`-SF?H`-A4-VBW+0)@C(GSI/W;E@QO6EI:6EK:('"R;&,+
M7"78>O\[8=#>=-Z7M=:[3$O`>]V8HS\M+2TM[6<:!T%7VN]])ZV$/`Z\OY+O
M+P'OV]SCM+2TM+2T;VZC#.X(DVA!52Z'KX<5D50:$MRF_7;`FY:6EI:6]D.L
M):?5T\'M@;.T]X)?^7LR\VD)>-/2TM+2TCH`:K0@0]K/`,+19TPP_-=;JC2D
MI:6EI?W38,@KFSO+X*;]_+Z`<DVK."T!;UI:6EI:VK<'N^P`G&3[_BZ3<=?R
MO];[SCZ0@#<M+2TM+>W'`=U2_.IFK>\P@<^/`[018)75XE`RC"$!;UI:6EI:
MVE\,AFQ%KU:R4VO+.^W[.351!3@)<&T_8+[G!+QI:6EI:6D_&0!YP+55+2WM
M[^\7F`3):3_74J4A+2TM+>VO-C:`;P2*T]*B?M&3/$M+P)N6EI:6EO8M@&\O
M46T$,*?]&WUFIFI;VO>U#&E(2TM+2_LG@6_T=Z_"6H+=?ZMOL-$?TA+PIJ6E
MI:6E?5NS,9L)8M.\/B+[1X:]_#V6(0UI:6EI:?^$C6Q+OY+5P\1]8>+>1ZYE
MM^+1.!\&[XL#Q_+"\__T/I.6@#<M+2TM+2T!]@!(G0537EQII#@Q`Y![@+U5
M:GDDUOEWQD./.A*9A):`-RTM+2TM+>VB]8H9</)X#\RR`]YF`%\/)*(#7*VV
M;0^@OZ)M/;`JKS5RG02Z"7C3TM+2TM+2+MHHD!H-!8B*9/08UPC$,@#/(V!Y
MM"1S"P2_HFVS#'!:`MZTM+2TM+0?!(Q'6$D.@K[18V88Z"O')/A,^RZ6*@UI
M:6EI:6G_D.')[^+-UTA+>X<EPYN6EI:6EO8/&7_#=Y/93?MNE@QO6EI:6EI:
M6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI"7C3TM+2_E7C#[_7C,I,2TM+
MP)N6EI:6UK3,6T]+2TM+P)N6EI:6EH`]+2TM+0%O6EI:6EJ"6VOOJ.65EC;:
M]UY]/',,O,%2AS<M+2WM[0LB&K]_UWO]KO?IM><.TD>*XOZ-8`MO:-?9ST>`
M&QJ`#@/?&_G<^ZQUO6=`(BX"5@[<.R_<!YPQW'M>3(RAV3[RN\<CG38X_YZ`
M-RTM+>WM@(0O``]_XEY[P..[M.<H6$!G88P6SQ:XP@#(P@#XP\3]CSSOK)/U
M[.<SWWG7O<PD6_*)^QMU/%!^3_'ED;[::T\ZP/<*Z+UR?0XZ-F5P7/C`/0%O
M6EI:VLN`V`AH>0;TSBYH'#SF%<_[.PS;U1E`"0RV#`:.&CTF!COZ$P2\W@CH
M8@"F1M]]?2S)`J#[M_WOI13UF?>WD7/USCUSWK%KH-/G'^^06W.AC#W_F#,S
M"L[1`:XSXX,O&6/^???.CR>O.7-,;TS48S,!;UI:6MIE`$<S]>I)N,_3S8)>
MN^#,`MJ801F[D_TH##_AJ]J<%9ALLWD,`"->V&,@KH.!5L#4>VZ!YY&6[$!^
M![Q%X/$`F.+,3:#9`*(>>(3X7@_D(CA?>/]D*?O?]Y]9SK\=[Y#;_SW>K#Q5
M[UGW<V"B<^VWK<\-9\@B/@%0"FD>!]7G!=BNYP/WQR&O96U[CLOSUYH%P`EX
MT]+2$NP^Q4XP.`L;C`A='NF5;,CHL1"0O<\-04%U3H.L&,".\7`]1R)^KW#?
M1"^Z>F93M]>+)`!0+.44O)[OR2JBTX##X_?@(17K"GO.!CLLSEU=9\>6\ISB
M>T=?=)A?``H`6E:8#F"6[4V)-(^_T1TV'.EMU+_P`KGJMI/\O752\9GW[/)9
M?2<!39#*S0DXWLV)TG5OVT`U['?*OAN#\^^P\T@],]*9(<<`=#U.Y%\2\*:E
MI:4]"7;]\US?7AR!X#/'V+L)^=F1$#X%YD]&S'*JT:+#X%-V8&X%3-AK8U0@
MK02@UR[/^KX"UC'8AN8!`,K))!I@HD$@RMA6-IWK%O>-AL\H#E,`*7C7X3$L
MA:#U*71;P5RGL<NOKN-]AJ`/--\Y53>I[NW`@=MWL(/#ALO#TMXU]P88BM,?
MBM-.IK]S8EX*[UVV"9V.4'3;XG$.>NU)=;#^;'LFY0+#F2_0=UBIQEW=U^G-
M?,HAJ^<);B`[9<G2TM)^O''[WQ6`R>/[5T!I*]Z-WH7<HVG^&P>RO:=FXYG%
M3PQ0*368H`NI$#UF=2J&S@&++ZOD_%W]RJ%6FGNY;+@,@TEC0,VRX5ST#W"!
MXC-XS7RT5CM%J-$Y#*6.3HE>@W>9;G]IG+\,7F.D.S.XCFQ_&L`V-DSJ>T*C
MN[:V#WK;"%=]\Z,/-?HF&EUC1E!A9`L&#N#GX#OL/JAM>XY-EL+!2(8W+2WM
MK["K$9K8@-QK`AKF%[*(V6REM!CZ:/L-P9(GXXS1#EYH+4;HLY!]G03ZB_X5
M+#IT/(ME>OLGAP-"T5A8]P65\>>272-BK^>X#O5QLRI<\@<:X.U]U@S)[NT3
M](="^!QLO0N,=RQZ#F8#N;GG\*Z':_UOOQ_BXGD8CWR.#CC3[XEX^++1+L_Z
MB9%_['6K([[:=[C=?M1CPL5'"7C3TM)^G-5;H'#FUS/2T/[NK]/^Y\T9GF5>
M_G48[-4'8AA=F,^VQ83%`5WLW13/Q1`C](Z.B'!9W0/0T;"A%EQ'CSF:*<X^
M"',7S5:2$@(0!P<L>5)/#KBP[X!P[AWZ75QV"J"=@2[P;`#=8>!6)B5F1U$^
MRKQV+=Y\W!2ROX@BT6@#U$Z6<N0&^]&44QF[Y;%SXO1Q.GW3=61:SQ[WNP2\
M:6EI/Q?L'G.GUDDXP2AU/%K%D5K&D<V$LG.:9H`YY[0.8E#&,^[.@[IT)G>+
M0]@#*0QB_AH+KV2LT#W:B3Q@!8[=]NLRC:,@H?,]CA0TL"!5+-:V_=@"2>R`
MN=;><R\6`!U0-`*B6N=Z5B[K&:`W^[<KYWY7?^-O:)_1_LX)9_G5]W3E'?.%
MS_[`T`EXT]+2?B[8C::[$'<VA.&'02^;<S%'=M!IF,U>\E4%=NU##F3\5WCK
M20##AJ9!N$7>`E.ME_=.H#5#E_9`PRL6^BO/_"HP.`HTTF+[78X!ON$[P;?N
M)PEXT]+2OBVXM5(][66ZQT)U@!3LV=`X6^,Z9.&0X+Y1]ZD..,%CG*,E@)<4
MXVS*+Y0X66H8##U306X$G/U))O$5Q\Z=L07O,7%'45'5R-W`Y+T^\_W6<_?J
MU;VNO`D:3W0EDRQRX*+K_:F^^[O`;N^99]L#$[VOK063@#<M+>W;@][QU=AL
MMSLK);P)E0(PRK\W=]9?4PZ4%+JBK*6"8`#R4.QJ>!QJE:%W@<@_N!:/`J1W
M%G<>"2P8`;XE`(2]8(51CG8&<O1<%71`>`_8]YZGU6^]ML'06V>S5$P?@(]6
M4_P)[/AH:6M>'%57P/]L^$)[ERP!;UI:VM^"CHO6ANPOSN?T[22_>+$)PP!\
M=*$3UT$,S,?*0O36)*MW^SL7TM===5RQUF<0K]Q-"V2-WLO5ZW`0'+[3@;@"
M1\J+[WOV/F+HP^!8#M\#)^^\Q2N7,JZWS?(.UGOF[?")UOF3H/_18@EXT]+2
MO@E>G0MAZ`)(-X)!B/=C!&I@'NQ>83$8HUV.7GM_[%YE)N#[O//JD3$$\Y_A
MAUX-P#*R]8?-,]_@FL]$?H^D+J;Y+9B`-RTM[8\#7>_GYT!O;R7AGP[?C"]P
M,2(`XPT>@EZ/L<2E.^AM;48JO?PQ&\!I:=\5S$=L<+?T]%\.G+/26EI:VA\'
MNC]G*?FF!LS=):-MW><BY6*8;"3CRH1^?EI:VJ79*JIRZ!6]BS[OU4#\26,V
M&=ZTM+0$O0&(_$ELXUCH0ZL6VQS<KW/<XTC7V5C/M'\#E.$[7GQ6/"#R\?ZJ
M!NL[OZ\<OV,BC0EXT]+2$NC^8]:KEA4O77SBBBPCVZ'\3?W)+;CW8T'@D+C;
MGJ/9.'B/7O&B6.3?6!HODYU_[8V7TE;[$I\1UQJD*A#HR"E4R@T\_-@IO(L&
MVE*/0^4KJ[;?__:*8?ZO.$,CG\TV20+>M+2T!+I=9/']\:ZW3+`!0%^5,?];
M%7395UFV0`X7G@T#?XOP7`7*.A>SH$BJY*'4()1>8YL+RRZ[_^QU8XYF4_7^
M;57X]1H%#4#+P?['P-.R[63Z#.F<8Q1\<0R<>6VN^N7`S]WJN6G3+'`"WK2T
MM`2Y:K;<4`?Y,[;9V09BDUCB6S\FAOO<^2KMWX'VN2.YL2:V<VZ.@^C7`Z<N
ML!M]_?P>?;!YW(R.&!UP/.N%/7//;_*=O;Y8%5^<\I[2>O-?`MZTM+2T$*G\
MA,F=+UG_O_LK`?H+?P48!4CRMN_EUC@-56OKD+A@>-2;2+#R>X'U#YMJ."&Q
M/=T&R*ZR#],$O&EI:6^:S'.5[S$0O5C"OXVE?<;WN-R=+*B0U9CK"B0U6!#I
MZ(0#AODG>]!WZ,7?Y7[^/;P?13MX_1.EO(XI_F&O.AG>M+2T!+IO7IA&=F#Y
MY'G^9O.2?_S6>=&J^(H*`?_.VYE$0%%F6]JK`'!W+F'_3;9"AP^WAB_J-K^Y
MG1+PIJ6E)=A]P^+S2GS$W_D0WPB3Q%N^/3F`[]:P[^YIS[ADK7-'T@M7T`N^
M"="=N?]_A[EFIY78Z#E3K11UI]_0S`EXT]+2G@2XV!BX!+L_]N9-?"MZN.C-
M`-=G=",`]1U`U`][T>/I?S^XEX]([S'H60CU3'`44>'Q\QY)#Z==]7'?$U1?
MU>'N'8,9O\-SMGN)BE,73,";EI;V%-C=IO1_`.ORI]TLQA_*50<P?VCIB'JJ
M"*'<4JF/<9/-GGH3,XJV5WH!.M>T*_`5SZ']G;T,<RR,%J&!5K!RK_7P=,OV
MQ"O&NBTW4,HWCO6X_+7W<ZL7^+RY?K_S/>7[:Y6-E,%13O:,>L<%2\";EI:6
M=I$\X$^Z60_H-D&6H^++-OLJ@6\D"2;![S4Q_FB#E<%G'&^0[G&MC=R1(.`K
MW@H[_8Y#9SH!<C%_C:^!!A1$I[VZR53EY$5[?_,B2]D3Q44+N6/@87'AS>TU
M!SG0-NT2+>SV?O\-_*0@C)EG=I^Q%W%COIR`-RTM;7ZB^D?"%WYTTEBK$M80
MF/3!;/3J)1"V[.[H.>:6R"MBKB/P8!0RC/<*;WL<`ZY4="<U&X@**GIP7)YY
MY.Y[H&N\0$<+Q,Y$O[/NS_)?^9#</:J-/B1,XVQ?XNA[G]%*P<!@?`U(G/D;
M!N<X_*'I:OJ9@^D`@4^<@#<M+>V?`[LM_(<.M'H;*+VX0C2!!V<7F"MQGCZ(
M?5TWF0WD>Q8NM,J`S5\!3D1H&^S*3]F5HCJOJ3?*7]EOT70OZCMDT]$(VC,J
M0]S2YW.[!7PV5]8`EB7M+(**XDF+=[SW*`VPKLH!C@+C7FA+_),-^V`C%(>!
M8W0Z5*^9MG[/&N7WX02\:6EI?SW`]9:/D8)-OP6;S08Q<NS^QRMP11N+?X+S
M89D)#8C`X)5JK'0@`2N($*<R78'8]EIC+00-GGK>3]`A&24).5]A%![`&B`2
M#BBTUP?G,J$4VH8_"!B]LQ+&SKA8FH(`'ID4>F'3S6>B,_:#"Y,3PW!W?AIC
M6SWDV1*]?LVC!^+'I8HFX$U+2PN!+O!W9;^_';JWP.X(I3Q"*(I=VOUK?$N+
M,(`&?_;-]-+&2@/L<O@E^A5MT=R6]^A(VWPV.6RR;K`$1$-5!RQRZWA*"#K4
M2$G@F20COK[W('C?.-"]^)LH&\Z!'C_BD[HCA"\>!JT8*S0<C%9?9R`X)IP:
M'L'WQ7$+?T+ZW.,F+P#>+.J<EO8O@=YZ[.<<\#1^;.'*'L;D;P+O8^CK#>?M
M!ULTG_\R-D?SZ6KPPS-.E`(E-ME+]M%ZM.1BH-EZU/:K"FOP3PZQ<;8_FJDX
MV!OXQ##'$Z,`HP<?G1*3,42R=&`0L$)Q`3H`&5';]H-V_M34_/'\Y)26EO;O
MV/<`NZ.R^7\<Y#8P6*NB42A"4%H9^E&<Y)]J+0[<4__;X;<X=@).PIB#O8JT
MUFJO<+Y9KX2\C#3?6^)T7M\C1G4SGG&Q^?YA/>R[ONW:@M'M2;RU5#?&.E]Q
MV&`[INI@:U[P0M]5L#I#&M+2T@:FP'&@\B<6T._JBDNM309WWHN@E7&%-11H
MO;E7UL5%O`B&Q]DW-%(H@@$TM4&ED\@#CM<0BMV;6$FR?<O?Q+D*P0%??WD,
M@-3(Q9B-?,C]I-FNH3OT6-KCQ%R_[VA(!GA/%&0)XJ5QN9NWA1(3\*:EI5V9
M,-FJ+B!U?[XOZ/W3R)K32"Q><-K`X)V"^]X",YJ98R$1N@Z!K%P5M3O):YY-
M*T%H)"YU`FR.+NTCXE<M]V&FFX+^6WDG^\D7]U2^N9^/Z*OA.\U%$T]'=S^(
M3[4X:`;,$=)S9"V:9,H6SSS>8B..4N],"7C3TM(FE1@F2GC]IL7NK1!\D)+B
MY53N,2BI%X@1`-I(N^_=G25P7$#.0_^U)Z_5:JMP$>;O>+FO[Z,C>8D>"'TE
M6.2;P&?KN;Z-Y[MAKB82'0D(EX(&/2\$[7;>-PY*$?K495[/^#OV]_W!]D1`
MZ.VH4S7#4_8HY=1#[LYMZ+J$O2R#!+QI:2^;^G_6QAOU_QM;&3'8"@PBRN3,
M_UO>RLDVN*">UU9P6\&J5KV_VG<P"%!&4FK:;/)H/"QM>SIP-5JF>26@=3(.
MM;=ABP:^^5VN6VM_A.\8UW\*_/SF"[,W1\W0Z<]X-#;:!O%]DOY(C3;7?DKE
MM,C)@E3^B$3.I3Q:B%IYJ77D$0EXT])^]M1_[6XWR;&G:M%33"<8@&)'F%>C
MFM>K)W=H22GVXD!YY:WC">>G%T+28CEFG:S).%@7BU*=KB=I+X$R(ZU8OG;$
MC2AJ_3/@<#9++'+Z4*[6X1B8B_9=\6U.<N00.5H-C1-(C!<:<M2GO3`L:=J7
MXE$E.\R)6>0[`&8V_&Z46KPD3.`M(T#84]$^]Z(2\*:E_6O0?)N!VHQGC_(S
MLQA;`-#,O`%.T\GHKV/,Z8&U%P"6U\36LM%(UR!4C"=?K&=F&!M&JQ.=MN?K
MWL.W4@'];G3<:-$\EEB';>!<I"XM[?V,4#F+V]^QS4EPYJ;6@W#R[T\TY+L#
MBMGP9W%-A*/EOUQQQ=_I!(Z72'8Z$R)J_\Q"6'+Y3TO[]\!N>PIZEKZ(I^7Q
M"9NOV4HFC_]>!;CB-GLEDHR6`S:![GR5M1<]^BSHDG_#]1:Y"I'?N8#3*CA]
MZ_F@;A[2_WGZO.IG'O_&BKE1Q_!+K/#XG_Z-XC@&_S[;W\;/\\2^PHCH"IV!
M;WYGYU31/M)WZ+Z^'X9"4PY9OS3J@2@^3(8W+>UO![DS*Q?06.EX12#R$NGB
M9E&/JL7+$PP*_/-[OC7W=[96+F<;]+<]Y+1`!=P=A7D6"YU^A;<SKUK@9-NC
MP/SWFT(I`\.(4=^WS"OT[W;85W&FC2H?`(Z0A!.2>&]T-'*Z5P3<<X_UP*<#
M.D=`+PX0I;?#ZZD%0;(9U;GDWW2U/G9VLH*WRT:`<B^6!P-S'\P[Q_O*S5R?
M"7FT+&P_8</S`A/PIJ6E>=[]NWQ\'=?`T57]JEQ#9[;FU#T_CQHKV:@.IL>,
M1L-W4368$HD8$SY["FB_>)5F$/:C6<WSN48`K-WN9Z>M)(;G:-\O+*3>FB>B
M9[+%-A#V0@ETRQ23ZJ<;<K8WJ*2GYP8G$6O4S7*U#$K$<*BTM'X/*#I*'JJ=
M4$6NNE4#J64`1UZ)&_4FQC=$]QA)%GT]".;4T$_`FY;V%QM'*:-+*.(%H.C9
M8YYX+'86F0&(.0&.B@(J'GNR_QWH5YE]]2N:%>7P\Y=0E)Z90O1T6GANF[G;
MODY7]Q*@GG^/<]&/E.\TE)2@<ZU&,N2F=4K.OE'6YQE"RSW6U<(0.`X;*J>7
M3]<FPUG*&2^8DU[HTI>G`!^:L(ZN2G8<_Z^Y]_A^IR8+ZKG(=B5BB'-X_QHH
M`'\"WK0_AF?2W@ARKV)7LI-O?VVR\3<S&[UD0A;LZKV,K7B8:;IV1(AWXPYY
M;$OATKOS%Y'.S^@<UQ5O@_I(#MA]U=S@)439K/_>NQKY^UR+U2#/51E0#1'J
M-=77Q$@"5:_?HI3)"EPTM;SZ+<+@#,^HF@37&`EEBCVUESB+&`2[\:4]AV*F
MS`(NC>-N<^#B1!&<M!?`\0Y6>+]F`MZTMWE5:3_U;?!M5S]V'Y\HVG:N69R!
MT`.+,[K`Q5OB9.7:9KSC:(U5&8<K>!E*!O4)C,`W'%LY-AL"]9(DG^E=#++Q
M;.RI_M>X$)LP*`GEH`#>=?BZ$0!H?6J.0,=Z.QV,84%?P:*E"3=2&-AWRFRL
MI'N<;-.H;C:>[[3J"3V'DKJ"M.>(71'_HVT*LYO3![V<].PO,N+FNU2A)*A?
MPRN\X@ZZYF\"OPEXT]+^%EC[A]/"GY^<XKIB[7GT!7&@[C3;WL*MRB^,)FU-
M[8C+;.1)#=T+B_;+')NW]L7G(/MY;SS#4P$AUW?]RG!_LXPL.E76VG0E+[5#
MHP/:T!/;_[I%_=B/=FC="AI`=;3!)6;&F/9KY'^V?I[W[MM8MCLKP:G0QJB_
MC4S`'+II+Z7.4[CM7A3!^V[$.43!-:\`OBE+EI;VEX#=5\0J7H$>GAQ62ZTJ
MBMGT;A_%5]]Y'P?@/\%O31*K;J&OG\O&NREE-([N!^S+X$H);*N'MOUW+,80
M;&OTWUAZ#-7//'J[%<\JQU^EE!:"T?-FN0UT.E%/.LYKWH%Y(,1;L\#9`83`
MV/!Z2;M=\<VBZ*DJ!KW^&4)AP^FF+^P(#%\-CAAL/(>O,=[%7R'^F`QO6MI?
M`';EOW_\?@;(F1J@URX^FV=^R0S?G&&[%=YA4'DIKZ-2O:U[LQN.<IV):J7#
M'.`/[W`H6GVBCKVMFP'=]^6#72D1A>-<(_&6P^\)DH?W_O\S^M:\WH=ZM95'
M*A*,WAIC_((&WBDE+N86!1M5YV,X7%XELM)ODZGXAVMCQ!LSWA#&=*PRA^=%
MK<B!9IK<;-^9Y3)F'C$!;UK:#P>Z?PK4ON+^`71CNL9XF6L;7ZP4/`=31R)-
ML8EB9B,XQ(8XOOP=#)U0K*`"73Q*4_O@I14-6N>?PRSH&SM*N.]K#LBWXU:I
MU%+A8):),)+6)7N>(0;/6R%&!V%Y_N"H-O,%L/L,QG/_!M/G`S6**?>`<TW^
M1R;&V;+F48$36:JX]L>N3).=6<R[=3W>$`+C:VT2=ENTWV\"WK2T!+M3WO/+
M"0RSDSM7"PG7J8%`7Y,7'HA/$'"<_.P]B[,3;,=69@G*,'9JR10Q*D,=@=T`
MX(5`TVM)-%T>RV"-++J7\(,1^4=I=&G9LR&_0[\/.FV"TBKO^V>=WVD0?N%T
MH[OGWZDR=//&6\=Z&+BG7%%$2#9F9J^^(@B-<%K$&Y3RA*2;544T$H](P)N6
MED!W=L'HK,GS)Q/08SZGGP&([?,)','.'9#[7>7W&"$R>J!G=!^;;:#:C/\H
MS22>B'GCB!)^=)W>"GHD:-'YG.Z?AZK`&8QMU1\\T*G^UKD(9YJC483J.;>W
MU_`8&_1/@^MQSG841\\`KU;HQ:!`0=]QFMDNB@ID]N)U3-\Z0>\CF1/>-(&9
M]PO'<7VQ?^,]CXFL2,";EI;6CU<MY3F)^($YL=8J?8WF0GO]$,+UD^WTU.3\
M%F>HZ-#;"*O^+@_)>2&5"$#QPD<:SHJSZ%J9*;>S1LH#LE_:,'(TG*.K[V?P
MLT>X")^+$T5Y@83=S$8T7@9L1ZZB@1."8YZ?.]#PUS`(V%HM@W>-N9X3B+Z[
MB\(2I5K4VN`\]1FG6IC-=_BR#I.`-RWMAP#2-S&[([*PK[P.'/F@/5%I=JKS
MJGQ9:2>TOLUQ)/AL/:AA(N15ZURKE"\1OO'6%F/[82R-I,_T6`LQB+UD7*!!
M;0'AR\!Q.SZCV:XU>JENL_%58W<<^*KQ/E(\H06R&#D[HP_F)/HU>U_T_O%$
M[X[2H1KE<S'QZKQ*RA-@=H:=Y.Q0??5TT:X+<T[*HI-*7>U'SH6</ATP7)5Y
M'J4>:K?B9=J\XED3\*:E_8L`^C=>)-2W%-N[Y,R2%T&U^BA6=>;%67%-[NO2
M>MU+:+J815-5IF4'[#:V?SFPB"-L82\0@=6Q\::O%U?;@!Y&GY0<?PX)>EWH
M_\*,IJ?V*>AW#9;Q30F_.\R`UU$]LG?`-`RT++2_A><N\<[=FQD!#,3X],*%
M<12"4>3`%@(A0:M,1)4D!,5W]Y_1K)F"B<:/9$+.=QQLQ$R_YP2\:6G?&9B^
M@=E]"]B]7/5V[(AJL7!!2;U<A6"7?&\;M7*E+)O$N0A)Z3!XGT;5R+P;ZRZD
M+$U1>`EO&T%^XMLC'%A#<&U_=8S:871<B3._*!![!__GW4MV```@`$E$051\
MPUB+(M5C1`0#XC=WPRE+O)<8J-S#J-R847QP?;<98N^J@T&,.9`3YV?O7G_3
MG-LK@H'2+]%;M07DKM=995!E07:&PZZL0[)=/KU0@6QZ`!FEC!6I[K.^HTY-
M%IY(2TNP^Y*37DD^B-E=CIV+$6"*JE-)U?9KW-+,),MM7=ZW6;D_\[YX["`.
MFH&4\)`&<W"8[HD!9J^TP?,-T>/*,`AV,=!79$&'%PV*QG7JZY[L-5\Z*ADC
M>MM)O!=+A]=E<4I7GV5E*9ZI`M$2Z%*,,CA#BR6N&.,5H!M5'?3$`3S_Z-D,
M6[(=E?&'@_C9<2FKV=.^+^!@?@\LO/VM"68GUB5YG,XK0-%9<##S-LI('?9F
M(0K(2VW_`Y+A34O[V\'N[Y.V>L4ZP!C+3B]<<"?^2)OI%:PNO1N6A1SH.`ER
MNW`'P"7&.!HDC*;2O#`\HP-P=32UWR-LC*K-V>90(&T-,GLR1RWLTN]L,*`7
M%ST#]E$:&[)/H@0RCM`<G'&5@@T#`S>`K?1+U&U)V^8T"!AU>(UI>SC]MXJS
M%AA(ACRII$0.OJ[2`+W=O"KXQ[:H5UR<ZMZ0XZ?:'0)@HG,Y<EM[$+?+Q-JD
M'K$J7\W)QIM0468IR[(<@'>W!+QI:=\,Z+ZJ1/!EV;#1K<`W(.EFV$)7;G=(
M`J)X5<M>MLJ$E1SHE'V"`!Z38),E`%TLY3K7V5S+;,BSWI&D?DQ'BLM[#:H9
MYMT@X<2<O]M70+2<H`X]I)[-07)VL/2"SJT@JBR\$A2GPG'IW:&`#I_8SH?M
MW'XUZIDZ<C)>T],'CIR8EC-"4X:6[OU9:;8Z*?'1F1"`3[5U+O2?,3-%0+2Y
M4C(P:;*($&:95>HJPU%!D:27#3?I]&BME;</%`JB)9AT>'URK/(P66IY%4\$
MF,X\8QZXJL$)']DGX$U+^T9@5_[[>R]>PNI,OPOOTDE,&B3YV@C=!2HOKC(Z
ME=KOL6N&VFJ6GO,YQEF8R^%@:W^[GM9W\,(_J8\=Z4@]/V?H()=`Q1RA='P7
M]67I,%^FSQJ="H7LCT0_ZG!&TB)'5-`P3`EDZV7RXJ0PJ%J!SA\4A2L>%DY0
M]N$(Q#L6;,3UJ+$(#:1#]M_<"AT@'5T'K2T#HTH3#-RV4U\B9ZGQ?1/L3XB8
M70?(KF3AZL7'>.Q')'+M#4#X,-7H0X,>$$?[N:(E;$$!_&C=!+QI:7\C>'[Y
M@>-,X'4.`$ZA@<EG0&-FQ"B*?BW8;6LB1"M;BW<[6^KR3BH=DB<$Y&V4Z,DG
M<PBUMI=-_XHH'D./T@<=N%B0CZ6NX%LM[Y9AE"RA`Q)"G=]B:4;QLI3C9MAD
MOKI@[NPX&:7K&S1JB#"=%P?K<6'`JW,DXJ;FM+J-8=5"6JUI^R0Z/D/KPU84
MD^MKF)U#P:ZNZ_J(VW4O,8K0&XFF3K^,5$/.8CZZKX]N.F)7I/":(F7)TM*^
M`3A]$7J\&.;Z+:HG\.*S7COSW-8<AVYT3/4!$T_&0*[GQ957G:UHVYLPWO8#
MF7`VM9"-9W)#&9SH`3:Z-!R0W(V,L%$'(EZ:WKZU`#YD[\UW>B^@8VSAB`;;
MO7[@`+TSL#>NB<;P.+<O!T5C3'2OV+UF[44$>M#J=R^&5&Z-/SE;C#L"];OF
M%7E#6[R0OF_G[L#)6.?.Y'(DHD$4^F4YP*['W=;%B-CP85O!,RUGC$>BG&7C
M1Z>5_:S+LM3OQT0V).!-2_L+P.XT^.GM>C9$[_F2^_05<I]%<.?6)5T6CKT4
M)7?AGMD[;R^S?,G+F0&P(\?IK4<MK87AD,060,(X'FX_]T:ADAQNJ2,$@/JI
M%'D*P;H9`K%.L*F?A!3@U+TQ"^98(QP;Z.R&.-$'^61S*/,%O8WFC`S'01U?
M&<>=HNFJ^#L^#EM(AJ,5SFAL59#S6A+5-;WO:V<5O<F4WL1:T_Y\R;2`4U)L
M^\L#[,:]6O]]O&1)')##<")"*0IXCTUH.!S?!5!#R&M6).!-2_OY0)>S!_]&
M/<FVIRYU2\5B%ZS0,V5]9]8&B$53,T@CG#F;1_+M_<@\"\I%FK\H::H6N^(3
M452P`*6]D+H+OIM"KAD]SB#ZCL-U`H%2T954E&VO^:0&'2>'&4YPQ'89E1:;
M?:7"UU""JJW"Y5:`<W3+T/&6(9TINN6?/:#LYX9)\'G&FX_EB]5%#NQ6/DNH
MT!;<:8F=^<[=]'6L?0!-VJ>PA^H,OIW9?;6A,4>,S4(8)Q7$=&$3O8^8>'/M
MU.%-2_O!8/>5J+6J-G4AG/8EM\+.O;W+W"`\/MNL;VE$J4F+$3+DA;?E`^(3
M)C3U,0\1XA@O^?T.;WKW>Y:2_-<!LT.-`B'N'VM!PUQ[!+3&QYPP`:56-.TC
M#.C!Q1[8E4EGQ0A#%]=)4$RG8<`KT0?5>=#,H:5X>A:].X$V5%+:R1&P/,&T
M/(IF/N*A\SJ_GX.VX^`"OTCDF,+Q9-6]'UU[4ZNN=';A3[*CWCO[<)WE];M;
M-BX:%<N+LP=MQR7#FY;VD\'SA0-'V"!V)I?^I5A*N&D8T4SO!]C-ZTRBQ:&8
MZ59D!%K0)@:ZQ<$A'534?W[+;J,'>)YP*@18\,\O);>V&+].A^`@I)CR*$9[
MKE?7V-G$11G892ASNQ/^5C,:6\A.W&PKWZCJ9//MQ:@/-#7PZLI:42IE%+A0
MP];ZCEA<<>MB5:UV%OK1%-LYH<MVR$T*%=S`^K$!>[<C&9[&X>@XGOXX0%G7
M56:'*>@?@M[6]@+:[QSE+5+#5;ECR#X#XR)G:>&TM-\(3/]4K.Z++D1<^W(4
M`=>]WK?U'-J.@7N^!G-28TB.XPF3VS05N!F!D%8V&CH.2J`A?8:N:!U9#R"Z
MOUTL$H+7#-QJW9\KG3TNJ?]\OQ<=(=P5%LEB[!<HJ0$]M7/2+LD5.CM-(-UP
MJN@Z71AH$^]XAJ?1X>UTQBM.,"L+AY7383OZ_I&,1:V,HAZE5SJN!"*VT=MK
MU5QF%7N`7N^T<FAL=9CV'=DW@&?[/'58#!K`/`%O6MH/`[N70>MO`(3#J0W5
M_B[_</NP.TE?;2=/B][3[^<D"7:)$NP=PC9V>:SI##&-9EI,8@^U&]2\$'M2
M1LZ*R7))9[D'B?`D,!V*H1W]G)W#1J2&^22\%N^H%W&J*ZVQJ:PQ=,UH4,!$
MY3*0,IM];`3]RG/"@J(<.Q,L'53%,2O&MY0A85Y79Z]N??G("Z#\(=C3F;%Y
M@G:$%?/"`=.3$G\U\!55!MT"%]N_&<.;EO9FL/NJRFG"/W\Y4!V:^#%VV-1]
M\U6(?.2N=H%4_3#+HK4;]Z4"4^=6A$,W\<M.]KU2PJ]X/S;JS]T4#18I0(<X
M[S'$5O=R![0*[/)J[3<.]"\3$^P%$+/]UMCX[-7JMKZS5]H2IK:3F(#=@U@4
M8L"P_4**`&!LBFA5)^,D8,7\Q*D#U4=ZB*\+=WWR1`.#FG?7=4R#02=O.7ID
M\FJ#:JUNJ=`@QZE^1%2=I(ZC-BC9[C`-2A-Z<^0\-W2>Z5$X0\;/UYT]&=ZT
MM-\`>E^Y3@X=.%TZETT0!U<;=O:&@K]>I%.;(:6`D9;:4DM0A-YC:V7A?+M-
M)OEQD-!JV4-[\GQF!MG70R0P_5=A"7!-MD4))=!,V'2W\35E63E*Z",L=(=(
M]S,^,V@A&"@K6X8&@($#=`=!=%01CJQ!?#,\$]W9P6TS!,["E>S]**2EWN%_
M<:0HQ^?8ET[B:(/>*A:8495U\6:WRF.8N/4H_$`I8UR1![%3IBT%/>TD6?$S
M.NF.3,";EO;=@2ZO?N$IR0!33:B@28E=?4J4]N(\?T*<(8H0>=-;!DJ=AX5C
M6U9KM$XTW^L+MPT^ZL:L`AHWW6Z/*7]]E`L]2]FV%CJ.$C/#?9!/G$$6,FXW
MKZ>-NB,&\2U``V09PAHNH.,Q(=U\1%%MK5+68/`]SE^/@V.S6=3#)G_Q$HZI
MR#\,.EWH>'L1^>WI&O=B1]TYZ*E!65XE4CZ,_QEZ#T8D39;_.W2LQSTJG1RY
M.Z-64!)C!6EZG['V8<A&:6:9(GAH#=/-'$G`FY;V#8'N929IB(C@U`DYXLVW
MSCU0/?24%*(I==`E>THI&]-IP-]8=5L4<CVH!E[-7GLUYFTLGEI[5#PE-@:[
M+`6W4I8M/O`A0_0`OZ2_NOSN+LN6X],"2?2X)GL>HXO:K"?[/'#QF,W>Z2-@
MS:GACDJE852GVG\"7+J7:/YYF0-52E=J+*J!U[N/L>+9DR`.K^E7\^O.Z=])
MNRTW]6#+LA2NZ\,A=@%RKT_2[8MJK:@F^E[Y&C_XEYQ_?@W2]6J2@#<M[96+
M^!;7>!7TOCJQ[!K8?<&-L0V]X[4"<>$)KS+8UM[1=N80M%<2/9U5R5L5T:F&
M=&4Y55OA_G,3+"C+P6(#'K,C^B-9[NO]CX#;7EY]-_Q/4([=,K=A2\,CO_P[
M1N-&9#!SD.7>PCM\$0QDX0OG#XR-9[RP$W0NPX$^XL7!7TTX]1)++P'@Z`;X
MNP<<R[(L!4N]'@$H"S:)LF9P\]@6%B.I-Z?3(`2Y@:MFY,8.H0F,]'P1HTQF
MTEI:VNL][>M@%[/K"MN`X1TA9F6""YA:6#'BO9LG-<D[LQ$&TXRN!4NHBD<%
M[8%K':+Q1PI*IP:[SIH!E&6Y.;[!:V(?KR@7L`Q(N\FT:_C1Y'%Q`?DSXQ)P
MO0$D,K@.!\D6&.M@0UOF`"_W>%_X\J*:!Q?Q\FP7X^#76=HL.B9NA1/-\7[V
MX@D["C`L!7OL[C%'V&,03VRR8[,T7$N4HHIOH/F6]#CQF%V3=,;6>!SO9`EX
MT])>O5[@.H"XMAU90AW%=@X'G*Q<?])"0^NISN<52@A[@IA110C9V`U(T#TF
MF.D&8@SQY*(4[8B[1:;8OK+.B^YC#C:6XSU<`1.(8UD>H/<9L,NA=D:UG'D@
MM'D%%*WW:E+8O:2K'E/,K=(;>Z"7^D?:BD[R=CBN##?T_'S'Q-1!BDY0<%5\
MCA/7X)OFU\&#6M7^.#03^\T4*["@<1RZRBVCSF`[EET7G7@DM-:QO)[#2UD!
M44E'V(LSI!;HO80&T8"C7:C^[78`=-J/L>I-AC2DI3T[&3^[W>=,7;SR!8R4
MF3V_,'N[K2U%?P<XKH[NPWQ=/:=6A@P>FF>:\O0"AQ(*\(?OF'YV<;OMV)R_
M)=OA;E1[8JNE/.*/!WF+H[;$@K(095UIVGS,>>C)W5L7Z(@W)6.<'3H*<!I;
M]PM.#12'B14%$$+-Y!*'K;QTUWIT'U[HCC8%<)W.MB<L>3ZE+`@"^S:CX'@O
M@ZX7LAD^\,"@BK1>35$'KVF>@=<C##`%24"W#IY,\2INGRN-.34,W!),+4HI
MR^UVLK=298=Z_%!D4=K:F,2^3D2C'E.P_'P(6:$.0?@*_12X2#91ONS&>T_`
MFY9V&>CN,D.V'-D?V,N"#W`8QM(.(/0!MII%;I>=3)P$$]@EPK:D*0O]#GU(
MB2KA('89WDO-+*Q<RX+Y#:O'_=$)F="R9T"40#4/=FMF!(H)<I&VU8D2IUG)
MAZC\8"=!]WZ#A"\8-TDH'333G;9XXPH]AE69V*C-%P5X#V`H^U(#S_"E<?08
M:60-TL[NSZ./'MGGU%7KO.M2>62ZD``E74LHU%6/S(:6,B$+BP48VX%I5B/8
M80C1<#J!TI"HJ+6&W?L*P?`S664<&/-E:G>G-,D$\YEP8AYA2V='@IGO]CF8
MZUJ1$VZ_@M63[T0WMP*A'24)KSRT['^A>@ETNS[F?S0("R;@34M[%O2^8JE\
MBB1V*W6A6CC=A4P(.5;$B65-Z:<CR(EPM=<2BS:$QDRWU<@*Z"!"\=MB?+W(
M!V)8VM&RGP*ZKE@FVPM(IWSK@Z499WGW^VII\Q>R,&AG78\4VM?3JE]]8$T_
M(M"VB%NA#O!UN-P_B5*X0)>?DNW.`:#:!+ALL)T4/@Q]S=LBB@705*K38-1_
MFUK)@?ZML<=J^FJZE,"W:':X61[8`.FXZ1SE"*>=8,YQL+N=)-ZC:AA,3Z#N
M,D,(-;H0+DSP=M@A/JVU/4D-BL&O;X+K:JX5!TO03H*JM'3L6*"WW5:A6+;[
M2N-<>Q*>VX_XF",SI"$M[2+(?47UM*GM]\8LQ]87$(/B(^N=EI.!6$P8Q--*
MP+R!W<X6.5H%']`3^CW%T_6S;'=,O+2J'9_Z;J?8@K=2-RE*"R*N2_<<`&D'
M<]*QZ)5O+1)HPB_^(%A?F^>BM3_[_3=DO:"IPBA2@F+!!B;?<?C\\5"L%GV>
MMTIH<`DAEL]BQ$9WA\."#`G>#R?#0U(R2*;Q'KVQJ,",B3BVHJB4]V_`4-27
M-N:1!@2"_9V0`ZQ%X45&JY4MBE1MRFE6^2"^$5=W1F]JCN(4KDI(F$W$NE50
MEMNR[:9Y2:RFJ,X&`/OJ"\[/6]X`&P5!NJ6()QK#]@LXA9&6Y;RJQ?#DOC8E
MPYN6-@UV6Z#NW6!J9$U6BRU&SF'I7<$$[*"WE(@?TEJOC3:+P.C._JX6@)F%
M&.6Q?1]N"UY\)Y;,Y*M>4F_!LPLC>CV$-?U^M*N._T6O]U4,+COKC@1@`]7-
M/-]+@.4:#[3V03O.0&-LL6BVKG**+E0<:-X915@X',`@JJ[5)T7P;IS!+H\!
MPN-HG,U^^5T&(+7X3JAM!0Y430`JJC;D%UO=P4%CG"AO*W$\&X]'^,/0NMU[
M'*GUWUV6,JJ$,8HZ#>N[+$M9CF(T<2_=XW:?E28<)6O0FA-M=9-A41LY]Y4"
MH<'NW<PCS&,IZ[HFX$U+^SWV3&G>>G'FS!=8>\H\9[_&C.4E48DL]^)5ZVE/
MD*'0.U"64A3H56#)LD(1'EQ9L%Q7'KA"OL2<Y(!#$C4.')1T[-.B<AC&XW,?
MYZB3L5!GYIDE'090,XBWI"4#@S7-Z@MK)C9F+GE1.T\ZJR@(%];6PKTSX8]8
M2.L+Z"A4E$'V_5*\C!B!$OB:!+RC?XB7XE8@.^*#'?;0,+JMWCZT@U^!:D33
MG.JD[ZJ&QM[@'V(H#4A62GIZ#H94,(G"5,K@=KY(1-W?/T(GLFS%9UY)N[1O
MK7K#C-<T]26W:]3SWE%:W0D?8>%6:GU?!E.6+"UM<'VQ#.:%J1?/3R3=$HYF
M(H]9SP9(59H^U"0/S82V)Z)Q<)UQ&"C:+5"OS2)F3"Z_N.)0[(N$V`:^O!:8
MC!HVFM7\KO*VC]UD:*#*FFY:EN6<]"?N$\OB/*A5B;522SJQ!#+#2CP01!&/
MG7'R>YN1&5,A-C:V]`2[J&]S\+%/4$"49F5";[A*L'M<&J%;H9ZI+90U@`D[
MH.*(O79DVXH(7W%\R:V*(A696E4UJ\*>Y#6LG"',+(6AH</J7`/`"CVI/R-X
MU01[G,2!:"+D0VZ+]1BO<1XJL#OB1#]"&6XJ.7B&$FD[_RPO`\886M@:QYIR
M%=CFL,8<P'5/DGZ46B^E).!-2WLG<N4,;=@0CJR+&V#J!IZ=MO8)=72G\)B`
MQ7_2:;#?7=<`-/.<V%LA"WOIXWFPRGKS;[(@FL/SN)J@K7O76L<:Z*H<+14N
M:35UQ[O68P'P5PH7A#MGJC1J!:M[+-<5H.T-)2AE#`VZ<3*K`QVQE0QY.&N-
M-=?=C8#05'7S"75BW)4PFT[.E[A_*X,E'=UV30W]-ED=%]5PTXEN%MK)G]`0
MCJO!L1UXWCVY]TSG^<7_ZN_*(L1>)V(9+(M2VG7^&(X="\+95J"MGL?:4H%=
MV[ZLQJ67`R"311_C&H5\44X$!XESB@'@R#"B%`?<^T[.F5AYGCM#&M+2F@/U
M.4]YN$3EQ&5\30')OG&,`V[HB4IF!T)_*"P3#\U<G%N^0N\Q`O-P!+DH(=^B
M)WQ7A)QFV;O"9O3?`P,JXJKV?BTQ9<LO/UZ`RB/:OG>[W4;J<%2VKFM9N9[/
M$SXZ/:[/E0ZC$P)L64IV@6F#+>M_.:[H"GV3D.H+^\].*(!"Z5*YHBIU6LL$
M1&Q>5$RUU7<XH_/<"^+&M>FG`IRN1&HKV]Z7+4`8S@`3/.%+6/E`UFRF;^^,
MLB_A!.6(M*^=N19ZTM'%49J`F.["0.AVH&0X!K&FSHU`.)*Y,0(J#\(2WY43
MQT)"#(]`PWFP3PVE--@8=I-3LMA2\H'$GT?F)^!-2QN`ERZ],G`\1U:4`+M*
MS<3V5T;`+L/)860B"A]#L,V2O249SD?QO7L@%`J45=^4@A%EG)ZEF1T;>+Q2
M,^TVTH3_PJK/.+RB7(BV>.;;QTW%ZPU?CRSK?>U)%*C6/_M5$8LSN\_<4E13
MD-`D2C[`Y4`.GPNKX/>1UKE@%4=*G5S53=SRAAE=IY?"T;/.Y=$$YM9&9*T0
M`-&F-SX\3IQ1P(C4M,Z1`'%%ZTH3]!TJ-Y[=!+Y7S\#SA<N$J""(7(4-3,R+
M!W2&GK404!$G@-\+A;!B\:L5`_&X@<U8$W1$"-WW"H-1F%M4%YLP(/@UC&_4
M'>%Y>$+5YE2@N!;1G8`W+2T$![,?X)K<#(JC_8CV?3F5J73<5P"&T&9VO=M;
M.@REQ\"Q!QQ/*OA<_&D!BW-NUO.S?,YE4)9,\M5V$6@4RQP#N[-UH6=\KU+*
M3511FMU_N-]7=VN4GL-UT*-G4A2WS@?T41CI]P!ZS%^0L7TP/IWX2@4B65JA
MU+6><Z1(H)+<["VV-OT?MI(J#(C%[[0VC$;BNHJOY!"'&/8?JWU,NCO'M<\5
M);25&L=Z!6,J&J\2'(EW&L!8Z@\,=)HEUBT^-HXY@<8.&?RQXLV!-:BO$X?A
M?-+;%91NU(+E3))$.4(0)"-[EM-F6==5Z.H67[16ZK$%8=@C2;Y7*WF6AD^J
MUDA$=[`E]ZZR>,7CWP2\:6G7R(^IP=N:1(]MZI&M2U?8D)WMZ'ELY<TVH>R8
M][,%!8BJB*'HJD_LKN!LW.:"N*ZI"P[XJ-(F5T:$K$^ME^K=:)/99"GC4L&U
MDL!MKZ)TH9,^DCA6K;+A*7.@]I(`'O`TSIR6&])5JP2+DYM%I<BY'6QUF:&]
MCZ'M5+H@5X%?N`P=O)T;#\^)&.OASNMH"2NG#M8)B(DP"YHDFZB^1[\(G0V?
M:47[-$LP#Y"61RA,0Q5O5K&KYWA[;6S#=YHU8BZ\T\A)OAH*M?<O8"FGRHF8
M3EFO$#*4Z6Q_X\RIL1"\-<P]?E.!<9)\TL4TG.(:E*^*QD%(AC<MK3%8O<+P
MPT3?,"+VYE)/O[WE[[\"E%\%POT3PZ?C5$OS43S"G5]Q5`=KR6`!RU",(KW)
MU%-G`^HEW5W5(29E#C79&/"MEX9EP42'T\OZNJZ"8(OCL4^L#QW68'&^X&AM
M`AQ=O+EM26X(S-L5`.MW7P;<.8:>ZMG0B-0BR,HU<LH=!!RUP_CUWH^C>%*[
M`G3Z5M'@QIVOMM_WG9-B?;.:5Y02:U*O^$IR;KQ;'I^/`4&@D7X=VR'?!4(N
M5[XW'39ARPS32V`M,$46T'6^NFPRY^=G./T:6R$>THY%#6CWP@OW^ZK7EU+O
M`TKGLA+9JY`K?<_+>%N$+[7&TJX"WAX\@<.MB`NHM\UD>-/2>G/1E.+MV+F[
M(06=R$PV%ML)4G=D&U25!':`0@4DZ0@K!C(S+(V2QP&DC]G=1>G1CKZ7E1/1
MMO2!%#LQ(P$1'$[T;"RK]_OZD"&R99\-/+2I04>R"H/'L50<(1*!>BP?FGGI
M\C[H%,XH8$TJ':+_[`X#"N!6)#@YJF\Q@`/Q^#Q#$>1W.Z6&W7<2-D;'*4.@
M:0OM0"B-5P$"51@08C3J@6<R&(,V_,2V@?Q<`E*=7T"7MK-P$T&LQ4EATJIA
MP(.>`@I*&METV+U,<AV<;)Y=19_700BKFMG@1C/+B%OAPI0P`,.I,6+970EB
M9=ONDI'K>B^V6)!U']AR36`FLVWN1S<>&)6T!T7B6QBN&R\Y#:)`C']W&R0K
MK:6EO8[Q=`LUU-!@C^GRY@J@J(EJCG$=6WCGMLQFRU#)"0X#66_UXNM4434,
MEUX$(21LZ!2W;`*=C49WG0ZR">(*V712V'IN`QB("&`451SMSK4L7`H1N08(
M2"7J3':S&-"Y80L3H_A(A:E*NZG/[6N$815<G62MYJBSQ5!TYR%-OXS.J_H=
M140)?,<%`9TM0-P(X]LKK7SL<`A`>3*X)LY!/KN,\_:JLAD4P8#I/L,<6!42
MT7B/+FA6NPF>`T..C%3_OL.&I$^S-K7:Z.H_2.:3@7MR-IQ\;]$^"JO0-`LU
MH4I.BV:650O%,39^F3S'Q7V]FZ1<S7W6_<W9H:%1CFD.(YE3PD-2$F8B84.S
MT\KM70F!\!RW!+QI:26..WL90!;57L)A#KV`]SC*,)@!SG<G-=4E6WJ68Q4L
METQLLOH(<MWU8C0]*J^+Y'WD`*#13/VILBE)Y4!LNEMX4(SW\?B,ZU)YF=:M
M1]_QFI3DX<%$CBP)T`EH'F,K0!0$YQ-C0YVD"8>U]U\O&NF`.!C9L6'%QOO&
M,+MJ7_2ND-+OPY$3PRH13;.C)\MW;)D#=3`KQ&?%H;^:F(^^`H4%NH:IHT?J
M%1W::>/@X<PQ;#D]_5=01OP+M$;[M7*)UXF"?4Y3A(9FE5%/&>;5Q+L1$@2N
M*PMN"*JVG>!WW<(9;`DXFA<IL2<;L^](Q(XL:"*U??M;'_YZ*9/.9$)W]*Z5
M))E\)ZG#FY;VNB*+;+$.C2UMZ9TW&80>J`E!WQQ-K%GFQXP,RX(JG'G.YA"@
MJ:F]VW@36O>Q=$79CQKV%D@.1=OYH$D]K]#L=).ZQ*KEX_F`N6J^5BCJ]U@[
MET6$?B`H#E%?9Q?$6.G0N?L][N!'/&!,T*,T"VD%9;`YC#HUR)+)*8\^R4:5
MD-@!`)KKJZ@*Q[B>@+G-HZ_:Y'=G]Q_03@%)EX64X1E2Z>$HP"+*R#+8*K*?
M'>6#9?PT69:@K#`;KN=L6"HGCE6)=IT<5@ZYQ3YH''L"Q'T@VO^1A1.H9!R.
M,`QXOHOMZTX?@]1YYGF9J#KONJZZ#+5QQ#W5B][[;[`DP0BL.>\A8N,(:]K^
MWU814Q:D095BL8U>KH>BC&S;!+QI"79[8^\JA/37LHGSH3%]<.J>9UJD4JTA
MN\K-I=P``"``241!5-6:CJU6>@PB`_I`7\B/SVK7?,*#]IQ,_37;_I[X.AP4
M--C(=!E(N)0*)OO2NJ[EMMQ4S&H'(9XL\;(4W.].#.)V;@:?.(]P@&[%6(I_
M086+35AM2))[:ZB5-WOX5&B`CCI)AA:/!`C+#Q&0(,;9>F4?O!VG@>[L$@`H
M.3(:>3/E2$&QLRZC&QSK,74K^?Q\^88YF1RY;JWC[1W?*O91!P;T)O^!S`@:
MRG&'I3OX1)1L03<4C&8:6I:E%"Q6GTNW6U!J>K9V7'=J=7629QW=#J3>R13X
M.1H481*TK+8X<P+>M`2[O^&D\SG/&)S:GWO&(V[O8'V@DA_8HU-"QFP0VM//
ML*>SOK"J_'6RZD==]8F6AI#]HD)A=*@[*TJI&X,!@$4EVFZ23-C*78?[OLB'
M_J8+=!K(<<$CJ4:UI(BWU@6-Q8X%/*%[N.\,`6"Q*3\5:U7AMA,,GIK#(A6(
M;8&I\_VB6]6L=GCV+5#&#^0MS]L#N<`B>%"46@O&SP>#8/:V=MA#:&1(#:U$
MGF"*&TPMWC`?GJ%03YVD(V<R)G15A^[Z\Y.GZ*#VCE1U#Q8;XZ+O!,Y<@'JP
M0-"UU$E=+?`'!-)WVWE7D9^`#JCMS=0#=6J&BZ2P<R)$(RR(7K/[=`\U&I\H
M61+VI"78G?0V?PO`ULL1&U-"=?CP]<3YQ=8;*<['4IJ!G([>X]1S!DR&ORAA
MH%7GWAD6R][BK)WJH'U/DDIR*/8K=2UZ5,X&38A=O4EIGGBUKP]#U2X`",>@
M'4:MI-F</L"C9+37'>R>:=TK6F#WB)NE^+;8.?"*A+!@A\=%%RS1,#O,64(@
MD$1_F-%AL/:JB.YP<8$)-&"5Q\I8;0F[9&S]#NBC@@WP*QAZU1NO@=VVSO#3
M8-=K-Q50/*H!A^Z[4*6@3V'GTX]T&\J<^TCRA>-22&=DK[Q!O_,+)X6.$W,Z
MS'#[I746@$WN$7!2>OO_S?@F[>]AZ'>*]R'G&!G:<[#=L$YW':`F6ST9WK0$
MN]U)G=/?[;)*348/%;CRA?S9!)^]Z[-;]WBTGJG]E=V)L<)I@CE<EF7STD?.
MABF(6R=RPP2W^H&;C$"OS1:I\\**%5ZUP$4NPKBJR&X9,8DFQ3%[VU8QRNK>
MFS6!]2/!7[C._/0Z\%7V.U;U=1LO;$C.B[X(L*<&(3+=918ZJ"O+1;&A,F0`
ML_,+!&@Q"9.N+)B0F1H=GYR1>?&E;N-CHB>-,LO4=WOI9XU6[.UDC,SV0=$1
MEKKR'NG-Q9T"0L<SR[[M_&R!KFGGL)KBQISO<\BY(R>JU1TRA.=-D=<#"X;W
MS73(LLEKK55`_"M"05<)['=6NU5V?`'*/:C\F0QO6MJK@#+[T_@,6X)C4[;E
M,1M62S!$?;`+AZE@_`1HW3IK'H\!*P;-,.)(1EC*<EO$AXU8UU'Q=B=S64[,
MCQ#@Q66:J<2\SHQH=R^88QU(@QI.@1,6&PM'/^N%U)0+Q-8^4&[++6Y+N-W*
M80K/OED!AE+T(BP9("_S$1W`-,3?L91&DJ2_$5"'L$"RJP+(5J,#>AN[PRGV
M/;_6=]@[+X?![<$8]L0M,#'^W3%_S@9TF4R:BWF\(AJ)B:-SJ=.1Y>_LL8^1
M)K&GO"+[HM.^\&[)R#?(N2*L<Z/![GE*6V+^,LOC3@_AK@!*,V:B[98AF``0
M]'C$;`O[CYH,;UJ"UE=]!^,#KW<>``$YP=BEAO:,FP[X<:\M'M@(QK-57,V)
MI?2"$5DOJ(^M]G/A6U?Q#&AD%1]N^T#\7J\&JBVE6W$1C=)X4G/52XJ24D`.
M&=ME`HW2`RS(K4(:/%7],\/_P?+N[*76A6X%C>C%U5N#$/0A]F,`T0"^*'U&
MK>HH9J&M->AU.SHQ%H_<H9HEEVH'MG=XH^F4.$/-+E;OFN%8I;=[8/!2U]FN
M6$,>B@X>L)MGKHN*?=Z=+!5)JL;^?AR<F80]/:N@C_@#&VZ'Z\(Y_Y)*%<`'
M<%[83J6280&RV95!4!I]EV>(B1"6TBB%S=*N'#<FS;;UD,[.C+R;>EECUY]B
ME,3G5.M<U[6LZQI&X"7@3?O[0>X5Y>H+$)E7$2X"75:77#'5I*H0?ZBZ#]Z-
MT46"&KR&B0->-;=0YLE,[/1G7Y+ED4W%,[Y0+``NV+12:*6N>@;X;>EF!7E;
MC1%4L^"=[?I\1`QF7<6`IA22_MXA"P<!%SI(FB+9R<5?08I[!>K0CZIF(&T_
M7%@"_;'&SOAC]$Q%$XEP,N=9C"S8GDQWL,&E++@=VZS[WQD,&(I$(LJ%66PW
MK_=[M;`_QA)$=]ZS_57QY^)O&(\XM1;Z["D^HEC)\'P&A^&#?V76ODJDQ1M.
MXW"<STZ_C)2@HT+&40=$Y:C8<`A;8*&SF^/-U6(G`,J)*DT'TU/(1"EE+48-
M!.W$O_8.(YM!9:SZO]]5V+FBS@]`76FC/)+T[NOJM^FF[)*`-^VO-^`ZV_I6
M&1YHI8#QM00-QO=DO*0^[JF![FW$^<E80](T]'UNG_V(V2:]S=JJ"F6>4L6^
M(KZUH*1H*:6L>XUY.(1+L5)5,6@:5ZLH-:MV5(O#N8C*C[=DLQU056&Z4EBI
M4Y>3Z\DV'IGC$K@O*`N6PI5G=O]B"/IE>0C@<W4D?6U,I)/_SAK;2^8+6`J/
M[#QG`400@SX:.'\\B.?<U;&#191TO2VWLMR61SGK</0%U+44T[_IAGO$7:Y'
MN]=)JY)S1:-#VI'+3D>%X\M!O"U[W&MF11J8;6.^:<;?N6U/U_DJ`?3W\BFH
M"&<X=>T<+%T\!AW.(M-J;_M\NO^';*XXYG:["<WLXI>:;X17JV)!J"=(+V8=
MU2R/@H&%JP6&$1(Z=H5Z@%RU([4Z-T9J"43AR.Z5WA+PIOW=[.ZW0]\&Y`ZQ
MS_5"`Y'T0B5R"H<IW/1J(1DF-CSV8#EL)F4[^ZTSX,,F[8E'5DN0N(=E673R
M%SK-Y^"!O9H69'**JHB$(YYNN6$#8C)[FNZ6<W&73PUV]U`.[!)C<MM\P1';
M;'?5([#;[>][GUE0%B[;-<K)-A[),!NZ742F^"$1MAS,YD/$'N6^,9)*Z2-8
M^FAEPK;G6&ZW<EL6\5PH]_O7IJ=9RK(\%OG[P7[*;7.42*K`'5XP(&7[]7;[
M*,N"$WCR!!P`RK*]*XS2T$Y95*J_H]H%6+"4CU\?Y>OK:U/CF,T(D)"P-R#,
M7Z#DDQOGG>$!^T$16OV-%5-9S9<5C***7\7`VX$H)N/O0F@0AO"-FJF7SGSM
M%0C9':U@3+?>]!Z#'X99,R[PX(GYP9D8VST'PPYF);V(H<7`!\R;CC7HB_VJ
MTMBB0J6<QQ/PIB78?2.S[&Y/CZR5,U^H7&61D86:H<+F+:]EK?(K7(]\4$_1
M5B;KSH3;=I\"K0%II71G#2@&R@5Y@\BG.+V0$U!K3=$C)E&*G3^$+XT`%H+8
M8S[BC@_I(VPE@RLR5OV\+QXL");V,0<*0+E]W/2V[.U6%^(`Z\IUB)8C!Q!-
M%%OANI:RW,HBXK$_/GX]U#KV]MF`[\KU`7REN#QJ&3E?SP!JF$`X`;>/$T@L
M95&P``K(]Y6352B""S7J6,:=;5^6I7Q\?)3/S\\CC($3(/-T@!W9$-AG$?W4
M%?:03DS`>^X.$3`R.[A_/]G<T^G&!NS6;9L:;/O2-)",7<77MNP'(?N2Y)]9
M3;=$>S^,7@"_=(PV9S$HFJ><?.G?R?2!G=[<\RU&ZQE.5U1S'B.L8.C$G",B
MO1TU#UVC[0%VZWGIS$%@J#M8DN%-2[L,INGGG,3@X!G87J?P<HC2;+/,>XRM
MY'79P:ODP.*A:CZV&Q".EIH$EG++V2W=/`IT@U3AG455F\<XP>X)-DV\:X'2
MZF1AN:_WBMUSF\8P.ZT^)5F2@DZ?H@8AW;8QB-K*YX,B<8@0)9;/@)F5%*"G
MAIK=A76[Z+H^$DX>3*Y<X&^*B'W4A+B593E#+K[N7U42D(W]=,<3SAC=C]N'
MRVC*3A-ODWO/"]T'W"R\VKL#>(#>V^W!]%;]P&U-!,ZD<"KAJ0M`E^<.JAVJ
M<'74XQQPV&C25#>)J=T=L"T+RK)\"&?S$9>Y)R-)7UYZV`P<'8/+??91QI$:
MAALETMFN0[BB^?<$ZJB<)X]3I2ET<:C$`.5V^RAA3"S/>URYNDZ5NUU43+$T
M=(JT.(4M>_DK*M#'%L-P0*H-M6#%L[/<[X\"$SL9PE".Y2Q9GX`W[:\$HU-N
MZ@Q#S`Y%B$',.LS(U70G1Q]N@.DK2WG$=-I'9.<^1W13QVEPQ6#`:FW*DK=R
M-D:)X\A&=$6W-EANR[%U7K:M:QWC5GRZ@*/EG<\DBR-??4]L\K0VZ65X.S)*
M9)0*KN]/(D:+6""*;0BHM]];M!T,Y_U88#?;%>[W!^`]'@?P8PBW$!0L*.1:
M%BYE/4HF.^2.$*YWV>[;`T![E;(HHEE]`#^B8<U!?DV"1Y2/C7&^W^].H`B*
M6WO1)CVQ..QLJ2@U*]FGDZ4D*-V"=-B;>UD#8S>85H_]V\=-Q*D_^N;'LI3"
M1SM\?7WI\"93#`51@IW3=![[>/83NU>CF40=;^Y%O4;A/3I"F$'P#TTH`$LI
MM]M2RF(25KTDXE7($;(1$B/H85GSK_X*#[K[=+YM'/3(6LI@FJ['"`TS`)6+
MPK*N]^.XM:P/T$NK^ZW?0ZHTI/WER'<&>`T<[ZC'5,-]MO`7!AZ!E@Y$/)%'
MP,^MA+%ERSN@UVW'<)UF%\BSP9]5(%Q.U%X)6=2LP=B^>?01U%9Z\S0J3MJ6
M`D5YY'#Y%4!H='?W2;H(23:::[!)D9XZI:37+^"\/T>>8/"UZ[2S<I2R98-`
MHM,G%*`4[W?=8F<7+/W"+8+U!I:R\EYL80N%^<NY,0TE';64Y79S66F&"@5\
MTR14.TD?OSX><DOWU2A3!'):II!%M5L#UN,6^F55!4FHT^?(V+>BP4D2^%8;
M/P+4/1S/VQ$O75>?*^7V\4@6_/KZ>K![BB&FULD^27;?X75]9`H)-=,7)/J$
MW/D0Q4X0.##"<?**"2%(MK4[&\OM5M^7`S@/=M>64J0_=U2.N3=G()X<#`=1
MW"4K7-O*(8OH':`BS<H97U],'UP/?K<.-Y'=(@%OVE_&[E[4(./$(?#9NW!R
MC<Z/-AM)NP_7>[8>V`Z2A\^L_QGIH>(5K_*WJKK$]@:C%-OHB\X[01##[VVN
M\IW3C/MBB-:1J^,D,9CH)4L3@(Z!UGN7";V"XFV.KG>K>4F_VI]H`VSQCEZ,
MI>?/->^OBF64%=ZL3F\-)K#%RK;;FV]KU=$)Z=>O7^4+]W+_^BHKE1Z'</O.
M<`6ECK&A$:NB)X&=)5\A@:[5)MX;5N0GZ*0S3Z5+)Y45^K):1U(@_&EQ!\8?
MOWZ5CX]'"`Q9ROWK:XO?9!4'KT&88&1IT)H(I6J0M=6FBB6OBZSU8IP3.BJV
MDIG6$P"4G.%RN[FA)O6PP\,Y$DX>:9A2QVVRSH+=$3!$;SA"W!HCIKN>2@K;
M<POYO]Y,]TBBK4?2H>ABY<=1I(N>E=;2_C:P^T9RN/*FX:O.M/3,F[-%O[)K
M"&8QR,R6.OYM9R?+#.!@S;*:2O%S-PL<TELCD*%%L$=2\*_I'0AU<QGZ-5)^
M[03!/-0R)&1$E8PVK@KPKH%5R\-SVU:D<TQ=PI1U,2;Z8/>L((4)^&D`A67:
MI)"'J.KWZ^/C-S9E5#4J*&=GVOOC=BN__OOO(4FUX&"J;1REK+CEYLM2OY,:
MD)U)F&&1,Z#8D@@^Z&%5-OET'$_FDN54`T%0V,UR"7LHRL?'(QQ%S\D(M*!M
M^`YT&`>='14SJ<&T)623V.['*Y..>!*>\^MM6<H1Y\`B_M4#:%WO5?PNS!Q4
M?Q;/6:H@7(DK&4;U02SY`4HG%4H:K@0)>RQG.6&EQ.",(NFL><M9,KQI?P70
M!3`VCTR4+*7YHA9=")A=3ER+`3X-E?3196NO`OI=O:&`3AQ4M.@537&$UPB8
M//'Y@J6IV3CZ,+\#OT3;[5Z2>B@/)67B*M>A?NW@>WG'D%D1<7[NAH%S7S*>
MU*TU(L(P9!CP[;9TQW'5Q&)78(^KM.$=-JQBN3VDOX!7]A:X"A7JH9V_T<M:
M%X!`.@8+4/[[]>L1^G&_EW4#B<L&!A[)>\4MHE)-%YQAG>L^;).YPK<%"C9/
MH^['U'$F9ZTKB^?S*N;9X"Z41^SO_7ZO]&KEV%)]$G#EQ5#\$)PAKTN,=_AE
MP>JIDX&2CW%8%BE=V*G$<K_?MQ_7X%X]/AEQC42UMH[L+GKE/1I-VM%(W^>=
M!7`=-UAD7&PI%7WB!+QI?PWHG2;"1C$R([JD,S$^@T";B!V70'SOT'.;T2M_
MJ4'0$6='EOLZDZ!4ER@^M%W+?+:AM_7V*C#HA4=;_4H><E+UZY+]QO-/#IF=
M+9M^5/_M8HF0Z>?>X\?A,CHP?82.DZ8SK+VM71*'Y-IMBU%LU1NQU:EK*3RQ
M2IJF0-E8P5\?:@'UKC$\?@30WHM&/#1\>80$'&HC>X*<U5WF^)RVLUT?OWY5
MGR_+4K[N][)N26[TI@W:+6@+:'3\+X5TVYG>%E>2L_>M0O*ASU?Q`YUM+0;U
M1;`L!<M2N*X%0%G7-8X=/9X%X?BAF%_AMG_\SD:<]CI*C8&[>TKQ1>N!O)5U
M7;=<C)IJ0-,)H@ASL0FB8]G6?E*:/Q>IBFG['.@^_?;\M^7<5<!RO%^*L!0I
M),,B&5Z9"\$$O&G_"B(N\?Y-:RQSF/080I7S.UPF(T#HQ(['R#9"-*@![S$7
MA17<!"-<&E6]PF??J^&(X@6`HTF*8U)LD5$V.8(='T&S,:TZ2,.D3G5!LG&D
M#<O>0QN(`3^&I1\>@NI!HN<<Z9<GBRMA^LZZ+.5>OMRP!AN+S,(&^-C!KMZ.
M;ND;T``]R;#:Q*,=E#ZVP#]T'+B7Y=YSF\1W5G*+(5U/I8^B@V+7<FX_?WU]
MG?>!6@JP4@P(WH_7GLOM5GXM2[DOC\0NL%T66(7*RR(UJA_!:`K[LTH88B3F
M7;EQ!3C]()ASV''*K#[VJ?+"EDJ5XY35(\,3._!B2*L""QY(-J!7^FA4\Y[F
M8EL[$7)HWN]?HK")T0-G*?&>6['1'<5RI25(NO.=41FASX8S8/MG_9Q[",_^
M@FZWY0#WLC'I9`50L-3["TK`F_;W,;L>V)D!NJ@GDR;QZA5ZCY)CCP'J`$T7
M[(KL"$EG#8AW5U)7#N#R=&GW6#')WK&2`J.0"$,UF:+#E,HV]D)27-W9??4$
MJ[)F;-5TA\^^VHH\M*?M,NAF2L<`0)5;GT0U]9_;G5;VJ,,]!MOB#(9$B\FN
M):Y\2:Z]&EE<@8_5`HCZ)3\RT/?J;@ZC'BG74CI?,,415-$5E-O'QR'S5?>-
MQB`7B.;4K"Z%]_5@4UELT399F*0^]?U^+^NZEO]^_=K`NF6EVOK%*'&,/X`M
M$8_EZ^L>JGQ$X0AU^D%K!P6.UC'-`*MO'I;%VW3!SSC>P<J!XLYNM]L&\D7R
MFE.(1"68N5,$.PZLC4S7(-Y5)V![N:&:FZEBL+%I@O?6K76];PX7G5"C49J%
MG26.IG\P<$*H=F"\PM7.`*LDZAX2E8MHBPT$?]S*LJ+<M^2\PB!86BG(/'Y*
MP)OV=P'=44:WLQ/,%HOK*]J[F&1(+<L@4,`,6+%-I=6%H*N,H4W?T7/''53Q
MJ'*$#72M6[4G!F"$%8<T5$S.9-/6<5WTT[X=$'XL$J..3;$A%89,#Q8K;S&C
M>$\P3I)D1BS+"T(P7SRRA_=L<^Y@4E5]*PVU?-\)`GM+6Z"$2?UL7E_5/_M7
M@'LUW3-VE9!FC8+2*&Z[R7=]?GXJ(+6S?[]$O&[M7$;0NG['C^('=[%U;-6H
M!-/$<Y>"%"TLXC?_]_F_\NO7?PK0#`F@H9_5^O'QZZ%@<+\7+?\6^4E.;Q7]
M#('CY&^&M3AZIV`O2[=.3R2$L_]\6V[ECKLA;RDDRQH[7GR^4.,Y!FHMVZ8T
MEW&N81IBKZS66PN_ONZ:F'CE6ANF)W;6S^JC>AZT/^Y`]RPF<<8Y*^"\+.4#
M#]#[2-)C[!#+<9'0*>VO`[LC`#=B@#GH#P\H;5/IXF#HWGDLD"7PU(THNJ@$
MUJ3!6J@[DO0LC_A:XLRBUC2I<+TY*WHL)G6OLM-Z2AA9K4DI35,V<(XGXE;K
MZE6FS*])\_"T,[4^K5G0@W:VN!4LY;[>C;3>#G[7Q_:>:CY1.&+$VW"39W!L
M^4&!7>JD,WH:MVQ$]A@&GCJ64_':9/G\^BJ_/GZ5([S5Y8+B/K8LRP/TK/=#
MV_-CN1V%#"S8/5PXY<7H2>"(C;S?R]?]:]M&;<4D&GFEO7UD<J+9:?G\_"S_
M_?=?/UG/;/O;L`T84+M7)CN!MYXW[,:4IPPBB[P08SL$J@P:J9T/<URUU8^^
M%G8X;6%G>3\KIPT,XIG=L7@R^6XYQ.:6GS\>/%WHP-57LFTH6_QJ9YWYVD)J
MK%L9%K7H:.C0BC^&GKZS)1"L!81>7.ORPGMUP>68?Q$4OBF4NRT,F6:OI1/P
MIOTXL.LE5`T#TE[F+=H@<!141F`@$G2(.*<ZKJ^61=\93I3E^`Z<V+DF`#:3
MDTP"@(!OT5:K);T14*HHC?*5Y)%Y?H(%!#$#`I2L+.6V7)-?IF"+C\7OO@&7
MY8@?LS&A!P#@H_0I=S#$#D`3Z\%23D=B9PXM,WM,YV3YNM_+Q^TV%N+0&!-5
M&5'R4::W6(W+4Y]YUU^E*>[P:#N4N+PN11O#(:4W_FTK$XQJ<UDIN#8>#:(0
M2"D?'Q]'$MP)&)V-:R>X\AB?ZUH^OSY%;&XYI;,:\=%2BLOJ@DO@NB=8[:#7
M^]PRZA;XZHK"$(S?U^'(R%T'.`.@D@S;KF,3W^AY+3#W1I7VY?:'D%9%>4HY
MXW:[;2H%JUX?C*15Y-RK.%>SJZ3FM<8](BC=ZXO8M@L(G8G!A@878^]1A./N
M;$FRFFOAO`W_&:($<`89H_)1Z8?-B>J)T2*T[W3L.SYA>?OMC^NVZS("`9`,
M;]I/M"&PVP*RK3D''?`;T1NHF5T%:DT\H8R/I0&#<!A&)?I-'[5R*ULK%_T0
M(73BDD%_PB"\M`-68.0`W<7&5NIRO?NY[ONDM<W.>SQG'2.JMPNIIO%3Q-Q]
M;V&6%LNZ;@O\4H[RE%Q9N-X+[UH6Z&273\!RO&]3^2D&N_N$_9#;V<^Q+\Q*
M,U.4(RYD69>EW(@2[L.R-P#.9[ZO:P4.2+][2X92)H?UMA%(!VW++6S9I]#;
MH(E+_>[,*A:4C]NMW*K,]CD@]2AC^ZD++1QZHW7IV1&&J2[[>TI)W>_W<KO=
MJKCM.K:=?B4RZVSOQVU]TYTSJRH*/'X^KR/`MX<0[6X&=DW5\R4?AX)-+15/
MC:`JX2L=8=...^@]PX&*6PC"KB%N^6IJ5T:%>KM@UKQ]JQI"HR+0[)78Y/-N
M`O#6\5]?GW<!=IUVI=$+-A7%:S!<YM95U*%H:L/431KVV66(>":9<Q@NN^O]
M7#><A1C!WQ/PIOTH=O<2T(V"S4;"&$;*=)FX^Q8F;BX\<A*-DN`@MNB,N"DE
MH.1`V\PZ&QZCQ5HN:%\`EVT+?CT4W:FV#N7"HP3%]R2F/09QUVT]:!@>S!F\
MYVKM:35R'(\L;\.%K!LP+&8B7BN'@+%XNKNMN8%M`0Q*Q97J&^?*4I8B*A3U
MMC`<%V7=&,"]QZA+L&:_'2`,.`/)R::2&JHV,[U(5P6GGFR_1*`=D(^_W9:E
MW);_U$H\*U.W;NRH9(Y8+;X3(GQ6ZB]X*[MZ0Y-Y&V0_=T!,[HFE#C-L@9\8
M?W9,VO'I@7>_,])HY@KVT0!HX.&H=.=\63J9=%E"&S]K0Z`\N45_BJR]/YO4
M:36"M0(%*P>!EAR!W$^1D_>6K!:@T?L69N.-61M5</SN1"EHK6*1"S%(^E!F
MWFW?;12J<]OY$<IP<QVY:AG?=L/N]WMS[I-]3L[I"7C3_D9H7)JZN:5#_O28
MW6BK10BLLP%J??D=B"07A@PM1!'1V#&80*^#QT1-P=:BNT]06^),D=OA@<@X
M-Q"XW,ZJ6$<U,B+T3GB6F8J3";UT_VH10"E<-8=H8V\''`DX"Z4D@=W^2A9=
M/-DPQT-,#+HAU8\X5].+G#ZG%`=L@`%/)T$_OXX2?+!ZLG1T_>A08-M/=,)V
M#PA+'C!@D5`0;<68P7Z_/T(8E#ZN:/LJYC>62A!,U'D\BZ-I?,B;/4(;'CJ]
M4.QW2VG#+X#R4&J080U5Z$+++P1J4`NKW#*,^$,7!H*5W4L\>\SM3)B#!/O3
M),D$CR*?#XKI+G$8G%.2OBYPM*T%"\Z$-9L01I:OSR^]D]0)N06BS_6:=&B#
M[Y&\U-'?"D#:(&I)IP=EB+WYJB6!Z9U"ES,WWU`3+-3LD3&\:7\-LQM)%X7,
M+AL`!A.SGB[H78?/LYQQ=(T%$B(6CHQYI'W;EBOU'%,TLU!5\4'IJTX$S^\I
M$9RL@9YIC[C/C2WCN@H>SS("T?M>"\M2LPT*ZGNBM0/IWL5?0&A8OA-D#Q3,
MXYABKJ""2UA\&1U*&F<F-SGH\(C3K.O#H>B!'P:#0RY\WB"KX],QY)">59V,
M$$40M^[2Y]W!ZD,\[HS9U]<&ZL0UE=*%[NNASV@*+TC]Z5)TO.L!Z#8=U?O]
MJP`H__WZ[V"T'NS7[GST0>L.(I=E*9^?G]KAE&$!'HJ65.6^O2R<([=HQ%&]
M3#X;^_($FS;RKU^_?-X!:/(3,"ANGZ=NRW(P]/9>U/V-`-H(P]-([[6D`=1<
M[/=]-;9+V6+U_?GXZ^NN&/G(H_!W5+QN:N::346&IN?JDAVT';S>G63L7E9<
M.M>R+!^5$F5Q^X1V$^C-!_"7_`2\:7\%V&V"C.`+89&"7AA#$#H9):ZH+<7P
M=#B+$#0>YB%A]=`GY+J><:R4'C`5X[PLJ`/(T&`[[3%B,5F+W*8U[TC$8W+S
MPLD81%'%^PF@OL708H':$I:+C%SP]DIE[AI+ARZP3`NY%0<X62RJ^%/J)"41
MX]B4>_**8C@5K]1K4<P(65L1(0``(`!)1$%4*_+B:$="S^^.!BA9O]\C7M@9
M6U1,\K;@N=@`)C;]W'60,<HLSA8O*Q1PL)![:5F:S/DVGFTPK@/J(7N"U_V^
M%E?6R4G".OZ.AL=M)QM8<>]BXKTAMLQ9_N___G?,"_?[O?SZ]>LQCJ?(593_
M_ONO?'Y^/L!\<4(3;!]F+2@EG77)NJKI0SK$%HP%[XLB074G!6#CB@.@7-C0
M78V^)P#Z5;!KQY/JJ^=THO5U)9,)383`E`L\BKJXU=4>YUS7^Z`S?^8\6`UV
MV#FYV/"5,YM`AWE1QU+3MK'=A3-.B:>\P,>:=5NHM-=MJ-P>'J=";;PWZ.ST
M['MG2T*JM+_%0E'L3FV*\(]6LFRX@`5#F5[OMJIM90])[X3CL>#H@5TGIIQW
ML'HS1P0(X3VG8>^"K<V=G:ZE=SSI)VAVU3"IZ_&<BX,C<'CZ9XWY@4X1S8U'
MOLYZL+LTHL4TSS_JC*D6,.RV&W\,9[[>2]06G?5OP[Y=7&4N\M"L=-:B#6W9
M^.73:_$#U$]VG.Y6B7Z6=D$!OT^U'Y2M'9F`>9=][//S<TM^V?JN%#IBO<NA
MV&T&+]J+;Z:_'KNG8*DDX3X_/R_'WO_Z]>M1BEBRHJB5(TX]9!U6`$=E0LY'
M$%4!/,UF^2_+(_F51:@0&-9X/VZ]W\OGYV?Y_-__RO_^][^'8[(IHM"?'NOW
M[L3K-K\["'UMM(<=LS2*@;1EI$W2G[RC5E*BC4>NO'AH@'<F%;/N?P.SEJP"
M:-M':4M7\G(06S3:2?+[_+EW=(9&V9W+QQSMECOOO+,=N"?#F_9MF=V1V*TI
MK[SWIUZ5"%=DT<R`[*6T./&'FZL<SF-*!0B%P?T^&+*UU'I"Q4A%]%!_GW&'
M9&A*K65+-B[@:)+15$TK>U@#_+"&4B#*3.K2O$//"`DP45A6=<\VXA(8TU$V
MK:!9;Q/*H7H"]/9P48P,U0Y`&`^+0)U#DBX<&!-"O)0.4ZH70#C@#2[+VFJ[
MLT)8<=![3/E"W?0P,?>0'/O\K,*'O*0L)?3$TSFHYBE'KDR.69V\:G&GVD(X
MS[V<?>!^_RJWCVM+]J^/C[(4E/]]_J_N.[1)D(TM;A8?`,M1<U2E"V)I19M]
M?'QH98CMJH]WH]_I>K\?[Q]'@0(4+(N69+O?PSX4R2=JV;$ER/H*IA0&TXT@
M3/:V@!@WA.X5".5ESK>R;LY9LSB@"@>"1P$Y=^M(FJGYG&:\F6H]\,:K&:-1
M?21'6N]\=]HIX#KR'-'81P+>M&_*U@[(C]E=Q"L$",;72__B3CS7"-YFQ9W"
M]X`-RQR7W7P<N%KO%Y'P^\R[<.2JK$-RQ*;6<Q!0)Q2P5WJ3C\EMN>FPAG-N
M?2QTZWV=?#(G?A90D@N>]NEL\LLAW%]A=:=@P%YFV`E@TS)UJ))3W+"Y*#=K
M;36'(QBE8BT0!`<+,&%`2]3_K;-4@5TID15UQ%8,>!%ZJ2JT:(M:61^%+I2@
M'F.A,7IK*D\@J/KL=A$;]G."#EG[^W1DJGC4RL%"6;F66TT3=OK_^?GMXU8^
M^'&$-RA'Z4BXU4F*&NS`+2$,4YBAE@T,`-RFHXIE>80R"-9]75<_8W_O7YN4
MV]Y_]DQ_;EK>%D3[0%5NL3?B]8.DJI:D>^7'0"?L'F%LI,K?>)"CR]F6)@;J
M$9)41%*9[K,:<_J1^7'M.X8\3ZFJ'%+-:9Z#6)2C7W1<>*E+5)?BJ&.8R>AN
M].9L_"Y$@HF5HTN&-^W;,KLC`&-$?6LF_VR:*;:QP"W'V\:DN4(24!6-(D;Y
M9/H"H'B,?^H224_8LJ`\UA<_<UKE8DE/?M?5+:6L9:WONU&I\KXMAI*7.;B0
M3;9L%4EQE]T=*9%$NH[7#.AE)0A@-2)E0@B55C&<DE94Y>8HJNOY,M-LL-LL
M[?9G81V&)^$+(`A@5@#"?:4">,KM<^DT?7U]'<47W+JL'<9-;=&3U2)<A`S3
MY]>G(TTEP1Y4/'-+TNX`N!7`@[E]'5`M$TJA6#*AJ2UTI<FB"F!8GBRNXJ4[
MP,?'KP*@?'Y^JGYX^!@N.*VUM$O%_MECY81$H]MUSO/W^UIXOV^ELW$RNU+O
MV>FN\D[630EF9W8/@$Z3*"L!O*R&)[3+(>;JUK2YUO7(VM,:ZSD<JC#0^;Y^
MW3Y,F!"5FH><.]1SK:;"6IPIUB!?HF4G4!BAF),DP#5LL5=CPQ%X">ARX?Q1
M5+HTQ3!.SH5UG??M9`EXTWX<LSL*9J.C>`4]3V+AV>.45FV/RBZ!3J0I>VN]
M?(0*!F,/ORPHZXJXI*PC9$ZRW'FO0QKWZG`+C@6N<GQ*$4R/6%11CN_1R&5-
M>RRLI8SL?5C6M_M.0[#+.*[;,O&LOW'J%[>UGL-<R\WYN*]WD\5\M@,[[D%-
MO*"CN$&M"^LDRIV?R6I,`6B6,:CD$!LG[>OK2RF<J'?LQ2.T).GH90R8_D*?
M`Z3T#@6[*M]S.?%$T:'J"`GO\V^!P@'*P::?<<%T$Q_/=[666*NQW5"`+E$,
M4P)RUY)=<5?#95DZ<E6"Y:RF!UM8PB$6]@^HV$$?Z'KZXVAHD(R3.[I-CJZ]
M+'J_97LQC\IBC@R9:`?IN`$1L(7B;#T10*U/B(.!=T]($[Y3R9[YR%LFTRT0
M^1C19$KY'FII-)8XD7'7#<^DM;1OQ>Z.``O.XM--I*!*Y'$3M$J=O&6.\Q,=
MQK&6]'AIF5M[`9Z[08=Z@`-VZ_+#Y[%[Z=B5G'0?Y&87CGKG=8USN,S+$0M)
MF3@A2LCB(3J^EY24A^^3]PYX;:P@RJ-"F8ZI;!5<0!/%5<NV"\X:F(H]X%57
MB++WH&+F3.##Z70LFLT,;B'*K[S=;F798I^5_P.M%D`7D?M28L=8<))M(J#K
MC7OVLN<KY"*3I9SJ5RJDA.5^OS]"8%"4LZ3)2)W@8^>#L^!&.QY9!&]Z=0C=
M)SS;H9RQVJ6XA3]*N83W53_``@4R*28?4L]RJM"(C$/M2!&?>LWV.RPVL)PB
M2=\O?B$28\6H(A^,JTPXM0EI%!7G6$S$S+&HP&W':+[GY@I4UQ*A`ZW_;(EP
MFGP06$>/+%;>1;6#VG60S^Z-9YYK8MT3KW6J8H(F*%C63L+<<L1AH['JRS_!
MG48CD+^?-P%OVL\$QY/'P:IWM33H!USS@Y6<#1\M7LSP@^F4B2/U)-NND0P%
M,.0\(<#ONKH24_'/^Q:93E*1`-7'S%#*"ZSY'\%*Z$E.+I2[<L*#!3SCVG;V
M9U<<>$QT2\Q8ASIOXKI"#RO4U86I2>`M$K3ZE!`[T[W="[&=7O&UCX5\3]2S
MS).W.'N0^_'^;@)OL,11#NV!P0KDE9`A;Z##*E._C+DJ^APV4<Z<[WY?'VRB
M1U)&2ZRI$E*#<HQ,%4&_[(LITL05DYRY='=6](M@^&S`"1`9/J,7=NVU`Z"=
MH;.?4"LZ5)7>I.8`%<`L8KM;_JX\:(^:W$&D\"S(4XXO<FVLLHZ)I!T*L0KE
M`<5X.HJ["&=(`OW24B-BNW_O\=!>Y`X=,F.VCQW_HZ]I#C'^;[+*WCY^34Z#
M]@?HMEM[NDE9LK1OQ.Z^"QJ3`TE2(PL);9&"F7MVLI$H^5,<B@1BF2DVIQC8
MO6$[I^&<G.`LZFR4!'5G1[_6_,ZF+LLBA&/BNO1-$?$%5:4NUD*195W7LFR5
MAQ[/OCPRMD4BQ`(X5`:*K_/E$8505:$DJRQQC\52JDTEFR$DKC3[8;L!?-U6
M![8>(0U#SI^S+7$$NE$X?Z:(10?0(60TG\!>QX*^CB+'X7FD*BI1Z()\N25*
MA][C$*UO[\$3O89JLUK-!#53C+KHPW/A5P]MWWU[O"J:X#B&YQ8YJBX"B,@=
M)^2:AL6E*(+B:HU[^M!%E,=51?48:?!5B8`ZP<X\1`4>-9LJ0[1<1^_8N3IC
MFN6Q7C4\%*]:85U8G$="WVI2QVCZKT&N%LTJS>!Z5\Y7W^10=<?^`GJJ?$@"
M>`'*KU^_PF(@,KGO?K^+G8<K=Y(A#6D_".SRZ0,<@F6"+>$8.30'?7FR%$`+
MM$"!WOI<&WMWE"6]<C<29J/-!I7B2E.-7S72FM3G.J5X'C)DAQ294_VIQQ0V
MA(9UZ(25,AK`&0Q`:JM_P](7C"]RDE5L'1;QKW7R&G4C-XO?L>WBU4R<P^!&
M+:"JP*TQN+T(JO?"$D=1"5+$K=;@ETX%*Y9VC#A;68*N0RGC'-&\=TJ6,MI8
MQZ3CCG-,:<`7\W106M1"JUH`6,C?&QK1GJSR@/A&16)8V:UB0"E9L^>>0Q12
MH58242H2T$K/BCP`J[AA6&L56A$\X6H:9-W"TFCG2)Y=&I&_;"08CS`;T:U:
M.%)O+,!9`T=R;LXP-BQ;A;V/C_+Q\>'(Y`F)S\T1_?S\+'=186X4`BA'A1G2
MD/:W@-T`T%XBCD/`X6_G[9-=E^F21*#-G6K&V.J3G-(TE>3A@P$]V-<&J=Q8
M'1$LVV&R7Y/S%JRI^-\.<+B>S%&=I6NV<S<PNE<+H\G\UXM7E'/L!(M0+UI1
M53R*23AJ6[7-.M%5/6;>;A'O+$??GT&?42VF`P6B\*-@4RWF'C-7/;=.K#S"
M/7@=W'H`\GY?]5:P*.I`RFUK*D>,15<K5%N\M&._!73MXT2>=K^_W.]K^=__
M/NNP"@X/].-21UA2(U&1/'5W%3M'N!>A0KW"64#='RH-;^@M:](+E6A1#E#X
M'X/MBD;?D5O^).L=FPCXEDTA8B<@]K\)5E?-LT8CV/Z=)RTKW'4H7Q8>5A>%
M1,Z"(CSG8D_V;63X-R)KCNO)PA%%1\LL>PC2-I^C,\]P78U"29_*0/!9JC2D
M_27(68/)NK3C!)L+!S.U2EDZ7CY'5/X-D*HT=TO1<CG%E)<UIU[+6LJZ:]2B
MSKNI=%[1`8<(*[\K]LDLLC3[@&K;7H4JL)!?*CZWN-=Z@./;%GNZQ^Y*35YU
M_U7-RU(\#8,CWNY0"B@=JK.46D22K^BV];IM=U?WTL!<Z[*V[GN4+:0371Z@
M6186J)/@V'%0(^?N``>`JZ3`"HQL[WAK]ZW<B$24/OMC9,TB1FI=[Y5NH">\
M514I=-IR+V%]LM-T6$0>0%B6=NU//&T&>7_,KZ^'P_/KOU^ZZIEI9*L-8AW@
MV\='^;K?"^\\89`1)=^!?UW!L;AA.'K84=V+G6,.+0&N9V1EF(1G'&I3KII-
M=V-@RC^2]M@E9%`],UTE+958[04PA[YH77FN.(Y])TI+M=M9=IU*&8+>?3N)
MU;8]T)-]+HTQORT9RR*I#R-3*+8`#J<";0)K-`TG`6_:3\"Q97#.<MDS6(00
MX3SZ%*?+;E(R?N=`/3)K`Q5SO71052O?"1(6/WU,3_'^0K=RW>+J3B_:;NL<
M,:O%U\^,X).]F,J8ELK^D2J[K#-_E#TN!;PWWNNCC5:NY<:;8A+WAWG$^"Y:
MS[33BU0BWH+R4$X[521HYV_X?]`E/-L,*%RJQ+0_BP^>6+1>;T&PCVD'A-YT
MO'_=S]"!$L5U^_?=`[L]J;*3R?,ZABE08M"K!`-[K.29](2X?ZYUA#EMG&13
M9QF-YD'5IV!W)+PQK,I(^Z-,8R0HT'N_K^6V.X`!H)723=%NSZ^/C_*_]?-,
MSC/:MSP\$:M3'%<G9S1Q\&0A(`H#'!7'Z($FJV5<CXUCAF_H7H<5"!VP!VBY
MK(8L<7?-DD588$B2O3`-C%>CVD;\_.C_BW(JZ[9G4*Q#[VX4H-"IU]/2#E:`
MDC'8I(/^+?FTKNLC2<W*[WF`?IN?EV4Y=K?"Q7]@F4_`F_;GP.QD/$[KP"&9
M,IN"VD)U<A`%6?O5LSAEA5N3B`9*-$`=`5#S3ZP9A7(DZ'C,PB-3'UIJR%DV
M>YM(5%G^HHK4$=-G0@WH$^9N5)V2WGD49-B5&4C-UMW7]3&)?GR4VPT-QJ/-
ML-CW%X%=S0^+[=Y0F5TG*6F]T_.+*Z4#Y+'1I\YE-T[;C8\495>#$MAJT<?)
M@%=5?='R*Z3:A'$BC9H').`L?JPLJP4=[=+5XEED-GLHOM?0_JY+9ON.2;W<
MHUZ(K59NI1VJ'2#I$,O=EH?B"DNYE:K4KPK-,$4@[-A>;K?RW_^#\O7Y53ZW
M..?](JHOBIV;W:>LVL71-;;W=<P'&]JJJX6=?5X6]R8UG'KH<Q<QKE@G;8FV
M6UF_;]OF-H:8WF2KZD#89%V=,"P3^2S8!E3U[E-/BRRW+=3D\;F,9:7K#)U]
M"*?S)MLNW)TR16Z*Z8^>V'?3K3^=#B]'Q0+R53ALGK-OP[W653@*SB)X5#R4
MZP:%,\1D>-.^,=CU'.P([+)_2+PL=I*OQW.S.R`7I2'_I#^4VT]N`F_@F5-S
MVKHMG2I8I][M0,2;5\>V:)!_;(VRK@34?MUL1@C(>#,5RR6SO_'(/-_!O`?>
M1O*-=>"@!6D,2GWXCA,#D7YY7_H=0Y71H%BD%$]'EK*@L*-M:>_UD?1A'2H$
M["(/<*=$\:''G06+5=+.P<BBAT\%P^-1:R/]Z'SR^_U^Q.\VR\#2?W9=&M@,
M//18,-E(==A!"RQ#]`.Y^T.N9<%R@,3[NI9;!?I7<7U4;"^=3KHL2[G]^CA+
M+8M2O+4B#=R"!]1>B0BGU:V^RG<!K4!@[ZM6&_<#YYOZSG)&A%TOV"90*KQG
M0S+,KL$!WO5[5_5'%#$@G!,^)H/E]LB_B$B3/;%6.?T#;6>K2$*WS/D][#M'
M-%$]=)L!D^'CCPKNCZ>_KVNYE5OM$)AK[N%L,HS-OG<U>E"T6H^A[A/PIGU+
ML#NXKHT#XTLW&MPK)^\;_K14B\$XJ@`#B-L7!FN#?LFJN;&2$?U-NW`X\6;J
MAD8JY\''-_O$M3QT<E<I744'QK"4];X6X"861`UD-#TIXZ8AY+%$JZKGA<.Y
MCCE=7I4A?SP85@XUUO*+XIJFM'E-*\M]72N-3;5DT):&I6'IG%A)3\$AJH@@
MO(]*[Y,LR[;85S6L.M7<O$M]?GYMSA%U?Y?QVI63N5^J!KO40>IUWX4&/Y+]
MAP%%^D7J!#FIUJ+&EPAK.(M3%&</WH2I0&;6T]E9.AW*=5W5F`$L"TT50\L2
MSX]G5KZF7A7DJK90QI,5Z45DT>DJQRZ=K`)IR81&R%-8$KZ=GU&-:#K5P21_
ML.!1`<\D<E6@%2CTV%8&NR[N5"M`+:DV8$R`M'I^55X8P<Y<)0U7=$@%9)]'
M_,Z/<`Z*\O'^_$+UUD0Q&IJ[09863ON.@'CR`X[B##YY_6*\1A_^-"EEE$CH
MRYR/X_<XEH<'-2%6\5[4I7LM9W5LD6W/3@8Q(!873(>ML$)["Y:R`.6^WI5:
M!@RX>%QN+2PWL2;99RKGGJQAGU%P5$Z*[M-U+,2BKD$5I_M\I/2F,ID%^TB[
MN4J'MST2!"FVHX-X5<OZF(!&%@2L/T,G"Q:T2N80IHI<@0(G$[3N<;^[BH<J
M9+!]MEA&6CH.M/'L1V3]`81]CU,?7U6\`M5,89-I)=AN[:Y0Q,C3W8/W)QLZ
M+I(BH64A'6$K6;O4COJ-#^JAPA@J]XFU@S=5')R>`RX8=7>30$@Z0G*<MI2N
M`$M>=3\U1WGA+&9'I[23IU%*^77[4,4FY-A91^;-8%BV&R\XGV5/]T0U6SC"
MS776,Y9THJ6ZA)1'<Y,O><8<GW*%_=7Y6-=D3H!HC`2\:=^&V1U:UC#*J!FP
M=P%LQ_JI>WUXME$M!@%>P/0.-(,?1SF27`'8<,K&JBF8!:$+>86YKZ"]MZCN
M,CI`P;*4Y;:4^\IMB[IFTDZ\;JD>X5R0)B)#@CN>8)D3(*O1!E<+J=!LC$NV
M<R_442>FU,PSJS"9DUNSO<CN6)Z)@JR2;8I8H$8<FG47_*_6W#-YJ:JVAH&P
MH,!?)%D^__>Y[0;404-K)95F]`R.D`;)2#V2WV`JD<G-Z2J$@+4/%^W<5-5C
M[8/!2%%Q0/9N0)IL[Q>/V'@1'_O_L_>N:V[CR+)H!BB5W7/>_U'W:KM$(LX/
M$D#>0+)LSYZUIZ7Y/';712)!7"(C,R-X9MF%";<V]C%;FJ%KBB>)')D;RGY%
M5*>TS\Z"3</,^EX%:@QL[U)')W1[-`9]#"`-7FVS'_QE"`2R/)9AV:XUQ9,Z
M>^!DGL7;3-?-*2`.K*Z9AO/F-9/E8'*NV9([(Q^6DN5'P%JU[3BF9Z"]KE!'
MTG_W#7C?K_\58/=RCW81_>TFM5\$N_>H8LP5$WX5T'?`QU,)%IQ%^F%O0*`.
M2T=_28WAC7$H!5(W2!7G2'0S^QRA2&3-RK(SM5U9@#F7`I_+H[-#;L\JE/\J
M\,+:P=DL9699TVO)]2QUGK&V]-<YJ38FCV;#4Z`\>XH,$X2FD7`P<RV5B,E"
MRYLX50/2-"6J>]<&]"XB0V7C+![D=-#Z=;U>+V,YG17\[!BF(4RKMM%1#[7O
M`*2`>M2,3Q4\D)'Y6D@5JH*6J\>[$1JRLJN3G`):D?ES[(SX-HH>.*MTOW:W
M8+KJ8/1K82I(88"A9P'%7WOB&(X4_-$$!W9,<)>;Z`\0`N/,8"`SHTRA-P/2
MI(N%@KN9SO/Q.+33)=2_VWE19).:`_-L5)B`R#;7B.E\ZZ/GFN\N3U,G:9=E
M`%JWWJXX`27UYZ7]Z)J4%=.E'AI\'P/.=]HWX'V__J^`W:L4+V^@(_X[K_$2
M>OOZQOF%!=W!:RY9KJ32^97QN@%6<W[E*XE%2%F*U$,7E*I6[I+559MCUC;5
MTFB[0]8$U*F<-QUC,M^8T[8BT<Y-9^Y'ON.9)VE\P_8FB(>9^YG^?UUCK3CI
M>M3A/I8ES,/YX0T#<+VDD=8CCM=[S4;#RWWI(E`M:>:=J)JL''L1BF':K+I'
M`F#<Q%G75;9U4\H,8JM7R:,B`(&=;AD"QLH<$Q@T-:>:CH.MQLG`;OO9@I*S
MD!)5M;3I0Z\S%I%U6^59/E)V+E3%IF"W'N.VF6N;<[DVJ,DT1&BE#(+1"1'#
M1[U^PWZ`7,XM`[Z`79M=IM!D?#A1^[;OW8,:94*BZZ5YDF8T#8\)F]HD]<JR
MR//YM/NQKY]V^I3<[&SC*0T"\9Z92)WI%"FB]W$X%[W;1\-<([OM%SI0\W75
MC7/8MGI(D3$^'(G-GQ!,SIPQ8F_`^W[]QQE>_B^XOA0`75PIS]C7M/0B"OUR
MXDU&U?!QRGIG9!HF3+=1`V#HYO:<V%GY,R"R;O5TXS\-(=HU<:)\D-JU)K6$
MRK)2N*?]8Y3O618&F2\12?K"YTU;_$HPDK+G>\TH[GDL&`MJ63=9)HSH#.BC
MP/?@F?G'V_7M"N1RPBZG-X+X=^J1[2$)%'A,NGW4%:P&[-+`7?I:S^Q8Y"CQ
MV/$OG#P2@[7J-(2E!#,69+71M&GOSA:'ID985"BC5AF9?^\YN=\;0K=:CV9&
MNC4`$Z3`C#0F>WI^G?W#X2=ZZI'>@XF]O"*_=#C2UI3E]YIG3U,V4C9/0WG9
M/6-*@]'#@/YUOY>ZLP[(=_WC1Y_/QZ[,(&,OG-7$0R`;JZSK.LGFN$S%1(LB
M/6\:0&=^;.1[&D-S77]&KJPKVZ=\9B(V%^]**V0D2"+I?ZP;3*:@Z+*7]^O]
M^@\!W?-#6L1ERW\+R-YA=^_(C6F'RRRBO/-^H4-:HD`]'`"='F`3G!&:@I3E
M8ZZX>Z/3V+-5-='%.BD.^W7#V.`99\9OG&MP&RG-!NI3JP;\=C,.3.<MLA,R
MC2\0F.;VV5/6`[-Y0@7::+1HKV:^KM`H*,?8?,U^D&3"YIX;;5!_,*E&W_VM
MRD?JH:5\I@T\NV\`A_UHC2-(:_$[M*>M`;17,<C-&C"IR[=!$A5+;RQT%5/;
M[K^S[L:YBVZ<YL^W"`24_L>RR<,)F%#_5MQWK9M5?1#?O!H[W8WL05B23)S"
MU`5U>0>Y-*+DC;V5B@;N]KU(%#Z:^H&ND74+C\;\Q-;C:^OKT?3GM835G$)$
M<CHS7Y8BI1F'4'H-==^EX#1_(2KC!3??,`*R[J:IV5TD79$6H,/5XYPV4#HP
MG_@ZGF*`LBQN'W1T$T4U)S--I/KGS\`V>6)I7]-OP/M^_4?!+F\`S3OUNOP%
MB'7/^/>,K6,`)_KGLB-S)JX/F92JG7C=GXTQ##Q!TN-S?NI<P6%J6I03]);8
M9/X*Z$VU.!'_7I9E9S(=&,KFPIVFG\MF1W)R.M"FQ2'!K>R,C.O6U`V(5(X#
M@*[+_@OS8GD\W!E,HWKA?]^#70U23]V7+Z3,3,/*,0B[;NYF3")TB%+I#03&
M=RM%MAJ9:B]@P""E!R?1A0`FLLP#DV;``6X5BTPK%)*X$`?#`[,!=%M5U5P8
MS%$<$ZC68P?!"A##&5YL6YW2^T$``CIR2'9-O5<UL`S5X(5L`L16B^E\`<R_
M[7ON#%]U8:*-`'CM+)@&HPFPU^NQE3G0,L[F9HH"HH`\'L]AHC+;=-4X[;76
MD6#8`;X."$=@LX\)%`/N4X#C`^A$O4W,*KEQ3]:_PG!F.&`,'(83*3N3C#M4
MW?.-\]Q?)VV?PAOPOE__MA=P'W#.OGD'$,\@S)7E]Y?U>UT'J2V4AWC)]WA<
M,E0!WV&:3R5M'*#D#"`Z%ADI<D1XCS,CBDPQ(/B^:VM,=VCU#?NB(0:^R"(Y
M&);ET66M[%A.#D!QSXS7P5(<7^1*.0E[-'MO<G;$,V%R5.=RY2FSF[T*(,_'
M4Z[XX9YN#Z*;T7[Z!@]^/M?5?-D;U^2DDE0,2ZS':F]NL4\(F7`^\_EE&']:
MEE;_G+?8G3+UJ1\)78K6[5NNXD/@VJ20!R7$O+R*9WLCCWETK&.W,BVC#M70
M2*O(H"<+$M,1F68U<)0+2,(*Q^"6JH@YR]3H9Q3&!S&H;-=G9DURO1J\Z3&!
M8XWM@:#&)K'0+64Q;H'#07#_TQHJV?8HE#%6WAI;O$F()"41$AGYMO'I0"8D
MTQC.8AJEDK,#"OWGVSZW-/DUS'YV[&'5!-8X\4K4SPHVH#?@]UW2\'[]AQG>
M*R2,VS^*4-=UYV.FD`0SAI.W2B!XRGO-#Z;+B[F'Q=V^1\G+`KSNZ)>B&=$=
MN>;/9-,=<P(3C(3)WPZTTI`E4E".FE91C'9VR$,)R8*_```@`$E$051RS:N<
M4<K^':]4:4QB=#=K7=X\`$1P6<NTMCR3WN2V]OK-KZVY!BJ7Q^-:NSJG]:?C
M8*%=='K*M&\-`\18Y@,G7P21D+&``N1:=HYF'T#*UF;_DTDVHY>3^-2V"\X#
M66S*19%D]&$:T8S17W?M4C:IHIC%0[()/%%M<2%C[<.%(XWNVYXF&9$>F)3>
M3,F3O6FX""+-(@SU!AF#A(P1/4#,A.WS;:@\32W`J*NDF0VH(!GCO\4'0#H8
M01:%9\.X/^L].,>EH@U5%H`NJ\([F2?U[WDVL]@U'X+GY"`D36D?Y;H'H#E@
M+DM))17\^FQ**[.3CA<;5W!_M'?[?KU?_TO`KEAV@S<XW4R+#U]DFN[]($]9
M6-SBN2*P@:4>\H:*ZTLS>5%;DY<USS%$S$CYM/,'-</B,P4#A0Y=[;(],$Q-
M69@(*G7,D=;S7&AVP`YD-+]3SW#[9PX?2$#R5FP_#O0`.&'L#<!WAX%N[%'U
MJA,UM7S\`5F69<C2.?`W>^SS``Z!04\>UVAR.^EOV[::,.D#XM`4XN!T;<`_
MGK#F[$&NFW;ZS\]2+2X]GQ4V69"B`5,(!=S/):!CLKXHNY*)!P>8!=1(V/54
M*"(&GAVX3GXB!G)P"EM%=*,B,<EL4.T-0>M-UX4SF(N("A!BQ"6=[9WR"!.Q
M&@0K82N(1B9A,))0&]BS+,_%,+*IHH>[KOT9CQ*JJ'B#L1]*4==U/`_=RI;U
MQ1!I8]I<KBU>[&QFM("NE7$@J?_569;*IL[@FB0GCRJ.VF1VXEW#^W[]A\#N
M94WNY>&MY?9YN_'L/N*^21.?[+$RAP`)8+T!+F^-*/.QI.))F:LP\.Y=Z_I.
MWAO)V48^NZN1ZD=HBO%N/VFS7BBIY@5;/9$1\Z"7N0]]0H)(\+!`MC:LV@$]
M,L$,`)V/?U::,NIO;=I6<ZG9+#)N94FX&8(]+XL%D6MR';V!RA>BQ!5ND_6M
MIID*N'HVC*KI;]0B2UP+/(U-;0TS,Z#H^5L)-L7Q=Z*ZKX38-U\GKW63GS]_
M]J:GZ1ZH>[=D6!3;X(])0)SC'$[,"TV]=XCS9S7O:FRUL@$<33Z1)>NS\:I&
M#3X8E5%?/U-F9+;[XO)#O'5Q=_HKB^!H5FMF..ES<]%UU8HXGBW'>>VY!\6]
M>=EE#L[VZCOG*B8-I2*[;?(>:)=>/H,LH7?8@MN,4)Y]F6=HXXBV]WO+DKU?
M__<!\070Q6V<R3_ZV<DN9]Q:INY/<NZ3IIV]\DTEIGM!FZ.=W:MG<7V[D$^;
MQY1?]`6Z,W99CPT<DQ@DQS@#?5FM(24MP73,$"4Y`W!Q\<T>68:C4=94-G6`
MHC)ER.2(%.6AZ\EDHA,9@<E$EDVI>=$]VSOE->0N];/KKC(&7%Z^:7*AF6:U
MER6:D6U6ALW>?3W,%);EH8[@"ZUCR754(VY`UX!E,BF#1'TBE^<L`J>K65P=
M*>`K>>'`$4W#%Z=KW#E\-6UFRF6E3MK,9Q1,Q&A+&Z<O3/P;,%EW<',>L5FS
M?0^J+A<)80)@"@:A]T8J591D[QGF,U9B+30MJ@@%JN%+0I!XDSCA8&2'%*-:
M-TR,(A(R9=LVM:U`20OS)L%$5^HV[G$6Z$\A/I,T33>KT1;V3?>]R+(\(B,<
M&C8IGZ]7UX>>"=P[:66[-UX0<6_`^W[][V%V>8?=/3>BG-DI_#8PAG1?^"S%
M+)A?.XSK4+:!Q*!^`*M[NI^>:3Y0L^AT6J^]XQW-B\P6TMYNLY[U,FK3`.$K
M&G&N>2<\=@W`*H4ELG2S.8",`X#<:GKL!R1PK9UKSH-X$]JAB\K:M;-G_:"T
M=<`%D()RIQS9K,W7:Y6M;O89Z::0.S41F!RDGJGBO,Z.WO!!AMM2K91ED4EP
M$(7UH0,$Y0C1@.;^I1'\F5*$!KI/:B.#88[.KH,F()XULX5Q59'<92VU&VNX
MH(L">3X?9R&`B6.8N.:94H76R$6:WX5$@)N]EZ]9;WN8N0O?L$>FO]^"H-$#
MNLO/!=M;5^L_JF"4KCA[^U=ORH247NH09+)"F0'NN5$B*I*!%`+'=HR<,C]Y
MU7JX0&ICC^3Z?+F)V4^0$T4\21$1\^F8JZ^XB.?(X#T>CSQP<?-S7==1JL43
M`YQP_XI@0.*DI^[_7=+P?OVOH7WOR5;A)&4S5A#^\.5!("C''U__-_L=*%W(
M3++R!%?8^LVO%$CDX+'E,B&^Y!2GJ,;4FKF;0V"EAA(%3SHL>/'?AM6>":*K
MJZEDVA25;M5>YHU*>Q5Y72^0>$[YE&ZN@A1`94BAN@.H.L2LFP'[?Y<B9?G:
MUOUZC<.$5[;(.HT[*YS3/P.G3\)HP=P;LQ)F28^1J4V^;DU1=8J1Z0J-9I-9
M,1/CSWZO,VJ`L:86U<QF]*GTJG<:KT'U8U*,K44_=,#:`/OC\3@-\_/&5>ZJ
M)DJA`89V<RR<J#KG$X>Q.U_+P!8G61;]8?4`NW2H>^@Y.U4)5;MK1J`]6W^-
M?J!_A1YA(C"ASJ.EE'LJ.*:V?3O9V]7><'(.C0`1?^@\3"9G<F;N[.YR>EWD
MK@>]KEO?/*:&.,R`NM.Y.^D3>`/>]^M_![M[\V>FG`@BV+TO:2;7AR'\P:6B
MV&DCA)*M809F?YUY3I.I:1,&)SM-5K<WWL38:9Y<+Y+O&YYA4HYASW;*58%*
MWL^7&3RXOWV'^$TC%*WU2=XP>S;[?B((U65#X=A`JO)$&JET>Q^T>J1?.+B:
MJD,[C>'7$_)G2E9[COB"5R?.+V+]!?0<U+7)G?E3S!U4<2F=%YY7DF8XX-@9
M,)&H'J!+1)@4VW\I/*9FJ6E*=@-+R-`U%>[`U^0PZ98T#9KB@R?)NQ]3PV[[
M_;(4T[QHF3HKP@I-W:MZ:(/:?9.3^;X+!DPCHWK_Q@B']Y:]L:KZ!DBEY6'<
M-7Q9!/KGS+1@FD,8DI**$01%7>"\"1GN9V0/5$LQSQZSS4>QEW6KDB45IP![
M<D9HIGMZ?/8UFBO5Q*!P<EW'&SP?#[]:S;6C@_HJ60D#3@@HB4>MN?;L=]^`
M]_WZOT7@SJE,W@7#O/6FOP-T;T6UYS#);)0S>U[>&)\93L/)>_'"@F,8&]2O
MA1SF`F`<B?SSU&`@TS/UOW"EQ.'[_W6Z50ZYFRN#CBM*F8J-Z>^5^'+,QCV7
M?(W,?`"KDVYG,LXJJO?X6C!JV3___@.$J6"'%M1FC#W%EC08!S/.9I^XAD<:
MF]V2Z#)S,M9&%JG6\]D,"VKFDGF#3:1C2<EL]:FGS=E_7R2#<79SC#*#JF8$
M@8V\[F7OA_^AV"$ZN).LF<T_,TP!!2=K94BJ)0$RM<.A)S`UZ\N9\VZ(8K1*
MA,TJS/?SK&H\E;>"15>(D\0X#+;/?JK4?O;\F=1BK=OF:EHQW2692E)&H$AW
M]L;=067V=-G-)`-F:Y['`]J-@(K,RKQ'+%2EUDU-=R?]IFW599)F4+)M9R6`
M;\#[?OW;V5U>843YFMZNS,Z16^_TZ[`VLJNX?@NM69D=WSP'NUEJ/"MG[8S!
MQ+[+?T:M/$\+^=IA`](8G8X2*L"WC9!^@[\R`,D]E[0;F653OO*8,?^:LO.D
MTD&MY,V9?2ZT'QE:;<&;3VT-`+P/_?UPDS990:]'2M>T!L>FP/;/81R@NN,[
M&PLD[E-^"'``,+IG'5C^9+%07Y3D36>&L4?.<PV),*19""])E7\M,JUV/5M)
M*DDR%Y[=I_``]3HK0%FW33Y?G^H9WMQ)CTG0W?<T0#?EYDP890GWWY^]UBAF
MU$G7\P!J\X_.DLX$QY50><6(0`:3"B1#G'GSO@<RD9$3YS"6A>C&A=#9N`<@
MO%_SQ\>'/`[]ZZB>,MH^2?LLMG632J5;<D/N,2J4[-^L3NV`B.>*64=Z/4EF
MY,!4:[LQVP_5J'9F:+0>Y5;=5MM9"S,1*>0\:K#)"7=M;\#[?OT6T/UEL.L9
MFHL?FU8I!1;N=[G=,U>FG1FM5\5LNK[*@9JL,RI+^8R]DRGC8Z-Y&#`27+)F
M5.R$3;U[=.)*.3VX-?DHW[(Z7K3?ZZ=BQI<!M\3/3UG>!/M;-@@A!3]G6OV,
M90J\NK:L*P/(FNK:9VDWN?O8'J9.D0JC]=IE6&%9:C;-/:M1IRW!MF"V,IB,
M\2B]W-][>3P$!YC'V>G&DP,_,?SP@?EHS,KBG40GN3N=(0&[.-WMPN<@V0Z<
MHQV][)GVJ'8K@:2\/E_R^?J4:Z_&J`A05#UX:,`T@:_5NZ73108L4]G6RY@1
M54:-OU)^IMO3DO7ISYAZ!)]4*A*GV[&V%':R9S8P@BVQ(D-0F,G\98'S`,_L
MP3)O$RW[OU_KWF0*`\B=O)X>(_KKI,VZ)7/.2QP:J^P)&Z/KS\4QP>U[C\?C
M5M:MUMH;:75I5WH"^:,P,8U)L8':8]XJ#>_7OP\0_Z'W@8G+SUG5>XUOU^`Z
M8Y19+<NG\5[K,M<\0NGI(TK(_")G&W$+NS,P;H8QH67A)%$2X)2-NL/,[S>^
M1^43(*QY0DTI:HDFSNGSUB0HGE%P!T=O3,*9RL#73*1M]0:4$11<`XC:5_U8
MP#V/228[TX"E42$8C.4.7,NM>S'OBYW)X^LUR@<,"G4R3DV1A#,&'E:/ER/H
M:(H42(JJ`VFH7J64T7Q%F1G/31^E5^3F'5UKF[3(K7L]H^AK]&E97("A?\I,
M=P=B<YU>E6">N>DYZ=AU7>7Y?$H!+G1L8@9F69;>&-4-)F"98)O>9HC*J!\L
MSA4_S-Q!D^<=814S+30?_+ERJ33`R::0IS]AF<DX/0="I+G71#X-L!KEBNW\
MJA'3NJ[R^OSLV0AO&@%(F%!:%NQLBXC*&3!VT5J1:+8_:V46/\:/99&R+)<:
MHTTFL5:J0,E*;4+I1^^2A]/5G!(X>@\&WH#W_?H-=O=7%O)703&S%O^OX9<;
M<'HLMFF%7M)\%6ILE>\X9&R`U6N[3NUF\]'9U__0\8UX.9KI]ON!-V;5&K$<
M0.5+H8`2+5?I.*-*8=BMW%*,.UWC'@6.U'8YI+?0F93**JV/*@3R:7WE#,SG
MUA&^!K.-ZW[@#&>Z4J``$WKW.`Z@T/Q\.I,H[``X&E@@5.FP/QNJPWP?\U)P
M.UC3.*J4(H_G4^JV9RA8JU2IHIVQS(D"56,KB`A=.P\B8TH]0$.<NV64.SP_
M/@P8YIF.G'O,3;E"MLU(806##HACW6&0)]V]W5FC=#:R=&C`&.1XFU;7`4A:
M:2ES8*OWUT&8F3Z4W,REWR+2_(/NHM=RS$&EPNB;P6OHC0L*.EB<)U*@P=88
M(ZWLC#"6XSX]@`T&!;!:QW=8D62:N_(;7>-,$Q!``_!#CFP&_'@"=C\_59F*
M*\Z]DEJ4Q!'O"ASJ=QAUUHPUXDDPIP.V4HJ4PUCC;)@[[Z]K[Q68USK=`#WO
MH:6HAT3@[!Y5V=`;\+Y?OP5ZOPQD^2OL;P)#$:6A3D/[,UK8?(*NN:/Y;S(+
M=7/FJFN`DD%O4VN$BIRP3&W!ZUHI=][X]I&8AB\)"-5IL1O/PUP8\D#D.+#M
M9UE&JM<8=P9A'`@=:V&,93W*1T[G&7DT(EUMKYH2@\2J:@8:3K/,53W_'=^.
M]]P/;<NL#("YR;JN/>VF^[H-LQ32JQIPBOD='Z3DC73J1,!H<"K+(@4BV[I*
M7;6/65)\@3'1]G'&9-W#6H!24@1L,*MCBK9M$QP=W0EM.]]<CKE42I%UVSJ(
MJD:Z2Z*C%1#5HA%!+(!;^UVV.=&M%DB(.<->!$&>HD6V[V)JYL(4#@V0IK'W
M[OY5#HU;;Y:BRR!H]9!YXL_%S/!=G,F+3%A<&]T8(`>;'8+6IA7[M:$&`A<(
MV;]S75MGL-&:!&4$ZH!G37<=6*@Z\;9FZ[:)/*[AU@YV?SHR99:N5WL81*P6
M+]2>8UG2`0B9GV.!^;4:T^`87SGA&7!QII"4336'^E(CWK'QG&S[7FNX7?\;
M\+Y??PSH_FXYP?G&%_=4;][0-S+PIM20YF-P#K`SWYYP.-A#DB*GM5MTNVQH
M_,'@.+*#>1!%-(P(56J\D*K)B;;AHJ'XJVXOW'%?LUW1^UO74(](HP8P9]1;
MN436)>WK9VO=/P<%N3X;)+5C@TFC*GFPT9%UO#^/>QG`7A2;'50%>HUAE>6Q
M['5J34L3ZOOJ0"^`:M*PSU:4$]>Z;4IW]5PJKIM=F)(91K!W48L]4K29$P@G
MT\3KDR4A)L?XKJ^7+&5192QR3YO[>(]E602O5:V%QE!92UV/T4PZG'$GT&R=
M4>+`C&WV-L..;S),):ZZ-B>4H_3RB<P<QKL1Z@LS>2!%E16!;$?0686!5!C@
MD`KL8*+&H5/N]GEBTBRHZZ=)A/F\2^1%/TNF'HU>#21G_WPP,[(<[E.\TR,]
M29^PS!BZQ@#&'G6REZ[K*J_7*P\X%/4^=1I4#)!6?/`B'K$WI(?W_7-+0;#W
MG8VOUQ7W9AZSL$C7;Y^7P;"7VD39S_AL->CW?[^;UMZO/PN&Y<]4&R!%=G+9
MM\:;[QR_,F_JBKT);:$7R2FMX\NUIM^#26/2=!13RT`EC37Q/G1G:U7O<Y0!
MU"%KPTR$_0OAQR7D/4ZY6G>9F>JB=9*[*]J)A(S2BU>_4U6#B!^S4<,86:6X
MXVM#C]@3Y;5O+=@=0'Z_CUKK[G&?Z,>1E&W=1`1=GJ>SN#V-M\^$95EV=8(I
MXS6>V_I:.WB>*EOXAD;:+"3KH>V9J"!D_X&)SJBM!-=E+LX\0Z*TFJYUA"38
M6+\%XE;@G]TX7*D"$XWG.8W=K)6S30;#K6\&SV3FV7N(53)13*'6.M6(0,O.
M^?OQ"A6&71-7YREYK6-H>0."WJ_)6-/_#LTW9VESW=`89,H8L)EA>W5PX@?5
M?CU7U-4!J"D=DV@8E`6)6;ABYN',7_UBKYP:^!ROK5;Y_/RT*7X/,=V@^6P0
MLQ0-G$6RR#1(\4%B/H-@FHY]4S')6%8RB^&FTICQIQ/G\_0>>)J%?*LTO%]_
MF-V]P\;PFCB<G/IRJ=E[OQ;52OSS)B/LB4(HB2@#U$[872UU%4&UU3(-JL(^
M7:0Z6[U14[O6K6KIH*^9,)A/.W%(:PS-`(GL;%"L?;9P)3LOO'.:E0QRH)?<
M6<)U==)83$*-O/R#;GS8%#EJ-1)NND-:=W!KMZ=V.-5:CW(&"?J<702_E+VA
M+.C<PK#2&GBMKS6(T<,5M]@B!2M_45F/PX:G2JVZ*[P#7]K.>J.R0@O.3`"@
M&>O)?E*9I&X<J&#6A"E-KLT"22L5K4I&IM%>-+D84E&Z/,*M>4:[<?)"?L8?
MWAIP<[XTD8RCEV3K9=BT?\0#XD2E`AD@TN4A@M[0"(Z0*<8ES.=CFN[FE`F$
M:F(5>JA+->_]4T.O6^[2>3K,A?T=Z#'4+"JCO7)VV.#&.71VPJR?GR>DCV?)
M<_(?@:]QI1OJ[6)FTI,\68&#W5EL"?QP&V2M1H<>,X)**:JDACK>T(G.-4X2
M.^.PBNU]O0'O^_5'P.XE%S@!NTJA*544^"J;S%L=[%[,!%^&SPT(0/(T7?7L
MKF?,<(X[F;"3*>@4RV9-'MS0=YQ]Z-DI>V?'/AK-PGVE7>:>5=//4VMGJ@T1
MB38IK41/K50,B:]O8^*K/!B3ZG1,!Q/M#H'>R(Q+QINRUZ9NZSI2G.T^L`LU
MH31]4:,Q<'Q.9./)O>;M\S78(*J@C49K,ZE3ABX7:<_(.EU9[(9<[LO]S;0B
M=3Y]6O&`UL8U%JHJXQ]J7IFLQJ-T1]>F>Y!-,REIW.NR#`^]V:"S]C66SXFM
M,G6`K(PKF+"Z3.%VLB%.IEU1<FZ<\@6P@O\ZD\'1C+K_/?Z]#T!1S6/C/IBR
M[I-"%$32(H`3)-(6B';KNGG/@Z\I8'(Y"ZVM;:41M=H"K2R;#M8G&US6E+R4
M)>QA'>RNZV$PP1C,2Y*LXC37%TQMLGT6JH1D1CI%ZWF8LCF_,>D>A>TX^RX5
MH1V)$#`&)T&BZFV8Y2LYV7S>@/?]^BVP>X]5G8$>?>AZP>_SI/N<.+F^&DPX
MB2N*.1"DPCGH]^PNXH:M:X$-&(/BZY!)<%I;8]YX=N'Z6F=[B#SN!1D>WI3C
MO4HI'<3`1S.`N69.?"F-5F32Q!=2VH`CHD=>E+"`SPK9%SM&1Z-<V[RUX+M`
MCOI2=5_*$C<7E!^(J90B!"P($NDR8T;B#8-A\>^C&>579[3O0<T&6&JM0R=5
M,?/V8!/'<KE#W'>0\WH-A&M5;&CJ/L=Y8)OM!:DAA[/SU5]&IAVF&Z6\,+^S
MZ;*US=EH(]1:>D6XV15,@]$)FH4R9DA!;3H*"K@J(.IK6XTI@]G[,`$7L(`_
MO3\&A8L6T'D[<GIW=ZT)G1EZ)+)AXIXWG>H'TZO5*`O!9IV7^^THK7A^/*=G
MS;JN`0":/80TS/[,L`<Z*'<HW]AKF]*Y&>F2U6_8NO1<__;8RWAF$J&EI>\U
MA7H^AGK2GN8++*7]!KSOUV^!W=GR\#O#=<UH7E5YQ>C*EQC>M)KP!$;;)1VC
MY[BQI)WSY,51C9"2SK%X9";O5B6T@T2_:?FJ1>UDK#7354J1Y;$<G=]#M:&4
M]J?T.CM?EJ'K%4<#$1S8BE[I'H@,)B6ZQX7]VW(XL=$!,-)NPW3"I\R_,H*V
M[GEGII-&$#EO<JE'R861ME"39[J**`%XIVO>L;I:3%\#\+,!,/N"=CIS@=B4
MS?*QF'-WA<K!!_4"NK&`KO6,^T(8#PY6O,V)W.=&FS!,E$]\:76HI:=4DW=B
M.+[C>P^&LQ3O6@;AV0X*!S+U)X;>@PPZ^WM6X)^2YO^#EK-9]]&XQ$M!VN=#
M=VI8)9MJ@EO['$U^#S#2B6>G@IY?"(0P#9F@[_/CX^,(QF;&)+Z6';&DZV1=
MA:>C!H)9_*>;<I&[>F9[%9D!8/M<:#(&5T3)D(L[/=LQUX?WP-V'5'ZVO%4:
MWJ\_`XK_P.][+=D_\L:3V"]GPV`81AC`'A<PDLVJK<^L8L!$WL8FF"<`)0.V
MO\*I[QVM8`2&O_)\M?8O+B^8KO-:2;TY9P*>L@H2Y5/=X=#M1XV@*"X%T,7/
M/X@I5]$R=5;LX9#K@AA+5:,3BFA[J8%D;T*C;AAQ@"=SGJ+(ME4I2WNNF(1'
M@R$*,F_8RS?2<=0_ZVQ3/1-UOJXMBVNU/8^57ZQUK%Y'V;IJ?[]>G\?X891X
M<-*!3F4.T0-'B%_T3&1@C/:G9,#`SU<8,`%:X-0#&E4%"S??34`YZ09HLG%[
MML:B(5QM%8?K@W$]\P#/E6RPAY)P_C<P@3`($T2VKU&B&H(QL];VWK#["[S4
MKZI31^:(<%Q;;;)4M&=-+VL)`\5Y(ZL5%DR#M2:#51Y%/CX^NETV4K@H$SG"
MV2-#EZD,;+R<)@'"_LQTGT#J0*C'T'_F;)[-SI<V7KW\;&*7##.>8HNI&=0E
MPY:?/<DWX'V__N-@-V5G^>^Y3IQJ`&4FQN?"P;L<5AD"XPXX&1"1"=OW]'U6
MT\H4)!X.!]'-RFU<YLAO[D0:LUP`WC/%I-GQL&V;;-OF``'DJ%B-OT%)4IL#
M6$)W*)NW'.P6#``;^L>0DWM$W)@I-*E:(,/PB<01Q.I[PM6,UBI2$-O'%."U
M8%<"D^2GXF@PJA,+LW$X(:RK\[EF!/V!K_F\.""C]8:-])-8XIV2D_!G__UZ
MO53M8U4I;8@<,E;[84GW_DIA@@/(Z,ZN,Y`]9:!<68BNU:\NR##,FB1:IR[P
MZ+!=@SXS2VPS9L1P$'W#I,J!H.SOF\A5^>IR<<_49DG:[Q0%F+V!!M+`4!13
MVO,_RO&+Q^;5@#.,"<[>0:=EM8"1Q8/NVC=`VC+]3;\9*7BBFP^)*8-Z+<LB
MWSZ^#9D].;'$*46P;5(5$#TC$Z@DSR0$47>X#YAR`%T_GNV18Q_1JMU9\"I=
M8O',($=$C+K-S'`S*Y'"&;)/B2&KQ_TN:7B_SL\O7A4B7!]^UV4(ZA28J%;S
M2]><(1LHB^+S)C6M,7D:;4ML8$$I2J[,0PH:T&22FM20*_<Q]Z02OV"SZ!&<
MKE_]M>>K6$VR;V"]?HNT]7_FSXPV5MV^;J/3[*0&P+:K5^D^WJQ)SN:).)U1
M+1O79=&\#JA6-%`YV5%S*R+"R*(JR;7P/%4]L06FKL9OPOX!)VO-U#N+*7-0
MB-Q^9K].!L`S@B@'ZOP8JS*!("U6RI<6N)9P"M)BAHUVI4AN/&F%HM.])(,M
MS%KF@PL5$RO7N_LJ5*VQ59.!T[S=&_8NR`1=$87<#(VN'RM+K%,0+<*I]LTV
MIAB3@$KY(&-$Z2U\TV?AM7?%NAB2P?+:*-_0J3Z$>:#JKWN)5F;!J]PF)50C
M"[`SN[U<8N8;<3R\Y_,9E3>2IJ\S1;0SL)LZ'XJX&O-8ZI)^$*/^/2!&*P-7
MV4/*[B17\[5AR`*W]G@3"=`Y&?;G^89T[]=],/!%L*L6G.Y?\HL*[F<@7Y1K
M..&*(\#%Z3UEFT1:SN`VD'(T)I52DD5Y1Z2&>9BK?^-&WLO7?G4FP&V@$)SZ
M>O!JE%S*J++:+OMT@V=G?2"JP>UTG&*Y`F=R;P?@SBV3YI.VU1BWPRS4Z.H@
M)>EX;L\>3.J*E9:P/RR:.YCP>A+J+FB]/G`B;6(/8SUV46_8ZE?ZN:]J*Y$$
M7[K[O"WFK':_L8B(3":]IMZ-2&PIBZD/3JQA3)`;0:>$X(K'-=)KSKKF1P]H
MO2YT7(L,`2E\@#U9WK9HBJKLXCC$48X:4:08W[\3NPI#OUFESN`4-/H@E/U/
MJ#G13"!<_!YMB7T5K`;&QI[79P9<*V#<DZ-&[7!8LTU]5A=#W#R4!(S[&15_
M#RZ8"$$GY[O<4HI\^_AF=*OE9F;!F$Y,U!WNB.\8E1%OEJ<S!\CE,W5D&.WL
M;;C8&H,SDPRS*6&H9<`$S-<81%^GWK_?@/?]^B5V]TZ]J98^\HHN,E/%XLT:
MI$D0FNE]<M)/>KD-X/RS^F<>'?:`MU[-$24.@*2W&P\,XL]&U8<(/N?/KBL3
M:'>G)*4<Z[JN)\!XOMYU:T`NTP0FD,?ST6O;YL-.=Z"Z<=0J$\>%-,,+7Y;;
M>+@``"``241!5,<WFW,R84@N5=N<A?#C\=A!%Z)L$\T!?MS_X[$S'+6&N3ES
MB+*=T9G+D3U@8`2?G/:Q.@P"`Q0L1V,P-L0W;%W=V2(SIBA)T+AII8JK:!0B
MRV.1I91NWPU(PLR/"9`WKB6!#"T`R+).T]W$=%9%A633(&1J9ZT4FM[1@!RB
MM.?_>#Y%%S:.O13CC^A_V];=VAT1K2YS)<^#,%($Q36:1O,,4QN@)QQBYZVI
MXP:4#;1KWF,,'B#>I8\CFT"9&B+0T9=4<\)Z[]'H6\-DI=1>2JWS.Y1IHI''
M`-2E%..@&$'FQ8:DQLW7X^N?M2W;/"U7&\N#)K[)YB$-XUO,_N^/JA&@)<]-
MN]"X7H>NU7N#2C)LO?K.&_"^7S?`+F]RODG*XP872Z/@:-4<>?M]DOW@E^"Z
MW01Y\[-UPXRQJ4V8W%:ON2S+Z6#AD,[B3,LVDT/*=%*5M:6<9/KYE1'RUJ$:
MR#AA9<-H'?<-@:S;ZL"!2"F+/)Y/6TGMI)=:$/!\/+O2A`:5N/&H;5#&WOCD
MI8X,((;]=SNDN@R;22LS,B_'+7U\^Q"4(NNVCJYLD?3`"E)03K*@+(MC<S/9
MH'/IGXRU]JP+)BK[3+JC=.=U"!2=JU>6DKVC"M,^X^/C0Q[+$B=UZL[&V,U/
M3M4).QM^8T.#ZUCW35(&O"30HJT9JX^J['O;7J`S)0WP/I[JF4N0W)]U\YOK
M2@!M#`)CX.XM9.F94<TXZI_-FB'E#-@A=#&2B2(%Q2B[=$8X50V@5%;G`!CG
M/YF5%<$H25!K*?*0&L,(VLESIF;;MF%28Q8E39-JWT_\/$V>S2Q(\?/OKDLI
MK\Z#GKG2I1Q(&VX;X*78^9')[_&$!&!B;<[T]_:OO9O6WJ__#*#^0PUJGL1+
M^D=GL>NM`PQIZUC^ZJ#R8IN@[%:22]DM9>N1[M;U@L9HX&3#)%JC5&,=(+9K
M>6P$P\^]!,W.7W^&NBD`@\6$]`YRRE[R`179OUZO`3X4BU!KW<'LQX=R3AL'
M9P.[C\=#:JV&%6S.94")$\)UV'MBLCL3*39Y618II<BV;;MVK3Y$#^#=V,6"
MQMKNUZ2[G7S-,8#]_LE+]S'X0TS=;"NAR8$74VJ;SM%K@,=8^VW2CJ&853E2
M^7N]"UI[5WBLR=5CD0KVJZ]]?'S(HJQ9=1*ZNBP!="``L1F/9)$'MLS]$!(]
MTAV81F;6IKHQ>2[H#5IQUS#65B)">3X_)-<AO?^J:KYRU@A%J^0!)R_7U>'4
MNFL@$&4PNTQ`V(Q!=M[0.:`C;6I?=$,<8A"<!G?J?@<];#^67M^5IN=@?(>=
M8!!%5II^%C??7NLJGY\_$]UI)AD:F\.A8]7[,YQ*!9T7CO%LSJGL0&^>;N-(
MM.U^](<HPQ_O:MEZ/:X(MK8_(.GKZ#^-&+CE?IMO6;+WZY39_4*T1Y$3J_(`
MD[Q8P=<YV.L%"[/;_/Y87+V+/;!/7.F.]]VVS8`670LXY$5Y73Z"I$8A['/,
MSY3?F">D/9.:=`W00._^S<?R[`=4K7NM+TVCGD[Q[7:\R[+T%!^CA[&LZZI8
MZV%-^5@>%NRJO[,:24LHV#I>"@4%\BQ/X^#5;8.W3?AZ[=?ZW.^Q+,MN12SS
M.N,,R)]E*HR$G"H:7!J[G(!("2P.$\W*C#5-QBY=!-&UC\F8G\MBV>G*RB`-
M`O7&D+RV?.\,+_)\/N7GSY]A2U*J<4:B3<\MZY3&^1[`UM08I<-L;:/7^X9C
M816@=@\>7=*,SKK52^85>3P6`7YOS]=U[[JI#,YFE\G/!,OG-'B@Z2>@ST9E
M`%NL)JW/`$`!:)!&):<#'R\9Z::W#X+@I.0J*07E8(%M*<SH7>-DSZ61\#)"
M*NI'MVWK8)?"/`/CUG3T!SW@H+)&EAGH]<_W,HT7,QB2N-9I&<?!WB;;!T5^
M?G[N3<ZZD9`YZ604AZ9*%+;PQ,?EFNAX`][WZY=9U7BRW&%T$KW=1&KU2]?@
MPSG8SYLK('X10,NYNT[&`,VNN7?U;U2UD+IN[GQ`/'A#FGIU*4<%M#.[WE]]
M&>DF[!M]46R&+O>H.B5G#C]1W>%5UEH/MA:J^60$!+M1@]K)CEK:X-@%&_G[
MLD%@5PWS[")E5Y[XK)]#7HJ**5=B^>O!`#=K6YD<7/J0TPH65P>./BC[(0#L
M)3')`6'M"72>CX?)`.-YZ)@L./8EZZ2&ELK3!X_]R.ERTV`4JNRFG#0RMFI<
MSW5U62HRFEW0R>"9!B/D-J[)0=VK6L)I:IWJC([N0%]6P?58ERU([))<C3GU
M;G.Z*8A098X42OWEZL1>SG,HAF19,Q?G2"*I/;9?UW_@66(FC*.!C)RT&3>`
MZ_R>D=#H<*`Z"RCU'*^J'G>F#&%#/(1Y8?9<!8Q]A9D%Q)3/SU=RSB"JP`A=
MYA%?.,WBAHU)D''GO!U`GB';N"Q+JM/;]II::]]KH:4`74CK3)U'K6^8'`CS
M]*RD[0UXWZ\OL;N_4^<#=UR=^0I<L9IW+'5_<S#4M2C=3CE7\9UJZISQW?3&
M`E=!0P:F,8E$[K/VOP)TP_4J=J3M/%J](>];MPRL<7RZF&OM4'L\'@,H)?DL
M3@\HD5JW4*<GOC8/$KZG;[Z*"`US?<6.:]<K3%E4*_^T:_SBD#(2U[&>6*"8
MH\`S\IG3;Z5-P7J"DHRE$F9X3J0(,P9/#G:.I!3!P:8MYX?XQ(:X*NW=*]*J
MITE)SY.);QZSKGJ47.K?1MQ#DWG4\Q)9D=7Q_*K;@XFH[(`AUUU*D5HIVUJE
M/)>Y3?/-K-2LG"0\.P?,M;7V['E75Z(SL\;U<+*4,AJ"C[D"M_$$9S*O4M,;
M&F$S;(#)#G5Y<Q.`9ZPJIH>43L*4,NJO[5H;^\.V5:EUBUDGX73=:",/GYE!
MEL8Z*6VX8TD/M1D8=IR)))_(:+Q#S%)E!Z65I)];0L6#`B9[($J!(Z.YVA?>
M36OOUZ\SNPDS=.L]+KJCKIR;3"W4F0)8TO%\AXJFCH*ATF^G;EVYLSR_,*C7
MNK^.:8L>BTK3==[R5PYU@Z\T!6;WR\2\(-1F.X8*&7LIN>4D)_:4_FM+*5)0
MTFWRSJ;>2A#TI2'M@%#-@AQ-3S3LM23-4I*D;R?Q"3V#&+5SE[(<DFZ2>ME'
M?@SILXL':SLT?4VJ5AAPK&;+%/2.>J<V@O@L,QOA]J[==0[S/QX=[?K7D'5=
M1\-2?UXT\TFSIZFTE>I(-P<V1U-9K*;41C.Q1,$V'3D)L$JA,YQJSP:(@,N[
MM:WKZJRWOV@7KFKCKX+C62H\^YW9^X6FMLF6R)Y)45_K&2`&S=K3L\3O=="*
M,9.]IW*4;CA%B/D>T],5LBR/TXB+)O-U4!83R[*L;.E/GN5^C<3/C6PR$K9C
MVE.@!KD4J/(?.2UIM%LOQ19S.'>8``"8NK:^`>_[]6]E`:<+E2>,G5P2-.+.
MFPM)I,3:Z2:%B;OE#_"J#.>`SK"/`3SZWGP:T77.F$'/Z9VDS/&U!W?WB;C#
MV?;%TR4%LY(*3FK..!D=W9%MQ-.9$X*Y&0,S:<ZX`9,3L.KD^3F)$$1I!7O!
M2RVJGP2$.JVWLRBX\:"L^%`_T""IU-O0GD58KZ27-6-G@GE2)\B3AKPX/)1M
MJU;7T_P0YLNZ/?J2K-G452Y*A67SN8$0'>0TP5ZMR!*4+5I`X)C:-#Q!?BUG
MXZH96DZL67D#Z&Q;=4`'69S7`W[]LYB4%=PI$<FLK*^`GC8SH23)M)EA`I.Q
M8U0!8L(0ZTTCE5!TM?6-`0[E1DDO7N:,^"M!BSAW;//,5*WS6</@:4`J$E1C
M?&F)"$8#I3J/LZ"Z-73F4\1:&U=FCY2JEA@3-B:'O6_`^W[=2H/Q9+'=80I#
MS:X^=&]SKR<7E>4O,&>Y[D`XG*&D7T6)B0XQY@AK)).@:CEID966G;W+LA]N
MG&<XZ?H-$7\YJ@0DDT7.4Z"IQ$Y2UPB!+$N14A;+P-`"3YZRZ#E`HLPT2"WH
M2TXQ26.RHYDC&W(:!C]AS(^/K*RR/![IN,]#QV$L,+SKQ4B-:=6"%/`P\=M"
M;&"9,G^,=9;!5K0?VK5+Q(6I!DYC+92]S./Y?.ZE#3*QKQ5)7>_T84R)]KVZ
M-C.SDVO@UA@JT`+U&=-])BNE_V92CT/E8I8MV>!F%_:!.@V.Z1;-5(+,!Z6X
M9U242='QPBXWS_PPE\,\"1YX0G+DGN*(P3>M:4(C)KR>+E-^0M=^>R45YT:9
M:H@G0<6D3CBZHTT($R]?E@8WB2T]]E*&92FV,0\Q:!_]"YG&N&:Z;QR]]*85
MG#Y#OHTGWJ^[#.\=DXE?I'Q39O(F3IRJCL'I6'[E<OQ&;F^24U.,B*TQ9UIP
MNI<-G`+/F"+9U*[Q3V"P6F/5K)/^Q!XV`XRVVUF)B9-9D_I-<MV#!-\)=<B=
ME<4T*3+PK6>\%SM8BB`M`:3*R""KN8Z@99=/>WY\R+=OWP]-91K%!Q_HL5ND
MVH.TS:EE*=9<X")DT\U.I#5?H)X.R@"E,@%&/KX$3D&)O1P'-BI%:Z?"=!1"
MMFU-Y_E9@$M*UT36Y2C:7<[<)YT1A*BFM%`#GHS`='X,8&@R,XSN;![43C,=
M0:D`IA'?%].?%;1X\%LK#9,]-5_73F6(T;69#PGH.LO>>5O>N^>291YI:H69
M!.+=?IBV\S\$(5GMJR_G,(<$>C9P-P+)U%-@@HK![#.4&&EU'D[V<LB%F#IS
M^H8SX#M!EG-#'JI?+;VG((CAJN>QK;O6L%5Z45FHVV>8>\;:%IVS3>)M+?Q^
M?9'QS!;6E>K0W6PX?^4]>/:^^!(QR\D*TQ']F6/MO4&S^P].[3]O#/I7[L_)
M2?%B`(*#:#3V47@7Q@W'EEV(\SKE*<B-#3%02"0!.L*H,W0:$47ZH*"$@\QJ
MM8IXRD7C#-U(8\LOQK_6]27KZCJR-;:^*&IKA^"ZK@>#:0U.+ML]6E.7.!V!
M5IJ@G+X,?KIA8>W!GJV335A&V!H\79Y2RB[MYLM]=+!WAH'TLV1&T`NMC;E2
M2/%I\E9;.R(#F%3M8+\L\,)%XYR1JM+-4Z&M/W$=HW,&DYB)XF2U!;4"#(!;
MO:27F4T(#Q+*!T)T;:TWW(!CP;-93M\"F66D>!HT9.!,8,NJK#6WEU]+@"0R
MA9#S_7]9%BDHD>T.H-J6LG3U(M+8<R.LG?&`D8%+^"A.VY+[DD#DF[O?S\+8
MVU%Y'NHXTX0J1%ZO57Y^_ARVPD%75UR6$C/R>0I\D1!<1AE%WBH-;V;W-Y09
M[GAT3RU];S##T]_S9@*8X<I?%ZCDC3$R>PNR0P;:U/1V>.&[LX.JA19'OS64
MC)WM!MG(2;/?O-:J`)TABM^%T3^%8CK"3J8%[#$V?9\ZQ$SC!U<3)=\B02@P
M05M"(+.RBSA.C"1FGS/KNB:@UDX@ZQ*5O'<'I_O!46N5CX^/#K2`8FQ2_*%-
M#AF@HKOF&8_Q!@KONB_EX`[37M)QU-ELQ>/Q&`<GHFG*S"%N6%;3:A;#KD^S
MKKR)QJ3I29=\@)(V\AG@I-A8R1A2![)"K:5)_QP_1\A$Z?5@_!_6CO?DN65,
M?*VTD"#)Z$SENMQS(E7G//TSC(H8?1W"*A1X@PL]7D:IP9E@A-_S7Y/<G1(*
MTS=UAF&N,`>]O0^A-S@W]12]CN<KJ!X-FE#S4+.^.O-@@A&<)+`@5GG"["$P
M8VW61_L=+5F&P8JF[W4`_,?CX7258_JE;ILZRV`T>.U40H;@E29O7,_(5&Z2
MLT?X-IYX@]T+J'!5PGG]#M=(=O8^TVNXJBO@UW,7YAI<\:<_U*V1`^:WW"5"
M=>=H!!AY*58BX:;#8;WA^V$`8A.<=IM*Z1]'?IYL'.-SBHAL%OP(]_LUI"P<
MQLL;)+(F&.8PV;$E#(R^.\8#4-(VR[N_.V2M*OUL!,MY.2<I,?U)5QO@TX&<
M`?&@96%!5=VJ;%L]E!IPB/`7,S\R*3UK:C)K+&(\#/5<=M-EEXZSDZ2Y306V
M6,1THFM#@+I5P1.'M%QDKN`3'%H519DS#,`4@RHM0P8%(&+#J%TW<!?@Y14[
M>*5OQJ0)9#HC&?&^.L!=NAVQF:Q]QBY/][@5VF.R=D9&@E8^RAEA:)8PU#I!
M:;,BR6`H%0+2CZ6$9]4#&20)K09N];^53G<63&LP9B2U?+F)4N:9L8H\]HH0
M1`#R?#R"2L'LO%W75=9MD]@/X&IN/2#4S7'0]<M(#"FL=&/F32&:P4=2#N.;
M"UT`M0?>28.VJQ-^/)_R^?.G!:RP9RK@#SI,D`5<]L&N0V<,9[(I;\#[!KNW
M-L>OD[3W+-2\)]'TQ^]V8^'7Q+B9LHXMVLYR<?;HUQ'J7$1&&Q:?W112EBF@
M8\2ZUL`4AIW;ZD->/HR3TI5FNQM8L5FFS;."S)^S<]`U,G$Z_<V#.2@HPW@@
M9!=RX*NEMEI-GSE\>9W%@)^?F&*F4=5!S5I,"'8FC8#*V&,'B/NX+Z4,]R^5
MKH4Z>'HJ_!ASGLX[BL<$FJ%C"-2<^42;+\R"IB,2U535<3U+=QO\A1Y1-][E
M`/_:&&-8E$K^.0TT)T8%':RVP`%'>E@_$W%C`74TJU**L#B3/@9Z9#\N3MW3
M+O(_U`"N#4S\_K^NFY7=0J*9BFAZ$#896O`5F%W-T"%1K8!WDD.H!<[JA>$1
M6K+QSS1Z7?I`&938[(#_$4A4*&@!\_/Y5.8S\?.;I?CK]>KN=JDTH&9AU3H"
M\G`[N#`&-M0.$!.K4RL]Z.\;":,/>1SWFPZ_6\3+$9Q7>K.*>7!QUHV1A$)N
MWT3*2;UK>/^AKSNJ#&>UL[SD$W"[3O2RUO>7&N/P6S_MZ^RNWC:7FN$%I,77
M"H%GZ$NEL:!I$=-`=Q)68,*6GZL[V;JMV:`X=F"VKPV!>#&U@E0%U*1C]F1O
MNMGJ9H"<D2RS,,[.?0[-S4T)[UO[74ZG(WF2;3@-,.<%T_3CCRCGU]RQ6*MK
M@FO-6;6[?.FZS_8S-;$7'LH%LXYVBVBMCB_"__+]`BIMBWZ8X@B>\)L>N4P,
M#L:8C4!S-.N-,9&)0QXFP;>IG:9NE'4L73:7];LK5O04LJHW`W8]TZ=W%I2T
MSRH^R>,9OUXOH](@7<.8)@OD70K3[ZFU!K?RO#O8^"[">A91DG>3LZ*O6VT,
M,UF']!=NBH\M(Z][!;2..9.MNCM`-G;WXZ.KL!@72_40/C\_Y?/S<^CO^EV1
M]JR)S<A4@%9,`,%)'1;-.8,H7>,D\6S_FB5\/)!OY1MW7I^O3V-N,D@,-?]Y
MAUJ`%^RT82+B.4>.A_<&O._7U_#E9;.:MD+$;U\+?N'B\<5[;4T;M5;C[I66
M$W`>$C"#"+-&C=\9&F`J_\"0(H.+H&WG_JF<ZXE6<D^+3YY6T+Q,6'++9.FF
MK\G/:QU<K=5X:(EZ&=X@K>5VU?8YE=5HJ@ZV:V)\<4?D-,P$&(3LB?K0-W(1
M#=;#Z*+-61Z6G;76`]".`*&#7=-0QA0@!?%[H[5+\XST,^3I_\04#NJ&N?:A
M6]W^1!1O@.0`,QPF'9E)PME.AM@-@)F.*;43'5SC'K]**QC.S)>$Z'(&$^+U
M0+V9@>2R7J_7>M270VQ:G:G=LFG,HUZOJEPK:2J+@>/X#'T_>C/2Z\%HTV+@
MF=%HAC"^D*BDX)LI!;F*CL^,<4(TZ*^74HP46=#O/0+4S\_/J:'.N#D.5A7=
M[Z27>OC./_M,Q)8\.!,&ADK<$>@UJ_9<!QHAB&J**%=;($GY\?.GK.OJ@I8C
M4^4S?71_)G2)UM*F!L&D4^NQ/3#ODH9_(J"]D"";UN;R"A#_@O[47=3+:X#>
ME_+-CVY76TDK%Z,6I$D!P]?OGK"]X+EE\N587GS`3$8F:5P",DC.W)3KHEM)
M_TC=MBF\"_/,-8_DP-@]/RUGY`P8]-_M0!GR8I"<;X^LB94]RVN+.8T+:!N;
MTL_-!S07HO]:9D-+F^F^1-UU;J2.&)F^G!6,U8`=!+6S.6VN/%FV0`!P^BNS
MYL>K728+LT?CE+(=;24)0>23X5H(5:YP8?Y@C%>#'>TL&(PX?0#*?+.#`4.4
MY\<WD4/FKM4NVOIX)JEH'.!FDY\_?XCM):`-AD4U4)F;31H<O=^+&M!^7^YW
MO;N;;UXZ,R;(LV<PG\VS9$H6;:J2J9C5@QUGW=A%#J8SL<UNO_OS\],%S380
M]!)]H6?DJ&UHH!<-#"<;7%8FH8?/UO</+3X;G-MU91L;BRR/1W*F,31SOEZ?
M>V#EQ2IZG3U2D1VFW*ZZS:!0,=%^ACY7\&9XWZ\O8,O;0-)V4_Z.ARUY#78A
ML8/T]KU.!$T[:S#Q`+]DQZDCZ_'O:V&;R?MA@I8N'Q,#>VB:0BX<QK+W;7]O
MW1J3CDE-&J(4PZ(W>LR>2<(=!N:]2^W@<)P:##\R`IO.+($>]$XD*9G4ZNJZ
M0\H%V,4)\,&4-;Q>&.I=B[5+14_/-DFH:C*:\5Z]?YT8B^I::501M"$&L[FM
MQU2\(`*CQ%-CJ\/O.0,&R=.2NCRVI]4O+'?1);:0+G$(=IQ!EX8/*P'!H,-O
M8##!EC<:4$U?.BOC&UR/KSR6AWP\/TPZ7M=YZI0ZE)R9<&^6^OOOOR4W4&$"
M)7G416,21'NQ%PKZ_8YT,T3+PEFAN@'VLZ"PS8>6>:M[R0ZCO-QHC+,::I@4
M`P.>,VQ5_TZ2,@%RVI4P7[LJ\5ZKU+H=ZZ_&.F`S_R"9D(U-+ZGY*TYI@G:*
M,97XH-VMR+A?0FS3H*J]?C95!LG[(MIK75=YO583@-M,P)@;UA[T6',N&V5.
M]]LN2W9/>C.\;W;W"[]\IW;7@Q+DLC9RPVSBQJ7B!)#]%O"?=?Z>#LZ,?>`-
MCDH"FW8?%E_1@KP>0-YCT]NK-:MU";&)@Y2G;HSLEY.#8JHY9P_31@%GH+Y1
M2H'ACJ?;8/(.L)PQL4KE9WPG,.(S>^<3"0S)T\#AE$N:8](Z0@5NBA'NAP"4
M6G=%C5**U+JEZ@EGNBPAS3E;:#JST5@Q,CH")VG3!G1CESL50XMT=;6!:9)K
M5O(J+Q`$XP45I8,*T9)UT9""3>*I:CUF1*6W(!G&DW3#N/)VW<7-8P#R_?OW
M4"=M`HJ#3=7U_!"1S_4E?__X6S6$P0(JD;3%<[]/QEB;]I>AQ3JHRRR<&]KQ
MK.B8X/"<X&7Z(GB=C8.?<'!K<1#.=1]C1CIQR/[9G$</PBCR?#[VABP-(FW=
MUVZDTGH4CC6R?ZN:T@Q?Z*V#[`)1%M8J4#,6W^KZ#L:^J'UU"(1@2C;,,X9'
MT(.RJU%,;.W;===:Y?5Z6<"L2`7S3.#Z>0,!<JP*WZ/(1'$($IJ;]5Q^`]XW
MV/U%8/4[`.PFKD(F&W0-&+]2/0S,.>&@M8FABVEK/)F`("?^G58AX&`[+!`P
M!X$DMLQ.D-$W95T^#31+T7+^N)R,@*F;5;7.F7Q7Z(Q.72OR60'G^&2?YV#:
M\B:ZZR??4ML%.)Q_1O,'E(J`9V)`GDXT>[T74A4>:8C5((;D92OZ*PL@2RE#
MGBS3#"5D*<?U/)X[VV3(7`9J4PO!ETF6(4X3CYIXFG$PM<+DP5"S_ULS5@@!
M@/HHH\2_`^;E0<$GI/3ZY<@$MSG:50,8U0AT>9-I?B(/P!;9X;Y?J7(<N/S\
M5*/U^$81I.0"1>3;MV^R*'=!OT@@$46`>]/0CQ\_QJ_5J%MK2HX(0<'(FB3*
M*HYSLR8]8M4M@+QD"#HX,C@:YG>I&C`1LFAB&'2(U0F>06*$_W9:S;VG,)Y6
M;8XT#5JS\ZC]GB*R=7>QXQ/",E&F+R)!CDWHK*[I,C.T)0JL!Y`&U770U.3:
MK2+O$.SU[VJL'L]#>DV7=<2C0EZ?KR#[UM^-3N&#63?,D2.`)H%LC`6<`XH>
M/*IW?`/>]^L+M.<UIKIKLL";W_\R(?T+].ZL^#YTV[::R523%ZY4#I[G]BK8
M"="S]^`2S%V22B0N>&@VZ43G>#`L1;(]+_5&<!MP:_(RVIJJ#F^.[_:#J[$#
MU8-[$RS8*E$DHIQ&V_0P59@4=T[9C+IM._.IW8\.<*NOO0!"S_A#@I@^5(3&
M+,&A1>83JA1`7K@6`B7(<NA^GFE_-K:R'5*/^MB[\QW+0AU`J0.)DVL('>2X
M6!-AO5&?K/)8'D8Z#=VJU1"@:J[;!ZR)LH(B*$6HA/VUFL*^CCC*0!3HTIF`
M3$?ZF`S[5X..JUK%&$;;4Z;>Z;].%4B/WUN613Z>'WG=/>;1_KJN\O/'#PL^
M=,F#5U-136N9"43(XLPWU@$^ZQAO_[Y"3MA%5_[DTA)>2C*SN<[.&AU.>X.&
ML$5#K)26JK'=UU2;EU'(O!X*,+4VU%EW?&<D^QCVALPAT$I^V?W$6.QB&#NT
MLK6:&#1D`!,N$*?8>5L*Y/%X='.*67'>:UUEW=:4!,'12!FF:W+XS;+`S,:D
MK4LC,1<'\@UXW^SN?7;W!M@-%O3X=?9U#K*S=/>_H5G.'](NE;YM]6!*82)G
MTY0@DQWUPMVLL;_T`O"8(Z&9"H17MEF613`!2;B0(A.(U"U1&TA8K*QC%]C!
MU[(LNQXEG>`]!L0@D8+R!H9T@]M,UHHWIK/6!VY@G(`<M0`[N%R670K,-=D!
MB:9QLP4U\DWZ(-*U>A.:PJ'D+'B8@5TD#8*M8<,$<2(&</AYB\3-RB"K:4[4
MIK^CGFFLG\GJM#.VWK.O5HH.G2E_/A[R\]`ZM=^U(O6ZD6U:1^T;B:@<<SL3
MB,E^RV!D8!J[O"B7TS_M7RZ0;]^_.POO\[F-(X#X\>.'U:_6)4`2;9C):)AB
MFRSOU:?IQMB=+4[*GJ[NH2`88K3WHIL/&OQE71E`.23[T(/D2JL-[$M#"UR"
M'-:(H])F07S@4EFE:G:5RAC%-"+.P"["6-EF/ZM?W"E]V8$N5+F&72D7>R5=
M8QAVR^]V;DS[;&N5S\^7>CY9@(3#E2]W]@O>,XB!=]Y4K^V]X[2LY+MI[9\-
M=O$E@,@;S"Z3A2/\$DE\\:$#-5+R'O@_4L,K44V@UBK;MLFV;K*NJTGK`Y;5
M^-(]I3)A<\O>1G7=.P4U?0``(`!)1$%4DBUT'\/?&:!^&%=WB3.IG;AY[T!M
M.0!JL6+F[7\MN&AL&RRSV7ZFU93M%JLEWNM5@*8`K06!31]R@(NE+!$473D=
MTT5^4&E4B-.MC2JE!OR+K=DMO93A_GIO8]_F:$'I8ZVS!+XN>.BEWO%?](=R
M?!Y#KFKH_M:M"BO3M+E,F%935>GBAL?S<31:V0R(81\32]ZK_3/36,UEO')`
MX26K?,UH:!HZOO[MXT.>CT=>/PW)YR1$UKH*>\.7=H=K!9\,S7*B;(_KD;FI
M/;NEWKQGGL3H&TMBEM=J@*?/5LT[X[C(6*[0YF)INLZFMM?7/*OU1P61J9AE
MU1QE&EYA2R^&=O!HM*IU&XU6V9XNXO31M1P;518#5JK!SS'=O*D6$VE5%?1#
M@([.:/>7\.-B&_WH@S"(/!_/^=YR_%FW;9P/(LZL!CDH\(3+'>?X&RR-]6/;
MSXLWP_O/AL)?9#G/O0^^8(9V_;.!"K[R9/-S__=T@#7[5>NNU3I2+5ECSU&/
M2PCO](U=VOOFX&(FNT:1F[O$[K"T+`?3&\S9M5O4Y#Z8%1PP9PRGFYH"@,6R
M5M`%S*J12-];ER"C`G*&&;M7SPQG50KC0S^8I'5;4[>GF4R=<92B]KI$KP7/
M'A=$85UBHO:,`"CO+J/'8Y&M/G:]WFU3SU+$U!'KIZJD?>ZM^`@(+0Z`8>L'
M"*:9BE7J:,*#E3+S^Y%MOMO9O&_?OQ^*!!+2XK/TM_]>2+\G`456!YO+&#`!
MW<[^57J_43^JGQ]/^?CV+6DTC+V-=`MW6S=G$I)</X[&P$I?5FZQE+)GAK:J
M5>LU]BI0M,:L3]D4Y;YUI502<(U^AK19OK;ZP,3:7#&M@]'&7G9AC"FLR3M<
M\`41X6&)'>NH59D:30^;877'6N/D/!B?6@+5J>J@4TI>70FB\V'&K9A@0S5C
M/I>'E&(#<]]F3%+6HU'--"N[\A?7ZVCV/>TPEQYGR`B@Y"RD9O9'G?Z;X?W'
MLKM7Z8&OXF'<QM"\^W93IP;\*0Q_>=M&(.O4EO6&%V]VDZZNBF[S2AN1`L-U
M8PQT>AP[,S$8:DZOW]K56G,(+Y5F:L`T6P,KY03E<:\9V_X]F"/@>)^B&*#2
M_RYE+S<H!>FA>'OFNO1=LVR%KD.$!W3M5F&8T@[2M?Q;Z$21O-P'UK0`L2T^
M;5"[6)5F/GW[]DV^?_LN*/OX`>ISU3/O6L=I[?D=EK=(MS*5F)KVK.]K?0TF
MT')4P@P/I*FD\<5E6>1?__IK?Y;`#3::*N6:.TQQ9D(@2,Q2X%(K<;DQ_?S1
MFOEX/KHJ@QVO.`9,TC>U5NL0)Q%\Z`'6LG&BI.=T,UAG18U#732&V=='F>[A
M;=[M<Q`IBZX;,K\DW8=Y/@)N7952[->TJDRM=A[0ZAN;DA8?E$\SJ(CQD"]W
MF:2J=.F/7J>C\=(]4Z<Q?W4NZ7KN(<FGF_-$.6-:Z+T[]]'.>>89&5*B2R35
MG#-.D_,#VIK@Q.I!D[5[,[SOUU?2XN2-=SDA?OB5ZSEQOO@S'F[7`"%*9O*$
M17.;VT73T>_4>22M3AD%9X!<EP6"!KTUI,5C@P`SS-S+*J#5%))RCE&J2,ON
M*D95-_UH";$.MGH#1CLDBW%HTN4,&H1JL?C48:M]OJE5%54N$#WD1:+%:EY7
MJ=FC2:(B>73T[/,)0/M2&L;9J<H!,BIIZ18/2DVZV#<VQ9Q-/^^JI6E8Z>K8
M$3`TJ\CGYTN^?R\I6]JER3`.1CJVQUMFE+*#WFW=9-VVO21IV_9[USK2S%;7
MO$P'CDEJ`>#H*^6H,]?71>?@J)AK_;R;H<'W;W^I0#//WD)D(C6G%"-H:VIY
MFJW2`0I5LZH8AC=4GRCYN!$L4945Q)WLV_=ORFJ:?>TV(Y(6>`Z=YMI+RZK3
M`;\$<AX$._G$8*(@5IXRRPY4#8*3B5)=@S/#/LTC.Z@I8%>#WYJP8'6?LWFO
MS2=T]HI!)02CQM>B].Y(V.YQ>2S=-CF?*WOS[^NUNL`G*O-P-I$3XQ^=K:.<
M6"[3JD,&DEP!_C?@_8>SN[_/DN8VNK_TECPKFYC)'"7]M?@SJ/@N#IV+;"%O
MOE&`40>U&DSLFJGU%+3%5/&`J"`<H-Q++IH>:_NE_?V+CX7CLPU1=J8TB\YV
M6,W%P1DU-F401%[E8(!=W]4^F)[Q56WEJC?:<%"9`VFD4)<#V&[KVIGIED;7
MUU9*Z8YN=($#U'CNK)J6&HO!@G>*RV`6D,MF!+#K%\QLS?LT=AUJ"`TXF.:=
MX("7`5O7;<B3#`>BTD9_<D7/XRIUHRP%$C86:J>]N+'0&!G8SWT\GO)X/*16
MD:UNPDKY^>.'L30V#5`\\=462=EJL4F"0Q-8J:MXN^K@S#;N[>/C8V=V@?/'
M2^LFE;6T[X^7X[F;\:*D&@G0QB+VZ^QJ`,><Z<$,#KO8.F3^D)5X#>%!5DI9
MEKYO=+FO106]!\0K2QDLI^JIJ-I:F]YM839?;6/@/B[*-=$%'TT!P:^_O:FM
MS'L&JAQE;I10ZJ.X=%T>8NMK]U*+M%Z$+L.@YA0<.4RU_JH+DF@7>E]#[>>6
M\I"L3U'_Q\_/E]2-N<OFB)8""8#DYZ'*8[+N;FTWW36K:W9U</?W!KQO=O=/
MOL.L6>H+;\4;E+,5E$DJ'/DGQ^>FU5N2KF(0?X=A++;>11Y9QP8,MP9ZE18+
M`X7,A(^-QXN@=`]T[6PE6;.-*0S4&7_%#+I`9==/;9L,1#<_0#C*$01[8P.5
M"@79-^7>3"56/F@0!?.Z@&`6,F%I.]M3BN#0K:3J\F7-\6(#W)I)+J5T7=;=
MXKAV8*%%XG7PT\'NE#:)$FOZR[;6\->"X;U^<F]>(W.@2GJ7(URRBG'NY1%B
M++??`Y=MJ_+\L+V<!LAZ9SOW?%GM23Z8R,.IK#R$H*R/A]3/.C1.M4P;$Q%J
MP#J&>Z,$1CE%>MI>K*8MS,WMY_9C6>3;Q[<0$$[#:T72ZYKR>@`EUA.KV=P]
MQ,GL4#&P-A`9YAX,<T5D9VJ#@]R!X4K9N_6M@U\;'[7#-PU;K5K#O6WML2PB
MRQXH;=LF/W_^3(/IAN`B(RU&/Y`<7T>J#XC#CEZ.,JHBK-'FMXW5MNU*#JQB
MY=38U$$HR12Q08DQ=+G4M;`ZM\F)IKU8"$F;+;N#72DB4J36[(39=X.M4EZ?
M6P]@!):`$)]%2HI-HD`<3)"%*=$$5];,4Z+K#7C_:]G=?S<*'C)+?P)!9X7L
M\RF>M@GU*]HWH_);UR)*M)X)XV68*DY*!%W!+7$PJD<Z&=6>]ZG/^_2<@Y%X
M:INPV2B;4<;!QB['P;3K0];>@2U28F,-<(+J81HP3/TG1NK..ZDMR[*S-+!V
MM-9/P#IOQ0:A<J@S(#RPKB:@A%<[0&,R=GYHC\_:UFT`"?TH:1FGH19Q`%ZA
M5&A=5S'%EM9K(0<R]+6?:OBUN'W)P.[,+0_Q>Z44>3R?LJYK3_%K5$UZG5);
M3C38L00(372$D7BFFN!!CH"H#'<EP.]I,/L.,I;;L$'(*THPZL8'BITZW8R@
M[&*K8V)#:P)A2I?"&O7-X[.74N3[7_]RM:\W2`4WORNK;%L-W?ZSS)_EZFTA
M$WKZ._X^A3UEW-==*TG`[O45#7KV^]Y_I$C4Q%%KP3#\<`UA^WVV#-)2'O+M
M0?GQ^:F40'*<"$_3'ZYY/"AS*#:[&3=H1[9F._U<GG*X=H>1;.HC4JE4*NC*
MRV(M>G=X4V"NJU\22:JAS1]89ADN($KF;@#81NOZ"(JKBD<9<W^OURK;IC-#
MM"8LH;I6C*/@*'L1)U+LIGS8QZCVC[CI`#2Q@N`->/_+7V>Y?=Z1N+T`AO<8
MWM.WO)&-C4L3,M-[('O3_V\$"S:%FC+1AK&9(>%X"]NVB518:T:7@YV6HC!&
MV/G8<1PJZHC>MKV.4?],*9EQNP365'][L*Q5R>R,FC;;\#,VRW5;Y6/Y&,`Q
MK8_&P8PD-7J`H%:II1RE"#LH0)F)!R.=LR9U+4BL;N,8;W53TD`#H+0ZQ2J'
MS)E2$CE3`?",M+6;GS#U!QXK*#U3D-:*GXLG]-?>[%?D]?K<E4AJ58=%*+(P
M#"BTKB?&N*(,1A$%3G;+FQBT,I>C+EM$RM(DZYC>OYBZ4@O*^XGM)0*9\YC/
MY\?>+/=:A\UKK+HUZ^)NF5@OJQ&K^2O(U^INF+';!B\E^/5%MO@LT<2=Y>:V
M"0X&?^5FS$[2"DIJF^2#@3S`0A%KWJ$5`F+&IWV/8C69!R?751Z,XUHG].X9
M&+6`'NR`MCP>@@/P(N,3U5ZB;9@+RM@;V@TKBUX<[&7K00#V1JYE642H`P+O
MGFD#_UX?+</M;@1G^B@H8^E5VO7F-GSK:J?*,FB-B*S3>_Q<,U;852$>C^<(
M=VL"G$E9UW5H>(>LBI[B='B\71^B05.@0")2'W7DPQ2JJ!(:W^@*>3>M_0/8
M75R<?A<,[;06UDM1_28FEWOUNQJT,#GM]YK`WQ0?46+ILLKMF@RR-5#M@"U<
MJV(RJS^@/+#U#"=S,742DH?"=C(P:?()O^\`V9F1`[WAKY(0\TT+FN#9MJV[
M]?22!^/2M@.OZKNC]8Y=JQ"09=FM@5%T`!'KI@U\26H*-1LT`_M&9LS%-*Q5
MI5]Y&N31U1?J`Q"3W_?DZ<Z2NWKUF=M6`HA]O?BR/$1DGZ^F;MS);?E:\N+&
MF@=PJ(BE/`WH%;'-C0TDE%;&<RA'1`O8>"(V*<"=Q<U5,&;9ES:.R_?O(OQ;
MUI7]\#U07'#;XW'/`S#1!OX*2)0&<J'ML@]0U@(!6#>ZO_[ZWALP39#I0*EM
M*LQV\Z.F]4CSD_7`;[`5NQ0C?564ZJ.K=NW8+ZO#SJ028<"'*T+KC#ZEUDT>
M7(XD$^;9`+\WT\XOW:F/4CI`U5&&;ZSMGU>4MBX4RP_GAMC*ME#DX^,IS^>'
ME1'L%U]&NZ(R)=$-H);]'&5CIG:X1Q32_228^-0@L=+LVMX<6EQMVA4X4Q!$
M8D.PKP\H0Q_">H=".8]&8QR.TA"X.G5HAGV_(,S2K"[Q`C-'.;)>@'H6OC-B
MS/DWX/WOA[^G@!>^+.$.UI7[%L)&U'X6N>-^32"O/A_X`R-&*6V7,!:8$^*6
MXR##40]I@)^CF*[ZZ2B'$+^<VW?J5/,OYP!"^8+<D_]A-N;LFU]-/(:)'?`N
MRR-T#E/EGM9UO63/BF)X7Z^7/)_/#GJGS8*2@=UJ$&,K.6FUSG6KO;&IJ/3L
MT"*U(NWW&,`H+M=K^F8+0$FR/1Z//.F132ZD\J_F.3X>CU'+7=!+8W"D3RO%
M2,G9@V2`FE*T=30D*P>79AB@@PDM/74PV$5B763`\&!Z/X&8Y?G\__[]N_SX
M\?<1:%FP3JKB+4>C6B?$&`#B9/%`:4]+@7S_]EV>SX<3RX][W5`@D:/TP\<W
MN\[VY^?/G7FC'2-HR_..Y>P[&-41^`8@USSLJD!0Q-02ZYI04S:A2G26H\PI
MK`Z>\#0*I%'K<:$!=P@5[T'D3+]/'_3,04'(P`!%EL=N[]S7H%B2@>)J2_TX
M"=)3F+9DU?1,M+EN=C2H^SI^"92HJ^YZ/SOH52A=E^'H\^#Q>!QGFFZG@QE3
MT%IQ0]O;0QEXJ(#0E$1-%FC+#E%EHDU6M(PRE>!R"$C)_-S?)0W_-)!KJJCD
MCHR!K<7)CVPY:VBFC<CNL-(QY7=!LI*S?.&OCURTRYJ^O6Y2\^SD])'0><^&
ML64J"^<[T%L)`%F-1-*,(?%?[:GQ.^/"'2!:LP6O-L$HCJXF`RG=CKG7X`W$
MUSO:@S*%U\TLI=,;==WD)1'TW@/\141JESI#@3R6QY#D*8N4K0Q;88R->UF6
MO39Z:<![-4V`L?Y8KH.T1#Y(1(.#972S@R?S5@,89RXAT087LDMXH>X5F]([
M\8_?I&Z$YN&\]+'+?-5MK\7$`#E0AX_?:PHP.L5%.VFQ*V>8YCQ3$PA[_9!K
MFT7,BIL/UF<I\OW[=_GYXX<(-]&<9*M(+%@.35O%5E);F.)H`,IB;IB[U0H?
M(B+?OGV3;Q_/::`)#YXTNR<65*R?J_SX^^^C/(59Z;\DDM(BXDI-#H:S]!(K
MU?:GJ&9H%E\DU(NB#%0&S4AV)JY**3[=/LEP<+;O#F)BM"#0[#\A0R/>A,23
M0$HUXKCP;]];4())38@NNSG85:GV:R:#I@D66_8B87<MR=JE"@PFUZ1J?8>'
MBY5,+"X8;L_GX[E(*>9$"OE4RJZH4BL[T]^UB47OYV)*P$J!\7.#DTVTMS16
M8JKT@GSI,RDK>P/>_R:8>^(>E`.[D?JX`HI.)>^25S3L!&<H>LZ6WH/O,V#&
M7V=Z>?+?G!BD*4RV;=N=!Z4T%3/F'+V.3=NP!H:2(LMC!W_ULQJPV_4'&S#D
M:,YIP_]0`%&NGD,_L^?454CQ!I81G?TI)8/Y$N5@$_;Y\7CTZVZ'<1OWC^>'
M/8!OS-;'XW$:)+1F.U8G^MX,-AJ0^U;DQX^?O8XY&YLTYC&"&%F7\AB1K6[R
MJ`]7MPSE!@4+%`@'N6+N&3RDV$#A`7K)/25<54-).0ZSLBSR>#REE$,^[[,Z
MDPW%3"6?V;1_]=\X6'M[GB'?TV82GNVS#XIZ9YQ%<E4/>WP_EH<L__J7O-9U
M=Z`[2BQV^^F]9OS'SQ][]J$%=LKZ5@<7:<"EU@Y4_??'MP_Y_NW;)?>`#,.[
M+V[;)G__&&`WP_A90UT\,QP`1/(<+IY)9JS`VIB[0^>UQ/(";05L]7N1.[A)
M=%8L!5+K""QZ&AVN=*B;1KA#"4I5'4-=YOE<>G.J`5Y^R1[O5UF/^2/B&[>,
MXUMC-*M-<7HWQP+5.IH+N=B4J0?W/ONA?TZ1)^A[WF)R.::.6Y.MO7S'?AY=
MHVY[ISW`&6RZ>7[PA!SL;N*B9!_+ZJ#)_L=QYKUAXG\?Z/T*[SNS^CUS-+I3
MMWO6I):KJ\3XD1)3J'?XZ-K3JE_#N;W2BE8IP`.Q4Y+N*R82Y.ESD1NUV"WV
M-S:KXFTQ7=I11);'XV#2,+V?S%ZX,7#;9`*=,=M6/@I3%[&<PAEO56OMFS$/
MU0D<==.?\BD?'Q^3>9AG-69@U\N(H5AM3L\,:?<@^X@]PYB4<K0<H?=UA06*
MI5(^/S]WP7ZQ-9FYYNF-*8E=7%X_IVU=99,JJ$>=-T:SW+*4_ME;K8/).4"=
M9@1/XVA7'L)MD\?S<01ZZ%W66@?8#)?7C>;>7+BMJP"0Y_-Y8P2T"Q7D\7R*
M]-]KUJ7[,_W^_;M\?KX$@+Q>GWN0!1VY:YDIAL:_GK4XYLS']V_R\?$A1+X5
M9H[$J>K2L59_?G[NR@PG<]_K`#/%2DCI5,KUW)JI%6@0)`?`HR#T[^_[#E0@
MF-!W2J(Q0]CZ432VD2[@@J*1[5Z']$3J)520R5X12VO6]35$0.!S-EYSNQ6X
M,Q_O(RL2P6Z6Z;$_TS_#6T^WVF6X>BCL=M8P-=\JXU94+7:!E`6R5:UD=_Q>
MP=R94'7'A<J#Q.C&G`"Z;ANPB@^P4X:P8_X&O/]%KZ!!^J5?O@9U%[CA-B,[
MDQ6;F>9Z,9/IM?`>^WQVW>VLWFMH`_PX/;MQ`^R:]T%B1XJOC6AS2V.TEQ$Y
M='_7;5.&E&,#OYY/DP,11;DJR9!<,W1N7@9CGB\F>KK`-"C@T14L!T-=M8;N
MT13W^GS)\^.IF,^3:LJF]S/YD18\.5$NJQ&*\2R&77,6?#+6`*M[#Q)_8&_.
MZ?)$AW[SY^=+/I[/X_KRA\6[ZSEY\,OSN3>E#(_8'F#PP.9UJ[L=\'$'WL8V
M+E=]"K/+MC4F>EF*5$*X[2P0W+AP4MZDQ^WGZU.V=6^,7"[6#^WEY!*WJEP*
M*/+Q[=O^[)9%?OSX(=NVNJ9;%6)Z,YA^H)>>'I=#"SE/'<WJ6=W%'L#N\_7:
M55GHLTG.5,-)XQC`S9V*-<H2;KPD"]\84)Q2R(!;PR+ED`![K:O\_'S)Q\?S
M1&X681\`$5B4;FDLQYA2I_Q=D'EL]$"QG7=-'[E``6$(:Y6-=:_C#]DGVO&A
MR+IM\N/U.N3$(*/BC*Y/7#&[W02(:=^I5IXP[F(<EP]CP#.NLP7C@*Y/5Y85
M:@Z#W+.&U$KT>7/[SMHO4OFR&=T&]'D2;R):IU,]6_@,H4L$0@5,(QCV\]SN
M(6_`^P]A=^]QFU\'QU\%N^<_@Y3EO?UA:F%\I;PC&\/JM".O-/[O,+S,`-V4
MQ#U)@:M?("GK:YU>%$H1M/I3=Y\T-6685X&X36O7GMT/E<"RV?/)1>FJGA.3
M071U;LQ8<$"V6F5)$!VYRY]A+?(\2A7.0Q5,65YH-[?6B-7&'1?LF68NF0-\
M4A,T=++KR,'(L1[6UVN79IL&+G>C4@Y')S?)FN+)7B(0T?3GZ]7=Q'99MA-V
M7U2MY*0VO=53[\Y5OV:72(K4C;)BDT<=P0K<,PD!`6?N4S**EU7:O90BW[Y]
ME[__YW^ZIK0V16A_F08XP6XJ\>V;+(_',$B8I=1T"E[BNM>P8%TWJ=M1!V]<
MK12KV=ZS)G;2XYT->(OF#:-;CCIXD4/:RT6!PU+9JHKT(:U[[?OC8-4Y9:?%
MJ=PP%OJ2A]'%`=9T)F`"O+1-,JH"BM7.D]U4AB):#?"D_N[U6J5N#')MT;'P
MV!7K4*!IC*]5\DE.PJHC!`E6W_TQJ/D`K4CCK=&QFV@LRZ)*0B[.[J-[LAZ!
M4O_TVD:>PXPHJY-+3"4H]CQJ\FW5[*,3V;Y`;U@#I3?@_8>`W6N0>1\>_S(S
M?`$(;WU?<B:$;A'^#N`-6K>\9HU3,YF9XMM5C;$M7QJLHC=`ZEJ+CK_%O2=+
MY1>?71;G<4AZ@UJ:S#>:^*YMGY4PG>$S@7\UQFC_`Y36\*`^MG4]:DR7RZS(
MZ13#`'+>Y6TXUAT<2-<-;H\/2B_2E\<,($!)FL_T@0Z7O3B^MJZK/#^>QKAA
M--9A6'2&W+4M.$27K$N"K%HC4RF[BU<]TN>52=0A^7W9?<K.H5WA1)6U\'X_
M`CJHVZV2ZV>5_[/^'_GV\2'/Y[,#[MH5/I`&2P9O>AV4KHE_.+8MB_SKKW_)
MCQ\_9-W6<0"[Z'@/$!=Y?CSE>:A_F-I?MW3I-+\(JX&\_V@Q`&%]K3LPJP,D
M>'*S&B2K0[J826LZKN+E_;3K8_^<P["%U>C\5J65FM"5_3VV;2#@,^&1F4XU
M#@:6VMJ[.L,@<GKD=5DMVDQ?44UE.,PTR@T;3U)D>VW[=9!#*[:?5=5<1DW8
MY](U9K,\AFX\4Z"P[_UTH#@_HS4I`8S]XOE8G$->F*8FD&B!VU:SP_AH?JW9
MWDM;TF"(AVKGG8Q,'#EWG8.QR)&1G>&;X?WG@.$[^))?>!_>IW1UL?D`/9/W
MIEP[82@PR(EDT33Z_C+8O<+?T><[,YWXHGG=5!GC7JA"6U"6W!-E!TM-#Q<)
M\<POQ!YB#8LD^G)I":EB&R@,<P;'AKAK4,"[.;;E6L'L\DP?'\MOK9W>?5_K
MSJ8BGQ>@VH@MZ60$_T4BA9AE)`;@X'1-;-LF3S[-(K;]-XCJ[\EZ"5^C<B@R
M0&L<'`$=F&#S;-8GNFFMF;)6P?(PP4P#1ED=J+_N'S_^EKIN4HX,`+=-_O[[
M;_GY\Z<\G\^N2%*/QKL0?(GOH(?[.HR(O<C.AOWUUU\[Z%UWT"MUS/5E6>3C
MXZ.K:YQEBSI#[MGV%IB:>;*#]UJKO%XO^?Q\C:"HJ17TTAN<!L!P`9SR6QB=
M\_TZ[)P$)]XG+KBC<4#$T4.[?];CHR3.?MD^Q\EVIX$797N]C@93<<HQQW!6
MK9!0K:,9M<J(`O6'$8/P^H!\?7[*Z[5:`7)*T$G7P(Q.=[8SU%UXU@HD-Q`]
MU@-4$YRS+9_5VAE917:;]&59#KMDE9%1Y1U#/YR]5*+6-OYYV6$0VVE]U$KW
MA,:07E*HGTH0JDZZ()MW3-+V^6_`^U_)[D:/[E^'Q/=_;M[\QFE]X2\@$,NV
MG%S9&<N;U07K^DM_V?.ZX_E1_M7A#!O]I`Z6NL-#Y$3Q@GO];L*JM%I8T^#%
M.>C-9.B\:YF7DR$M?]2DO(P#5[8)RY"I"H#LT&MM.IA0]K0A>#D`@:Y7QDWE
MN@QC9O.I5PD7*.M?)A1Y<K`EZY<G3)0Y`KBG/S\_/^7;Q\<H+/'UO+UD`D;%
M83P[.\+#!(3=$<^/:7L5%*E4JB3U1(Y%LR_=Q$(I7@AD?:WR>#R-3)GT0SRN
M77CFV-F`M^=5:Y6?/W_NUUQV'>,'V;66LXQ#+*E`N(=V]:4L\J]__7^[1-NA
M?5N611Y-0LXS9:VN\ZB538LWF#MJZ8"DUBK_\S__(]NZJ;W,UG!VLJSKX]**
MK<`)M5*%J]7SB\-$0P<@!F`%SVXHP*1Z,X[]:W\>SV!>P)MKDR;8Y.'0:(UD
M#"/MC'R:;CJ.4H^6E:$*MKH<H%+)@<PSC)^?KT-RT;EGTCY;)@%'8VPJZ@AX
M]4\ZDYRL)X!>>HY,1<6$WHSGJ#6NL>RG7V]E8(GK\3L27-9<F1@0RY[$UMM6
MU[]C&CY]!L:5V5'5@(0&WF-^OP'O?QW8=1-%SJPGOFI;H,0?[_1:38A'WNB*
MNUO5D)7.WBEE"*FBWJ!S%[4F/^A[52Y^,S8"L'<H4Y4(-#<I<>>(R-'M3)V_
MLD"8K./M$<L-&M/;@&-^K3`'WIX:KN8@1/.@[XT[49IH61[[9SEGI*ZB?P"2
M6FN7K#*>]T?:_OE\]HUT![,(XTF*5-8`>.\&6KJQ$,-K5)S_J7)V:OK`Z)L_
MLPQ&QB:*2[\FK.^L%&!;5]D."2$]?W3*?C@2(<EHQ*YH,@&3[F\&50XDM#&,
M+;1>'$-X?J"25AM^7NXS=[);EF),2SP;/"RK*9^?+WD\%GD^GWO01PWJDF;'
MOK:M^Y.^B,<!<F_MU][%S;'D.0.O-:^KK*]U![M=`Y5NG@WQ?IU2'J`2)ON0
M9?]CQ@KSZ_;S7!5':U95&Q[L:UF!\ALKTP2>W>UK_UZMW#]+`W^+PL:^I=WR
M8L2\K_JR!RS/CP_QS7/#06V\UG5-72))3N/=?'!````@`$E$0518:B:YSZV2
M')H,0%\4*]_5428E>-VYC3;3@-F9Z9LZO?K/86']^?/ST.%E<`5DPM`SR0X(
M8D!NR^1$,<LRK*'=N9FJ!2DBYPUX_SMAL+@BT!.PRXEM[7WZZ[*])`:WZ1OQ
MSF=BFMERF_"UM89F+!LK@(!E.1W!.^Q#!I"1^+QF(S%`+DZD6B!+V0_RF)Y&
M*-JR(&!G1%"*+&7INU353(Q`6?],F'#=($$GA]9]YY]'XT$UX&O\R@'JCT/P
M]7H%,%4.6:"FN;LLRY&"VXTALO0"66_%<-,UPK'QPM=2J[?0PNI98#("F7@`
M,F&?Z;(4<+K#^O!O2A6-_69"0S%+,RIKX[0#5#O]J<]GN$&ZX$C5<@)690&1
M->YF!TFJ@2E`B%_;MFU/ZZNQ[>,2/FO__NOUDG6MLKXV^?[77ZZDY&2Y_T)V
M*B,F\K1]M,DSS5.UREHW65\O^?S\'*E[.6I7$^"2JO=X5RY=C<5,&BI"<!WT
M1%<]U;1&9?#0Z\QQ]&B-P)GUL%T^R01JDQ\3N%6[-]G4]C"XT3;7XO:YKA'L
MB)/GQ\>^/YH]V=T[T0$O*8G:1NFI]>FYI$MW*#8SYRD(WU3(W.*:OHF+>CTH
M)T7%QA[2T]V]C:;)>-3=DI"?/W^.()-^WQ(S!Y#4]6L]XCWN8:ZA[NO<=7F-
MV"P?X*\![Y*&?P;H#?#*'CY?E"V:U95>I:%X>5+`6`A>H<C;91JN_L^D(NDU
M/L6(]Z>UF%>H>V;@X9QP=#J9$Q++B*Z;.@/[>V25FGO,[!VYGF9-E`36URH;
M+#.VJ'3O>J@\M#I$`RZ-%)S3&Y51R\@CW=A!!]HA1`/DUFUG"A[+<AR"ZN=K
M[9;+M=8=K*L:-GT0ZK3\*8O+"%['K57%P;C2B0:$$\.,[/D'+DC5SPW-T/EA
M&!G>\;5UW8[F/(Z:1'/@:/<HF0`6)&#8E5J0SN(>9OVV@Z4U5/DT*KPB1F^N
M.X"[S.MSSX))7;+@S4%\'8[EV?;/>[U>(@+Y_M>WW$7K>OO*@W"=I;"V8&*H
M[LF;D-8-[+6^#BFTFK+$LQ1&-G<L.+7]@7D6CN'[7F]ZO]::,[%!G86'\D&U
MUW&4>P"VT=4$BKHGRSE,[E]CRB;`[Q'>$.70E!Z]`?O`/)9'.AXD#)C:Y](Z
M6.T#+++MT!S)+-WHJ<T=NHJ%*BWJJ[>I2>C#6`<6JL&Z`T+X$AQ;V^KKUJ@+
M;G7-NC-P83M[#/FA2VD02!#KNFGA>.+;*5FCSDCVP;#`M4:C#N_6">`->/^?
MA;,W51DP8RB_JJP00K+\V[/]][KYZXO`6Z[M*!K(,JF0#+9JU8/).\*,YHU.
M79G58L+6)_9#1,O4J.JG60.0<Y8:Z:!1^$_=9"247)V'RBY8*0^\/O<&L^-0
MV<=RE8(B6ZT&[/J'35.S2=FV*MNZ!5_4`?`.XX)CA+=MZRRN<>^B!E[850)@
M781T>0`P$9@XF=X\66==H]F#%&(N*.`!-:RM9\#!)VM($O9D#TA6J3^VPPWJ
M*<MCL5WG/#ES;,^U.DAH&!DXD.ZOH8,)U^YNZVVIF'+U_<HHC,^3U)'+$K6T
MOJA:S.E>V0!$LXTZJ++7ZU.>ST>O#4\#5@5DX+))81]T++61*H"D"A1&#0(C
M(["NJ_S\^7/86T_2Y=YZ?/P;DZ]/YM<9\"5]=4#(K)GSQ=3ZNE$Z4N*LSJ2@
M$14B??\Q&8G#I:W5).MK*<>>U?;#/:-DG>FF=`5=]4"OR\^L)F(V8%LW&V33
M9HJ@2[_HR\7$-+GU8$TS\3IP[F4!'$8:ZA08M>8:6-M@!^J\&;KJF.91_'YP
M#)'14Q!/&.EU3'%!G[8_1]@S`>;$@6K0[:`WG.Q1V>0M2_8/XGE_YV4$X'D%
ML),&?-[YC)/K/0'9%U'!U!W(?!;R#V)R#1J,\M2?3I,:#CBD*1T/PADV)QN^
MN/2;6&<Z)"P_E2D/W#8X,+]VS*JA4:UR"X8`(3*GM_OT:2E5GW4PUM#UST95
MAVJ#@X-GHAIQT$L-&ALRKL%I38<TNA/&H3CF^?]G[UW7'#F27$$S9V9)>][_
M4?=LJS(9COT1X>Z`F3G)+*F[I9FL^7I4ER09C(L[#`8#7*)(^7ND^&-@V]U8
M@(0"A&$Y@"0"X^@F[*I7']Z:P&$_/[K=CML9O#!8WX2M?7.7KX+N.,[I_XX%
M).<@UO6JXWZ(Y=J8Y$<Y9,9R"U#TJ*?V4=5I?U3?3YVZ`#I(QT'_W>6^&1/J
M'Q\?"GA%[K$8-'&M\,)R;>B00[(@)]$E/75X1D:Q_O'Q<4H72([4R4XP,FR@
MRD:+V(*$*"*#<8[GK]>G)+G"423=NVU>D^E,`7HV83.U<`#>])[7"SI@1S^6
M-K:OI+;;Y2AP>WLCZ\!S$.XL#GI(FN31/@LB4G(A(->KVW4_"%N_J4CO]_NR
M@YO=Q4ZW=^Z%=G1YUL>Z%+V[4<D:."*8!\72>E+=:YY2,+WTI%R-13>LR'M;
MX4Q>[67\![@PTMD,SS52?JCHJ@#*L-Q6\L`(H$&`^!OP_@]D=Q^BWZ]$WX:'
M9*=FQ8:E^#5P_;7WP"_^6\46@P!8W=&K0CI"LI)'$::3HB'[W0JX>GI>PQ!#
MPEE>\<L)<)9!M]+2\LLC,5]34"R5MHQ"L8`LQT"8\%;;+,J0#]_7:>`)CDU!
M805MM2:EYR`)+;@>-:Y8K3H>TICMQ'.'2DP$[#XGN!''(<G29ZOA#1/J>9.[
M8!DR0(WGUG`"T9$V-N)U428I5!OB.=`UV$3>>,_H9ION`P>!K>&%:J0W=FB9
M)U957MV$"QB^,M@Z!\QXTAYA<!,[ACP/Q]WO=_O\_#P'*QLGPJ$(#>GES*I%
M]KQ8')5`.)/S^G%<4@6?]^H8L$O:^:O#P4"_GO/SDL&-@$C!E6OU'0"#I7Z`
M9>VSX]*LFG@R^S68"K*)ZM;M?ES.%KY:\./^6QTZZ$3^'7:X&SX^K+6;O;W=
MIK^RDV]Q);>;C&CH0%!-,K_O^_O;Q1*WH,D/&N(KY9';[J-+TBEP8JX!1)_S
M(%9'*$=YL#2`0B%*:=\"A2553D/GQQ?/YC4L!QOVO4B`>JQIQW'8'S__"/[B
M879&(IO#L*:'P5Q?P15F6;_/8+[;8W\DCQTT7_,DWX#W?].O7P6[?R+![2M!
MO_+\OA#1^ZN@'Z%RW8)VRU1P81*DWQ?[J;I4J<:]_A6=!F]0(LKD1=+C#OL`
MO":,*)9+NF&"R"ZD`41AJKT^L?#@STGLM'4>I,$T^$^)2?$+>=VVF[JY*R1A
M,'G>VMI\Z3LM71HNIXB>?#SG1'377'>.)>6!&.A:'SF6O"&/-FV(RT[QJ)/%
M6WK8:.+V^7F?(&D-OOG\_7"O<,<,8_KY\7,&2N1-_=RH[_=[N&==G#9FM/2F
M'6H4'B+WBG/\KB765L_ANLYO;V^3U9N'=;7)+:0)1M`36=.?/W^:MV;-V@G`
M.&UO,%O]L'YTZ_V8K[VU9K>W-WN[O>W#9]#G9Y\69J=T9TB&=)*_A0'%T#;#
M`MX5@,VLX:;&\:QMY0%%;]22=[<J/$:(;:,NCNFSB2*LO?=N__KC7RN@I0#F
MLRN"<[",-;KC>GQ\')?+1YOG)*#U"7!+_V7..@',V\U^^^W'>0]=WT?&15EF
M98N)EGD1S]*AX9;C/O2]%.0!#HI9UGT0EI7`IRNC&?>1CK@77[_"8*"Y/GA#
M>RS2@F!%>:"OZ.'LWK=`J;L6_$QGJ*T"=5[4+8^)@'I>J!Y>L[3^?$L:_J'L
M[AZYON1T\!<BYD?@,#;7M^[`7[(L^Q-$-1X=[^._5ZW](RNF>@1J,9L91'H`
MWZ^%>2A[^D",L4?S!=*>WJM;C?<#3X[-IFN)\8KV6VMCK`H&MM5*C3TO_HX6
M<0"S)3P.[TQ@:Q=K!GM[NYF97]KA^[38F2TX&8S35*@U+=VW;B31-0'!GW-:
M'`GSXU'4N1_8]+@VV&2P[_<CQ5'S[7.[72RPFWU\?)R%03$:CWZU+SD%#Y""
M)'9GG*V#7,WE+6RBV;*,"Z>-\3Q]IQ\_?M@??_PAUSBWV@.;>0U\LA[W?L#^
M[__[?Z^6^66!UYH=]_LYO-E'LIZ"Q<,.\_O=;K>;_?[[[P1,%I`]CL,^/Q=[
MOB448`;O<W`I/6,<2.$VI37+#G!)$J;G=>'8L?3^W6)"8WQ^/54B?*NEJ+@'
M6X;7%+];"JN13M!DAI6]9#TX#';8(8![V20B2\,O$:I,_*-?@2'-;F^W-!LQ
M)"FKX!RGX$AL^6[:8\FD='Y!XJ"OOOX8!ASA%\OIQ.1A&1T'I]CSJHN828&E
MK&ZMV?_S^^^7W.3Z;LW7,^_K/-_:;9V7YBMJ>NYI3FNZ29+F_.Y$V,QKTNHM
MS)\,8:SD0:2M:0XB?@/>?RSL_:M)W#_[L0^1J(XR[=_S*ZSNGP.[3PS+JI2T
M^=![+N^WC@N5<7OU;U8/Z>#Q:8XK@K\0@9R+"CQG]F7B)6R^I<:L!KT:(.67
MC5(-QJ)',3PFR!$80F9>^$0!G`P$.XYS.GR$-'Q\'(0E&.ES)/"2%2Q`L:;"
M>=D&,K@0F0)"@6,AT8R&PYQHSUJ/7EA.3;;=4V@76\@!9OW^.:WI.C.DG'0W
MVLU%$`AS1S#V?[;0X]]5D(O%.SU/S6J*%%N*TOVTLKL?=[M?C@LIF8W^&Z>W
M0$X*<ZWJW>YP\?4]?Z2)1G@RK'9:AO7CL-[[!`YV_?W/CY]VOY-+215/%GZU
MYL+Z.[-\S,0::,A'YP76O%/H@'@B>O-P)93U%$NY9F(Q)N_GSP,SN?A(.FE;
MDJEJ;?%J,,21BM^EX48:_/<)KL25>(A')GLO7M&AL@,Y_G36I@?YGSQW]&=U
M#JTTPO0\.,T=\#R)Y_O2=PT!WLN<YE#\U$/_^/'#K*VA5!BLH:U]CPK5^_%I
M-AQA'(G5]UFDJZ6FYNGIM:RV`J\,^X)HF#L/HD\/%F??@/=_,4;&7_`FSQ:U
M?QOCO`.%OO\,;%G0/.2Q8RV+ONHO?)$'1NTOO.46JN-Y1'36^B%M-AHRP2\T
M%H"I!8#[P^M3L<2(AK,]1V665!$0^*%SP76$&8DA"T!F/^4K;)DV`M,7(.L(
M[!DY&@C@=MF'4ZA$O+<\%%;&$@EJ?U1^JB@J)00FB6>HJE^]]]-\\\']UMD=
MH+CND=GF$K`V1EQMVP%LA@8SW7?/'N[K77_[\9M]?GR*/*`#E6A>?L^%W8GM
M^AK`2V4JB('O<N\T/]FU^_W3_N__=]AOO_UFK37[XU]_V-&/.5AIA?[3`WA+
M+"=/QQ>:\.86RXX@]:&.D@>)0HH>=NHJ#*#M!=N&.6`45]3H!^VL68U2EA2W
M&T8L6[[NG$I6)S<Z<XWSG*[$;6AA,1X[+,#Z\^<?%`>]0E%&8(;Y&2/<>S^[
M1`UE;<</1<5K3`Y%PG94V^MPPKKKI+M%?ULW"5L<[\GQN_+HNKV_OYVQVV[V
M\?DQNSFGM*/9V^TVOR\ZKD"?N_DMC'!S:%+H/#E;JADHWL4(!&>ZPXW!L^5B
M+7:/G/7868+S#7C_29CU92NRY-SS"A'[$%8]A7B;X+&'".Q%"4,)#'<2`NR!
M(2H$'-)?'N)-X,$Y?T6/\$6PF]K<10D<$J!*GKG<[V$QGUUUN-BMV>%8]M[#
M"&<]#OXD)58(Q9#I<FBTJ;P[@WTR=S=Q1;C\,`6PFC!B*#R*=<A,O3!TL^9)
M?GU>Q]<>7I'3V<"RW9>3?EF_=F6UY8$]0GD1.NT73MMD=%W9^76B`KFDC>W$
MU#@E6,61N@Q<6[C-V_4_+YC)N'F.`)!5J,5["!FAK7\'+)HC69!K$+RBH:%Q
M[R"9[(^.Q7!/^->__D5@TF<GH,+Q&MWA-'0#8:RB-7>I=<:&!Z#OL)BU*MQF
M!:6L(22(ES/?/UBDKP(Z#]?;*?TS&%A,UM6TL^%6Q6U[*"X76RK68E?7*T8<
M.RSY+7-0PY##C)`<`';S9I]8'L.]GS:`IR<Y[/.S$WCU!/2$_099=WF(BZ="
MSV/._/AM0Q#.XOJ>O+8HJ!P_VV$V@B<'8WR[^25_6FX@?E510+?[T>UV:];1
M[?[Y.9>\1I-^@&^"\LZ4RED0FM6^U+L_SY1+%'LL:?^+HGA=X[4F?`/>_T&_
MTA#4`V;W2TZRV'_6GV%L@><2C,>LI6X3D4&HD\YH@A<U=_2HL"@9UCF,55A=
MX0N:XY(9J$!\]+J,H,^2!A=I6"YHB5]@AE%XRG*:363V4HT";.\;#G6-4\EF
MA1Y/M'MU30*[+)9\>5("L3!`>?X78'9QP`#9=`E:,T_A$<OKTBQKMX='\@)$
MT>1-0*EKI*=H%_$HT,5$8@#6U1GI^V@0*J99.1=&B+6ET[-'K)OQ$(S&\8)M
MYBY]XA@X4HNEZHY:0S7J^WKY27<(^P,4P04[SG@;Z889HWK*%$+!8@RPM*T,
M6W9M;OT*5B#NZNC3.61$!F.Z7(1S5P23('232Z0+T_8N])D*%85(A91P!H6U
M%.U^5+[7*/MIZTU7)'DPAR"7`#J7H66]0@6:DM-QX?*PJ+@5UFHNC.[<11S6
M[1#K@7,9N$^D#TGU4QE3G#^=3L%4V.D7]QR[F+:5/'@VOG,UF#<`</-`7+2S
M(\&L/S__[2HJ/SY_SA/;HG1K.$O,H=4H6<$L!%9'(UYLMJL+*&;*:5A[3JF7
M"-T"C\4?YBG]!KS_DQC@1RCX5]\%O_;!S]2DKX#=KWP@'BE\H2S:EBP6<+)S
M*BT^(0"^N2`!?^Y22!O5@I;,M^SU5\[MG(PM4YYVR(#3;+B5RC&RC[%$_$=M
M3UD!D$C_.G==56@AQI[.-EH$.\34TJ*8+WCEF:K%1ID9#UA_T.DH92/Q3QN6
M+J:C89^]NKG!I1Q8]PD/8L'%UH<9TYA7'UGY]'T@L5@GF)O!`J"0""]]81-\
MBB/<RYG?/CX^%RM'&RV#NYZ>R6!XS]_ITK&H#E@K34@A0@(3]Q3[ZB/M`A01
M/<!NB,".#@U5]\$0`8T+&*@&3^=0GVO!Z'@P;Q#\:L^0"%HC!N!(PY,(Y74^
M[]-1IELR8`9U#A"+.!397%`?<T]9W3S(AQ3O/9]*TLS7]R-$MS_L^')W!.)2
M8(8RPL*@-EX>6`"$]8"+&_<GSWRAU:Y:=XCGBX8N/:QB*:Z8XHX1]B!>FY<M
MY#ZN-7;%9#LN=+T[L,O?C;?-;\#[3P&S>)93]E=@5Y1,V9<^\Y47^>OO40,W
M?P%2A\][.-#E@46L_]7#@@W#8ZSA9IM`K=>O!.+PU@/P^`J;#,HKWUT'1'/O
M+'WT0$(SPXS``.^_>Y`[%$-['0A7W*DENAIW#%!S.V,LN,Q>9':I5(W$\"C>
MY4VGG!$V/.S8;&=OTO"6S/+0R>W]Q4!M89JR9C"VOBMJ;6Y:/4\\Z^3\F!ZO
M@S,ZI3B=;]F"11L/EO4O`/@BHOGR!I6!,!OQU0N412D'HLV6:^(7I\H-)PX&
MYM*UH"$XZSVXJ%S`B!F\>4UZ^<QC4]\RZXL$5(,':8298U@1I%TEQMY+%EQ1
M$W7V%YX4<U177RYX>;R)@82GNA[!?%9**W?MMEC0R\LZ?+;4RVP%5A%A%1,(
M\JE`^D_/X;-@[.K]''VUG#GKT*"':E1!UHSC^4I=W%"(ZS7S//T09RW2P*#K
M!24:8P)5X)0Y=&*G*>P$_MPYRJUP9&(;O9)$4-EA]L2F5]*IK"B%;\#[/_E7
MT2;Z9;"Z>SV^`(;]K_A2J,'P$UT$GIZF1Q/A]0A58NKP"\5!>BHC4[RW<`O4
MU!:(2P5-"^*PA?&B9M?7*8QF6Y_(;.))D:9M8"_,[:WPK1U@,FP_*`(G=I_O
ME;7-`).Y4R`2F4+"P(K>;8IFV,CB_N(>*AF+8'#O)E(.L+VD\2==H7/@!N0C
M_=G#.J?S?>O0<9*Z2"WJJB!*ME</*N^U=S>A@-KM9KA?(2!#+VUM6CG!J/"Q
M0M//Q5>P6NL=I\=K`,;NS2*O-_2G67O:TG62)PJV'0"-$=?+\HV#"8)-8K#H
M$#V\'%]5F`KGF8!)?B[RM>>`C=I-1)]%<"3N.#/8IWLL';>M!#QV.B#D)/*=
M6.PP6QTZ/N`!55`$LK<KSCHS.(MA;FN%@"<M->):,0;.PO5@>8:.=\#B#`7H
M?`L148#=49123[+8X];Q=3-K%$D\<M::+X<;=II17WT-E!&O^!&X\<`3/[*Z
MEFX[W^YW1IV";\#[3V=^[;7V-9ZRIJ\!M-?!\@.OX%<'U1Z(A/'BQ[VFR(C,
M=O5F:V!*V_:^P?*HS1S\3Q8!&_LR'?"R(N^QCC?W'$,E&S<>)`1CL[AD)HK.
MD>SK87B,\H4E.MC8:-YI*APE>$K`^V*/8LSS\H2-7\K3D%T,6AA:3085(_'+
MRI0Y'8QQ`AH#E*E#A8*;&3(A,;D$VP2\6,U87MO/9,WA];,#JQ/2:'B+"Y[=
M32Q^HYX;V^L[^,4DK39WA7N'5MR]3_#(U[@?70:^5EB&B=;9PQ.-SC['F+':
M*Y7/)GA_N*CL%K8=LSD+'S=T*\O.>>\6+"V#I,B<ZTS#\D_6NFWH5K'`^]#D
MBT8`4\9P#EZ:_'PZ)C>U$KR>IXTK7"C'"@]N\G/F&M&)?9<.#%T/#;$-SSV=
MMW@L'D8N(:EH)X./36[]TJKV8I_QPK=:F:DX@"R:\/A]9S&A:[[$9L?[P_7\
MI.VH6+_,<CRSL3N#A9$3%)'E6UNZ?3T-"B3Q\E&#6)"!R(.I\[95T'\#WG\"
MJ'W1G>'+[&Q59;\PL(4'0!,[@TGVS?LB0'_JFVM6SAZYO:IE?2QIB,RHZ,@J
MCU24)Z9$N5&S5`'QG<2B\C!&RLLTM12;Y*BGM#75:]$BXLN#=N<$@@T+.;]C
MR2BY-/E2JEG0(;J$4YCXW"/$(/'BC(G.R$.)B=4@Q]!6H\E$]?Q[UK'R9END
M597W:&A%`[R9Z747;TE01.L#9I63IF(W,^FVNVX.PD)!V4(4(1.[J-H:L&8`
M/5T/+LE`WO#XN61WBO5^([4LRDB8Q<KV;^,8AOR"(G_C`%+Q"$/2`K,.M[HV
MGD!_&.$/SW9D[%9!%965G@$&V:#E(=4XQ,;W!D0JLLX]>5$'52@G#TZP-=C5
MQA[7=%_*[Z'W96D!Z27ED0HROD92-%=2'XY(UN,<+B#\?='QN-,"E92L?Z=/
M1.',(,]7C,H-FBLL.11O-YR85\F:4M<N`,F8T/<4D[AO]JHUC`&K-;N1>7W6
M^N3/TX:H!EPY.7@L*=(J1+X![_\R)OC/P.'R)U`SI=MXW:\<M)NVC'9'B/I[
MXN4/J=FLN&/#BTC&XL?Q8/+?XSR(9X5PW:;732[5WHYMZSR3U:ZFM;Q@C1])
M0W*V=%P/B/7M,%5QP1:@#+'2M,G#`U"0\^WE1A:'SL8FL1A/W51!B'?OP&$B
MRD4\G[WG^P\Y/`/8G3ME0^-!],X61T^D#.1*L;X?V;+US`)ECRXKVO>>-Q]?
MX1SN_E+AKJX)/!Q91];B2<SV.47^*=0?N@7I"6L?F75:;/%@=9^MB"H9A-PC
MU>#=!'ZLTQ0+LG7>.VK.'#+L9H]!`E80Q=36<CM^6E0AI7&Y*Y/HA1^P4\'/
M@1WJM0OY7EC6"0N@N1:5"''CXY[H..4D5DA0TSVWZ0RX[0NV:64(2G0<@!Q!
MN#1=16QC!:@2A5(>5WB41PD;.]*HG[5V+7A.A,D.O@?3,ZX7X"FY5CVW>5`L
M<NFCJP;Q$Q8B1!AK=GZ`D"(RF%9<YM*"%-&Z[_+Z_H:"?T-D^B*S:WF/VK[7
MZTQG?#+=MFW[9\QN,6;N7SD/OR`V]E_X:8T2W[R#^Q>NGR>6@=<%396R!<!L
M)PN`S,@N%D1O`%3G#KK0Q*&>W7F;K&.<+*;/3+&^O,A>G[4^DX6K:Y./;2JV
M[4H&4H@_2\"Y:C=#GQ"$<QU9[\)Y5OZ('@USKFMS&;6SCVUD/)$D+@AOKLRN
M>@";G-?M9E2B,@58/)0C]E+%^>7;RS>MCT?>Q;M?YP">RC&F;1KVSUX\!YVN
M?S\.ZR$`Q-U3),?P'A6/7K>L_XS?$<5EZ^?_&-!.!A`+>(RHZGD?F++#%B*/
M)53!\B!96164#AGZ3^,^RD!`PW?`YPE=CXO$YS-ACJX#B#F,+A_S'@T6<;B2
MRA"\C5=SH:WS%\]3N`_'4L`='W2$M47UL_.X)[SD]D)@DIDUM'U!QM*CO6N@
MDSW:%2#"/LR6M=#<H2DMT$/Q-,$[=%V8#BG`]IF-?U\5<G/-*XB0$M'3^ZZ`
M$G[&$%9_K/MRDX":!M(]]F;6J[X9WK_;+[>G%==+G.PO@,68..3N,U82>`:9
MB[GTKR:O19R"7_A"12=,8$QJE;K=;LU89]0I:2:U^N+#7HB@A&QE3=W\O-LT
M+1\9Z-4F!F+7$KDY^"$R&M]/S44C_D1%;IA[;$89=#DI6]M\#S$0;J?N;P"#
MR.;,A3!$I,[B(=P3@$?X&6Y!%XXDVSV%+^UJQX/4EL#CCD4<ZBD@%$]:FWM@
MM7(K;\>>HIAN-F&7O"Y$72?9)RM/KA4Q$(.9*R\87P_A#J\^K*KI5"]0!->*
M]!R,X^M0_78$-F.Z'.Q[BM7)V*PR"$EP,:ME:3U=.A:1IZQ.AWBV7I*2E1""
M8OV@=GI8Q'+(AVE2G+NP:-7B[)+DQTQ>2Z"U!G9J]Q"CMJ=]F:WAI25G\5(*
M5/?U8F#.I<3>!&*F)IS*:-?`,C/KUP]V0YZ/",_`EGU$2)R+FM0+3$=!W+BO
M&DM8C.-XJ=CHET\N>R?/=6GY\IY,/*\P6*E_D:"BD+T:'\1H]T&2%^$@8;@L
MSB=8:B+NF.2,=%<XGF\A@DO'`-\,[]^:Z,6?]%+X!4<$=R^+1348?X0_'T3,
M?N$8_2L8/F$Q7R;DF]?%-*^Q(8S?M]8N"QLW;VW^N=UN\W_;31V5MG4-;4PM
M7-Q([7'\;/P03I;ZL@5'G')E9BNU[;&`9$P>&*\MP,YXW]MUKE8$ZCJW\A6A
MP!PQ56,:VT.J_O5[Z,^65#>8PR'PF[4*K$&45R.2LE@@*X!(9@?7$#^7=<L`
M`"``241!5`LS*E=80LF2[M<#9<Q>:84@)(IEMKXC%P&@]"9AZZU*DT(=[B!@
MP8W-_97]AMV/^SE\1@-!SI"2Q;P$D)A='T4@"Y7:-63H-.#E".WZ<$\*DQ:;
M!\$HNC4OO)I3F@"U>Z`28?'YS?KA==ZN4]"RHP6*IECVWX6$H%BA)_;B/'`7
M(!9@".D]"E"0KO<\AOC,Q!5S6S1MY%)Q/9'?CR%3DEH`:_!4'&Y.E0OZ>2^U
MZYHU6[9VM12@7J[S,*DGFMDEO&5]QRIBG7I5TTNY48*=;VF)MKT_*H:7F7+>
MMX2)1=4E*VHJQ*3-0G_MNI>L$#T06X_4@8IS+@^R8\SL>VCM[TOT/M5!/@"`
M4;C_5>P,9O86X_-H6&T?R/`K]/0C!OGQ^Z4`+*O:L5Z^=S_ZM=FBQ-)X1#RG
MB%`+`WKKU2>S>V[LQ>HC;-K0S2(E7*VD(Q=7A3AA3`SNQCW@X?D5_S%//[FS
MQAJ!D*U=\9M#-]B/2;OP9&^,U>3B0<YA,))EAF7YX"(SA.Q>$*W"'A2;>-()
M$>EK"!O04^N2_%-QY'6]LP&Z$@Q1LT0"$C96&M4&/8(3=NQM[SUYT3Y82@*[
M&!>3=;?>/^_VX_W'U,:VZ0*004V,"V[N=J3R!D5#PVW&@E3G<^-.B,NW-OHA
MB]55I!:-M9CJ5#'D,;9AS?<W:.7,D?>-.F'.RWMI7N>VNEPRQ(@\#"M>P$E?
MS!()U(4$Q?_R@BTI7+/(R<^36'*YCO!%284,R-'SJ&'>6*X2Q'SVL&1V'DQT
MD@BQ&PF>$$GQ4=3<]KQ%R;/>9]0UNSB`AHR7-CJ'>T=6%-66*`T-<L:13&C?
M/%]L0V?"QB^I2-TUC+,/^BCFR>V\XFD\,5P]B+^'UOZG,;P)['JR9C$K.@\E
MPQ@?_L+?*N&^)_J%KT2-E7'&_G@@K*CHXKFH7W$R7"<PV_O'PFK'K_/S"C"H
M/#E=VV['P2QE;M,R`$2HEI/4^OJ_+LV;<$VQ&TC33<`\MX2Y?94]B_?WK#O%
M^E[+X-G)@TH%Y%;S%$%<1A7O7`'&9E9Y^5(;._FP2]6T&U[<!#2$+^%B@*0;
M)B1-2L06&F>\:6!H`9,?*S<K!]]0>4$%[5"'R4!2/&]&MJ.JVS2+$S1])C?U
MX/6,U=INZR#?6K.W]W>N'LZ`%.=M-%A.7:"LM6;63C[.^AKJ<:RV,.*BEUH=
M'K9XNV00ZEFJZH9A7];.X`QAH7E84(=P*B^LY15<R8^@@Z;I>YAZV`9KJ)$^
M-W[)]_`Z30S`C*&.7MG@A"^17[&4`U('@%$4](EF7VAC]Q@"+_-X.\H@H'G-
M23N[AB&;E=%CU_W1H;I8Z>!<?]41V`UG\.VACJ:C:SF&NMRV7?V'5^"$)L6M
M0D+E0'.(%SE$PH,C#\3:AF<<(%:%O6.&DW2K)GET/^ZFY(+'U;LHS)F1[J8R
M!E1[G9?L(#DR(!$S$_A^:WC_OF#W%88WW3E"HOC39F>TO]DQ-$4$^_,P!7OL
MZ/`4XY;2G:+*>]&A`85Q+Z[%O^%D=\M*LFH/;O[[2OX;F#T)1N6Y7>>%AC2R
M8Y?..IGE:Q#%T`/7BE*2+SP8&F+C<P.GX7@1T[D6/NZ"N2,)#19X67_?JW*^
M,(;?=3589UE>2P^DLF>KMT?/@FWPL`PC;6SK=@75]CX//],ML_B`#@M5#+Q7
M%GJ:^62H>I+8+!HIO@&R<5?1K<)X7<?<6K/?_\__65*$>E<+05X\.6]VN]VL
M]WX./_'F9\'A%<$>RB%=V>CI&EOYPN)[\6RH\+B(IPU:U>B[%Z?>Q5MZ1L9<
M$A1-3$#L?KBN=6)O-MZ_=QH*TX$V3X$48=(T!+"D>\H7Z%U[6N5,4DV`>>GJ
MB/@L3EVP^N2>%G>>UMK(Z#LR&1`]O'/B7=`YSW-J$C@Q`7K</\=<3(BEWCV5
MEI2^ZWK/SD!PIHEN,<M6F1'O&BB>Y\W7`LQR))BE;IJ"_.AX8R'%T1^N;F+A
M[)!U8'4=:DO#Z#N]H?;.POH;7O[]?GT)[&[1HCW@XAXURE[[0=_6:O9K,@I[
MEIQ6)XY]K9"HC_=^'/64_R.<7E2?('-%E+TBDT59%XBZY2L1P+%-Q5(%&L:*
MEEG^P@7VQ#1L*X4"[+#?+<L+,"4B$UR`XC>K01@9UN5L>^SDS(E]^M+]X);`
MD;R/:TI4^HP'FW)Y#MTW1="F$;&#?IZ9<=\PX/X4;(<MGM!$L&5=?S<`3_+\
MW+-9V-Q3Z-T^/S[L_?W=O+5P+VRB(L-QW6XW^_GSYSR'IUQH%R"SO[VC$\!.
MLL,2A#[CG$=$<EB#?>/_RBX<S4NR8\I+L"`K5VTRW`5_P0^[*EJR_RNBY(B`
MLYL3@\\^Q)L[JFN7C,\]T$\-*@_A$9,;Y4?3S,U-T@*=$27)4YBI3A9K%W-I
ME)B'H@G`T>>(K:,1U1XFXQ3$Q_3+T/%3JE>*NOV]BW"]1AM?N//,E`XP#B_O
M9Z/$N8X%BE<,.I91!]:<I;+VL1M(5*MIPJ1*6)P4=)#.144RY$[6L$.S-)@X
M?O<->/^F#.\S:/(GE`$;IA=/Z&-L@&96MGX)=.S?QIYA7]\RN='V2)=;S4-'
M>49?"<;PN#HR\^K[\WM:DKD=O1<X7E/!A#VC65O.O>>6K3)53M/7F[N&&5/I
MEOIB(>B_3KHUA"EO"]Z4O<.`@P:T,K!(+@[2=KN^<9I:?U3#A[,)R]/(S.H"
MMB.U'^G'4G2E[=X$#WIQ]3^YOU!GX$G!2G(F_M*^C0)>WT99S96FI+9IEHL5
MRR$CYS1Y7_(69I\N?7HWLY\_?]K]..RW'[_9V]MM&[&;.DUC&.7V9LV;=>NF
M^0^J>8VZUD>.$GAXOK*.=EAX189Y.AW$Z^1+5<P^?4N??8'(;D&S3L]=:U*<
MY5`(+;[YJ[3F,I#T*O4A=GFIQ7&M.TW97(_!)7Z>%W<*8N`C3]($DIP4*<SB
M]&'[ZZO.)BM8!T%GVM&M6;MD6%`I45QWN#N$$'EL[$%,K'GRL1V7'\4:=15Q
MT)F:/@-;R+U<EIOLA%,%T\@*YL%UQ[2@@)EY5\E-3'*<<=R9W-U>+T]+FZ]B
M$1DKN"^`?.Y/2$(EI+8-OET:_EE@]W5$^ZP]*VP&,MA#Q;8^/31_"6%OWW_[
M]?"%V&":@">'`50,2[28PI-S#-OZ`X_!F6K*6;5/IW/![79;4^/$+;B=+=ZW
MVYNEV"`&"J'5RI/_G!K7&ODH^X8MW##6QBUFZ#VC8+?9[>TF`S.G]5B?`WJ!
M%$D,VOCO^X\?]O;V+OJO\C[QO;1$OIW73M5*''E('7+-<*]DXYZYFBWH+89V
M,M#RYV3PM`S2:>:2-RJ>Z34LN/Y/O:B]!";5IZ3[SQY;9X_[0=8`LMGJ@-WO
M=_O7O_YE/S\^5FI9#,-XX&GZ_N-'Z*Q`B]XPC;X#N^R%^V@YCFX3`]1'+VK(
M<>Q2N>@UD?%KMJ;8VP4D9@'!3XD7S'TUA?<<R"^@YB03L-(/M5_7;^0TX`)G
M4X5TY7N,P3]F=_5ZZ/M7Q6JP`DY:?4Y"8X_723`VG\?(*XP,_L+,K5DO&J<>
M;TFO.WXHUBE.ZISV;>Z:Y&;5T-LJ+IR84U@SH%DT-%SWY7[=9XD.@W)Q6Z'J
M=C41@S\ZS`S-S-J6!$!B9D,JGUAK!L:6I6S!_YV]\V/'6:T.USG_9GC_9\+F
MK^D3-B`R!0>6Q;]GNN6K@+U@K5#1N2_@;FU)^Q:W\@,+3_"ZI@\+7;%3;.'4
M$?;^<F62&$(WN[V]6;M:I?W!9BNM2CPJ:HB115S`O;QM/&:Z;A9--[=V.Q>3
M-<&NG+E[MKI:^WF8MF]-](SR3H%,<I<NXDMR`*ON@>$_6\5YFK(U#]/K'CP#
M,65+[\_H.>F3Q9/,#O.R*%G7@KY1\&G=/?[GL^(/"V[GB7HH\$[1I(%)CE(1
M/J86;+A.UJK;Q\\/,S/[\>/'.8BV._?!8/OM[2;2G+5?%^XDU8!E8L$:M7*S
M?C%&%H.UZ$6\Z^C3L`V66Y,A1`]LO`[]C.-2'FPQ89>WJT_"=SE26/!JE1&C
M8OAM:(9]?/]NQ@X`Y&G-6D]F)/F:G2.(;6I#![,_!Y'[:L>[C30S70,J/6X+
M]Y+X"8/6,3Z_U'7H_+[!=:")WEE9QTZLI_R9UM6I/>6+6XB0;\VG#1H<9*_)
MOKNA@WI=%R=MM.A>83(0FQHE[C*[X`@A%V'@3=<GX[N9ACQSG"^?<]'GF@[E
M>?/M?$"\1YUD9JR-YUAA'JYV7Z7&-^#]Q[&[>)X\'77CE8[4;.:B[R!P9;^%
M';CVU\'H]@/=]G(%/+?UQ1.L+S&>TY3=4B+#*WKF>!QM>OCZY<"@K6)6*74:
M%(G?X-9NI_W1T1?+!6U.>8A@%(K:-PR<)'DM<YIN736^`Z",10*F4:RQQAD;
M0#^VY5*ZL&,!+%C(SX_/S&B:BRZ\O*6#7=NS9\DC961Y$(ZGQV>Z,%FTN7%K
M]9(0M"8%CPQA>6S<5L"X"7"2X)*`0%EO79MN%.EL'MJ%PHA$4$1<EE?G)H!6
M86L48#H!XLCX3Q!Q%5#=3M#[]O9F;[=&4]:9^1[O,32E;^]O]L'W4`"UR8ZK
M6ILX94N&W#866Y=?*ZS/P2^_G!O6L[B*IZ&!%>WVJC[,O)FWH(@$7<\9'XSE
M-A"`P0I[</T,T^<V+K+LA-,::83=$G`^P>4IJ6B^V-)&PVGK+#>^$2PJSQAH
MKV'`!;`Y)E?LT0A,J3?T^%A?`]Q\_=IY`&U#=+B3)1<OL9X+<%`DL\<!8KE9
M78"K`M]37NL(WMJ>-[0%A,<U***LZ3K$8ES,-V`B(P')UIS<#Q(K-:5NL:.V
MBC5EFQE\5\FMEZ6F.']X(MZR,R']5.GHH`$8WX#W'P1V$^##'H"YVZ-&JV2@
M/Z7%9JYX_>&O\KJ%U5].*]O9++@^H(]=&+#O-7E@QF)["EZ1B18H`NJYS;4L
M'<=.:=U[7^/!`22.H9VC'P3@43"K9CQF#*6'DEXVWV/#7Y&IT6A+YPH,H`LJ
M!W4<]SL%0QBU0O-"Q>=2W79@_<QJ+:71I1]TNG5</B]K`,TLL0,UY2Y[1<"!
MGHV1U@*\Z7?N);V:(Y^!AB?)'R(.E<0V-W$>W;B=<*J93&2+=A#4?E4&2=0:
M5[NX:C$^&J22PHG`5K=NG_=/N]UNTU?(BT7"+_ND<2):NYGYIPR"LJZ3P6>Y
M,H$GQ-<U;>T$L/.\MV;6NU[WZX)X`MA(#8"3S>M4<#&C_T1;A5QL=^I$L-UD
M<R^'L1RK+:R?.;[K>._SWV;G93X[EQ6;$Q/93Z#?K_3(U%]#8/7&^7+]_GQ.
M^^PD='4[(!`O##-?U;;\F-NEU8UL8)14U'N:6YA*DYCXRL+06QCDFR#84^B(
MK!E."6VF*8B>#-G<=NV/%4B$Y%GMR'L:RP-F,(H4&L5)$BLU?D:K==&I\*%C
M;71-P&YQ$)F'$Z">W1:WY*7M<;T<;/CU#M^`]V_R*T<TVI-V_`,PG+P^RP_4
MZ,,]SEPW]09M.($#/!@^BV![-)%5O[/Z(*O=2OZ8.RLR+^D^VT?$N;0$UX\C
M@9"HB<K,$)B4".]G!`3=1/T?#M$GJ])/O>,#6X+Q">_O[W;<#V(5D4#+\X20
M?54BFR@B%V17+',L7+PLNA"G,$8KC8"4$Q"N@%MT;8K#?<,)`F1(OR;_,\,7
M(*F<VS;;?NL^]9!AWR)[BM5FG<"&6*G4%JQ\0T5'H``R#EBR_=RP0_+@PRDZ
M0N@&Q=>G76"E42N?V6RY5]F?F^06PM)!HZ$]:C'C^N<*`M#[!%6R*T<FO@V-
M*.S`_0J(Z'IM8Q()3E3BHGD_@=[I@7H-FU'GXSS&*19-IQ!!9H-0Z$4WCJMI
MGL#,"*M8WQTVPB-1QF8CYKEID,2$&30DVIP>.P+;_73-&#*MCB5I.+M273UH
M+VF$NYNU$91#7N(M#S@ZRZ38_SC$^ZX@G=5A\F"BUZX!LW&]HF+?J:"*QK7G
M^6@%-7'V&?@)\P'..G(:+X5"Q'OU/*<0IX,)T$+LKGNP>70/`XBZ67A0;V^'
MD@TT-&J!E44`BUK$XO+1KCK&+M[CTOXIUKAZXB)*UC0B1-_#*?:8B0BWJCM5
M=[B_`>\_A.%])I]-9MRH?0?B`-#YX&F6."HI@.W_/6&=EY09R";KD4]%Y.ZR
M)]HV`2UZZFPBTJ"I[^G?W4,>_(2NRII4$_)6%2"TH@R3;V:?FI_)9'BMM'G@
M@0L1ZV\I=O?]P!%64`(/-<P%SMW>W][MZ$?M3QO/-ZVH'C?@31?#V0K6%S]@
MM"F:YWM:._*P1P,<T@KVH6=SLFGC@D93SG8WO[=&LID%,JH\^=AB]X".D."B
MK6GP0*55K=^AT<,L8EJ*AW5?H+=BND7('!ZZ\5DMS$"WUF8R57H49_I1);FP
M%>'J7FJ]5P$5UK*..E>CLOZ;U\:7+&(`]^;Y')B)%,G#^I@R(DQ#&EPLWP((
M%]K>$S.'32V/'I,D1QO>+8H*]OL,K7%M#)>U"8*F/&-*)#S()];WFA9M'HNC
MDXD?'05$K6@XI^?:`TUYXU;Z!7XE^0S$&*9PF68KVN#J7"""+6X+M:5'MRP9
MC*AJ`.JEI\5RFFEY[6?/7C"*Z_T:2,O;1D]=J77=.\]C>%S_(U.LPUQ`F#%P
MVO%)$SU?'U@'-V:@L\A>.WTMWG79AL_4*<@+H($M.EJN,I+\=GW&-^#]A\D9
M-JJ"O%ALMW5-2,H3CO5ZZ,%+D-.D[,$QV>/FW,-_\*H-6V!*WY&7W->`N`)N
MV-_,QF3VFS2^A33UI:DI\H]4IX`U]5R=(]EH*9D(VT??'TA$JFK82>]KJ2T9
M:_1;:V9#SE`PEH]NK#FP,C<`3SD'YR+:)LO343'Z'MCY5G<@L`"+;@"#L.,#
M;=K%#`SP]-2?=CCDMQ'2IZ*VKHKJY7\?'J.G+IK/A%K".>NT.5``VM)VJ]T(
MO!KRD6+!17<;P5;V_\U#D7+,KIT'-R^9=@;^;V]OZ5Q%><[:E-O4O(_"M)/I
M_PE@002=)\=@?EZ&EEAEBUZG'8;[?'PN"K0J+JE0KFMMS'T-I5.\<@]KS60.
M!13X?(^TZ'C+[AUCQF!Z"N>!0Y;;C+]OK95[UV)Q&[G&%&WFXO15WT6(BTM7
MS>N[!\D70J6Q@%@7RG<6?];".HS)UJ88WHV'M9-.%)2PMU[CV66O8S*H[;IW
MQ4G%FZ1LPO8:]%'PS,&Y$,X3ATJ16W(Y94[6I06,YX^"97R:%E@+FC(C@L*Y
MA/=#[:ZNX\C>N^M\<?<1X6?L.UKX[R-G>!7TO@0L']#!L</]+-4MM9#MN8X2
M+WZ/QS^+4$%F4+^56)2<-C:BAMTUR191\X'W/<['*]?.'S.WV*)%<I7P2L&U
M&V**0TH\N9Y9H-R&K;_5V^WM6KQ[9CA=%S4^-@%-O%@BWI,+YL?S-[TI*Y`5
MSG.GA9-9DEX4,^.%[=HB)>4G#8\Q"`X2HHWE4QGA:D%@0ZP6J(6*SO9?&HAQ
M#A\Z!7<@M/+#O1AUW>2>L/2#EN-C"SWPN%_;L-"RJ#,?S7OJ,1.XF6SJ:%N:
MVZTU>W]_)Z9Q#<,!.0_.F]MQOQKLQ,+WZP>Z6*+E[.S)[EX7X]X7>';WE.PF
MK&CLIKG/Q+?6&H5,:('2"RWI9,0'1BWT^.-U;.>$2Z)AZ,+F&PB$$#,J/LG"
MQ/G%CBT5Y1PFQ.)U.Q2`<-,#U,%S^<[Q-1J%/C]_0VL/$`U(OX_`8:.A2+^6
MMJ:R+G(G&,.#R2YK`BZDH;')Y-(Q=I(O=8X&AR#(^;/>7&0%AZE3B<KB-)Z:
MNW+\#(,&ECG6.M=HP4%G]"O]V=Y4[%:H61&X>D$O=XU`^Q?;W/)&UZAUEE8Z
M-O[?`O9-[K&QS7T#WG\(P_L,76:-S:9UA1JU1M#[3.JY_=<7$.\KC#+U4LM7
MQ>&,_9%YBL=*4_+1;NQ5Q)ZIDB>OJ36Y$':H/XR>M<#N,C.(V/R."WF9&N6V
MF]TJQOJ6=K4U:[=F_3CFQ'E:,3?:\#BW6RZH7*U[#AL0*[)=+0%MH?L#8D[E
M*DR">VTMXBJTV3&VT?>UBJKUT,QCR83'"%JK6WP.U4DO-0>T+1E;L0)\B..^
M-(;HO6!`8YJ3I2*""P%^@OLF&,7(!]C=[????Y\L(M\/.^G+^([#&K!=K++:
MHOD$AR#]84SO8ANC="^Y">A>\@R]^X84@.</*&%A!C,P>)V@W&WJJ"MR9*JZ
M+G/4,3@VP'*W<)GBX*MGX`);`V[340*NK@K.T0)+;S_MOXQ;ZT@,*`I0(V=:
MR!=M?U?[)&BX:@W3J8W>&JZ\V&L$KVTG<!M^C6`.)V<&1RTS84]EP.C85_]C
M;46QN!P@KJT",@3YL&P`E?S0BP`0C]'MV<X.OF2"'"[C86_A!\"EZ,[=KU04
M4EM,A(31>.:%;93=9W35S!M-3#3U;Q_>?P;8#7/\FK]NSQC.P(6\@&1S\Z'(
M(Y?F?DPU>PVKEWBS^`>\P,`^>G]9'EY,OTK']J)2(;O50]D(`@AQ0OA,)KL_
M>=B+]N&&=4Y`&S4QCJV/,L0WE$_L[=;.M+CC,`MI=4Z:7T<8:!0P6=O\NL<T
M(A[Z\+")>\G;JT4K@3Z.=)4""%I'0+>K.-`6K?C*QRJ:DC(`CE("?CX+C:K/
MDTD;KAO)*=98/:K:R$*ZDNM]Z%'"P$$*EB-F+093A(C=/B)C+^NB=OU,<P4F
M7`@,QX_W]_?3G2'<#RHY*+QNO=FMW>:6BMZ+H:[S_'1>#NF[-?ZL>"WIVGLL
M8H!A\&?3P.'\TWKR+P:[HUN_AL`&J,1@ND.WQ8JUN+FEZQB"7/,BZ6Y5C$UT
M4I!!9M?C9HF#1W`S-.!$++>@=]?6^A)R\*SB.8@66XJ>B]MY?ZXU3H>:V`WB
M/`\W#UIFDNK)O>_K`9O@',5V@2@M,!ERU0A<%XM!=,SGP^8`6W9S:9;7O=RP
MSW>*NW[/Z":L'38GPP1RO!@`7J1T>;#0M*RC,".$K%`K^GSJD9QM\*AH'T]4
MN!AN&KTGVMW`"GX#WO_RKU?E#*^PNWO6DELKXI"2GN*7HXAE*WT1>18?PA&C
M1MGLK]#!_DH"4VKB$,J*L8[025KUB;2G6@XEO[34%$[,STW]_OEI![`?I"IT
MROQO-QJ,LF1\OJKPW;'6S#@R?>XN]8+!K-UNAMY/_]W$OB$7+46-X46%+P[\
M)'<8S`SQ)93MGJ4<77(H!YMA4T\J]E#4KG9F?JXA&/8VA1CS^K2A`F\`LEB'
MP40M)0@TC6-&OF_%@FFUM=FB3%\?1#W0^]#IV0?4MDLLGWP%++2;&^>I*)8*
M>F#2%$_`0+&I[BX.'CS8_O[^?D8+E]/6C_[N],!^NS6[M3.V^[BOA"@,^[(+
M/+0!--%I,%+MLL:C@(<A+*<<HETHU]UEQ7$"TFM?=C'BCYVGP;9V`G8<F,#'
MX9NIA,EHN]FM@!T<J.(.<1OA]G#5O?!M@`=20?\HS<YH3F(`;:](FE53"4WL
M#]KPXWRU9E?A8^<@6ABZY7N*M;0BZS$"T`2JF/EMY,*P;.I",@X-3`[V>/IW
M)P>2M:XTIV)&;,4HCCKVY0:#[G0DKEM@W2V!=KM0S%Q',L4SH6,=:1C5B3$6
M]Z=J3[^D'['`3`6/1=VV`F5O:H_Y#7C_Y@SOMKF]3=:R++H-FQFWG_W)<?@6
M0'Z1*GZ8&`'5FX4!N6>?^9("P4M7:F4"0Q'ADA03!JHMGM[""8%0(@^UM=;F
MIE=OX+XI;'1#:;=;6J`,L&CNDD`Y?5YK;F]ORZS?]?])*V]\3KLUN]V:?7[>
M=8(Z;`ZH;+B*8H^-\>&T;!;:P*G4&S]WI?NTR""DX3&]:,Z@MCA'ISZXBN]U
MM3"C]G3TR6S.?KDCF,"2_=;XP!;:>BA"*D[PZ)8)-K?;-9U<W_,P:RWX+B]0
M-#Q#6]-VX#3#CX59"@Y!O.7+^&?^9M/^K)U`^<=OO]G;V]O#]3%W"LZU8N0T
M^)5:-7V!!]H%S&^^?L_I<621AZ(H\##-SZR_.'DT:I^V2P4+!2^W-@H'Y`X"
M69,"W>APISNQ#*FZBR3!66K#EZ.9V'&MI*WK?FFZ[CCYJXX\M#+Y4-KF+(E8
MLHT<P%"$';EO.G95##14YN,;P,\%<QMGOY<LB1`%`[QUD]0Z9K<M@4</H0Y4
MJ%^DA`_J7S37];HLZ_P5U;:^#@Q3E^SL0Z>;K0^@O(**W"L=@$Y7B!6D;V0#
M._+*BY:7J_S'<[LH#..I'&7=>M@F)<)SI^Y<"]JTU;-O#>_?GOO=P]VG.1$H
MAY:VZ@;@A4]^#C"QBVY_$95B\P6]U!5X`B\[+:\7[$;EJ5LZ1'``4G1F$D4'
MN,^SC-T9B!*SP]/VN4V.Z<7I%.L\]&/N9F^WV[4QNM+/[/^(?=$R%IH?/WZ<
MP1''8??C6.;R`0S"8&_MS=[?W\?\Q6F?QL2%>^8G'Q12B=N:[6%;4^8A#$2&
MAZ!SU#X62LNQO`,9C%=TZQ>(9Z_?K%7FG((5PYD+NMF-QK(@,_=EHT93X_S:
M=KUP,3EF;(,'!'>"ZXNV,#U>#>OQZ1-+/P[]<)8[(!=?=.['\?51>KBVPE/7
MQ2"@5$`9LV`P^_';CPOLXF$G9T2N(GQ&'^"T-4,_@C89\SYE0+O8510=H^$P
MT=<=*INUBY-%!<I]#)%=@W=C>&Y%,NM=U\6W=XW].S>+?46QRG2\A4`MJ:=#
M*(T`O.@H@B!54UI05N"F+>=NN?`?/S-\D=W<EC0[)#]RQP'JJ#+^VYJ?7L%M
M1^VJ_`64_SZ>DS;L[H;&&X74K%U^P@X9W.7A+U#+?U@VQY6M7[[%LQ@OF6^)
M!E'=<,EO=?.;3[]DFT4KRS]\:;Q;2:'*=4V=@8E636=!"J_U%-/.!`Q_)F=/
MN"=WARE0\/".P8><W]_=MT"<N]CX9GC_SNSN"S(!?!64QA8:#9E@YV?P2,Y0
MD+15*M63XWO9MC?QL>.FQPOI6_%/7KSO$Q]D`D^E3_$8W,*&?0X/9N\]`.Q-
M`(&TT]94\LGNH?`&@0``(`!)1$%45BP^V6V1OC"BN.'Y.W[=;C<[CJZFY"0Q
M\;%I72W^S_M]V0XUW^J#'Y'^Z[V7=LW]M"&SOCQ<LU3<PR:^F$K^%"E2/-O@
M8'/"$1TM&&!$+;%I5#.N\\%:7?:<%FLQ,7&_!L2:%U\8#WR9=;#-K]2MBA)-
MUV=H@!\WC5(\<H-V3CJZ1<_-&(Z!1+R#BB1<FMTBL<IC<8IR75O7HE]#E'W]
M]+!CXJ$A4X>::0,G7>BH/70BYO-`8N^X"A@>"K(5,7QMWA%PN]3#'F0Z5$##
MYG!;_.P8UQPC>;?W##ATH\NP592MY/??4POQ.63G#"0_R;;D5]09F.=Z$@57
M$,;-0TL;A>2"UA9A\G$-5I+\@#I-$%!JY6";!#$UUWD"L094-AG,2(J<JRD6
MX%CQYBFA#LP>!\84LD^0E_%@3`MRR[AKY"P'&YVN$.%L^;SXUHA?_!5FLA[L
M\3Q)'+Z5`A<,ME$VB[F`Y_OC&_#^U\"N;1>(5PE@Q^L$:@)6+S*[3RPG4^&(
M$MGLC_/EXTZI84A\+?S5-\ZQL/LR(4@<K/Z>`.Q^_\SZ-V3OTJ/WJ[W&U6@T
MBK')\JY-;3W,]_O]E$9LAES&AG5[>SL':@A@CV,\^F']H]O;VYNUUD[0R^P8
M8NX-9HOH..XD`UDMN+ZK-F:Q$"TQR(.70!@\L!N10H277KS2L?>]6)FUEE8X
M%<@U*P:\TA`0>Y>.Q1K(=Q;K7JE%JW(9));7`DCEY#8`P;M8HTFK&UH:F5Z!
M(`]LI<F&N?R+NVB`2U!:Q%P[V46YF7W\_&F___Y[Z0\M28O!20.AL.D==O_\
M5/#-15MQS22HQ!0H[ES*JV3,=K6L3Z;Y\LD5ILMD*$R\59T]<?-6`&'^EZM#
MS<Q;"!:Q,MI;P6M/25<(PQ2\_@ZGB]@OB](7?@T/@(DF-UI_H6;<^3W6,74!
MB?/Y`6FEQWF@]#T&1_#`,)+O\=+:JKG7[,B@D`\%PV'P>@/D4!`\&5*1:3R3
M=%*'/G5%=%(`[E84).N[B>%(F#:>6G</\QJ>B3!W#_[3='112E(]830WTB4R
MV'.)-<^ID\]R=N.%?4L:_IN0-[2,O@+_[)F4]R5VM<`>+U+&+_*R#US+_"O'
MOA$05:&+.\"=90_8]'^?,\7Y^(E=V60SQ\E81+<(0'LQ<1.FWQ_7]%`_>CK-
M;JZA9I<796MN_3@F*`.YB']^?EIKM^!/FA6D$T#A_.S!GF##O.E@?TC^TG%[
M1AN+48C?C0<\=U9J(>8:X*EAC?3D5C407":Z`E$%BM#)X2IL@J[QS@9OL!7+
MAFFU(8'80,TN$6G@E1AYT(0TM\XY^M=WY]9\TZ(O;,?&9PQ6FR;2F=F5(`!O
M=DRP=G[+C\]/>WM_OV0-7H+*5N3K.MV7GY^?]O'Q4X!6!29TW5A@:`!Q'>*#
M@"Y/NOOUO2U*(EH1I&#!TJP3F*@L)4.4<V2G=ZNI!':TJO`4^EX3[SP$L6PB
MQL0JZP*_PS=YN#Q(V1#<.2J'S&AL8H;BWO0%TM-R'],',<,T8HSQC!WOO6BM
M6W:F"!Z^<@]"C`57E*^9RH^"7UP:O-KMD="]P<468MV'+::BANC?L^@+:\+.
ME])4'ND(,?-SV)Q![ECWPK/FGF+N>:UTV_CC3R>:]2+94SCX(T5Y*_/LWX#W
MO_?KE]T9_@*8O0.D6[SG`8M]E4#]LZ#7OX:SG]/)_H7C]M)/MI(G[_+,/0!M
MM?JJ3VJ*KPW6<!M<K0^[N=T_/Q^RZN,]!V,K8,KRWMN/X_(+14&<LN>AAC;S
ML%]BI5V[#AY!35J0W;:B'>Y\.)[>@_-XB8'A#83/AP7F(_IAH@IS,-7BK?=U
MT@9>&?>2CE5+!'BC[3P,8AP!O!CBU7Y5L"4:5_K]<#*((1AN+L6##(U`.$C1
MKYNIARLNRS+608YC^/CX./V=FQ(!>U<`F^?M.`[[XX\_I)B3^[SW31=@W8,C
MJK9R&!"@:17HU="`1XLHM[`]4(["-J).E^/`"4$!V"QGV*SC'JZG6PZE0'`;
M@*D3QS0KB?[2>:U-FOH'A.9D_RD"UVRDV%W1L:Z=%?=L`"F-'M.9"9QO6/;[
M_'&O[X2-I#->H!`R<#6?*_32DO+\3Q?V$D2!.W)@1K0^5(<'S,AB`Y+]H[E-
MAY*=^,`#:+82?-=[SFBYL&PAMJAD$#"L8;',9Z]EL*=W]`/G(!'3(I&[#]^`
M][_%[WXU6>V%C?ME%/B%%VC,(QYAB)<!*K9,Z4N5PM?,?E&SO<]\'L1?T!?8
M?'2\`)[\G6_;BA73SIT^+UPK@G,^V2N%39I`M9NGMG2Z%B0JC#*1^P"\(1;5
MQ-2\6$JQ+Q(6@=%G"QC(I0.>I)5XT`D*^T;`R:-%&ES98;[N'!7JRK0A+.PR
MG`8(TYD86<=#$*=%PB-+%FVI<GN2K8QV*6_\>Z"P-+/H_;V&S]0X?_U,#['-
M>G>@!+MF8PCR!#.M>6C+(TE+)MCMW?[UQQ]V]'ZET:%DB.61B68H-.P37^M7
M=/&,U@VALT!FE"2FV[-V/6[MB.X#%J0T(YVM]X<^['S.6PH36OIS#LQ8[?$Z
M[C6N(6L;N7ZVUW'9L6B7A&">HWX8^A/\M4-K&ZF0)&<%$3D0<.Q(@&AIO160
M/5K32WET7#--([;SN5TMI/CWR?[<BYF0Q'Y#UO@0T$;@T%*T]ECW^[#J._LJ
M6W*N3W(B%^6I\R3`&W(_I#V5.Z!"/$#TS3J>`EVQA!)>';YOP/MW9H'M1<NM
M+[VG/QZ`*1I7->'Y!,W^(@G[B'@ECL2V<8>Q];N)"_=@SQ:+`7CT"UQZT,?R
MAKAXUY(5O$"7X\'OW<(*&%MB'"]*';%JZ,XBQ"'TMS9(UX$3"][&Z5YY+=3#
MPE+-=G&),0TQI<Q\GS_?YQ=T2YF:IA;#H3HH3F4G4)ND)M>+^FZWA@9'"",K
MF[W3YH9T'^=:%8F%`C%+5EWG!YLVDD40Y'53KE(4(!S9B^C*!RS@"UR651'^
MN@SO50"W8J*YD`-.S>YQ')(*AZ)-B@=MFLH"3C?OQ^F'$?Q4TIOQS(^UA>%8
MY=82[Q\SE0QXG'0/$2IQF&O^7NX_2`*@%(=A.C]JM9GQE6*SHRXV3!TH8RA&
M4N>4C.MR?^$!NWR_K/D'?5T7V\0D3`-*AE<=)&`AK;@>-C:.?L:#;E7VM>XD
M^9GGB+7Z-"<0D/_I+,'7P&H'B4<#C?,<=3P?"*=P'`0]^1"+>'$MTMQ/*DZ1
MA__B7A\F;M=0L(:"C,WP&_#^G5G@OY;:I6$H?[@9>F#-:I"\V0">V//B+ST7
MGA[G#'R)AQ3G+D\>B\RD9$G!`DJRT04@D`>-<ELN5>RAEQ.=)0#4H)W9JMWY
M"A9%TKX.H"!3+:X.`)3"HT-3=6N2'=OBY7)DDSB7V,J=["?$OLXU+PPK)/<Y
ME]9FR!VV79A\8A@18S<+-AJ/6P%K\&B$(?`&3:`(RSJI`F-1(SW=`%**GVNK
M'W$8K=,]P<4&`8,`DJRQ_K3-B]QCGM(%:,?@R=!31A>!Y)Q@)E&S6WL[=SN.
M7G9_$(JEF)C'NL+J&>7[PZ^'B,'OL,DZKZ'//\<"4[2N8:AF@N!HX0;LP3E0
M=H]V7JYIJ*RZESK2(*9X8/,SYL&KV&IM^4Z*HD5G69?J(S2'Z9I98=^EP'%(
M'TQ8W/AL1V:X<M3T`,2RHGXPL:X9/1BNOW@AS!.+=K5&WZOE\UYT.2P,<1EJ
MS3DGH4E!M>MM7L/$;'^W(WH6F$5<G=?R:GI!1?/LQ1[+][@X0*WV3$^?E./3
MS_5LW//?@/>_`V3_(CG#5W%OE0.!-$$@<#>W09^`Z:]8I;UZ[-H.-!./H>`5
MJ"Q3K/01!C`JSUH7:Z^G(X549<NLF3.#5Y\M$1:DE9:65N?<>#I.Q\8%`ZG\
MKG+?M\H3CPDW+FTQ.5?!+S8S7!I+BGAX<3OR&(;B%(P7)LC%(6)Q7'.1=]49
M\@*:VMF6F<6G.ON=/6`,CH@QRDX;I<76'.E@'=-6H#+9-V+QT9?)?9H2?Q#>
MT`58@=:$E*^\7M]66WA<`U0]""P1`WNM%E\C/U,54$)D2Q^Q3RZL$T)!Y.(Z
M<`TIMBJYR1<8+L!$"L'0V2IA=)GUTZ+)E0$N'NK6VF33'Z_`JLN-4^V1^%A$
MA3^D$UP8XA%F`/&/%O_4I&L>UP.%)94626E/@=$ZH`;9PZM\M]:6$HD-"GV\
MAYUGM:/8DX9[AIEX`[C7Y8A\#H(_=B!.=ICAT;H$6^X2D>V7HZ=Y@FJ?%AUN
M@6&RES"1$&'FI'+!@!0WV#!G-MU]O"AL5H>HF+.1MSS/\S?@_;?_^@4J]M7W
M'>;M7Y#E;D&G>ZJRLIK/2HL'[%J&?Q&HK[YV[)!X$,I))&L!/KGR!^)$KHGG
MZM/V/&M#/5OQ6&0KW?,`G8`AS8S)<H(<8)`-'];6XIF32.C'I?BYSFG+[#ZJ
M<>*B/9;:<6:)*7#W\AZ,"^G:WW89\M?&VYH`]!45':R?@A>U"S#W&O06MD-^
M.4J\?*]#K9E2M'(8`(JRR524AMCF.6V^V1R=P)N39QZ25FXS8#0*+[C<=Q+'
M761))RD"K/109?LH\Y;LK8#3?[;WTVNW7=K:=FMFG^3%K"/S5WNW19YK:;0O
M_UF.'I;OZ]'7,W>'$@"`R@6RKG'9EG$8C17,,,S$DWJ%V9@,:ZUAV*B?Q^7#
MJJRO!4WMO"^\'M3URR]W!;%0%#R61S@70!U1XD`Z>*U$"R#J:<`6Q?I028#4
M[WE-\0L+BARFP39W'7&5(:>3D/L9]?]U!P9C/FTE-(:0!A=6UU\FRT"?P>[=
M+H-?%W`,@WY,(#CM?3MQM5_)(<ME(<,".+;M*$GB+.S4Q/E&/=+F]^M%N%;<
M/^<],P#U=]+:?X3/_6O?RO_<^WK10GI\Y-A7R@43$)-2?OE0W4.$+^I<]P`:
M%]A1[91B>C\],V?;HZ\X4BBCJ2)8T\^)E\8CG@UZ5`^ZTJ19C`4X^>Q>D^U`
M,4!BD=3SHLD9=&A%:_C5"\8M^04&4KZPM,#GA*W8>=ED_9I[8HB3A5KP#N63
MU2Y0,6)JX\59802Z<33RZN16^PQ3"!NQT\_RHKLK!&K&R4?*J`*Z@B[V]"RP
M#C&FN-6?%]NB)0,6BB0QVXR=A<U`H;N5[<]G3'G5/I[(X#JF^_UNGQ\?=K_?
MZ3R<@2GO[^^Y10M]CLYZ`',8+MWFXNW*USJS;E%;7)Y7@Q0(*?2$NT*3J6>7
MD";.$K,P,:??IT-/K#,G9BVF6AGH<7O/:.!BT&U[+Y.<A8>E/!46(*!SI>4A
M.S)ZLF9#8`:]2@-/>XZ'),)S@"^V*L*]<!75GELUB[3WL!<E>5`\=Q'`8R8<
MCZ"3$;$]K;XN%PH%OC7_C`*4\@#>^C?2C'?MG,6I@59L`P+V.U8,>D<HPJCC
M5E0`PN_+^0X6;;'S%#JNL9#P8E!0[H7KW[\![W\:_K[H,/"0%RYOQ*\DECU^
M+>(J^L([^Y\X)^[U.RQ?/Z5TW4V&FR)3NIB>,$$]8TV7E^/Y@#<[K(<$K%U+
M+&/>2](HVC17X2P!DQID*O-V@2(?P-S-NZ_`BCHAV6;L:FGYX\N+DK2GL[@H
MZ,;HKPN>8G:RY`FO;7.J_1QJZKW+0-'POYR,;/Q\G)&<#";F<%21W3[N!P&O
MYF*^[`;KAQF\2QMOMK@]V`()U=.E"&J^)I<;'9N\=M.:%'_@6$NA"B*P(AW)
MI^:2"PB4[49DYMKB!'_V^%7S_K!VN=8U#*P'N,CK".LKN]Z7]-V.X]#!13M]
MHC\_/Z]X6I+XF-O]N-O]N`N#.B.[JX""N;7[8J;A$OPBVV80HD^1QJWI/>V<
M7*GN"L>54*B]\'7]D((D+F8W),(C>%*E03M@>JP.O^,Z30C*LO<E/I79I\T0
M*H;%EFMKG/67`)*'\&2)T2_0Z^*Z,/3L<_C46.]MIM/W!3/)C+;<S]%DJVC-
MNZ7)WIGLYJEIP$GQP3D!P>M=Y2H#4;+["3]7DSGV('<9^U)LO2!M?_.[IEB0
M$9E\HMZYEK$,`Z`H7TD=/#_[,"3I#MM!"LPLQR*6YMD*AC:1:;X,+C41SB4P
MJ"Z="?Q>7^8;\/Y7@*Y_G?JL#?.^ZC+V&D@%V^3@(9`*F2OU`9%,:1<,JNQ>
M]*<,((?:?1TKZG,:<C>;7J!JG$6YZ1M]5/;GM`>VFAX%!A)#NK1M;MZ/@IGP
MH!OL@<%<(+5=WIU'+'9@8AX_-&VHV'`"1GTSK.ATS!8"*F;[U;/NE1<_;VV%
M!#BQ6)12UEJS6VO74(2RNO&8)Q/?NQC7S[/8%KMK5PL5MI@R'VQY,VL&Z[T1
M`*KUCJQUGA&7?GVWV_G=WOS-COMQ;F#B_\KV/.J$L(:DVOS)Y*\*)+G%O!9%
M7*D;.T#4/KD:7.!IV%&`G]?KP7BT&X&C/+#HH@&LUD!V&F#9R.?GW>[W^_R9
M-%0YP!!4.VFNS@WBM4J`I=%@GX4(4RLW82HPG!T%/#F9",L9Y%*M44N=&CW.
MPU(RJ+3.]:X5!]/`E^AM7;%\@';/8GM(\E\LVAE&_>QR(!@%8T>_0$]M1Q9E
M7"#@#:A'=?2J%6:>?HV_[ZR-IY78+_WGNE]JQY(4#L+`,W389QUL#/HT1&05
MM9`NP[KG+(6;-&_GVL5N0-$)@^Z`Y)IA>[M-UOISYT.&D;WJV)H,CT[&O*U[
M%5-6Z:+=]9!X,<,^6+[U9.B:Y0BZ;:NWNPE1A40>C3/W#7C_0[]\(Q!_!$>]
M&#;ZLY2J%_0J^]RAJGX?&JG;<_G"`T0^]AE.O'+'\K#<?"0H40HAR:QUT^G5
MTE.R3VBZ)J]1)\I)0IBMYLYU[CKO)B3FZB&B-+:\!ML\V!U`FS%`M][=R'TG
MM`HC\Q*;.28+5'(72)(,%R:X'WT._(`V$-:"=G0QGQ\3_&-E:]8,C8W_2=?8
M5G\!@.'29BY&>AWS[7:[COV0?S=7IFHP)DL_>6Z*/F4L*@G@^^.\!AR=6K7'
M?24T`6:WDW3O1U_MR'Y*(H0@MA[:S4BLJH8@9/>,4>QA8U"<I0-9P+2.J9L.
M!(96,%F.Q<*Z0S?VO2T?RJ*+"Y_Y]E."=+WV.-8]:=IJY^-P\E]CJ#-LJSCA
M"^*A;,F**Y?P!.J:)V;UK)FN?_/Q9RO;S]5Z-M_?08I6WR^SE8\K%C,H1=M5
M^$N@A.W;_NQ9'9ECN8XMIL5Y8M6C[VQU[.(BL7$4T6)7]:;)`LSKS6C)&+*'
M<QD53[_ZICBT"^R*JP_O$X&T.&4M(>`F%&;#8YG)!5R=*;_D&,E&#;9G>J-3
MD*FG_'JNU!VF)9L.E1*TV+4,W0IK+A*>?(*=NDZVB1)W/0XM4:GH./^V&=>K
MD/JULS?V-^#]C\/>EXG<;,;\%2K8M[Z2BK8BBU-M6D6ZRXMX5I[!1Z7<9=;M
M#'YJ.=YJ3Y#1].@B#A*FFY5V4:R;:\R4@#9]BI"UT0HNHCZG83L@QU(-$+H8
M;[L.LTQ#^QB^=K(6L,,:6AA42@C<.`L]G3G/C%N<E':68Q`X/HXN6F.?PT0^
MY14R2.!N1S\F2S>D!GVZ62RVE'5O`^SRYK=DUBY`>;!AWGSJWR;8[4@I5!UF
MM\$0C"A1CPR3%CR\^8_S=0L2C/.>/<,\G9G99N8@#2:SQ4%*H9LHDF2\AP$Z
M<3&*;(CE0B_I"%TMN6;L*KE@K+FGD+;GGGHZ")Q0%5`P4J+FM1JA=EWY\.`1
MGP)4XH2WFZ]BTZD([?.;*/\)';3ABEMTF-V6'5-HQBVO5FB70W21U%@.0XHJ
MX5?Y5/.VAM-,8Z"MT'@+F^:%"P14RB6G*@X63<>%EH:6*I;8-P4.?VZU0439
M3`S;D.(%!+)!X[<>.R9>LGK:+M?5;C##$9P:='!1.P:>&.?S9;QFY6N89$#&
MPY[J(K)>$]>"PM:-=]C!),/*GU;F?[@O=+E`+OKU@$6J6.W!K%X=&[]F9\QT
M2%#\%:A(]GA#R5"OR\"WA9^O/(2'+2#+?UOXN6_`^Q^5-#P>#$J1KR5RM&VO
M/32RD]^AC(I7+4M[5"6_$"?\@."5X1ND]>B%`3I,@7L,/-AI@'?.P:/:AGQW
M%.S!M;C&&1Y:#*&*_&L342T7;44A^E`MMRSX;^+"E-V[,$QS4]T(]6,KDJ41
MT<P^L[S+>BB!IP%V+U`Q6&F$Q+A^^:(.J<%P?#!$P+**AN,"O=1?7W("EH]<
MH+.U-L,,_`*9=FB;USP4?I7/*AO0@^ZN0GYBE[Z-V5#W7*)&@,"`S8M!)F[[
M5F$"**,):3!$?%PS(%KLG<:41@G$8G\6@S*[%$%XO.R$//1U-?K6R?JO%\!5
MPR<@3BJ5%[;($&;]%[RJT?4[\K7@YY(_JP>@C;P>:+O=Y+[1P<!(&%!W)\G0
M7(8R-0A%P2XG/JH<HPBB4#&N,%W"!)XBGZF3G``2T#UDMZ;3M@+S8(#0M/MP
M$0*CJRYV?.9B!<GW#?>WSPY2LWBBHTT<2GTGGW.^_SD$I1Y"E+4")L-_@RQI
M=G6\N&B['$`X#$>2](:4B"4,I32E9K81`/J)9\OQ+@''7`2QEMB%T58]!RK`
M60ZD8B^O*-9_UCA(PN60`T7V+76]?$4Z$SF"P@#^&_#^Q\#N:\SNCHP%5*^Y
M%T&$-8WMQ:K7X@E(?8)FL<??"8SQ(H9,0.:*%=GX#/98H+Z`CJ4';`^DD6L!
MF7B&3(5&FK2:KB];U)?&.`[(],$2PPHM%0%@Z-3]SCAC:0Y79OK:.9#2TMRR
M]S)+/4!@V*9#P4$`(J:OG>W=!MAMZ&@=9MX%E,#;Q3+VM*#.Q6^<%RNL<N*D
ML8_%?$D=&LDBSJGB+N<R`@[V_M4G2;V)ESW38.G[8J]OIV=J`^R8D@^67:1U
M6#<`<W'UT#`&TF+#,LB&RH7TQE!P%%NCT;Q@18=F)C`-NH7/5O#5Y\&P-":"
M22\&Z=+M3<?2"Z_DT]+,I>7J`GZ5<9N>PJZRH"5;XJ(HXBP(Z##S$%`0B(@B
M^HU!_<[^SZVX=Q;EM8KO.)E/0(*$59G]OP#96M+4_JLP\=/SSCY>;FF@C64P
MJI\.MTUE$X;%TLT."%#%-$[I5AUZ$8MWEL_IM?2X-L;BMY'6V!9X;Y2\Z).M
M=SU<UWMP.!)XD/>(/A?9$VEY*:]YA"G[8&:GT,4`0@I/XF9VDN!JLP:304Q#
M[C#(F@/:\ZQ()4K^X"0Y"4%)\;6R#U,A5'EEK\[8>O]OP/MW`,0O_,#KRM^_
MYK/](?M<?,XK&<A;W=4C!OGQ$;HKNY1RZTNF]UJL0BKC9)'3GD'#>S1H-H=E
M2B/B3=ZDF5A@*8C8R$D":*]LR4*OV9)QMUCZK*EUV0";YZ$HUL,.IC@$'I27
M;$H],"W'N'7.#@2LNS5;;3'05.[Z3JL5"1^."6;'<>F49^)56YK73DQR[^<T
M..H0BL6<NB3R+9(3V1YR+,9CF$-LSER!&H-.V3!B]P?"T%8%=#F`P\!Y,^1F
MH46YTL)"=*HM-G]*]-K8U"OK*K^<`OI5Y#3JJ.1[^[&9?I"F(*1+E6#W`CR\
M>=-`3FSOFZM5&;.$ZE&*8+U7;=:!??7]`K2LJ5P9W(T%&#\O[=+[&Q=`YJL=
MQ!V(81L6F70>*"HT=#X$7]G.=X)-!H:=AI'4!<9DH-"#6P:OAQ8B<OE:J\RI
MA7L9<T"Y8K@K"SGW*A$S#N5IEW0X-C3WM'^-QZ$[0M%D,O`G81RRKU\#?[,`
M*>PD(^2EKN-DQKWL9TJG847ZPGB2HPJ8$AM,VB^Y(Y4?;">WB2C#"[:%T]J1
MGN?TO!`!@12>J7LOH.?;LH-#^X:;?PUP_,\!XR]J`?[4=W)ZW+U\']^V,'X!
M:<,V5:W>^#PXM5A,!1G3[NA!MB,S+XCGDX:W^+_33FM8_KB)4;U\/=:GC?=I
M'H;#3/6YR<(%84_2UI<SRV!>.%!8H6(I?<NT&0]4(3DD??`"P&3O9K$.0^'3
M.B>^N9&PIC^RA^S:&/ET#;#KWNQVNYU_OBS=AC74<1R7KA9UX`$JJ8,Z#_`Q
M^,[F*'97"HF(`AD/02@:9N!6IR[-`H6^PSS6Z,L+9>WX.R,"V.%L,=D336:+
M'8$E^4#FQ*>T05EYMZRO*Y]-%(F/$CNZ@E6\^34LB""W@$[B#WWV^$Z])P`=
M`>[XO!QSO+R+&[L/="@#2C[0XN<Z&?X%KAKY;Z_OKRU@]-,104W_6Q&B<,FH
MG%OJN_46V@GW/6%1I7!!PD@RZS#7P<)+M]Q]6A/9T_Q]I_,(MUJO2]'2S:<,
M0F<'HF6@;^Y$+*F/A>MZW<>LS^;[]Y1==25H/,]&>TA)2D-]PL:ZWH\6]BQA
M8O/Q5CLV2*8!C_,O:Y?OIMIZ&O<^_\W7Y_5K?>N@<VAUG#0_SW%?2<4OL_H2
MGF,)Y$O;%-]):[_.NOXW0+CO9`SX980;DX5CN[CRZ/RU\U1$7"8/Q06*4%`,
M[FSO`HUAO1;3%MG>,`F:)J51#*297Y99[7)AZ!-,<K#!:-5W/+#/<!KT:LW:
M'&3R)$^IVKHA_&S.]\H$A'G>P$RE`4`@40+SXGSN:1@O[W6%`'@[B^C"9L1V
M+V`90(3!I18VA=XY!<]2BIN`N<MU80#=#M!Q(-G"O>2_['JNJY8=Q'<YL.(7
M8.P7V-'6:U_`N"/,BKD,QSQ<K[BHX$GKJ@T=SAW21=#^ITSA,_M'OL`YG**.
MC:T&87BMB<-3>28!U"Y'.I=.[*;+.6ZD\(%(2MA+EJT!JZAICBEF_V2WY1\>
M[VUX=@CH\IX>DB18LZSG):X#\OG\W"!VB;@-YMG2SHN..#)XY0[RB-WU(8-"
MI$F0$KD6$XW-/>!Z3:C058L^+8B]->NF(0SSF*"S&U6L-2BR7)T$5L):(^<0
MM,'^MJ5%O>Z7/@=D^Y2.)'<(6+GXE%(8+-B[%L@U"=:#Y9E![^&Z/1N&F3NF
M1=H,"PFA2IHFJA9R\L1%I94XNT"&0Y-:Q26Z*34OA?7UF/RZDFB'-,[\6\/[
MSX#37TDGKB8IGXD#*J&^F]@CK:$=/-8I#%',```@`$E$053R/N1LW'8UM"-J
M`FNP.V[L"7SL#"F8X-]OU\U^O6<;_IN7J?TN*9T>S-NM2<SM[78KVV)G*W@E
MXU37S6<@@BWC[*'K#`V6N*%.@!]]T9EA),WA9!^VFI/LJPLU!IW`N'=8[]"D
M4A`[UD$&YSEV>K!4$&W@6K%T=FY-)0]VKEW?K4]0$=+7BO;^^/O>,64;1^_6
MCRZ3T[SXWM[>3C#<#[G>]_M!@X3$Q#MGU&=TC-X-PV;.Z7O-F%@*4PF%22=H
M"(_`("=T)8#@=K6U"]MNM^2IH``IA&WP>K#S'F/0T$++TQ74"F`D3^<N\";\
M:FXAQX,\-]UDKL;4\LK<$RL^/**7;VN3`4F?&SM"?CG9FI&?JDA$;'A7+_U\
M'(8ULEAS.O#1:$T1JT5Z(@/?CCZ/UZ_SI:WRU?IN@[D3NR:U."3SP<M-@^*(
M8RA%B.OM\UH0L/55(`GPB?>$#6>,53A-D0BG9P:+,!A-Y3<7B[9D91<TRAQ,
MLF*GQ[GT$+H#,CT_?WNPU=<,(.FG21;X_/B4R:&3[Y<76);M^@JR83U/7`RM
M8[;@KNG.>N4E<1))UG4$G8#J>1N/S[]68-=CT/Z)E47_(^8<LG_Q/H]$UL2(
MJ2P]B=U(YM1-"L)OP/OOAK;`0UCX$H[%J^^_)W6??DY8P#PDJ<#PIX,N+%2&
MNR/&0X88Y;!4C3;'XG]-(E=A"X4?ZW%TLRO525K>)TDKD^G-W0X4:,`G]S//
M)P90+!C6_,6OR-U+BPJ#X>A2W?-$?1P/6)7R6N1J=GN!WL$$==G(5VK1'#[R
MP&2ZD>\G'4M3!S6IT-W29W0"6-W/H;?)E%RML3'@U]&MH4UVK[,OL[L!QPG8
M>[=^\3WL'L#@]C`S\V.=AW8SV'VUW:[ADV%M!G(<&.>KHVOPBM.U'C1;MY1&
M%0>#%N[,C**QTP:"C^<87D$>).'4.KMFBRP9SK-0V>@:T[8;I)9Q``S2?:!B
MJI@8APS?.#END&>MY^;KV.P[%Y]ITM.K0+,+M-&@([H<FUK4/6B7D9T5""0Q
MX.O#JBXV89#3[+*+6Q6Q.I[CKBWHP+*/9;S3FS;X>`+.SH&36=5UN7K'LO]R
MU8]+E(,3DTLQG4/&,><;`(G+'=[7,^:W.+U\S6<R8%L^Y6P%M@8K+2PPEQM.
MLCFCPFZ*8-K%N'<SM#@'E3>DH@LT"AV?QU*!.@RMBJ2%E6$W'@89H3:C:\A2
MZ:,.#6+@-:!7UG4&*3[<L\O/[)"@ZGA!&7KNM#UUNRB>'2OB@`7%HMZW^7-I
M+?70!1K__`UX_[:_=M5+!KMIP?P3H#H/1KFV%;`#L?GO\J3[;@.QF<V[EVBL
MH:LRE&(KG-C_%`<;G"$/^L`CY*Z?1.WM9+-B>S5)02S9>G5<3.-)2;!]Z.7K
MBA+TBO]JH(&`7%&O*?5+``&35B<[%)C%(;\SE`-,Z/+0B9TN"(.Y[ECL@`QP
ML5C-"U](4!$P0#8S=]VLWT`_HW?"`,#.>CWZ[F+;9=%\/N@,:9CO+'B6`\7P
M>FW%]/A@!D?(Q$KQZNL^M>CUS)/?H2TM.W],]XZ6?MIN!=GZQ!1&#RPA3/UY
M5_J;3RLW<<CB[R[3Y)9\8)/<H1H*(I#I1BSQ!`.7[C%;$DR_94V=(B:("@9I
MKY+7<@2K9I6FF9\95ZUS\N2ZI`K=I(LRA\HN;U:GEGB:3]\$`(EMW'6-9[<B
MI)>YHTQG0Z;E+[TS\1Q!VSH972]2*`5`!AO`3H\]==U//_/1M<E%MW:PL@,`
M^!X>W3)*M4,GMI?#$GCH=X*XKJPJFCC1B'O+S!"V`D!/3K20XU";W?<;I3C$
MA+]CLF5URQ38*5&;L0**O7T^,UT+;@_QHA+'':P,XU!@E)5MY4H(;AB>YP%@
M.Y*P#MG`!I`@#K'C&_#^!]G=/RUL>"H8."<I*6^ZO!F^0`5'X^LJU,!J5L1]
M)\L(23N(#%$&TN="[OO#CC&T8804AI5B0Z]9Z6.P^YT6#13,[[7P=8?=:'!@
M3>)+')=,Z,]@!4KR<O:SH4V;<^GC$`0,FTA12)(?H/I>^`J!P)0.L!2"V&"V
MT.)/)=;*'<MC5]@T2%);M/-"[$&/&#(H:S8_NYLU7^>K#[D%8-Z['39"W8;;
M0`C,\&67--F*$4QPV>]TT17Z%;=I%!MK<OPC\6ALC+VOXP()W4"QP5/^0>\Y
M6NM@*<'HHHOKNY.3A04[LFQ/QDSL!.P(LB5?4A2J-<^SWO-$#ZQ**RS6.GYF
M>K3;RG$5T5=SM:!=UA:6K/#GG0X@C0!XD&-X,1G^:-D#I'OAMG35/JE-3^R"
MNF0-O>0*'3G0$W6Q!%Y+GA#C@6>"6L?T1"ZP*ZU15J?64R@!Y)XQ8].$*4$-
ML:]CB''X;I_67[WP8%T+.=,DO/0N@)M;]WQ7(_BB-Y&24`$T+EG+MGJ`4J=+
MHF3DG]WX`9CKWQECKBQBSMI<@'JZ[B!,.\""Q1=2K#,HT9`#391H&-9^OF5*
M302((0F/O+4Y#EJ*=WGN=58#M=^A7.O2.*ARG"ALXZ*7OF?:FXKRS+BC8'>C
M)[G9MZ3AW\O1;MMCM@>D$<9N$\=JUC)IW'B#"!MEKL`*?T/+Z5Q6#$9]E:VN
MF`=F4>KOO5;BC:0PM#-,VLY)&11SXRU/V<;C'`NA&&+[&:>XHH);*97@0<`V
M4KO"6>J(UXP7`Y^^D9S"Y*83^BX;."W0*3XGWE6+E>U@0WTUZ,>E+3[/P<E>
MG>W,:POQ=FY0)#&>DH,B^0>RJ6P6Q6+A/3K.)+K+-8-X]S/Q:&Q:0Q8"S**#
M`10/TT6]Z7`E.-N\)S!I=E/FOO<RH6UU#*R,[38K.AHQSA,:A,&#4"-5S#Q[
MP^KCDB-D(2`(Z7Z)6LNHQ5W,>*_7-.=K-AADRS(.!,LMK&EXMZJ0YG9P6]>.
MY1Y44)1K;;14<MNW82]]YZG_U_"9.(!9M;.SH?\"ZIQZ=2;TM:`'!_G86I*&
MS"%'&6KS>OT=-E:LH[[BO34$I).7+25?V>HF=)(G*(!3/W-V3[\6SU7`#94/
MO=Y;(RE=+J1W>RJSR1)W+??J0O*:7(B9-NB735VU-PI1064;!\A,3]W6-C*`
MT/4+@[.R'H+N(;9@XW"-X00A[*_0211VPJ0,_\[9]V&^WLMCIH&\YF4,-=LP
MRK6EYS-+.=:0*)(=XQJ:F_+`$)@1R9;$'E-PR[\-\'YESNI_'\/KTHQ[V7_V
MT0H;?T`8COB>:_Y=)E9#:^$1D,4S38.%!0_[=TF#*7@@M_#]YVD+!Z6^&20+
M&!Z<^\M#X\K4ZNSH9MUS@I6YRA`$$$.]V$/;%Q%RRWOX-237[#@@K>.A\V4F
M6H,M74#X^1Z'+*@#P(\A'F8<QN8W=7J7[4QK9JV]V>UF$_!*D&38,/K%<(]6
MV3GPUZ5=UII+*[>1ERN@+;;I==^O][M=@VYA\1U6<H.ANMQ*K^M8,/^QV)#"
M\V(4";`M&RQ,KTYIW?5>LJ017+&<P^-@&NJ6X/PF\%`6(J2]H7Q&G,B3JC7I
M&P]I965>6_<XO8T)WN9K((J'FY)/;-%%`&D'+;!GZ/T"'I=\2((9F`TE?CNT
M:7%I:^+S+*`.2OR>3&VSYK=9O,_(X)D^9J4[@"6IEI<[Q`#"H&=MVMN%YX.M
MR)J'EG6'Q5G;DTE=H'*&&0P'CN8J<PH^TS"S=O/IS\W7?%X#M[Q6L-W8==V8
MP*@*(,JZ$%87!@%7*L/1-61VO#RWY%6_X!0?'FW9G(C1'+<P&/(4=5]=77$0
M<[&<6Z:4E],(K6/NX>=GP(0KI<-RF.MO9Z%)WU4[$(%JX\(5&__>&26?]3"Q
M<([UY[@W.C#'NE-03@B$29K=I4^ZO+G/<_-O`[S?8/=E6X6'0/#Y.:YC!&,J
M$:J$JK%X/O`5U6-!`)6/0.ZN]5GH)ARFTT^YW;XSVT\QH-9K"Q;HA*FA6^_+
MR#R$%5MA];U`3H?!NVR48!].*X*`W!-`&(QNG[Z=S`)KNP=AD6*1V@E*;;51
MJ97)#&M;H^9+I[GHE2L'?NWD[^_OUEJS^_UNGY^?9%M&:YB9-6N&%I@KN>:G
M"P*S).=&V@FTQYOD9#[:K4T`<Y`DY'9KUMIM.F_TH]MA;JVMC7JPN6?ZV<WL
MLB9C,'O<[U-;.*0ONO&-[PB)__6+=A/&6%KO181F8$G&>W6R+!/;*'`\:96,
MID^;>U7WHGA6/&P<5L1>J>+`0YL3P3Z.`RN<INJ[(1%%''/;)>`A^&D6>DE-
MF7(Y;PRL5.>(U'H5"KK4<#4:R+)":XB50,5@S]KI1SKN.[3IQ)#:]:8J>@2O
M9'2L.%T/&D=FW"U>,P]PRN<S8<04#N#26O"N[5W7:E?&;7G.0JVSPGTP<%KO
M*E:#:92V4<"$-U<_8%--^714`'1^(?E]%Z1"*J`*5M\U>8P+J9Z<:2VY3;CK
M@+?<X[XZ*G.@.0IQ@Z4[1.K#+&]7N5@QX*FR%,_A-VY21,Q';\JK0(4=ICO'
M++AHH(YM$3HSK(4'<%7P6R+;8M$K)5(*LZD&\8;4@:_/MZ3AWR=H>`'V8RM-
M>(2-\81A577G0X5!T4Z-;^3+BV^3H/N8_=V!\^(%KD:-"30_8G87LKLRW7,H
M,<?R+B#69V@!F^K#6%NH3@IG2P^)/>\7@+M1R``#SJE3',WWH>/L/0PL.)EF
MP#X_[PNLL_42_-Q0PN!7!"6C[7Z_VK+IQ`W0>;N=VMCKG`Q90-).7IO-,73)
M?57];[>W2R^\;K3CZ!<3"V%\QV>(W=AUOL]$*;/WM[>IJ1MZV'$IWM_/S_KX
M^#D'`CV8LILO!X#[_9ZD#!^?GTMS?7TG-CI?U^4<%AK'?!R''?V8S#4$2'9*
M*%L3\M%\RV'SWU*1V$&::]?0&4X-(X:/$\%ZI:V\[FM/_J5!AB"^SKJ6^#5H
MY^UJ65["3\!UE[VL@2RY4!!P:K:)C=9S50V_<E"#>3O9I/E>I\8T#42%_[^>
MP<46<;J:!9]P9ZLQJ`QL'$NG1:&'AM2Z%S++ITXFB)),4]UO8!C)*8&E;'U:
ML05J;`+8Y2,>92^K'>W3P8%G(1+[#]4;\UJ&Y&*AK77I:D@1TH)]ELD:RH7,
M(C**HH:*NI3"&?3=5?K?#!XJV$;^\UG(=W(]4&LYI^<+XC(>;#E#1'>,A?/Y
MP%+*'UF>U011"%ZYY!ACHED$.E!IB+BS@;^!"MB'(T5S73^X4\G[E_BTQ[YR
M-.--*7=#D*%=5NF>!JMF_P:\_TYVU[\(=&7EV"L`9.(`6V9U_QEK:`$%JZ-=
M'.1ALE>8:^S`L(?CK1;-0"\5\;QU2`"T317>,[4%K]?<[W=[>WO+BU@Z+='F
MIF+AV1-V`9/CZ.<&W/4H1N1NKS2E'%H0%S"8`)_>+XG"Y1;`QS/T:;WWDS%M
MM[E`,/O8G`:_+D#W\^?/.:@"D62<$HC/S\\%Y*_SV8_#W-MDA^UB49><867>
MM]8NS]N['?V0>Q)7O[*UP][?W^8P6;_`X.?]L+>W;NUVNS;EGEK3DPTY:::+
M(8[WIK:2W<?Y"K?[Q98?UWD<U_5(8/?ZS-,WBX!G+I`TB2_:3/GV3A0C^=C*
MCVL/#6)::($FU[`'M7<7=JY/;VGVOF7-8!6BDIXN:.NT1[]6.6<19.@DMC#B
M<^"(@RE(S#7TV48>JE34#\NS.#B:,B%<6>(>8L;SZQ:+.*0"PW)/P9<F+P[W
M!W<_!^#<Q%>:@05;[JUDLJ!EG9+:X^R@$'@>,A.9]RJ3T5SN9?1P#S)+;2YZ
M3J.BC#6J'K341L6FQX),I`4R92':5S,/T<W$%KIM.Z*V>;Z$E)C^OZN3UFQ9
M0'K1K5G=1T^Z8*&HC:VYVAPXM&`9Z6LS20`^)YFI_K4BV.9>4.7.>.RZD*^\
M1VF0Z^>$3&5/+:9X^KV,":VBQ:,I$A"^V;#:^PZ>^#=QN_XX.A&/L>X6YSZ3
M2CR'HF-1IP8-=H#9GFJ&\1#LJO61/8:ZF?O="`05Z\,>$-V;BCGGI]_O]T<7
M\QJD@)BI&ZK%8K&7X\^]]ZG?X[;E7*1"GZWZ7D8,%'\G&:SKR%/<X?L/OU/^
M,!0#@,=QV,?'1]*W`J=\XL>/]\GP+NWN1%-FMECBVZU=K&GQE=SM?AQV[WUN
MZ@+*S.SS_GD&?[!UU05J_OCYTW[[[;?%:`EX6:R3S_;?B/GD&VY-;7-\;IS]
M&DS7Y\>']>.VOC^TY79>BWP_8I.PE.=&\>#^#RX<^199(+]X2$L%0]6.J3HQ
MGLOIV"I%,;@G=V)(#)M`L?>0/-:#'1/(0>!R2^G,)$6OWN'=BB#)*'34E"KH
MK<4&F&H-J;O`-FQRFIH7LJ/-AF[1<B_(F;KJLF/!G*PDG0HXAAPL#\#2Y+H;
M13^[ZD9E4"W?FT#L$%6Z7GW6>4C1#07>HG,R-*"N]GF>&/+S&;Q-[>QE%4A#
MOG,0UWI)>B3P!R-`9<G59NXCQ!J#[1=CLJ*W*7GK/8!J&N/U:5-X77%IYU,*
MWF3R@XQH#G>9!-Q$*TM-7%Q?9A2_'4%LHPHZT_15S#"66*]#SB%W:V@8K2IP
MN,CPM:9UH^2W.=A&<TBCH^$K<&489XSB[QOP_ML8WJ^\X!77V/T,+K[R064R
MUC9(J5B3/$V<[PZ"-?-X)-F@U-3D0N%5!?C$(NE1P`=>O%[7Y]YNM\EX]"NU
MZ]$YQS7UVSL$I%F`"VZNUDVHA^Q43I(C?6$((%GE#-SB]]:V-\_]?K?;K5F'
MG<SMY3R`P*K=;C=S=_OX_"#]ZKJ!YO#$!?3OATNZ&AOS?GQ\GK*2$F!>W[?C
M2DL[$@`_CL/^^.-?R@P/OU(Q6;<);*II_20U<VUGLEO"T7&%6O32*JMZ<B.X
M1/EOV2$A@LRH.14#KR`=0M=84I=A&L^>G=.'M0*K!6J')>_-5&!B`S0C:'>6
M3;"^$3,S20NB<Z/K,DWNPG[WZWZOG#C8[Y;UAFL01XOV*4]HMMA2EN>D>%^G
M@;DQ!!H8N!"%.EGG3BX3VF(H+H4.C+$952#XA66#N6A8,-CZP?JCIS;_:.O+
MY'U@0FTXHVS65&8?^VR<(!,ZEUWA/"]QO:4]R"]@<S#P`\DG9I*86E]-KA<:
MN^VN<HAE)>;I'AG`K+%%6O.2*9[W)#/'=/_VN2]0C._0-),V9G:#Z)Z+T>6<
M\%C=/W$X4Z/("62&3A%WP:0X\&)>YCKVD1ZYW!!=TM\J1YYY,AM90*;"1-U^
MF&B$$NORZQOP_ML87CQF,+^&AU^*"'[AR+9Z@Y??,[1,++04(^`D:\N](@*/
M0;Z9;<\G$HN%&K'OV-^$SO4@>S_;YE/3VKK=/^_&D_L10"FPPZ;HL*)-EG^]
MO;V=^MO/>WH_3O*I(C-YZ*3Y2GUCFR&G@9:?/S\OQX6^.6]^#;9=/K=@<V]N
M<>OT/-LQ#9:F1[WX[CI?6LS/2W];=5)85VSAODS)5K%P"BR4,(:AU3C:I_>C
M+TWX]).&=N@HL$6'3CSYL1KEONN4-S0B]OK99D%J`)--/)U;5Q>6`1B-Y"-C
M"`:2X.9J<<>,5BA*MP6@:8B#:,Q=/:,1>Y&^XJ4GC@B%`3LD1#_BY=2DK6S^
M$`_ZT!YL`->Y#T6,N0@SV=^8"US66H,8R_BX=TJHZ@,(1F`2GI&RB*!A(E<"
MC_Y[@7!?5:H,7'H(!GD$3#;/[LX_N56>[=>%Z&05-L!\/T"'2:XY1FG"&'*"
M(*T>-@YGX._9>1_:3Y^8:A;<XIO;+T:6W`\<%#,!K.^S(GY.S^^XXW;,ECHG
M/=Z\"1B>;]N,Y#EJF.PQR=`VNF-C&R\7B\)2JD'%S)*U0&*2/?@3\^,Z9%[#
M+E`U\6[-R*6#"N:IJT84S/MI1L'9':[,NQ<XHL6N#)1M_@:\_V&&]ZM@5<VJ
M_$^]WWS^_R(07B%?%"@3"3UH]?WL*$J;(WLAJ#D85-?M6P7S4:L\!I.6%1*!
MAPV>93V:>>Q2KXWT]G:SYLT^/C[40W31NZ=-4!'1JQ_)BZ!IVIC3SUS:P0X&
M6PMD'5,+',WOKY]W,S2?4;H]=`&520_M6&(UHC'\'#_PH+_R!>C[<:0$*K",
MP6Q:IIDDS/W_['W9EB/)K23@$5RR6IK__\Y1=V62C'#,@V^&Q8-D5;?NS)GL
M>_I*JLHD8W4W&`QF0>N9M1;,,G]VDKY?+0#5V)H4$Z;2!YBB(LT6AF!'U9@,
M!!C"UDV@M6LU^R83[VHY>G^MU1:<A]1.938592^:T,0P8GD1//=-/0]`1]8&
M*KO0$W1?R(1:9Z'4;!5S87(SCL6V5K5HQE.`6FP:V#*XI9TOV(W*CR%117=U
ML&NCEI,*\,CH;*">L6$IH*S/1&@WX,5*G=HU;>SBWF0@8A6>0EF:/I_[D&S_
MKNK,HGUK:W`&$R4I5F4:7.GS:9K\]AQ;ZS`+LB2<RS#6<#*<)-!1`L.*Q!I4
M\XPP00<'40.1:#W8W_0,H,JIU^J[(:Q8X52UV(F0787E%43SB;0?;<[:*4/)
MW)3E@N[T!!F-_<+@L1%JCEV$T_#C9DW1UBTHJ?V14?Z`99&TG)_D%B`6`@"N
M?;S)`%0RC2TVD8%]X)7\!HS1U4HQ4PL=_DY:^^^!W5_U)8YUL.^SP\SIJ8?M
M$U(W8*AP_9]Y]TZ`;M0*,5CI)?E&T":VK?WX5_B8\:4CV4!P?FKP0B]0*54'
M!&!]4DJTI&6T+W-6UBIHH20'>@QK\J\C)D6WLZ4,JKCG0X\0.Y8491B#==7/
MP[R%.6_Y,[!XPQW-M-X2TWW;ZD#36,1S!;36W%Y5_X$V;-:%<790_0>?Y\(+
M!2R>$?!.OQL&5VR<+#(S(CSM)O7U!9*>$D,RFY4CA%TH]BU+,_E.=O-OSUK[
MZ\Q*"]TC>0$HM59\1ELE?(_R`+G-O[2YG'#K2/36+KLB`:D?L;QN)N<[[&0E
MH$W6PU[(Q@Z1=F/#.(@&9O)%;Z@U`+F`[FK-NUOMSW<:PZV6B<W*U<%V'NR0
MG)Y@["R=:KV#IZO1A*([@=:9LQIB:LX>S:4E0\&&Q9&HXE>4SZT>]@JL('N`
M!"MO^0:VU``=:1<$YN&Z(2%W@L60#08ARHS%CVBW`_2WY=%UX$1J8+,/`:;A
M#-/#0M0Y&;*&6=OU$:G44#%Z+N:C/=V$19E.BK?.9+?>)8*!<2,5P@=9=0_`
M6UFUB`D+T@'*21$E8FM1=2K?MF3_32#\NMC@\/?D5[Z3V5G<RHN?A[HFF3*C
MT?$+S6,UY(AD'<?XK$J0-ZZH_'KQ$9TW!^`:;6N<N7;5I#7[L+SO)(O06AT(
M2+*1@@R63`+;(B:>WZ_)-=WSW@?(T!Y(V#C_X#-B/'?'0)(!QB&S$EQ'8[ZA
M6NC6\8G:0.'0S.B4'=)^DB1Q@1-8#T6F7=X!(]*I!EXHV"ZD@XW`LJO8&9&#
M]T_IY2C\[ZK%3J(`,N-&;:E[1DWC&(:QGX'2B-[8;6R>8)'"A\6E+H+$L/P:
MQ&-G93@KB'(5404*D],?NV)%Z<EYKKLFWS/M<@?1[@`VE<X5>!!-CL-Q"("R
M2DT[6B9!$F7BHK&'(E*`0%U:BJ68""UI`7:[W?6L])L2#$Z*ZL:)]@0F/^#7
M0"W#D&]/VZI%/K%+].U$039%H'E<APS$='ST]8B[,/;O$!"J_B2+BN:-.R?2
MH[L9>_7@5<P)Y!HJ^MW8$2K_6!IDB+?05=U:9IV-AL4_*4_A%O)BDUB]+EV`
M=7+.+ZEV%$Q7;I`GY0IVC3US^#X-!8/4>XZ)A*13Z+%;B?,-(EK/3OKWQ-0T
MWX#WOP!T^0E@DU_]X!=`]`!G,*'^QL='.MGG:-TOC*ZRXY@!-EVYY\W9@[^:
MQ+RK7\.78E30XC_#X%MA$_C!@7-#GW@M7D?.7*I[A<H4[*@DMV"8R)*_/&4P
MBPZV,T[93.0+F;::OY9M\TI]*E?")UU>Z'P4B[1$N>IA+=#U;/T\5(5IR$V8
MFX?NF/)V9OC,3]_/Z!E@9O\\"JL6H9I6M]PXP\\SE7ZQ,,3&^O;<:"D*;!"L
MNR/&O@^U<[HB'=/TZ#F-+*/`AN+\:T$*PR"?T9NQMM92Q438,?*/6S1@AJ$9
M:EB+Q\0KAGFH]\=&GRHC^RI!$(&-WW:OM(0)-<PXO:[LWGJ'(@WVS;GW8.\V
MJ;CD!BQPZ)7`ABGJ4""QT4YC!_LSKD7O8&_M&D;*DU>9^#LLCCIS5JPZ=L-R
M!N!D"O9LWN$"D).R=+3OJ@.+$VUS@H%%IUM5OL8XRLFN*^"BL"D&GZHS(%[*
MP7V&`BK^9HU':"M'PSF$(.C!@/P^W$AC6$ZL9SRA?S01R2@@0[M+]U2*UDX3
M2H;8V3'JC=4/E27H8F`'+KJ'/)%;::"LV5L%\E7Q-IZ_]`U)_]E_IGCLMZ/H
MY(58"QW'*R)O?Z^V(XE#)6)MJ83RAM;.89H;@/;<!C[B6)]]=TSI3ET@9')5
M.?A(3,7A^"`46!4(C;!_=LAT"^W&G0`GV$V331WFT92T<P0(V%V+A=I!Y9S5
M."\.8?06Z(&L9T@'TQB,".\;9JFK3&;UD'!B8']:E'+JD<+DKIP^*39R!OM8
M#B!DZ`-UU+JMBAOD8&A!&@"(J;4_;2M8E!;3&N:W27Y\6"!!KKD>,,&_3%1;
MI\*#D>J;G_I9V%A`=\Z)]>:?]'T3>^Z&33\:>`K+9;&R)!XL7+-0ZN\&0_I7
ME`3&YMVH)Y=J2`5!6AYTM#)XK*)<M'UN2B,ICQ/W"?G<+:%$,7B-:45&,XL>
M#E(%`SR/+J;:^=R%@7D#(/60AJS7'X)!N@JX>P=(:2M['P`8\M9=&&LZODMB
M_P_CV>U.QMI!R`WWX8"J"<#(""PG^F"[MK+Q@(TZ1+W0R7[_E*..J'A)73]_
MF1,<7>)4UZYA<:E#A7H7D731B=:5&>P!;7%D?=_=[FE_GKR_+R<.KZUV)QIM
M.SWW0-7)Y^!:!-W!IQ@*YR'LH,VWAO=O9G/?T<<>#"&]PA._A5N%7@2[4)5A
M)1UI&VVU2Q0.K+D%*&KQJN`%#K7&,MT5HS(`1SOIZ2*E&=K7KP]'_30``"``
M241!5&T/\)C@8VL^KQAFUEZ>L_)EK^EH[MF"*,O3>J+'_>XZWO9BA;I5:_Q]
MZ%E,.GG-3/1KH'K\)*=NVQ27A\KI@BWSSB[!:&RR[,SK)>J;=Y8H<)/H"8-"
M.3>F1F_DE,DQ9*EW#44;]JMQ>?->@>::32M!#6$`PSE^3((`!#:L_-@466<)
MJ[&7[M8A09(6Z_09RR`YJT++"-EH;,NZ3H$#M,VS9K`;JS584_!:-FV9/D37
M6$%;T#1=*_/\@67]CJ1D`A-(AZ:PD0:@UV_SY<ZJ8R-J\"T,MC$2`UNLJ8A;
M4^HIQK0&)K!EC]OJ;P9H)1`A(V-("L3J:]BZ0=DXO[`))M!M>/@9?,\3=VVK
M7:#23$X27!\-3/6EQ5<M,<PGL#DV=(Q@#L:ON<<VV_U0L9C6]<BTU*)TM[EC
M1M70VTY1(#O1O\\!Z<0^'I@]B<NFJU`.W;09.M.A6ZQ=XB+BKE^XAUC)#P62
M!P"W6J?=FR;?__P_@J;?8F656YC("WRP[8WK.,40"K*#MV2=%X0P,E9\C*Q)
M&9NX_T[!KCBNC7M4)]/SCTHIT;HN(9CU]*0!SS(TG*R).\+I5_Q$)!`3\R'"
M5D$3''/[B<OQE\2Q(':Z,EGKNM+E?%8?[@V_X^=DM(`+XWR_W=4F.;MRO7V6
MDAJN&FQO`C9'3$M?LY!SQGT\!.?3B3X^KG0^G^EZO:KV'0/HY!HE[1E=V^[3
M&V'B(L-@9M=]4+04)V(N#'9B#U#'=1TL'IOB$*UTRE_J_RXUSI=)^_8@0]L&
MNKK;165IL2^HBZ[F6I#@V@_)2-^(&K"OW]>&MCCLUK#;Z(O%'[M.3F-4V8`4
M,G9>VA9)'!N.H"<;?^9G;+-(D-(HNKA2:Q9*+DSKO-_8/JY?/B2!QS!#>W<$
M,@L\#Y$VW%]?_7>PUJ#7JAWX<JRWN'>W=SB2D:RPV5MX#+KU"?_!-18M<=!U
M<VN.D'LOL5CBH%C!XC]:W^G)<XG7S2C(M%9<K-N,J"4(?9#UH7AW#?T^L6OS
M,_,A053^,Q]BA'3446&?]!8%0)#,W&CFG41FW:T@,=_!("VROL[!M9X=&T^M
M'X/WHS5TOI'D?QV/$KT`Q-R0F'D1^(6/%6A7O<H.]U:$#4L(DL7B8353KT(;
MJ@0R9/>O>VE$3R_Y%#8/N*.7SOYMV`')4D'C:BQ/2/O_J8_C&']Q7`W82,W"
M!J8.4L?T.5YZ,T&O]@*&UF!AAI9U&94T;&:<F)8TSD^=BJ&$#=\Y;3.C;V6[
M8NVS[>">&X9H+58I(18-0*)\04D9FH<P>`8SDXX9;?Z,*=&ZGNARN<0`QMQ'
MALH?V0X$>PI$HNM&2N;9L@WU<2\0)#:@5P!L)DR_$#6U3/WG"%KPC!0EXX0=
M=XF#`FA]>@8MBD1=3[U1^2JO'7\##XF3LVY#^8@N-+BSV0U(XW,@L!LQ%A1&
M8Z&N:[5_8LL*DM;N]F&WH%6+K6*UGL&$;B21;JQ=SN(`HY9O)-45L]?;#E^-
M`!8F=#Z)PDV0A12U9O!A:QJ+U!)W+OY=!7"@`1ZVC(V%&+/IT+&75D4A)(%[
MA6)Z@W0PKP?7Z6Y6`]KVESSK^C@&&.^/J-0Q79R;8U;QQ:(`M&9@)]I9UFX_
M6%!A,:6?AR@-D572(>J3V0Z;VB&Z"3`F9O5,,^B?27FADRL8<)]UQ!LKA=]+
MA:CH_S<&`QGL$MO^9Z1NUL/\^Y_?^&=63,D3,O4HQEY!VV<M_H._>UTY1V&4
MI%"@;3UL_XOA#`$(M)=8]'\/_U4-/\.LADX31C]H:.#(J+JD@6U%&G`ZT;*D
M:N'6V+"YS=H1;\Y<K<A2LJ:%)4&&J#HF<`&KB=M>IQ@XG]&&5F1%R[;M&RUI
MH65=H85&/2R#:P(2*6#"@59+YNU4\C9)7*_1:#&6YR<!HZLV%6C][?M.0D*G
MTXG2DIRFM'R&\8:$A1N%E6A]U8YMJT$5%HBX#=<^0PQZ6VG?ELJ_G"@M/!9^
M*_D`\#F`1%*,BXC6(>-P5VO1E^GZ5+62-4(4D]D,B&O/:GMNH1(9FP&/WR7F
M<+6Q/M78.E:2$J:@0!G/&QV\,;V@@&*&3$&1R18T[3H"&\W'G04BJZ./V2]F
M;R0M!I`[T%F+GAG;(0+M?6:]7O6B.A$.`#*Q9L;Z"295B![KH`6LU0Q8A=_#
M]Q-M`#$V'24CN46(HT^R\](-&-/^7NIUM,<O!_'6*DB&/+A.M6BR?RXY*UE-
M-I[`S1=;`B#5W$#09WM8Z/FB.?Q^$A=O&S\>XYVQ$@O[;G(@8>`#QK=W[GK%
M@H2):(:V^W]G\[[XM1ZO<19Q'N51T9`E^!FPK^@22R-/."I,O(VB(=4,R89_
MWC3-WQK>OXWA?1J#\-[GS8"HO/I[<0M<#GCAF6-`L]121W7DCA`QO6\<[[,_
M9]OJDMEW'UQ3V#$;"["DI;*.U'5V#53:2E]H(MX%AN)T6KON==LW2,TI+^#V
M**EFJ<;USIXK9O19)9/41?1X;/WX$]@!49U\WO>]_*O8=*W==*6*!3_D9:+8
MQF,^9M.1K6C?>;O=:%W6GB8W[H=`.WJX7_06O=%O,SRG5,'TWI]97X@(##8H
M4W_TC)_I8<2D#-5C2CKGR0`4KHX<3=O)+@Z8,=6,T?Q>C(1"^ZTV<).@D.'`
M6JII@06TD>AL,3Z[`+7.8*N6^AAXZ@!^=GW5AMV.35MO)4IJ((^E64%19V,$
M?'W1)4.BYQ=3S\RY=S#@)NZ-7ZNSI=&A#?X]&?*#7+M%RFL<V]@8.`#.(NB.
M,>HC#M9^G5B6JQ^V_FOK36HFWOMSR(ZX8-#)]FL;^/9BU'!C[I3[1<3P'>T\
M1H_?UH!H2<R2BR[81-,.5EA,&YW#W0A9Z4@3BT-G4>KM40&BF/[ZSBBWE0YZ
M]7O3[>F"8TR!#AD+F.&-/E;8,506D!K6P0*UM/(L"*H=G[@UB7&-,>\*V[;P
MQ(A'PCW0ON>&*<9N4]P7_K8E^Q^5,[P$BDWI2VSR$U_Y?'D!),,"[$IN[4$8
MRR8<QZ4!LG&_>38<-DT$UOM(>##*<]2L=%IKK#>\P@AL1#OY$`:3'1Q>4_-^
MY2ST>&R=(;%#2VUQVK:=>-^=O9@:+A7C:0QYYVVQV1X;$>\Z$4ZT9"3#<``!
M8,)VW.S9T"UT%_=P^%*(NZ<E!8N("KN>O;65.&"?U8!+WQ"[7W.Q7>/[O5YO
MD.4$;)0VUP`@SNAE#-I`PX(PPW!&NWZL-S33*P=7!JH):I%#.AC6DX_(C$(P
MQGO;``L%@QUF@$Z`_14`Q2G5@H-4Z$8'/C"$D[-,NQL<&%CUUFA*-3JW`OTJ
M$2@XIH*H7MRFYNQ5P3BT56%(*\'&3<SSS9+T\!86;(,1'.=80"B'K6<R6N)D
M?'6=?AGTT(UQ8D;)1!P7FS,ZEIB<NPD.L)\7=1Q&=UC&.M7N#ZP7X]G-CF7$
MZQ:&7^":@P#5%)0:O[#J,@VO5NX%!?J4XS5E$YC`6H_B<1#<HVR94O7N6?D2
MF\)/]_MZ$B#(2$A:HAH^E[B6EH(I0\PWREY0&J>BH864)9I:@GM!I;V3=;`#
MJV[`\$X>!6]6NFR<$X)XZOJN^&13T5(A>!<B#W<*(N35WOFD>RTJS$>36]^`
M]Y^4.1R!NE])D.#G/_8T3C0\SKE_*O&OI\0=`<)7"@`YNJ#\[,0\JIY98+H6
M/EH1!9_+?/"5`"2;PP*1&6I#!D"&.[(+85#'+13:WO;)<#)60Q04+S6J=G)?
MG,&X+8B,9(2.$N`DMI(3TSYELK&CVHS`M0WK[R9(*D+PL>^[ES$XYH8]YS%N
M"(!?D^861>@R.T8!-T3&"6X>N=.L&/+J/TIV*%H;OY=]0EP+43-:8]`LBS>>
MQAAB)HR*C4SD85_OK%X*F2\=.L"F8-'GTP$T@)Z$N#_1P0`<NXG^I!A:5J#)
ML9+&_DML`8=>N@P1X5`DIGJO/)CVH21*CPT..`48S!,<NTY8/;=RV%'$XH=#
M`,#>ASQ(X+/^L)APH)9?\"=6$B.CZVS%>W%LR,8*,9``P"N;P`-8V7+5^YNZ
M?W!6]Z@_URUBW"8:-J"'T>0M%`0D#EI2T)PURKO<GK0]9R4-P=1%>WWV#&QM
M7]/;^R_PS(@O@(S.M]V[C%T[GMUS=-,9&MP<,-^Z2"%+7XWH]"S&QI"5.<-8
MSUB1*D6N)6J]:]>6>0Z6<`!3.8X81KP=2L94SGH-O@'OW\/QOOZG\@(8_@TZ
M60[0[S%P%1]ETSXGA=,%TS0MGJ#P5T`^/P/N_'HJG>MGB/S&W400>7Q_(BPN
MP2^S>R;80021J`7D!\&8M"T1B?C:8&;596&<*03XK4).#IG>OB$(A>U#(E+&
M\.%S):3.$<$?#B,UEBI:1>VD/]G0!!/F8$_)6D@5P_P\!@.MK18Y1QT-$%NR
MF;'PL5/WX7.L)J*M=9MF7V9)='I89[QD&9ZI+HM`8!1H"T<0DI4>(.#G$8#"
MI(($^L`7LI.IB!P&D`&M)P_IA-5.II2Z1C.BAEH+UPX,QDNM@&1#ZO'H2/`F
M5VK?ER4[ZRT2(1RP5^QF[>`UL&L96I3^N&Y8ETZ8QZ.%7VB"7[7)1YQS!7!J
M'>'8'<%VWMJQ9JT?MA/]S9]X,79I[=ZWISV/JDR=(Q9APD0L'*;#]7<5^D2B
M4\-'02HR*=RD`V$,3>!.'(KNP+:B&2EXR6KF>P\T']S\S570A(0#E_U:,),Q
MXNSO$X)N'<8@/A`'U^(\[A&3OA;(@&<BG>K(@[S`7F%6MHK>$Y@"!Y((@H1K
MGMD7,A1$73YFBJAOP/L_!(^?N2S(!$S)P=""DY^](WV0":!FWQJ;L\G!D?-4
M?7`(,N7@'%4T]ZOQPM,P!(XUSA+?K\.B@0\898G)^C'92ZX.5W9D/+N^K.R6
M[*)(`=BE`Z9?5/X[Q\RZC=PUH0DSMIZ)#SV'5<PNBPG8\-?*@D8"0*`87F>@
M3TK.,,9YQ>D5D34I<:GXYWHCYJ3!1A;I#7@B<8LW&]#`D$[$/?)9&ZFS'3PQ
M[*YBZX0!#++^'+AGJ4L*6`.`YMT+C$\!<$F!5$O-,3#(0Z=*76J1:&A1K+<J
M*W90(+)5#]NX=G3.?9!L!`N0`G+XF3GG<#42G+87/=1E05$#O4V^@.UU5XR%
M]7<+&6!G@<80JL'@>H`,7&-`,TSR8W&O$O/J?V8[*!46/R!(Z<\#KBGZGB$+
MW%O:AI%+`-]23RV18'D68^TU'I[^KD.;OOTU^OVFE&+?=O*M?;LF<P3H#9&A
MG9+\GCS<"_(T8(GMHLI0."[H<$.:]0TZ*FJ=2Q1JD76GB9[J`MA^AQ"M"P<=
M$U&A'U:ZPL"V)M-9:^O[FI:Z#F2=Q&8^D\RYV$Y7,I6LLBRKS\TWX/V_BA.>
M`"7'U!K&X$7$?,CN,D];9-J3D:89[V)!M]E/K(?U,RV.X584`#F2T,I+5"R%
MU]!X5_O%@=Y,SWMVHY%1LL#;NGBP>/398DL#"4&4_'4$_F?N#!.##HQ@FYZV
M:K'*G!&V["XY,CMX<$Q@@)*,F/Q//_PUF`!2C%T<D(P^C]TKE;FSA_VCC6T@
MRBXZ<VS=1Q1CW"0S+=U"P/5AG-*(8@4-78Z8Y7'!VN"5VB0`:)+!^!%;SYPZ
M;=;\!K)J,0ILKKY#P.2-[*F#\<$_*J`KJ,7T!O5V:*H\<QP4%FT=RP[TM:$S
M9*:YM[RY^]!:IVNT2TM&/ZK9;F/FBQ(D,;K@)BG`2&Q;R"*H50-#0B9J:CQC
MC*PN#!Z;X(`>`1O\G6U;8;!!OX\@+8C6V2Q#$J`)`'8^RPS%IE+<"^E.0'_V
M4B@'&->&U)!3#WB`()Q(SA`5!3A0_#3=K0VVLI=[-1BX+`M=+E<ZG59=R/O)
M1`?V(LLW/J!G9AA":>\C4K5>P\>^T9(2W>]W)=W;MXTRLQD.I,!K=ZP5U\N%
M3N<S?=V^Z'%_Z%F5YG17)LF)@@3`8&H'SEW/IGP#WO\FH)5W?N\@'HSAEEJ-
MC4P(SB/(5Q<@M)T9#$*:`FHF.Y<.[4:.$3=3%(YP1)G&%\&&L7$$X.6).P5:
M'Y!/1;-9`4^QZPO,K[5W.OPPGX-,O=^$&I$)@$T!2_&6%IO]`$E<C4T,R[%=
M%9V_2B"JD:442&*`V=7S+GJ@RNJCU886E&:*101@*G;(H[?YLF.DFIZS*\50
M5A*QWI([8$4O3.6IZ^Z##&<'TXZO?7O]K+%_#:P[A4JK(PH2^"S8)Q45BT-4
M#-IU=(Q0&E>!UKJR<D+]L(3->I$\+=:0Q1%S<WS3RCJM(.`>NEIJ;?+V;+%U
M@X!G64JA1'VHKMKJ(6.,PU^-%:W>:ZTK(#)D,4-/#$5M!_!"2M+$''H;I]XA
M`/`FK%1KC,\=Z^-M;*UR;``$S"E-/(*UO$!I9/&=ZM(5"?<C!5U:%Z"#V:2!
M/8&^5T3IMVW(`]I7B95*$#EV,0*Z=I&T?YZPW=X+M.'+[(88$]/Y5/S#E66<
M"9]0`23FVEMFE*KCB9WK2/5:MD'?'@01048FYW7?W]R<:2>BQ^-1`"\#.V%#
M:D0SK9:%S50L.A_W1Y73Z'>;I8TM#VNZ[KW>M+]FXQ;\60#VWX#W_]I_F$(/
M!)<5+;]&(_NY^2A7@G+>C:[H\.C\M+],6+\0I/F:?^8>\/3:S:IB.P%L66=Y
M_>X\!<&-U7O'-)DB8,R>[C<M+L>\!JS$D4W7C/Q5U399ZGMBY`ZMT+B=RY[=
M9<LPD+)-MU9LT48V*P#BQ![4>T4:(.[L&VXE_9X"9\%Z[EF#?LOTV7(!!B2%
MQ_,BE)TT27=09!0`65=EN8,)[L-"8T!D.!W(Q-@?W[L^PI=8>W(V@,$<)!`&
M(&B@/!<X@/Z?ZM'EL;%CBQT'5KK#MP7L@9-`MU6#UGC7%(INLZ)EG9HJ5_<#
M"@@&4./.D4E2Q98C6V(`$[7>:=#77&<&ZX_#;LB\PW!ABR]63)^1:BAGC]3O
M35I2#Q^2P%FFVX9%$C?+FD>L&X-#BHB./)X4?'DO,@4R`![;Y\ZS7@ZD>)/U
M)B"P5<?$=3HG:XPHYPIR*Q@F'*[+2I?KA<ZGLQL;4#(<.)YL6OL,;+\PT^/Q
M(,F93N<3219Z/![$-6V3;*0S,ODPV&JK7]NQ.U\N8\AOWS46:<?+3.S6F'@3
M['[<AE(6($[Z]6#=S3NR1^Q1Z?7#OP'O[S*Y(G_?9^%_<WZG1U7PK[@H\/-C
MZ;JR_/+Q\W/<'EPS:X`:>P=:XN[I]T>#$R:^5B<4!4D@,H?E00JFWP"$7G"4
M,'_!T6@;!#H:=P9YYH=\\(R&8-<,QX4N$4_>@;"9Q@=,B6LUDK)>BQXNW/@D
M9W^:UI:)C"F^F'Z=2Y%@S0891XOA.H#>IQJEBDAPW)C.5)DXAI]M:H8.J"+O
M*89;)-UR:D@OQLULB[Y(Q*J32EX2.]5#I(L)\H5V?Q\8DH_`"S;7@1RWX74)
M@G&BX,&L*]:P"%M+(1X\!SKQ2Q?-X_(E4P`E2DQ=EM$8.ARN:4QD;$V&EE$C
MPAH/@4UCICV+W5.6?+A%.XX,KA&V9=VMP@B-%#@H[DAM^J2Z"WI]%[10Q/=H
M<JTY*C`"]C<B']HQ<60CQ\/SN15;;,,KQ+.O;`H-#M9\!UIGS14$6Q.RH/UG
MBKI9S&X_:-<L<:+UM-+U<J5E6<82YYCV84F9]YWV;:?']JAL;:J!0TO122\+
M/1X/^OG77T1$='_<2;+0OF\EA7)9NS]\"XE):=&N$82V91RNZ7C>'Q\?],5,
MC_O==0:CKO1LP*A=PVP*RG!OS;G;.N(PW9"4B7-C:97F-^#]3;`[JR*/B,>7
M.-W`6/\E>[!`QO"4'XV<OR>V4K$7KI!1_[B+$:A/_0S^&R`^'%:G7W2^B*CH
M`^WN='VT]^K-X4&[R$09:.X0)X#<>BN^]/TPK%:`4]:PAFGJ7/!2X1.!U<!_
M4\5SRCA_Y''4QML&U:QFU+58M3F_EFP$0R"!T)S!.8.5'E=B=ISUXZU8>>A2
M9]#3ZK:ZC.X*3EO38"S'8)@!B+UAJ-N4JK/!&CRIYR\/$*PW.NK@M(72L(L;
M%N4#&BTOZ.&*`1@Y&\]:8.XM,)_I*P<Q(&"7Q$I.T9ZG-HB(X+-]=PF@P4'!
MY`H`ZU!AG_LLVDJ+0`XSNB\"SS?J#[7WLUJ>6V'$OENC@B5X%$:CQ4O='LVE
M7O6"(ZO(Z*A#IV8G<$@N`'FXR(1[)VI2@1%6[Y.W`G?#51;(^SI%E#XT?G8T
M\!6*?9)[A'$PB.J-7@H;N2PK?7Q\T&E=PZXJ_F[.0OO^H&W;Z'Z_CV0X&DEY
M!?@F6D\GNMUN-<&3*-_AW<^9'OE!1$+W^[V"72Z`MPZKKNO:)19+6L80;RO^
MS?HO(K2N*ZW+0@\*'*+@`B>0'6&'3&AXKDNPT0KKM9P/`CA4-X)%%9?M^_YF
MP/NW.+;^/_//O#7_2XCK\.??&G*;[]<T%1($[-8AO3E!,S*Q-^##\YD))(Z*
MC2?7P?@3Q3&P<S_RZ/KSY/3#B=DG-T#D&!%:/2*39HGBV\!O=QTL?AUFW8$6
M-H+B42L[:#&]8DV"+4Y['6<DN1I,>>OE#<Z1,:*2_;VJ4@.V0`6`;T(6TUZ;
MWD/6,H`V\5[PIK;6(4BO2BX0)1NK-LM&6TF%5`LN#9J=KM9N]M'P#VE#^)QW
M=:,0M`B<-YKN8YH6^B.WO3*3Q.]88$P_&S)"%G*8]9,+@E#Z&^-T@0^(!CIZ
MP*<_"YB(F.,T+@N^5=&G@F+\$)',AQ<T&`L2Z<:@(_5BBJUFW6IP63M/V!=?
M3.+%+'+6_9D"YM+E&*+TR>/]T%N+]."0>>>(2<_`FID.9F]'."9]QT#@A`BV
M?KE=NQX0'VU`]'0^T\?'!RU+.MS0MWVG^_U.V_;HWN(J`KD/598_;WK:;*-X
M@Z2\$AI3$O=PX*P=/S/3^7RFTWJB95EJ(`9T3.S@Z[)06I8>^#,\JDFYHC!$
ME*NDP3ZTMY:$S)P5^V^CDZ.MQ.J=<=@#I25_,^#]_P?LOGU97J@%(K#T2E[#
MT4>_TDV/#/I#(<$LZ0Q^8#:4=008HS_A)W_ZDJTNOO`3M[3&E+"P;]L?V8S!
MG[!Q"6!;-T#;N$=XOG3\GD.W\_>>B;`I8L</$+,^6;&_&UEMA,#7,S9A'+'S
MNS22!6?U$4RZ!UZ;1YIW#038<^K,P`;69\$.43'W:D/94C5=;/][&]>+@1F%
MLLB",VI"G)J9NM;7<;4^Z[GT79=9QI+Z=53Z5^M:T"F>_G=*OSBQ33G2*:+Q
MO-Y0]$"5X,8CHD%(LRE"WU`1`.X\K*?(!!T<_&,C:1V`4LS22+?"9UZEAU4?
MWQ"L@O71F/^2KH%EYBKS`!<'(7TO3<=7\/C%6"8>L%SZ?K'KNXG$H141::.C
MJ4F]&PGBD&=#P:4X(Q,",4`5VJWAERK'"3)C`^8Q11`GX@,7HG,KMH([O/<:
M&&.Q)<ISF=0S2%URH0>T+/&!H35I6>ARN=#']=JO04_:(VVO]W@\Z':_T;9M
MB@UW,POP#&2X=E9#;=<]YO&<(C[<]]S__O/SD^[I3I?+A99E(5Y7)=M!QOMT
M.A$S=Q9ZWW=@Z(5L($:359S.9\I[IG5=BL1C7>GQN..D7UC(,OGTM8AU[T4?
MB+:_)0V_@V/?F7!Z(7`BT@#P6\X.<YS]-*S!F$/SP9<=F9W,ON!HR&L6JVU=
M(&AFFW5T30_:^C8%1]YRN)#XF'@*1SOG\O8,'F&A\8P)%PVT7V!:_?"CBA<S
MH0\".D`/8I5%F!S?H+X0VVN-=@RHI(C[A,&$?V1L,C,X!YLF\MZ_6D@OW0NW
MEQ8R!)HMU4>#Y79RS8ET:'?5IJMD""/R5R!Z+L/`G&`P!9NA,Z6Y+"8..>LA
M%4XFJOJ5+I*9P&?3L6ALG+ILRNI$#^`H=:226"3,E(W7&[B\%GBK8Q13D)'7
MRO9P"*<!)<*P"?3D;<^HX/-NW#?0%K"'9`2*(&5G9W35#7@YO_!`TN'!@3GF
M27<'I_]5D>BZ9*S7H"[)J=/R><AR]-./ZV0,O%-*YIY(_W.QG3ACQ8SQT,B2
M8]0M.K)H%PR[#^IAXZAM7GR'L[(,.Y0V5NNMZ\<'B0C='P_*>:=U/2GYENP[
MW6ZW(ETP0Z/ZN1GV>HKA!-`;LI\4V@M/_V[/.WU^?=)I76E9?E!*RUB:67_O
M:5UI759:TD)?7Y^%J;5#P,"J+\M:!O5.0_>?ZG7LD@T[,S&Q:(MTZ]AM0SUQ
M^H:M_S#8-2_`RW9<;ZA#>+++SR7BL]\7"LP:/.CBHW.4Z<D^8Z$M1'@5[.HO
M?'[&ZJ?D33H\;%IU0LI,"^LO4W;E\L(UM!?GB297/&SU5F(<L[RC0RO'VF@^
MX-]AT?4,?Q0XH:?>([UL>^`X8%6(M(W2]-:YF%L])*,TN>*'3:BRN&I:6EUO
M!B]=S4P[:RY@S1HXZTE?C-'-,NRX^LUA)[?PGKL#6`H`$7<_\M`QYH`Y]?9N
M5'-5I0^399B"[B"%Q^>W1\%(7KMFNO^?\4UNGZU;^Y/.ASE(^SE'(,L60Z5M
M+*J+I)]M,@-IXWD?DA6F92F#0.@M2^97%'@"0-S\;^TS63;P^8!;`Q36L2+#
M?1C/)#"@:BT<%90(+B`E4CJ*M/$>Q]I'-Q](_O$]P]9ZG[Q'1P)08EI'#^5>
M9&0G[5G5UTP,TRGF&-EO2G;#Z-8<K.P0\;O:]YW/Y^YJD'.FGS]_TM?7#9Y3
MHFU[T,^?/^EVNY7?S4UV,(;7^NV17/\-!C59IQ"J;4C$O(_BP*^*A);R'C^V
MC?8]]^(F=J\O_W$ZG^A\/IO/F^$48,\Y%6F$*7SP`;77>#SC.98Q">EUAN0;
M\/[J/\QOT'1OL[3R7DK:"ZWKU[Z;G[8-^>G@'9CH\5N7@)[%&,@A.<H$DT'/
M4#G(',2U%?6[%GN#'AYI9.$0Z.N?%0Q"\\4B`K>8%&23B#TS%("&@.&6"=B=
M1=3V=M_!3=<;CTQ[!&*SX65>,EFK(AQ,D4E1Y(&]V<A5$,+8X]J0QSB7H*7*
M$%0@+:83FGXH70``(`!)1$%4'HO4_FYLY?C].8O:I%1LIAEGG!82`"0D6E,"
M'U5U#@W<9MRYP)LX6P-]UKJ`":/8P;O5I$IS"8"0CTF1)^:E:$QEMX[*TH?.
M&D.*0RSM_P3"&]R;*+'N'Q="<8!"*#=P0!P"BFB`$W6@RA[.S&DYL&R3!REF
M]QJSR=WG-?G"O#Z8):*YN'Y0E7OHXQ^_WP!USAID>Q8QEE;8\XY`;R^`&DO'
MXXU)8,W%##9U`(3<4)N[1N:1Q447NA9VB(Z#F0PVH0N7RX4^/C[H=KO1GW_^
M28_[G40R[?M>F-!MH]O7%WW^_"P2!@+_6B;EM(:RLHAXZD5;3S@+V&EXKR*R
MP`7_U)^]/PKKO&W[L*U#0@!^?CV=BI]PM+.)T+(L8)%FG$G2H@:#M:<X.Q9W
MMG8)O#S?P1/_)/-[\`?/M+82]!9_5\/[!F5-OXF;/3LIOWF<WJ?Z.4L<37$>
MH"\U.<U1K<$32,['A4>@(Q'2?J/\CFO'D\*`%9C7D;-B_RZZ+X)]60!MDRF\
M9P.;:",4`S*9=C-L)*0/$K!M.YD6H.*#0YUMU?S1BUQ81($.-G_>0QVJ57II
MJ7)-9R.=:]_U<+DGO27E=%#MJ[I,PLR[04""]($ZAD&D8>EDP3&K0?5A%R&0
MHB8OOJ,X$3U`ESA/93PV&+%7^EQ&S^]LHI[92U.T_9N7N223O-63XC#ZU<2@
M2K#^MON2Q;IS8"W(_A%G"(Y@(T.Q709UG@&3:770P7JK+;BT>*16*OH3A-3D
M?/G>#+[)!QI@#.N8/!P]*KK+A;(;I%*Z5^@6N``&TA[4(]([]>/)$SK]F889
MY41VNY@-WD5Y)AFZ0)?SF:[7*]WN=[K=;I1S[J!61.AVNU?/7'$:7"5U4"R^
MZ#4Y]#+7X3^)F9:42M'0V-`HF:U)K88(V\T#W.XW.I].=#J=IN$GR[+0]7JE
M?=_I\;AW=GA)3&E9Z'RY5+]GH6W?:$F#V5V6I>CN\^XTN4WOC^^SD@V1'RA$
M]HCYVY;L-_#A*Z-7BCA]'2B_I?E]+E>0(W#:%N47=[BWE!P&0,IK^Z<_^.FP
M'#!.9.RH2.OV'#D#G]_M?Y]=,W29MZT]"IUN],0V.5G<\7V<1`9/KZ4YEZ/G
MD5^Y>>#!RVY<)'X/GH5WJ`&*(Y&Y2<&SK)5XT\O!2I+U8&33RASA`@@A,*+4
MA5'`1A3UUT5BXWR1J#5AK>>X'V]6"7JD-CAI&VH?XF,E9>@L'L?W1H>XB"JT
M?4>`1U!$>\<@G<E&F';_WQYR,33'//%^'1Z:1>/<?%>[]E:!QNS8S'ZX*0UF
MV#@`-'VNLY-JUST5)X(.S*2R[P;T]I2G/G0EZAEKFDH;8L/<"B,$+PUXDP->
M[?D:FWV3!FB@*F(L[Z9#AEP&*%M"&18D>(]`ZVI?S@8^DXE!%](6B,9UU@P/
M:><985Q11CQUIECB9JW!.)"#V%U!:83K'E<Z)V5@DDPW;(1[Z-`)<?A95)L!
MV^=<[;M22G0ZG^EVO]/]\:#+]4J/^M_[-1$AG(?L$A/!YW&L/[FZLB"#;,CT
MSHHS5VE-2G1>5SJ=SK3O&WU^?0W0#>LF$U.J?KY9A)8ET?E\[H-H[=C6]414
M==5'WNCKZ4S+FFG/F;:]V*"=KU<Z@6PAYTQ?MQM=SA=:F2GO.Z64Z'J]T,_/
MSU"JEBRC:_<A8VTWMNVR1GT#WO\1VI?"C4A>_/GI1Q\.<_G1L):&0B^"][?`
MKOS3U]"#77FQ,+&?Z:RI@`$+>U\VHA08&V4?IIC3URL2/#-G<4,O#B$2Q9KD
M*>`64A$V&DH%S@A^D]&`@H=-4WA0;#Q@#>`2/_"B6[2DI\5MI.53.04'NE(S
MZ:M:[K#`YG;XD>N#="`J!G#CPCO`FK;J:N^DU*$/,443JQ:B?A*ZZY:*3+5M
M6["].N@8J#0_PUR*Z`)1M4Q)@P1B:,^CDX,*+A@WO.MU&:^/J'>O#.)Q."R)
MW04=!ZSMK\2=IW\O$K-*',/GH/OQN@*)%.LIP)R7C7Y4[[T``<`Z$M*X@X\&
M3!*QMA43/61I)3G(7+;A-9L:E[JO\+`LPQ2[$4]=P*AFRWFZ]D2@DX3,?8<.
M`6&,O1[4:A*)94G:AQE"*D+?<?.L-[NKG(4H$>B-#6-<KW./KW7^R+H@R3(&
M"W-U_3C7F."OKZ\2&5Q#%=9U+0X-.?M4PTA>U(\KZW,#J[\R5%;"))8ET;9M
M!7"?SI12M1Y+3*?U4F)\?_Y4UZ\]FY>J,WX\'G2]7NET.I'(%Q$]^O?N.=-C
M?U!>&\M+@09Z%'II68@XT;*NRLVA6*@5QONTGCH[GI9$*:VP]N@N7:Y=!6W'
M",F;Z/$,)%4'XM]H]!_^YP7F=(!=?A-5.@>G)S^IER-Y&\6^(&=X18/Q"G!G
M#8)\&``;8*C3T@XUI'2,%E^-58BTT[;;A-K)V;1Y9.XCP6=&(WF:X8NO(QZC
MGK`-I8OQV1I3^5<>\T.=.Y.;/"=3D=>)JH/B2S3#%H#NQGA:FRX=4F&C=D6Q
M+8UMMA*-;B/&C3$3O<@2Z'@[4#6*XBSSR-(6%*^^$QAW$963FA1K$ZG/`11,
M7$CZE'1*:N*[#9>EWCHT]RZP2K(A%S91RQ4BS`K(JHU?M3>KA5N3)[BV^]`(
M>PLK#0US'L>J`<4`FZG?7PU@=2-"S/"79V_W/7?0)I$G+#Z$]CX36F6AEK8F
M5-4":0!=K04=S'-2C*0:-DOX=VQ\?$D!O^$V(FY*'F4';HL1_?X6UHX=\9/`
M+:&=ZKYG2FGX-V,7CR<[W2A>I<M7TD(0'UT.:(=.C$PD4I&42G6<ZII6P.:)
M]ISI=#[3^72BSZ^OTNJ_7.BOGS^[A&%0E]#%,(-^$LB#VC^G]437ZY76QIQR
M`=4E%&(IY[8/><#E<B')N0=4"!$MZT*7TYG6I?S\FA*E)2G'DYQS&6"[W>FQ
M;?18'O3O?_^KI,1%^PWL>8F)SJ=3M3+,]/GU1?NVJ^'57(_I="IL=+\V&8W\
M(5)<<$B<%-!-('&Q>2K?@/=ODC/0JZS;4U9.ZP!^1<[PHNVOB5SZ&P'^KYY[
M`$CE"3*6@,*4`R.Q$)!+?-PQ\\7A<?'D\X_LV'1]HW6;,Z<&GA.V08?`GQ@?
M_X)F9\W9\<'S[P9G0FLNY7[G(C^U.L'JUPX`=!"A*J91CZU:D5D80%UCQ8`6
M'+HAZ:RL_5WI["XI/>BPE61SI^O'9W'2E_9^AL\5!E@@ZZ:`O)<V*!"O&'73
MWC7:1P;&/5M;$R/78,.$JBX'`.H([$:=`Z7W5='#,@()%)O>&,TV;`2^N&E$
M!(\P@$3.CMAZ2</UZVWO>LS9LI65X<N2G>?L<.60'EZ2"9T14&8SUN;8*Y<A
MJ,5W$5`;+P:<M20[R>2LUO+$\U%U!KKTQ(+8P50R^0*[%1=D]:88L*'\Y]EM
M40WLBE#7@0IV>(P,810E/B:W`=4,^FT..E:1EKBO-/5<6CQO6A+]\?%!)$+;
MXT$?UX_2K<F93J=3&5K;]RY5Z\\&-4<+&7,`;0@O0[HAB7JW\[[1Y\^?=#X7
MX(M3E/?;C1(7UI=K+#=7B[0&"O=]+Y9BZSH&UI:E']/U<J;'[=:+/JGBGGW?
M:=\V6I=%*?VP0&9BNI[/1<:P+)1%Z/;U1?MCZSLUUQ-G(I*\T_VVT_9X5)]N
M`D<;S>;@<\L1-H,!UK&6?FMX_UNJA?=(X!<'W68`[AG8%=+).'\'62W!)-1;
MNN4C!&H75A+GTZ?8KX/O=DR.B7]]KCDV&E1L,0M(`PST?I[*Q\9[T5\&C!,>
M?IUC8U-QL3)GKR6&PN/::I3YLIW:7$IP;!LVPCC865"]FF8H`;/FSJUK&OWY
MY<JN<']#4N>?\.(Q<1PAW%G=`68&R-3"3@90W#7-QBQ>%V]M0S`,DXG\C=Z1
M84R?X=EFQ08J\W9HF0_FEH#E#B18%`6/>)VT]:?N@H:45/NZMX>[AEB4Y95J
M76>IS*2`QZX4WV&83\#SQ-0NU)0S@&_M%TRA="):A[M4("4'%/4US1!YG`QX
M!6-_IR&/"T`]6.4'=[DY-,"]:!ZWDH.X14.,2##)UUC>#/'5?5`0[>;`20'!
M?\ZD0T>87>^JM2.:=&"IURHEKDX,$,EMNF"I`7PR@165O>\@-:4QP`@RH@(2
M@T'&]OTR)#?=+YF9]ERTMM?KE=8UT<^?-[K?2I!$!OLU]9X'N;KCD=6#?_T:
MIB+M6=<254Q$])___(=$B-9UH>WQ*'_WXT?7[9[6E3@E.I]/SM'#/E.2FSSC
M7'L#S<&C2E^:1W*P._9]*B5:$].^9]H>#WJ`AAG?BK24X(G;[=X#,-J')"1/
MJEPLX>"G\;RF@/%OS\4WX/V;V-U?!8J>M)2G+*UZJ"8:T./ODC`63)Z0P:_1
MQGKS?H7QYE<_G_6&;@%-2[=Z0;;K/'Z%7_E."H&X1*UU%:H@:O+VH`S1*)K%
MW1MG`\,>:$_]RLC;'`&2T^UN-UCEK[N/?:0P\:BS%1(7`'IBV]=A'":K38;9
M3,2<DA1$SXS92+0L0IYW1X!5&YN3O6((+@WT8TAHL*UQ1W\'`S2LM:"6<5.L
MNP$=-N*7.1I(U-/\%!Q;;&VDUXT1N);-[W`H>\C`@DX[:L8:#J]!&QY2:VJ+
MR34#BG@_N[R$8K93`K&OTJU'L;Z-6<\Z&(.!V;7=*<8@DD`>H*P'S7W/@::R
M`U>X_UF]?[KH46$*EG$/&`7;<A=37.P5)!(PM?:Y8L,(HWZXZ[9[AZ4P_`WL
MYAX$0BJ`H0]Z&B<!`F`ZGA_?*_3[B2A0G4UW1O:=Z':G?__[W[0LB?8LM.U[
MT1!7L)N5@Y#6G97W)'5=,ZZYK7A<4J+K]4K+FKJ48=NV(C78=LI2O'.%A);3
MN4J%%LIYI\>VE;A@(5K6!,_LB"Y>H.N1)5,6IG;K<K6@2\QTOV]$E&A=$V&"
MHI@)\WW/]/GY2=MC'U*.$==&G!)M6Z;[MJNMK#NCD!D8%B9)=CA-NL1)E'L(
MCD9^`][WP>N+C)/K.\L[OW`,7-W'O>JP\.2`9L3@0=8`O>%5$;<@*/9#E9E<
M`#<3_D6:79QR9)XY(12TH0,MHK,T8RT>$J%GP:B:L?=ZZ"@%2MEZL37\2D.W
MR`'[1]:Z[<4'"3Q(^Z"8B&,@K(Q`;8SBKR\'I/O!US\I1MFU5(\*.=W*1PWL
M6&@[*X6,6V,7K.Q!74X.GJ6@D!#??1!#50P['@8S:3_PB@X%]OI8FR7OZJ"U
MR1K?,=A!L?8?[7H_H90TXZD=`J7[O#9G`T^"ZF,,AZ`\)P8!;6T#S./&`8BS
M;>_^K"16?J^]_6\"GI@I](YM_V0RMGP81PT!(IU]M^!1%7Q#BA$VOC1^<-9,
M6`@.P*U=373<+@.S#E!0M$9=$S02'KMRF\@8R3T9?&O2DP;:X67?<QMNJ^>9
M?!!-UV83T>[65CWD:$&GV#4FH^^ME`(%BMQ^;;,N>/@T`CW*D-6B@2['Q2Q&
MK*N!-GAW4DIT_?%!']=K/8Y,/W]^TNU^[\-PS%P*#&:ZW>^TYYTNYTO5/Y?W
M(.^9'MN#F)<N>6A=K5TR)4JE*-B+%=GI=*:]!LT(E0+F\_9%]\>=_O6O?]&Z
MK,&(=3GJQ[;3[?XPA?F('"_,_5C7VOJ9\=WOJ6EQD>V)!E+'TJ[[=_#$?X'A
M?4%,Z^X1O_!1;'LX=/R[O;5EV_+"JJW'+WZ6*'82K:;XI=-V#,41*`E#`IPS
M]W-&5V=HA@E.[#%*>$5$#J;<F%[[PWX:[-D:"V3=T!4<BTE-ZC_#GK['"6TV
M2EWV\^UA_<;,*NBB#<\<OR-L-FQVG.$1LZM^TKG%Z]`3GKP<GJ6W\91#4\GF
MX9`^)*8/-`UJK.C24.9`\=`6A4PRFZ.SH$0#H/[3*D@%@(/M&;`.S$@]A."@
MXR#(/(&LQ3D;!+K;EN(63,_CY#DK$Q`AGYKH7=UP4EM,6[@<,OKM4@U48-4B
M;G*",00[_#JKJK-,F;?!+EAO6FI6U^B2"2,1Z6EYI&03.A(60S?PS;/A(NBO
M/:*4XVC8,02):SXK4!_1\6P":D2HMY=5ZEEB<\\\L1(&8.#0)E-L&9F&,T8'
ME8G5<Y*II?Q)`6%YC#^U9S:U5]LP^3D/'^!DIOJ]IS;#.E?O?=:6EV38XR4E
MNEXN/5RB,:88?L)2"`*N%H.4A5@R<9:>H$8U"3%QHM.ZTFE=Z>/Z0?_^UQ_T
M<;V6Z[#O]/,_?]'79QT"R\-W.M4J+6\[W>\;2<ZT+BNMZ41+6NA\/M.^[?3Y
M^;/(F'*!FGG;*6][7V?ROI?G3<K?$^9!Y!*R4F0*!9@GEOXO<Y5OY>']C7M,
MH;TA1;X/H8)?=;U6A$/*!S[JX]@&F\:-D,G?MF3_+,/[%N?IIP!XTOZ?X:EG
M!@EJ*8U&9Y^PRE:7BQNSKUA?TQ\+QVS?*]?4,]VL!WVBZ\$35M&".HE,#K01
M-U,P8"AVHI;,`)@I6DR'U`)PL4`\`$,T`:CZ'/79\A-PRA$KWMD."X#9=^<"
MSMZ!=/%9ZQPP,H?O(EE6FUTGPWEG<K`IVX1!G`K&A#,9$UP8!$QMTA\6;#+#
M54IBW*-CC=D^L*=]P(C8"K=KN\^_E\P4!"U0]UNU+R`'189CWE#/VMOFN6ZN
M`+`C%X;61K?L\J3K,IPO+(C616MKV[<!,3(.P\W+E(@HI:H-!@4RVDLU)X8"
ML#))YG'<W>N-1G(3&X8/2]"J7QU,NV&!*=#+YN&)FUC[_.IB0=P0%[+S.DV,
MC$R"W?T9EE1LG?V&1A5^IG4W[+EWS;IHR[:FYW4`'H><B*==EUY\9'&9'KB4
M-V>/%M$]?)]U(<BF.]7]:FE8ENGH;P:+.DWFM#\3*(R7I6AI+^=+84KWG?9M
MI_OM1I2+%I5TJ3HLM0B>_78-<Z:T,'U<KW0YGWO`1ON^^_U&7[<O(DGU=V2`
MW:;]KP7$XW&OZ69")`OM^TYYWXI&=UU[4;%MCRI[2)2E!$?T[YP,=B_)ST50
MG04I#@S;&-*3<6W[^]ED._M>-;L,YP'K+,Z3B%0)(SLK=CL+4*X+?0^M_5T,
MK_R&G$%"`',,7E7K.PBIX/!KQRH2:4GGOW=(H!JVD5\&^3W4BXRGISQQ-IA=
M5AX@(CK6>?&@$3Q+2)I/;IJ.0E+R`+8`6&"QDQBXFV***<YET`/IT7?J3_8N
MG3#D%<D%(.5G5A"H`1J7YD9!FIG5?(BJCXS;K@-NKC5I@??!2SBTP=Q#!=@K
MIH%E"F)VR:0KF=\4U$9T/1LFF9GAI]*T4X-D>FA*>P.K9"%EP>;7I\9&<@EY
M&\"W>QYGQ8AR]?TE^$\K)Q@%F-6K@NV;:28@>)"#R&';X!JKE![@:>P5,IZC
M30H.%';B7VE;J]4;:RWE*#9,<QN&OEJAI%PQ^D5,3G(A.=>`!78RHQ%N5X?V
MLAAM,75F>K2XZC.C7"O\<XAI?JV(&*!0V^`-8$L](C@9%Y)1>,7=%QO?BUV?
MW`$,LL_C.N&`6__?;`)BDCDWB>WPF*/CY;#E;0<SV;#32H=,&OA*(`T1(;I<
MSH7=A=_Y^?,ONM\?/141%VL<3&P.#5@H9!HM?UY2?R:$B+9MI_MC)ZH%'[?>
M$G:A0!]_?VSTV/^L`#51SD6>\'$]5SUL^7<]G2EGH<=CAPCU]M:G&M0"^O/>
M760C/=1]8H%DPU.-'MX>CQ$\4[6\),->KWM1D\_&0BLXJ!O=;$,ITL=O?DL:
M_C$J^#E0?(7S?4IS2MR^G[?B^=<&[U[VUI67I!!NPQ9-PHEJ33__S@$87_OB
M4%'[!.5&K5E';8;)1]%4.X!%AB,"I8;P..0<W%>!03!AT^EQ3)K)/I?9T)=F
MB7ISF>.P`6>,P#2?9(<>0S:!3DK>PN0RW[6$A+T4A='JC.TLDO;MG1J`8"LU
M8,H,DL,I:@)B5P@Z;\IN$V\Z!#!`)V"T?3&#VLMG.'@_&.)-O6)?!EAD]M[1
M[7EAAI\UC'1E0AD\6G7`QBB$AG`*P$Y*[J$056!R$\=V%KGTGLMT>.Y,>MUX
M&].*PV*<5!2I@-:\_SG';#8^,]+:WP#HJ(.>9-YC+5.(F-Q^S618+'$/3"!U
M3W#:7,MU0'J&&E1(LVO'(A+W:AB^)Z4QN);!::`#/_9@5K^7\0"K_?,B:\E]
M[U'O-(EGP#OS+EUVY<`N#`(21XXA6O\:]:[:L;00B':/^_$)OD\-?-I]/2CZ
M^O-&W1]9KU&LU@A<)]I[L%=;N]/I1&E)3>'0@<'V>-#]?B_'QJSW`M7YYU[(
MY+TDG]T?&V7)=#Z?JP/#Z-K\_/RDK_N]OX>/;>_'B!(>Z>MXI@U^QHJ1!.Y5
M2U'[XX\_Z(\?/^CZ\8.(BAXX]QVP'B^L06BYV-=($1+N*U"]#I$82M_/;\#[
MF^SN*Z#WC2]X_6.9?CW@@7D*L.6W#DW4QO_LLKBT508YL9VE,IA5O/.KIH>?
M?+G3`#_%O.QDHTIKR4&E`@,A8FX>Z_YKS%(>2(2G+@*B6[5V.E^#65&:NB-A
M"P>B/3&G/G]/!$;`Q&N$7=2=3)P9)O(#5Y1IW]1Q_NRLT\2PKM;VB5E7'FST
M,JV5:C7P5IM>I)R#E1`$S?T>I<'N5;:R7[G$=<*>1P$D^GUIA<DL`0M!2D]Z
MXI&*)/V_)\J30B@WIS:.@9^*8@7%'E76K6R:HAP[&OCJB7%-$VXTQLZR#UL$
M!M#U>]=2ZP"\DI'`$/BPHMU6['^;QD!:!S^Y`^1VOPI02X264A2`@&!B5S''
MS#B0)P!J1;'9(@2@F^-@#])2IB'S`%`.[@TX[*/6B1E3&C#`_GM]]X4<.-$]
MJ<9X=M(`GXFD91\#4`_&7O1*Y]83CN8!('&N+WV,TA4/G/%<MNU!7U]?15?;
MV,\<`P,1W^EE*LEG_^O?_Z++Z4RIP601NM]NA34VA8:/.]/7TTK(SN=+#Z<0
M$OJZ%8G$MFW@>YP/L4Q*B=9EG6*&%BK!1/3Q\8.N'Q_%):)>(QP<S$(NP$4H
M"I01=:_'\R]CT-"0+.W]_I8TO,5R<ICO_$2K\(*<X74@/?/K?=DU3/6N7SL"
MD3FOR@?Q#,\LR::.$(8TC7V)#_PPH^/G./3`,J84.!K,KH=BQMS)<\#L#@VH
M90_+KTC8&I`7[E]\P_P$MK7TXDA=++@A42@K<-/:!]6%+4V\G$;;]!SJ=WT,
M49V@9H4RD>5B=#/`C<D-[`R&1-N(!<6"Z#(Q>G:5A5@_=E*V86(89O+-@B#=
MB9^N,_V/*["-[,BL]I?A^F`HQ8BW)?-,&*VM.A]Q`(5YPCC2&,2R1<MHY(MB
MEE&\S"U]*[64KJ7J>C5PS<X&S[Q&75[#VJK.Q/&6"%D+4I");RUJ5M\O$#/6
MW0AF1`JC9(1',ADX7)2)_"A\W(--%#CUP`X5:<W*LU<?+WF]&\_M`>TY'8<W
M^/6"6;._47RRLJGJ1:4>$D6W%#9I;G@M\;U`-Q#U6(A>R[,(D/)>[E&2P^Y#
MCTT)W"#B*-YFO5;:_@O]^!@!$=AEO-\?=+_?7*0N&5)#Q8EC^XEQ4%3;>R5.
MM.>=OFY?E!ZI6[>I>]>Z/2G1]7*E\^DT'A/GC2_E,YAI69:N^Q>1\K]3HJ6Z
M6#3!#BZ5&MN@<,(D`7)PC&S>XRS?#.\_QO"^Q<#R6UZZOX&Q`U'!*XPP30P&
M^/<^?0+8)6)_#XASVX*:L;JCS6.GB-DAZG@^?$P9-9V98@Y$M(">.9!E:`<`
M<?R#/+V.HK(5&;Y7IL^!3;*<,=YB!F'##<JDV9"9_H]NL-V<].>RFO7R+5NK
MW1'G,2MF4XBOI;A%T;($!&UXE6!E6Y"J92CCL^RI*PLBW0X.+?':5#^T5R-&
MWS(WEL-"/3#^T]C5`5"'+*'\79Q<Y))O)>H8\>2>`*AF=L>><U:!#TY.`6M-
M3_D*B=YQK*GZHHF9:$%#?%(%Z[#]BHM<T?9A2D*1PN<Z8M;4N;?S)NU4@4!5
M.4&`]C9F[?3]Q7>R?9?(/"!F]IFC><9*J]UKM(D\:G8M-"M'#DV+<93)W0Y+
M.UK8/8@3]Z*G%7"M("M^LKF[9(B]/N::J4)3C/\Q%(1]J)3TSYQ.)[ITN0![
M6T;<#8Q?],>/'_1'M?J*Z(GS]5+=0WS'HLMW`F(*Y2Q[SG2_WVG?]W[>2UKZ
M\3WNCS)L1V@+IK]KJ0EMCVV;.A:)%"G%NI[JT%SYA)06NERNE-(R8JHEVG6U
MMD[W"H/BBLS>9';I;X;W-\#N.VYCQW_UFB?NC.1QF^;AK\A;X/HMUOA9>$7T
M/R8V;/+&)=4>GT_.J4^"(X/D@4I\WC`HPA0"JXAMEB"/I@-O"33^!T:T8@;E
M5%4_0_H!8,%]._$84B/KG!!,UV,[F&D^`&=971;XGHFS,6[H\LQJ3K$^8TI[
M7![C'@$+IKV\V&H=;@P<DUL5B#0?5I>2Q*.DDFQ#34QREME(&.VQS#U0'LVV
M\T2^-<Q10`##9[(6ET2;VJRQT)C%P0H/0(\^LZX9$;@Y8,"!C1D>+#$I^RB!
MXD`DJ?-MF[A-)L.:5"#FMOF^]H&]-D@FT>"3]B/V^_*PAG+GIU&MEP@%GL:1
M-C:2)[7V\S.)0=@-G`!61V*(.!<5E&=(Y,\[\2FVUP8[!FKM83$#=>2\OG7,
MLBB3%&6G1Z-HX8,U:[P;`I\!Y\_&-[NQO3ASL0L1+R1UZ'"XM-AI=EV4CQ"8
MA7;P<VB@?7ML=+\_:I&H.RP])3%@-NSH\FD]T?E\UI*A5`;@!KL_"JR]VI/A
M)7O4Y+0B5_B@'Q\?8Q*]_K/O.ZWK4EPFK.<1,YW/)]JVC?9]=]TW!FL85:C9
M+I!]E2"25/EA)/YF>/^Y?_B0X3V"*4_)2GX?8[-C*?F0-<7*E@];I_+\<V9_
M]\H//P'&,U8SM/6DN`VGWB%^[?#ZIF#_C=C3T,`_>$8$B$`Y:!((N80H4BZA
M_OHTWTHT96)C530%E*QU4SQY#O6`&04LZ[!U4HT0MFW<N<V5A$76K*!X_GYX
M+1X^UT):`2A3MHI@,MX,2JN"H__B>?1%```@`$E$053^A$73FEV_(."OXH`1
MF0$Y,JX.%G"HWR6*"XPH%8:D)QI.V3QRA'P'-/(JHTAU0"ZQ;YOQ$"[C(!P.
MO[7O;#I@3%"S+'MW"*BM52_38:.CG:P'B8>3A/4?#B*A,S"\$J3CJ8$QCD$C
MZD\[.PG:9SXPS+5_BIKID/%T^Y#6(2N)!L?)?O'[+>Z\!WAG9\'6UK$&7EU!
MD#B\IHR^UCG/V>T:F9MS_9?P7Z8L3%)5M?K/R[?L>QG^^OGY&3X#XUJ0N_\]
M[(3&^>/[4)C9FWN7NUZ=`B=K?!=S2Z@K`W&ML,LY5]`)UOS]?8_3+MMGY2ST
M^?E)]_MC.+74>[3O>P'7E>UN9Y3@V/=]I[]^_C7TPI9`DUG;>;#XNNLD:H`8
MU^UOP/LJ?.4#D^,7&>%#9/<&T'J#^'T9&<M+"'4&=OG7-1AR\&5/3T@.JX2H
M+:),Q%WLP@1117=;?`@(QWNE3C8RO]`2LT;+GP]US@JD<C#9QS8Z@H?6;*)U
M&)(0F?R(9PN5N486QR2SJ2`XJECL"S09M!DLICYFWS(04]1(>"'57&'.3B+1
MCE_7,:+9=[+.">*K)C&THFO'$D@7*&C%L6:0V5PV4:/=:LK<_GF4:M6.K;?J
M[;U@8%J"=[\0+E[-2B!/<,`X*J9H!O;JICIAFMGJGHSN7GHH@7[?$X`#]7V&
M?7?OW41_Z6*[V;>?4*X@`4CKLA09T@HE8<BZ^'3@(*:*(00#.C'(@@J>&W5/
M8F1U;8&7@%EE;I93XO^EXOJ16\$-8):H3.>/="T*Y#<9GENXAP@$@Z2V$BX1
M[=W2[SVY8EKT?R)[W9(-!TP;5G_`^K?KMRP+G=95WV-DQR?88%D6NGY\T/E\
M#C>^+$+;8Z,]N/=1Y'78J62B95WH=#KU0(EVK6^W+]KS#IIG,>^AT+*LKD/7
M6.;'X]&OVUX#*2Z7*UVN%Q>:E(V\K#P3MB@4.ZX!TC1Q[W[7NJMU5PN]OB4-
MKV*S)^W569O]);SY9E+QRPRJ08U1'+'\QC49K4MY__."7J-P&`PVPRW^\P[[
ML*/-(6'`QW.IA],I!2W&L$(]./(C=XS#/PO99`X!>]?)<:RI%:&G-AQB%@ZE
M.U.@7E[K!$`;WME:P49OOU_[$6MG!9'G;\/PBC32D"?807\C!B&82#P\6YEB
M>14!K*(0!)TL:O@!@&DL/&3B/2Q!G+$V3;9Z7WYR[_5G=Z:M6Q0AFD^*AL9B
M:5I,V<MB+=B4W:"U02,ULX7/3/%XG2#EJ08V%Z82!KA*R,8(FU&6@M4OJK>L
M-04?2A.\7&`,9_6XYBP.V3<M;L3"CC:\MM%"AE8#!Y!3D0X5$=^F"6R_BOM%
MGNR-]C/Z]YAG05"B4L^-@\Y++,EHOM&D91$)?'A9IPYVJX0>$")P[F*"ND=X
MA1Z:*G]G)21#^E#N6P+'BTB6,NS3-#`/$Q"9*>]"C^TQO&F-EW:TU@JTT1(S
M?7S\H&5)W0NW_=2V[W3?MK%OL1G)3(G6=:5N))/!&[?^Z)[W?F\>CR*[*."=
MC-20?6=D261K>`SF&&$_''=-B%3TMIMGJ$_]-^#]QP#R&\#U+:'L,?*39\A2
MY.6O=E/,(8C1_817W!EF?\F18%*>7"IY3V-,*@;"D78^NAESRMA,^O+,DY="
MVPR?CA3=(SF\*?ZOV(VS2C0Y9<`U!_9I3/,D0=469#/)+/%='E$;[*Y)5XD%
M:%4/?TE\.4'/*O)*5,DD-",`8M[$02C.39#P/U$"HN]K,)RJG!M`N\N#@K.R
M3PE:'Q)-@.(]MVE5L!G;(35.P_Y'`UW8;"0N*B4$MCIKT#I^,,4I?5Y#JP%W
MTUD.`#=:V4M*/K"$`MVGI0:,;4-WFVB@-LNX1ABC'KGWP)_M>W;2#QN,(4?K
M>B`OLC*!D7S&_ITE'V*3)4KF8^=.D$UQG\7*L[`HXZ>;H'8T$:5G1SUP:;>/
MSTDD#C@K`%ZJG'%\(]$'[G_5>]<_SS61+P.3+`3.!RKQCHF7`J837/NF`2^.
M)D3WQXW^_.O/$6.<6.U3?5TT*8Y[WHO^?);-(L8Q1`9@%!O&`?>/I1[K4HB*
MI<9E]V<S9_K\_*2\9]//Y.Y&,0I"46PV&X8:U[33^402;%RV^$HIT>5RI75=
M:=LVNMUN@_%5MHU<,V.&OK<Y_`@2.*1CGW&5^Y8T_,]#XY>'R'[1>M>U?%]C
MAI\#=_6Y_/JQOZI2>!7T'TJ!^>AXAIW0T<65D.4W8,&U3\C)-69RNB-9!1\P
MI>P0&@56Q`P:5)07^*0QH<F$NF+'GCU-R!L:QUWV;@WZ/)XT`8)O4)R58*H:
MQ0!DYEGYK&RTGKSA&\E#_L#&O(`I\"U`QXWCP4?]E"3#@$(^?05A-H1"LRPR
MAK84RUC/(73)"CP^U:1T[FW%E,9U8-8.$YW!KRSJ</G0WV,GZ!LP2LFTV\W#
MV'QU<\XU\$"GBQ5,I%OR;`-D.O`QT<8@-6C`=\AA>("S0+_:S@5=%\A&.F-V
M+_FA,NNZD;OS@I8L2-?K:W>17-O36;G)6+^:84.7F2DK!Q8,XSAX5J6Y%PB$
M.UB;0U(L*@*J`JI*E+&@"P+/#-J'";7(L*(C%R+#W>,9`?`X-G`OJ=<VM\CB
M=FI9H-@?[7AEQ]>D#KT@'RX1(V!AR#PRR%S2NI04P-KV;S^[[SO]^?D7[5E(
M**G[F^%8LTCYF>:Z`A9ZVY[IS[]^TNWV4&3-ON7ZN>-^Y%R;#'#M]BRT[UF'
M[=!@I4_GB[(QQ&<.07(6JD$:52*3%EK7E=*RC+]KX1,T0EQT&))FX953$\CS
M<I,#U3__9GA_`S[R[P*VWR%U`Q9PVDQ^AVW^I7]8\3C//E..M+GO(/J#5NGK
M;+AHEHF>`-*)%E+(RU,A0%([%ELVO$__LH]F#;Z(C^AXMB!)/,_&<=MR>JW:
M\:)+`-H2.8>``$]"W&-44`F][M2A@)MHW?!P:HATTP$K)-'Q\.&Q-0:!S<]'
MO"^;`@&C+U'/.XA]8Y'&DPZ->#LD_"=GG2#6904*7?1<O<'P-5#@;..@'8_#
M)#R$)<(4LKCH(ZL8]L;N95WAS087B^PI\&`FT\X-VOC-5:,Q6FS]LY$55?9T
M&"-,RI\8;="ZPX,93$)@2@'[&OEXS[S>DQU*LKIZ<)FPD>/Z-%EK=6'X+,L^
MOK/%32LF<QQ5^6MVG816X66)"G\_V-H'&ET70;QD@$NT+?2[E6\RTT*9,LT"
MZA.G'B.=B2@1]V'%+LMB7VCHX!RRBXYZUE-*E)9$^[XY/3AV39AJI'3-.U].
M2RW61.FHB87N]SMMCQW<1=@XO0"IP*@Q'N]92DS+LI;@ARS$2YLAP8Z.7S.'
M1_A(:V0JOKHM%.3CXX/6JN]EXN*%O6>BY8!(Z@M&(F:A?=MIV_81[F+2Y?08
M"#M15N]G--<A\DJ_;\#["M!\HM\]P!A/VM+R\N^HQIZ\BNF:M<AH+ML/F#6#
MGS&[8G_[F1T8T?,HWR<LL5A6DY]+)2(_!MO^M<EID79WI':QX\RCWQM1OT,"
MT(^'3?@$ZCBG6F@=13N]CJKW+['$16)S]?X3P%XT`,%/GS6[J8K35UJ;')/#
M$$873S&XN7<BDR<%6&\!C0[:#$G0$4!9"(>3B(,,]&%91I=+-9ZL&X1B56/T
MN(G4X(7;T'HNK`9E.IM9>PV7EJIY%HQ+0[M9F<1$[AHY`[B"Z-=?IUU%WJ3M
M>Q-,J1O351]2T&4Z#9Z(Z>ZPB63VK7L<S$&W!@[?&5_8=*VN*ES8%#`\W2_"
M`CF(ZVV@50BD`Q(KQ;L/+/E!0>;6`V#XNU'D"&D++;N/L=)@-Q#1VO8)WKO!
M]KIW2#`NFMSS%VF;^S.01;E+%/_<!";*^H"=,ZO52W?I"#C-],\6]"\+_60%
M.F6M($P8YL#:]NQVN]&^%^`F=6%#^S`=:%)\@9=EH1\_?H`L`#VCF4ZG"WU<
MB?[\\\_0V4.Y*7%]4P1MEI@NYPN=3FO5RS))9J5S8TK&%G`\O_N>:=^E:'>I
M:(ROURN=UK4`?+#B:]*0C)V*J?6==)G%DA9:_W6B?=_I/__YW[TP83L@5)_!
M/M36"Y)4AFCK-4OU_O;')7T/K;U(),:ZQNG`D=G3YALXOQPG3!&HYB/,;'16
M$]]6?@6(/N.Y7\#M@A+&2-M@=6P<5Q1B+AU'?T=!U^L9HN()RV@W)O92@/#<
M)1IE\B!4*#+-ID#*R_,B!0W2\5H&\U1NH$%)'5I&N0\0"$EYT1/QH5;A8*AH
M]HY)4)3Y9#?I+`$?^=W)<?%Z5.CU3`]K:T0X=&>C;1N#Q),0"M'#GC(LY1KC
MP<KE@$.?7_*!<PKX]*L`@RG1L3-X\C;\K36=MNCC@\%1KPO2X)EZF]':20^M
M[`#O"A@8!DH"FS\$6LTKF<.)?%P?M$>TIU4M-4_*-_@(Z,Z>-PMP+=NLK-,P
M`:]C5F3D@P$Q>(<QH:Y:5`SP'OIX@V."BB[6WZ$MLT1YW>*0&`[1,9`48HD?
M]%Z&\`@A4OI,5<?B,Q1TSA3KE[2.O1,+#!T.$CW?3)C<)N%:E>L1)DH56R9*
ME4$=<J+"R'(JC"ZRTYUM%J''MM'I="Y?F'6PPK;M!6BO2]'Y"I(W/(Y;)<:Q
M8J(?V][?B<9J[UNFS\^OXK,;%+$-;&ZY)*9EDEZ(91%:3Z<R/-C=-ZJ3`Q'=
M'QLMIQ.MRQ)*R.S=RGDO/M8ID7`BR7MYCO/HJ!&L2PS7#RZ`6<=;-Z,\1]^`
M]Q?9W6?!$+\2YO"6K=A38#IL1:*6[N'Q/&&<+>?0<"0_.>FHTXQ_QK/OE^.@
M#GE&B4<`,YCQL;-R3.3:1;-VFRJ`(/9RVJ8_NN`RJ18BO<"!.0(S,"R!7[&?
M#32`WCX[!^\%#G8TL"+*O2-^NJT^.F(#Q#V_PT9ITEDD.R2&"413=BE@>BV[
MW2\1CP+*ZDV5/*8S9*3``S=+.J'A;,#ZR[440%4-Z$*IM:8P3(7`52A(MR/Q
MJ5NV3:[<)/"WT[BG;.W@GBQ7D7N%&$95.4EXNRILS3,P#_UU0!-^ZPQ0(US)
M:,Q5FEMM?R.SZ\(*6G`'QS'<-HC!:7`#;VD-=F/_#!74H6*#28%,+*Z6Q(KE
M;H>B6.\&T'BIUS0-J[+ZF9&E&Z%<!B*'QW#68"I56`*C=2*[X;EH*^@1U%CA
MD/>WU76FCEM.J<0RC^Z!F#1.'SFLUKUZ_1+(F@2>QR4MM"PK[8]'97FE#YMR
M0JEX92&I@$G4FK;/:\>^;0_Z^?-G[700".42#&Y)&`'?"N'M\:#3QP<MRZF?
MWYYWNC\>74]LYT%:Z$-;6ZS7=5;OQ7B9T[*4`<(]$U76>K8H9!'*>:>__OJK
M2X_VUNG`HHZ'PPS7288>XYY+&`X+:Y=.THV!;\#[MR/D-W\$6X_T8L+8.PG'
M3"3/+)I^\;-QFXBFL\/M*C`D"*4)TXMAVSF_2MMC"Y]<I*J6J=A&(NE)6+?A
MS$-'F'QTYNRZ119D["I8J!:,#G0F`]"-!1OIJ=.LRD*7?/QNUW**^KVQT(JS
MHAD%P?$PH?"!\P>SLZ5R8+>!48G9>G8%C0'O";L6)@6-92I_4-93QK,5%0?#
MXFHT'81\#CRA'()\O/!H]Q;0U;^S`HN4-*`@?$^9ZO0V:78ML(3S]AA:TM0G
MWYD4J)H]A%;'3*R+!B9K236^:X!=F-`VC+JR+.JM:U,<D3:10[WN8%1%/S/-
M^HL'^-HK@&HO7P>46&!AP>4L-T2GEMDE2N:!%U@<BI&`D`R-KB*L6SJ@*4#Q
MW-O040JZ+@+3[R'K32VAS),KC=TL;7'6-:D0%+/D4PI-YV(V,X$K33OR+.4-
MZL.&V4C:(#.R'7(V=GGH(SYTW:+62V89(\+2(BF2DB@TN<$`>^4ZIR71:07_
M7=%4]O5Z)<E9A5GTC4NMM]#=89W<>#Z=Z'PZTY+Z$="ZK'0ZK>4\LK@.;%?9
M-FUR*AKJ94ET/IW*(>2M/UOCQ'9BR;2D^F;:@8;Z^5O>*==DQ+SOA47>]R)]
M,M*']L_2A`[&,JZT0\2.2G?O:/H.GGA-SO`6KF7Z36_;]_[\.-R6#ZBK@R_B
M-Q/3GARW8KN,:$R")$0FW[+5S-1K106':`]NDA+ZDQOZG9^=S%E(PN0I<$.8
MD*42/#AN3LG<9ZV-U7*&D4M.T/(2LFZKD2F%LTT*V%=DR"5X^CI)]):WJY]*
MQ\&0F84<$I+8N6[A')A`I#9E<Y[X<YS,D0<M?&8?[.'N.Q?=8_O?C`$@3##L
M-8`W!6WRUHXEKKJTYM')FJ%,*9F4,<V(]4V186/B`8J8J;LK,%-HH<73-]T,
M!D'BEHCU\^10UC3S$66XCC91BD#CIR4./@2AG)L.'>A3XL9-@<!%`DCZ;O_D
M!JQ$1MO>#,PY"4,[Y@:2B"E)'9XBHB1E0V?HF*7ZO"4&?U8HLA*GX8G"`PBT
MZY,*Y=O9,A:AI0**]GE+2I3J[R]<9HUJ?EA?<1/83MEWUA89R@8N"QG;;EVP
M$@X+BOJ='O<@Y;C;F2[,W5H,$T%9VGEWK4P!F-4>H%WWI.*'0))5+<L2N)[H
MH!BJUQN<?IKL*0^9RK[OY5ARI@3M!Q;_3K7!KV5A2DDHL5#B<M^XO?\D=#Z?
MR_L?@/U^#)`.6:<(Z;RN],>/#_KCCQ]T.BUJ>5D2T[__]2^Z7BX5F-;G1(0X
M4__?DG.]_N7:7$ZG$A<L9=B,JS8_P379MP)F^W-)P\.<4[DVGW_]I+SM=%H6
M2LRTT&#.^W_6^YK:?>\%QM@_RO>WPJ8)8<J_"9)(OQG>_S*[^TR\\"Y8YFE7
MN\]?3W/3A7[--U=>%%\P:49%O>23[^`7<3D].78VXEG,6U*#8Z2KX`CL^<V8
MU7G,3@(Q3!PM;%E:GC,](?,\OS!LV([Q%Y$/,[MSC9*Y$#9;4&+/2P(_8:V)
MBY]`UP:.VHHHU^B@V1<M.$@1F?Y'0T,]F`1./7%R4IAL-*V]M2GL\KBUB3H.
M@0VTSFJ`</B#(N"B7`M$[`JA@P"[$;S"R'3/X]2MKQ*E-NA-*:/^+^N[!1K2
M[C=*;)A7S<2/J-[DV_^D!R([,VL'>OQ8MF'6RCW2QOX"7%V@C*J3ZU8W+_E8
MWM*92Z:#T`?-\A_Z61L9B=/52^1ZPHHE)01;G>G.?;W'L(_^E>@/;=[O/6=*
MG(JUE]/Y^P(1SU\GHI'R]9ZO(Z:`-]V;<1W`48*1T>:A!JI`-D/X1M=]L[@N
M0@:OZ19X-#QN`;37=P&E$LSZ>5#2H+JV+DM),KO?'_`>Y1)'+'I8LK'R^[[3
M[7ZG95V'M:&V/:'[_:X2]FPC"!/E.N')3.?+A7Y\?(2=OYQ+(MK]L4%'BF$?
M&?>TV:\)$:4ED52KM19EG7/NA?VV;;3M58/+OM`A(?J\W>BQW>ERO1"E1-RD
M)B#+Z>MK8K4F)-;_6Q,9P1Y5GY=OP/L,FK[:,Y<7NO&F%?@TV>$W6>'!AQJ?
MR:?Y7^]^H[P5GA$-U*M0A`E\Q\%V(6-98K\CF-[W4)\/K.7$+?1JL(;U$`V;
M7=9/+;/;S-S@!IS/X6/!H<QY>F_L$`9^CYA6MMK4HO8ADXZ[M2X&1D]I+XH;
MF7,6!_QT&,@"+=MXC/Q5!V#(6B)"P]Z)+3M%K`;MF-AO-*"3Y-*O!)>%44[H
M--3AE%%^'C6XR6Q>4*,DSY9ERL2<AO-!9WE!;0?."&URO#'9`FT8D0QL>=*#
M@ZT-RG&(`1M9QFAYMW.'P2D94HP.F-J]2V4B?&QDF4B28C=17J,LF,QZFM5@
MG/0!-0DBK!=>[`L[B@8>AOM6VRG@PVO?MQ0&D)"S\M,1OC&SGK-HZ8=]D\SP
M6S_'%GY04\F&S,47@:W($@%313D8VJ[WSG5"X1U65FDT"64QUG/H?M+>G3&Q
M;[-#(:BBGJ\PN"(HG2YK"46/$1ZM<#5S`#'.3;8BCL3QFMEF2T:$SDBL;".[
MCE]*//?"R[`I2\EM9IR6$<H!VGN12-XS9%DI,6W[1K?[C<[G<XV"'FJ(V^-.
M?_WU5RWZ$NV2=8)::XBD1"DMQ,QT.I_H?+G08]OKVE`*]"ZCDO'SI1BJ1\B-
MKRTQQ#\_OZA)J7/.7;=KDPH;(X];6P9+0*(AJS)E&@AXRV=]`]Z_B\@]<`N(
M?^\XOO$=^O>Y[ZW\!H?\&E,MKV#>21JN_VMD=R0<1F(!?=>S"4+GI<`OG-50
M;V*=($QAK"]Z'0@;"47@8A&%&\<M_Q?NVN&UCQ],=1Q/Z'1<_,1,V%OC>$.I
M*::@L2W:,U%/5ZN6*+`U'6QR`'+9L,T,_]E*O@:2)FR3`HIL_'$QT:IN%APX
M$A"/!"?E$03,"5I:-;/\OO$:YH]A@V;23&([+L]2LRI"&#9M;+?WH4H9<N>V
M^8IPC1#%(`L&+5RY#YU)RT?R!@8]*-R7#*UH3A"4D4V"&)N!-B:NSAR[D;Y@
M-<+X[DZ?:U9``9E%[=`1#S#9%U99EIFI?I+YL;#`>@.3YZVUW\\'"]0`?/;_
M!!TQMZ0O`R`H`,="95W%05UF:ZF31XA`X%S@HG.[9AA8NZ"HQJZ)B_.6L<YT
M0%1ETZ4`]!2BB&8GF\2C:;E9Q.P,X`4,N2[]OF31#3()_"RAM;>N)UJ61PEJ
MP(Y("T(P_L&$FOM^$%AP$IW/)_JZ)=IW<9M(,@EX*0T;Q-.ZTEHE`UH.0[1P
MHNOY0BDENC4&608^)V#X4V+ZX^,'+>M2W&AXIW59^GTI;F?E7ES.)TK\@V[W
M&]WNJ7KT9B(N:7(_?_ZD/1>YP[[MM*9D]@R.=>!FS@#71F8="TWHY2O?DH;7
MN,QHJ.4%T/L+?WT(UV9LICS]W"<>:6_+&>(S^AN(ZA>O&^CLB(P4@77KV69O
M>_?@P9;(_/MZG"N3UUA.)(UX/10`MI:"^/T\?^YF;@\XL&/O@83)Y:]U!G1Y
M4$"E3$@9_-\B?@,8A"SWECZ1EQ9$[?'XH8I=@8=\%NVS*E"J&R^;A=.^VPV@
MX919M[NJNUUOAYH)<<7WRK#_4AM;%11T;^S&ZB4]W98HN:0O!'^J281@!H&E
M`LX&]%06-U,NND(>+7]\;Q`L)6!Y\YYKRW<,\G46.0UM,=H)82Y*XE0+H'$L
M)08UT2:[=X^`Z\!5KYQPJ-$DG*&LHC#78RA+^?T:OV,+9IQK@&69+>N-'L_*
ML0'879;0R4=KNL=WY+Z94W<':+^1L\\K3VUHD<EYTB:,7!9V78<>X(`,-F5*
M#/I=`FD`L8NLMIIE=$;H^ESV;W)"R0';;HH,>1&^*DWWFT9QX/4@NI.HUE_E
ML$)=`RT!!L!A.,4P=Z`O'1"ORZJZ@N-SBSBWR`&DRZ6R9-KVG2Z=4O4/_[JN
M]./C@SZ_OFC;MC!2NA6EU\N53J<3W6XW.IU.M"QKO?Y)K77GTYG6=:7'XU%T
MND#@M/>TG0\G+HEH=4U(RS*\=.OW;]M.V[;1LBQT/E\HYTQ__OE7B?JFX8>=
M<P;65LC:'R>C`U>=5V7;(>2I?SV(C4/(WX#W[Y`S_$W$Z4MZ6O9(]SE`9576
MO71>_,YYF>R329'P*Y<)!U*"4S<#*Z*_1RP3.),N3(H)98^C$W^(23$O>O6>
M`VB9R2M8YIL&Q0E/9.U[C+>I6Z"#/'.9,$6:=?53A3[AS&-1CJN+MUXG'=G)
M8`5FL3`31B<+RA6,E=&P9A+7BNT%1!6!-ZT8+IHZ1T_ZIM#EKS2&O\9U'%$`
MW"@;'LSS2'_R;LVI#:BQE8QH[7$RS@1V#>-4I0^L`:F(CAH6D$(P3'3C?R\%
M!'>#?3+M>*T%K,]A&4GOUY=-8$,[EB4ME/->6^:@VY4QD$A2K(^Z_R>RW;7%
MV<-)6P%4V]W]?MG8X3K<U?=59T=EAJP,4]D^*XLQQ`9G![0YL\4S&Y;.I?/!
M<3B6E+43A9B"43/$I)A%+*N3"O\8NNCN!D*I_@S:>;%B<>U"B]('[(CA-41'
MB11-[?*0\*B"#O0]S$/Z4<('4MPN,^*3!L"9M9.+^GKG7(+!+OYK^F>1MZ$C
MHS5NS_?7YQ=)%OJX7FD]I]9.'/<F,7U\7(E3HC___+/X\0:LETC1T'Y\?)#4
MH;)]VTO!FJ2X-*31,9(L]/GY6=;%6B`VQKF=YKYO)%EHWS;:4ZI!$:D,I27N
M[^K/SY]TO]TI+0M]7#^*OV\;XE-&V=3]KR.@H_:?;M&GU^O$PT?9BJN0FQ*0
M`WT#WK^9BGP]QO<H*N)%5EB>`TFGW00/3PJM\X\/:#8<AXM`9+;.`3Q6&[O.
ML-#?Q>3LM)Z"?)YQ@NR:^FQ3P4P[3T`3)*QI3/]=9GK9,9X2EPDN^BDX=NN1
M2H"3.69=19A4T")KN[`C?9Z\4!2HA=Y<O_#4IY[![.^MTL'J``:KFQQX%T`O
M`!K)`SRD67@"&N9S@I0IXQ$*4=$,NC1.Y!*J$B]>-PJL9SO-!.EL75.9AQ2"
MNYBQD\3E[Q,KL5T'*Q#%A:"(P#NT[3^9:HNX?4_6K#!S*BW2SL1FXCJP$FFN
MVW`;#M&TI[`PDAKHC*$D[NRQTL:3EN?B>422C@$&D[)MZNUU,\@H.I?5VR@:
M]9GU-W9#6J3=5+"KT)A.3%%3KS:2&`S68-R*&NK^IPFTKKE+=K%``,TJ3G,`
MFZMLLV!Y&1(8W4J00)K1?(LU^<`*0(;#:VVZ'ECGJ)C0(1L6YXHZMQY:D2`<
MI'4J7%8XZT*FS['I,`<<)&Z?FR&F79$A]9>6=:6/CX_JG>O1L+*ZJ]=ASSM]
M?GV22*9_K7]T/>RP,"S'<5I7.I\O='_<J\U:5MV,E!9:UJ4,CFT;?7U]%;"W
M+G2]7FE9+NHRI+30]>.#]FTC(:*OKR\B$EK7$AI1[,AJP0[2B/8<<Q:ZW>^T
M[YEN]T=Y1O:=_OK\J6(CK12G!:LH:T3XN\4\%X9^Z;_G=_1!_`X)F7QK>'^9
M^9TRPF^V]G4&HYJ8C\:0Y"T@BI+^B<^8<.S;^D(T\B%(5X;Y$[!KT2QK<*@6
M$P&*PNJEY(4)+W<1Q2'JOE1+/`JE0`NSEBX\N\7V9?2W7L/9!Q<``"``241!
M5"VZ<1>?8<`*6O4SMITM4Q@,E5#L7J`.(GBPV!F^^\AF.Q8XAC0J_QH<>_.,
M9O"*Q4EF'&21Z.D3GXXFHET=5)RRLSW3+'&WLJ)A887C:T,ZX:-TEX5[^S<A
MPU4W>#(MR*:=4PQ&BH;Z!H#M0,$PMAV8-J/[@41-)*X,YIPHT&U6:R!N8*UL
M=KG:Y6/7)"/#+-;CE:A[90FYY+7F),'5H;3I3M$OM>/WG,M$=QO$<RU/,A/Y
M`_@W^Z>,U0\,M"2VN$3?-X*N06^[FT`+UY40'D$6,(R$01Y9@.T6[1MZE`28
M1;.E[=[G[J`ARH.]Q=P22'U:6WT`<A[A#CP`="3IP.Z7#@HI6O`90^J&Y13[
MR\HS&*45"3H,*`/C@%AILP;=O:+II#M3/2,U-)#N/O:L'7Z4S9I0:%]XN5[I
M\_.KOMM:)J/.6W7>N#HUS`5G]_N#4K43RWNFGS]_4A:AR_5"MZ\;+2G1Q_6#
M<BZ1Q>TYOMUV(F):`,2V8SZMIS+45JT/'X\[72Z7&J(Q`&^2T?5Z/!ZTI*+A
MO7W=:=LW)?%I_KK*/8;'S(+.31053M4*"[9>TL9Q@T@[9S@"1K3LZ!OP_J+T
M()(:,/V*CM4/4LV`;X@X:29K&$S4%!BSI2A%@4UD*"1BY]X6)7/P>T;/)F-8
M1RTX(EH?2<;Z"C8(O'ZN.X8)6?U_RU0WI;+5.:9N@ZM'+A>Y3\(KQRJEX>5@
MP^UM23!][P!'HI`)G1O'S@))3^<[GPIS'8=01)3><<Z?EW9U<M%Y+U93)/.:
M$/1\?8@+A`)LIJ#;0LJ2W/,U!L:H"2.I$9:85C:LN.HWH3X$?'MS?1X&2-5#
M%TT+J[2MB7LRD';)&`X%0R<YAO::!$$EKC%H;I$)!Z/[]C,-U%BVSD[=#PTG
M=X_.3".\`@%,"@(K-/-O8X*+>3WJ=[LE6GLN4Y48"&HT`:C4X=4EE3AG9/3;
MBY]:.SZQ]P$7":4\^-\3LL(&U-@H6W3T2*VK`%(E3#5CR<Z#G"O@[,`H);4T
M[1"FT`]?+&-*"NB7'6!Q27M<.P\)V->NS4S:ZFZX%%`HNVJ:8<_>)K^^FV<+
MV=\C#_!N>P7'T0D*'MZ]=N@3_74'T]U:Z>*<;G`[Z$LGZWNO+/E$2#@12XGI
ME>IR0))HWW))7-OO?1U'+7.7_D&K3D1H>VRT;T+KFO3@9)4XK.M**ZVTKB>B
MD]"ZK+3M&RTI54E..=[/ST_:MHURWOO[=[_?*:5$U\N%T@GUO*E:])60B^NE
ML,!%*ZR)E-R'8%,'X/^'O7?=CB2YD80-'I%)5K4T^_YON3OJ+C(OX?A^^,T`
MAP?):HWVVW,HG1EU5Y&9<74'#'9I+@V&.AD@]LTZK[R;);PBI<VL<>W5GS0L
M9&3.[UZF=\1J%\597'XCO/]VE/?LY]=B-SE)EOT$]>"$:G!::JQ`/(JEMJ,Y
M<;2##Q1ZQ$&P>55V<]#0K]4*C_RH+W(WT.#KOW8G(SB3\5_7J:JG[XHK6B6>
MYT<WI1?X:D8\+$B:*GB!*WS%C5#GZS.C%($*G7QANU.`<KF\N(HF?SU(D6MC
MR67,&HWLU>-3D6>N&.](]>EH%+[!HC!5)[2L5@5=V`Q!VF0@HE%D;C-/9W%3
M3RJ2OND8OT[N(`6&FPJ1B:LI*4'8]JGS0&$C/UGI!.(NPCLHD`C-W;UV'3H?
MU=S7LKGE9D(?C*7550G\''!A/#,@4B_\_:B?1Y+-.[452G,1YL13CC*E+&X!
MPM%ZLU6:0B2"Q+*PK=71I!Z9HGUS"VXHD:DVF,%.'H[.)R7ZC(*\E!D`B,&7
M*25-AQU9MZ93M<\AB;;8B06(72?XWUOS-/OM:AB9#5?H*M0&VO3TNM9(4A.3
M)+;79.H*[1L*2U]H;B%*:7#JC&S:5$2GIPD41,%1T85Y7R@$!RZ7K4XN-ERO
M5SP>CWZ_,GFM*4T/>A$MP-OM'1#@CY]_].)XW_=^`/M^,>O<Y;)CO^S]LW[]
M^H5__>M?7=AFK<T5C^<=KR\OI:'.BK2E<5UZ\Y'J=^UU/;$S-:GI<'_^^2=N
MM_M(!'1%KGF7'-JS7W;\\8\_RC*5\WB.()TRHM,4M^XJ%8A0,PYV&B)"DYL.
MXKO@_0]5P1^!H3H%(V+"#?7?=8@Z%^(S4J<?!!RL;79\R(5.OR<?7C(NM%AH
M,5U315SF!XJI^=PG5]C0U$*AIQ=.W(;;1_?BU-D(K'/$CAD-=\RCS+J(8IOP
M6UXCYM'#[$)A+840A328(E^-;9O="$9A)8[4KF?4DT!H)<&&XY^M40AJYQR6
MY*O<NZ,FOA@`HKAGR2G"!2:8!#(V=19/F4AE]HYTT;K>.4/4\EFY0>+I?#L'
M+KP*@IYG[J.,Q+7L8X';%9S<,+07+))D$FJQU[0*IO-JF?=#$)G-RM''Y2:"
MFM_O:G<D6[_&4!O,D1H7,Q]&G*K5K-\Z<M"$PO-S231F1&;N.<_>NS4L;-4@
MKRIVA"YF?&2+RH;^PM@JC8I$J]^O.N>#_B-J$5-U+*11)'-1.0",-N(720Y!
M[9:]4T5OV!_^F@8TF(%8<^PTA:DPZM9X\R1VM)\UWFMO4V4*;YTI$3T<1CF@
M&]U9HG/T^][2&I12]*:.E*L)Y!"BGO1)`P1'];N]7'Y"H-CVA-?M%4<^\/[V
M1M>R^G[3.V?6.E&\WVY05?S\\;.'/`ROV?8,>]9T*1SOC_OLQDGKW?$\\/;^
MCI\_?PP1Y9;&^]W6SR;PK).=]KP_*B\XI53"-7BO*;G1"*W\Q*Z[.1^5KP]D
M/<Q$4@EN%\_IX5`0Y\,T>..%Q\2IF-^V9/_.NE;_1D&JOKR23Q_$Q[9DOE"8
M"T<-Z0:>WRM?MUJ0(/WADQ^@IHNG:$;AL;Q.1;(ISF`,#69:PH1R?^)*BL0D
M%*=T$<<YE@9E&Z'J&34`%M4]*79U)MEZ>K_]="^T^`0/Q]-@+"]VC.2\'=ST
M##CTF/^3]0S]!B9U'_V/46WK$!ARSKJD@B#[9"_5W+G10F.-@J3E@;"I$G)I
M$;$>+\N%EK>PZRA(X:M",V7]5?/[QKVM4)-*[M^;-)&"W"'"J)&GDI`PCGF*
ML5>0;W%CE+LQ?RL(<RYC4HELMK2?HT\N:ZI^@-`[]2@L%6-TG08R9"V4V.F`
M">_%^<$6'UI136_-EK-.3>K$W64AO2DX;0'="W%7`%IKN+@8!(_S82W!.&Z6
MFPYO;R9LEZB(;&E,<3TAH>H#(ZQ0DFVAQ1G^=^ZYFQ$9^S-)+A7,1I(W!Q">
M_$3-8@L<\2X/+36P]_+.):+[&*M?1WDY8J<5?CX4R((L))03ZR^<:I3ML.L>
M"/>1%5L:_ML_?Q:W@L?]WN^5D%N,H8/IH*T\'T_@!_!\//'^_H;+Y8*7UQ=H
MH;%W*LG[>W%W2%LJ?-XV)8#UW<Y:IB*:,Q[W.Y[7*RZ7"P3`O1;8);YX0]:C
M-@*%(PP`/W_^1,X9?_WU%Y[/I^,_BXEVC_9EWB:DBE/__.LO_/SQ6A']V:NN
M<?4]\")4X)K2Q=LCJW5P^"YX3PNN3Z*UGNOZ10K$>;GA2CO]N_0*/44'O>GW
M*JI!%W[``6S\Y4.RP@$%"YI-:LN)>&_I#B`QNBMMZ?MDXR*+#&06T)@.7&0N
M3\6P-0RB'5YL$4<CUM,&2CT*+@B.50%(F'C&I)AAF13FKPV4E^(V$2!ZV24O
MG;Y?!CG#,&M7)U[DL`EV^ZB;1Q->D:$"M1L92-4>C)&^AK[6XF`6Y:`@M>PZ
MT%.%N+%0HE_PPIQ]+F@O6I((CH90>V%.;O&YVE/7BG]M0[$K8M*0UX9L*3V-
ME3RJF=3UV4XOD@AR%4`5!XD,D<VBH3D'CUU5L`MS9I6*T&32OK+F[@HQ"M,F
M,AKBED1*:S'4"9A[8,:I-2Z7$YC\.+X5#=;3M)XSN3`85-&,3='T>XX&X18+
MU8G[+*`0$Q)H%@NP@5Z)"`ZV4',`1D-.VW/A4?B9:RPF7EB:*$S@J!8PUG#\
MVK;K)L29M][@<Z'/>*2?3&BT;E%ST'Z'A6P1E<6#3V7=2/$]-/,C)\Q3V]AW
MCK"G?KE[<;N51+,M67[LC]<7',^'21&TWZ=3HY8UX[__]=^EB#X.W!\/W!YW
M7/<+]OW2T?K;[59075CDLZ^%9,O%UGEO;[_P_IYPN>QXJ:X/S^<3NEE.-Z=3
MOK_?ZCD$^X_I&F5:YY/,0%3A%UO+P^@Y]MVH<>*`M:+T>P1K>KX+WI.1^J=]
M>#_AAWO^ZQ+0YP/$[W.'\>'?K?U^XTJ54Z=.OWM1F'V]_AYCB*RK*I]2O#1&
MLB<7!J>&5<,-'K9=HI-I67S<:V8!+>RN8-%HJ.RH'JK+9`>.DEPU:E-:D5CT
M8(`^)^E/C%R'+@WV21)C(JZ&O_M1V(-0NI33X3@#>@ZMB%$%<4;[0SQ#G]?F
MMU4(:"@4HG'2'L:XO13(,$(31GC9<4`K4BM!S\&\1Q/YVHXCUPT0:?*V;EQH
M[4*H^=$<1;^]3MIY;:D["/!O]A$]I9]MLO6@";O9V9CI;O1.-`?.N6<N:3O*
MK'$L;GLF&BKEO9\/1_E0U2FV]LC9!;%I_(KQ.L`H)&"0.&-#)FYC#9YM3C:;
MK>WBQG6L3=;?MY^C>T\,K4-CX,;08L3&H_?S9/2VOI,CI(1'Q0J77&R.15M$
M;!O=+]YY>MBG2GM8G:?>'`JL=_)4?"Y22W5JS.)BRGB^IXC+S-ZQ8N-W,9P)
MGH\'KIMU6MBVK8_T!7,J74/=C6]O5J@>_1".XT`^#MSE41'D2H%I:U/=N!(]
MX-U!PCFCH(KC(,#S^<#S42S,`.T1PONE<(4?SP/[7F*"[_<'V.=6P7IOLCP-
M!8CV_85IX@OXD&9$B5+4YH+K3.@8O0/?!>]O(+SZ&Q#K>0%XEB:ERY_X"E%`
M>7%9#N_EY#ABY'<JC.6+U\9]D(CS`'5*<G7"*2.DX[&9N#9?(^9F&RDJ(7"#
MQ*M1>@3%&:ZOM2T">MX[YCA+@3KAN"YH()X6&'D>+^REW+@T>KZ,2,ZO2#)`
M2/91911(86/EF`JSLJ[S14$.FLTAHEC9MDD?>T)LNI>42G+>'!73OWO>H$>B
M],2HNBB/47'01F5HL@OI\;UV(V>49Z!HQ4$AFZ,HOK?2>=$:N`OPM>K(:RW"
M!__2CK$E"3;L/?FH352Z=R\5?D>NQO75D[=\QS$]@RUJF$?ADL;Y60H+I;RY
M]YJMJ))QRU#BPB9D/88P!C:^F-]7W[Q.3)LFE'&N![-7[UPTR<)_G-%$8;H,
M+!7!!F:,,)N"4,N4EM807Z@3&5(1&ST;85'N>+#M$'-60RLQWL--G^C0!G4(
MK3^><'^5>4TP-I`R'"R:V#6Y]UF#(![;P\U4L1EA5ON,4%)B;\),ZIM86H2,
MW[F]WW"]7''91WFU;SO^^8]_XNW]%^[WQXP6A[6'])1AV^AK$456MY9DJT'#
M$U;Y>-1:>+^/?O[/NGX\CZ/?RXNTY+@\N,_L.P[%Z_45SUQ"+D!-;M:8I#G\
MA<OQ;MM6"OQ@?,Z!*ZQ[49<K@,GK&28][KO@_2U$]O=<&K[VB?HAPOM[Z67Z
M&[\S%\[1V#W6\)\:K!GJYQA1S3Z<T<A$(KXGB0QHA1L+.M9*:_X.,QIQ5UW/
M6A?58"Z/F7Q/2-%9`+#WVA!JJ97].S'L:+P1!%]G0WJ"2W>B!=+I'(QG:^1:
M('!J:\^I<+9/D6'_*D8XIC+/Y]$'$97WU8HEG8J1L8BVM7,\O3)XO6!/7YT0
M_+X13_=^+IY'PIH,I-@57X-*00X;.MY8S=KM@UAX$_E>JVIQ!&@[)KFLY".;
M?S<^O#+XRC+S@)!0C.^?SR?R<4Q"IO;/S9:KQ:@F0KF+K^?6-]NL5-P$S\"V
M%2_0Q^/1A6H#Z4MUK'_8=]`EPHP-4^ST956LT9/BBT[^9`D*3-NLI?X,1$AN
M1IYL%=M#D1QR#:8$U1,P$:S&V0#NG4N3<-"Z'*`*!\M$(7>1E*63>`<:SU56
M)U1N/-NEKRR]SV84K:`88EL(9RKV_3HV$/6R\WB*AKKKTL->W-ID&B.U3A9P
M"9,B#'0(GL>!M_<;CDO&?MD*N@O@^G+%D0\<A^)`AA[9%=]MVYJ+MM;\*-VL
M%E/<[GDRP,,01#8P(+OX[(QB#69!B0';VB%I:7;+\_PL0,.VT3N]X\>/5[S?
MWG$\C[XV'L'DE=F`Q?>W'-L??_P#M_L=[V]OQ?Z0*E:I695*3<R4"EK7.2,Z
M-=S&;X3WWP`%_SM^7W_[P_6W"]\5E0-+1/4SI?(J,$P]"JPTN@U&YHP6SW9C
M,GV7#2.0Y27T=D""$?=Y;J),BFN5.4*7/E^#$8!^%)D'.;FOV@5OAN_7(W"'
MLEO4Y?_"_BN;$.3H8)T%#,06$6-O#H;T)!;C0L_P!;VP,.`.MP)=H:?4HIX^
MYL2(@F)Y<[V^0$3P>#RJ'V6>A(`:CH`'L@H2J'ET3\Z>%$HIZW^68`K8:)ID
M1M=9G?!LA`(T0V!?1[1B(`<A*27.5WH4:+NVY;KDSO?KF[LTU?KP/[U<+L60
M?MNZ[=%\70:"7/QT-X@D;"GA<KW@<KUV+N9Q''@\GKC?[S5.V#N4E*+]>GGI
M+]>1LT'#E4RH)K&DIP1XY-ZM$1(AM(O`!*9JJ'>[]^_.8BK4U]:<>U1R]%UV
M;0RF,'P\#0UO#2R-TD$.&BW)*J4T:"SUJJ3:^"09U)*11":=PN,]>,/WE8JG
M>9ZM4^$R'%9@T'^V,?/I;4I!("(D6-681M0:N@*L9&MAR+6?!,X4Z)`])@_R
M^K*^O_\"\(K]^L?X+%6\O+SBY?J"V_V&?_WK7\B'=MI&XZT;E-8T].1`0H5Q
M=C2V:5G5^;E/4[2QM\=WZX>`0BP4U^N.__KG/Z>UV`I\`W3=[]N2`"3<[_<I
MB:U?!^>!G>DY2["<;'.;V&FG6:%]5ZQ_L\;]F_S=C^*(STI?_<VZ^W-4AG%R
M?A`/L<B6]<-;!5MH0'W0:M_ETJ]$UC`Z"9/\R%ZG$(W`%S+:=!R_;HW`RQ*!
M58?&K=+DU@^1[3CX+#KOMB[0/0YV<8BL5M;H_GBQG$=`.])KDZ+Z553+JP45
M.`.IE7#,.-*=K(#"C&5AQ[^1V<?P-A"'ZI5?N%111U0T:!3I6I^/Q`V9\C1!
MC35>%WA*,S\O>`DT(QO,1.<D,'@N*6W:R9U7C@N?\=E!PE>[!WVC<(4H+#I2
MZ`G6']N\\2UE*25<KM?^^YX[RT@J*HLYI81MVW!]N6+?+[C=;]W2**6$R^6"
MUQ^ON%XO!=UY?S=/?LXET>EZ?>+UY;6.VIO1O16L^$5.@^F+%<<-01P7C$8\
MU28@W9TAV?0U+BHY1I5&\J$.8$Z9Z5QA#KR`I[\0FJ_!,:^BQ\6-;%)4R&/$
M0JN."?&>''*-.31B?J<&:NG3^!I2UWG[4^RVF"#-Y+W',PS'V7KZ#B&CD!IX
M-/NETT^M*<A*2[,"FHI`L^]SF..Z=:8>F#6X?716Z-'XQVGPC)/@Y>6*Y^,%
M]_N!XWB.0J#'Y>HDNFD<7]\@I!!=LNL+3RL9Y14"*J:):2^*,X[GLTQ7(+A<
M+OCQ^FHH-7_^^1=RSGA649Z-;Q]E;G([7J[N%9?+%;]^_46%/Z:U"DKX1GM7
MC%T5R=-"4Z/OX(GSL?07"DCY79Q6=2V,"L8!?PMDEGFLORH.`UQU&L5[5,[-
M=V*H5]`C#1MZ8[YAU,(SMXD]+L_.CQ!(-<5N[#ELCM*,1,9W#M6X15@,6G?B
M=QNAY+IX'I;M"*6UC69)3/$S:!=T/P0NW4-!#DVV$U<-F@1"[]0Z/[)WK5=A
MKSB-/`[NL9O<\"@5L,)4%YWYR<:=H=RT;=N0MLTD6RDE<?GGME'1NF684DJ=
M<PDIQ4+BAW*@^NK<5)BS2<(.3Z_(Q$GE:S?Y-I/:NGF7,B+-3@`#";:3@E0Y
MN&U\S7QA.$-^'JVGE/#Z^HI]*U&B]_N]J[4MVB;#4:-N[*\_?D!5\>=??^%6
M[8_:?=GW'7_\\0?VBAP?1^4`8GC*%K','=?K"_;+!4<^D)_5J+[3168Q5K2F
M*W'PQ;DG-*2U/Z>+ALFL@Y%=#0;2:'RK.5[6-+,2IKY%_VZ:&Z<"\H(NBVC2
M&+FBP,H3CP`QCL1^C=:BU98K:QN;#W5(UHQDPC.HV-$\V1:.'DDF6E6/M98Z
M?*]9*H:7W5PJU%K<E<)K%LLRA2I!*,6QK=%BBZ;D>,S0<.,U00D0W.\W0!4_
M?_[$]7(Q=CF;;/CYXP^\7`_<;N]X>[^9YA?\O&2UCCD](ID;&W$T5J:FN;U/
M=?8$GAJS(KQM#7>)"5;\_/':OZ1=T^=QE$"+1[$JJ\2::=OA$EC8M2AGJ!Y%
MX)I+5K/UMA_3+#LET'Y^:5&M&-[^-\+[[_G/!RY+YYS?K[I!_&WN0I01Q,;E
MY_BF+DIS@8VMC9"GOI%T,_EHP"=?P%<#)$?FPE74HZAQ@6GHOHZ**WXLMV2F
MR-)>3/F`(^LP<7'",P2)N)S6-5*O.KW\4D>2';DCI$B=?%U5P]$8L+(<DBXN
M$GZH:('TR56ZV.AYU['HA#IJS"@H4BH(Q./QP/U^QV7?N]IX:N]XK%U7YVZ"
MKVUXAFDZP=<H=20\]<0VK>E-TAP+"+6R8UB`.>XBOCD3%VU-Z*/`(*U'SD/!
MGTN4KN5)5\0J236RURE,P]Q'&:A/06%_X++O)5'J*&B/1Y$8L4\B_?=$!._O
MMSZV;(EM?1S[ZPW_^.>&E!+V;2_7[!@0I:+04A[/>TFN>CZ@CX<+;1&;4!AY
MSYI1M1IG#^^-^^&:[!9]'X!@"ZQ822[!.^'%FGX:P,\'NQMP(`J_JT70.6,1
M[0]ZU*U[QZ+5I3SOI<A-QG9FT$5$1L`#]VN9)H4]PILN8>YI6.@.$=ST*`H?
MM)NO$5?7+[C>D:`5]\FO+TF@AQHT66HL^NC_,R4ZRNF^3RG&W>*R4'4R_OG/
M?^)RV8V0<M]W;-N&R_6";=OPZ]=;Y6A;[]^!?'NM0VO:,C7J;M(C+N*\T9B@
M/53"8U3F?J=B([COQ77B<KUT/K&?W'%CS<R/:3^2*3^3WH=HEQ5#,0'K(;):
M#GG63D/Q:7[?'-[_&Q2(S_`C)@I`_&-?J7\%A#1AYJ$N2C/[^[THB!%*D;CL
M&FX(#<423D(UR6LKZH&$R#$Q!YH+P\R^&)NW.9'Q:HJSZ#EUZ'`V8R8Q6!8_
M_`%*/U%3EIZX7@\EG<O)/I*,UO&XGP41*?GK6S9&5(&%+C9?"005(QX7)+T-
M8I&C3=_M'`J?Y#9?(0D<)-JY[OL%*27<;C<\ZQCNM1<6;D/L"^:P8NJVOB)0
M31TIE86!B<B@/'@1W7".T#XJ3EL:3A82)+:A43RR17@9R8,3V2P4^)UV5`N\
MA-1#`0[-X_Z90(9R/%NE'$A*^/G''X7O63^+^=`LJ.H%0OVPR^52>;H9C\=C
MC-?5MDVM@$XI]6*\TP%(,/7KUR_\K_]5U.^/FO)F4%:Q*%`OKCG9BV@;(?@`
MU_7ZHA-DE47<%]\H^*([GS62)VN-B>J6\<[8N%@LPG3$"LW<%,<7VY/MESK?
M8\`4HD6XE(Q(,&<UWL;-5WC8JW$@Q#A8#F+HE)&4)I_B1F5H_LJYCOD5@"8K
M<N-K[74$/5$OV1`C!<=+*WMNS5,#1Q4I;`:!=RM_/!XE'$)?L.^[I=#4^_3C
MYT^("'Z]OR$?!>7,6<?RSE,(0R]S-23O14'HC[K&O:R_-0VOQ2S3L_+R<L7+
MRTM!V.L$:M^V897V?`[\7@8'>@G!\'2,IHO3I"$RC^_/*Y&KV=N7J5GA_?JF
M-/Q'4-YSA'>81`\^DKW1&ODSB$Y`F)Z1%,BJB?.G.<L=9#G"UF.=`]@5QPPZ
MR82F1.-LJ>DXS:.S)^UD:S5D3/1-T5#^L^VE("L(4TN0F57T7'2T[PZ=)421
M\UQDFI=V#NJQ&RB1EG6Z\,/$S`A\A$(T=$Z)BZQV^F8A@F1H)8)M2R5CO0J/
MCN,HOHV&Q<_EY(BB[2-.-K:O"."1#VL3Y%HH$:N`SX1.3D*+D^<2/7#`DS[$
MT1F&50\C0&WTN.\%@2B>DC4[_O'`]7K%\WF$G.71$"@VV?HS6C9@&VW:.:]5
M-)721G&NP)8V;/N&)()'=3)H!=:^;4A;X;0VBR]`\'C>N]]NB<Q]HAS^N#:I
M&K-G'7'`!:`7!UH)-`W?7NV(D5+"E4"/W,5J*0U4LZ5.M7\_GD^\O;UAW_;N
MEWO4$>:Z72[W^S@.0-'Y?ZT@R(P@UF/,QP%<+E.812;^I"KP>-QQN>R+QE0A
MLF'?TBBPR')M#AL8*!ZCU.R8((R4,66'!\S.[DZIP4$TU:@<74^Y"8ODD_W&
M_K-S!O%,!9E]JGTCJUA;L''H0P\S:-_#4<O`9$$GE&8&L1.!Y3&Y-=`CYW,#
M/M8`_WY'[A'F^1-9;."!]F39,+'+AIHB3$3P_O:&XSCP7__U7XLR0/#CQT^\
MO+[B=K_C?K_A^<CU':)"M/US`YZ$PC\":S\16:*K(?):/^>R7R!)<'\\<+E<
M<'FY4!!01\V@JGA[O^%VOPW@HT7012F/9D-M#7>&D&!S+JAT"G0I`[B9MM4U
M)N)%W^6?OPO>?Q>*J[^)\$Y(9?PR^,[NJU4UCZDX6=2&"!!GT;6QDZT28C]1
M$>U)2<:`E!?F>B!E\].0^L#%7T>S:#%C2Z4N8O!^ODFP;_M`;7@3PQ!HB.0I
M*,+7=NK`88T@<+9$8^&3V,W0GZP?\<-Q_?C'4TH51?`QMR-,(&WE_^0A9?P[
MB1C*OZ>T=>6M#5^H]SME)%21CI'7RK11*W3\G%@*B#$\QW`2@$.6)GZ(+"8(
M8@M=K3#(92N%YJV-SNOH+:MBVW>D[8&C%<(8&_6(^JTB&21LVXZ<:M-PD/$]
MWS]-V-+>T3Z!%''6MA6Q5?TN*)"VA&MU-^BH9<Z%!ZM5XM5<#;#C.+*ATS1$
M/JGT`DUU1,1V-*[15*I7:[=V:LX,WLJ-GC##X:OHJ*KB[>VM^&2FA-0F`-38
M]A&N\<CGT0``(`!)1$%4XQG=;K?"$SXRV8[USLVDVRDU)[YA9C.1PA,L'.14
MJ1Q\/FU$#`B>S\<<UN$B<W-NJ+M6I%LJ\$\EK4/&@-+8L,AL\N+]P,.7_\Q'
MS)KB("AB@\1J\S,]<K@U0-0X^T(PY]RM[G@M\@(_1F!]@]R\GK-RP64+V#2M
ME7E,WSB0H0DQ^3EE)PBUOM\R^0C/>AASGQS:J^Y\YW"+<3X]T2Z/HE;[EJ;>
M'=X(ZC)*JMC]?JLN!U?L^VY\;),(-DFX[#NV)-C^N."O/__$^^U]3!%$D:3(
M:Z')%N1BLM:1%EW2TN%"B!LLP(_7UVX#R%.+5H2GE/#^_H[;[3;`&3?.%(H!
M][H_H3F>%X)Z"IRW<>0DMBY&%)OP*6[DK)J_"]XO8+BNMM%_WT?K9PMCG1?$
MDQ"T_A(G&G>W,6#0'=O-SUE\&"!S%+TY'WVA:0A`R<7.)<R*3J[P:TH1I80B
M.OGZ[(79-M;C,(*%Y%#;K,XDIOGR`55@8P5?`L&6"MKV>#Y[S.$YW8!5R!$5
MPY"-K(N'*F:<P2G$3WH8<?P2:5ZKY>SK6+ARPM*&?2^A`IJ?@5W:K-0_.L^-
M;(S(,'^HL\=4H*&"P[9,.UU&1'#9=]P?C]A@/0\RGR[LR6+7Y-DL7BIG%*B&
MZ6UDC_K<9<7KRRM^';^*?RRLSV/GG4GY]^OU"D5!BHO0"G6$'H5A)&RI\-M4
M%>_OE4Y!\;[%2W9,)QZ/)W)^XCBT%V![%=N5PE5*@$,5_:@6_]K"NYV3U3(U
M+`T];-9F_9'L\:68T"];8*JE?X#$7)7JP.ER-KYZ/%.-4F+@%D9*^P4LEF7/
MQQ./3YCR/YZ/6:TN',6;ZK7*4#S#2=P(%\!(<4L<K""4)E9LV7KDJQ-[^:C9
MG/,T!8M<#?A_1X2O.\[NA,(\?V)+^<:`2@E,%F_V.TTAV(O-U$5@_N=\`>G1
M:!$+BHQSF-T!E(O=^J[F2NYMT\9QO2U2K2U6>^&!W%T6.E5+IQ303KSI7&9+
MPSASRVC6E-R7G^D[VN\]GP?^_->?]=G[HQ2\8*%N12&W':A_]_+Z@K1)C\DN
M7/9G];).T`P<QP-IVW"MVH7&YY>`*M=0]K;OB93&\.7E!:\O+P4LR,6#>=]W
MO+Q<Z9J69^-QOT-2P@;TIM[[,T_T-QT!3*-HI;"50/C.S^N(LK9T2%ARH@'R
ME!I^U"GO=\'[I:I4?K>6_>3/Z;+(-H5C4("%WQDD`1ED@<0CP)K3:\9`"\J"
M9L6A1[<;*G2%PW7[=;'<HHV#A1@937=I(ULQCSL7)2<7)#D?.+B8I0ZPI72)
M`VD]W&+RUYGVT0M$P/.O^T+6XHI)0.>%?09%$HG'36:$WS.`C$U1/I[([[DL
ME-42JOBEQ@W1<1Q=[0X%#B=+;`V,"HV\:$-B5P7%G)ZT[3OP>)A1]50L9)MF
M9$0/;,/$A8@;D^U[*18;E6,ZS^>!R_6*E^L+WM[?1]QH\YY-`TG<][W_>1&=
MZ!!YP0I\&KJKJGA_>\?S./JYMOC?$H"1ZJ;WK`X'Y1A[45PC67=ZG[1:)K5&
M4;4Z+!"EQR`KL/Q5S?/]&-&^9"-*8J=\(IH:STR&`W,=7;!DSHD.3^8^.7"C
MZ+81/^X/O-_>\3RR=?H`T=1I(Y64@$H7X>N0->/Y>"`?J=`D<O6+I>F5S*_J
M$-+Z*35&G"[3>QKWD7VKE0(1,BS/.BHXV6LU9UT42H'#@-L(M*+E_O/YWOD]
MH%G1=8"C\F5;2$@FCC<WQX"U9HMB?KW@3:S_H14;6D6S1:3!Z"\Z'[C;,U:P
MI$SJ1MIA,M'JV;ZG)&I2>AB.0^LDWO*XA]6<&9"7QE+=?N&8$:80)J17I!2*
MMUMQ<;A>KQ6\45?X`:^U$&WO\W'D\AQ*XQLG_.N__QMI2_CYCS_P?#SP_G[#
MXWZW5"<ZS'W;\8\__BC-=<ZXW>_8JJ-*`PU2JD+8^FZ,Z&#!Y7K%_7ZG=:PV
M."G1HC"NLQ]?3^M*G<R85+8/..[=@,C%Q_=&KTZU6+3VS>%=H*(?%Z?Z&U7M
MHF#^5/#$O#B8144_=6+&`DKMT&$*@%B:DDT*"5X<I',+&=F84EP`$AKIY''-
MZ(7Z8M>L/?:`A9')5C3@.1*G@CC>Y_-I$*OIG*E`G>Y_'>T-]-R:GPD+@42#
M^^=XI#3.L;9B8HH[A6\Z>.4M/-KG\\#U6F-9*QH\_%@'NI&=\$@G%02CV7F^
M7\0/Y2)"JUK[>#YCOU8ZAK8!>M$/?S>/:COGG0YDWW=(+019J-.*\\?QP`47
M[)<=Z3Z0IXZFJAU]'<<3M]L[GL\G;6):`QK$>(VV(C#G8UCM.73R\7Q`,5!/
MOA:YW;LDW>NR^XRV8ZS7:=]W"HL(;-:\>P`L_:<45D>0N@4;0QP@?!Z9-.EH
M*I/7:U1P"5%B^._>*L<Q3W9TQ%&LG.-F#2B4BM<:@?P\\,@E5"%K[DE?792(
M.'`"V4J-.O5"<R]L4WL.^P:>!T^SZA'4O4-3>("G3!+%B*=N7$AF,U%0]V=V
M?!X5S;;!3',1+8G07O31O2W2QZK5:!`PX(+CDK?[08VEI3'IQ!<;]Q1&C)1(
M4[+Q<[31J+MZP[>B2R@M\&CN$8'S8KL'&U$K[$@]FX)50-\'2[,8:[L+G^^6
M:6/EN[V_X_%^@XC@CS_^P(^?/SKX-)[N\0XE2<!6ID!9=]PKC6"#X/7E!<_'
M$^]O;]A2PC__^`/OVX;[X]X;FY<:]G*_W[#7:5-Y3C/^^/$#O]Y^X?%X%">6
MVOGGNE9=+E=`RG?_>GO#^^U]T)0,MJ;6-HSV:6$ZG*-QIIJV)D*>RR)NHCFH
M#+Y8,'^.:"T:W_]=\/X/4Q$([UL6O5^-'?X(9_:_T<4KE"8SE6]J1S:J=AQO
MC+"9H"J6O=3,XH<+P(DMP3I-=A1C.#>R4"`PS%9H!C1EZK;%;"DZH1WG%U,(
M<>+1<5&BETTD-R%0]PUL+[+@:&A$A0'&N-<5V6[L9Q#X*E+:MJWDL;L"DN]\
MH9I<NLBD>1,SXI`K:I!=NE`KWDT(>4!NT56W5<_AR!G'_3[S?2D@8]_W&E&K
MCH-G;RHW#U/3(=*I`#[]J_W^\_'`&WYAVW<2.:HY5]'F^?J`R*.C;@-]<[R^
MFG+7/L^$7SB.9D.9_;%;:RN8PL,VD^4XMKJAWUP#P<?E'38LJI*[,X.YYN3%
MR?>7N8VCT,DC`$$M6FOH+W0?<_?*G)L?#G;P#;'Q]@5*,A4H^:N-XS-QF&OD
M,<")>#K9(\XN%VF,7KNU7G*W<Z3/=1V`!$E?(Y&$7`G4Z@,6L<P`B!LKTY]K
M]9KNYQQR,ZE@JX)CYJ9&16KN"79I%CR90IW=2Y@*$$VG#+<C7%]+;>)L!MDY
M)2"/]7=!?&J>&LXHH-AX@B96`]"*V-;TLFX$CC^JF`6"@H$2,P?9+A&%#H!D
MWYG6&+V]O>%RV:NG[0,OUQ=L^^8T$.-=VJ04L)#:!&\_RW3O61K&E^L%6P)^
M:D&&\W'@^O)2A;170!7[5JZY5%>;/WZ\EL].J3NQ0`$],IYZ+SJ('S]PN[U7
M7B_%+D>332[6&Z"@S6/7.@H)>2(/L@D)TM2%:1)HXYM&<<TTYS]]^_`N^#9?
M\L75KV"Z\@5TE[_#?M%'1^>_MXN)/OAM(^@(PC#4;:9&K>HX7H!+Z`KLQ$Q!
M*4:33U]H4\<LD&@-N>%>@&Z=(PE2>5!:41BV1EK:9M%Q:]#`E`+K@,AAQO%,
ML&^3Y\$[ELI]SO#"#E\$27!`^]Z$9@^#NK@Y;$VD&I8]F;A-)O)4JI5.WR@P
MAX:(8-\VW.N83)QY_F<F'-F%+;3"?]]VW(Z#1J@:!I;PHF9N2"UR$A7PF"*)
MI=,`<E;K0:+QA6[QJ1-2B3%":VA8&^%#,B&#P])HMI>2J<%A"[)2F.0A2*-S
MR;78V6JPAGFUVN]3F`1[_BI'#KL2L!6JN8L?'<*'H3COJ&808<KHH)@UH-`;
M)LX^;#B,B'VF&D*?<\*V5<&>X0139+8A-A,?E$5J/JR!AT^,1KIW9#7?4^;!
M)C'',RRWJ0@+P@JX&5?BJ,G"NSK>?Z07H^6Y4<.K]&M<Y!`1[7\F66Z!VGO>
M*W<(_;X8YY-YK6L3QE(<.=H+;4Q"[D*9W"-:S*S2YS+JO5JBQG2/Z#*TF:AY
MCT+#S*%KD&&-*01;"\68L]UB<X-Y'@?^]__YWR7@92M3GM?7UWY\E\NEH[&H
M:\^V#?J`;O68Z,\`X'*]&%XKH+ANU_8`]!.Y/^X]VCKGH]@.*G"]7`M04),1
M7U]>2F&J,)KBUBRH@_<B"N%,VBS_3<)":,?_%?^^S*:MDY6E<$K?:,:^"]XO
M4QH4T83^O!YF1VKY$ALBXM']5J'NO/Q6U`7UPW:)K\TPL]?`$4R[T$`C)@)%
MW#9NJU([9K9D5\\Q]8OM:SJBI(YI)>@$_X8"=B36%WG!_5#A_`,Q8YO&@;4)
M9TJ)6G".#XT!.O-8/3UD0DSK9Z64X`9#=N^@L5$^<OCL;-M>#/P?#SR?AX',
M&^^TJ7#W?<>^7PKO[/&P%DZ\F%7:AD`<,FD1*Z8:%#]'RS7E^D)-:E!#WO)T
M;2[[WC?!;=OK]XP4L8%^+D2:Y(M;_#W'G^=:V(W)2"F&LS;E>447,T8A9HPZ
MN+@%4MH(L1GCY,AJ:0KQH@V^/0<=U:K4&F^_U9J^'HV<&VTAAU0;\\J+C?8\
M+;X`2W$PY4&Y;L=1Z$[J./&CB$G(0A0F3IV"5N_@4C2FYO0@`DE<2#4Q7=U$
MD[B`D5@PUKB*)G6-%@7&';@([N]6&OZK$"ITG:\I`_<=_1([1>$E[]RZC.@7
M[#(SK3%Q#+!'C5F@-4\/!L)O.<*#P^X;]S95:EH1'P@!I\$0?TV;_9;`4&W8
M&[NY!O!Z9`KJ:!_U`1P(@B;9E45P0O6">9^!><UBYP@?5-%^ZLB*C`P<P..1
M\7P>A5.[[\A;ZL5;KO'CC<;CQ:)->+WM6Z%SY`+&;)UB<N!^?Q1-2R[W]%'=
M3*Z-]G"[E\DE@/?JM++MVV@\G+XLBR]A1QU@DBYA(^_%-'5M^C10]=C[7`)&
M=018C-<J$07KN^#]/1;#9T'>F82B#L[4]02H%RYG4;0."5BCRS@M=N&^EZD.
MI?N>!X-J9E*6HZ6+751UIB3,/5_9?)X=FCQI#OP&SV.,>CV>QX$-PW-VVS=L
MNB%W=X)C*,.!$\]8KH"I".&)'8V@.::6(6-=\;F]9RTAU5;<D@DYF[F88Q$]
MW-]ICW,MJ3E7['LV0J4R)LW=^[5<,Y!7\&S$SA9!0L;KJXV5"^_BF*"C,`N;
M.-Z$70%9SZ?][O7EBOU2W"F.X\#C_ABQQSK069'<4;&.+O;(SN0F%OQ2"8DJ
M"$%LSX;J1!DJ8^(-U^L5E^NEB()R[K9=X]S8]!Z&>L,-5AMI-VLO%<N#;)'!
M8O`J.X%AQPD-XK`;8FFXNAC&^FU,+G+,Q7D0*]X1ZIP--WG0!JK/:T6"Q7N=
MLFA*!"^OKWC^^6>_!N*-:2=!T;`]F-;*9D]'U`9=A:\WV[+FJ"!I"&V,#H(#
M%328/)&`D*Z)+SIEB@RF.&F=&QO^7CD)NI!%JF([!M_(L`O/_)T(!7-,>XC2
MYR?_7<0-U5S0@QI@G7C2$^)LPDE@]!Y\'@VI;4+)W$;DB28"C<HR44)&,R[]
M&1E4[X/D&%FMS#E0CN#^>`(H5+@__WK#MFUX_?&*9W5H>#Z>-6I[H_0UQ9]_
M_M5%8#]__,#S<>`XGCW>^^WM'6_O[V:?:J_'^_W>J=;Y<<?]^2CQ-Q5-/W+9
M*[+;"D4Q)9KQ/$2SCF2^%O0$%#]NS45SD@L=0\4,*HV,A74M0P,R[V]:@3B%
M#<+1;TK#_ZTR&<NT'V^^Q.KUCQ!>H4C&3Q["LCB>J0X?_)1^S$0>>Y$&<9MT
M-%),^0797"=Q-`/P9C_OBZ,@5N"9GYU/"VF)4X*T[T@YX3B>.#P1WQ71GA/D
MK6*MALZC7%@;+2^NH>>M`L#S\9@W,2>+UE[XZ(2Q,U52<\:]^IY.`C:_J-=Q
MM=^@VMBMC\/]X43I=1V9$SP?>6R<.E`T?MZ"P*#JERO%7S=M%4$\.H>ZU.QB
M%+IS8I)TRR*#XB=Q,<K$Y2-.^V1-YT5Y,BRB7JY77*O:NL0>WXK;03/Q;Y<@
MMXV5$LPT=R2XN5"DZB'=&X6M?,\SDV^F8!HQ]_&MMXOJ80+4>.4Y2%JDB&3>
MW]_732VL-V9#`H6F,6,4.KBJN9XG%U]<M*`A6B*X7BYXW[8R=:!CRV2Q91!.
MH%L:2C`5:\>B2LVD+J9_;;+DT,-6X"7Z.S4(HH:HO2_6?(,X4'H/B=!DAJZ;
M+U1Y?,_7MCWW/`D)$>`6>K+0.H24!LPBO2&&S`:]]FEOOKCU4=SMZ>(XXI!&
M%?@;LUC:^M*N0RU8O+F:IHH)<JH-T6":4L1R6^K$4(2\99L`N#\>?7T6`6[W
M>__\XSCP\GSB>BV<W-O]AI\_?T*K__7U<L%]VW&[W7`<!YY'QO5ZP>-YD$/'
M'$S1',79Q6,5"2^KZ;A'?$6-\)J;8:W"[WW?<2,+L?[;">1G/^8]1LAM&)#$
M):]_F>F-^2YXOTH-^`1*>EY:?J5,5H-P?O:;OHI"R]?J]-`G=_ZL.6:06]J!
MB`:<GHJB>6-YSR51&8I>"2QBE%#5HN#O@8A]`]CVK19,.W*^FX+0G*L&'4(D
MTD"R'$AVC7"E_J<>,_+);!9G=G2I-CW/=@1NDRC_>QP'4K4K:P6T\0FF'\_(
M!@UAVMT0-%543JW8"8'%53OXSITSP0%N<@#O>>Q0)`$N>['1>7]_P_WQK"X)
M[?FS&TH^M+MJC'`!/X6Q#4M'K!6&2]O'D3HLR++._+[R'"=<KU?DX\#[^SL>
MCZ=%0(@?G#N&BJ$8QP@(.(["L6OCQU+\2MVL=*#T@<B4?9.Y>6G/EHF-)5_9
MAJR+*+`!KZ^O>!X'CJH45_>R-%PY;6FBH?3Q+XG;VCWJOMH:K,4D\-HZG2/B
MI0X#II2$.-M8Q@KK--61*8@&+&QS11E[A'J>=#O?G'T1R][/L848_W-#BDO1
MZN@!:M=A[Z`0H:;#4G#02S)9@7%CV@)<HL\ZXP"O?'(C'V)?2%DZTVQ#U>X+
M'[,7Y'6;N,[3=05K;:),'/HT*1AK;T??R6+#4@Z5T-[VK-5@F1$-V8_A<KU6
M/89MYMN:FK:$X_E$UHR4MAIHDWM!W7S"BX/"CLM^P?:/#?(K59K7L%@LT[X+
M]GV#R*OY'K\.-7N_OG[52=^1CSG-54A_H+!BM"!B6TU&805QGL_A\]TXM[SN
MTA[,]NP:`%R1&),?H.^"%^N.^S.5[N<H#1/\=^IY*YB1PB]]E]]T4^TF%?BL
MZ5H4H>F/(KI6RU-S6J-58(:`QA?.9DD]S#?=#C$Q<F7LHD2=(&$(BHN`/H'+
M)9D1K3KUM.$M@=B@?G&MU[IYK@X1T1"0@>)IO8']=$U]EO'B/9Z)<!H&8[1_
M;U9L9;&4;E=GKAP5UTQ@]!0`9NOTS</'>!J4J4;P5@_(3.IV+A.5+++\D]*X
MVZ5AV7%_W'%_/*I?;C:K<9^.M.>@HJ--Z':PGVBR7L=C$[!D;).)H?'K[='3
MG#/>WMZLB\1(07#6.U+X?*#L>`R$J44EI[0!\JPCS'(=!()##RK6[?/UX\</
M_/KU:T)2V#^UB]0<Q:GQ;`T:I9CN&]JHO\4?$T^V;WF^:9(Q0FZ%/C=?TL;)
M`NR72W$`J5'1?#WY=P\*)R@^LX/WP6BEF`:=T+V&1JH5/_DTL>/(`0V@/>L:
M3_($U@8P*!XY".$XLD$9SV@*C)SZPCE3L^GM`IE?Z;\C<X(<K-]SA"A[I-JB
MPY83/*U_(D9HZ#>*/@U0<<#&(E*X4UE2OY]#*Z?F.3;7R?-^=1XC>J>:X6^M
M9C(X)8&FA)\_?W9[L#:Q::)4D_KF20_T'#>>[E8]U_,SXWJ]]G_?]QW;<^N-
MT.5RP?622IC%D;'M>P>>\E&G&Z)X/C.V.A'=ZB3EK[=?W:8MTL";<Y1XCY(Y
M$[LX%C&*@"'^Y@`5X5/OUH]V\GH*`G[;DOT=*/@WJL]/FN=J#&A^4*1ZGN_0
M+8H4X_N,;-P)HF+(J^YE=?AG;@]MM,/*3?D<.JX!VF9^UD80K8M\4LC9:Z.G
M8QB/EDR+&XB[U%/ET-&?WK$#%FU#XT"B(PY^D]/UV2Q0&H<$TV:?)++$&^?U
M:-0(C@<-KKOW3VT+,#MIJ!1%;Q.0W)WI.9_KY7*%HBSJS1R]\4TA,VT!L/9'
M_#BEK0@S[C5*>"BA!\1O%-Y<HQH'ATSCXGDD;F-&LWM?(M&F':FU>-[C>=A1
M/25K^;=9S'?9L>KC\<!Q'#U)[W*]X'J]XOY_[L89)1M$JQ1@U^L%M]O6@RM4
M&<V&;7P<_7R>ZD@5T*AS"ZA%NE`*7)(1NJ(YI#6)?^$G/FRJL<];'=,>B[5$
MT+5J3H35T>2&^M$[T!H=[SW,GN`#8<R=%J5A<:G+^-9^_6K#QU0#;E0B<5U$
M$XK^F<5XS,WU81@^)`)!D=R<&DQ81BW.SB@%9TCP<)304V%VYS6[.\SA$@+F
M58L1V3'5C\D%2>P[+C1F'Y^AAIZCWE5'9@333BKMG_!WB6;<WV_]\[8J3'OF
M`]N6L"%5/Z[4W^5\'*71UZ%'D5HP[GL1(O]Z?T<^GMBD@`%0Q?-X]@3"3F-H
M03>72Q=UY3ST'#EG/%L:Z;:5],H\WO/DP!]N%;L]V`D2-E(\QW364$BBZ2HY
MG7C'AP['T3O/3GC-A>:[X/T==!?X0AQP4"UV?]//VY^=H;/5WNZTE)0DD&PS
MJ4.JA<LR,)(7^>"813Y]/CHM@C-G0.9P1-/V?^1HO&T[5'/9&+U?*#C6D'Q)
M>8$^+?C1PSRZ6E6/KACF39:+HL,<N./TG8@.F5=F`SLDG`2<-65*!4M35TC0
MX10TSQ:>[)4Y1MA%;;ZEK88#:!B*(``NEWTDH@4(=Z,P^.=T3AX6[/N&Y_'H
MV>ZVR[=M#H/E+2:SO!<@3FO]/2$O2%%X8Z-Q;$V4"#NVAXWZ[4$1JS92O.C/
M%SYSXW"[W?'SYX]*R:FI8@TUDU33F+P@J7KYUHCC6+5*OJ_*UGZS<EK!:#[%
M/%.S(8G0W!;G2]9M6TM(DC2\<_U:IX./G*KCROO;V^Q*48\O;:EOZ`7UQ]B2
M&?4UR["6OVL)7JI0/>Q&3/]_%,SS-&44I+D+UL3QF-KZD@QEH3QWAUH_7$\)
MB-!4OA8I)1M:4C];R7*N/:,<7,$%IF^R8M]B&<X7@"TL:W$=-;VV2)1Y>N.*
M9,\1[MZYW9G&N@))GR;-WL-<U+=)G/*8YLR!!#&-[=R]I)VW\[Y7X'Y_*R)<
M`>2!;D%T3(WOJ;(=0.'W_GI[Z^?Q!"`5U.BV:)B?&8Y]]W3%]K/WZJ4.T^#H
M'$CE]"TJ/+5=7R,-:3P:E`0R[6$C2&EH-;R-:4NQ^RYX@X[TO.C5+P&]2^=<
M5?^X?)(7\.4*OJ`/-0DH24).>2IJK=-"Y,1`XQ^S4<\OGWQ`^6`:?R(UM"X7
M&9W5UO05"5'1USB'0-J*@G\X%@RCJ$V*Z*G0&XYP1.B+4']\2BES7FQA"A6V
MJM&`CJ%!N`@[>DS(ND<;"9&0SSP:.A;OFA(U6U+8,\]>/"EV]&K'H4$DJI;Q
M[[;O.*IX8J9T1,>@$P=&JH?O^_N[60"CSY,4]4VEN$DH%F,Z>?X.Y;[U>Q;S
MG#$)B%%D+T"":.7<5N8'BLF[UM([UU%K]R,^N7<%Y;U#\:,D(P%X?W\G%,Y?
M@UI('<^J\MY,$<0T$>\,`6>1-D?@SDUP2*9QG-V.D#%'O89X3*/V*O))=;RJ
MJMTNR:PK23I5143&F+05[Z(32XC_94N;0<9'H:\CZI;0<X[@]2/MTN2@4SKX
MQ?1B)2M,D_5HWA5Q/(7*OEG6>4(A;OU,Y`R!]BR81#%[8I\I1G%"=?`H]?B[
M.=UO%8DLXCF]U%PNDN;XO<$B=KGY'[?G/XFE5:4D5ES*7NGN\[A18?Y\7S_R
M>*;'GBNAIF6Z#3+N;T(008^8)]W7,*8(J6O^N#A=7$/F03--48Q7O2P;!BN(
MGB/.EX50($9/1+V*/>3KJR_#(_^[X/TDPJN+2E=__]O.T>"_?3+CCF<`J6XJ
M35'?D2/F".DY?\+2'89RV-`<8:,5=85(=]*\G9WV46_"0$^AOD;T@WH$_@!X
M/@_LE[))ID3V0?4[4QU7'L^CVSU-2-<G+G/P+KK\2IA1S8"\!&'<G(71%JX6
M>O[]1+L88^HQ\E>K/NN+(-,:AEW3_%P8KF--$4MIH^LHH4/#XU'H![?;>_A<
MP&'P)G6LWNDDJ8]9GQ7=75F?">6J^V:.'RHCUJL-T[@U8F9K(XU)IJ`,!?-;
MU?%=CU*45;_?;=L+*@[%_59C0-U4?V7\?^2,^_V.U]=7',\G;K>;C5L.BZ9R
M_:_7%]KDK1E^W[2-T\"XED<^<&O'>D)M&C9DM=CI]G;%!]M'!Q=SHBJHR^R;
M2WM>*MSOD5*(J3CK:6OU_=W2AF>VO&FFYQBDKQ4&C8O.!5<3*:7A`VM"-6P*
M.(K-&FP(0?<'G1'"YJCBN:3^/AJG@``][=,%CX@ZA(TMGO)"BZ$N]$?4-B1P
MSR=3"<:U=E.UL$"VCA.^.#+/<+;1WIU68HT7EBAXU'3P`:H#?08OFB<"3BRI
MMIAD;O+P\<:L/U&+;IJEI"8_3C[Y.GC^#$AGT!1#2KQ\>\>%=N,^90DT,'TO
M-M:+<%/8-1@N?7T61(8-9B]2MZL%FA-V"#+KHJ%!3/DK='QB$F+_(RX-OR>T
M^O\7POL[QZ\G?["PX/U;UVD6!2R2=:B7:R@65[**,][$#.EJ!`;*>BLL&]IA
M,]9A>6M'+@;<G9<I)P0&U4E$PMWHX_[`ME61$H_9N@=O1H[0W3/:RB*=*X@:
M<<(;BUHN>=#&K-('$5B7!@FV#,L^L62'$:N)*9;4<WAU\FE5GQ+?/^/Q>.#1
MU+8:68!52@=3&3PRHVHK')#B*:7:```@`$E$053?*6#2=)['@>?;6Q>^,5_6
M%P0"IXIOFTUS0%"8[TM<'.N,7'C>YS!3D.Y)"1I7JW.;5Q0;GH96/A_/8@2/
M&A!&FR+[]/K_/.YWO+R\X/W]5@2([2NR3CDWK9A[/)[8]TOGP4[HBW`\,:9K
M+Q#\ZU__&I06]M162DOS'K%)<-TO2*F<\^U^AVK&MJ5B!P@;(ZZ=;B(&84^5
M^SWQWK45F95O6HO>G`\SAFZHK'<X`(7?*&LBLBT*-5B\A;QY.0:[H^):2Q):
M+&T:7=#8,>^6A'=][5J(7:/TR,DFC8`&4P@&A2:/CG6!V$E07/OS\(AV]$PS
M/261VP9\42A6ZV&++_:QCOUY)_]AKS%Q3C3LNN.+1:VA&D-#@9D#/D:D9F_A
M25!OR,/C*'MU5C4>TTJ&)ZT:'R)@9VT*2UGPT;N6I$#WK+LAJ9EB3I,21NG%
M`PB<AV;ID4K`TI(0L@@46('"@S'ED.[_1,'[_TJQN]I4].3$%%\(GB"W@`_5
MA+-5PU+@)=&Q$KS/B399'2H[C<D_Z%(T(CO(%#&K4[47(7G>G'^@(=."J!/K
M8BJB?8(-_^WS."!5Y0RA$;Q#/E?/@L"*GPQ*[3!/73T['5FU?:E&Z*X&E39!
M".K18\>IA;:-6H/K$6^0'J;7;F,U/R6F-Q=*V,K:(Y,CI`IFJC`-"Z:G.4(1
M1J'%-`N=:"%L`V42U7C#Z`X(]AU3CID%7-*:17),<6T]M;KMFA7=E**X">T\
M3[<U>",131>BF-H\/)]X?W^W!4>BN%-85/[(!V[W6P^N4)?R-EWMJ0@[9KJ.
M>W3)M:F/BG/./:*44;?B6E&^JZ'!?IWH?K[U[]YO0^QCPFX4R)5#GS!S>U2U
M.U@,9([2$3D]C!K.<5P:PDFM2>I!$N&ZU^@#MNA=^:9[X55#)=.6G+5A3"D`
MG$B3KD=H!T8WS8=?<!/%GYVSFO&X?]]-L9$S5$:$[(J"8'QR@;!P'L<^6B%U
MFZ4X%'B]UUK;R(@7W>[K2@_A7X`>#!.LN9TJU=:(4MV/Z&L_Y!42X0JFIJ;O
M:;1)MM3`:`_BZ&5)$CKI1+\_PAR(#XP9XN5GS5<+XJZ1!VKRHK85HI>(JZ62
M`Y',-1)JP*O3T#>EX7<0ZD]8DH7^L_@DYW>"ZV+1FJRA:M.SJ5L05-=%&1_@
M)-(R_RPQ*FRE\*N!YW06;`7F%^BR*'W@Y1992YA`@_J294ROH4<()I1#X5O5
MZ><MU]CRB<3%54(B+B1]O$A<S#I$BJBCEF/CF!(KK6$;4]I(9U^$>ZF5Q`]Y
MF(8T-V9VM"R!G9"$HS/KAJ"3,M[_IUE".0^"L.#WNDDO-+04DL7+2(@)_^Y`
MK\=SKCB,#RV$IC`$EV2=IT\<O9E2*EQ6S3;B.:1WC'?A<7]@_[$CB>#)[]ET
M3<F.;&EU%R\]/O*T)53U&-@E52>(5JB%P;:E[E"A'#_L/\LCZ\XGN#C6:!_;
M>C&3%Z!Q(<LT"#:ZAVL06>5OQ^L2-F6^P.V(;AWA]R91'8TCXLXJ>C%CD\]R
MGRI,;A6!6`V(PP1\H,-TG3'3"B3-P1A]/33O;>KB/8^4MI`8=HUH"T3BZ^#&
MVM$$UQ=Z'<WLQTLBX0@/(CI%?TZ"\YS3V!K`(Z;#[N]TVR]\7#U0H\Q)#"8>
M;F&?:)AFHU]#XL7;#<(6_%`;!#(FBG,B9K]W[1C<7C`%*'E*3P?`B6)E*`DZ
M[J^@JAXB,$R6-4;[F^^"]W<0:ODJPFNKCH\*97ZH/R-@TQ7\[,;8I[^GGX/D
M(Q\!<\P:H,:&W[LNV:,AO_)H1[YZXV2JH72Z/NI&3'X$#1;L!USB0-1&&C6%
M#<B8:O-5_">/R=SW#76THUY(W(1\:`8BF".:U7MT:%=$6_L8']$YCR%E51LZ
M/L9(]$/8E!E5OE,&BMO\E2@XPN*>B+L75.<E3$,MKRY$\2E>E;*55O4P/XBF
MR.^;$)PUV.QK"A0G@I>75[R]OV'56O9(6]/L%@[T_7XWM(9Y_"S+0LVC2[XY
ML0=A&R;VJDB2G"V4V`D5H7<E);$<-XOMU,>9Z]AX0<5A"T?1:JK?8WI;(4^\
M76X^-$`BU=T?6^@VDP<]><?%A"CX9U)H.C"*[F2BD9G6T*9W#3UM`23<.8C8
M`C)JHNRS,SM%J.K'B`N)HN:FRPFB&B<8,U=]+ABU<V,-?8^:@8:T#WK(:!I3
MT!@D&6EMS2?=-XQ^UQIN!<G8_K$%G"RFQRS4`L8DAD$7G?W_C)"L$**LN+2O
M?3E7R+/J=?K]3\91)6$>5HQ`H\']3;`UR\3WX./,@[+1=XB/]FNEGQ?;L(O+
M#>90#`W6?`Z\L"6N=11/WR7M_T!!?')S/ZH[@'/^[]GO2@"U*/1K=FL??*4$
M_^3=UJ9QE'B$<+R\_-]VV,83\;,G3YN<>,,!4X0[<VR)BT_XD9(@0/VX"Q]H
M;.=783;9#GOC:,1'/[\:R:6Z:4L24_RJKBW;;#2P7<`D6)S]>$(^7,5DZ1*A
M/C;'(.;V]T36^ZI$5?,<N>,:G_)%E=IIT%@1G3TSW<<,T4=V7Y,(L89!K_G_
M4A**'ZU7/@TDB9\-!4*U?O?>%,'U<L6VD6"H=U<(Z3W=][)N*,^C<EO9^-\4
M/MI'^]Z3V(KQXGMFQ$?1O6L;EWKJ3'#<&'&GD[C4X3C,T\\D:!Q<Z/$L=JNX
M5BR`K0J%DL9(2!?P3ID"VW,W`AZK;T9FYP%K+Z:P[B/-)[45_'Z_R%F)#ZQF
M?8L01^LKK-.S%OXG:Y]8#;$=C(*H^X\O@C%BT5[^8/LL1:;2?=!<K.0TVTA9
M;KS;\Y-UMIW,;0*DBU0PIUM14L8IG-B1`BZF-4_%@`3E(@GR,1K<]C4IH#)J
M#671ZL66`1PM"K[6FKDU;0Z[:@T>'Q_;,#:*6<W**/>V7E>FGF74),=^/+#/
M:*H.$I7#FU.E9R1+P?#\<+M.]P/ZL&81BO<65P=(0!?4RJ__1GB#%_)#2L,G
M_FZ2+DTHXR=KVD^D$G\UN'C&[A`>GW[R4^1K(+';W.<\)XM)K<_.A]_,$:>S
MZC:\:/2#&MC_K:X3R!-WA!S`\HB";&*1"-V.&IV9LRN0]3-+ZEH]:55XP>"3
M4ET_7>I&]N)PSZQJ31\^Z\GL*`U3T)S:ZVBX8+ZY"S93I8AK3(ENKB=IB`NE
MM0E99W'YI=`)K3+S?->P6/L=-<V#B3E>\$]:O&<)[ZA!$_>[M>:2F+MKT6AZ
M][)BWS8\VD841<<ZPWSS/!IDG@M5Z[(A;K-3+JC8]Y>$6\EY>`+`\_'L''$$
M:[5"D0^%II%R58)?:'(C%)0A-)YN34[6CG8E&=Q*S3.?.4(O\Z*@8SK$DE=J
M!(.6[M#0S3-QFG&#(<LQ#;Q_^7Y'U(+H_(J_KW9[0B6!GD_2:FX[S"D_*UQ:
M3#:/WYEFT?C"P_DAT[JI?0R>:R'<$AW;1"I<$>LQ\K&;N'2*]D:=,G`EFA&'
M9G@OVX%(NMHB\2A7ZK7EN%Z9`25>N(2XU$0]:)Q5Y:;<3_!<DSH%#VDIJL7=
MX&$KZ-!L=<US18VGO=2MVTJ?,];3HG/(:EUD9%RF3OEI]SZ+G5;ZFJ#AWM\%
M;X1`_1O078&S9M;S`E4^B:Y^_)TS:K?B_LK).:V.1T_G69^_:I-G7QC&(9#%
MN%;,9ND^5R)44()O9PA/X?;Q^1K(PFS8C7A&!**2.P-6T.ML`W/6)`0C9.:?
M^6ME\^C=`DTZ/'4KDT:^FXC%"HS.KXK=T.,XOA1AT3O&X!*&54P7-N+X>H&5
MBT?NQ2(+VYH[0?\9F4:S4G9#8PYJ+8;&RKM@OAN[J]4X^.7U%2_7:[5UN^%&
MB7;E][,9)X_B5[K-$>B<CN,H:76K4`.1<.$9Z6/1W]EK-!5S'M'$V.28_M"]
MD*5X);<1?U]76X"$S*N+5N&?J/4(Y>*;$:=!%Z`BOXV'>T$H<Q)TV./,@DT3
MGYRMR&RB%R"V+;,>P)_SJI6P@7$T$!_;7GFH&C3-DV_M27',!?IP#7$T)+)1
MX]&\?Q8UF.#TF&!Z%]N/-%H#IF0T3,]@Q"U6M>*G%/6@W98P3]9KEMNC,:V!
MW4R$/D=<FNEDAT`--W3:[Q)%;/J)H2QJG$.'-_AB>QH%\;0GS/J,88<FO?`=
M#?!,?1)?V`LK!^:$4[_O9&ZP(8;FPK9%WSZ\GT!X?]=E0D]V<OWL[WP1QM6(
MTJ#Z^>,,HD3U$X7W9RBBIY]YXGEKN<"A;']9AGN^K(;9:7'C8]&[^$=C,4,S
M`Q"#/,A)Y\_=MP8+VXH*,:FS/^B(C#B'BCKHF=(Z/M?P23KS;Y:`#^9\?<>"
MIQ[D[DCCTKXFL*`Q'$RM\[7@&T-45!2I<ZYS_UV1YC2=NT*XB4VT\D2%4+WN
M@2D:IL6-$3#9F!FT9M`B[K=B/Y:KM9OGWUK#>]L("*2,%[.:YD^)JVH*+^+R
M38))-S7IOJ`GJX8&[ZY%WN+8['[?=3'FI(*4Q5-&M\JH&;VL_7>\152+#&>/
M8D:.W#F-<`P;'N'?@N[8!SW==_A<6S'N4=_(;WD5[&">#2,$%HKTGHO@QGL&
M^?HV%XR5]9AWC3#%L9O2M.]D*SEO`V:N`U;A,I'P<#0'&WUN^RSC?J%Z[ISD
M?(WY96CA21'/FZWF;`"&&I27&U-IB&6T][#(#?QN!Z)%D0^!M$&Q8G&WM[:T
M(K5Y?UVDY$UF9^.Z)6?!)V*38L5X9-,$,CLZ&J/QG:NO"]I@^7_?!>\'"._O
M4AK"G_P@FO<SG_=57V,)HF?/"E61\VI7/CH.Q7J$A$`[*8B1UP^**%\0J[.X
MT#,_.9FK>]\L^$9`/M$@&(<$<;9F5/P&@,4",&/O3YVBD?W&%G7=JWLP4#H-
MS=0C>H&8!/5H3"%&(#9]D.ODY^\=3Q=S(\V".B4<:<^(CU#%XI,IDY^C&!6Q
MP.BR*(::9VE=8-+ST4:!;KT\[<;OBSAP]&[]+VNFIJE%_8OC*/[5A?^9K<^E
MR.).JVV<>F*46D34IS2MU@;,N??<3)Z-KK/CC(Z-2D[\7#)R0Z;%1M*&A0[;
MN]E![#K%K(N\Q$3R=FXYC/',.-8TT,"L:HYK+@(&Q6.U[ZR$BNSK'-F81;S<
M,^2WK;U#'#?'ADL5<O'BY@6C9Z(WOS:U!D+)3C"Y;GHJ\ND=:HAQ1".QZ*G8
MWP7QC(.?->AT%%01@$=<Q&LPM?.(K_40%B/(,H]M\T>7P:E5OD0T`6">]G3,
M&E/R?/(ETWK$-Z'$Q!3V[-6YOA@N"_.>:0I^NB=#P*W+0#6OPQ%'4Q3C1B7F
M?Z,*Y3\2//'_<K%[BEZ>UZX+.S,]'2W\%G+\&1"X>M!]NE26984Z43/TDQ5Y
MY"_,&Y)Y^759I9V@ERO_RQDI-F/456'N9+/3..4CZ%M!+@L"S^#R8\#82'^,
M@?S7C-$8(;2NT+<"I`6=@$?S;HQIQT]B5C)A1*`!!'E1S9^A#!`3DN!MG?S2
M9S:AEAMLQJ$)+'8TGTF=B_%V;`5"9'4E\3U72F9(4M%`4:@FUZPP32)J::P!
M<$L$C$;2H\`HXJ7DQK'6UW?VAN,(57\_4ECD#DJ1M>'3H*&>"Y"/IEL#&2/J
M$MEYC5`&_]5,W4FS8P>AZUJYA5P\<LRQ3Q\S?&,))EEB;>QZT^*YCL1)]^N2
M!&XBW,QQ4A<767FQ9LQ3`[$6CT2S:47!\&HFY)&="C(E=269.-B>@M&G!0&-
M9=5H9/*'C]P@?.+='#T\(\K%74,"+G\1VTE#9(')L8)W!S-.I\8JF7<1!C3P
M]S:Y>^4Y]DWTUYL/6NJ,SWL38C=7$VU()KL:B(V%YO>=[#'5Z&58N.S1XU@L
M;#UQX?RK=0:'[*)N*1%FK^`42UJKU5(2^K/@&N\$/C>B5#A?^^^"]P,ZPS+L
MX-/V70%,^&5T^(-2]Q,^9T+CU]\A:CA]D[7W^D"@M/Y*]18.Z],//S,>#7XF
M#MA#NU/>`_,N9;;Y\@4VU^0QEK[V@940E].P:)<6GL#A%:[`D9.B<_*%)+FN
M&?\+IH+0TB+LF-?[KG[T1.>)(PP,AP>UWL<+J+&CV2E-F(,B.[$53*I?V602
M((6NX,4[ZA60C'!FFP<_U,')_(HO:K)1UL_A'7YL'8V+V_G*D:>?#5,4`T)[
M.@D\\`/)KGSOJ*GV"48OKMV3+$%!'3X7WNR>:39M8H#8KL]$DDZ6>F[=JFX,
ML=N)A*EAW;OV9#V)QOC,T9V/984P!Y0<&NU[%-XGFW%QN-RSG.N%_[Q6*.H4
M';Q5VHNXB9J:J-A$!1<7DDP?"&DW?G+#:.6PJ:@>LNUV6ULR+O(2<SBI7^8_
M[WQ7R#)&L]AR>:]E%%$C->3%',$ZED1\;']O.^()L?`HN];PY$/.-_VH^<FJ
MQ(>-A'6RVIXF&N)2A"R@0(C8L6PYSCS9[Q4QFCQ^1$;13^AQ/S.N2X@W_5WP
M_F:I><9M_-"?5[]2\GY@0"M?/Z<HP7S:H/C!%8OVN%WJ]#E6S%]HBDNA!W3Z
MW:_Y3ZCJ^8^'<M<9R>GV7A)SER0X437UO[BT('O5?<1E;-]D!4:VK%![;=EO
MLR701&BJK,1FTD57]AIR`;5XWMFPW(G'IN(-,&;_\[T@=$[4+,P194."H(1B
M,9:*<$H]9U.M91@`18))EVM/76KCO*$D9A36"[L,#8`CAH708-7N0RNKW'AJ
M6")?4N:,3L(\@Y07*[1F?]4LE)COAN`97'$1^;S@5.21V[)0(:)4C&3D2:0R
M^DL_`G(C[JRG1>?XE7(?.U>0"F?+P\04TL(-1O>VQ12N9OC52M_+OKQGUF1&
M%!B(OCJ/M5FF!;'#9K1-A;F)M0T<:B+/W0B5Y4*B6+C5%+&T#;H#%5=\KR:T
M.M)>"'JQG,-8XQJYVX)88!/%_(*4ILD5Q7Y#)U$J3[#,L]C>"1F:C!X9C%R;
M$`V:FD:?<HJ,+GJT'K,>(!&QZZZ:^6`@^)1%,R5L`(KA5"'J:`>VD;?3K#J]
M@M="J*$]2E"="G!.4_+3/)XF=6><V8A=#(IN-1`CA(1BE`,__6\?W@\H#;_#
M+Y!/_6),KI:S+]+E1TVQ@W)ZK++\OK-A].1#ZU^L!2O""U9]72J>2F!>'&HC
M3[$H3(L/R7^H&PV*:`W\;F7%BT2((O?S9'&,@@(&!O]`5G/RQ?D9.H;S'/;'
MJK[X@DZ;.1>2D9L%:\+9'[=[)ZM'E5WO[1#A[D7;`S@D>!YF+]R!UNJR_8LX
MLB+`5OE^:4L6-6#_%$[(`@L(U5I7]7.`&=UQAELSS_=^PKZ#%&H2)IH-^Z^2
M>&KB+4(,&APWXDH67XD:)IV5Z3JCDM.SK^K<&!+]'CZ>)DB\PD3);D-,1<>4
MUR*MR)[,<#=7Q7)`_<A\_ZOG:?,?;=9[?'VRB[-NUSTY&H`I(G'.?V5N<L[9
M/(=,S>@!'`%BSS\CK@GMK@@I3<?BUXE,T=-)4@E<H$",J.#B9+7NL>L^>T27
M:UCLLL^J=H/:L8ZWX^H^RLT;5F"<W7D]]!'@V6U0!GCH**W2[E>N69ZL%`O-
M2.@>EP93JO>8D#<Q)W<*"2X]7]@"O][+EI'V4-2I=N]3N',#17/7O\_:7,;'
MNZ<837J_II3NGMLS1;9]&>,9,UZ]-(UDX9Z?`G4AJ8YDP79\2N^<TOO:(]GM
MX'::EWXCO">4AL\4NY\7M>FB;HUD2K]3L2^0U54^\(DYF@#.1N;K!Z.?0*P'
MDJK&:T\C)#J(_>2BPX9\*3`-/]1"8"L$W_NF$`JCE-.N&M\_@2PV`Q<]['@4
M.E7M$EB`?1RY-UN@S4E[N8LCK%732!?S:)^$G%`[!1"#5*TV](F*HI%UF@=G
M)136^>A4@YRU>YC5<IQ)<$8^#95F44??N3[#(L4](0V:!(0Y8FV_3!1E3/9P
M="\4`7`.FVPD#DWDHL/Z`=LBUG<"6J-E0QZ?MRQL?I;>LLV@E&)=#>B<-.<>
MJN%]:CTW5>MHF;GFDMC-PJ);HC8(0KG9,'Z;SBM8;;.FBS"4Z3,7]PB3V-2B
MLUAPWR,!6?OG8Q7/&_S[$+S.SW_B8H[=%=K:D6!C@QD%Y**1KP>CMJZ8GK)H
M6"7OK<G(7[4]PQ%O5K.Z`):`]K%RJ*`YH%_GIGTLZ`RG,(3V/<[B<6Y*8+UH
M*<U,7>,I55O`*[TJ%[;,6[?HMYF*TE[2H\K];N>>A^$6-,X[T\+M/7!%I!>]
M:O9B3IVT:NU.YR%^/`33>ZU^7!KP_!7:N<IB;NP\/1=:PS-`=IIV=0?M_]\(
M[^^!N+]'D)@H0_IQ(:,!Q>`K1Z^VQW)#Y^5Y#K'#9Z^#?.Z:+2*TU$4OZ.KW
M)(:4Y01%,H6'\YH-D=HD\]>0NM2>AIJ%AP4OM'H/E:GWY9W0;'_=G=N#?M10
M>#PQ%N6)I(&XN@5?`G275WJ#TJ`9T=L-+QJ3(A@/KY/9%T^2$9;I><"%"\OP
M*`XC=MF@\'R=K!*XC2/%C*7)#U,D:#`7:7#`-!;-"[]BOL9"!:A\X/7-O;8Z
M+Y3,S9\;9:MR-S)H-7X4WYJ!Z?3D/%'0^]>NJ&']W:JI="55T"'`PKQV?IG&
M&-PCZID+<JDR)4;C5.?'J/X<(V.<R&8YNKJ<)&I0V+;DQ`CQY80]?VUZ"(0Z
MJHQ:B@@CNQUYY48L0`E7O%!EI##KM&ZPVP)S>?W4HC\6:7Q.3[]SS_#PUG5<
M:P@XY,QPWZ=CSV---2E_,P35D'7_CFD-/C'/;%V8+>]]/#.IKN>2QFP7+3VM
M*=)J1SBL%\4T7YG6L7[O>:^0@6[WPC"Q3S6)XD2`>CVETDTT0OJ;.5K=7!/$
M[0TR.^<8BA3OY]D*0M5OS2/#LG@28\9HA1L!Z6EO/62RO$10\C-N5I'MF+X1
MWD^4<1H`E/KEXA.8>;`R%4W_G@+<=H`?G]3Y=YP9$DB(Z7X2M=9@3KWBQP:;
MJ#BN4]1@\&9@N,@2G86C7H20^7FYKZ[($$29=.O/6GL?2_@<&@2[+SZZ3MT2
MF:R:F@5.4VEC*D+5H'X>613!9%?D-\GN`N"$2"F)*0Q%;)>>-4:W?`%E4&F7
M6B:$*B9)5ES2TO4"M"&;34RZ3Y#OV0HZE0??LCE6"'DR1Q,A9U`OF$5.(SIX
M7&.;N*7&G2%)FE/%>CH1QK-1-V)&X1/[H"9&-9,=4IDP`'92L$B5'S\:=J,;
MXZ0I,7`U<9.^9_>BS04%,,HM-7:JH]PI050A1`>($-CH4?-<60W<-&8?Y/&S
MR4>_^E%^9#$8^<[Z@ME%?GMU/`NHVCUN'LY<D*[H(MXMQ(LQ010`M.L.:]V5
M82.;X<280T[AO+1-N!#,L;(8;L0*Y\!V#/7=E_X4KG4`<R(84_GX'3'.'$+(
MKHY&/G5.::$`)7I0-[CUVR':4CFGQ9=7IRH"Y+H!7=B3J?/*KL=@4%*QF4C#
M(JW'L,UK7CC2&/.9UI"68TG#.0+NRYJ5I<FR(7"I?ZZ,*I^XN(8^/#G\R&@>
MFKCRNZ1==[,QTN@FW5\N3C6>"Z\*:/F(BH&I^S\+8UAYVXK#!;^$@#?>4BJH
MX>C&';_2SB(<6CL0E@FT<BA(JARIAO8`$N#5.B-L2[J%AM-Z.;D/D3G%,M&N
M=?@KA$\^MJB8>*PBV+8-^V4O/-5H;B#2BQ5O1-Z1!QK!"Z$%8="&:S1.GW\J
M)%)D5:5>S6R?9\/*<-<K1G4-K-(14>8&\\B6$=Z.FA)]HV7X\`Q7/==;^#E/
M)J>>-R=)J2*A8[R^I<UP:<NU3Q\M4MTR*E16^P))+5+4.>:+!+KQNX'UE6`:
M.]M;'3_#[7T5[3W!"0`L"R>%&3A6Q91,-W/=,8=1Z"K:5]V;S\B[NNM1?9![
M(YC[[UKDVMY?#7Q4^;V,DLUF+V<):1+>=LVX!`37U3L]A/2C@-<;7KM@(<R:
M9]%EP#7VKA@1K8&CH3.YF=ACG46/2I'9YKD+-`VKO4VIX&*!(`RMC8(;E$;H
M,A#XXBNFE2^E4U(=GSD#%>6UT<EEPWO%>]<-^(FAF;31VB4$28LM.$<SM$V?
MP<CJ_"RPDT]M0AAP883?T+V<S[':VH'#6-L53($#A+IY<?M^D>_@B;^%IG[H
MQA"-5W\'5?X`6XP28&;@5$+J`)8()!7`$H.<_--;'8T(+13'<<!/]\U+0KS"
M-N;*38P1E)U%A+29_'`1'?R=D\$^P'&#&I^,45K'@*P@MDPY]2.>D"27R*2P
M""W1']0@76/8M:6$Z^4"`'CH$UERV7@Y_`&QL,0L6M-,F;IC':@)%ZD@5)0;
MF].-T%M,L0;E1,/7.;9N@6?EL$6?ZG)K[6TK\C2W1@,-9>Y>P%4CM`802JZB
M&4,AM9JXSX&J)60<0,Y(J<3YZE%YP<B`IGX<#159`/HQYND\D_F^];D2Q]KV
M@C05YP2B+'"Q9M:33-&@=0P]BOC1U'C;,R5[)-XM$Q<$T##^5]#0<IGXC'P^
MR-HMM.!1=`S;*AAW`2%4,=O%J:)+[1:G)%1X6?J*TONR2D#C1I612N]MZWUV
M):7N;\N4*6/@G]>HK.?,MB+4VX.%QQOX_D9HMC\';K;:/<J:S<^WJ0\?7[NF
M.>>!"-?//8X\3W#"!B&(5*9W6HG7'G&HQ8=A"/'EE>O%@4".^]N@9)A0%?#?
MT[)R]DX;Z]KFL$`OD22!'GHZE>C.&43IL/,]N\*HBJT3C`9`/RAIYJHE-QM-
M]TLA,$0.I_TX1<T0+#,MT%`^G)7=*@O@VX?WZX6GO]EZ4@A_-8(W_CGIA=TR
M[`#!>"$H&C[^+HVG]S*7S%$WWCTC6Q+4)\Z]=9*2DDUUB:@1=0$?A6D"$$36
M0J9BSK[@,B'TXLOC4.Q@HKC,,R`<RRB8<KS-Y&?RYBS#EI$-;XM!A:?@DWJ?
MD5F5H+B.!#%M"A<9V#OO6JA!'?CXC3>#R+(ZXP++4@_B1[?9:7E'"N'T'X=F
M#OLC.RYG"D;YYSQ&;%T\18B+F4D*_5V:.;TF,<DEG^F8_0G!BP+%ON^EX,AW
M')GO@1CT*7[RB*OIN)N3K5#;>!K2%J!"$)\<Y9L0RP9<88,``"``241!5+4$
M/69\/$HCWUSCB@TUHSUK68UO<))1;(II+%E,B>EWL;!E&K22V>:K\WZ!7A@C
MF%HT2IA!D&IAGJ&FJ1_(NGV_?/V1`VK`$'1I&$\K]5QT0LV3=1:A>QNAPAX%
M[.$F#:GT`CKW&GC$F=\WGX;&ZZ[`AGM,P1*]L;)4*1,,$E$X,#NUV*(\F?7;
MX;Y@]Y>H@.;U2OSY=PO#3+[+8PUL8E%*4*!G6.RT(5!H3\$576CKBN6L'U8I
M$E``_32D",2RL[BS:SN+#V?*2Q[/.\?]ACD[)/8-4`Z1>'JH.F56].-//ES"
M3YTHG.C;ENQO(+SR05["A*.2(OZSW]<V,6O*O_ZEY4@=;/(TSZSG?.Q/G'CP
MYSDK\G$@YZ-;])S3,2P5PE,8_`A<`>0C]Y=LE5BEP4T2&N5$]T?=5-S^OA@A
MV>I"B<8D%<$'J=)4`'3EJ40(K<N<<'?93:RFQ3KJM*U*5ZT/I([/Y:`-*WX*
M1`PDXIBLF1#$=*IO-%`WK>0*Z&%5E`,DC>UR!M]2+8S01ER^"<@D_M%A-30*
M4:_$G[?0,5H%"3-8)3W&JRDE<F:@YU\Q(>9A\8)1)*64W&9M_SNH/PA%BO.C
MJ-82:(H>7K_/&D06LP41/R?%6BJ'**,_5U24U<8WVX5/`_$D%XF+BGXN$H36
M`K+.ZDV];^9T%IPWV@-[/G/1:3C.Q*_4T'DBBG'&A'!-P,`2K-%1\+OJO-_O
MUHB1!1GS?%NQV_Z7D6-O+^6+K7[_:2T1XI3GK%-(TX1>YCP)9(5X<S'E`0:%
M%VHPO>APA?Z*P*S-[<]RH[KD(>@5\$2B>0`SM2$W2YC>3/*>V`K2AC!/SW02
M,^7U%)5H'_76E*%(41`Z5'A+L]:H)I&)6FG7RF0G+9C7E?X>83C<1,)1/E;O
MN\SOF@1^WO+MTO`QPGM68)XQ+T,FVH>>J_9WE1_FSQZOSF*QN?#VZ.Q'Z/-Z
MXPT+_<CL7&V83*K=\+9M9L.>OGF*4%*K`)6SZT\OMD2;TKKX7`GE;)UK7RVU
M==5<$`>"^NZ6T)6VXJC'0F,Q,0AVQS](V"%)#+HP;718+&8L4E`>)07*?CA^
M[0FE!HMT*Q$;\VNNI^.:<ORLA(IXUQ4QXN*#,'HQS06=Y:=J3!YVQ;4:7T\N
MMGNAVVFAQ;M3<_FSX\@5!4U]X*A!T<A^ISZ4A-7C-L96XV[N9'PM(J?V=V:4
MVJ^]3@6^+D(`4IHG#B$2*<6B,%?OST-S55@GS%XSM6@\,G(58%F$TEMD9?O<
M;PE"W'>5H?(>_J\RE.\BT(01'&+H!YX"8)_K[*R_5B-!C\K/-!XQ1=JJF,6B
MJ(`ILFWCF`E&:P5^Y.+A/7C9I]=,$X)FMTWGV*,U=UYNG:.DA&T;PM*<=9D*
MJ$#H'0SGJ9Z/W(LHD<`M9W4=73,@WNG`^U8'L/#PKJU4O2R5OK0![?^@4#T@
MB?R%R>U`E_<WHD#$>[7QP350A<X%9?"Y/-X;[CYTCJIVJDE>PR.D1JR/,+LI
MJ`83*G*@H":\7?^L@:6H=S<B1/O;I>%W$%X?HO"E#_N8\>LI!BO;H>7O."A1
ME\78.)XP7^$3CFEFA/<9]9Z,8F?;4L!3I!=G\J>-_DD6B4)B1BBF"S0OLOMY
M\0X$P6QRQ:[FW'/'5^Q4A^C^"Q5+0?%MIOJN^%>=5[[F:2E^M$-':\1J,I2L
M*E'`!<<U9*.J_]0[4S@*XPC(@HB1:<L_12AF\((4'Y/LQ]$V1$)I@\J]Z`7F
M1+/A":W59%YMVE!M5,;F7VD\WJHC2>@K?!Q'^7GPM&)&CWT,:;_OA*;T:ZGK
M#5P-M6=P0_G?4Q=883D*UVRI#CT-3SWB)09U:XC=9-EGD/,Q2LU3,=S6!,<_
M),_=AN)FLC]B1;U2>%.AG]3[%^1K8")OR;*P+/^3S?UB)'1.QPH<'01AO+$&
M4ZYP60U&S?Q,&TLPEVHF;N(C)GZ,W#B8!TQ(NG\?/?\8/NC&Q52:I#CC9*&=
MN@$-FE"1D`_*XW_?S$:H;]-)1`X9S)_VX1_0V;_></_)7Q[JG4[442?([E`&
M[29W[K%.^?.MF4Z+M#CM0$@TCXMK#3.ZZ,7](-1E$]]K`1'&&]C%*FLF_^]L
MO(*-'[=8/_=^%FI#2.SSIF9F[=,.QZ,\$@N_"UZL'1H^-I'Z#;A8Y5.F7>(Z
MEK[@+$C?&HW(];Q8CSU:+?KVF?,?`BM\J+9K@JO(4W)"EO`Y\9Y&';@&2+$X
M?K7&L*LN(%D>CX^B7"84-,PI#LZM9]'G'(R6A8(@9AH(B'?9!"$&U70%0UL$
M-D+355UJ6)YK_;)IM<5GH*_=_0&8[)VXP&)$5E1QU"+#1G"VD5BJ&YY6;MP!
MI]<;UXWC?8,B455P5"^N84M6F@%.+S.V3@(@$\HM5:A6_]FC.;WH;?RPBD1*
M38)"+CM22@F;)#P?S_)]:=U(]O.(O$DYPM073N+N:5#L(N3-B>.#KAG_UA[*
M-D<YCSA><<7,%$KAWF^9+,EPFJ!F3D$&8BA->(8X1KA[FK9;$#H2*#W;1!H/
M]HSA)^PYI&I\E5,0G-!-_BD&>-`\U#17EJ<=HWYG`BPSC8`-?.";*N!8ZWK?
MLE8*Y`@H\:+7B`HP.44$?V>N>\`['I9\,A6R$H`8_6=U\%/;<M?0975.E,K1
MZ+61-RCVPA$#CJ;B$Q^+H)/%<2/;UDP@C?"W(4=*%HY>=D[7O#[+C3'0K`0-
M*,O>\73L$S0D'QEEEHELITAEG3Q-)MJ>^.D=@@W&3T]G/<YHH"0`9"(]@0WS
M:='NWRX-08?\):3W"U6P.'A]O"SS![5@`&:V,Q$\BLD,2T8Y+Q"G4K<^M:E]
MMT\WR=DEU#C$!R/!"\-+V]?[./)ATI!*D2,?'F?D7BS!#1&%&]NTKZ/DE1.E
MKW?%-XESXM%A)_3SVA<#:.D")9H1`[/,A;0-(:ZIC4-M"W=O+)P9>Q?=Y"+!
M&1&EH/M2[LUEOT!5\3R>2'6QV[<=:=L`53R/`\?Q=(B7_<^6$BZ7"Y['`7T\
MZBB*"@MAT5/U=LU'=9P8&U)#75)#C'TAT3<L13ZRXS"+L2=KO+(D:H,%4KDN
MY=`$^^4"U8SC.'I,JY+89Z`IQ/%3-2B,2*HI;98/571N.H05CK*AB?Q2:2PI
M2N(2AW)+[>RR9F=385%S.*NK,9IOSP\F(9'I#]4EIK&]EHFBMJ-=?RX3X.`*
MH0A%-`X<'BVD]R>WS5EAT>U%<A=3$)(I9DM3F=CWMQ>L@YIDQ#H&B)S3`)EO
MS/2:"=D/:#2VL8LYRZ%`T4UW(M&?2:S#H!7T)NY\@&?I&`ZM9AYY*V`F5!CS
M=?"BKIENHTNK.=]HB;H)F;BI&0*W##[F*AB&<7.Q:UC?GR-?R\7]4D)/NV=Y
MNT?A)IX[@BM(?3J79+P5PZ-A85D@+,RTKD@VL4S,.J<:;G7S/5"'.*4Q[5D-
MD25JSL'6D3KO@[P.J&V.3;J=?+LT_'W45C\&=<]&,%PAKIE*]B&2B)F`14RM
M[WZ#0FTHO)WAN[JQ>GO1U2*=8F:JZXO"J.@0JY0-9=NV3U_;L7`IO)AO+#R,
M"KB7032\QM'&XNTX]"-5GU?=\H*0]72ZH%.W;<_/U@49JF($)GSI4DK8][TO
M'$<>7,=<1X?;MO7QI,I0'[=[DBK'F@WKVS$?S^?P`MYW/)]//)]/&C\38E=_
M3H'^,Z,X&<@QNS1(S7+0;C%6CKG]7T<^@XV^(=/"(_!:K&QJO8A]#&A?/.N&
M_')]`:!X>WL?6P+9:#45?:6:TLA\-`#/YP-'/HP%$Q][&ZER,=/<#@P":?8[
MG3C0/1AD(?P2\B[S=E5V$Y:)A\^67)ZKZK^G\Y>%%RO+^V5(D9N(J&O2!1H]
M#.K5%=@V=2SG(Q34).*L)DDUB8N/TW*2LVLR&$GDC7DX&&13/*HE>1/-8TZZ
M$X?L,DI;6!2YOUM3H<'I5]R8*9!%)Y%CA`JWXS@Z/]I.!_J[TU!?S%.H57!&
M7T^@I_Z^H9]TY/BP2%R,!9D6V86;GBD5ZS[J=JP-)$"OWUW>)P<4$=+H]P.F
M>XSK7I[L8T%C$3_E4"6*EH2!(`IU34Y<;(,!5Z9N$%=*>)WB?6L22)\P`8<W
MG*$7BA\AN9\9"^](?FR3P)'VJ'/$I.-S?Q>\_[,U[_10=7_'-L8E1)3[+*U>
M='8SRZ'?;/>LFP/M@05".".2<[:XV9>:DX)\C,1^A)*;A48TM,72S_C<?O!G
MQJM/[;7F0EV#H`Z_B$^9N)$+LZPO2%28(1CKP8W88F..4=CDZOO:1W.5SK!M
M6]_,'X^'+;"THC`I8=^V29#%#4!+W=JV#8_'8WP6'<^^[WA]?2U(\/-I48N3
MZ]"6KE;T#K6W.*<#>UDU9QPY3PM\BP25E+#M&XX\[(?*PD\C;0$RB(.K1^_@
MAL*ZO'/[?L&^[W4R41'4K/VAZA.9>E]8A`-5/)\/8\M5.+BY(X^<!,?^J3GR
ME)71R`UE_T?-;:Q:GL?Y,%'"$2C$2%1<GY+`S;L7^'4@:![5)<EY1+2@_C(U
M`B+KJ5WA]NH0S9;8+6/!Q+,/"0K`L5%[1)Q1UFR#'WISH8.J$Q1A'%"AB!L6
MP\UUZ[`O=OTDSH+\:J)_N6E+/A6DKB.'$ZJQ'1=3'4J*5SPQY4;@H/3`5O2W
MJ8U&:7-]<B>&"R[N>/WW*IH[QXR$BT,NQ=$S,%$*$,2+$FNW:P(LDNT1W)%B
MAFG-;6O(?"Z4G-8T#[[H-12AY`KC,6Y4;O3=*8G:3Q*:)'K>O3O5GF37W1/4
M%</]^/DSA^4J-\7#J).^SVVY1F.2T2=R@CF!C^_$=\'[-_^CG_W[:>1+G,@8
M<#2;RVIC,U"^$7P-A61?*%;P8S02\,K>XX"V<;*/T/Q$!R"NT.Z)X4;FKE/`
MP^<:#`E'),J>BV)3L&P`Q+PH"5$CQ*&O@XH2-*^?[88\VN]][CKG6"?5K-2&
MJ-!'%6!C<$),CN/`X_$PMD'LDYE4\80/HF#ZA?9-ZOE\XG:_5;$5(4_UV<@Y
MXWJY%$3(I'VYM";R'!V?5>#<G`4I`3FG4,33-L0>3A+8[H@(D@(_7E\+ZHRG
M%0LI%2D09#V<RT!%!5$V[\?CB7V_8-LWR,-20[J`C.[-\(D>M]4HS76^_Q(U
M/\$_1ZB1&M$I"XNR042]JX:X`I/O3TH21A?/B.LY'4BYZ)ZH/FKXYF'QAC&I
M\2_;:.XP%P\3OWG$ET(!33*A9H/J'+^T:CQC9Z3,4@28EYKZ^SESED^</Z;S
MM92R>!R.[H$\C_K;E(.H"HXW[6T*.=8Z\_$[JH;Z,(O_K[TKVVXCR95`%BF[
M__]7Y[1DB96X#[E%`,@B;=]^D\_13%L6Q6(MF4`@ED2L1VBSFW9J8A69TS0B
MW0,_IT>L%1H2D0NM3D?O2T:7<$BSJ*?7L*W6]!"'(B_S6,Z.AVD$+A-(-Y0[
M1Y-`2\JQ/L\&)_$TGX\FF=TZZI5[_IE.YF@8B/`:%JW)S-HU-0I.#XJH+H3=
M$#74C"A_H^`>-*;,S>>[X+UXP.P_?U=+"Z?8LLG6TDS#R#.RVW`,@VI-_'>/
MFF2?O]FJU%A88GIB4GR:1Y4EY_],*YQ=&@LBSDZ4E8Y33'.B""CMPY@*"BN#
M[I#=$KR*%'_.*%?^:3/DD\Y4'0JNJ8<O\LI8F-/.W^?G)\2@2G2^Z`7)V""M
M(Y9UI!7)VD#/DXO=L=B/GSUKX[C>[_<YBF?B#(_QS<4^CY$<(L:C4!?@Q,YC
M=3ZCV>B2(C+%);P)\VR'4P*Q3*V1.\[S(;56.<HAQ]&%9P$M76E$5E=D<2E1
M4&E2>TB)2X:#$5WV#&:C:R_2"`BO"R?`>\8C;S16A6D#(N0HFLJ*72\^PW$T
M.C%PJ<GH<_@=)M$[UX4P+D15%C(U:`:.$VB:?>84^-Z?6WB_A<HM$_Z1RM:>
M!4N+J#2QS%$0TN1";Y552BL4`N6EAM?.!$PH--#)8K<GVJ912A%X`;]6CY([
M]-B302EPP?.>,6A%8Z$<:3EQI&V0G,>."XQZ9E2:K:6HLB/.$&_*CJ.+[C/&
MC@+K955DPTW--F8MFIX/<^`.3E2*%)X`=<&;UU@36NJZ7/J]:J&89H&CHV)X
ML;'0@"DMM*U:!)Z`JF6;)H+`D.]25[;=WY4/K]GSM&!+5M*<$&"7X^L\@S`:
MO%\<]5-:QCJ2C`?CO1T3*RTW]M!,3F:\6R'G[LQ&N)L%!C?C@+)NTL`\ZC;$
M(C.0(WB"ZM9WV"MR!?#TE,X@>9&OODJ?&SS>EQ5\A]EF*T,>)KK6B\NYX5I4
MU5KB+H'GKU:3LY[RZ_.S-SJ<A*1@,T>1I:XAH;A1Y\5JAO2)=I9NMQN]IBV\
M/0#@/,D,/PM1&+QC;@1]H2++)-Z<^X`M4_Y:JYSUE./H]`]9W+WACD%);L#;
M1)]?F\ZN"M=UB=XPHCD@4F:Y;5THBO91HZC`WZ.I0N<U17?KLE)KUP3.K6M@
M#>@:.A@@B[/5.-K.(S@TVVYV.DW]*1W.K:]X;]4U#BY:6K-QUN4+WN-(2]^S
MB\#:4/!Z<'JD.0!A)4ZU,]TLM>(JFB'VOOB9%G%9L:RICUI`2\F'UO+@#VP<
MITN!LU3SPK@9PB%"]F:AH,]&`!$R#Q[0'N&>#:`8^+%"1'%=?/F:1#E;^.S7
M01Z7^\Z@+D@4M06K:PB`F>\-P3E9D,O:!D"78N#5;9@]ASQPF>N].0X1"Z8K
M.\?KDX(@`0(CSSH):U(NNBNL<^E]0/>*DE--MI-ZS06)ZR_V;>F4F^\_?\AC
MN'R>_^9WZZ;HA;]OG<7,Y+G)&J_":8BIAJV2AHQ".)>)QE@W(7_"E(>_(A<Y
M=>6U*IWST2.(0,\Z?BR3D*"$7]4;MD-U/_X]:TP,1TC*[ZD7398WWP^JY`3=
M]:DT6/%;PA6<=D^`[!RER.VX]<VB`GH+'HNPDGO3>W,)5VMAYT0I[,:)RQZ-
MH;M@;4>[B6-/+843^\HA;V]O7!S!6W$BFA/%&"^>C>\[7"A$2KD[#J%,I?E`
MO*,/L8;(3#R7?O'V0A]+J`\K2<D;[U\5P\*=>DA08P&5.:*0YP3O5A@%6[&(
M[/A-#J<Q/ADM%S#YL(WP\>HJ`+PVU0=4Y&-FZ<KWY5;B$<56\)35YAI:Z@FM
M(=EH/#MV$H4Z-%TV"6!8F"X_\C@AP`(WI/*Y8\DF)U@,^T:VAL3"*E8M<.Q#
MT>2H"+OK45P@C)^`H$>KIN"5NO6=)R/(A]]1&>8Y[KZ\XD$2M\[Q4\Z-FDT'
M$$T>R^XA7EM(S1*0NP"/224HHOU+])CKS8@>ICVWZJ(.E+C=\UJ>5`[>[%<U
M`$R9.XDX8,='S(M;[S2I=\1!9W3/;]:E8=N&C;%\VY+]+2I\7;/:D^^E1;+&
M&]&_3IW1M9F%@(F=3CNMDLTCNXM,'CYCJ@9EY,&KI1WVM#DJ#>CL2TUWB&3U
MQPR!`,YD?(+G&UL?1D\,F@-+^Q.[Z'B>>B?["8)PIKDPK[\Y3607W=@B2R%2
MM1R''+=;M];1B<8^SD>RV,OD<GH?8!.TEF&'B\PV:9J8;X80(Z)2G8*\4WL9
M$7(HD"IG$_[X\6-^KAH0.3[/*!;#K@@W,:LB7Y]?<K^_K<2P,ER!VNM__/PI
M(BKO_[[O@8N^L0ZAW"IH)#QKFB77[:P3>50P89V!#J8;`CYH%]Q"T\255Y5<
M`Z).-A:NU`CT-$$Q<3QD+I2';W/UBFXGQ#,Q4I2KXQ\C\D>F^)"2)TZ1CO<U
M7X*U[I8$J<."!'U=+4$\LQCAG4M!)@`+-(A-<>W?ZUF!&=#F3E'*J`\*J6SL
M-8PTEHLIZA5%HI]X)?]KF8K\D.0),&FSD"LQ+`*F>U9YW(ZHM/=&GN=NIM^Q
M:#0VLL:)G::SR"SI]0$!JH-(HJV=3JYKXU9'7<EX^VI&I*%6RRKS^6UQV$N2
MZ)KRKR6C1N&T1N$90RV'2)%]K'G86UVSK\'MQ<"!9[']>?+"4[5OA/<*+7@^
MX7@9#OXMVUZ+V.'N=ZZ+^IS00*!=2KU@VH$9CX&(*\1>.Z&3TQ3^N3JW]BSF
M/NTRUO'!TJ5,]WMVBCV:9L`C-AR1)H-EW3VL%Z"]3T6RY#RI;L9.Q@4;.O:B
MS=.,XW6CS?,\Y7$^Y.OK2SX'3S8!`%7YI@C4.-?5F^RMI+@XECFN-:B"%K6O
MQ`TA00XCA[O]_,?'^^3_6O?-W3T9L#Z'A799EK6"[?/7)R-#'6TZRB'W^[U1
M+<@6S(3%IOL,[.T$[JJ[)J3*(7[`M4[[S%%$3@$J]G>,^-(]9A(Z4E+_PTA\
M%J06Z0GJUJ,IK_73%L+)-&2E!T5_*<X]RW*E.PGKA.SAS#A13T#PA<>2(;B2
M%/XUH=T@(KN2Q2*@D:)6"6)*#VZ"[NY^#_XWQ5AWJ@`Z*SS;-VL28RR64RRL
M&@5L8`,8UW8->X)_#N?Z#.@K[RML_3;#9E3<Y$HOKY46=C]8H_<"@T!T#5E.
M+H.292_4`3M.]=0G!S>9M>?.I]4@_&;0/DQ`^%NI.2F7M<XFW">A-OB88`4-
M3-%X;8-KC[%(;U"/U.229RZ8J&F1]SSVPV^$5WY?L&;RG"EKS[&\)Y7I\]_]
MNP9A9L^/R+*%NR\.1SE$>M[WB:,OV8RY7SJ#^C)ROON8F2>HV759&F,,84'4
MG863;M'=(,Z#]9/^+4/5W'@.\M'6PC2KQF68J"IRN]V[0*W2&XZ/5AW?]03?
M6-S`,QL7Y"D2BB8<EZQNH_0;K68;N<9MG@0F-`'05:")I.*$L]:)IKV_O\O/
M?_XA89K/:1^6F3AZ$XKC'.*M(BHF7X\ON=UN4LHAC\=2KQ^WFUAMP1S3)U.9
M^^FYN4HQR)*:K&?K47#&D^>>VX:3"?.1ID*H5S:O")&NLI^*:+\.O)"T.%NK
MQO4$CCL['UB*]:U7I]T>-5,:-S'+.#8]"6K^7#.,G>-DLK5*O-4&*MU&V(M3
MBP54*8>C[>@,)LD\47>I@'Z:%(K=!!$<Q9<`\ICN#T]<!U@TIY,N@($;#=D5
M"FU!#V=)1M2C8BEEQ42O$?1P?-!HVT66)S(CQ@G-Q_0R&QZY3,.8'M8@7BTE
MTH9JC2)0)1%:<KYD3=>(0^[0:'ST%>]53+53I2G4^+Q,(8"D0EO>RU[#,E%O
MR/\NT+3[^RLZ#RG@)IS0Z3L.3L\38KX-#WB<`E(259_<I'0^8;U/N\^9VXQ(
MMFI^GT\!O6I(9_Q&>)\69WD]:J\&3KQ>Q_)D\F(WTST&\.2]'+$@@(@+F?*Z
MM=&52[^A@].@00R90P,U\NP)W1$3CU4^K7B)Y[-:W_5>9$[?+$^P$Q;E3C-\
M`5]M?7&T;R@<>FSTE!ED=!2-"SUEU3L$G7A*QI>I'(>4HP"Y?_TN,T0W'!_4
M5G3E?#TA(!74Y7X4JH&*.=[O/$\PJM]=-5QX->SMF4@"O\:Q#)_:\:6`IIF(
M?/[Z#(C9=!MPWHQ(TPC^#F"!]GA\R=O;#9Z?(K=R[VES)PG@YOF;JW*-Y\(6
M!]0V5G[VXIHQ*0P.O4/;GM!,./ZN'R.NILU<XI]MD[TP9E3POM4,<8&_%Q@1
MF[E0.H6-6N4)\-U^NI1Y[D=1L;-45"S`.D*NW3)1QQC:G%=K7W.*KFM8P-,Z
M*VXSFZ3=?V=K$/TL6E)A7'@_7OQY+T2+>Y]#FP&T.,\:$MDRA-@WZTCW]/J(
M2;D:SY>15UH3&@;@I2Z183?35AF.%JN@*QA_;/(2Q]-3(C)ZAZK.\YKQR#,A
M,]C%3)M+/S$ITRQLQ%KW9KR(%.U_[T]2HW,,4>T043KA@7))5URL<[9V3'L_
MC<F-$]8PEN>0!*._MCCM!\EZ:'\K'-PAK$V=UFJ*^`X4K3J^%%!M)0W!:J+X
MTWP7O++G,NUVF%?\$%3UE6R$?4WZGWBB*1>JEI?2/I(O6Y@]@C<]!-`*R78?
M1;?G_7G1JSD4?8E\JWNBFHJ:%N_^L!^WF]SO+6B@V6P=<T.@+T?=L`DE^4C5
M_6=!JQKEJF\NR%MD7'LZG3U']+T`S[#)&%'2(HEP<!,7K&SA-OZ,4(I(-!@+
M57&\-^:`%?!YSL;$802=QJ_V?;.>[`P"FVP:_2I"0C!28/<`BL?YZ"$4]R:`
MN+6&XS$H%.Z\X0'Y&-,H`(R4"G$;18;<K6CB#7<S<8")])K(T_;.&D9HM(;Q
M>KK6J5"SYI]6%.QY@5#V._W?J^U":IA^E-_?+CZ\<_V'/=,8\WNTU@"^(Q&0
MMM=790K.[P`K6=/A71)VT;H*G.)Z8<VT7E=FH8Z_R],71LB$%XME""@>NTVG
M&%[3D#=K`3F,][TE$XE0C,*Z:=YR32P@MH2*&M-5QC%EC48(3W(W>^J,THO>
MZ&C!8KHH(%=RCAGKR@Q_ZD6QJ(E)G5QW_X<F?(EKCAFK>]0EEWJ0+-.K9)5.
MJ)M-`F=Z6P-XE-^?;X@`%\DI8>H*B7&/?%,:KE#<;3'[O"#]`R*#3^#\$X>Q
MRV-0KD[#9S+;T0Y`F)2Y2-#D]L^I(0J32'N!S^#!CO5@*)E^^]>C0K[ZQ;K6
M9J#:1X73P-][_8KC@\FUB/&JT=(+,_DIJ#(AON51CCYZ166M]_A<"VM6.)2C
MR*$J<AP-Y3V]IRF'.M6`(AI'4^/XC19=(X1M!J%4(=0<[<A6X[7>\W:_R>?G
M5]CLZ9B*TNBL75\8_ZH/48#S!H(.&@7V;YSG*59-WNYOHJIRO]\[\GM2D`#3
M!.`]C$>S^%R%C=Z-44,!LWD.57WX#-,(=$YG)%@9SDCN6:BL$:?A#@D%,HJ9
M,/I6<:%LL&/GZ:Z%:-(E#)!G',.B0`7.F>?@IC00:P-,0NYG$8/'S!S::EV4
M*"VY<GK6%@7AJ,8XW4%_$*!$H?`5`E<R3FQ6T%9G!^;7B>H2NS@0(!:EZ`OL
M4^'"9"!UAHATEQ`C[.:,124X!PU:Q+"K\T7PO*<&A<$%<BA`@96<5H1>+U0\
M&J7XH>`2PUS4'6/V>4<!2JXF9N$YI(`--3$IG?\]Z`8F)B>XHCB$W6$U:U.O
M92?I6@``$BM)1$%4\>'7VO^M,+T$FP4,7\'P'^1:2TW+VFDM".(UOXZ0SW=H
M^$`4#(MD]=[BQD"$6'PVR,HM`=94T,ZNH;K#&.V[X/V+:M+^`(6U9Z6I;0&]
M?1'HBN3+PFN,NOUK$#RU'!/2PM&.D:/@#E]?1*OU(J',G1I-NFR+93W9>IDC
M+[?-S.@`VQK2L^/!V]%$0K+8<E4%M4\RCN^)S]?7'A9%C#3.Q!H`&\CM=IM%
M^?"378N,Q<7<I2I)']%9YTGM+%X60T5AD;>$@**1$RT+;:UF<AQ%CN.8H@FD
MB1S'(?=>2'J5_8@L?7O[(>=9Y?%X!'-WE0,&VN/F*\#1G?86_3@U3#TPM4R)
M%M,VUB(M<>['SQ]RO]]$2Y'W]_>V`3B%-(Z+D7M-R+$NIQ%\W0SO\$65)/ZT
MV\5`\V;6;!9DLXA0"0XDY$0@GLN[[+*";W=1E_B(`2L2;)#X^)RX:"/6-;'.
M"59JJF94NS%S;VV6*Q+7%YG8Q*'1OJ=8S_>`^]Z@$![/9#8!2X,DA!7OYIH@
MWPQ-[]GQ_&+<;R)<(PNQ&@O5'0IL3H3&W%V-7JAN&M&<&]:-6I*P#P6DKKAC
M\39K:<?NBZ$A%!S%-%2+C)C[9IW4"`YP`*ZO+94I@0QS"E+!%0?V48W%+)^S
M49:YAHZF--/IO?TNBUJ&8:E'R+"[S^BY<A.F&2JN^6[5L!?;JFP-O)49Q+)]
MH,>N3JJ6-"ZP\YO&\(GD/O;3ZF]*PY_^^4TT[V66@OXWQW51_4+=ZI3]P.MI
MOJW'6E`L$8OX4=33CX/&W!(1*>=!BPC2,[Z(>33,W%S&A+P9?96'Z62\&?G1
ME$W[)BJL]?JR>+1"19A?.^L'Y-<U^L';_4V.HXE)'N>#4O;8`%V)(N"=#D9R
MWD17"YI_K_&\&T)"3#6/Q<4XV6B<R[-6J><II11Y^_$V$]E*_UR#)E#!/-U(
MS+&JI&$[-CF#X_,5`<YC@<^@;.FC:.JW[C,+"-;P.&8/GZ_'8Z+C#=U]B"4\
MI.!J(4L<I(*)?E`,RG)#(>0L'\JDXT2S&OQS??-'X0[-CQ[4WCI5VP8),SY:
M.*1@2>87+C%M!0H+E23`Q<6&,B*^$.=V#P@[M+AP%4MH$]@`>7$.NF\(.#$L
MCG,OF@V1/$V7;6P'D;>Z&R_/PLN$BM:L*%7G[+!#9U_YOE]7/6J+_%]?"&?6
M9^/U17D1-)CP^#]E\G^CU9<E!?)$_@HW`I+<DXNVI>`GC+SJI'YSU*GEA0[K
MJ^FR$YOT`Q5.>E\Q#X@J%P`S="@^/+W)_(;5O_K[MO<&'UYZSCV/&,$.#=,S
M?[]>"Y346\73L^O-A2R@K[H-=?(N/'A\!8*BO%8)D_/V85%%5,LWPOM*[6E_
M4%=F&]0SFD/Z[S1:E+1+1'3FVN\7/%%QE(EC[J()<7T]B&<ODOR"Y)%$W0+8
M!EV7TYEZW]]H<?#\>NE2:49U=QR%TC%11-LDXW7!FP%-8G.?)'01NSS6C<_&
M7&A+=Q-8OLBE''*[W6:Q=?9QNKI*R\AY(8^O/L]3/G[]DI\_?\KM=I/'X]'1
M#),LW56]""G9<,-&V(_IX^-#?O3WT1^-GE!K$V*<9Y6OKT\YSRK'<<SOX29[
MUBH?OS[D.&X-+7(;^2@<&Y^M;21>A#&/345NMT.^OAZS4%K\/:&"R]S([O'X
MDO,\Y7:T\_5X/'(02N,95V@;U-@&#-TWQ'"LVU&5;>.4B,>FPT%T-T"NY^")
MM_,"C8!YA`0F'%:#+9,X2I./_-:BX;DB#^+8@FQ=(XA/;&0&`9MF85XV-`.&
M<=VN4?`3H:+HJ5M2#]IU3T4*P#B&$M+#ZG):$!!06?=IMKR0]6ML[8*RK)GU
M*.4635.5$Q!IRSY#1V>/X^"H68UH)2/-'+^\.X[J$K`0V2L91<,6RN\+>9J4
MP;V"@EA_7GB,OO![$PQB63];@*==B9[4&RIW1QM,10;2OL2.`Q5-!KUF<6KC
MG":P(+1-DX2K/](IL@8LN_99,Y`5M6O8V:=(P1+0UE0T`3,$(JK-(?@<A+/\
M]MLDJFR/E_9VD>^"-X/!L\WE-^JNL$D]+Y)M/]*7U^@*/IAJ7ZS'^`D:=?3I
M;.N"@;!?:YHPIK#`S)&51"\]"YUWY(=8=NS&)P7KB&SCM00!X[%KY-P&JY:!
MOBGW'&89?UOIO+K#I<(V]U;,O]=>7OOFO=:(LYY2/^O<\(S"RP%]W=XGUHK%
M?G+/\Y2/CP\YNLU2]&/E1)VL>&[7WEM\K5'66+`^WM^;"!"I)<ZW]CP?<IZI
M)E$>7P]Y/$Z']BQTC]Y3JE,_<%#&>58:H0^N=.3CK4UUC(3?_WV7G__\E/?W
M?TD4HJ[+FQ00?S^:+5LWU=B`$;+$@B0J?L![F2@+GA9@XE`FC1S')-U+D\D'
M=_267`O/5V!>`&W2T'RG0BM-`\J7)Z?!0V]HTI_'IRKRAJE0V`1`0&K@>+C&
M>#M>"[X.YOXM*U@I>:IR&,XN,7-\[RA%3CMA[,V%)R>F7>]S67`%HK(&5`%&
M>Q=:&H(M<&HUKIXFEFVN0,V.R[\&=0`!`7>"OU&LSF`%+'I%N>F<S^RZ+]<^
MV'(TM1@\,0`9P=0P>"49<YW4\YH[QYWN%3$X-G3`<`EU_5ZO&^$H%ZJ\)N`S
M7ZV"7X0%KVLL3#U7?\:TCZ>.+)B$0#;U]W8IDR8Q03L%7^"P[_A8&&X.@N8!
MZY!OT9JDW5):Y+Z(U%ZAPB^_SG*0][K0SGT[XR_9.`=0@(!)/?,\\DLD.@%3
M?2&>&$-$GB(F76T^D7KC\$&8M1ARX*'PJXV$-F_U*)=-!(!+A<WY1K0/$YV4
MQUQF&[9BMX-KQN6`4G9AP11-C"-1AUN;A/?S39;V,`HL`*\V2"P.6!@5Q[`9
M%?NL9VC@5(?(P(\0PZT[%WN/(GHNFZB)G>8$=JO;;_9I*(IQC4)?@(L6BEPV
M:[2&\W__Z^A?+EPAY`,:J?7\D;EIFCAEU.8EB4X));1QVW(4:(_<&$4NT[6V
M;%P3T?V,;SF0>)H8"&L)LF-;?T^(`B2<-#"$MN@"`2+$:HOCVU#*,M%(CZ36
M6KO/;0WWVD`Y0X&LR5Z":]C&>]07==.K-D/;.B)<O(@'J1,"#@7]X0++WJ=%
M;D9U&*AK1FG)/'G#/3`B<_O*58A77)F"XB@-`_T-3:@H!61X3V.>-FH,8J%I
MX_!:MNDJT9[/$C>JY#Y74(,;OLR8;D&%^RQ4ZYQ(>,`#M04CHAPI'D836YW@
MAX\B7Y,?#E_!I#+\_!HW+F[0?/IAIY=4='8DG-O8VQ[W!*N.EJ61.P]-O4JV
M/MK<A\=ZC>FM.,G^+GA?+B%AJO#RZWBW>!8O;*]6U2^@A-G+\69^5CM7R3O&
M(*0)XBK=5,!N[*$ISKO.T2QZ'==(40P0QWA;[#RY=IJBW.OQ4-%4*(?C;ZMV
M8;RL$W'+QO^2%`N6'3WYM!J4V3#R0TB:T($N;$LV,G7(R):'HI*C%DX@A>-.
MSD9/[E/H$IQOOA-[90\'QQEG8[ELK"LTIG0?PPD@T6L514>#+UK-%UD[<861
M&;])%V/4UF"@#58H2G'A!U-^[<V-CTQ=A9%.M&E7R&2K!:<48\"(B@\OSRRI
MO'L!*>A5$KJ3:VG#]93)4JS!JW;CQZMQK=)2Y``ZP1R!]K%$$'B5LIWD9=0'
M1`=572=W-4%LALTSX,%_H%"4]M]9'6H\1:\91:HNU;VFL?#[O<1\1'(0P@G]
M;I_:1F(P%1=PD]#?(#(=&ZD9))$L3]XE1*[H&_X9@`E?#='2>2"2VMF?/X^C
MH,@-+1!MCCEK=T0HO0.Q'K-M4M-GDPI*E=XL(&MN"84)8O`A$18;Z?F_78MG
M742,4PIU<)^1"!O*2G6QW?TO5=KU+(-BY"Q=1W-1S37>RN@Q\I4JT3HX2DH+
MK!.T%BU"Q+=H37XC>$)_Y\<2K]%GA:;NH=#KU^G?GP1]H>"G[ZO[;Q8)H4&W
M/P'C)I[FZJ7'%JLCM"-QG5`4"5T]=H,AVH#B>"62[I/3H/2X9V5H+!(ML4<1
MC595J=`%C?N3<T>;J?K4LM6U3R/N1$6=%H1/[FV.K\7,]WCVKKA?V53!J`OW
MJ;46I@-XD7?&_>)H)][O5LPC;/#YK`E(K&9J>C_^[,=;XS.0%0R"J3^T*"<3
ME.DANBEBDGC391.VN'(F[`M]O<[I]G>V[Q5XJI:M52C2J#E(:`535!B?JR!J
M0A$:"E:1KM`U/Z6L!JF-5UO3+GU<6ZW*:57J$)FZK-,IT-2VT:L39K9GJO1K
MDX1*"(<I(-7`NQV$,;S*LC^\<"A`C8%MD%B#H!1_/KT[@X_.#9\I";RXBC?.
M[-.,FIXUC@^QO8GON%TX3B#*Z\]71MTI":I>R8E'Q:1T0=@PZL'=HJ\-<DB5
M)1R3*5KK?]<B,PZB%[2U%ZNU'8A4L?X]7D/#O>_L_M*]&F)U3=!C/=8(-NYI
M&(Y8;XKF.@D>T[3.(<5`T;W(>51WYQ_KZ1#S&M%"M'ZG50R[4@BZB?<"V\:Q
M#B`@^&:92^IWP2O;3>7/ZTO;_.4RA.`/B^NG!P7/E-]_=%-@1_HP\V,P;G:.
M+_I&-HK74D8"F$:SW=Z-:2E=)%<HS8:O22P^RG'(<3MR0_*,9O@[U\MW)\`O
MVFA:H;B5X!21>PPJ);;Q?9@KJSVZ&B)?0XI6\CO,QQ!HLF'ARB208,.?*4V,
M<QN*YW1>"2DU<;68PHK`&XX%HJ<XS*9`O6DY/Q2+H]P'R6:]:)20@#>]7:LX
M$>3B><9Q=1ZMC#_G"Z@T'4^$%-8["H59G`H,93@B@CY!T/\.0HW%GBJW\5A+
M(@[B>ZR&@DI=88-CVRHKH8M&G'`(%;\_B@F-8081F=Z$5T!"F3_)WJ6`G`LZ
M:N_&42D_%;G9:<!$YH>+*OEMTA=,7-QGF,4@%,.[B0@)\T32D)<8J"`;VD43
MF54HQ-&6S#;1RF4393P*9"KJ$X&J7J#8BV.O+C2&O8H-K-V7>P`Z_&CJB,%-
M@?/$I8F!!5<)CBE>%(=*'NF</H@I;BA@JX[^,(OQ=/U>8KK9Y"9[&F2;Q7.K
M%T"B7D&$%C<PY#\31UK3>V84[D93;4CB^RYW]Y2`OX=,]<]^IZMQ]-5WRM3X
M^O2P7O[L7'R0+)K0RY&816IH',40TJE39*+L,\2H:'^KXSCD.([`0=Q@AY>?
MU=?Z:=,1D!96BJYSDD1+BLTP!I_VL[,SFD*,-.;1N)L=2.OX;S0`SY)_$DLN
M#9LPWB0N.`%1YA64GA9KR]@],2$W<:C+XL@B+UN39`7/#D91G!=5$9W%KK'-
ME<9&P,G,AM=26G1LN/7ULI#"<AN1<>0$&XS\T9IM!$44[<^3+BLFVUA7X89;
M-C&HMGE=V-S0CFP6:"EW($7XRV6P"HYKE9LKB04,"ATSL,+7/.L.5A*$*02`
MH/#5BZ\:4@Q):\ITAM:H2^($$FD)'IGT)SLK:D/BH$!Z&9YC*/B6N++26/>Z
M$).T4,X0X8">)L^^+XR6D+F#'))/-&BZ`=S9-'QCXV)Q)7H+=HG"8F4=:[4,
M9PV;,;[:,-V^CM?AJ-M<<\@JDZE3DR*`./)LUE:#K&[-0@N\4GAJD%V+=/J(
M/U.4+-%>HWRP->"*'W;)H(BL*G.EG]$G4SM'L?#LAV8.T)>"1;]%CV$24MMW
M\$2^$/V__G*YL*G"SB3!KM#3WZY0X$2-]KMA#Y>'G6^,EA3;:/2\;$J44-"`
M9`[!5<9EE(U25%;2CIG]4;OR.X%V5"JJ1_8R--TEACBA6ECPP7C?>Y?Z4?HT
M6">:="Z8"HN&>@Z4)FB1D$)X(?J%_"B]T6HZRLS\6O7J>@&7-@M=:9+@Q6MS
MXAU\8#3+`2?5+ORL%1)4C5MT(F$#Z4HXVUE`@4?LJ]7)K<T:'WM*[(="H(@+
M_V@%FYDY#Q9\)IV0#9"SS'5@K1$+[<H,L(.=%=`6&JI7<]ZF1J-\#=.'E88V
M*`8Z@QX<&@I"G*+<>"S!KVVG>:&!Z.<7"ZZYMFV1P_[_-3HXA"9#->4L>X]>
M3`>S(!:RU.R?.Q9-$Q=W81B^>$YM)D=A*H4*GN!R`2CAKNB.(10UC/85/[\K
M;HM#B2<5*`&U?'.B@Q@K%H1:%$CA/+&9;E(G/YPH6/U^*ZK4V!4J2KNOKC*/
M>=8#P-LV%V/OUST?GC']J[U83IR#%#[KHXG"I1O>O[AG*$`VWI5(9#D_:/2[
M+Y/2Y03H+@X8DQOU0D!+U*F24()$Y/\`NTK)9JYV"=T`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G<F%P
M:&EC<R]M96YU7W1O<"YP;F<`````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R
M-#4`,3`U,34T,S$P-C4`,#(S,3(P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````!````,@(#
M````X)59&0````Q03%1%+UR7.I7,________*4;FZ0````%B2T=$`Q$,3/(`
M```)<$A9<P```$@```!(`$;):SX````/241!5'C:8V"@,7!@<````60`@<VN
M4-L````7=$58=&-O;6UE;G0`9VQO=61E;6%N<RYI;F9O?*`UT`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O;&5F=%]M
M96YU7W1O<"YP;F<`````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#$W`#$P-3$U-#,Q
M,#8U`#`R-#$S-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12```!*P```$P(!@```#4BD>(````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?5
M!Q@/&3EF\^)Q````'71%6'1#;VUM96YT`$-R96%T960@=VET:"!4:&4@1TE-
M4.]D)6X```)S241!5'C:[=N]BAUE',?QWSPSY^1LH@GNQBH8;(*-D$(C1(2`
M))`BEY#.R]!2K\$;R$4(BKAH)=II$1)$#'8Y&UB7/2_S9K%A%8.5AIWB\X&G
M&Z;X%U_^,\Q4U^]_/@9@XHH1`&(%(%:`6`&(%8!8`6(%(%8`8@6(%8!8`8@5
M(%8`8@6(%8!8`8@5(%8`8@4@5H!8`8@5@%@!8@4@5H!8`8@5@%@!8@4@5@!B
M!8@5@%@!B!4@5@!B!2!6@%@!B!4@5@!B!2!6@%@!B!6`6`%B!2!6`&(%B!6`
M6`%B!2!6`/]9<^'F#5,`;%8`_X=J__%R-`;`9@4@5H!8`8@5@%@!8@4@5@#_
MJDF26S]_:Q+`2U,G>:V9Y^WS%_/!JWNY7C6Y-)NGE#I5*7^=5$E5I:JJ%^Y1
M[3]>CCNOM*8)O#3M,.3)>IVO#P[RU<$ROZY6N77Q<CY:7,KK.Q=2FEE*J5/J
M^GFLR@O!$BO@3'S\Z%&^/%CFDRMOY?VQI,QF:9IY2M.<;%G_")98`6=F/0RY
M^^,/N7_Y:NZ-=6;G%JGGYU(WLY124I7Z-%A>L`-G9E%*OKGQ7AX\_2W?SYML
MCH_2;589NC;#,"3CF'$<Q0J8AB_>>3>?_OXPR\-GV:Z.TVTW&?L^XSB<7B-6
MP"0VK#N[>WEP?I[MZCCM9IV^:S/\+5AB!4S"9]>N9?_P:8Y61^FVZW3M)D/?
M91S$"IB8-W=V\LN5J^DVZ_3;K5@!TW1[=R_?_;$\W:SZKA4K8'H^W-W-3\>'
MZ=LV?;M-WW49AC[)\]]M`*;@C<4BS[IM^KZ</`+VO<T*F)Y9*>F3C,-P<L8A
MR<EW5G\"SM#!8A*N,50`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O
M;&5F=%]M96YU7V)O='1O;2YP;F<`````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,3(R`#$P
M-3$U-#,Q,#8U`#`R-#8S-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12```!*@``"<0(!@```+V;
M*;H````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?5!QL1%ABI#\]T````'71%6'1#;VUM96YT`$-R96%T960@=VET:"!4
M:&4@1TE-4.]D)6X``!FV241!5'C:[=R_CE1E',?A[_OOS)F!#-F$RZ"VQ=+>
MQ)OA%BP-+;>@-81:4:]@"PDT%.Z$1,*N(=FQ.,/BQA@+L^P4SY-,.<VO^.0W
M[WG/E!=OWNP#<`2^^.G'/+G89[ZSS7I[DOGNO8QYG6HTP+$3*D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0
M*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0
M*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`
MA`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J
M`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
M$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H
M`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
M$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H
M`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0
M*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`
MA`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H
M`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$
M"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`
MA`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J
M`*$"$"I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0
M*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
MA,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
M$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H
M`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`K@=GVXO$P3*N"8O;ZXR$F?
MDOT^*67Y)"FE"!5P')[O=GFPV5X%ZE"I[/=[H0*.P[/=6;YY]2I)2:ZURD8%
M'(F7Y^=+F&I-K2VUM912LH\S*N`(/#H]S</M_4R]I_6>VGI*;2FUIL1&!=RR
MB\O+/-V=Y>N7OZ6VGMI'^IB68-66U))N3,!M^NK77_+X[?M,8Y4^IHQI3ANK
MPU95G5$!M[M)??GSBWR[>Y=>2MH8:=,J?36G35-:'\LY56Q4P"UX='J:I[NS
M/'[[/J.4M#%EK-:9YDWZM&Q6M?6K^U1"!=RH#Y>7>7UQD>>[79[MSO+R_#P/
MM_?SW>Z/3&.5-L82J?6=C'F3L5JGML,V59:??B4_?+\W2N"FM"0G?<J#S7:Y
M)U6251\IM2V'YM,JT[S)F#?+1K5:IXWKH>I/+G0*N&E_)N]^3^9-2JUIK:>.
ML1R<3ZN,U7KYR3?-A^L)GR*5)'V^LS5#X$;ML]PP3\GA,F=/&U/Z6*5-T^%,
M:J1^C%3*5:22I*^W)Z8(?)Y0[??+M8/6TGH_/-GKAT]+2KFV25V%:KY[SQ2!
MFW7MW;UZ]9I,:DT]W)4JI1Y"5?[Q]3[FM2$"GZ=7AW?W2DI2R^&)7OG70%V%
MJG8W%(#/IWY<K_[V?U/_I9?B<CIP\YO4__$7X`1T7*&#T;4`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O:61E87,O:6YF;RYP:'``````````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<Q`#$P-3$U-#,Q,#8U`#`R,#0R
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O:61E87,O:6YF;RYP
M:'`L=B`Q+C$N,BXQ(#(P,#4O,3`O,3@@,3$Z,S0Z,3@@:F%N($5X<"`D"B`J
M+PH*)'1H96UE7VYA;64@/2!?*"))9&5A<R(I.PH*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VED96%S+W-C<F5E;BYC<W,`````````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,3<S,@`Q,#4Q-30S,3`V-0`P,C`W-C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($ED96%S
M('1H96UE(&)Y(%)O96P@1VQO=61E;6%N<R`\<BYG;&]U9&5M86YS0&DM=&\M
M:2YN;#X*("H@0F%S960@;VX@=&AE($ED96%S('1O($EN=&5R8V]N;F5C="!"
M5B!W96)S:71E("AH='1P.B\O=W=W+FDM=&\M:2YN;"D*("H*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O:61E87,O<V-R965N+F-S<RQV(#$N,RXR+C,@,C`P
M-B\P,R\R-"`Q.3HS,SHT-R!C:'5C:R!%>'`@)`H@*B\*"F)O9'D@>PH@("`@
M9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE;'9E=&EC
M82P@<V%N<RUS97)I9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C,61C960[
M"B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI8W,O8F%C:V=R;W5N
M9"YP;F<I.PH@("`@8F%C:V=R;W5N9"UP;W-I=&EO;CH@8F]T=&]M(')I9VAT
M.PH@("`@8F%C:V=R;W5N9"UR97!E870Z(&YO+7)E<&5A=#L*("`@(&)A8VMG
M<F]U;F0M871T86-H;65N=#H@9FEX960["GT*"BYT97AT('L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-C864X93@["GT*"F$@>PH@("`@8V]L;W(Z(",R9C5C
M.3<["GT*"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8F%D
M,&4W.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-B860P93<["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X
M('-O;&ED(",P,#4S.38["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"BYH
M96%D97(@82!["B`@("!C;VQO<CH@(V)A9#!E-SL*?0HN:&5A9&5R(&$Z:&]V
M97(L(&$N:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C,F8U8SDW.PH@("`@
M=&5X="UD96-O<F%T:6]N.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(S-A.35C8SL*?0IA+FAE861E<B!["B`@("!B;W)D97(M8F]T=&]M.B`P.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P87)E;G0["GT*"BYH96%D97)B
M;W@@>PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V-A93AE.#L*?0H*+FQI9VAT('L*("`@(&-O;&]R.B`C,S,S.PI]"BYS
M;6%L;&AE861E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@
M("`@8V]L;W(Z("-B860P93<["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(
M96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*?0IA
M+G-M86QL:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C,F8U8SDW.PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*("`@('1E>'0M9&5C;W)A=&EO
M;CH@;F]N93L*?0HN<VUA;&P@>PH@("`@8V]L;W(Z(",P,#`["GT*+F-O;G1R
M;VP@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)A9#!E-SL*("`@(&)O<F1E
M<CH@;F]N93L*?0H*+F-O;G1R;VP@82!["B`@("!C;VQO<CH@(S`P,#L*?0HN
M8V]N=')O;"!A.FAO=F5R('L*("`@('1E>'0M9&5C;W)A=&EO;CH@=6YD97)L
M:6YE.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P87)E;G0["GT*"B\J
M($9O<FT@<W1Y;&5S+B`J+PII;G!U="P@<V5L96-T+"!T97AT87)E82!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F,V8S9CD[
M"B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`U,SDV.PI]"FEN<'5T.F9O8W5S
M+"!T97AT87)E83IF;V-U<R!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P8C%B,#L*?0HN8G5T=&]N+"`N
M8G5T=&]N.F9O8W5S('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,[
M"B`@("!C;VQO<CH@(V9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C,#`U,SDV.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*
M("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E
M<BUT;W`Z(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@+6UO>BUB;W)D97(M<F%D
M:75S.B`U<'@["GT*+F)U='1O;CIH;W9E<B!["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B`C,F8U8SDW.PI]"@IA+F9I>&5D('L*("`@(&-O;&]R.B`C,S,Y.PI]
M"@HN<VEG;F%T=7)E+"`N<VEG;F%T=7)E(&$@>PH@("`@8V]L;W(Z(",Y.3D[
M"GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C,F8U8SDW.PH@("`@8F]R9&5R+6)O='1O;3H@;F]N93L*("`@
M(&)A8VMG<F]U;F0M<F5P96%T.B!R97!E870M>#L*("`@(&)A8VMG<F]U;F0M
M:6UA9V4Z('5R;"AG<F%P:&EC<R]M96YU7W1O<"YP;F<I.PH@("`@8F%C:V=R
M;W5N9"UP;W-I=&EO;CH@8F]T=&]M.PH@("`@<&%D9&EN9SH@,'!X.PH@("`@
M8V]L;W(Z("-B860P93<["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V)A9#!E
M-SL*?0HC;65N=2!A.FAO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S
M83DU8V,["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(",S83DU8V,["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V%A
M8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-A86,["B`@("!B;W)D
M97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@
M<V]L:60@(S`P,#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"BYS:61E8F%R
M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C,61C960["B`@("!B86-K9W)O
M=6YD+6EM86=E.B!N;VYE.PH@("`@<&%D9&EN9SH@,'!X.PH@("`@;6%R9VEN
M.B`P<'@["GT*+G-I9&5B87(@(VUE;G4@>PH@("`@:&5I9VAT.B`W,7!X.PH@
M("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+VQE9G1?;65N=5]T
M;W`N<&YG*3L*("`@(&)A8VMG<F]U;F0M<&]S:71I;VXZ(&)O='1O;2!R:6=H
M=#L*("`@(&)A8VMG<F]U;F0M<F5P96%T.B!N;RUR97!E870["B`@("!M87)G
M:6XM8F]T=&]M.B`P<'@["GT*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C8V%E.&4X.PH@("`@8F]R9&5R.B!N;VYE.PH@("`@8F%C
M:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+VQE9G1?;65N=5]B;W1T;VTN
M<&YG*3L*("`@(&)A8VMG<F]U;F0M<&]S:71I;VXZ(&)O='1O;2!R:6=H=#L*
M("`@(&)A8VMG<F]U;F0M<F5P96%T.B!N;RUR97!E870["B`@("!P861D:6YG
M+6)O='1O;3H@,C!P>#L*("`@('!A9&1I;F<M=&]P.B`P<'@["GT*(W-I9&5B
M87)086YE;"!A('L*("`@(&-O;&]R.B`C,F8U8SDW.PH@("`@8F]R9&5R.B!N
M;VYE.PH@("`@<&%D9&EN9SH@,'!X(#%P>"`R<'@@,7!X.PI]"B-S:61E8F%R
M4&%N96P@83IH;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C
M.PH@("`@8V]L;W(Z("-B860P93<["B`@("!T97AT+61E8V]R871I;VXZ(&YO
M;F4["B`@("!B;W)D97(Z(&YO;F4["GT*(V5X<&%N9$)U='1O;B!["B`@("!M
M87)G:6XM<FEG:'0Z(#9P>#L*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E
M="!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P-3,Y-CL*?0HN
M=&%B<V5T(&QI(&$@>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P-3,Y-CL*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V,Q9&-E9#L*?0HN=&%B<V5T(&QI(&$Z:&]V97(@
M>PH@("`@8V]L;W(Z("-B860P93<["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M,V$Y-6-C.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,F8U8SDW.PI]"BYT86)S
M970@;&D@82YA8W1I=F5486(Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PI]"@HO*B!!;'1E<FYA=&EN
M9R!S='EL97,N("HO"BYR;W=%=F5N+"`N:71E;3`@>PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V-A93AE.#L*?0HN<F]W3V1D+"`N:71E;3$@>PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@=')A;G-P87)E;G0["GT*"BYI=&5M('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"@HO*B!0<F5F97)E;F-E
M<R!O=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I97<@:#(@>PH@("`@9F]N="US
M:7IE.B`Q-'!X.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["GT*+G!R969S3W9E
M<G9I97<@9'0@82!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#!B,6(P.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#4S.38["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@8V]L;W(Z("-B860P93<["GT*
M"BYP<F5F<T]V97)V:65W(&1D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C
M864X93@["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,&(Q8C`["B`@
M("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED(",P,&(Q8C`["GT*"BYP<F5F<T]V97)V:65W
M(&1T(&$Z:&]V97(@>PH@(&-O;&]R.B`C,F8U8SDW.PI]"@HN8F]X('L*("`@
M("UM;WHM8F]R9&5R+7)A9&EU<SH@,3!P>#L*("`@(&)O<F1E<CH@,7!X(&1A
M<VAE9"`C,#!B,6(P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-A93AE.#L*
M?0H*=&0N;&EN9612;W<L('1R+FQI;F5D4F]W('1D+"!T86)L92YL:6YE9%)O
M=R!T9"P@=&%B;&4N;&EN9612;W<@+FET96TL('1A8FQE+FQI;F5D4F]W('1H
M('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-A
M93AE.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C8S%D8V5D.PI]
M"BYL:6YE9%)O=U-E;&5C=&5D0V]L+"!T9"YL:6YE9%)O=U-E;&5C=&5D0V]L
M+"!T86)L92YL:6YE9%)O=R!T9"YL:6YE9%)O=U-E;&5C=&5D0V]L('L*("`@
M(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V,Q9&-E9#L*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C8V%E.&4X.PI]"@IT:"![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B!T<F%N<W!A<F5N=#L*?0IS<&%N('-T
M<F]N9R!["B`@("!C;VQO<CH@(S)F-6,Y-SL*?0H*````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]K;VQA8B\`````````````````````````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C4`,#$V-S<Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+V=R87!H:6-S+P``
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`V-0`P,C`U-S$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M:V]L86(O9W)A<&AI8W,O:V]L86(N<&YG````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$S,3<W`#$P-3$U-#,Q,#8U`#`R,C,W-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````C````"@(!@```"Q-$L8``!9&241!5'C:[9QY>%S5><9_=YFKV4?2C-;1
MOEFVA+'!V&8U!`P.`6/B&`PI@5+:!`QM@0)A"24EE"00*$UH$IH4TE"WK`Z0
M@,%F,9N-5[S)LB5+MK6OHUDT^[VW?PP>:30CVQ"30JKO>?P\]KUWSOG..>]]
MO_?[SKD6=%W7^3,P5=5H;Q]BTZ:#[-S9S;9M'?3U^1D8"-#?[R<:4[';C"B*
MA,ME9=JT?.KK"YDSIXRSSZ[%Y;(R94<WX<L&F*ZN$4*A*-75>6B:SN]>VL$?
M7FWBK;?VTMDY\IG:E&61!6?5<O75<_G&TEDHBCR%C"\[8'1=Y\[[7N.)7W^(
MINDLO706OWSLZRR^]%>L?6O?<>NGJM+)#[Y_(4N_?B*"($PAY,L*F.;]PUSZ
M[54IUYY\^$+V[.C@IK]_D1*WE<IR!WGY)FQ6!9M-013!YXOB\T7I[AFE_8"7
MOKX@JG;T(5]TX0R>^/EEY&2;IE#R90-,(!"A<RC"#0]O3KG^X'=.I,@69W];
M&W:;DAB0("#+,@:#`4F2DNRDJBK1:)2!P5&V?3S`V^]VL6E+'Y&H.FF_=34N
M5CU[#66E.5-(^3(`IK?/SUWWK280B/#?O_DF#_RNA^:^*`#%=HD'+G,S/-A'
M-!K%:K5B,IG(RLI"%,6,X437=>+Q.,%@$+_?3UM['_^Y<A>OO':`<"0S<*;7
MY?'[%Z_%Y;1,H>6+"AA=UUGYW';N_<$:/",ARDNMK%IY)>Z2`G;TJ83C,+M0
MPJP(Z+K^F;6&KNL$@T&V?=S&/3]8QX[=PQF?._?L<E;^^DH,!L,48+YH@/'Y
MP]SQCV_PPDN[,)L,7'U%'1>>5XPLBY25E9&7E_?Y].L+<-<_O<&SJYHSWG_T
M@05<>?EI_^^%\!<*,*WMPUQSPXNTM@W3.-W);2L:<.4:4!2%DI(2LK.SC[A@
M`X,A#ASRX?5%\(Q$L-L4G+E&ZJISL-N5H_:O:1IWW/<&OWUF1]J]:35VGGOR
MZ^3GYT\!9CQ%WW+W^_C\"9T0C:KX1V-8K0JJJG'&O")67#<SK9&'?[:5->]T
MPH2UC,<T3$:)IQX_#Y?SR-G&QJU=7/?W+S,\'.*B\\NX=GDED@1Y>7FXW>ZD
M@!UOL9C*FG<Z>?GU`W0-AK#E&"FO=)#C-)*=8\3OBS(T&**]U4/4'^7,4PKY
MJV].QV:;'#SQN,:EW_H?MNWHG3!3\,3#IW'!>:>D^1*-JH3"\;2V1$$X8E]'
MLDU;>UF[KI.^_B#^3];C6&Q&?2ZWWGA2\M_OK^]F_::>8_JMH@@X[,9D;6K&
MM%QFG9"'*(XM;$J%JJ\_1&=`Y<[[ST)1I,/SA&P0>>7%%JSJ*!Z/AYR<L:SA
M%T_MIC,,CZU<G`*8T4",VV]XG1O_JAKT4<)A`:/1F-'1=1\>Y/K;7F4T&.,O
MEM6P["(WHBA245&1TM=A\_JB//[D;M9NZ..D,TI9LF(N3I?IJ'IET_INEJYX
MAZLNKN"J9763%O$>^<$B+KCLOU#55/+]:&L_\^:,X'0Z4Z[?\KT/\<149(.8
MO*;&=08[_*Q^]J)/!11_(,I-=[V/XC2S<%$E9[J/O0+=VQ-@[3.[\/E\6*U6
M1%'DY[]I8MG?S,1@D`B%8H2"\6-J*QQ1^>V:0WSWAQNYZ\;9G'VZ.QTP&[;V
M,^WD$ORJ`4+C;H3@O0]ZN6F)PM#04'(1GWBZF;>;_5Q_VWQZ_6./!T=C_.B[
M:[ENL9V\G"!>KY?<W-S,8%E_B+^Y?371F,ZRB\M8=I$;69:IJ:G!8K%,"!DZ
M3SZSC]^\<I"%RQJX9=DL!$%`!?H#1R53*F:ZN:FQF%5/[V+?C[=P_^TG9WRR
MMBJ7"\^OXP]K]Z=<[^J/X/5ZTP#3WA?B_L?/3[G6ML_#6__]$?OV[:.ZNCHC
M0Z8SIL:UM[['N<M/H&%6(O1]&KW0O+^/LF*-]O9V9LY,1(*!H$9^5:*M3UL<
MF#&OG,57J?SHGG6XG$8:ZYVI@-FX?8B",VKI\4]\/<'3YR7'483-9@/@V5?:
M>7F;CV^NF)<"EG`PQA/WO\UW+K$RH]:,P^&@LK(24133'-K7-LS?W;L658,%
M\_.Y?'$ILBQ35U>'R93*&/V#(:Z_9R/FVD*^=>]"1%$X!I!D!LX9EY[`:\_L
MXJEGF[GFLOJ,3RU?TL#J=PZD7!OTQ`D$`BF9F=<7)6XVT>U-_?U['PU07Y-%
M)!+)./9,]L/'MU-V:C7.JGQZ?9\AC&T9Y+ISK%@L%@1!X%!7`,7EH&="6YUM
M'D:&@BG7C&8#E=-<2/)$7R4N^>NY_/"G[_++'R](!<RN]E'ROFI+<];3'Z"B
M,-&0S6;C^5</\M@KO2R]83Y]@;$X%`G'>/[1=[GI$C,-M28<#@=55549)VQX
M),SU=ZTE'(,2MY7KEI<AB0+5U=5I8-G3ZN6:[VWAM.4GDU_B8&#TCQ=OLQ<U
M\/@C;[+PC%S<Q>E"=MY)Q5CM)L+CM$E<%XC'XVB:EF2,#=L&R:\II'O"G.W8
M,<3BRRQ8K=9CRJPV;!M@[;XH2Z^O2%M@'=#BVM@2RID!.-#KIS`O.\G,"=\*
MT@A@Y2\W<_$IJ6WT^^*\^!0LO^-<#%FI>VFZV4I_`#HZ.L8`$XMI=(;E%``<
MMIT;^SB_T8HLR[R_Q<L#+_2R\.KY](^./1L-QWGS5Q]PZQ(C#37&(X)%TW3N
M?60]/4,A)$7FVF^48,J2*"TMQ6I-C=E[VWQ<<<_'S+_J#+`JGY%5,C.-H[Z"
M5:OW\>VK<M)J+`99I*XZEUW[AI+7G+E&)B:5'VP=P%9>D<8P86\`AS4W+:QF
MLF`HSJV/-#'OZM/2%G>XR\OF%S918HTB"+"CU\#E=RY,%^M1%;L4011)]KEI
MYS#FAFDI`(Q%XCA-,;ZZH""I<PY;\5O#?+2AC^K9[I2V(\$8B@2CHZ-C@-F^
M=P0Q+S<C%;;O&V+V628V-T5XZ`\'F7O%//K&@46+:VQ_81.W+C'04&/$;K=/
M"A:`%U:WLFY3-Y(L,[O>2D.-%;O=CLOE2A6W_AA7_>-VJBZ9CT]7\/F/;XJH
M%.?1U':`P<%!BHJ*TN[G9)N1Y#$D.'/2,YXM+:,4S["G,$QD-$J10T,0.";`
MW//8+FQSI^.)&V!<.^%`A+95&WGX>@=VJ\205^/FE5+&-1HZY*6N/.&?V6Q.
MK.F!,.Y99H+CGA]H'V%Z918`-34U*=K*M:N=X78!\X3VVS9V<OYL<ZKHW;##
M@YCO2M$CA[,+NQ:@O=O$_2\)U%Y\2@JS:'&-0Z]OYLZOZ316&['9;$<$B]<?
MX6<K=R%]DH4M/L>%(`B4E)2D4??MC^Q"G]6(CZSC#A:`"`H15<#O]V<$C,EL
M2/H)4%5J1I;EY-A"8976@`'!G^KW4-L(YU89$00A+;Q.M+<V]/-RFT3->?EI
MH:CUI6W\Y"]LV*T2;K>;SA$5N5!->PZ@L\7#12>:,)E,R+),**S2'C(@38@8
MA_9Y6#HO\=QXL`1#<7[UAQY,Y\Q-:3_J#Q%LWL^Y?Y<(=4G`?+3;1ZBD/,V9
MJ">`4X]S]_.0^Y53Z`])8QF4JN%Y;ROW7Z+26)6%S68[:D;P[\\U$PBI2+),
M>5$6E6XC.3DY:1.[M6F$W[4;R#\]AW"`S\4B@U%FFR5BL5C&^R/^&)*<F")!
M@!E59DPF4Q+8NUI]!&TY:?IEH'V$$Q9E8;%8CBAX/;XH-SW>COGT.6FLX6OI
MY/)9$4H*K.3EY5%86,CFY_<0S2[-R###/3ZF7:(DV657JX^0-3MM/?N[_3S]
M9IA5ZX>Q6C\>TZ^=48(UT[&$90A_,C]]'J2=VWGH6CNR)%!86#@&F,U=&L/9
M`@BIFW"1MB':^ZW8%YQ$7P!`32JQZ.8=/'!1C,8JY9C`,N*+\,JZ0TB&1+<G
M3T_HE4S5TW]YYA!J50U](^KG5K6,'AJA_K2LC(L:5S4Z!D))7ZN*%1Q6*45C
MK=\Y0M":3??P!!\]?LH+Y:.&H]O_=2^]);7(X^<5T*,QROO:N/0;5A1%P>U.
M:(K-^T,,%YL@PYP4B*-83:8Q_=+D30#&D_JL>-),=F9RID$``7P>%;6C%[JZ
M65P?Y)H55BPF@8*"`AP.1P(PW0-A#NSWH.U_)ZT=2="1!`'O:^^GRT9-8]!O
M.2:P`+SV01=134@N0EV9$449>RN2]!A6>?6#`?SA_L^US.TP"\R^VI&QH'BP
M.T`PJB=]/6>.'8#L[.PQP;O#2^"#_0GZ&6<G5XL89/L1`?/*>_W\YZL](*6/
MT2#JW'*+#4F$\O)R)$E"576V[/;BW?Q.QO;./C4AV@_W^5&3C\"'K9]M8C0-
M48!HG0F+6:*TQ$U>7E[BZ`C`ICU^=$$B4_)742RR]'2%AYX/IU>1))$?/Q]A
M[BP;=75'+TR]N:DW2?&B"$5.`PZ'(TV[[#T8Q!\A;2&.MUUZIA'%(&"WV]/N
MO;VE+^EKKEUB5HT1L]F<#)VJJK-Q;R`QD(DO:Y62LG@3K=\3Y?J']H*<^2AH
MM5NFJ4-C?Y_`UBX_X&?$'\<;UB>=DX:*Q/D?HS&1R6W<,PI"NF_UI1+&"=I]
MT*O3-:213``E$0UX[KT85146OC\[+[E&,I`8N"&S\PV5,DM.4^@-V/CM6D\Z
M=0/7_'`_:Q\UTUCM.&*\WM\30ORD'U.6@&(0TM@%8#@01Y`_WW.U+KO`%>=D
M(4E2"FL<#D=K-O4G?!5@\>D69$D@/S\_.7'M/6%Z1K2,?C96)C9,,QV'T'6=
MF_ZEA<&`/ND8]_;"0R_&@!@P)N".-">-E3)FLQE1%.D=CM+>'T604U]B61+X
MZ0HS%J,PP2?XCS51_N.-]#VKQY[OY8IS3$RO+1T'F.;129UI*)<019%_O64Z
M;?U-?-B4KD"]$;CL^RV\]6@CA<[,^T5[._P(DL3A,1@4`5$@XZ0J!O%S!8PH
MP%W+%6PF@:*BHK10^L[6`0:\,61%IJI08E:5@M%H3-G>6-_DS^BC($!#F9BL
MMDZTE6\.\O)Z[W$=G\T$97GBF'YI#B!DF->J8@&+,9&1CM_>T'6=>RMC//GV
MQ^DZ#WAW:R_E;B=FLQDY$M/X^&!D4GJ<499@`5.6Q-/?F\99-S?1.9B>5;0/
MZ5SYSRW\_H'IF(WI;0V,1),4?YB9HG$RZI[:$A.2(J-JG\/V//"W7Q.95R=B
MM5HS"N[&*@=GSLYG:_,PEY]I1!"@K*PL!0`?[AG-.&>R!#]?`R93$$UH)1)+
MC>/O[_1-.M>?U::7"RDUG\TMF7V;62DDJ_7RA/N'!B;'0#@NX/%X$H#9?3#,
M:$Q$R%!NMIF@S*4E'2G*55AY=RWGW]62-A$`&UKCK/A9.[^ZN1I)2FUOV!]/
M"LCDM='$6=N)5IBK<.:L;-9M/[[%%U&$&\Z';YPJ8#`8J*RL3(*@N\?'`P^N
MX=`A#TN6S.1[5\]AW:86LI4`+I<KN8>6'.N^4$:6B`.O[3C\;D8S0O9XLV=C
MN9XJ>"?QK<ZM$X[+Q'0%7W!LWEN[(]SX;QV3^E60K1.-)L8B;VP)IL6ZY)M>
MK&.0M!3Q=DJ=A4>_4\:*GW=F_,VS&T+4/-?%79>G%N)D64P#3-L`S(U$,K9S
MWU4EG-?<<MQ8QF;4N>-K.@NFZQ@,!FIK:U$494Q7W+V&S=NZ$_M`CWU$84DN
M9\TKYM"A0Y24E*06YOQQ]O;&)]5]G]:,LL[=%ZL8)SD!VN<3>'CUY$E%0VD<
M13$@RS)Q56?K@2AD6-.'7X>?O`Z(>U*NQV+:&#U.L#(GU!3$DXPD;VJ-3#KP
M&27QC&K_ZG-SV-D1X1>O>S+ONK[DI[IHD.4+QHY3NK*S$`VI#NWJ@4!@E$R'
MV.;56WCP+TNXXZF>/SH&G5JM<?/Y&H4.';/93%55%5E966.UIJA&5U2A<$;%
MV(9G5X@+3*:,Y8(->T/'E27^<D&,LZ?K6*W6C"G^JDU1!#ES<5$2H+XXGMSD
MW-T19C0N(AC2(\9D%2W!D!F,LJAS\Z+$'M;A3%+^J"TZN>`MB6$P&-*$J2`(
M/'A5(7NZX[R[)Y2>"0`KGO107I#%J?6)CDKRC$@3$-P?@"VM?BHJM(S%LQLO
M<N&R2]SR9`^^T*=+L04!9I:H?&M^C#D56K)`Z':[T_I2#"*G+JBGO7^,[6;-
M+$*6Y;18#["^)3PI*W]:JW1J+)L3QV`P4%U=G;&_EC=Z$61OQM^7Y&K83?J8
MX&T]/KXY+3K_<%Z8.14:5JMU##"W+7'B'?$RXDW_S'16B8K%XLBH]A59X#<W
M%;/R[2Z\WLR#V=9TD)FE55@L%FK=9NPVA=%P:HQYO5GGM)G#N`M=&=M8?E8.
M<ZMT'GVIA]6[97I\PA&SG_)<C?F5<1;6QZC*TQ!(O!UNMSMC"M_4$433=>Y<
M7LFS'T<8"NG,*9;XR@SCY"%$D5ATD@6__X_;LS`K.E\_,8)!@I*2DHQ@`3`;
M12Z894*(IY_KJ"]0$<9'`0$6S;;B#WQZ_:=(.@Z33D.1RAE5,<S*&",?QH"@
MZ[H^,#"`WY^Y@YR<G(S')),TIZH<.'`@*5X%04@!F*(HE):6(@@"/WNMEW>;
MTC="&MTB=RZMQ&"8_,T(A\-T='73=-!'2[^()RCBCP@891VSHE-DUZARJN18
M=`02V5=N;BXNERME_R=9S-1U7MTZPLKWAS`;!.Z_+)]"I_68OPKP>#RTM[<?
M%Y:QV^U45U<?^8#[P``='1WC!+R8\O?&QL;DM6`P2'-S\V>/XD(B,\[)R<'E
M<J7T]2?]:J!C*,IW5W:2Z4O5TVK-?'MA/HI\Y--IL5@,G\_'Z.@HD4@$5571
M=1U)DE`4!=,G^RF3U4$`NCTQ?OW6($U=(6Q9`A?/B%)L#F#Z1+.,US=3-@%,
M?^K/3)Y^W\/JG9G9;%IA%G]]3BZ%V9_/!V.>497??^SC[=U^HBK4NC065OC)
M$J-8+!:JJJJ2F=.4?4$`$XWK//C[0=H&,JM^1198=(*5"QHM6(WB']V?INOL
M[X_QWKX@'[8$B:E@-FB<4SY*E3V``!04%%!<7'S,9V^G`/,G-G]8XR=OC-#A
MF?R3AQ/="C=^Q9'R3<RQ6CBF<7!89>O!"%L.AO$$$T);%G1F.OW,RO-CE#2,
M1B/EY>5IQT*G[`L&&(!05./?W_.PLS<=$#EF@?N^YN"5EW?RSS]:@R`(W';K
M5_CFY;/9WA4E%@=SEH`D0"2N,QK1\89U^GPJ!X?B]/A4QIV91A$UICG\G)CK
MPVJ((TD2A86%Y.?G3['*EP4P`/%XG#4[!EE[0&$T/I92?G6ZPOQ"E067/DTT
MELB^)$E@S3-7LL=OY*5=D6-JWV&(,LWF8YK=AU%2$461_/Q\\O/SISZL_XSV
M?_I_<\FRS*+9!<PL'F!=BX^]/AM#41,Y%IF#?7YRJTM3GC_0%R([SY*VQ3#>
M;'(4MS%`C<5'7E8(@<2.>'Y^(2Z7:]):QY1]"0!S..=W%^:SS!FCM[>7MKX^
M'+J3ZFHG-2=6,1K1/BF6"9PXS<D['2#+$I*@(0LZ#CE,KB%,KB%$GB&$PQ#Y
MA)$D'(Y<G$XG-IMMZK\?^W,(29E,554"@0!VNYU.C\K;K5$$X.P:A7R+RO;=
M^XBI&K*0^'/8)$E*UF`<#L=1#V!/V9\)8(YD(R,CA$*A)$`D2<)@,)"5E87!
M8)@"R)_`_A<P-:]U^LRB80````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]K;VQA
M8B]G<F%P:&EC<R]B9RYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`R,#<`,3`U,34T,S$P-C4`,#(Q-C8S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````!
M`````P@"````W;_RU0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``
M"Q(!TMU^_`````=T24U%!]0)$0L>*$UOWM8````4241!5'C:8[ARX003`P,#
MT[W[#P`=H`4.SG&U:@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:V]L86(O9W)A<&AI8W,O
M:V]L86)L;V=O+G!N9P``````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S<R`#$P
M-3$U-#,Q,#8U`#`R,S(V,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````-P```"@(!@```%I;
M8@@````&8DM'1````````/E#NW\````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4"P0/'AT!TD;D```+ATE$051XVKV9>Y#4U97'/[]GO[NG']/T3/>\
M>AX,8("))"!*D*RH06-$%$$+(28;5U>SV=TR;EACR$;7VBK7;*I,;:U9BV1C
MR*(5$35"A*CDH9L0W@/R')@99H9Y#]T]T]V_[M_OMW\,-+3=`P[,>*KZGWMO
MWWN^OW/.]YQSKV":ILFG(+IN</)D/SMWMG+@0"=[]K33W1VGMS=!3T\<+:/C
M=EE158E`P,G4J4$:&T/,F5/)C3?6$P@XQWVF,-'@.CJ&2"8U:FM+,0R3US?O
MY]=O'^+==X]P^O30%>TIRR(+OU#/ZM6?Y^YELU%5^=,%9YHFWUFWA1=?^@##
M,%FV=#;_]:.[N&/I?[/]W:,3]O&B-7Z>_OX2EMTU"T$0/AUPAT\,L/2A37EC
MZY];PD?[VWGL6Z\1"3NIJ?)0&K3A<JJX7"JB"+&81BRFT=DUS,E39^GN'D$W
M+J_2[4NF\^)_+L=;8IM<<(E$FM/]:1YY[B]YX\_^S2S*7%E.M+3@=JFC!PH"
MLBRC*`J2).6LKNLZFJ;1VS?,GKV]O/>[#G;NZB:MZ6.>VU`78-,K:ZBL\$X\
MN#/=<=:NVTHBD>:7/[N?9U[OXG"W!D"Y6^*9Y6$&^KK1-`VGTXG-9L-BL2"*
M8E&7,DV3;#;+R,@(\7B<EI/=_,^&9M[<<HI4NCC(:0VEO/7:@P3\CHD!9YHF
M&U[=QU-/;V-P*$E5A9--&^XC')G"_FZ=5!::0A)V5<`TS<O&QJ7.&1D98<_>
M%IY\>@?[#PX47?=7-U:QX:7[4!3EZL#%XBF>^-X[_&IS,W:;PNJ5#2RYJ1Q9
M%JFLK*2TM'124DDLEF#MO[S#*YL.%YW_X3,+N>_>^7D?<ES@CI\<8,TCKW&\
M98!KIOEY_&]G$/`IJ*I*)!*AI*3DDE;J[4MRJBW&V5B:P:$T;I>*WV>EH=:+
MVZU>]GS#,'ABW3O\?./^@KFI=6Y>77\7P6!P_.#^O+N#KW_K#08&DMQ^<R4/
MKJA!DJ"TM)1P.)PCAXLED]'9]OYIWOC-*3KZDKB\5JIJ/'C]5DJ\5N(QC?Z^
M)">/#Z+%-19\+L37[I^&RS4VT&S68.D#_\N>_6<^%F#PXG/SN>6FS^5TR8$S
M#`-1%(MNN..#5AY^_&V&1S*LO+.:>VX/(XHBU=75>+V%3'4VIO'C]0?9_G_=
M?/:&"FY:$L4?L%TVOG9^V,GF7QQDU9>K675/PYAKC[4,<,OR7Z#K^799L[R:
M;W[C>OQ^_P5PYXU7S*5V?-C&-Q[?@J;I++NUG)5?J4"69>KJZG`X'!]S&Y/U
M&X_RLS=;67S/#)KFEH^;3`S#9-/+S80%C1]\^]HQUSVZ]C?\>ON)?&*YOI2U
MCUU+-!H=K6QR5BVBQ-&6`?[NJ>WH!BR<%^3>.T:!-30T8+/E6Z*G+\G#3_X9
M>WV(!YY:C"@*]"2NA#H$;ECZ&;9L;.:GKQQFS?+&HJM6W#F#K>^?RAOK&\R2
M2"1R#"V/1=4#0RD>7KN=5`8B82=?7U&))`K4UM86`/OH^%G6?'<7\U=<2S#B
MH7?XZMFQZ=89_/CYW[+X!A_A\F#!_-S/EN-TVTBELA?BT13(9K,8AH$D2<C%
M@!F&R5//?TA7?Q))E7GP[@@VBT1%105.9WYU?J0EQLHG]S)OU0W@5*_06L4M
MZ&FL9M/6HSRTREN0PQ19I*'61_/1_MR8WV?E8GXL6E[_:NMQ=NSL1))EFAJ=
MS*ASXG:["00"^<01S[#J>_N(?F4>,5,E%I_8W*:6EW*HY11]?7V4E945S'M+
M[$CRV0O@O/DL6P#N;#S-"QN:D=11.KUC40!!$(A$(@7N^^WGFS%G7T,,RX0#
M`TBCDM8%XO%X47`VNY+3$R!:84>6Y1SK%X#[R:N'221U)%FFJLQ"3=B*U^LM
MB+/=AX9X_:1"\'HOJ023(ND^C2:[1":3*3H_%,\@R?(Y0H3I43LVFRUGA#QP
M0[$T;^YH0U)&AZ^=-AI?%V?]\_(?&]O0HW5T#^F3UKUK;4,TSK<4S;]9W:"]
M-YG3-5JNXG%*>9R0!V[+'SO0#"'WAX9**ZJJ8K?;\S8>2>F\_<=>XJF>2;V:
M\-@%FE9[L%JM!7.MG0E&-#.GZZ(Y;@!*2DJ*@_OMSC,Y,XLBE/D5/!Y/0:P=
M:1TAGC[G"Y,H2Q=8414!M]M=,/?>KNZ<KCZWQ.PZ*W:[/1<^IFE>`#<8TSC1
ME40\]R5L%@%5$0JL!C"0R"+(\J0""[@%5BZR($E2GC7.N^2VG3VCN@IPQ_4.
M9$D@&`SF&2*GX9'V.((D(9\C'T45$`4*\@N`JHB3"DX48.T*%9=-H*RLK*`H
M?W]W+[UG,\BJ3#0D,3NJ8K5:\?E\Q5-![Y"6,S-`%M"R%*WVZR,V)%5&-R8>
MF`!\\S:1N0TB3J>S*)E=$_6PH"G([L,#W+O`BB!`965E?B\G"!?`#<2SN>#,
MC0V/WFU\7$(^E06S2]BQ;V*3FRC"(S?#W=<)*(I"34U-3N'.KAC//+N-MK9!
M[KQS)M]=/8<=.X]1HB8(!`*X7*["*\%<.:.(!>!:>N'SZ7111=:MBG#3X6,3
M9CV7U>2)VTP63C-1%(7Z^GI45<V1PV/_O(V_[.D$8/^/_D0HXN,+<\MI:VLC
M$HD4M$]YE@OYK8A*O@LV=T$B,4P1SV!NHX-GOQKAB9]V7;4?7E=K\/<W&X0\
M)G:[G6@TBL5BN9#,-8,.324TO?I"L=Z1Y!:;C=K:VJ*ADV>YBE(KDIR_J"<!
MNX['J:XNWL@^>GN`@%OB']9W$4N.+RT(`LR,Z#PP+\.<:B-7+(3#X8*S5$7D
MNH6-G.RYX$6S9Y8ARS)R$6([[\JY3CR3-?C:"T<93N7[F==N\OWE4PB'`F,J
MVG)Z@!]N[F+K09FNF'!)%JSR&<RKR;*X,4.TU$``W&XWX7"X:-HYU#Z"89H$
MO19>V9NF/VDRIUSB2].MB.(GN'$^[Z,O;#G#[P[%"MDI+/*=934HBC3F1JE4
MBO:.3@ZUQCC6(S(X(A)/"UAE$[MJ4N8VB/IUO`X3@5$6]OE\!`*!O'HPUW:9
M)F_O'F+#'_JQ*P(_6!XDY'>.J[//NR!J[]?XIPVG*7:;/;_>SD.+@ZBR>,D-
M,YD,L5B,X>%ATNDTNJYCFB:2)*&J*C:;#8?#@</A&%/1SL$,+[W;QZ&.)"Z+
MP)>G:Y3;$]C.Q=C%\3BNMX*7_S#(U@/%*7YJR,)?+_(1*E$F)7D/#NN\M3?&
M>P?C:#K4!PP65\>QB!H.AX-H-)ICT"L"IV5-GGVKCY;>XFV&*@O<^ADGMUSC
MP&D5KQJ089J<Z,GP^Z,C?'!LA(P.=L5@4=4P47<"`9@R90KEY>5CWLZ-ZR$D
MGC+X]W>&:!_,COG'66&51[_HN6Q0%XW/C$'K@,[NUC2[6E,,CHR2F"R8S/3'
MF5T:QRH96*U6JJJJ"JXVK@H<0%(S^,GO!SEPIE!YKUU@W6T>WGSC`/_Z;]L0
M!(''__&+W']O$_LZ-#)9L%L$)`'269/AM,G9E$EW3*>U/TM73"=[$2FKHL%4
M3YQ9OAA.)8LD281"(8+!X+BM]8G?"K+9+-OV][']E,IP]D(^^=(TE7DAG85+
M7T;+C)9GDB2P;>-]?!2WLKDY_<GZ-45CJBO&5'<,JZ0CBB+!8)!@,%BT8!^O
M7+*TEV696YNF,+.\EQW'8AR)N>C7;'@=,JW=<7RU%7GK3W4G*2EU%)1Q>666
MK!&V)JASQ"BU)!$8[3R"P1"!0*!H4IX4<.>S?3@4Y!Y_AC-GSM#2W8W']%-;
MZZ=N5I3A]*A_656!65/]O-\.LBPA"0:R8.*14_B4%#XE2:F2Q*.DSUE:PN/Q
MX??[<;E<5_S,=<5N64QT72>12.!VNSD]J//><0T!N+%.)>C0V7?P*!G=0!9&
M?^=%DJ1<CO-X/#@<CJN*ITD!=RD9&AHBF4SFP$B2A*(H6"P6%$69=#`?E_\'
MNA=PQ#[H0W4`````245.1*Y"8((````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]K;VQA8B]I;F9O+G!H<```````````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,S4`,3`U,34T,S$P-C4`,#(P-#,S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!+;VQA8B!T:&5M92!B>2!3='5A<G0@0FEN9V4@/',N8FEN
M9V5`8V]D969U<VEO;BYC;RYZ83X*("H@1&5R:79E9"!F<F]M('1H92`G3&EG
M:'0@0FQU92<@=&AE;64N"B`J"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VMO
M;&%B+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S8@;61J=6MI
M8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B2V]L86(B*3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O:V]L86(O<V-R965N+F-S<P``````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,#`U`#$P-3$U-#,Q,#8U`#`R,#<U-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@2V]L86(@
M=&AE;64@8GD@4W1U87)T($)I;F=E(#QS:V)I;F=E0&=M86EL+F-O;3X*("H@
M1&5R:79E9"!F<F]M('1H92`G3&EG:'0@0FQU92<@=&AE;64N"B`J"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+VMO;&%B+W-C<F5E;BYC<W,L=B`Q+C$P+C8N
M,B`R,#`V+S`S+S$P(#`P.C$R.C4T(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@
M("`@8F%C:V=R;W5N9#H@(V4U935E-3L*?0IA('L*("`@(&-O;&]R.B`C,S,Y
M.PI]"BYL:6=H="!["B`@("!C;VQO<CH@(S`P,#L*?0HC=&AE;65L;V=O('L*
M("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"@G9W)A<&AI8W,O:V]L86)L;V=O
M+G!N9R<I.PH@("`@8F%C:V=R;W5N9"UP;W-I=&EO;CH@8V5N=&5R.PH@("`@
M8F%C:V=R;W5N9"UR97!E870Z(&YO+7)E<&5A=#L*("`@(&AE:6=H=#H@-3!P
M>#L*("`@('=I9'1H.B`Q,#!P>#L*?0HN:&5A9&5R('L*("`@(&)A8VMG<F]U
M;F0Z("-D9&8["B`@("!B;W)D97(M8F]T=&]M.B`N,65M('-O;&ED(",P,&,[
M"GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R
M;W5N9#H@(V1D9CL*?0HN<VUA;&QH96%D97(@82P@+G-M86QL:&5A9&5R(&$Z
M:&]V97(L(&$N<VUA;&QH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`[
M"GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD.B`C,#!C.PH@("`@8V]L;W(Z
M("-F9F8["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*("`@("UM;WHM8F]R9&5R
M+7)A9&EU<SH@-7!X.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@
M("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<BUT;W`Z(#5P>"!S;VQI
M9"`C,#!C.PH@("`@8F]R9&5R+6)O='1O;3H@,W!X('-O;&ED(",X8F8["B`@
M("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C,#`P.PI]
M"B-M96YU(&$Z:&]V97(@>PH@("`@8F]R9&5R.B!N;VYE.PH@("`@<&%D9&EN
M9SH@,W!X.PH@("`@8F%C:V=R;W5N9#H@(V-C9CL*("`@(&-O;&]R.B`C,#!C
M.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C9&1F.PH@
M("`@8F]R9&5R.B!N;VYE.PH@("`@<&%D9&EN9SH@,W!X.PI]"@HO*B!3:61E
M8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD
M.B!W:&ET93L*("`@(&)O<F1E<BUB;W1T;VTZ("XR96T@<V]L:60@(SAB9CL*
M("`@(&)O<F1E<BUR:6=H=#H@+C)E;2!S;VQI9"`C.&)F.PI]"B-S:61E8F%R
M4&%N96P@82!["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I;F<M
M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O
M;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V-C9CL*?0HC97AP86YD0G5T
M=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@+C)E;3L*?0H*+RH@5&%B('-T>6QE
M<RX@*B\*+G1A8G-E="!L:2YA8W1I=F5486(@82P@+G1A8G-E="!L:2YA8W1I
M=F5486(@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U
M;F0Z("-D9&8["B`@("!B;W)D97(M8F]T=&]M+6-O;&]R.B`C9&1F.PI]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQA
M=F%N9&5R+P``````````````````````````````````````````````````
M```````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,3`V-0`P,3<T-S4`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O;&%V86YD97(O:6YF;RYP:'``````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<V`#$P-3$U-#,Q,#8U`#`R,3$T
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;&%V86YD97(O:6YF
M;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-B!M9&IU:VEC($5X<"`D
M"B`J+PH*)'1H96UE7VYA;64@/2!?*"),879E;F1E<B(I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VQA=F%N9&5R+W-C<F5E;BYC<W,`````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C$W,``Q,#4Q-30S,3`V-0`P,C$T-C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+VQA=F%N9&5R+W-C<F5E;BYC<W,L=B`Q+CDN-"XS
M(#(P,#4O,3`O,3@@,3$Z,S0Z,3D@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@
M("!B86-K9W)O=6YD.B`C965E.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z
M("-F-&4U9C<["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@
M(V8T935F-SL*?0IA('L*("`@(&-O;&]R.B`C-S$P9CDV.PI]"F$N=VED9V5T
M('L*("`@(&-O;&]R.B`C-S0R83@R.PI]"F$N=VED9V5T.FAO=F5R('L*("`@
M(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S<T,F$X,CL*?0HN:&5A
M9&5R('L*("`@(&)A8VMG<F]U;F0Z("-E,6,R93<["B`@("!F;VYT+7-I>F4Z
M(#$R<'@["GT*82YH96%D97(@>PH@("`@8F%C:V=R;W5N9"UI;6%G93H@;F]N
M93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"BYL:6=H
M="!["B`@("!C;VQO<CH@(S9E-&4W,CL*?0HN<VUA;&QH96%D97(@>PH@("`@
M8V]L;W(Z("-E964["B`@("!B86-K9W)O=6YD.B`C93%C,F4W.PI]"BYC;VYT
M<F]L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E8V-A9C(["GT*+FET96T@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V8V93=F.#L*?0HN8G5T=&]N('L*
M("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SEA-SAA
M,#L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!P861D:6YG.B`P
M(#)P>#L*?0HN8G5T=&]N.FAO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M(",V9#!A83`["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-C-F$Q8V0["GT*<V5L96-T('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E
M,&,S934["B`@("!C;VQO<CH@(S`P,#L*?0H*+RH@365N=2!S='EL97,N("HO
M"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V8T935F-SL*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C,#`P.PI]"B-M
M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C93%C,F4W.PI]"B-M
M96YU(&@Q('L*("`@(&-O;&]R.B`C,#`P.PI]"@HO*B!3:61E8F%R('-T>6QE
M<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M965E.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O````````````
M````````````````````````````````````````````````````````````
M`````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,Q,#8W`#`Q-S4P,P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R\`````````````````````````````````````````
M````````````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S$P-C4`,#(P-3<U`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+WIW+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-``Q,#4Q-30S,3`V-0`P,C$W
M-#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M__^^'""L&1Y,*BOBP,+%<'?+@HR[KK"YB)&DE)?LP,[[^/DW-3;:U]J,C(VW
MNKS)SL^)BXN_QL-D;&4;0A4Q7ADN<05;F35:DCAWJU>(N6HJ;0`N;P4Y>Q`^
M>QA)B2%LIT98ACMTK5!RDD%VFP-]HPV*KQUI@QN:OB]SCB-]F2J&HS".K#6I
MRT*AP$:QTD^NSE#$Q[MSEP#@Z%>JKV/#S`#%S@/%S0G-U@W8X1W-U!_F[B_R
M^D*AI2S?YT'W_T_R^5"KKT#T^EZ_PW;N\&78UQ#DXR&PKB&\NRCR\#7'QB[2
MT33\^T;EY$+^_5#V]$ZHJ)#O[^[0R@7*P`#$OE_MZ*_$NVG<TWO9R)>TGW/D
MK$[-=P'+=@'3?@K-?`W=BACJFBOWJ3[^LTWMJ$G[LU'RN&S7B"?2S\S/@#GT
MIVVZFX6^+@K;/13G32:Y1";$3"WT8#K/4S/?7S[];TKQ;DS\=%'/*`?#`0"]
M`P/'!P>L"@K1%!2_&!@A!07>)B;-*ROK.CJJ+"RT,C';/C[7/S[!.CKU2DHR
M$!#J3$ST45'C34W424G@45%"(2',='-4-35/-#1E1D9>0D)N4%!J3DXQ+R\>
M'1U$0D(Q,##U\O)14%!03T]'1D;AX>%_?W\W-S<-#0W___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#+
MZSJ/`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+U)1$%4
M&!EES[\.`4$0!O"=V;7GS\61B$KM010J"JU"(WHA"*]`H?`"GD!#2TVO$@^@
MN.8D<N[6CCDZYNM^F7R34>)OE"@!N$\B;2EV,,S@58EYOUJPQKPL($<"T["V
M;:7<T!(B`"`=E`AU;VWB"8M$+<D()8QWZE2G\UE6(^]9R[3:Y\_']!(>A(JP
MOV`:-+&RB2XHE8,4C6],]9UL=W,!2(ED.4R-LG^C>R)<]*51T0OX>.HC1$F]
M[_^\]`9'(TO.,9\<@@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O86PN<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#0U`#$P-3$U-#,Q,#8U`#`R,38W-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___]4U-L<Z._]G:`<!`,P``,@``)\`
M`'\``'8``%P``!@``+$!`:P!`<X#`\P#`U0!`4T!`8H#`]`%!<X%!<P%!;L%
M!6$#`\T)"8L'!ZL*"M8-#<T-#9`)";H-#=@0$(L*"D0%!;L0$,\2$H\-#5T)
M"68*"M(8&,\8&)01$>$='9`4%.0A(=0@']<A(=$@()T9&;0=':<;&Y(8&-@G
M)[`A(>XO+[(C(Z<A(;DF)MTP+[PH*'$8&/(U-;\J*L0M+<$L++LK*\<N+AX'
M!\HP,+(J*LTR,>$X.-4V-=(T-,\S,_<^/MTX.'D?'T82$OI"0MHZ.KLR,E@8
M&.=!0.`_/OQ&1NI"0N5"0OY*2N1"0H,F)NI&1L4[._]-3>Y)2>Q(2/]/3_Y/
M3ZHU-9@O+_Y04/),3/U14?Q04/9.3NY,3.E*2OM14?E04*TX./%04-1&1K`Z
M.M)&1NY14>M04+Q!0=U-3?975X(O+^Q75Z@^/OI>7NE96:E"0OUD9,=/3X8U
M-6(G)_ID9/AE9?]J:OAJ:NUE9:A(2+=1450F)AL-#7<Z.K1>7E`K*SHA(2X=
M'1@4%!`0$`4%!0,#`____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(0+</(````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````ODE$050(UV-@P`(X.0UC6ROS-,4Y1!1T[<)2
M04):06T]I7YJW,+R1N8!B;E`(46WFJ;V1E4A075;)Y^XG'B@D&4!2TF%_V16
MEPG1A9'I::%`(>:6<E\3)9Y)$_L:BE(S([R`0LW5(09R7!)=_2FU];DQ3*Y`
MH;H$4UD^7NG@WJJRXOA`=T>@4+ZUB@"[E$YG=W9'5JBW@Q50R$-#C$U463^Y
M(",SRLO9Q@PHI"?)QB^C;1Z>E!OCZ6IO88S-.P#?\RZ$Q<1]K`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B82YP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q
M-C4W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____`!=(3VZQ4&NH-5B?`2MV"2]W&SEM(D6&-EJ;.EZ?.UV847:V0F"4:8G"
M<8>N<XFO`"YW`"YV`!Q*`2]W`S!Y`S!X!3)[!3)Y!S1\"35[#3J!#3A]##%M
M"B=5$#V$$#R!$CR`%4"(&$*$'4F.%#!>(4V2'TB)'TB('T6#)T^.(4!U(T-V
M+UJ>(3]O)D=]&S)6*$E^,%:4*TV$,%*++D^%*D=X-%>1,E2+.%R:.%Z:-EF2
M0FNN/V*=1V^P06:A0V:A.UF,26VJ2&VG06*64'>W4':U06"24':S37&L4G>T
M1F:94'2M0EV(7H"X9(:]:(F_9H:Z:HO`7'6>>9;$?YO)>Y7!@9S(CJK:EZ_5
MDJG-AYJXH;76O<OA5WNS6GNM>(&/N,78J+7')$1M46A^:GZ(BY6+DY-PL[*2
MHIIACX9/TK8TE((KP:U1L:!2S*4!T:H'H887Y+TAU+(?NIL>[L@OW;PW^M5"
MX,$^_MI*[LU)_MQ0^==0]M=7H(P\HI!$IY9*R[=>TKYGP*Y>R[EGT;YKS)X`
MS)\`S:`!S*$%S:()UJD-V*L0VZ\4WK(8TJD8X;4=Z\`K\L@U]<LZX;TX^-(^
M_-1&_]A/\M!,^]A1]]50SJ`#T*(%U*8*Z+PF____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MFO">0`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!
M5`C78V#``I@,$_DRZZ9.Z&J?VUN<9^\&%!)1\XL+RRKI[IC3,[&LR=T3*"1O
MGA`;[II;T#FO?]*T9F]GH)"^3R!+C(!<46'?_"E5;5YV0"&GX'@K3@_!E-+B
MR=-K6ATM@$)!_@X:[%HAW*GE%3-J6VQ,@4(!+MJRHFR*R;QILV=5YUN:`(5\
MC97$A:24N:(CTV=6-IH9`(6L522%)13462.B^#-R&HQT@$*:TD)B,JIZMLRA
M23S9];H<V+P#`*'H,C5U"CRZ`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V%M+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`Q,@`Q,#4Q-30S,3`V-0`P,C$V-S``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____!`0W``0W("A;##1B$"A+2&"3.
M)S+?*S:J*C+M/DGU35?D25/B2%+Q45O@66'T9&T-`<`/`\`3!\4=$L0@%,\Q
M)MPI(9\Z+])%.NI(/]952O163.A;4?-.1LQ:4.AP9_8-"<$-";\6$L<8%,(D
M(-$R+LTV,]\T,K@[.,-)1>Q#0-!75/134.123^);6/%M:O,``,P#`\X%!=`%
M!<P)"<T-#=80$-@8&-(='>$A(>0?(-4O+^XU-?(P,,HX..$V-=4T--)"0OI&
M1OQ!0>9"0N4[.L=&1NI/3_]04/Y.3O904/E75_9>7OIF9?=J:O_,>`/,=@?0
M?`C.>`G,>PG->@_8AA/6@1/`=!+2AAOACB/DE"3/A"/4B"6P=2.R=B?NGC6\
M?RKRI#C<DS3'B##AG#O2D3?*B36P>3'2D3S\L4GEHD2[@CC&BS_^ME/VL5#6
MF4KSKU?SLE[HJUS`<Q#%>!;$?""G:Q^_?R[5D3KZK$CJHDCJI$O_M%7YL57H
MJ5C,``!_``#.`P/0!07,!07-"0G6#0W8$!#2&!B4$1'A'1WD(2'4'Q^=&1GN
M+R_R-37A.#CZ0D*[,C+\1D;G04'&.SO_3T_^4%#Y4%#V5U?Z7E[W967_:FK_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"[9F2J`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```*-)1$%4&--MC#L.PD`,1/W;39!(@RA`X@X<
M@LMP#BY)1Q$)I0"!^`@28GO9K>%5]M/,`/R`L(-I7=F[5V4I;`F@#M%'-25F
M)L:<BA+1/N:)F`C9'P*SBM)099-_HE34>F*/08V$.48<]4A0>Z]F)1$"V6@@
MT'KOI9:GV/.5U>;5M"OLJL4+FYLEW0O<GR<]2$A7P?/H5HIYB87#@M'M,N^6
M\(<O34M.V(\2TXH`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F(N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U`#`R
M,38V,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___R@E6"XK8`X,1P\-1Q843$)`;$)`:T1";%A6A5]=BUM9@71RGA(12QH9
M4B$@538U<CLZ<$].>FAGH&9EG5!/>5I9A6!?BVEHDP``3@``30``,0``,`,#
M40,#4`4%4`D)4PT-5PH*.Q(26A@87A$10B$A;1\@91\@9!D92QL;4"<G:B$A
M5R\O>2$A5"8F72@H8#4U?3`P<"HJ8BTM9BXN:#`P:S`P:BHJ730T<3@X>30T
M<#,S;C(R;#X^A3@X>$)"B#HZ=C(R9D9&BS\_?$%!?S\_>TI*CT)"?TU-D$9&
M@TE)B$A(ADE)AU!0DT]/D4Q,BU!0D4Y.C5%1DE!0D%%1D5!0CD9&?%!0C5=7
MDEY>F%E9CV1DGF5EG6IJHB(C62LL9#H[<?[S2GMQ`']U!;VN"MO.%)J1)EQ7
M&%A/`']S`7)H!XZ""H-W#=_-.-W./LRR`,FP`(%S`<"K`\.L!,FO!;ZG!7UO
M`UY4`\>P"<.M":Z;";VF"\:O%*J8$<^X&./,(6UB$,^Y'X1W%,^X(8I[%D=`
M#>W5+]O(-;"A*N',./CA0O/=1F)9''%H(?[G3^'/1O[H4/?A4//@4-S*2<NZ
M1(N`+^?54>[;5.K76I6*.D$]'5]9*WAM*____P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$S_[X4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$
M050(UV-@P`)D9+62>&=U-Y055@NH&[GX`X5DU9SC)*<U5Q65U#/K.0:$`H64
M+6-B>>;E%6?G]K';>X7Y`87T(T3".=HJ4W):NH0]0@+=@4)"\5'63#59J4W]
M^5S^P9XV0"'1:#<-MM**]CG3>[F#O`4M@$*QOCI*K.5IF7,+IDCX.-DE`H4B
MC57D66K3,V8GSQ1WM34U``HYJ"I(\=4U=DZ<-$/,RLQ0%RBDJ2@MQ]_:T3-A
M\E1.<Y,$;6S>`0!)63':PG4V20````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]A;BYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-#8`,3`U,34T,S$P-C4`,#(Q-S`P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____Q</&PL'#X>3IK[2YB\OHL,/,
M?(6)`'ZR!8*S#'VL'8V\(9C,+9C%*Y*\+)&Z+HVV,YW'+8FQ.*'+-IG`0:?3
M1JS409S!4+WH4+OG4+CB4KOE7K_E8,'G:,7J6Z/"JL#)JK_(UN?N`H&R$8_`
M$HBV%HJW()S+'Y"\*J'/)H^W+)C",9>^)W>6,9.Y,)&V+XNO/;'=-Y_'-)>]
M-I6Y0:G1/J#&0JC/.Y*T1J;+3K??4K_H3;'83K+94K;<4[?=6,#G5[O@5[G?
M3*+#5[C=9L'D:L?K;LGL<LOL<<GKO]+9H+"VJ[O!M<;,UNCOQ=;<T^/IV.;K
MZ??\X?#UVN?KY_3XU^/GZO;ZH:ROQL?'LK.SU-74U=74V,;`Y]?2]N7AW40D
MS4$DXU4X^6]3[W!7X,W)PQP`P",%QB<(Q20)P"<)QS08M#HF[UY"]E]&UUA`
M]&E/UL&]Z=G6]>7BJBD5J"@5ZTXUL3LHKT8YOU!#SF)6UG9KS[FW_O[^_/S\
M^OKZ^?GY]_?W\O+R[N[NY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,
MRLK*Q\?'O[^_O+R\N[N[L+"PIZ>GG9V=E)24?W]_____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````CNI;X0````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``F;,F!;%6%*0DY%=V]'6
M7%\'$IH^N:DA/BDK/;.HO:6!L1$HQ!$9'A'$7%%6FLL4&!(<%@H4TG/Q<!52
MYQ86Y-$RLG%TL`(*6;H[B4@(<.H:\SI[25E;F`"%W&3--/6U^54U[.4\I<5%
M#8!"\K8Z:BI<"GQB;)(R=N:FAD`A96]V)476RJKJ&A;_`#]?'Z!0>U=?7W=<
M8GE^2D)KUX1)4X!",;U]/9UIR7F%J<6Q_1.CIV+S#@#HNS%+[?6MKP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%O+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,3`V-0`P
M,C$W,#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#___^^.CO_9V@_-38B(R,K+"P?(!\'"P$3%@HB)0%65TUH;"MH;!B"A3YL
M;2:5EDH2$@!_?P=86!2*BCJ2D4(T-"%)23565D)D9$X4%!`Z.C575U%+2T93
M4U`R,C$P,"\_/SZ)A`-^=R_-KP!<3`T4#P#4G0K,B0#OI37HAR;;<!3-50',
M1@'<8"',1`/-1PG*)`##'@7.(0U*04#.$`/>)!B["@71$`?,``!_``#0!07,
M!P76#0W8$!"+"@K,$!#/$A+2&AB4$1''&!CA'1WD(2'4'Q^=&1GK*RO8)R?N
M+R^G(2'=+R_R-37U.CJR*BKA.#CX/C[7.#C)-#3Z0D*[,C+@/S[\1D;G04'^
M2DKR1D;&.SO_34W;0D+N24GL2$C_3T_^4%#R3$S]45'[45'Y4%#T4%#Q4%#L
M3D[41D;V5U?L5U?Z7E[I65G]9&3W967_:FKV:FH4"0DJ("`Y,#!/1D9:4%!9
M3T\@'1UG7EYN965D9&1145%04%!/3T],3$Q)24E(2$A&1D9"0D(Z.CHX.#@T
M-#0S,S,P,#`O+R\N+BXM+2TJ*BHH*"@G)R<F)B8A(2$='1T;&QL8&!@2$A(-
M#0T)"0D%!04#`P/___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```F5)NW`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])
M1$%4"-=C8,`"K*P\8@JS`YUL+*WMW/PBDD!"SF$%N9'N!AJFMJ[>H8EI0"'[
M@+S\!"]C71UU,\^@V-1XH)!/%G.&KZ.^BH6VEG]42G(X4(BI*"?8Q<C0W$%/
M,SH],RX$*%1=95)2K*:D6JDL6E%>QE(*%*IIZI_&P<7)R\/'7=O8*L\&%*I3
MF#I34$B87T1`ID&QHV<"4*AMR@R&&5)BXK)RDA+MW7T3@4+LTQEF3IO4U5)?
MURS=V<LZ&9MW`/J.,+ZKUMLN`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O8F0N<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#0U`#$P-3$U-#,Q,#8U`#`R,38V-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___Q]*(")"(RM-+#I9.P`O```M
M```<``,P`P,O`P4R!04Q!0DT"0TZ#0TY#0HF"A`\$!(\$AA!&!$N$1U)'2%,
M(1]''QDV&1LY&R=.)R];+R%`(2]9+R$^(29&)BA(*#5>-2I**BY0+BU.+3A@
M.#!2,"I(*CA?.#-6,S17-#YG/CA=.$)K0C98-C)1,CI=.D9N1D)H0DIT2D)F
M0D9K1DEO24UT349J1CM9.TAL2$]V3TEM25!W4$QQ3$YS3E%W45!U4$9F1E!T
M4%=Z5UZ!7EZ`7EEX662%9&6%96B(:&J*:C!6+S)4,399-3]C/C]B/D%E0&:%
M941F04MM2!U`&#%6*PTO!0DL`$QI0AT[$%MS3UAO3!\W#6]M3EQ,+T`A`6LW
M'XE2.FTN&&0?"6L:`Z5D48HY)YXP(905!\)31J0D&,U;4,A:3]U84:X%`*40
M"=LZ->I*1LP``,<!`,8``,T!`<P!`<H#`\@#`\P%!<H%!<P'!]0*"M`*"M`-
M#<X-#=,0$,\2$ML4%-<4%-D8&-L='=\A(>@F)N4K*^DO+_(U-?,Z.O,^/OI"
M0OY*2O]-3?___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````+::.!T````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````ODE$050(UV-@P`(X."18O5TT0L/9N`7%
M%`UM04(B^IZNP8D%^:FQHK*ZUHY`(0%U=X^0](;RLMKL,&US!QN@D)R3EV-\
M4T5)34M'DK&#70!0R-+;136YJK2ZL;T[R];>1`LH%.06R)127%G?UM67ZVBA
MIP84\K"2XDLHJVOM[)V09F;@RP(4<O81XHS(;.[HZ<^+\==4D0<*Z0CSL'-'
M9106Y<09:2DKR`"%Q'G9N?A%I2.C'4W]U)28);%Y!P#JG2QDI:V\/`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B92YP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#,`,3`U,34T,S$P-C4`
M,#(Q-C8U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____.SH[:&=H'R`@.CL['R`?45))9F=>#`T"$!$&QLT`L[D#R=`%O\43
MN+X5X>@FPL<J[/(U[_4Z]OQ&TM=#QLP`RLP`Q\T!QLP!R,X#R\X#RLP#R<P%
MM;H%R]$'Q\T)SM0*T=0*M+D)N;X*T-8-TM@0UML4V=L4V-X8S](8V^$=W^0A
MTM0?RL\?Y>LKZ>XO\_@^]?I"^?Y*^O]/^OY0]?E0Y>A9S<X-#`P!X^0A[NXO
MX>$X%!0*&!@-(R,9.3DP<G)J,#`O04%`R,(*R\81T\X<W-@JY^(X\.M&XMY)
M]O%0[>E2].]5P30>R#\JTTTXW5M&P5)`YF=3T5]-Z6Y:W6E7Y6]=EBTDGC,J
MH#4LISDOJ3LQVTY!K#TSKC\UL4$VM$(XN48[MT0ZODD^NT<]P$I`XEI.Q4]$
MYU]2RU1(T%=,U%M0Z&18V5Y3Z&9:ZVA<X&18W6)7YV=<Y6=<Y&9;S3@NUD4[
MMT$ZX%-)OD8^RU%(YU]5V5Q3Z&1;XV-:9F5E:FIJ965E9&1D7EY>65E95U=7
M4%!02$A(1D9&.#@X,C(R*BHJ)R<G(2$A&1D9&!@8$A(2$1$1#0T-"@H*"0D)
M!04%`P,#____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````7[\VP`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"\
M241!5!C3;8PQ#D%!%$7GO7DSDWPJ42A_J2!1:"16H+`/:E$(O[$`(A)[D:@U
MUJ"2"(4$B9CY\V<\-3>YS<FY5XB?`'<Q[K[4[>F:2?U<-DL48N5G^^/]924`
M)%H)%&OG(/J210.`6EE&KLBH$TX/HP&D#I[1Z#V7L9JC48`8K&.4R=TD7*BF
M"!#R/#*2U%L<*H;H*WG_'=*6J*7U^8080\%?)&1?#1)J7(%)]#ZP-57#33N%
M-(40V(KB3S[0SD<@-P'/S@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V)F+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`R-0`Q,#4Q-30S,3`V-0`P,C$V-C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____]9V@`6@`!7`$#7`,#6P,%
M7@4%704'8`<)7PD-90T-8PT0:!`291(4:Q08:A@=<QTA=R$?<!\;6!LF>28G
M=B<B8B,A7R$O@R\F9R8H:2@UB#4K;RPJ:RHM<"TN<BXP=#`^DSXZBCHS>#,X
M@S@T>C1"DT(Z@CI&ED9"BD)*F4I-G$U&CD9)DTE(D4A/G$],E4Q0G%!.F$Y1
MG5%0FE!0F%!DJ60,9PHP?"\R=S$V?#4_A3XRA"LK:R`.5``160,66@DZ<#!`
M>#9.C4),AD!1BD9;F$];EE!HGEYOHV4J>AA!AB]YIPV>P!W4GQ#%?P70/R&V
M%@#,&P?)#0"X#`6_'QC>.C70/CC#.C3J34;42$*Y/SOM5U#E5$[E75?P;VK'
M``!]``!\``#(`0''`0'*`P/(`P/+!07(!07("0G."@K0#0W)#0V("@K3$!#.
M$A+9%!38&!C.&!B0$1'<'1W@(2'/'Q^:&1GF)B;3)R?E*RNF(2'I+R_;+R_M
M-37S.CJN*BK=.#CS/C[U0D*X,C+@/S[X1D;B04']2DK#.SOZ34WK24GH2$CZ
M3T_Q3$S\4%#\45'W45'V4%#31D;P4%#R5U?U7E[E65GX9&3S967[:FK___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"9O1WL`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```*Y)1$%4&--MP<U-PT`0!M!O=R<S=BQ;
M.!&=4$Y..>:4KBB)`E`$$A`K1EGV?R@`W@/^,#B:Q]V</V\^B$C?]6<+,X\/
M9;W_!":6C3A8#.->_>JS(V86BK"8]J=R\W%96#;,-<'@0!J;UJ:6G3.U/1.N
M6J)K9C3YVYE6%82O\.8#GH;ULNU2VKV"H-N0E%]XZKLZO5\J",M'JD1.6#3>
M2VFPN*9LB600E^;<2L$_?@$,RE(.(86XZP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F<N<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#$W`#$P-3$U-#,Q,#8U
M`#`R,38W,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___\;'Q\G.R,3)P^[S[<_3SN'EX*NNJO7X]#R"(,+'P,/(P>'FWR%O
M`"%K`"-Q`R5O!25N!2AS"2UY#3!Y$#9Z&#R''4&((4Z7+U.8-4F$,%.1.$^,
M-F"F0EN:0%R80F">1E&$.VNN3VRL4&NK4&FF3G"K5W>R7GVT98*X:D&$(#]L
M*4Z'-&2F1F2C16.92'.O57BR6V:63]38TO;Z]//W\>;JY.3HXH6'A"]S##%T
M#S5X$SU\'5*2,5>0.7*I5G6J68J\<"]G`45\&$^`)U:+*TUW+&B;/EZ*.G6F
M36V:2(:P9#!H`3AO"CEN#56`,6^<27BG4<`+`,`-`\41!\0<$L\>%-PP)K`N
M)M(X+[LU+>I#.L8[,]9'/O-32NA53/-:4>A94-0Y-<P"`,L$`,P'`]`'!<P(
M!<L-"=01#=@3$-(;&-\A'>0C(=,C'Z8=&[`B(>TS+[$F([PJ*/(W-;TL*L<P
M+LDS,.$Z.-(V-/E&0OQ)1N5$0NE)1OY23_Y24/903OA34/[^_OS\_/KZ^OGY
M^??W]_;V]O+R\N[N[N?GY^3DY.'AX=C8V-;6UM34U-+2TM#0T,[.SLW-S<S,
MS+N[NYV=G924E']_?____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````?P)V4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MJ$E$0508TVW!RQ$!41`%T/NZFS?^JB@"L+6P\(U)#)9*#+*2!,L9"F.*U]T"
MX!S@1\`1MO5#302:3#^^$\!];\P,4[>TVP/89+&QKDNKS?-.;;%<(6`:>VYF
M3L7@1J%[/0E*>SS?24FX&-XI[X`0K<HU!:8@S_#1'(*)OV>/9BB)*/,JOLZ"
M496L3]04)K>V-2`8WU-BX1@E)%55$$I58I(ZDU[,W?''%XQF4"(+QP!G````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]A<BYP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-C<W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____U=35Q\;'_O[_[>WNZ^OL
MU]?8S<W.R\O,^_S]]O?XV-G:P,'"I*:G_/[_^_W^^OS][_'R[O#Q(J+,%65_
M(Z/,):3.)J;0)J3,**3,&69_*J7-*Z;.+*C0+ZW6+:7,,;#8+Z;--*[6-['8
M-ZS2)WF4/KGA0;SD/J_4/:[20[KA1[[D0['4.)*P,X.=-XNG4,?N0)Z\5,SR
M/Y>S5<GN2*C'6LSR5+_A1Z&_4+343[+23JW,8=7Z3ZW,3ZS*9-?\6<#A2J"[
M-W>+5;;45++17<7G7<3E9M;Z:MG\7;_>;=O_;=O^:=3V5JO';-;Y9LKJ6K+/
M8+[;<MS_<MS^<=?Y;LWK9;S8>-KZ=M;V;\OH69VR?MKW7J.Y?]OX<<+<9ZW$
MA^'_@]KU;[?/B^/_@=+L@]3N?,??CN/^C>'[DN/]B]GRC=GQB]+IF>7]\?3U
MY.?H3+'-3+#,4;'.V=S<T=34S,_/W=_?^OO[U-75S,W-V-O:N+NOP\6\K*Z3
MV]W"Q\BWM+5OIZ45@'\>I:0MGYY2S,S*Y^?FS,S+A8,'H)Y6X^'9Z>CE^/?W
M_O[^_/S\^OKZ^?GY]O;V\O+RZNKJY>7EX>'ATM+2S<W-S,S,RLK*____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/)+[#P````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``J2E]?T2(QVU%*3D
M5'3,/4.`0J)J3C$1;IHR8N+RZH:VWOY`(>?HW+S4\.*B0BNOL+B4S#2@$%\I
MOW!)66U=375!OH"@4#E0B)EQTK3I;:V=S=V3^_LF39T.%.J=T%XYHZ.KJ:5G
M`N/$*4RS@$)<;.P<G%4-C?7<+!6L/#-Y@4(Y\8%V-JY!44D96=GIR0FQ0"$+
M54D1"44-8P<?7W=K,R,]H)"NDI2LLK:I1W!H@(N]I8D!-N\``-+-,(\O#,.9
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)H+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R-@`Q,#4Q-30S,3`V
M-0`P,C$V-S$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____0-3;=.3K$P\2)B(FDI*7Z^_SQ\_/EY^?BY.3*S,S'R<G3U-30
MT=&XN;F:FYO'``#'`0#(`0''`0'(`P/(!`3&!`3+!07*!07(!07&!07,!P?(
M"0G."@K.#`S0#0W3$!#)#P_6%!39&!C8&!C6&!C.&!C<'1W;'1W@(2'?(2'?
M(R.D&QOB)B;/(R/()27E*RNL(2'I+R^O(R.V)B;J,C+'*RNX*"CM-37L-36[
M*BJ^+"S#+B[`+2W',##O.CK),C'&,##1-C7.-#3+,S/S/C[*-#3V0D+U0D+5
M.CK3.SOX1D;W1D;</S[;/S[</S_A0D+Y2DKF1D;Z34WE1D;J24G[3T_Z3T_[
M4%#Z4%#N3$SQ3D[X45'W45'U4%#T4%#V45'334W,3T_'34WR<W/*;F[B?'S'
M;6W'=771?7W'?'SHG)S-BHK8DY/[P<'UO;W&N;G&NKK=T='/Q,3)P,#X[N[S
MZNK)PL+MY^?#OK[[^OKU]/3Z^OKU]?7N[N[HZ.C>WM[8V-C2TM+-S<W(R,BN
MKJZ0D)!]?7U\?'S___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!1#B);`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`*])1$%4&--MS#L.PC`0!-#=C;_Y$*34=)1T'(#[(-%#00VGH*7F+)P!B9HH
M-HX3&X<6IGR:&8"?()SQM.W,9=E:J77=5%<""'%$6AG+E-3S4@#!,?9Q\*TE
MS753")L(SR&CAPM)ZE*/[T1AAWU<#)*KLE+1F$3[C-#?HU2J+H2[A6E(&4.G
MF6H*;;I-GX@H.%K+/!WUSH\.6")$_Q3?HR[9U,)#QG@^R[E]^3!X^),/WMA#
M=.[*F=$`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O8FDN<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U`#`R,38V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___]+`P??L[N[BY<S+S-/8
MV-C;V\G,S./DY+*SL]+5U,O0SL',Q/#Y\JF^J,O8RN;SY=WLVC!X($J+.*_!
MJCR`)V2D4-#FR9JAF#MO*DZ+.F:H4&BI46>G46:C4'RT:'&=8N#OVSQS)D)R
M,&NK46VF5GB>:9*X@XRBA+G5KFET91Q'"4^-,T1[+4Z&-V.?27"G67.D7I/$
M?I3#@'ZB;[G8JQ]-"CAH(49\+$N",%"(-%**-EN5/E^90E.%.V.=1F.>2&FE
M3&NG3E^21G.L5W:O7'FQ7G^U9'^S982Y:HR]=&!W5:C`G4V$,5Z90("C;L_2
MR.WLY<7#P,S'Q./9U*MQ6+5[9;AY9-NFE,.HG\*EG=A_<LW&Q<):3][.S-`/
M!>$H'<XK(>-#..I01M1)/_9?5_YJ8>]S:N%P:ON">LQI8^)X<LUW<OF:E=&0
MC-/!P/[O[LP'`,P4#-85#^XW+^$^..=(0^1'0M!%/_923LI&0/E74,964LQW
M<[^(AO&XMOW+R=ZTLMBUM,P&!=80#=@3$-@4$-(8&-4X-?I&0O]23_]J:IUS
M<LRLK,NZNMO9V?S\_/KZ^O7U]?+R\NSL[.OKZ^CHZ,_/S\W-S<S,S,?'Q[N[
MNW]_?____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'7(26@````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`*TY_;6]J25=;04
M);15-$Q4`@KI^,QASBM/S<U.*LEDF63F!A0RE](0G-H<&Q5=T#1-R$3.`"AD
MX:*@YCN#(RR<?;J6JJR3+5#(WLM5)&#6+!XVSBG>,LYVUD`A3W=_8<7^N)#X
MF"!C<0<;*Z"0AZ.8/G]P1&!H))^$H;2?)5!(7M>4ES5_PO3)A8U3!-3UE(%"
M1J*S^BK;DS.RTJMRF&9KJ@"%N&?6%;<FEG9UUZ1T5M=S26+S#@#@P3+2':O9
ML@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A="YP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`U,34T,S$P
M-C4`,#(Q-S`V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____SB0ES,3%XMO<I)^@^O7VQLK*]_KZ\?3TW^+BV][>T];6T-/3
MS]+2SM'1S=#0RLW-R,O+Q\K*^_W]^OS\]??W]/;VZ>OKY>?GXN3DX>/CW=_?
MT-+2Q\G)Q,;&]?;V[/#OQLG(SLG(\^[MR```QP``Q@``?0``?```R0,#R`,#
MRP4%R@4%R`4%QP4%R`D)T0T-T`T-TQ`0SA@8S1@8D!$1W!T=QQP<X"$AWR$A
MTB`?R!T=SQ\?FAD9I!L;QR,CQB4ER2<GK"$AZB\OZ2\OS"DIKR,CB1P<N"@H
M[34U[#4UNRHJV#(RPRXNQS`PRC(RWC@XW3@XUC8VT38USC0T]D)"]4)"N#(R
M^$9&]T9&XD%!X4)"Y45$TS\_YD9&PSL[^T]/^D]/XD='^U!0^E!0\4Y.]5!0
MMC\_KCP\\U96V$U,\E=7P$=&[UE9]5Y>RTY.^F1DZE]?Z%Y>VUI9^6AH\V5E
M]VAH^VIJ[FAH^&YN[FQLY6QL^'AXUL[.Q\#`QK^_V-'1V=/3RL3$R</#R,+"
MQ\'!^?/S^/+R[^GI[NCH[>?GW-;6T\[.R<3$^O7UZN7EZ./CY>#@OKJZ]O+R
MU='1T,S,____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````-_*GJ0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"_241!5`C78V#``C0T[1(J<H),]-1TC"V](E-`0F819?G1M@9JVD;FKN%)
MZ4`AC\R:VN(X)PL;)M_8K,+R(J`0Z[3^[L;FAGKF.I;.]HZN'J"0O`BGC(`P
MNR`/ER*'**<T/U!(04R*3UA.B)=;0DQ47%)6"2C$-K&WI:U5N6F22O^4"5/[
M)@.%JK,#'!W<@I/S2JLJ2PIR,X!"@:;ZZKK&5MY1J6DQH7Z>SD`A:P-5+4-S
ME[#$]/@0?Q]W>VS>`0!GWRYB%OGB*`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V)J+G!N9P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`P-P`Q,#4Q-30S,3`V-0`P,C$V-S(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\Z>3L`7P``6@``.0``
M.``!80$!6@$#7`,#6P,%7@4%704%6`4'90<)7PD-90T-8@T0;A`*0PH291(2
M8!(8:A@12Q$=>!T?<!\?;R`95!DG=2<G<"<A7"$J9BHX@S@X@C@R;S)!A4$[
M>#M(D$A0F%!&A490EU!7G5=7F5=>HEY9F%EDIV1HJFAEI65JK&IJJVHP?"\P
M>R]!B4!FIF5%@`--A`U;CQ]PH3A#>0#+S0#-T`?6V13BYB;O\SK<WS[Y_4KN
M\4SX_%'(QP#'QP#+R0')R0'(R`/+RP7)R`5&1@/+R@G.S@K0T`W3TQ#8V!C2
MT!C<VQW@X"'EYBOIZ2_M[37S\S[U]4+X^$;Z^DWJZDGZ^D_[^U#W]U'U]5!6
M4A1A7B%N:R],1PK?SR'LW37.P33WZ$;QXT[.O`74PQ#ATT+ZZU#4&0W=*1WI
M.R_&.C#0/S;U3D+E4$;Z6D_T6E#=&!CF)B:D&QOG*RNL(2&O(R.V)B:X*"CP
M-36[*BJ^+"S#+B[`+2WQ.CK',##),C'1-C7.-#3+,S/S/C[Z0D+5.CKY1D;;
M/S[A0D+Y2DKF1D;Z34WJ24G\3T_Z4%#N3$SQ3D[X45'U4%#V45'___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#):G^#`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*!)1$%4&--MP<UQPC`0!M!O_R1C
M0L"'S-`$-$TC*28SN67"(4:[DJ44`.\!3PA&']_7.)Z]:E(1O3%HR9?JHX:8
M,`N#<9CF'C%"C)F9&Q3[B>/]=_S12L0\.A1I+OY3]$I!;$WJIV)9]W=?%R43
MIMX-BA+WA^MY)Z=I<H\*AA^*M[S1G%*KV]:@B*\262GO;'A$ZV"X%[-$;UFC
M;+UWO/`/"H)++*YKQ:,`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O874N<&YG
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q
M,#8U`#`R,3<P,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___]=15/)L;?F8F<Q+4+(N.7XA*+HT/G<T.<II<+558["3J%@Z
M4(]GBY)GC\ZTS'-!=YE[GL^VVG)DAK"EP%Y(AL*TVZ&5NEA3;(9XP61>AE-'
MF(Z&PFQDIG-LJI^9TA0)?RPDCG)MP(B$R;JYQA$+@S0ODW5QQW1QPY.0U`P+
MAA02B144CQ\>D"$@EB4DFR\NE4=&JT)!GU!/O$I)J554P554O%=6O$=&ED]-
MGU!/G&)@LI^>S0$"@P8(AP8&A`<'AP@(A0D)APL,APT/C@X/BPX/B!`0AQ(3
MCQ(2CAH:F!H:E1P=DQT=ER$BG"<GGR<GGB4EE"4ED!\?=BPLHS`PIR\PHC$Q
MIS$QIB4E?28G?S4UJRHJAS@YK3(RG"LKA3HZKS`PC3]`M30UE#(RCS$RC#\_
MLS<WFC8VED)"M#P]I41$MCX_H3L[F4E)NTA(N49&M#T]G$%!HDQ,O$U-O4]/
MOT]0ODI*L%%2P$Q-LU)2P%!1NDU-LE-3OU55P5-4O4U-L%%1MU96P597P%A8
MPU96OU55O515N%!0K5)2KU]?PE-4HVAHQV=HQ&UMR,K*RPP0BB(FBSP^FE]A
MPS-$J^MU<L1.3O!D8_AG9ZY/3I1+2NA[>[MK:^>-C/___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````*E@/"(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````P4E$050(UV-@P`)X):6GBPO83M5V<-:7+<RO!PIQSI[+S#*/BUO-WBM0
MV:2R`2C$/FO.S&FL'&R*KGYAR:5:*D`A$1[A&:)"8I/<?"*SRNHT;8!"?!I2
M3#+!_(*ZX0K=U19=&4"AOBE&2AYV$]4-XOI;S1N-4X!"O;7%D]V=W+PC<LK:
MJG(SDX!"'?'R$ZP<?4+3RUN:3/-2$X!"V7IRJCV>`8DES36=$I:Q44"A(!<=
M0U__F`*S]HHBZ[3H$&S>`0#YH3(958(&B@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]C82YP;F<`````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-C8P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____U=74]O/RY.#?RKNX
MTKBST\/`SAT%RB0,T"0-URD1TBX8X30=W40OQ#\MLCHJS40Q_V1/\F!,^V51
MU%=&UF=6R&)4S')FSG1H_9&"SGALY(^#X)B.QHJ!_K.I_K2J_KFO][:MS9F2
MS)V6_,_)S*NF?PP`S!L$S!@%RAP%S1X)UB0-BQ<*E"`1XC<ATS,ARS4EL#`A
M[D,OLC(CIRXAN38FO#DHP3PLRD$PX4DXTD4TU4@V]U(_X%`^_%A&Y55"[EM)
M[%M(^6)0\6!0RUA)^G!>]&]@_7-D^'1E_WMJSV58S'%EVH!U[IF.U(A^^*6:
MRH9]THN#X9F0[J6<\:RC^;2L_;BO_\?`_,K$],W(^M/.S;&NRA(`?PH`SA0#
MWB88U"\?IR@;ZSHK^D]"QT@[_E]0YU9+YVE?U(R%S0X!S!`%SQP2V#$G\CXU
MQS<NSSPS^DQ"VD,ZNSHRYTI`ZD]&_U9-_5I1]E=.]F!7Z6%9_,_,\L[,W,S+
MS`D`G1T9\CHUOS`J_V]HTL/#_OKZV-75_?S\[.OKY^;F^_O[^OKZ^?GY]O;V
M\O+R[N[NZ^OKZNKJY>7EX>'AWM[>V-C8UM;6T='1T-#0S,S,____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````84'20````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``N+4Z^48>R:Q
MJ<R8/D6FP3X-**2N5ZS4U<'N:J@V=9)?H9`S4$A7H"J\?4J,1E;FY/Z`,A%'
MH)"I:%-HK;<X)Y=81I1"N;`=4"C5JS*X63.6@UL_+U*QPL$:*.3I5N+/JA6O
MPVN<HAI6:F,)%/)PRI6>H6R0D&PKWQE2)&@!%'+ARY&8,<TWW5VJK5>V@-\,
M*&3%D^TSO96EIKJ%>6)0OKD14"A1NTYRZJ2^Z(CN"4R!C29)V+P#`-B7,:@;
M#L3E`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%W+G!N
M9P``````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-@`Q,#4Q-30S
M,3`V-0`P,C$W,3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___^J04/Z@8/GBX^)7%]^4%:]GZG)K[UA76F[Q-:URN)(7&Z0
MIKEDH,EHI,QJH\MOJM-KI,I^M]]YL-6-Q>M]JLJ6S/"%L]2<T_B5QN>EV/NE
MUOFLVOJIUO2PVO=FH<=FHL=FH<9GH<=GHL=II,III,ELI\UKI<IJI,EJH\9Q
MJ]%NJ,MQJ]!WL==VL-5RJ<UWL=5\MMMVK,]XKM%^MMIYKL^$O.&%O>&&ON&-
MQ>B/QNF5S.^7S?"%L]&<TO6.O]^=T_2BU_J/O]VCV/F4Q.*1P-VCU_B!JL2H
MV_R;R^FJW?ZIW/RGVOFFV/B?S^VDU?2CU/*GV/>5M<J1Q^:TX_]`:7]BD*>"
MN-.3QN&PY?]`;7^"Q=QOIK6@S-ANI;-VK;IUJ;:#N,:2QM.&M<&BU.&/N\:%
MK[FLW.BASMFKV>6UW^ESJ;1RJ+-]LKUICI9\I:Z%KK=]I*RAS=:QX.JMVN-U
MJ;.)O<>%M;YRF:":S=>-N,"HV>*0MWBFR9*'L6J+M6Z*LVV5OGBBRH9_G&N*
MJ'2RV):4LWV=O8:_Y*6NSY;$YZJ]WZ61M$Z2M$^6N529N5JAQ&"OT7".J%ZJ
MR'&8LV:^WX&BO6^QS7S*Z8[+ZI+#WXS"WHZ[,C+I65GZ<7'___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!8`X;X`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+=)1$%4&--MP2U.0T$4!M#O_LW,(W5=``D>@4*P!D#1'9"*;@:'8`>H
M&CR")9"@@`1954(S?;S,W-L%P#G`'X2%/9;+EY/=QYSST>=I?B+,IOMENG[?
M51U*2C-9,WJCAQZU63;38A,45^W6;E[WD5*68KV!\<WEXNW7+2<QDSJ"<.SG
MS\V)F97)W3>$U4_J[L+$PM%IN%.<C<V#F52(>KA#\17JQ"3"Y!X>4$R^#1Z$
M1_)2*5?\XP"S`T>Z`@"F,P````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8FTN<&YG````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#0Q`#$P-3$U-#,Q,#8U`#`R,38W,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\```<$&"<L("=02
M$\<J*\<N+_)86O!?8.AA8^YE:/=K;,-76.YT=>N-CGD<'[<^0<U)3;(P-X,R
M-JU'3?_6V.C"Q.&FK6,W/Z%H<IYK=FE,5+.(E:B"D(56<<FIP81UA+"CM<"N
MRV!"<T(?7%@]<92!J8=UIFUG?#(E8Y&2MJS9R$W0/H#H:'2Q2[KBH)2C3=?6
MQ=S9OM;)J=_+G^C>T)9G,]O.P-ZA?_+=T=1R3L%'-<$\,>UO9=-A7OJ!?NF(
MA<P``,T!`<P!`<T"`LX#`\P#`]`%!<P%!<<&!M$'!\T)"=0*"M8-#=8.#LX-
M#<<-#=@0$-85$\\2$ML4%-X8&-(8&.$='>0A(=0@']0A(>$D).@F)J<;&^LK
M*]@G)[`A(>XO+[(C([DF)MTP+[PH*/(U-;\J*L0N+<$L+/4Z.LHP,.X[.^$X
M.-4V-=(T-/@^/OI"0M`[..`_/OQ&1OI'1_Y*2N1#0NI&1N%$1.Y)2>Q(2/]/
M3Y0P+OY04/9.3OI34?E04.5+2]Y(2/%04/M;6N%95_UD9/MN;O)K:[M85N=O
M;;)85NF#@?___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````+WTD4X````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````NDE$050(UV-@P`(D931Y%224
M5+R</((BTTOK@4("==T\#CU";"YN_C&Y9;5-0"&1WKY.1WM185??%G%^L;9J
MH)"BK#*?MIR\*DLHEYFE%4<)4$A*0[U=34M:D#6RRUC'J+D`*,3-614=R,0<
M')%D9VIA4IP#%.JH20AP<?8-BR^TUC/0M\T""K6FAK@[>8?&9I<W&NJ:9Z8`
MA?+"/:$N:JBP84]+!`I%^3BY^44D%=4V5>;G9"3'8?,.`#2C+F>(M_ZD````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B;BYP
M;F<`````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T
M,S$P-C4`,#(Q-C<T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____S%M=[I&2P18;W,K+9F%BDH^0_/#Y.SH[?WY_U=35_/K]
MU]78]?3VZ^OL'R`@S<[.P,@%XNLO[_A"*RP-]/M/\/A0P,,#Q<@%Q\D8U-8=
MX>,_S,X]Y>=&7V`CR\U/:6I"PL(`P+\`O[\`P<$#NKH#P\,%P<$%P<`)R<D-
MS,P0R<@2QL<8U=0=V-@AR<D?XN(OW-POYN8UO+LP>7D?[.T^U]<XUM8XS,LU
MEI8H[^]"\?%&CX\JU=5`OKX[\_--X^1)]/1/\_-0\/!1[NY0[.Q0Z^M7U]=1
M9&0G>WHR]?5JVMIDG)Q(Z^MVW]]S]O:7]?2?:6EE?'QX/S\^04%`6UM:O;D`
M1D4;]?3+T<D0P;00^?2N1T4TGI).[^K8T,['O8H`7UI,N;>QFFL'VYTAZ[50
MWI0U[)A&XM_<JZBF5U54G)J9PWU>I)6.O$,5/A`!U$HZJ5]76`D!PC,FT&!5
MN%U4EE--8P\*<1X8AT(^[+NXGV]MFFYL7@``Q`<'KQ<4+0@((0D)D2LKX4I*
MDS@WVUQ9.1H:IE%1DU13[9N;R(V,XZBGXMS<[.CHDI"0X^'A^?GYZNKJZ>GI
MS\_/RLK*LK*RHJ*BBXN+:FIJ7EY>,S,S+BXN+2TM*RLK*"@H(2$A____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````$`&-+P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```#!241!5`C78V#``KQ,K>R]W2VDA%34M?6-;9R!0ES]R9&!_K+1B1):
M>H;63JY`H1G3)O/P\PKFYBO8R9@YN#@"A=BF9_:Q3NEFJ6?JC8\)\/,`"G'.
M#,MNK:DM*^VI[N+@FY``%`J:%2K05-?8WIG7QCQQ$O=4H)"/KZ=H07%%97-5
M>5$P>TX64,C-2$<M/*6AI+"E(RED]MQY0"%S70TER:C4](RT.,78.?,7`(4,
M-)55M:2%1<3$Y2Q-;.4CL'D'`.B&,GKRN]7^`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V)O+G!N9P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`Q-P`Q,#4Q-30S,3`V-0`P,C$W,#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\`7```60`#7@,%
M704%7`4)80D-9PT09Q`8:1@==1T?<1\A=B$;6ALB9",A7R$OAB\J;2HH:"@U
MB#4N<2XP=3`X@C@T>31"E4)&ED9"B4)&D$9/GD]0G%!.ETY>=UXV?C4D;P`F
M<`,K=0<S>!(ZA15*D"<_=29-C2]'?BU.AS-:E3YLL$MII4QOKU%LIU!>H#I@
M<D9A;42$C4=U>"[)RP''R@')RPW3U2>]ORS5V#KHZDCW^E'X^F3(QP;-S0G2
MTAC4U2#*RC#)RC'AX3C2TC35U#;GYT#\_$;EY4+'QCOJZD;__T_X]TWJZTG^
M_E#V]D[Y^5#V]E?Z^EYP;RKX]V7__VK*Q0;/RA+3SAKHY";U[CK^]TKR[$SQ
MZU#4ST;$O`"GH2'=U2_CVC;@V3[]]E'_^&B@D@J0A!*BD`WFTD.VIT.4=0:H
MCRV89S9]0`;-)@',(P'4)PK[:5'.*`V+'`K>,QCK12O8/R>R/2KX5S[_94WN
M8$GL7TCI;5G]>63,``!_``#.`P/0!07,!07-"0G6#0W8$!#2&!B4$1'A'1WD
M(2'4'Q^=&1GN+R_R-37A.#CZ0D*[,C+\1D;G04'&.SO_3T_^4%#Y4%#V5U?Z
M7E[W967_:FK___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!W1@)Y`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```*A)1$%4&--MP4M.`E$0!=!;
M'WB@#!RX`A9@G+LAU^$>29CHQ!C;1(+8=/?#KEO/!>@YP!^")VQ6A5.-,'=W
M?U1@M5CF'`PU,S6!XUP'R3G8U,6DKN'XS%)];#=R$I%U+7!\;/KOR+ONY6%\
M*^=+0''-@6UKSP<IKC,)1=>=QFGW8[=\_>*1$P3WE\BF*E>A+5O+O>.]#ZI[
MZ5V"3$(Q,,34%P8NDY'XQR\FXUF]#$?9MP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O87HN
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(V`#$P-3$U
M-#,Q,#8U`#`R,3<Q,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/____KU]C$YOCU#N1LFL2,MM28RM1LB>D-.T#M#GU5@WF-N
MYEYGUUUFUF=QY&MSU7>`Z!PPO``GS``8?P,JS@4LT`4LS`DMS0TTUA`WV!@\
MTA$JE!U"X2%'Y!]!U!DRG2]4[C59\CA8X4)F^C)-NT9I_$%@YSI6QT]Q_U!R
M_E!P^5=U]EY\^F6!]VJ&_P!>``!<``->`P5B!05A!0EA"0UG#1!L$!AN&!UU
M'2%X(1]Q'QM:&R%B(2)D(R^&+RAL*"IM*C6)-2YU+C!U,#B&.#1]-$*50D:9
M1D*-0D:01E"@4$^>3TZ;3E"<4#9^-4Z%.3UP(6"*/RA4`"M6!%)S-'"343A@
M$T1C)U)W,$MK+5^"/VV032]5!VZ12G.44?+?V,AN4L^OI<ROILDQ!<`P!L,]
M%L8\%]-%'<U((L]+)\Y4,-YB/KI2-,97.-!=/,19.=)D0^)J2?IY4N)L2L1>
M0>!K2^5O3^1R4/)Y5N1S4>QU5/%\6O*`7O.):_R0<<5Q6/J/<=9\8O:5>N.L
MG,NRJ]M-*,U5.=!</_1U5,IF3.YZ7_6$9_.);?J5>L\O#<`['LI*+YM`+.1G
M2]AD2])E3.]T6.1S6<%?2^-V7<AH4O*+=.Z\LL%I6\*.B/___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````)DS:D(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````KTE$0508TVW!2T["4!0&X/\\>FVP'9@0PH`8949<FJMP"RS!11D'
M,&*"DQ+L`VC/.=<%R/<!_Q#FJ,H'OUS-1%55OQ@HBQ23N;&(L!`4W9#(!WEL
MR1.3!`C;DJ)Y2KDER=)7\:XXS.+DNQ!=[5Y_T\\$QK+N(]:;M^?E9[V(>8;B
M;#?+T_ZEZS\:&X\9BF\)S]>NX8H\CT5`<6K-1*5,-S9W=S`&=Q8N"A5/$9%Q
MQQ^O>E4'PA3+LP````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]C9BYP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,S0`,3`U,34T,S$P-C4`,#(Q-C8W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____QTM-P517A0<B
M?@`>BR0_F#A3__[_?'N`Z>COX>#G!052!`0M"`@T$!!9(2%H)R=N-35Z.CI^
M1D:)3$R.4%"065F75U>465F6:FJC:FJAG)RGT]/=YN;LV=G?V-C>ZNKO.SQN
M9F>>$AAB0TJ(T]3:P<G0Q,O1NLG#X.OF[/+M"6823)Q2`5H!`58!#5X-&&89
M)W$G+G8O*VLL.GTZ39I-/7D]2(U(28Y)0X%#49E13H].4Y-37:-=7J!>9*1D
M:JAJPL?"Y^SGUMO6Q,C$[_/OY^OGTM;2NKVZ"F@',G,Q<JMQ5J)1"UT`#EX#
M+FDF59A,69I0'6@2.7XO-G(M/'HS2(@^\O7QO\\0X.M.LKH`MKX%M+L%N\(8
MGJ,AJ:\HM+HNO\0TS-(XT=="S,H`S<L#S,H)U=0-X.$=U-,?6%@-IZ4;LK$C
MOKTJRL@PU-0UZ>I&9F8L24DT8F);X.#?UVPAZWTO]HU0\XI0BCH4?2L*?"P*
MO6A*JU$UL%H^S```QP$`R0$!QP$!S`4%RP4%S`<'S0D)U@T-TQ`0WA@8TA@8
MX1T=Z"8FZRLK[34U]3HZ]4)"^$9&^D]/P4].V%U=RE=7VV1BW=S<_O[^_?W]
M]?7U\O+R\?'QZ.CHU-34S\_/IZ>G____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````UIK!/`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"U241!5!C3;<'!30)A$`;0
M;[X9W,5D)6LTF&A#-L&=4(4)-X_&`CAZ\VX+-F`!9J,<A,0`R_XS0P'Z'O"'
MH)E5K[W_+/N'2H7D-R$U#W63I>0-555A&%ZD<O/"L.O/O!((5C%_'NK=>C09
M>P@_'@7WD_7HV"VV=O$DM^+R9M"O81/:-=IIVX<[B-_]SH-"RMB/A]9AN&26
M+*&,J9UEWKT;VB%#O)"E.8_,A*&R$(I0<IJ9F?C'"5C=4/::?HW0`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-G
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T,0`Q,#4Q
M-30S,3`V-0`P,C$V-C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____0-38`?0``?``%R`4)QPD-R0T*B`H2RA(8SA@8S1@1
MD!$?T"`?SQ\9FADGTR<AI"$PV"\JKBHXW3@XW#@RN#)!XD!!XD$ZPSL[PSM(
MZ$A&T490[E!0[5!7\E=>]EY>]5Y9Y5ED^61D^&1F]&5H^FAE\V5J^VIJ^FI%
MQP!&QP%'Q@-)QP5+QPE.R0U2RA)7S1A<T!_L\C7O]3K;X1W;W1W?Y"'BZ";B
MY";EZROEYROI[B_IZR_M[S7S^#[U^D+X_$;'QP#&Q@#(R`''QP'(R`/&Q@/+
MRP7*R@7'QP7,S`?(QPG.S@K0T0W0T`W6TQ#3U!#3TQ#6UQ36UA39VAC8V!C<
MVQW?X"'@X"',QP#+Q@#-R`'-R`//R@70S`?3S@K4T`WIIR_LJS7OKCKUM$+W
MMT;YN4KZO%#SL#[ZNDWZNT^C&QNL(2&N(R.U)B:X*"BZ*BJ]+"S#+B[`+2W)
M,C'&,##.-#3+,S/0-C7U1$+5.CKW24;;/S[A0D+Y3$KZ3TWE1D;J24GZ3T_Z
M44_Z4%#Z4E#N3$SQ3D[X45'X4E'W4U'T4%#T45#V45'___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"XZ)A$`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+I)1$%4&!EES\L2P3`8AN&THFGKO"!:ICK(,,7&K;D%%^'^Q,J,
MPU#)G[2)6/N6S[R;#Z&_>:CAM>*>*#^:96%T::Q./O)"TI6@*C9-"/<+AGR$
M2;O6$EB:ED[RTE$4826`T<G[#.N\TC_J@(`EG;ZPVL^,4(Y:4LK%,'UROL\"
M.%J$D5$P']%'B'<T?JM#Y2HE\O'P'IR+402ZMK6KQ"P9W$*^'0=6J*HVKLHF
M_6N3;R@AH*TQ]N^-@R\MK$^\.2-(*P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8G(N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U`#`R,3<P,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___UAXI@$P:P$O
M:@LX<294CR91B#IIGC18@F.-O%V%L0H]<2%1A%F'M@0Y;"%2@")/>$5FA%YY
MD0]#;1!";!)'<Q-(=BM5>2Q5>3-8>$%NE%%^HQU3?252=2Q=@TYYFF2#FSIY
M.P!:``!2```Y```X``-<`P5;!0E?"0U@#0I#"A!D$!AJ&!%+$2%X(1]P'QE4
M&1M8&R)B(R%?(29F)B]]+R%8(2AI*#6(-2IK*BMK+#!T,"YO+BUK+2IC*CB#
M.#1U-$*20C)N,D:71DF224^<3U"=4%":4%"74%&745>;5V2C9&JI:F6A93!W
M+S9W-3^"/EJ768JHB0I?!2-T'56=31UI$E*21HVGB$-^,WR6=7.L7E^11D6(
M'3-V!72I3*O`F7:H2'&B.'FG0K+#G9W%9&V5,5:*`&R%/7N439.^/GV=.Y*Z
M+W"6`XVJ-'6+-;;34*2]/G>*+:G%09.E2L+99<SA:+W->H&1,I>E2L+0>*"V
M#9ZQ,+;%6*N_$*:T09BE&K3#)];C3M;E4:*L'+*[,<3-.L+)&-SB2+_%0L+%
M`,?*!>+F*_+U0O;Y:L[.#=35(.'A.-74-N?F0/[^2N#A0NKI1N[N2?[]3_W]
M4/;U3NWN3?;V4/'Q4/;V5_CW7O___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-"+P/`````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)4U0R5
M?+V3.WHR0G3T+5W<@4)J>LY^,25ME<6M-7%F3FX>0"%M^Z"TSE)1%F:>K-[L
M,"]7H)!Y;/F\+DE!.0D!]KJI+0F!0*&<_OF3JCBEA(05F2)GS9Z6#Q0J6S!E
M8@&KB)B\-'?JW.F3:X%"/DE-$QKYQ6459+@J9K2G6P.%//W#\[HS>=DX^!+G
M%$79F0*%''0U5.+K&Z*#JYM3'&TM3(!"!IK*ZEJAN7TS"R,";*R,C;!Y!P!]
MZS)VH@;*#0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C
M:"YP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S0`,3`U
M,34T,S$P-C4`,#(Q-C<Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%U=35Q\;'P<+"LK.SU-74X.#?W=W<S<W,R\;%X][=^N_M\.GH
MQGEQR\/"L14'M1L-LAH-J!D,MQX0M1X0LQX1O"$3M1\2J1X1OB,5PR88O"<9
MN"89OBH=K2D=N"XANB\CQS8HR#8IP#0GSCLMP#8JA2DATD(UST(UN#PQV4D[
MN#\TUDH^N4$VI#PRSTQ`N40ZK$$WXU9)SDU"P4D^QTQ!ND@]RTY#P$H_T5%&
MLT8\W5E-S51(V5E-O4U#HT,ZZF)5T%=,R%-)WUY2U5M/MDU#W%U2UUM0Y&-7
MVUY3ZV9:RUA.YF19WV)7P55,PE=-UV%6QUE0WV5:O%5,Y&==WF9;NE9,ZFYC
MX6MAV&E?T65<Y7)GZWAMR69=SVIAYWENZWUSXWIPZH-Z[HJ![(F`[8V%ZZ2=
MRY^;Q9N7QIV9]<3`QZ"<^=#,[^/BM1$'Y5I1^/?W_____O[^_?W]_/S\^_O[
M^OKZ^?GY]?7U\O+R\?'Q[N[N[.SLZ^OKZ.CHY>7EX>'AWM[>V-C8UM;6U-34
MTM+2T='1T-#0SL[.S<W-S,S,RLK*Q,3$O+R\N;FYLK*RL+"PIZ>GE)24BXN+
M?W]_````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````?B0L[P````EP2%ES````2````$@`1LEK/@```,))1$%4
M"-=CF((!&*9,GJSJ$A]N)B\B(":CK%=<"!*::!<79>&7D:XCJJAI4U`&%)K4
M%QOMIA34V>$KJ6;H4U(%%)K0G!!H(A?*WAJC;F4?4L$*%&(LB#!*X^5H:^3D
MSO3TKVL!"N67.JID=;8WU5>59GM[,70!A8JJ-:2U3'D::E*3$CULV9F`0I5L
MLL)\N0&UY<EYKM:6W;U`H?H6<7XQB<@<KA0G!V.#GGZ@$$N'H)"4@K9[6+"S
MN;XN\P2@$`8``#&W4"6\4;%/`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V)S+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,3`V-0`P,C$W,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\[.CMH9V@`
M`P\#!0TA0;!.=/9D:'8`,,P#,\X)-\T-/-800-@)(6H%$#0=2^$A3N0?2M0O
M7.XH2KPU8/(N4<<T6-)";OI&</Q!:>="9^5/>/]0>/Y0>/DR/F,`-,<`,\8`
M*)L`%5,#.,X"&V,%.]`%.,L%.,@-0-$00],81\X=3MLA4^`9.YT;/J0B1Z\O
M7^HU9>TJ3[LP5\8X8]TV7M%"</9&=?@Z7\=&;^9/>_M0??I0>O57?_)>B/I)
M9+-JC_MEAN,80ZP90ZTA2[,N6+Y!:<Q3>MIAAN)<?M1EB.`I4:\G3Z0]9+Y9
M?,A'8Z!.:ZI:>+EHBM-HA\H?(BD]8ZQ';+D_6Y9NC]0?("`K+06FJ`KGZ4#4
MUD3Q\U!.3QKFZ%(6%@"#@@7)R@C$Q`[7UA">GPUN;0W<W1O>WAW-SAOCXB'M
M["_AXB[:VRWO[S7(R#"YNB[0T#32TC;$Q33W]T+M[D'Z^D;1TCSCXD+GYT;\
M_$_\_%#T\T[U]E#V]E#EYDSR\U3Q\E<P,"]!04`,"P,"`0$P+R]F965J:FID
M9&1>7EY965E75U=04%!(2$A&1D8X.#@J*BHG)R<A(2$8&!@2$A(1$1$-#0T*
M"@H)"0D%!07___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!JW/JU`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4&--ESSTN1%$8
M!N#W_;[W'$<F49@I-$(QA27HK$*E56J)Q`)F"C9@(1*=0D2K4XA$*Z(0<>^=
M>WXL8)X=/,`:0GN322K=7^DWW$/4HY#/%[/RU@^5)@\R$+?#ZNIPJW8D25J[
M$\9Z<3V\YAU&?=O\O8"PI:3X1(]*@7FX,2RL>PZG\R!&>5E5"*9T]'7R8=I,
MWBH)0;_3L_V#D;WB6%M+$'S[<I</DO0YRZW^@#B^GWKP$&4EUU;:R_H'_[(G
M06T@SG]Z`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8VDN<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(R`#$P
M-3$U-#,Q,#8U`#`R,38V-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___^;MYN_U[]SBW"B-(3:9+S:%,#J+-$6E/D28/E"N
M2D^D25>Q4%:M4":&'2)I&S*0*2AQ(2IT(RYY)B][*#Z?-3%]*C6"+3.`+#:$
M+D"<-SB',#N+,SR--#Z/-DRI0D*4.D>9/E"L1DZH1DJ=0D>3/TZB1E:Q35&F
M25BR3UFR4%6I3%JR45:L3EJQ45FO4%JQ4E2B3&*W6EZN5V2U7#J),=+8T<K0
MR<3*P_/Y\O7Z].SQZ^#EW\W-S,S%O]'*Q-C2S<_)Q.?AW'\V`,Q7`<Q:!LQ<
M"L]B$LQC%M5I&=%G&91)$M1L(-=R*-QY,+%D*N&`.=Q_.^:'0>N.2?"54=.#
M1_6:5_F@7NB66?ZI:OFF:,M4`,U6`\M6`\U<#<Q>#LM>#XM!"\]B$]1J()U1
M&M)M)*99(N%^.+ML,\9T.\9U._&24.N34_RC9/RD9?ZG:/>A9?>C9OZN=,S%
MP-C1S,W&P>':U?;P[/[^_OS\_/KZ^OGY^?CX^/7U]?+R\N[N[NOKZ^CHZ.3D
MY.'AX=[>WMO;V]C8V-;6UM34U-+2TM'1T=#0T,[.SLW-S<S,S/___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````.TN`GP````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````JTE$0508TVW+.PK"0!1`T3<O,^:#*11#M!'<@B"X`&NWY5YL
MW(=BJ0LP1%-:2""9]W&TU5L>N``_&=C`PJ5N.'"PO[:C/+D@0&+CYN0LB*+)
M8@<(<_ODL5BCI%F4N"Z0&Y12&SPPGU-T_"%K'S19PI98<C0=@858B.IV1LPF
M2"^!F+R?%D%XW4M?5F&\^T+U&(14A6X^$%$ES2H(H`BS?$D-(M,N,B]E$?C3
M&_!36Q"[ZR1=`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B="YP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-S`R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____N+.UU-?;
MQ,G+T=35S='2J*^PV=K:HJ.?L:V=M*R-N;&3P[ZMQZ1%?5D`?%@`PXL!PHH"
MR8\%QX\*RI(-Q8\-B&,*SID8D&L1SYP?FG49W:@GTZ$GSITGI'XAV:<O[+@U
MKH@JWJXXW:TXN)$RXK-!PYL[PYP[Z+E(NY8^[L!0[;]0T*A&\L57\<57]<E>
M]<I>Y;Q9^<YD^,UD],ME^L]H\\IE^]!J^]%JMIQ>O*EYMZJ)S)`'R9,5Q)`6
MS9<<P8\;SI@?PY(?SITLOY,QX[)`UJA`Z+A(S*-#Q*)2N9A.T\JVMJ^@N[>N
MRI8KY\Z:N*N4\J],P5T-G89ZPZN?J)V8]X)0R+RWN&Q1N65)X<S%UL;!V<K%
MQSD0V$@AP$$?I#D;K$`AKT(CMD8FN$@HNTHJRE$OODTLP$XMQU$PR5,QYFI&
MS5\^V65%]'50Y712PV-(WWYAXG]DYHEM[9%XV(ARRH!KT89PZ9B"X)1]XY>"
MWY>#WIB%YZ&.TIF)V*"1Y*N:R)F+TS0-PTPNQTXPTE4US%(SUUDZ_'%/Z&E)
M_')0[X%D\H5HZX5KYI^.YZ>7P(^#K(9]J9:1P3(1SU$T^F=&\FM.]F]0[HIS
MHYZ=M9B3V;FSZMC7WM#0P<#`____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````:5\V&0````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``O@%
MI#4L]50DA(6<Y604@\*!0@*2JN:&:E(BCE:^\WT"2F<`A<25C$PT944%7;W\
MF.?-K2X`"LGKFNDHV-F+V?KSSIE969('%%*WT%=Q\.;BM@YEC>V/;I@*%#(U
M<'/1XIP\FXF%8T)M46X64,C8P].&?59D>A-;8T]71W8&4$C;G2<L9-+$^N*^
MNIB*]LP4H)`R7V#4E,*(JFG=T\O*6U*3@$).P0EQS?$UO9WY.6VM:<F)V+P#
M`#SE,>3<BIC^`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V-K+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q
M,#4Q-30S,3`V-0`P,C$V-S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___^2.3JM?H!B042::G";@Y+.M\B5?8]20$^JFZF%
M;89Q4'>]K,%<4U^NH[1I5'^LI+C`M])F6Y"4BK]E7W\S)W5018<V+'A&/H9.
M1I.,AKHM)GDN)WHS+'\U+GXZ,X4X,GX]-H8]-H-"/(=)0I)(0HU(0HLZ-6].
M2)%?6:584Y!O:;1P:K-S;;=J9*=H8J-T;K9V<+AW<;EU;[9U;[5S;;%V<+6$
M?KMG8Y."?JV"?JQR;Y,I(W@N*'HO*7LP*GPP*GLP*WTR+'XS+8`R+'PT+G\V
M,((V,8$]-X=`.HM"/(Y-1Y512YE64)U:5*%"/G=>6*=@6ZA6499<5YY43Y!2
M3HYD7ZM'1'I84Y1C7J=>69U?6IU<6)EK9K!I9*MN:;)D8*%O:K%M:*UR;;5H
M8Z1K9JAM:*IV<;AN::MW<KAV<;9W<K5T;[!E89A\>+MZ=K2%@;]D89",B,*!
M?K1\>:AX=:)J9XZ7E,:(A;)Y=IZ<F<F!?J9A7WR=FLB<F<0X-8!'1(Q85)YK
M::5J9Y]]>KN"@+F!?K6(AK=Q;Y1Y=YVDHLLM*WX\.X9J:9-;8:#-A7M_6E7-
MHIS+?'.F?WK?L*JN6%'5?G>G95_-?WC3AH"04T^Y;&>80#YF*BK___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!:7?W\`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```,%)1$%4"-=C8,`"./EJ9PCQ"O8[R<BI)<;K&@.%6"9.F35U
M$C.KA%.H=4E=<0Y0:-[L"=,G3YO+)-98VA2NU]T.%!+E8I_)SR;0X-(2$I1B
M4F`%%.(0D9XCW,O-H]0<E9!EEEH&%+)H-1!7M.V1E.I(,C+7C^P""A6F:WK(
MVKM[^[7E9V?&:O<!A7*#E1WMW+Q\`ZLKDF/"BLJ!0M$JKK+.GCY:.H;UE7F6
M-@%`(75Y60<%5?^X#-.TFJK."`ULW@$`+)`QC7_:DP<`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VPN<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-#(Q`#$P-3$U-#,Q,#8U`#`R,38W,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%0````T(`P```'%,U5(```!@4$Q410``V@``_SDXWC8V
M_WL`C$I'_UI9_\X``.D``/\``.=Y>X0`B:48C(1Y_[V^QK6V_[W'__^-B]G:
MV=;;_^_O[^_W]_?W[________P```````````````````````````%BW;1@`
M```!8DM'1!\%#1"]````"7!(67,```!(````2`!&R6L^````2DE$050HS[7*
M.1*`(!`%T?[B*#JNX'+_FYI2:.H+NQH`:%)I03:;*=RE"W4YAZH>J-O6NI[(
M)'N_DE35A+?N[M->&AD^Q-]J_-`_8;P-5(HDRTL`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V)W+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`S-0`Q,#4Q-30S,3`V-0`P,C$W,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___^\XO4OG,PTF\LTF\H@87XW
MI-0XG\XWG<PXG<L[GLM`IM1$K]Y#J-=#J=='IM$R=9-(IM%/LM]3MN--J=,[
M?IP_A:9%C:]'D+)@P>U.F+MHS/AEQ/!0F[U5H\98I<ECN>!=K-%>K]-QSOE5
MF[IMQ>QUT?MKO^5LON->I<9PP^A\U?Y]U/U]U?U[T/A[T?AYSO1_T/2+U/:0
MV_USI[]TI[]SIKUXK,1TI[Y[KL5YJL!\K<.$MLZ'N<^3Q-N6Q]V*M\MLCIZ1
MO-&BTNA_I;:FU>J3O,Z9PM6OW?*QW?*IT^>DS>"RW?*PV^^FS^*6NLNKT^:Y
MX/(NG,POG<TPG<PTHM$XH<XG;8M`K-L]H\]1NNA6ONM/K]A'E[E6M-QCR?5/
MH<1(DK)6J\]CNM]RU/YUU?]NQ^YQR_)WU?UWT_MTR_%YQ^F&V?V%U?B)L,%!
M/#E%0#UH8V!Z=7(S+2I$/CM)0T!+14)334I84D]64$U:5%%B7%D6#PP9$@\;
M%!$>%Q0C'!DF'QPM)B,R*R@W,"U*14,7#PQ'03]43DQ@6EAC75MB7%IO:6=V
M<&[___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#0J.V(`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+9)1$%4"-=C8,`"V-C$M$R,%(6X6#GX
M1&35]4!"@JK&>1JBW"R</,)2*CH&0*&(I)Q<M=APYA!VWAB9M*QTH)!3`%.@
MLXV9J86MO8NGK[<'4*BMN*B\N;ZVOJFUK+J[J[,0*-376U'2T%[7V%):5=-3
MV5$`%`KR<;0VM[2R<W#S\O-WSW<%"F7'1X4&AT5&)Z1F9J0D)\8!A10%@"[B
M![I(UU!325Y:`B@$=Y&^MK*"G*0X-N\``"Q[*7I`.O\X`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VTN<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#`U`#$P-3$U-#,Q,#8U
M`#`R,38W-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___SIM.P!(``!'```M```L``-+`P-*`P5*!0E,"0U1#0HW"A)3$AA9
M&!$^$1]@(!]?'QE'&2=D)R%0(2I9*CAT.#AS.#)B,CMK.TB!2%")4$9W1E>.
M5UZ37EF*662:9&299&6996B;:&J=:C!K+T%Z0&:897B7:A0]`!4^`1E!!1Q#
M"2!)#5AY2&V,7BM0&$%C+^#D(>GN+\?*,,[1-//W/MO?/OG]2NKM2?K^4/3X
M4*2D&ZRL(:^O([:V)KBX*.[N-;N[*KZ^+,/#+L#`+<;',,G),<[.-,O+,]#0
M-O7U0M76.OGY1MS</N'A0OKZ3>7E1NKJ2?KZ3_S\4.[N3/'Q3OCX4??W4?7U
M4-'!$-C('>+3*\_"-?7F1M[10O?I3_3F4>W=.NO=3,JC!=.$$-!"#=M,'<<B
M`,P6!\H-`,L0!=`8#=@C&.(O)NP^-?1,0N5/1OE73?%73OA;4<@``,<``+L"
M`,@!`<<!`;T$`<L'`\H#`\@#`\D%!;P%!<`)!\@)"=$*"LX*"LP-#<@3$-D4
M%-84%,`5$MD8&,\8&-$?'>(A(=\A(=(?'^(F)N4K*\HI)^TO+^DO+^PU->\Z
M.N`X./,^/O9"0O=&1OE*2ME#0?M/3_I04/504.I85____P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````)6\VSL````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MGDE$0508TVW!T6U",0P%T&O'<1X4M6(#)"169"D&8@4^**V$7D+L.!V@G`/\
M0\BT^SF=Z_-9U\?U:U<N#-KHH7BK;2&BK68P5$O,=6VL1"GG%QA+$4NU/7Z%
ME,MP"/+RLEF_G92<9^]@?/9-][9G5F(R"PBZWRU2.19A"AL#C/[1QU31G)AC
MA$/@-S?.FB5-#_,`H[L)JTJBB!DQ\<8?*X%/*U;:G,L`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]C;BYP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$R,#4`,3`U,34T,S$P-C4`,#(Q-C<V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```8!03%1%````____U34VQSH[LI<JE'$1NY<R
MZ;A9]H)7?Q(`?Q``S2()S!H#BQ<*SR02_W=H]W9ES!0%SA\-U"T?S`H`G2`9
M_6UDS`@!S`D!IR4A\510U$M&_V]JS0$`S```S`(`?P``S0$!S0(!S@,#S`,#
MT`4%S`4%T0<'S0D)S0T)U`H*U@T-S@X-V!`0SQ(2VQ04WA@8TA@8X1T=Y"$A
MU"`?U"0@Z"8FIQL;ZRLKV"<GL"$A[B\OLB,CN28FW2\OW3`OO"@H\C4UORHJ
MQ"TMP2PLQRXN]3HZRC`PS3(QX3@XX3DXU38UTC0TSS,S^#X^^D)"VCHZYT%`
MX#\^_$9&YT%!Y4)"_DI*ZD9&QCL[_TU-[DE)[$A(_T]/_E!0\DQ,_5%1]DY.
M^U%1^5!0\5!0]E=7^EY>_61D^&5E_VIJ____````````````````````````
M````````````````````````````````````````````````````````````
M````B3-BT0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```">
M241!5`C78V#``A0X12-D.+P,U>14=8T=@V.!0ERL;`*I(<*:<LK:1M;^,4E`
M(5X6=K%H2R%Q12T#"[_(Q"B@D*0TOY0='X^LNKZ96UA\7!!0B#DCQ=-04`1B
M4$*H#U`H/370E%L>:E`XDSM0*"W:4D=""6I0@(<+4"C97D]%#F:0K[,M4,@3
M[B*@0:X.5D`A$PV8B\*]W9ULS+%Y!P#P^B/<YHNO1`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]B>2YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,C8`,3`U,34T,S$P-C4`,#(Q-S$R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____U"XQU34VX3P]
MYT%#B3@Y^HR-\)J<`,P``\P#!<T%#=$-$-40'=P=(>$A&Z,;(:TA(J\C+^HO
M*+HH->\U*KLJ+L4N,,8P-M$U--`T0O9"1OI&0N)"1N9&3_M/4/M03O-.4/50
M!<(`",4##,<'&=$4*MXF*K(F,;TM/NLZ-\<S0M<^3O5*4.I,5?51#KX%$,$*
M([<3I"4!HR4!JRT*IS`-MCL8Q$TKHT8LK4TQTE\^N58ZVVQ-S&9)V&]1MD8J
MS'-HNR\BP38JS```QP``QP$`Q@``R`$!QP$!S@,#R`,#Q@,#?0("RP4%R@4%
MR`4%QP4%S`<'S0D)R`D)S@H*U@T-T`T-R0T-TQ`0RA(2UA04?0P,V!@8SA@8
MS1@8X1T=W!T=?!`0X"$AWR$AU"`@SQ\?XB8FTR<GY2LKFAT=D!P<[B\OZ2\O
MV"\O[34U[#4URC`P[SHZW3@XSC0T\SX^^D)"]4)"^$9&]T9&VS\^XD%!X4)"
MN#8V^4I*ZD9&PSL[^DU-_T]/ZDE)Z$A(^D]/^E!0[DQ,^5!0\4Y.^%%1]U%1
M]%!0[5!0Q$5%\E=7\5M:]5Y>Y5I:^&1D\V5E^FEI^VIJKDU-YFIH]G5U]75T
M^WM[I%55T&]O____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````I*5ND@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"O241!5!C3;<'-6<,P#`;@
M3[(?V3*!2Z%3,!)K<&$!SER8H8S0";I(RX&?0YTF`1)+#-"^+W"&\"!YO?[=
M?]9!KTJG-T^,HZYNYZ]^'$1SR=<"QO;^SOOO.H0B.1>9$/%*]O-13ZV3HJK+
M!$:U^?TXS9I44_;A#XS.'NNI#REE41Z?&PCI93.:,U-@=C/?1=!;K<Y$(;";
MFR-B83\PLZ1(2VNM@6'N1!0E<%O,S7'!/W9#3O7]$+5-`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-O
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`P-``Q,#4Q
M-30S,3`V-0`P,C$V-S4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___^A%!:E&1JB&1NN)"6K*RR[-#:1+S"=-CC*1TFG/3Z^
M24JQ1$766%K#4E/:86/27F`!(X4!(X0**XL-+8D8.9<G1)DK2Z8K1(PR2Y4^
M7;4Z5*%-:K](8[))9+-1;;]D?<8'*'P)*GP-+H$8-H4:.HPL2YLK0G\U49@_
M7JLR2H@X49%$7J!/;;=1;+!6<KE5;[%C;WY&5FAVA95T@9"!CYZ`C9R*EJ0Z
M2UP\35Y`4&%49'5E=89;:'5O?8N/FZ=28G'-K0#,K0/1L@?/LA+;O13HRB;=
MPB_UV#K@QS[^XTKRV4S]XU'QV%#4OT;,JP!_:P#-K0',K`'.K0/0KP7,K`7-
MK0G4LPK6M@W.KPW8N!"+=@K>OAC2M!B4?Q'AP1WDQ2'4MQ^=B!GKS"O8O"?N
MT"^GDB'RTS6RG"KAQCC2N33XVC[ZW4*[I3+\WT;GS$'ERT+'L#O&L#O_XDWN
MU$GLTDC_XT_^XE#VVT[[X%'YWE#VW%?ZX5[ITEG]Y&3_YVCWX&7_YVK$#P#&
M$@/%%PG.'`W9*QW-+1^B)1NM+B/G/B^Y-2K$.S#/0C7S4$+D4D;X7$_R7%#_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````D\I+=`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```)U)1$%4&%=ECS$2PC`,!"59C@G)A`P-#;_@);R&+^1U^0,-=%1A
ML!4LHZ2@R94[=SMS`)L@7.'8'^0U1?%5%4(]$$#7=/,4DS![[W<.")I]K^D=
MO\3,57`"#,WC-$K60H1$5'1!%SG_11B7UA@#B6*J\4.HN35TSTF7&3ERQ02&
M^AA6D6,3E9*?"*VHFM@(JJ5$A"$;05Y)L=YM^P=^^OE,(54_474`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8GHN<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U`#`R,3<Q,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___X$F88(H8X0M
M9HPR;)%!=7,T78=%<)%,>9I3@*UDDT\7/8PU<)A`>II$?FLQ6'T]9ZI7C[=G
MG<:%L8(I9I%4?KQPI+ESHWD>8J%,B[1HH)Q1BK!<G+AHI'LA9X8R<ZRKK*N?
M^V16RX!UW)B-]38HS#PNS#\PSB\FBT@\STT_U5]1ZUE-V$<^IV-5X5!&N6%6
MW%A.Q&%6TEY3S')F^&-8U7=K_F==VGMN_G)G[F]DYFMAWVQAWWIM^71H['!E
MY71IZF)9QWEM\G]T_WEN\7AM[G=L['UR]H)V_8%V^VYEU'YS\8-Y]HI_^H%X
MZ8^%_9*(_Y"%]Y2*_XN%SU9-PEM2RE!(LE]6SWMQ\L;"^CLTUD5`TD0_L$Q(
MO&9@YUM7TG5O]FUIU'MWY(F%]Z2@_A\<?S0OT#(NS#8RS#TXV$I&X3`NE%U9
M[E-0QV%=X6]K^EI8SE-1NVADY7EV_WAU^8*`^H^/TY"2U;N\]K_!]H.&PHF.
MQ[2[_'B#S7.`RZ*M\I/1DI/)D:SEJ9O+F9C)E:[9J]/]S]O_UY3-C(W,@YS,
ME,+ZN<+RNZ;FF97,BIK&D6^:9L7UNKODK9JZB\G,QX./<Z:SD6MO-5E72'-F
M.;"B>+BLBZ"5@)EU.JJ&AO___P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/]L@M,````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)X>`3$
M1"1D%.0E17GYA83%@4)I.44I9?%)=?6%T=FY!26E0"'-</\`^_*6KL[&"AU3
M%R\WH)">=Z"K2M.4B=.F-ZN:>T;:`H6<@GWU:[KGSI@WO[?2TL/!&"@4Y&>M
M7=VO.'/6U)XJ.T>S,*!0@+NNAG+KA-ES)G<H65F8A`*%?`RUU-5"VOHFM4<Y
MVT08&0"%\F,R,]*SDAMJ4Q.+$_+B8H%";"Q,S*Q\4K)RTMQ<G!R"[-B\`P"J
M:3(,QN_.A0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]D
M92YP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S0`,3`U
M,34T,S$P-C4`,#(Q-C8W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____T#4VQSH[YV=H.CL[QI``QY(%TYX0S9P8K(8A[+HU
MWK$XSJ0T]\=&R(T`R8\#RI0%R)`)T9<-W*0=WZLATIX?I'P;ZK,OKX8CN)`H
MNY`JPYHNT:0U]L%"X;5"YK=&^\A/^LM0\<1.QYHP]<10QX0`QH4#S(H'RHP2
MUI44XJ,FMH4FV*`OP(\M[[,ZRY@SVZ<^^;]*[K=,^,%1[KE0R`P!QPP!SA0*
MR1<-V2(8TS`GY34KOC,LR3HQ\T<^U4(Z^E9-ZE%)Z%!(]EI1^6MDRP``QP``
MK0$`R`,#K0,#SP4%S`4%L@<'QPD)T`T-UQ`0"P$!LA(2O104TA@8VQT=XR$A
MSR`@RB8FZ2\O\34UDR$AQC`PPB\OX3@XTC0T]4)"V#HZ_$9&XD%`Y$)"Y49&
MQS\^_E!0^D]/]4Y.]%!0XTI*V4Q,]5=7XU%1V5!0OD9&]5Y>]&5E_FIJ$PH*
M%@T-$`H*(1@8-"LK+R<G1SX^,"HJ4$A(54U-65%14$E)8%E9:V1D:FIJ965E
M7EY>5U=74%!03T]/1D9&0D)"04%!.#@X-34U,C(R+R\O(2$A'Q\?'1T=&1D9
M&!@8$1$1$!`0#0T-"0D)!04%`P,#____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````OJ.@Q@````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"U241!5!C39<^Q30-!$`70/_-W#S`@$J`C"J`+(P<$2`1(4`1R
M8!)B^J`,D(@0(C%.?'>^G?U+`7X=/&"/`7B^>V1WF.>K.M70@P/+\N0YI_F+
MHM4&)-S_9"O;^+S^H#G-D/!]L5RLMZ/R5SZ:41,<;[SY&Z8@Z19EW,%QJWXW
M%:;,KF.\5ABN-$K-W>F4U-X3-F.HN5NB-S4)AI.J=CR<]CRW6)]ITQLNHQHM
M=4RE'@S2[_X'_^M,5B:(*&8L`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V-R+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,3`V-0`P,C$W,#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\"&DT$*GP)
M+X`[6Y]*;+4_6I5#7957<:E%5X!=<I]E>JB"F,D)+WX4.HH</XDE2I@<-6DX
M7*@\69,]6)!4=;I'8YY:>+=4;J)-8HMMB<1H@[E6:I1YDL9VC;R"F\Z5HKM=
M9767I+V8I+V@K,6LN-%Q>8F[Q]_(U.O/VO&ZQ-G0V>NCK\66G[#+UNO/VNUS
M=53.SLJRLJ____S[^_CX^/7N[NOKZ^C>WMO4U-'-S<J+BXG]_?OIZ>?,S,J7
MCW3LZ^BC?U.E?5'8U-&L8SNO<URO4CZT2#N^/S79M;+ZUM/*-B[`.S/!/3;8
M24''24*]13^V0SVY13_@54[B65+D6E/%3DCH8USG8US?8%G@9V'B;&;E<6O0
M:F3B>'+B>7.X9V+(G9JVEY7!H9_QR<?,JZG=NKCZU-+OS,KNS,JV%1"V'QF^
M)1[%*R3'-2ZY-2_20CRY.36]/#?61T"N/CG-2T7`24315$[/4TVT243565/4
M6E3975?77%;H9%[C9%Z:1$#E9F#+85[I=G'L>73K>73E=W+L?WK&;&CPCXO)
MFIC7JJC,HZ'DN[F^(A_0HJ+^_O[\_/SV]O;R\O+EY>7DY.3AX>'8V-C2TM+0
MT-#,S,S'Q\>\O+RPL+#___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````""QO<M`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4&--ESU%*`E$4
M!N#__/?.*$S2,/F2(I(*)8&;D#;BIER03ST*Z@A:&8*!,*:)BCGW7!?@MX,/
MN"$@8A.Z+-*#1.0^7@L:04'MA2='"D6"H47E%'EK-DGNO5<5PN*M*)/F9T?-
MQ^MWVZ3^W>(<C*N#_U7+Y:/"2.I3$*6TEN8[;?$E;#\W5$"XITD]3.P7%\:X
MV;P)B]6B.^X&.=/R\D?O=0-!GX175?6D-2(]P>/OW3[^>R"S)/.)VQYO/[@"
MGN1,MXGHM/<`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8W4N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P
M-3$U-#,Q,#8U`#`R,3<P-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/____IG:/=M;K];7/&"@_+=WKX<*+L=*[(B/,NQN*A5
M;6D4-TL"+Y=JEU(`83\0CRP*HVA>K`0!>'=VNH!_Q8N*TJ>F]IR;Y@``Q@,#
MRP4%R@4%QP8'R08&Q`L+R0T-T0\0S!`0TQ87TA@8S1T=VQ\@UR$AWQD9G2<G
MWAT=H"\OZ"0EK#(RY34U[2LLN#H[[#`PQ3@XW38UT#(RPT)"]#@XS41%\CDY
MS49&]SH[PTQ,]T9&Y%!0^D]/^4A)XD='X%%1]U!0\U)2\596^5-3\5=7\6IJ
M^E)2OU14P5=7P%U=R6MKU&AHR6YNRWQ\XHR,[WQ\U(.#W)65](N+X924[IR<
M\)N;[J:F\ZFITK:VWJVMSJ.CPM75^<[.\:JJPZ^OR+FYTL?'W]75[.#@]L7%
MV.#@]=;6Z@,)S(V.J\3%[)B9M]'2][Z_X&5KR:"E])^ARIJFS*FSS]34S<[.
MR,W-Q\S,QO__^?CX\NOKY>CHXM[>V/[^^?W]^/O[]O7U\.[NZ>#@V]O;UMC8
MT\3$P+FYM?+R[M'1S<_/R_WMYL>+A.A^=\\B''\``,0)"8D*"LH1$=(@(*,A
M(=$L+-TP+[(J*N$X.-\X..U04.-34\M65M]@7^QI:.MW=O;9V>SL[,S,S/__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````,-4`OL````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````P4E$050(UV-@P`)XA36LW-V,5&0DI974]2QM@4*]/$+Y84&^
M7AZ>WC[^`<&A0*'^J=V=\YM+RDJ+JRLKRNL:@$*39C'-X2J*CT](3$I.24M/
M!0JQS)L[G5U`5EY9T\#:Q=7!`BC$RC9[8A^_E(*JMJF=DXVQ(5"(>>;D"=QY
M?H$AX>(1$F*B(D"A&5-ZNA:T-U75U]2V-7:TM`*%IG'P%19$1F7EQ,;E1L=D
M9P*%.`4SY!35=,T=G>W-3/1UM+!Y!P!@-C*O_/W<6`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]D:RYP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-#(`,3`U,34T,S$P-C4`,#(Q-C<T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T1$2Z"\P
M_VYO_6YOQ[N\RL7$__GXY^'@S0$`S```?P``S0$!S`$!S@,#S`,#T`4%S`4%
MS0D)U`H*U@T-V!`0BPH*SQ(2SA45WA@8WAH9TA@8E!$1X1T=VQX>Y"$AU"`?
MG1D9Z"8FIQL;ZRLKL"$A[B\OLB,CN28FW3`OO"@H\C4UORHJQ"TMQRXN]3HZ
MV#,SRC`PLBHJIR@HZSDYX3@XU38UTC0TSS,S^#X^^D)"NS(R]4-#X#\^_$9&
MP38VY4)"_DI*S3T\ZD9&QCL[_TU-^$M+[DE)_T]/_E!0\DQ,_5%1]DY.X$='
MVD5%^U%1^5!0_E-3\5!0\E55\514_UI:_5I:[E55[%14^UU=U$Y.Z5E9_61D
M]V5ES%Y>SE]?U&QLVW%QU'!PY'Q\X8"`[HF)S(2$T(>'UHZ.S(F)W:*B[+*R
M^L+"_\G)T+^_V,G)Y-75\N/CX=/3_.[NY=C8TL;&_O'Q]NGI__/SS,+"UL[.
MX=K:U<_/U,[.^O3T^?/S^/+R[NCHZN3DTLW-SLK*S<K*]O;VY^?GX>'AV-C8
MT='1S\_/S<W-S,S,____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````E\[#R@````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"[241!5`C78V#``GAX
ME%SSVE-EA+@%Q11T[+U`0K(V<;D=B<+<_*)RZM:>@4`A<>.8V)RN!#Y>$2E5
M*[<`#Z"0231+:'9//!>3/+-M4'B('U"(K;*BN*6O*K^@L*BDO**T#"C46,]9
MU];76EW35,_1T%S+#A1BC324S.I-EC9U#XN*\'=V``H%:TD(I'<G*1LX^7C;
M6>II`H7,@"[*Z$H!NLC7T4)?6PTHI`AT469G&M!%+N9&NAHJV+P#`"^2*\LB
M&S\E`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V-V+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q
M,#4Q-30S,3`V-0`P,C$W,3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____%N+K#N;OEV=SWZ^[8S=#4R<SJW^+BU]KUZNVR
MJ*N]L[;(OL'RZ.OQY^KIW^+#MKKRY>GQY>G-PL;'N;_`L[S/PLO`LKQO:VXP
M*V9#/8E63ZAT;KEJ99]V=8`X,I([-9([-9$E(5H_.)<]-I(^-Y-`.94_.9-`
M.9,]-XQ$/IE"/)1$/I='09M+1:!*1)Y"/8A12Z1.2)PW,VY23)]74:A"/7Y<
M5:]43J!:5*P_.W=*1HA&0H!B7;-G8;=33I-K9;MN:+Y;5IU138Q138IB7:9T
M;L)I9+!X<L5K9K!:5I1_><U\=\E[=L=Q;+9V<;YC7YZ!>\M_><=Z=<&"?<R#
M?<QY=+Z!?,J#?<J!?,AN:JN%@,=]>+MP;*>!?+V+ALR#?K^1C-./B]&0B\V5
MD--=6WU%0II/3*564Z-B7[-85:!03HM95Y9T<<*!?=%I9JIQ;K:#@,]I9Z.*
MA]*&@\R&@\N<F=EC8GYE9'UA7Z!55(MX=KQX=KN*B-.(ALQ:67YW=IR-C:2)
MB9?7SIW0Q9*$@7'#N(SFVZ_%O)Z\L)W*O:O:S\7D6S726#/'0!_72R[)6T7'
M-QS&-1S-/B2]4S_S;U;59$[Z?&3J=%[H<UWV?F?XC'C___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!`2B,U`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+])1$%4"-=C8,`"E)6M`U-C/(PUE-0-K!S]PD!")MXI"?Z6
M.DIJ>C+VGJ%10"$IU\3D`#-=155M(SOWH,APH)!M=%*\G*2AEHJ^A9-O1(@7
M4*BXO+Y9OCJM(B,KKZBNM*8`*,3/U](I*,'4W<HBQ"K,*<(,%)HSJZ]_\J0I
M$WJGS9@]<_K$J4`A`?;V+C%1\9X.+BX.-EX>;J!0869Z0V5V8U-^25EM055N
M#E#(5%-!VJ4M+M8G6-;-V<'&')MW`(UP,+A5E0W=`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O96,N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#0S`#$P-3$U-#,Q,#8U`#`R,38V-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/____E04;T`
M#L(%$[X%%,08):4A*[$H,[PO.<<T/]4X1-5"36-=8"`2P3@MN5Q0Y%Q1W1`#
MO3$GK3PPSCXTPTD_U0<`Q&5DXVQIU0$!S`D)S`T-SB(BTB<GV"LLPC(RS#,S
MQCHZVCDXT41#XDE)[DA([$E(YE!0^6!@]F1D_6AH]&NLLV:^N3Z5@4!Y:)F;
MFF*#:I.:E#M..EIN3V5Q75UD6$A,1:[!?Z2T>+C#?FAR'%)8)XB/)\S*`,[-
M!,W+"M;5#=32(*>G(=W<+^OI/.#@/N?E0?[^2G5U(_+R3/W]4?'Q4-341O_^
M:(F(0<S&`'][`-#)!<S&!=C2$(N'"M+-&)20$>'<'>3>(9V9&>[H+^'=+).1
M'O+L-;*N*K*O*N'<./CS/OKT0KVZ,KNW,OSW1I.0*\;".__Y3>[I2>OF2/_Y
M3_[Y4/OV4?GT4*>E-Y62,?;Q5Z>C/OKV7NGD6?WX9/?S9?_Z:K&N5,K'9\"[
M6\._8ZJF5]//<-S7==71=^#<B(R$(Y*.4J"4+6EE0JB>@I-T6(![=YQ^;=2'
M7LA5*).'@^=K4J6&A/!*1H)M;,P``,T#`\T)"=8-#<8:&>`='=0@'Z<;&[(C
M(^XP,+\J*LHP,-4V->I&1O544O___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!CRJ4T````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````O$E$0508&66/O0X!
M41"%Y\[]L2+81"$B2I52--Y"IZ;Q%IY!%!I/XCU6(T%'PU;+[MZY,V[O5"=?
MON(<@+\H6$"SD]9Y$0*BM4EC;P!<JTN99U;81^L0#)@DE>](#_&5DW/H(WJ7
M.9>#:^;=---:***Y$5^>2Y*Z-[/"X:1@PK[B(5.0]KTKQ#<$";6(+)9V)1)\
M8-#@JR*HAQM/JLLS=OHJ:'EAM?L0*KWEZ%<*#A07H2G2]3$"ELW?'8`?S+AC
MH*V`6H0`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]C>2YP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`
M,3`U,34T,S$P-C4`,#(Q-S$U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____[>OM_/O\^_K[^/?XWMW>S<S-R<C)RLK+K*RM
MW-[@^OS]T-+3Z.OLS]/4Q\O,S]34]_S\T]C8R<W-S]+2\?/S^OO[^?KZ^/GY
M]O?WZ>KJT-'1Z_/QKL2UN<"[N,^^@Z>)N\&\J,FIK<.MP=7!\O;RS=#-]?;U
M]/7T[>[MXN/BU=;5QL?&T=K0]_?VX>'@R<G(L9R%[.?CR,"[PTH&OT@&OTH*
MPGQ4TI=WQYI_UL2ZV,[(P4D(PTD)R507V79%QW!!PFU!V8)7WYMYQ(MMZ*N-
MR*:5V\&SY,N^RTH0T9N![LJY\^[L]>_MW=K9[>OK^_KZR,?'Q\;&^_O[^OKZ
M^?GY^/CX]?7U]/3T\_/S\O+R\?'Q[N[N[>WMZNKJZ.CHYN;FY>7EXN+BX>'A
MX.#@W=W=W-S<V]O;V-C8T]/3T='1T-#0SL[.S<W-R\O+RLK*R<G)R,C(Q\?'
MQL;&P\/#P,#`OKZ^N[N[N+BXMK:VKZ^OKJZNI*2DFIJ:D)"0B(B(?7U]?'Q\
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````4\T<F@````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"_241!5`C78V#``AJ;ZDI#HM-RBXKSLU+CPD.`0DWUE5$:
MR:)%Q46\W-(1H1%`H8::I'`^81,!$4$;3U]Q_7B@4*V,>("UNY.%E:6+CX1D
M;#I0J#10S-_1S-S4R\%8*#0F)1<H%!FAS>]J9VOO[.;'$YF4HPL4"DO(XE0R
M\O;0DV66BM<Q+`<*:646<,@KRBDHJX7&9N2750&%TO**2]C5550U66(,<DLK
MN8!".45!A3EL3*S,D8G9P175M=B\`P##=RT=9`&`3@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-Z+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#4Q-30S,3`V-0`P,C$W,3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____&``/9
M*"FE`QFC#BIS"$!M$5)I$E`V$'`U%'77U]@%#9997\(%$)4,%I,P.:X`"%T.
M%V(1&G$F,:-06\8`%*`!%9T)&YL-'Y\*%FH2):48*ZH8*:$G.*HA+84P0*\J
M-HXX2+@X2+9!4+L[1Z)(6,)&5+!79LQ+6*U>;-%D<M5H==AF<])J>-AT@-E3
M5W2OM=T,()X?,:908,=B:Z3GZ?-YA[^PM,7&Q\?@X-_-S<SRY^;.`P/0!07.
M!P?/#0W4$!#;%!3>&!C;'1W>(2&C&QOB)B;F*RNK(2'H+R^N(R.U)B:W*"CL
M-36Z*BJ]+"S#+B[`+2WO.CK(,C'%,##J.SK.-#3*,S/R/C[0-C7T0D+5.CKV
M1D;;/S[%.3G@0D+X2DK0/S_E1D;Y34WT34WI24GY3T_Y4%#Q3D[M3$SX45'T
M4%#V45'D3T_Y65GT6EKDV=GEV]O^]/3\\O+V[.S8S\_2R<G^_O[]_?W\_/S[
M^_OZ^OKY^?GX^/CV]O;U]?7R\O+N[N[KZ^OHZ.CGY^?DY.3AX>'>WM[;V]O8
MV-C6UM;4U-32TM+1T='0T-#.SL[-S<W,S,R=G9W___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!\'[!B````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"
MA`PF6S+6M_=.FM3?U=9850$4$A0V-:MI[9DX:4)W>U,-8RU02$J15]^0>\*D
MB3T=S76,U4U`(7EU'5$!30OKOLZ6AHK*1BN@D*J>AK(LCY%Y6:%-27%I43E0
M2%=+Q5A"C(^=.2PUOR`O*1XHI*TF)RG.R>KL$9F2FQ83$@`4,E&0YF>S=W(/
M3LS.BHL(\@$**<EPL=@YNOK%9F0FA`?Z>@*%1#B8;!U<O*+3<Y*C0OV]W;!Y
M!P`6Z#!B',3\:`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O964N<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V
M`#$P-3$U-#,Q,#8U`#`R,38W,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___SLZ.S8U-FMK;.+BX\?'R$Q.4R(D*#$S-T!"
M1E)46&EK;P(%"@D,$2<J+SL^0Q`U9QI6I1M7J!$V:1I2G1I2G!Y:JA]:J1]9
MIB-=JB):HRACLB5:H"IDLAH];2))?3!FKS!FKC=POCISOS=MM"I0A$)WO3UM
MKDF!S4V$S3I@D4Y_P5N1V@4(#%6'RT5MHUZ3V5>(R4QUK&::X&>9W6:8VV.3
MU%V*QUR)Q6:5TFR9UW*AWFJ2QGFDWG:@V'VHXA07&Q89'4U05%)564=*31\@
M(+*SL^SM[.'BX=35U#HZ.4%!0-75U,S,RV9E9?[^_OS\_/KZ^OGY^?;V]O+R
M\N[N[NSL[.KJZN7EY>3DY.+BXN'AX=C8V-;6UM75U=+2TM#0T,[.SLW-S<S,
MS,K*RL?'Q\#`P+^_O[V]O;R\O+BXN+6UM;"PL*NKJZ>GIVIJ:EY>7EI:6E=7
M5U965E%145!04$]/3TY.3D='1T9&1D)"0C@X.#4U-30T-#,S,S`P,"\O+R(B
M(B$A(1T='1@8&!<7%Q04%!`0$`T-#0P,#`D)"04%!0,#`____P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````)-R'^H````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````OTE$050(UV-@P`($!=6,':QUE"2%).14M`Q-@4(B"@9V
M-D:J4L+B,LJ:NB9F0"%Y;5M[2PU9,5%I175]<RL+H!"'*P\WIZ,>+Y\3OP"[
MBS,74(BIH+BFM8>AIZ.YMJJLHKH.*.1?Z./6S=#;V=)875Y6Q=P`%&(I:VCK
MZFIOJJTL*2JM]JX'"GGZ969G9[+%LX9[1">FY^0!A6(24E(28Z-"`P-"(A/2
MLG*!0E[)*4EQ,6%!C,$1OJD9[OG8O`,`J_`N58M>W00`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E9RYP;F<`````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#4`,3`U,34T,S$P-C4`,#(Q-C<T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____PQ@:
MQ1D:AQD:QKZ_U<[/65E;-C8WPL+%1D=)]?;X:&EJQ\K,[/#R]_GZR<O,P\7&
M(B,C]_KZ\?3TSM'1S=#0^_W]^OS\X>/CW=_?'R`?R,G(QL:U-C8U34U,1T=&
M6EI9R<C!W]O$T\6%RKES[>OBT\>:T[14WL1SX-&>Z^'`R\.IR\.^QKZ[QP``
M?0``?```R`,#RP4%R`4%R`D)T`T-TQ`0SA@8D!$1W!T=X"$ASQ\?RR$AFAD9
MQB,CZ2\OU2XN[34UW3@X]4)"N#(R^$9&T3L[XD%!PSL[^D]/^U!0]5!0K#DY
M\%-3\E=7]5Y>]V%AZ%Q<Y5M;]&5D\V5E^VIJXVEI]G5UXMK:I)Z>U]#0R<+"
M^/'Q[^CH[>;FV]75T,K*^O3T[.;FQ,/#_/S\]_?W]O;V]?7U\O+RY^?GY>7E
MY.3DX^/CTM+2T='1SL[.RLK*Q,3$P<'!NKJZ;FYN;&QL:&AH4%!03T]/3DY.
M1D9&0D)"/S\_.#@X-34U-#0T,C(R,#`P+R\O+BXN*BHJ*2DI*"@H)24E(R,C
M(2$A'1T=&QL;&!@8$!`0#0T-"0D)!04%`P,#____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````X<-;<@``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"^241!5!C3;<P]
M#@%!&,;Q]VMVL799$2=0*IR%1)Q!H]-Q`16]2'0:A80[*%2T*HE&ZVOLC#$]
M__+)DQ_`3PA-C*-8W^XF$Y%0U(8`<V'QK;7-F%F1(!`<JA5FQ_MC%"5)7`A`
MH!,BOO++AMNUE0-";Z6!#<RSG'/NJI11YNI?+B">EPP2MHAEY2T,Y4'ZX3`S
M(DJZ?DK6:;TVO)Q/EUZRC59Y;XU*TI]8<S>62(1Y0##C_O1CM?T`+@C'!'_Z
M`O>R/:0M+]6@`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V1Z+G!N9P``````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T
M,@`Q,#4Q-30S,3`V-0`P,C$W,3,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#____N1TCXYNC4RLO5U-7Y___X_/S!PL*RL[.R
MS\;9Z>/!R<3U^_<->2`%:A(@<R-*G$T`70``7```.0`#7@,%8`4%7P4)80D-
M9PT-9`T0;!`*1`H29Q(8;!@13!$==1TA>R$?=!\?<R`?<1\951DG=R<OA2\A
M72$J9RHXAC@XA3@X@S@R<#)!C$$Z>CL[>3M(DTA(DDA0F5!&AD97GU=7GE=>
MI%Y9FEEDJ61EIV5HJVAJK6H"8@$E=20H>"<P@2\P?B]!BT!FIV4.80<470DC
M:!@960HD7Q-1AC[@X-_5U=3-S<S2T,QE0Q)A/@UI,`%F+0!E+0/OY-[8M:>2
M-A2N1RRT;6'FMJZIBX;$KZO]]_:=&`;YZ.:I$`/'E9"D%`KBM[3,``#,!07B
M65CGY>7>W-S.S<W^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;U]?7R\O+N[N[K
MZ^OJZNKEY>7DY.3AX>':VMK8V-C6UM;2TM+0T-#/S\_,S,S*RLK'Q\?$Q,2_
MO[^\O+RYN;FPL+"GIZ?___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#.J!:V`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```+M)1$%4"-=C8,`"1$14]6W,=`1XZFHJRPJS,D!"\KI6
MYGI*'E'I5>5%.8RY0"$930M+0WO_F'"6M.(\QNPBH)"&B;6Q@U^<.Y=O:D%&
M9J$74,C`QE3++3F0/S(ED3TCO[0:*.1L[J3LFA3$%\\4P99;PEH/%+(T4I.R
M#4BPXV8&&E3APP$4,G:4%15R"0T+B04:5-O8`A32EA,7%I-6]`R.!AK4T-P*
M%%*1$!:55%`7Y,TM\:YOXFS#YAT`3U8K9Y<4FGX`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O97(N<&YG````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U`#`R,3<P,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___Y8Q
M-*Q05,AV>[ER>I=88G=-;I5TE*>+J8=QD&!MIH.2RH&2QF%UIEU[M3]:C$]P
MJD9AE$ADETQHG4YKGU!MHE9SJEAUK%]^MGJ?X7N@X'"0RGN<V5Z'S5-SJ66)
MQ6J-R59]N6N9X'.=W4^9*U>9.%V;/FNK3"AS`"IW`V*G/G>P5S)T!3A]#4"`
M&&NG0G.P37:P3W>O42YP`#)S!3U^$$F('4V,(5J8+U^<-6^J1FZD27>P4':M
M4'JN44N!&#UP"I6V:H^;3%]@#7%K(WUV-'YR/;MJ"L)Z(\:!*Z%X1?.V;JMW
M0+I;![E=!_&M;+E?$LQ[->N@8H4_";U@&<>"2]1]1:YO1[A("KE)$;Q0&W4\
M']I]3\]M0+8\"K4^#-QX4.2#7MJ"8,]S5KQ$(L%-,+980NN&;+,H#*<H#.:#
M;=5#*N5:0L=/.J!#,N]G4&X5![LE#;`B#[0G$,<Q&KXQ'<4W),,[);HV),<\
M*<Q!+<E%,M-)-=9..\M30^)@3NIH5.IK6.%W9[<:!KT>"F\4"+4@#K,B$+DD
M$K4D$;HI%KPL&GL>$L8Q(;LR(80E&94V*MU20=U;2ME92^MK6]QI6N!O8NEZ
M;G01"+0@$<`C%;HG&NU?4]UG6^IX;ZY#/,!.2?___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#5ZO\`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@
MP`)F%L:X.^FHZ9N:Z)I96%G;`H7:)BR8WQSAZJBII6=N:6!D!Q3JS4_.2*R9
MDQ7BXJ"J;6AL`Q2:&!8P+RBTHWUV7YJOL[V&.E`HW2<I+M4CLZNL>M+<J2G>
M;D"A[.!PSRB_DIZJNH:FQLD+V8!",V*]`OTCN\MK<PNFLW+Q"0*%IN5%)\1W
MEN9,8>'D55"2%P$*U5?.:FGM9^;@D591Y!<7%0(*5105,[%SRRE+R<I(2H@)
M"V#S#@`;)C+Q94(]]0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]E<RYP;F<`````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M-3``,3`U,34T,S$P-C4`,#(Q-S`T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____>UU@AVEWJK@HM,,KWN@F[_4ZT=DSRL\S
M^/Y*R,H`RLP#S,X'UM@4XN4FYN@KM;DFS,XMP,0M[_(ZV^`^W-X^^?M*[?),
M^/U1^/I1[?%0T=-&^?MD^?QH]/9E^OQMQ\0!Q\4!RLH%S<P*T,\-R<<-T],0
MOKX4V=D8V-88V]P=W]\AY>,KZ>DOI*4A[.TUOKXLQL<PKJPJR<DQSLXT\_0^
M\O`^T-`V]?5"U=8Z]_=&X>%"P\,[^OM-Y>5&^?A-ZNA)ZNI)^OI/^OI0[N],
M\?%.]O=1]/10]O51Y>19TM)6[^]LB(8*\_!CY=U-Z>)FGY<\I98.HH\7H84E
MC&P1P:ISM)-%NHPUNHQ.PW\\S)IOP%<&QEL'V'$CCDL9JELAZ8$UP6TNVWXX
MWH5"]Y=0Q%,"TF$0CTT>M6$HS'$T]8Q&R5\9[XY.JE<IC652]X)>Q2L`>QL`
MQRX#QC()SS<-CRT1VD8=SD8?Z%@O]&E"MT\RXF1!^71/]'10](9EE59$;#DO
MR```QP``?0``?```R@,#RP4%R`4%R`D)T@T-TQ`0SA@8W!T=X"$AT2`?FAD9
MI!L;ZR\OKR,C[34UNRHJQS`PW3@XT38U]D)"^$9&YD9&PSL[^T]/_%!0]5!0
M\E=7^VIJ____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````@*2J"`````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```#!241!5`C78V#``EI:)\Q9N&!Z3T=S>W??E%GS@$)%
M9=7U!345)87%I>655;5U0"%?8R\?;R$U1245+5US!T]'H)"^C%Q8?@@/-R\?
MOXBXE*L84,A6(2"J(5!#65W'P-K%S<84*"3O%YW'Q!RNJJUGZ>QA;V$$%)+U
MC\QHC(_0%#"S<W>R,C$$"DESL`2%!K.RL7-)2HAR"@L"A9)S8M)BT^,2LU-S
M4[*2,A.`0OV=36U=O9-FSIT_>\:TJ9,G8O,.`!]E,O'N;H#)`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V9I+G!N9P``````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-0`Q,#4Q-30S,3`V-0`P,C$V-S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____-
MS,[!P<;%Q<GQ\?3O[_'&QLC[^_SR\O/O[_#=W=[:VMO-S<["PL.WM[@%$6$0
M&VLA+'DU/XHX0H4T/7M&4)E"2XP[0GI06I].5YI78)YJ<JUZ?Z*3F+J:GKFJ
MKLL'%64=*W@=*W<V07]!3(U07)Y78J!>::9F<*E^A[IF;96$BJQL<(BPM=2G
MK,FRM]6]P=L%%6,+&V8-'&L0'VT4(VP9*&T<*6\@+W<?+7,@+7,G-'DH-7DM
M/(,O/H@J.'DP/'<[2H]"4)<X1'X^2HA!3HM"3XQ&4I%/7*!06Y!?:J%57XUR
M?;)X@[:'D;^CJ<F6F[,$%F,$%F('&&4)&V4,'6<,'&4/(6P;*W%79)U-6(1H
M=:Q>:9AU@;9M>*EO>JNUM\#.T-F_P<G<WN;DYNZ_P,3"P\;Z^_RRL[/4U=35
MU=3^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;R\O+N[N[KZ^OJZNKIZ>GEY>7D
MY.3AX>'>WM[8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,S*RLK'Q\>_O[^\O+R[
MN[NRLK*PL+"GIZ>=G9V4E)2+BXM_?W____\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!5LJZ_
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+Y)1$%4"-=C
M8,`")DSH3==2=T]N:6FLK2K)RP$)]76R^JHZ)+8TU567%C`6`H7ZNRIRO6W,
MTYKK:\J*&/-+@4*Z@8;ZKF;AVK(Z<@%Z!@KR0"$)&6F1R-!@`4$A83%)*7%1
MH)"FAJI56%"(B9*]LZ>:AXHC4,@_WLO%V"C"+2HFSB\AUB<:*,3%P\1LH6B9
MQ,F1P<;-R\</%*IN:&&W-K5+R<LIKFQHZ^@&"F4UM[#8*CNE,A:69[>V9_9@
M\PX`\)\O7N0B`DT`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O970N<&YG````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#,R`#$P-3$U-#,Q,#8U`#`R,3<P-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___^$A)/E15LI)6M1<;5UKC(":P!1XN">)
MQ0QTJ#F9RQ!VIE>NT".+KV&VTEZOPS:'DV6[R`UQ?11R<#F+BF:PL$"+AD2.
MB8W+N&JLE5F;?6VOAUF9<':O@V&<;@!;$`E@%F&<:6VG=AUT)"UX+SIX.P!:
M```X```W``-<`P5>!05=!0UE#1!H$!AJ&!%)$1UR'2%W(1]O'QE3&2^#+S6(
M-3B".$*20C)N,D:61D&)04^<3U"=4%":4%><5UZB7F6E96JK:F2<9(C!B"YH
M*E.>35>?45Z;66FI9`]%"C*"*T62/D^32$^427.I;'RS=92<(<;/+]SF.LG2
M/N3O2MOD3.7O4=OD4,#)1NGR:/?^5LK-#.7G0>CJ1OK\3OCZ7LS+`<W,#M+2
M&M35(-?6*,'`+,S+,LG*,>'A.-+2-=34-MG8.N7E0\?&.^[L2>OJ2?[^4/;V
M3OGY4/KY4O;V5_OZ9??W9O__:LPP`-U8+^!D/O)S3/%V4,PQ`\\^$KE()L10
M+<]7,[TS&N9V9\P``,X#`]`%!<P%!<T)"=8-#=@0$-(8&.$='=0@'Z<;&[`A
M(>XO+[(C([PH*+\J*L<N+LHP,.$X.-4V-=(T-/I"0N5"0NI&1O]/3_9.3OE0
M4/___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````.?#_J8````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````LTE$0508TVW!34X"01`&T*^J"YL9T!$2%Z"8N$&7
M7LDK>`4.P(%<FG@&]FY8&$D(PMA=/QQ`WP/^(#QAO+^SOK<J2432NX#RX-95
M]]%R2LP$P4--))O=D?/DD0IE"')'7NX_;_R[&?(H'()%:X?RT?'%Y#">4C4P
MFNVV_EIYKAK*7^Y@Q/70!Y=&2VUG>J4.098NZLOJC<MKGW,$!/,?M4;4R>?F
MZ@;!R8P2KYO$9AX1^,<9G990JG%'7JP`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]F:BYP;F<`````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-C<T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MG8N1KI.>IXZ9WL72E8J08DQ9N*BSFW^3BFF"O["\H)N@9UQHR[K-O[3%@&F.
MT<?>?G>?J:'+<G"+FYK':FN(4E:54EJ9<7^SM,C499.JK\_?J]#A:9NP:IJO
M;)VQ=Z.V<9RML-#=L,'(>+/(<*6X:YZP;9ZPA[_3<J"PA;G,=J2UE\WAC+S-
M<9>E<YBEG<[@=YNHFLC8G,K:I]3DIM/CA*:SJ]?G?IVIJ=+BF+W+E:RU<*[#
M:J.V;)^P;)ZO<:6V;Z.S;J*R;J"Q=JJ[<Z6U<*"P@;/$>ZNZD<?8?Z^^<)FG
MA;7%A+3$98B4BKG(D,#0;I.?D+_.>Z.PA*Z\E<33>J"M>)ZJAJ^]@:BU?J6Q
MG\_>AZVZI-+AE\'.B[&^J=;DG<;3K-CFH,G6K]GGI]#=IL[;M=SIM,?-:Z"P
M>[/$=JBW>ZFW?JRZA;/`@:VZ;9&<@*JVC+?#I]CGDKW*J=CFJMCF;J.QKLS4
MG*RNT-[=L+2?RLVKPZE?N[BQX:5`[K%-O;JVVZIKV,BTSGLOYYYBJZ:CQZRD
MZJ23YXIVZI:$XJ"3NT<TT%]+]8!KZG]JPFU>[XIYWX1SE&)9YJN@J5=*['UM
M[(1TUWAIN89_][>NOT<X@3`FQHN(=4I(M'IXQ:2C____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````ZCQ=
MVP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C7
M8V#``MAYQ28*\O%+RCNKJ6KJEJ0"A>9/F35I]M1Y"WSL+)G:ZZ5,@4)SIW7U
M3^B;TZMOR];:T-AA"!02X6"=P<TL(*Z07577UMP4#!1B$1:=*23!R:6H75G;
MV9(9"A22D;4V5Y*6*_+S4NF>/IDG#RB4D9+OF%61XQ$84U[=4Q,;#A1*+];1
ML'?SUC-)+%->:!-B`!0JS757=_(,,#9+3HN/C#8J!`H5:#FXN/J&Q5E8)25$
M103Y8_,.`*'P,O$,[RM8`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V=A+G!N9P``````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C`P-@`Q,#4Q-30S,3`V-0`P,C$V-C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#___\A/&,H1&PT4GU0<:``)UX%+&(%+&$0
M-VP8/&TA1WLU68LN3'0X689&:9I"88Q.;IL'+5H)+UP?.5DG0F(N2FLU4G15
M=9P/-%\3.64C2',E2'`U68,[67M(:Y-+:HY5=9I`65HM2$@O24DS3DX\5%10
M:FI&65E6;&Q.8F)C>WM6:FIQB8ESB8EQAH9WC8UB=W8`0P!!ET%>KUX!:P`$
M;0,*;PD.=@T251$>@QT@?A\PDR]#HD(S>C)0JT]1J%!FL64&;@`ZFC4_ACMN
MNFH$10`$1``+<@4,<`46?!`>?!@GBB$=8!D]DSA,J$96KE!<K%<C>P$C>@$K
M@@HM@`T@5PHYCAA$D2=*G2M`>RI=K3YJMTUCJDADJTEMMU%QKUE]OV3`Q`"_
MPP/$R`?$QQ+.TA3<WR:?H2'2U2_I[3K6V3[S]DKHZTSR]E'+SD;GZE#U^&C)
MR`#%Q0+#PP++R@/-S`7)R07*R0G+RPK3T@W&Q@[5U!#6UAG/SAC>W1WAX"'2
MT2#1T2CBXRSKZR_O[C6[O"S(R##1T#3?WCC&QC+2T3;P\#[W]T+3TSKZ^4;D
MXT#BXD+%Q#OGYD;\_$_W]T[\^U#EY4GS\D[GYTKV]5#T]%+S\U?W]U[W]V7V
M]67]_&K___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#$E*NT`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```)])1$%4&--ES\%1PT`0!,"9V95.IH0?O'GRXN$P
M'"_A$(2A*#`6I[O;)0!W!@W<(<Z<-ZYC1)VE;>6;XU(F^_E<>E`2OPC'B\_L
M;43*)%K"\524M4=*-"D#CM=C__BMS6>?'HKJ!N%Q7/_V9FZ^3-[VA)#[]][I
MYLM2LF6".+41J3&Y+-4BWHECCZ!$NZUY/=PRB.=162C50T;-S,O]!_]IED]+
M!Z^JR@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9F\N<&YG````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0R`#$P-3$U-#,Q,#8U`#`R,3<P
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_\4("<()"L`3%<$<(<HK,+\M,KPO-=D]0K@[/\-!1>5/5-1,4-=15NM;8.9<
M8.AI;>AP=+0C*KPM-<D]1==05[Q+4<E16.-A:,Y:8+-.5.9J<-YF;=]N=.I_
MA:<P.[`W0;-(4JLX1+9!3<!-6,M:9<)>:/KY^I^/H):'FI2&F-+)U\K"T+NR
MPH9ZD:*:K:RLK=WN^:.^S;_<[*G"T,GD],?B\;S5Y*>]RJF_R[S3X,[F](F9
MHLKA[K'%T+O/VM7K]\[C[[3%SXBQQY2^U+'0X)2LN)VVPZ6^R[K4XJ[&T\7<
MZ,SA[-;K]H^WR=CM]\CE\<',S,3.SK['Q^_W]\;,S/?]_?S]_+&QK_S\^_7U
M]/'Q\.'AX-[>W=O;VL[.S<W-S,/#PKFYN(N+BOOZ^,S+R<O*R/[]_/OZ^??V
M]>[M[.KIZ.GHY]W<V]/2T<_.S<<``,L!`<<%!<P'!],0$,P2$MP='=0G)^-!
M0?-75]S;V\C'Q\?&QKFXN)N:FOKZ^OCX^/7U]?'Q\>WM[>GIZ>;FYN#@X-[>
MWM/3T]+2TM'1T=#0T,[.SLW-S<O+R\C(R,?'Q\/#P[N[N[BXN*^OKZ2DI)"0
MD'U]?7Q\?/___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````!K>
M(&8````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````NTE$0508
MTVW!04I"810&T.^[]\=`]`75P(&@`U$J27`+S5M`\_;A,MR$"W`/(DX$G6@0
M/*I!/I0*7N_>VP+J'.`/8LI\O7F8M0:W7KI93`3P(..G9-C1/00)B\\K89#E
M/OS@5D/"MK;MB%O]];U0;<8)";L4>7'_<B*I2C,D?$=5FL>1JDJW0,)-]M9^
M9J?'#R'M,N8)7>WGE>C9^86(B!""X:A1!?F5K:XY&H^7$(B`(<SB4>\*\@G_
M^`5\14TL`*PG&@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]G92YP;F<`````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$R,3$`,3`U,34T,S$P-C4`,#(Q-C8V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```8!03%1%````____B#4V<7!Q__[_.CL[7V!@E9:5\>WL
M:@``9P$`:P$!:0$!;`,#:P,#;@4%;04%:P4%<`<'<@D);@D)<@H*;PP,=0T-
M<`T->!`0=!(2>Q04=!04?Q@8?A@8?!@8>!@8@AT=AB$A?2`?9!L;BB8FCBLK
M@2<G:B`@:R$A?2@HDB\O@BHJ;2,C<B8FB3`O="@HEC4U?RTM=RHJ?"TM?BXN
M>RTM>2PLFCHZ@C(Q@#`PA#,SD#@XB#8UAC0TGCX^HD)"C3HZI49&DC\^I$9&
MED)"ITI*?C@XFT9&J4U-FD9&JD]/GDE)G$A(JE!0HDQ,JE%1I4Y.J5%1IU!0
MFTI*HU!0LF1DLV=GM6YNQ;Z^W=?7SLG)P[Z^^_;V1$-#SLS,L[&Q6%=7W=S<
M\?'QW=W=U-34R\O+IZ>G:FIJ:&AH-34U&1D9$Q,3`@("____````````````
M````````````````````````````````````````````````````````;9[9
MX0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"B241!5`C7
M8V#`"K)9,Q+=Y04X^265#)W\@`*Y.5F9;'$:PIR\XHK:#M[!0"%F]K24M`03
M'FY1.35[SR`?H%!Z*DMR4KP1EY"TJH5;@+\S4"@FEB,J.E)+$&Q0H*L=4"@B
M/$1'1DP`8I`7DQ50*,Q778*'1U06;)"CI3E0*%1?BH\39I"UF1Y0R$8!XB(7
MD$&F!II`(641F(L\;*V,=56P>08`W1\@HFF6K1(`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]F<BYP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P,34`,3`U,34T,S$P-C4`,#(Q-S`U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____T#4V[NWQ``#'``#&``!\
M`P/)`P/&!07'"0G(#0W)"@J($A+*&!C-$1&0'R#0&1F9)R?3)"3$)27#(2&D
M*2G',##8*RO$,##-*BJN.#C=.#C<,C*X.3G*04'B.CO#.SK#2$CH1D;14%#M
M5U?Q3D[57E[U65GE9&3Y9&3X:&?Z967S9F7S:FKZ967E>7GSA(3XQ\?+P\/'
MPL+&U]?;S\_3SL[2WM[AQL;)[^_PV]O<^OW^SM/3R,W-QLO+Z>[N^?W]]?GY
M\_?WW^/CUMK:Y>;FTM+/T='.R\O(R<G&[.SJX>'?V-C6R\O)WM[=V=G8TA@8
MWR$AVR0DI!L;K"$AZ2\OKR,CM28FY3,RN"@H[#4UNRHJO2PLPRXNP"TMQS`P
MR3(QQC`PSC0TRS,S\SX^]4)"[T%!U3HZ]T9&VS\^T#P\X4)"^4I*^DU-Y49&
MZDE)^D]/]TY.^E!0[DQ,\4Y.X$A(^%%1]U%1]%!0^596[5-3]EA8Q["PS;:V
MU;^_W\G)Z=34\MW=[]O;X]#0]^/C]N+BR,?'^_O[]_?W]O;V[.SLXN+BT]/3
MT-#0S<W-S,S,RLK*R,C(Q\?'____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````LHU1,@````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"F241!5!C3;<'!30,Q$`70/^.-8V,K
M*,5P0U$*0*($*N)*%8@B*`'1"5EYUV//IP!X#_A#$%'NSU]/U^7]\BWY=/>J
M0*Z5#]L&BBXE12R(I3C]6$F)-1T;%#F'WL*`)SFE/#H6U-):,/BD%/%MAZ+N
M?>W@_!B28G\C%,-^;)"?)01M^XM!8:M-\O!X<V$?;E!L;<QP()]MVMYM0G$;
MIL%)1EFG3^(?O^0S60BZF-I_`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=I+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-``Q,#4Q-30S,3`V
M-0`P,C$V-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___]Y$A/:-C?/<'&/3D___O_5U-7'QL?*S<W^___4U=7&Q\?!PL+G
MY^;@X-_-S<S(Q,/Q437Y7D+\74;E64/Q9U>KGIW_5D^]GIW,``![``#.`P.)
M`P/0!07,!05V!07-"0F="`C6#0W8$!"1#0VX$A*O$Q/2&!CA'1VO&!CD(2'4
M(!^X&QNG&QO`(2"P(2&8'1W/*"CN+R^R(R.T)26\*"B_*BJ6(2''+BZ%'Q_*
M,##A.#C5-C72-#3`,S.P+R_E0D+J1D;^4%#V3D[<1D:.+BWY4%"<-C:(,"_,
M4E'\:6G\;F[I;&S,:&BT86'0='.P966.4E+QC8RY;V_=AH7$>'C/@8'@CX_Q
MH:#2BXNUEY>OH*#X]?7[^?GX]_?=W-S/SL[^_O[]_?W\_/S[^_OZ^OKY^?GX
M^/CW]_?V]O;U]?7R\O+Q\?'N[N[L[.SKZ^OJZNKIZ>GGY^?EY>7DY.3AX>':
MVMK8V-C6UM;4U-32TM+0T-#.SL[,S,S*RLJ[N[NRLK*GIZ>=G9V4E)2+BXM_
M?W____\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"[/6X\`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+U)1$%4"-=C8,`"VMJ:>1BSRJKKZFHJ2G-2DD!"+0V9:<55XC&UE65Y:8SI
M0*'6QJ+D_.@@*S=6R8(,QM0\H%!3%5MN0J"2NJE65'92<@X_4(@#:%"BI[0"
MDX5_7%)62350*#Z-CYO30U;5T"&`*[V0O1XHE)Q?42NHJZ9O[^H;FU<NP`L4
MB@QE\?,R8A85\_8)C@@/"P$*V6C(2\FI:`N).+LXVEF:&0"%=!2E9)0UC84E
MW)ULK<U-]+!Y!P"2/BT;-=4)*0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O9VPN<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0S`#$P-3$U-#,Q,#8U`#`R,3<P,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/____E04=535-:NK\;'Q^#@
MW^G1T,T!`,P``,T!`<P!`<X#`\P#`\P$!,P%!=$'!]`)"<T)"<P)"<X-#=0/
M#\\2$ML4%-@4%-(8&,P8&-(<'-0?']0@'^0B(J<;&]@G)[`A(;(C([DF)MTO
M+]TP+[PH*+\J*L0M+<$L+,<N+LHP,,TR,>$X.-4V-=(T-,\S,]HZ.M8Z.O)$
M0^`_/N=!0>5"0NI&1NY)2>Q(2/),3/904/%04/M75\]+2^A75\I-3?UD9.ID
M9/EM;?UQ<?9S<_]Z><QA8?IY>/^!@?I^?OB`@/V<G.&.CO^DI.&9F<Z-C?JS
ML_ZXM]*7E^ZSL]ZHJ-BCH^>VMLRDI,ZFILVFIO;)R>&ZNOK0T.[+R]2UM??6
MUO_BXOSIZ<R_O__W]__Y^?;R\N7AX=+.SM#.SL?%Q?7T]/[^_OW]_?S\_/O[
M^_KZ^OGY^?CX^/7U]?+R\N[N[NOKZ^CHZ.3DY.'AX=[>WMO;V]C8V-;6UM34
MU-'1T=#0T,[.SLW-S<S,S+N[N[*RLJ>GIYV=G924E(N+BW]_?____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$@G7?P````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````O$E$050(UV-@P`*ZNMI94Z/]@Y.;
M&VHJ2O)R0$(=+0D>IC)"4@&UE:4%C(5`H<Y6=A=+!1%N+M'0LB+&_%*@4%N=
MGXV*&"^'@+A]=DYN"1M0*"O%55=:F$]00LXX*2<M/0,HY.T5'A\5$<D2$Q?K
MYNS$[``4<K0,:VQNJJLJ*TJTM3#4T00*V:C:-3?75Y<7Y_A8F1AH*`.%="7Y
MW3-!+@JR-M/74E,$"LD*<?(8^88$>C*9ZVFK*\EC\PX`V#0N,]O3E\@`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G<"YP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S,`,3`U,34T,S$P
M-C4`,#(Q-S`T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____U34VQSH[_V=H?SL\S%]ASF)CS61FUFMLE$Y/X7AZU'1U[HF*
M^IB:NW)SYXZ/_Z&C^9^@TG9ZY(2(L&EL\I28O'-VQWQ^X8Z1_**FY927_JBL
M^J:H]J.F]ZBKS&9KT&EPS&=NV'1YTH2(2;U64L5?8-%M2YM45*=>;M%Y9;UO
M9[EPC/"7BNN50KE.*7,P1KU21;I11[M34,5<3;U95,%?8-)K1)%+7L9I<>!]
M<=]]7;)F;<AV@>N+@NN-B.Z3?]R(BN>3F?&BU-4@S;T)X=(XTI<8S'\!YZ)`
M]K-7SG4-\9M0V'(GS%@%_XUJS",`S1$!W3\OSQL2^F=>S`8`S0$`S```S0$!
MS`$!S@0#S`,#T`4%T0<'U`H*U@T-S@T-V!`0BPH*SQ(2VQ04WA@8X1T=Y"$A
MZ"8FZRLKV"<G[B\OIR$AN28FW3`O\C4UQ"TMP2PL]3HZRC`PLBHJS3(QTC0T
MSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*ZD9&_TU-[DE)[$A(_T]/_E!0\DQ,
M_5%1]DY.^U%1^5!0\5!0U$9&Z5E9_61D^&5E____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````?856WP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"T241!5`C78V#``@P,+'2<G;3,C/0-3<RM[!R`0JQ<_/*R`CP<;.R<W+Q\
M@D)`H:22GMZFK(3(B+C4S(J&CD:@4$XWBT]0<G18;$I&45U;:S50B-G?R\W=
M+S0F,3V_IJ6]M@PHU!?BZ>(:$!6?EEW9W%G/5`P4ZFWR]?8(A!I455H(%.K*
M"XX.AQE47I`+%)(45E)05!81DY*1DU:1$!<%"EF:&JNJJ5O;Z^HYVFK;:&I@
M\PX`*X8P#Q?/^D8`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V=R+G!N9P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`U,``Q,#4Q-30S,3`V-0`P,C$W,#4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^(AYI!0*-*2;@[.I);
M6JF1D-4``%`*"H@,#(D.#H@.#H<1$8X6%H\8&(L8&(D:&I`='9DD))HO+Z<W
M-ZDP,)0Q,94M+8DX.*,T-))"0K<V-I8N+GP[.YXC(UU`0*@[.YLF)EY&1JI2
M4\)!09I*2JI$1)E45+M96<186,)34[986+Q<7,%<7+E45*!J:L=M;<=@8*IL
M;+QQ<<-X>,YW=\IF9JEG9Z=_?\MP<+-K:ZEJ:J=O;ZUN;JMN;JIM;:E^?K]Y
M>;9X>+1V=J]34WN.CM&-C<]Z>K*/C\Z&AL%]?;2(B,.`@+5K:Y>=G=IT=*&6
MEL^'A[J;F]68F-&0D,:0D,2&AK9^?JNDI-Z>GM:FIMV6EL>5E<:LK.&JJM^E
MI=><G,JLK-R;F[B=G;J>GKJ>GKFFIL*@H+NHJ,.@H+JRLLVTM,[!P=RMK<6L
MK,3#P]R2DJ7.SNB=G;'0T.FGI[O5U>[1T>G2TNFQL<77U^[%Q=J]O<6_O\:\
MO,."@H?*RM'$Q,NVMKR3DYCQ\?CIZ?#?W^;<W.//S]7-S=/#P\F^OL3S\_GQ
M\??N[O3FYNSAX>?:VN#!P<;Q\?;DY.G5U=JSL[?S\_?%Q<C?W^'DY.5X>;&D
MI=SHZ>_GZ.[-SM.JJZW___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C;_PV`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"..2;U0TL8SWL
MK6V=?$*BXX!"2J[3@MT3\U*34]*S<XO*RH%"]0MF39\2),##S2<LRJ*EJPT4
MDO7N,6%VF='=U3EQ7N_D_JE`(5;VN0K\8A;F5HZ>_I%1H;Y`(;>DF4:J,N)R
M:GJ&IF;&;/I`H9:VAMJZFL:.]M;>O@GS)S4!A70D!;DX>85$I%4T-905I22`
M0F&S'6SLG+T"Y\0GQ(1'!/@!A?*STC(R<PI*JBJJ*TN+"YFP>0<`3[8RW<:V
M1_4`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9W0N<&YG
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q
M,#8U`#`R,3<P-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___]38VWR^Y(+#YQ50;1=.:2=\J"9XHBA\IRAYHRU]I2^`J2)9
M=3%^ISB$JD*7PC^0N#V(K2M@>C%JAD&*L#5QCSESD#QWEDV7O#YZF$N1M4)_
MGD:$HTN,K4B'IE*7NE>@Q$Z.KE*4M4N(IE>;OV"LTENCQU*2LDV*J%*1L&BV
MW5*/KE:5M5J:NE20KEZAPDZ%H&*DQ5R:N6FMT&:HR6.DQ&ZSV'"WVG*YW'&W
MVW&XVVZSU6FJRW"TUFVPT7.XVW.WV6ZOT':VUG6TTX#"XWV]W7V[VH&_WH"^
MW7:OS("[VH;"X(C#X>[R]/3V]U>IT5.AQT6!GD5\EE&/K6>QU5R>OF^]XVNU
MV6>KS&^SU&*<N&JHQLW2U#^0K4N8LS.)IC2*IS>-JCZ5LUREOG&VS83'W(W0
MY^7IZL_6ULG0T-'7U]_EY=OAX?C]_<[0T/7V]LC-R[6YM[W&P:&NI>WQ[K/%
MMY*AE:2PIFJ#;'Z3?L32PVR&8GV.=J"SF%MQ2W&&8FV`7\')N[3"IXN:?'F"
M;'%]7X*'3ZZP?]G9U\7%Q,C$6,;$A).2?Z^KH/[^_OS\_/KZ^OGY^?+R\N[N
M[N3DY.'AX=34U-+2TM'1T<[.SLW-S<S,S/___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````&8_-,<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````P4E$050(UV-@P`)8V41TT@NFS9@S)U]0($`['"C$)FSHG98S??:<6;&2
M@:&6%D`AWF`OS]3LKJ+RF4SJ:E:.)D`A\6@?IY3BFH[VRC+S"`=[`Z"0OJ^S
M:GQ%2T]W8QVS=929,E#(P]U(-*ZDK:^WOIG%SE17"2CD:BO-EUC8VE!5Z^\6
MJ1<B#Q2R4>#G2LCJ;*HNS7,)TU*1`0HI"G%S)&5.G3RAWR]&0S-(`B@DR,/)
MGIP[92+CI`QC.5DI,6S>`0"'>S$FD!!Z%P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]G=2YP;F<`````````````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-S$P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____@WAZE'V(4DA:<%Z'
M64IN5TY]3DEH;&6.241F+2=>5U**.#9?0T6`$!=8&21C(2QM%"%@5&*@$R9F
M`!A=!1YB)S^!/E*(.TZ!`AYD!B!@!R!@""%A"2)B"R5D#"=G#"5C#RAE$RQK
M#1Y)$RMH%S!N&#!K'#=W'C5P(CMY)3QU+$-Z,4F%+4-Z)#9B-4V)+3]N-4J!
M.E*++3]J/U>2,T9V,D5T/%.*.4U_.$Q]-TIZ1%N51U^9-DAS/U.%/E!^1EN.
M1%B*1UR/4&:?1UR.2U^35&NB4VF@3F.736*546::5FRB4VB=56J?5VRA56F<
M7'"A87:H8G:G9WRN76^=:'RL:7RL;'^O:7RJ;H&P`10_`A0^!21H!2-D%"]M
M&35T$R9/'#9P(T"`(CQV&RY:-$N!3VRK2F2=/%%_15N/46NE4FRE4FNC3&*6
M5FVB25V*5&J>67"E:X&S`"-H`")F`R5J!29L"2IM#2]S$#%U'3Z!'SY](4&$
M&S1G(CML(3EI+U"0)C]P-524*D-V*T5W,$I^,$I]-$^#-E&'0F&B1F2B/UJ/
M1F*94&ZK266<4&REA*:C>*R>8Z^58K>65\247ZF"0+)F2)IBA(AAN+1AG(N(
M8UE9____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````;U)/-0````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``J*C4S.+BXP3
M8DO+JVJ;N_N`0C&)=I'!62E"_''*6@:V[A.`0BHFH6%>.B(L<P0T=&T\_/N!
M0OH%$0%&\=PSIK.)F[KX>/<`A1RB`B4TQ;BF36'FR_#Q=>X`"H4'.6HKB7),
MG#2;)]?/3;(=*!22IZ<J*\4[>2J3<+ZGO74K4*@P35U.1D%PYBS.'&\G*_,F
MH)!%DJ*TO%HR.VNVKZNEF6$#4*BFHJ2LLKJQ*WU";V=;2WT=-N\``-'-,:4?
M]D9.`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VAK+G!N
M9P``````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S
M,3`V-0`P,C$W,#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____1R<7+N++-FHZ_(0"^(0!W%`#`(P._(P/!)`3#)@7")07`
M)07`*`G'+`O)+0W(+0W"+`V#'PK+,!#$,1+&-AB,)A'5/!W4/!W702')/!_(
M/1_)/B">,1N4+AG-1">G-R'B3B_B4"^I.B.>-B&P/B;22R^S0"CE4S6U0BJ^
M1RZ[1BVX1"RI0"K#2S'`23#74SC64SC)3C3(3C3%3#/L7#[*3S7+3S;O8$+N
M8$+05#JS2#+P9$;<6T#663[Q8T?<6T';7$*^43N]43OT:4W?8$;D9$GB8DCT
M:T_S:T_H9DSH9TSS;%#K:$[K:4[R;5'Q;5'N:E#N:U#N;%#G:E#+74;L<5?K
M<%?P=U[@<%GS?&3O?67N?67V@FKU@FKVI93,BWWPTLR_(`'$,!;1-AC-02??
M1ROS9$KJ9D[U:E/P:5'V;E3)7DK(7TOK<EOU?VC6>&;FI9K-O;J_&`#")0W+
M*1#%+1C",!S633CG9%#+8%#(8%#F>VSWBWK'=VOJE(;;L:OVR</E237#1#3O
M5$+/4T/S8D_S8U#;?G/6@7CBHYS1FI/EK*;=J*'\S<?+N+:^%@7`&@G7+2'9
MR\K,N[O,S,S___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!V_:!:`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+])1$%4"-=C8,`"V-GE7>(CC,HGLO&(2&G:^H*$Q&UB(QVE:^JY!"24
M+#V#@4+">E'1'FFE$XKY4]/-7`/=@4*J8055A7D5S$R-19D9`3[V0"'GN/#*
MZJG36+JZDQ(Z_)U,@$(QD7:RDUIRVSH;6MM#W"P,@$+1'@I"R2D]?;5-==GN
MUOJZ0*%0=5'.DL0IO?G].=[VICIJ0"%#,5Y6[K+)S0Y9?D[&VAJ*0"$9/E8.
M04EE*Z\@-W,#+14Y;-X!`.[*+HHAS2/&`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O9WDN<&YG````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,S`V`#$P-3$U-#,Q,#8U`#`R,3<R,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X````$9T%-00``L8Y\^U&3````(&-(4DT`
M`'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q41?4`
M`?```=T``;D`!`"%0`"$/0!Y.`&%/P&`/@6(0PN+1@:)0AB23@""-P![,P"*
M-@"*-P")-@"'-0"$-@"!,P"!-0"`,@&#-`&"-`%^,AB020"&-`"$,P"#,@"#
M,P"",@!],`!\,`!X+@.`,P-_,P1Y,05W,!:(01^5342<90)\+@)Z+#*353.>
M4S>@5C":3#FA4E:M5UZT7%>N5&.T776_77&A887&9W6\483&6(G&7&^14J+3
M:JS?3J/23[?<5LKP0[W?0\?F/LCD2L78,MCL2=SM.^WY/^?P`=+9!.[V+_'X
M-_S_$?__`/[_`O__`O__`___"/__"L_."___$O__%/__'OW^'_S](?__++FN
M!:B=")&!"9-^)X]Q!Y)@&8-+!Y`\`I,A`9L?!V`X,Z89#+8*!*$+!V\J)_\`
M`/X``/P``/,``.,``-X``,@``/P!`?L!`?H!`?D!`:(&!````/___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`&:.QZ(```!W=%).4___________________________________________
M____________________________________________________________
M______________________________________________________\`J9^D
M90````EP2%ES```+$P``"Q,!`)J<&````*U)1$%4&--C*,4`#*4I9H;J;$J*
MDBI@H*P&%,I-C76R->)AE9,6!`(!9:!0069^8G"8NYVQ!KN(M)"@"E"H.#.3
MH23.(R#$V]Y$BD5>"RA4E)F5F<F4'.WOZQ_JY6BN`Q-B3(_Q\_4-#'>ST81H
MS&9.\/0-BG"UTN46U@8*%6;F)47Y1#I;&'#QRD*,STF+=W&PU.,4E1$".H(?
MY(@,:U-]#CX%,0DP$%<%"F$``+L1/:2[?"1B`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I9"YP
M;F<`````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#4`,3`U,34T
M,S$P-C4`,#(Q-C<U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____P<+"LK.SU-74X.#?W=W<U=74S<W,RL3!Y=_<_??T^/+O
MRL/`R,/!HRD`I2H!I"H!I2L#IC`)JS(*IC(,KC4-J#0-J3<1IS<1MD`8>BL1
MND0=LT(<L$0?KT8CM4LGQ%$KR%8OOU$MED4JTV,^U6="SF-`H$XRQ6)!MUH]
MPF)"T&E)VW!-RVE(W')/T&M,VG-1V7-1MV%&QFI,WGM;UG=8VGU>S'99V'Y@
MWH)DVH-EXXYRT\W+TLS*^/+P]_'OZ.+@J28`HR8`:1<`HR@#K2H%JBH%J"P'
M=2(*MC40J342LCD4LCH8PT4AAC$9P$DFT5<UN4\OSEPZQ%<XW6A&P5L^KE0[
MV6M*VG!0VG%1T6Y0L%M#VW17Y85JX(-HR\3"WM?5[.7C;14`CS<AXV]0U,S*
M]O#O_O[^_?W]_/S\^_O[^OKZ^?GY^/CX]O;V]?7U\O+R\?'Q[N[N[.SLZ^OK
MZNKJZ.CHY>7EY.3DX>'AWM[>V]O;VMK:V-C8UM;6U-34TM+2T='1T-#0S\_/
MSL[.S<W-S,S,RLK*Q\?'Q,3$O[^_O+R\N;FYL+"PIZ>G____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````#X'?+P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"^241!5!C3;8PA#L)`$$5G=V=W6QJ2)D@.0(*F&HWF"!C"!1"@D%20
M8!#<@,-@:""I(*E%$IK2V:%E/3SY\M\'^$'`K(@"VU8U.414&!\1BENWQ\^R
M9(7&8#@$"3J,VZJJ&R%1*ZLN@-!_#-AGC?:9EM=AAO`.\^>+6&F#'128^56D
MSJ,[3HT3IS81G'LED[&=M.2H+A=!)R5_'^Z-!&9V-#=[NTF]"E;*FP\1&+O6
M4GBUU=`PDSMHN[-R*>`/7ZA71QG4ISZ^`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VEE+G!N9P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`Q,0`Q,#4Q-30S,3`V-0`P,C$V-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\`>P``=P``30``
M3``#>P,#>0,%?04)?PD-?@T*5PH2A!(8B!@17Q$?C1\?BB`9:1DGD2<A<2$J
MC"HKBRLNCRXJ?"HQCC$XGC@UEC4XFS@RA3(ZCCL^ESX[CCM(JDA&G$90L5!0
MKE!7ME=>NUY3I5-9KUEDOV1DOF1HP6AENV5JPVIJMVI]R'V(T(C>X=[4U]3)
MS,G(R\CT]O3CY>/5U]7-S\W,SLS)R\DPER]!I$!FO67-S<SJZ>?V]/+R\.[>
MW-K6U-+0S\ZG41NP6"&R6R.Y7R:\82CR?S6_8RK$:"W!9BS':B[*;##-;C'2
M<33/<#/5<S;ZBD+8=SG:>#K@?3[\CD;E@4+JA4;_DDWNB4GA@$7_DT_^E5#R
MC4S]E%'VCT[[DU'YDE#KC5+UF&#5AU7\HVSEE6/_J'/RH&[[J'3D:B'N=B_*
M:3#2;C3X@C[@>C[^C$KNADG^D5#YCE#__?S]^_KZ^/?HY>3^_O[\_/SZ^OKY
M^?GX^/CU]?7R\O+N[N[KZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1
MT='0T-#.SL[-S<W,S,S___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"J!":X`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```*))1$%4&--MS+T-PE`,!&#;
M>2__($$#0F(/QH"E&(2>BB&@IZ!B`UH@<?QL'(D.KOSN=``_00@P:>=QET<X
MS9;W:7$(@%4S-8P!U$JLO2'(JT8-`YI8F16Q<RKKC'NB8TH;I#P-3FW#78>P
ME70FPIZ=UOWBR:SB*\*.U>DQW#B92U+R8B1>N40705.1\>M]%2%V@8M^5R_A
M+%B2?69J20W^Y`/6@%P6!X(+DP````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'(N
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0U`#$P-3$U
M-#,Q,#8U`#`R,3<Q,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___[Q!0[U=7ZQ(3,&DI<U$3)$/(*%-7X,U2:2@H7([5UD;
M/5X50<:FO%4G2T8E4()@C%(V7'IRP$=!JP``A04%B04%AP<'APD)B0\/BQ`0
MDA,3DA@8D2,CGR4EF2$A?Q\?>"@HB#0UKB<G@BXNDBXNC#@XJ#0TFS4UEC,S
MD3L[GT)"K#X_F%!0PU)2Q$Y.NDM+LE55P$E*CUA9J5!1EV1EL"4GI2\QD3$S
MD41&ODY1P5=9H7)TP75XQ7=[S,7&Q^WR\LW1T?G\_/?Z^O'T],[1T<K-S?O]
M_?K\_.'CX]W?W\3&QOGZ^O3U]</$Q+R^O=/4T]'2T<C)R.3DXM+2T/S\^_?W
M]O;V]>?GYM+2T<?'QMO7UL7`O^S;V,EZ=L>FI.1S;^>II\P``'\``'T``,T%
M!<P%!=`-#=40$)`1$<P9&=T='>$A(9L9&>DO+XD<'.\U->$X.-4U-?5"0K@R
M,OI&1N5%1,0[._I/3_Q04/504*T\//975_%65OA>7OED9.M?7NE@8/-E9?QJ
M:O5H:,U96>1L;/=X>,!>7L9G9\)F9M)P<,)L:M%V=,=^?M&)B=O)R?CS\_?R
M\N[IZ>SGY_GU]>SHZ.3AX<_,S-?5U>CHZ.;FYO___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$DZG7L````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````ODE$0508TV7/,4I#01`&X']V9EY\>5NEL3!@F48A1Q#$@P1R%D$0
M;(.>04AM[P'2V`EVEHF1Q.S+S*P'R'>##SA!F%,[S&57S)A%5.X%T$%W?.`F
M^ADG9H(@YXXBM;U()X.D#L'SD]>1;X,>6PN2=Q!NSKSYNYC&L5NRFMJ;X!Q.
MQD;#%8\244'"_BX:77_(RNKA]D`.P<^BY+K]OG[5J_5+4P*$R;X/TO'GY#>9
MN<<7(QM8N5SN!(Z*NCG]X!]Y(TG\UHQJI@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]H="YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,S<`,3`U,34T,S$P-C4`,#(Q-S$U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____UQ@9Z"HN]#Y"
M^TY/N@D4P2LTUT%+[D]8[X6+PR`LO#`ZQC5`VD91Z5!;ZUYHZV5OLJO8IJ#&
MC(#C)1B^13C00#3#/S.[4T;I3D+41CJY75#M6D[E=6KO8E?EAH7(``#'``!]
M``!\`0'+`0')`P/(!07+!07("0G'"@K.#0W0#0W)"@J($!#3&!C8&!C.$1&0
M'1W;(2'@'Q_/&1F:)R?3*ROE(2&G+R_I,"_;-37M.CKS*BJN.#C=/C[S0D+U
M,C*X1D;X/S_?04'B2DK].CO#34WZ24GJ2$CH3T_Z3$SQ4%#[45'\4%#U45'V
M1D;34%#P5U?R4U7F7E[U65GE9&3X:&?]967S:FK[*"O.G)W6>(JX7V=[>9*Z
MD+"U@9F::W9R55Y.M["1QKZA:6)/ZM+&Q:.7R```QP``Q@``RP$!R0,#Q@,#
MR@4%QP4%S`@(R`D)T0T-S0T-TQ`0RA(2S1@8W!T=WR$AT"`?S"$@I!L;UR<G
MK"$AZB\OKR,CMB8FV#`ON"@H[#4UNRHJP2PLPRXNP"TMS#(QQS`PW3@XT38U
MSC0TRS,S]D)"V#HZ]T9&VS\^X4)"YD9&[4E)ZTA(^T]/^E!0[DQ,^E%1\4Y.
M]5!0^%)2[5!0_&1D_(%_____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````NC1*A@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"X241!5!C3;<'?20-!$`?@
MW\S.[H5<5/*G`K$&0;`1&_'%4@0;\#4UI`Q?!"60(!XFM[-SNV,!^GW`'X1K
M6BW7>ABRIB[.NOF609>+E0UGU2B2XHS!F"\V[33D*8C$U,4"0;_F\GVSN^>:
M]RE-!L'[!XW^9A2V'`/5"L+2<S!ZX%!>/;G[#^%E_!SSU7$BOBMF6I\$?M#2
MSL]$=.NUN4%P/)4:Y;&_Z%JQ,E4PODQ90NJ3J-96&_[Q"Z/%5JWMM<Z%````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VAU
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R,0`Q,#4Q
M-30S,3`V-0`P,C$W,#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____^]O>FH*'5U-7'QL?4U=4`;P``;``#<@,%<`4%;P4)
M=`D->@T0>A`8>Q@=B!T?@Q\AB"$;9QLB<2,G@"<A;"$OF"\I@"DMA2TH=B@J
M>RHUF34N?RXPA#`TB#0XDCA"IT(YD#HVB#9&IT9"F$)&GT9/KT]0K%!.ITY*
MGTI"@D)0FU!=KEU1E5%=HUULNFQKM&MQO7%NM6[S]O/FZ>;9W-G'RL?[_?OY
M^_GW^??J[.KHZNC6V-;4UM3/T<_)R\F^P+XVC35*BTG*S,GGY^:T``"S``!Q
M``!P``"U`P.X!06V!06U"0F]#0W!$!"]&!BX%Q>W%Q>$$1')'1W-(2&^'Q^.
M&1FZ(B)^&!C7+R_)+2W;-37..#CD0D*K,C+6/S_%.CKG1D;204&V.SOJ3T_K
M4%"C.#CE4%#D45'D5U?L8&#G7E[;65G=6UOI8V/F967N:FK::&CL='3,PL+0
MQ\?/QL;+PL+<T]/:T='TZ^OGWM[]]?7\]/3QZ>G?V-CQZNK3S<WX]_?^_O[\
M_/SZ^OKY^?GV]O;R\O+N[N[JZNKEY>7DY.3AX>'8V-C6UM;2TM+0T-#.SL[-
MS<W,S,S*RLK___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"1*FJ"`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```*I)1$%4&--MC$L.P5`40.^WVE),#"W$#BS'M`D2B5B$)5@$VS$@
M(HTTKWWW79USAB<G!^`'A#7,JBHT3>Q4LE$F9P$L\TD?@O7"JL0$`O/I&"V1
MBJH6)#ZHR_ZPU0(-A9R0?7AI/&4L8)9B=!'=$.R.UYHA)3?;,=<Z5"NFK"F\
M=1="8KP)=*']F!0Y<_+DB_NP?[ZBD80R%XQ=>D0@>%M$)E4&6WKJ#/[P!=57
M1;)47@'!`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O:6PN<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-3$U-#,Q,#8U`#`R,3<P-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/_____^_]74U<?&
MQX2'B\/'R_3X_+;,WLC8YK/`RP-%=@IQO@]TOA)ZQQ)UOQ1XPA18BR."R"-^
MP1Q1>#&$P2MRIC6%PC6%P#R/S#9]LCJ%O$>AY3%PGD68U4".QT&.QSEZJDR=
MV4>0QD&$M5BO\%.@V5VS\EJMZD^6RE^R[U6=TUZMYUZJXUVCUVNZ]&JV[F6L
MX'>_](K(]H&LS(*IQI*XUJO3\9NUR)VVR:S#U*O!TLC?\:R]RK+!S;3!R\;+
MSZJNL?7Z_K*VN=C<W]'5V,C,S^KN\0=ROQ1WOA^"RB*(TB!\OR:"Q2B`P"^0
MUBR'R328X"V"P#&&Q#N4U#-\L4>G[3R.R42;VD&+P5.O\DVDXE2L[$Z?V39M
ME4B.P&&S[F"JWVFU[&ZZ\5F4OGJ\[*.[S+G2Y-_P_.+O^,+(S.WS]\S/T?C[
M_=CF[]_FZM;;WM39W.#EZ/'W^N3J[>+HZ[W!P^GN\-35U<'"PN?GYN#@W\W-
MS/CW]]W<W/[^_OW]_?S\_/O[^_KZ^OGY^?;V]O7U]?+R\O'Q\>[N[NSL[.KJ
MZN7EY>'AX=O;V]K:VMC8V-34U-+2TL[.SLW-S<S,S,K*RJ>GI____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````*D6S2P````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(UV-@P`)$1.)2
MC%/U%$2#@B65=)*-@$+<@E))"1%"_#P>?-Z!85$Q0"%6QR+V4M?)%I83"_*S
MG8I+@$+3)S)UU-F91BJ;<;;5-[17`X58&%M[)]E+I%FIY376M_9,`@K5-E=5
M3.$2M^;0S61LZ6:>!A1JZ)HP>:JMB;:A>4939W]-)5"HO-"!+2NG+]VF/M?=
MQ:W,&2@DY^O)*^#E+Z.JKA$K+QTJ!A0*]_,1#@B)UM(W2-2,5U&4Q>8=`(M@
M,*,G#W+-`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I
M;BYP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#``,3`U
M,34T,S$P-C4`,#(Q-S`R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____J(Z4EX60U=35Q\;'\O#YR<G,HZ33IZB[F)_+?HBW
ME9['@(Z_H:W6<X6\?(NYEJ*^U=[OM<#)[/'R^O[^RLS,U-75Q\S+]_OZZN[M
MZ.SKU-C7R<W,^OW\OL+`UMK8RL[,R<W+;K1C8JI3A<9V19(P2Y<W4ID_5Y!)
M:JM8:*-8=;)DA,-SB\QZ1Y(R6J1%8)E0B,MU/Y`?.74A4YTX)'<`*7P%*7H%
M,X<--(40.8480I0=1),A-7$;/GHC1H0J0GXH5Z0U28@N4)`T7Z%"9:I&;[90
M:[!.*'P`*GX#+X`)5*0O3HXP5)8U9K)":+)&<;I/<+90Y^?FS%(`?S,`T%8%
MS%4%V&`0U%X/SF`2Y&\AG4X9V'`KZWHOX7PXLF(L^(I!_(]&QG,[_Y90_I90
M[HU,[(Q+^Y=4_:-G?S(`SE(#R5`%S%,'S58)UEP-BS\-TF(8E$01X6H=WFD<
MU&8?[GHO\H`U^HI"NV@RYX)!_Y1/^9)0]I97^IM>Z91<]Y]E_Z5JS[BKW<>[
MX,S`_NC<\=W2U,.YZ-##IY:-]=W1_>?<\MW2_^OBPJ^ML9V<^/?W_O[^_/S\
M^OKZ^?GY]O;VZNKJY>7EX>'ATM+2S<W-RLK*____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````.T*-R`````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"Y241!5!C3;<%-3@)!$`;0KWZZ>\`@!")(-'@JSN"*L'$+'D!7
MQIUW\2ZP(!&"1B$P,%-='D#?`_X@C)'2J%YV5\8LMQMY4UP5*9GU3S90%1H2
M%/'S[B,?K'>]O5F+:(9B.(C)O/7@S^=^%:D$(=2O0K/*C>+<E?F>\?3R_DC?
M9<7GGZG0A$$8&85C.)QR(4J1;:%((:=`O;VW:W>/)12=:+D0Z5X>R=SS#HK<
MR?3%;:&+?<-WWL0_?@%1.$=6NGDVX`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VEQ+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#4Q-30S,3`V-0`P,C$W,30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^(&QSS5E?Y
M>'G*PL//R,G]]O?\]?;QZNO;T]7\]??PZ>LO+B\M+"T_/C]Q<'%C8F-655;5
MU-5/3U#W]_C\_?[)R\S#Q<8B(R/.T='BY.3BX^/V^OGN\O#BZ>6\P[[&U,F\
MVK^CMZ6FN:C&V\B.LY%OGW)@E6!HE6B7NI>AQJ&&HX:;LYO.X<['V,>ONZ^X
MP;CI\.D?(!^[P+OK\.OJ[>K&R<:^P;[@XN#5UM72T]+(R<CL]>LV-C7'Q\;;
MUM7'``!]``!\``#(`P/+!07(!07("0G0#0W3$!#.&!B0$1'<'1W)'1W''!S@
M(2'/'Q^:&1G/)27))R?I+R_M-379,S/=.#CU0D*X,C+X1D;B04'E1433/S_#
M.SOZ3T_Z4%#U4%"N/#SR5U?U7E[Z9&3J7U_H7E[S967W:&C[:FKE;&S&O[_5
MSL[*Q,2DGY_NZ.C?V=G0S,SX^/CV]O;HZ.CFYN;1T='&QL:\O+QW=W=R<G)P
M<'!A86%45%104%!/3T].3DY-34U&1D9%145"0D(Z.CHX.#@U-34T-#0S,S,P
M,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL8&!@0$!`-#0T)"0D%!04#`P/___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!+9+&8`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"G)P#
MX[*2P[W<'%T]_4.C$H!"SMZ1&2G1`>Z.+AX^(1'QB4`AIJ1LEO388#_?H+`8
MYM3,-*!0?A$'#U=>#BM;;B$G.W>!`U!(0DQ.345<05E=45Y6255:"BA44FRI
MJ6-@J*NAKV>KK25L`Q02+2NOL#`QMY(Q,S(MM;:O!`I5U[7Q\G7QBP@*5-74
M"C6U`(7:)T]GF#YE0D=S?6-K9V__!*"0\32&&5,G]K0VU#?;=?=)3L+F'0#]
M5S">O;>-"P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M:7(N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0Q`#$P
M-3$U-#,Q,#8U`#`R,3<P-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/____I14LMT==-[?,FRM./AXOKX^OS[_.+AXL_.S][=
MW\3#QOO[_/+R\\_/T/3U]M#1TL?,S/7Z^N[R\LG,S/7W]\_1T<?)R<;(R/3U
M]?+S\^7FYN+CX\W1T/K\^_+T\T^94DR53@!S``!R``!(``!'``-T`P5W!05V
M!0EV"0U]#1"!$!B!&!%:$1V*'2&/(1^$'QED&2^:+S6?-3B7.$*I0C)_,D:M
M1D&=03J*.U"S4$^Q3U"N4%>P5UZU7E6;566W96J^:E:85F:E9H[`CL'&P<_3
MS\'#P3IF.6.H8G*U<5Z-78+"@86^A)#,CY#+CXG!B*#3GNKLZ-'3S_;U]/?U
M]-#.S<?%Q,6LJLBJJ.G'QL>RL<@``,8"`LD#`\H&!L<'!\@)"=$-#=,3$\T:
M&MP='=$@']\C(Z0;&ZPB(NHO+Z\C([LJ*K@I*>PV-L<P,,,P+]$V-=TZ.<XV
M-O9"0O=)2>%#0^9&1OM/3_504/%04-MR<<QL;,=I:<9M;-!T=-9\?,IU=>*)
MB;5R<MB+BMN/CL!\?,N%A>V?G_BIJ.^BHOBKJ^VEI>6EI=>FI>&\O/GV]NSI
MZ>KGY\C%Q:.AH>WKZ]O9V?KY^?CW]^?FYM/2TLG(R,C'Q_;V]M75U;V]O?__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````!?DW^@````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````NDE$0508TVW!,3($41`&X+^[_YGWS,Z04*6*#"<0*%4"T4:;
M2QV#*JE@E<`AW()4Y!!R&66Q.]W:`?@^X`_!`89:_>O;5PU)VA,AM2DQ>HPT
M,Z6`V+/EX)_=2^YVHBH"Q6PR.VVU.3HNC[66Z11`7W<FW59CO-LLP_K:!@AV
MVLOJ;-^?<WO417TCYB+Z<')SF/?7[:(/G@OF'I%)K:FRU(PKXO7=0\E2;B\]
M(AS$1[B:6FL7,?Y$)O[Q"V50/^2)H[Q'`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I<RYP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-S$P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____VWAYK9ZO
MJ9FLE(*BEH6DH)6JT<3=S\/:DH*DFHFOHY.XQ+?5GH^SLJ7$CG^HS\K<HIVV
M#@V+#@V)'1R3553$`0&%`0&#`P-4!@:'!`15!`14!P>'"0F)"@J,"PN+#`R)
M#0V,"@I>$A*0%!28$Q.1%A:5&!B7'!V3%!1G(R.>)B:C)R>B)268*RNF'Q]X
M)B:&)26`)R>",#"?-36M+2V/.CJS.3FP.CJR*BJ!+BZ,+2V),S.8/CZU,S.3
M-366.3F=/CZH.SN?1T>[/S^F2$B[2DJ^3$R_3$R^34V_24FT1T>M3$RW2TNR
M45'`45&^4%"Y557#5E;$5E;#557`4U.\65FX>WNX=W>E?W^OIJ;=FYO.IJ;;
M!PJ*#`^,)"BE(B:9'1]R,C:P.SZK-SF/BHO&D9/-FIO4B8J[J:K@;G*P=WNZ
M/TRD15*I4E^U8F["2U.-<W_/@X[<?XG1AI';0%"H<7S`<7NXEZ+DS"P@T"TB
MUC8KSCTSUD4\X51+VU!)[F5<[&IAREQ4U6);^G9NYVYH^GUTZG1L_X%X^7]W
M_X=_^HB"^(V'RB,<U&MH^9F6\J">_*VKQPT-S2$ARBLHT41#Q5)2QUQ:S%]>
MX'AV[HF(SWMYXHR*Q'EX^YV<\IF8____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````%88K\0````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``J0E
MD]B[>5-$%:44U'4M/8*!0C):J9SM_(DBLG)JVJ9N0:%`(66K<(XF/B4)<7D-
M?3NO`&^@4&%%I6"#4%EN7GY!47%I23E0:-ZDB4Q3IL^8V3]K]H3Y"^;.`0KU
M]K1-FSRUMJZ^L;6SJZ.E&2B4E9[#W,>2'9&6$1T;DQD5"10*-%'AJA)0U3%W
M]_=UM34S!`HY:<:S5G,G6'B&A/DXVML8`87TA./8:GB27<1"_9P=K(T-L'D'
M`#FK,J4&D>R+`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VET+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R-@`Q
M,#4Q-30S,3`V-0`P,C$W,30`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____0-3;HU=8`<```;@``1@`#<0,#<`,%<P4)=`D-
M=0T*40H/=P\0=Q`2>A(3>Q,7>Q<8?A@161$;@1L?@Q\?@B`98ADEA"4GB"<A
M:B$J=2HXE3@XDS@R?C(ZACL[ASM(HDA0J5!&E$90IU!7KE=4IU1>LUY9J%ED
MN&1DMF1HNFAEM&5JNVIIN&ETP'3"RL+!R<&^QKZ]Q;W2VM+)T<F^Q;[+TLO:
MX=KJ\.HPCR\\E#M!G$!FM67-S<SJV]K2&QO>(2&C&QO;)R>K(2'H+R^N(R.U
M)B:W*"CL-36Z*BKE-C6]+"S#+B[`+2W(,C'%,##.-#3--#3*,S/R/C[T0D+5
M.CKW1D;O1$3;/S[@0D+X2DK0/S[D1D;Y34WI24GY3T_Y4%#W4%#Q3D[M3$SX
M45'T4%#V45'@2TOY65CM557V6UO0O;W6P\/>R\ORX.#_[N[ZZ>G][>WVYN;^
M_O[\_/SZ^OKY^?GX^/CU]?7R\O+N[N[KZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6
MUM;4U-32TM+1T='0T-#.SL[-S<W,S,S___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#NE&4L`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```*])1$%4&--MP3%2`D$0!=`_/3L[PQ:+@F51!D9D)-Z"S)N9
M&IMZ`(]A2)4F),:$*MO-_&D/(.\!_P3T6);K8=<G?.U#60PO'3#FT3UU:"'*
M?)8@Z,O0)N^"UU"N9EDA6)1HMR9OY/.8,PT1-W/5XVJ[J7SPB)-^".YMK<I6
M2<G)7AL$1SO\T"M)%]7'"H'>_=(;R2IN]#,$]FF,B:P(;3(C!#J=I7/6I_C^
M[6P-%_P!2+5;NG;TAW\`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:FTN<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-3$U-#,Q,#8U`#`R,3<Q,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___SLZ.S8U
M-FAG:!\@("LL+`UV#3J;.@1M`01L`0YW#1)Y$">+)C:)-4*706NX:A1Z$%&G
M3BB)(5>M4`QQ`R>('2>!'TZ@1@UP`!%T!1)S!15T"21^&#N9+T"<-4.5.$VH
M0E*J1EFP3UJM4&&N5QUY#4:*.QM\"C./(2)]`S*+%$B-,&6U2C*#`#F)!X?$
M7E.<'6*C&'2S*U>7!86X0H*S&(2Q)V&!&9S*-8^R`)&U!Y*L*LGF4:6[`[;+
M%,_B+]_N9;S)`+_-"L?0-.;Q/F-D4(B)&\S,`']_`'%P`"TM`,W-`6UM`:FG
M`]#/!<S,!<W-"=;6#4Y-!=?8$,_/$N'A'>CH)FEH$:^O'^OK*[*S(W9V&-73
M+\?'+OKZ0KN[,D%!$OS\1JBG+___3>SL2+JY.O+R3,&_/NOJ4')R*,3$3WEY
M-:FI41H:#9&035E9,VMK0F9F4"@H(4)".%-323(R,3`P+S\_/D%!0+JV`+"L
M`]71(>;C/O'N9)&066!?2@\.`&9E96IJ:F1D9%Y>7E=75U%145!04$]/3TY.
M3DQ,3$E)24A(2$9&1D)"0CHZ.C@X.#0T-#`P,"TM+2HJ*B<G)R8F)B$A(1@8
M&`H*"@D)"?___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*)H:!L````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(UV-@P`*\
M/"W4!5059*4EI7@T+9,R@4*-$0F.!OSB,I*BW(8.\=EN0*%94^OK4LW5N#@U
MS*)J\]M[@$(S^EB*DD/M]/3MP],:VKLK@$),S6T39P97^8?4Y/1U=/5/`@HU
MM5:RSO:N#@J++>SLZ&.>#!1JZ9V6Y^OC;&3LFI);.J&,#2C449[HYV&MS<NA
M:YN>43!E.E"H)";`R4106%Y)1,C4)2ZK&"@4&6BEQ2XFIZBL(L&G8Q/MCLT[
M`%?Q,@9R=(O;`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]J;RYP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#<`
M,3`U,34T,S$P-C4`,#(Q-S$S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____RAL<^VMLSY.4R0$&P4)&Q[6YX=W@]?+U\N_R
MY>+E[>OMT<_1Q,+$NKBZ]O7VY^;GTM'2Z^OLT]G<O<7%W.'A.CL[[_'QY>?G
MY.;FUMC8[_#PXN/CV-G9R\S,TM33.4A`*7TP-H8Z`'L``WD#!8`%#7X-$(,0
M'8L=(9`A&VH;(7(A(G0C+YLO*'PH-:`U*GXJ+H4N,(<P-(XT0JI"1JY&0I]"
M1J-&3[)/4+-03JU.4*]01I!'/W<_6:!93HE.:*UH:*=H;K!N(RHC&1H9[_#O
MP<+!-I`U1X!&6I=9#FH`+C(K044^7%]9861>96AB&!L4(20=4U9/&1L40U()
M1$H(:&AE>2T%:E!+%@,`LRT?IA(#:C<R600`SFADOG%OR0``?P``R@4%R0D)
MS@T-B`H*SQ(2SQ@8S1@8BA,1SR`@TR<GHR$AVS`OL2HJR#`PX3@XW3@XU#8U
M\5!0YTQ,[5!0PD5%Z5E9T%)2^&1D\W=WX82#\965RZ*B]-G9^>3DN[BX_/S\
M^OKZ]_?W]/3TX^/CT='1R,C(:FIJ7EY>5U=74%!03T]/1D9&0D)"04%!.#@X
M-34U+R\O(2$A'Q\?'1T=&!@8$!`0#0T-"0D)!04%`P,#____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````.]6\_`````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```#`241!5`C78V#``N*B7,4[NR=.G\TP>\:427T]0*&DK-CP
MK@E39S',F3EM<G\O2"@MOR(^4M$E,"3(QS?8/\`/*)1;R5Q2G-`HZBXO)RDA
M(Z4`%"IOJ"W*2"ZHDY9U:VYJ;6L'"E77UV2G)#*QB`FW-`D("G4`A:I*<U)9
MV=A%.'@XN;AY^?B!0F5YZ3%A2LJV]H[.3EX.GG9`H<+,"&\U#2T#,RMK<Q,C
M?1V@4'2HBJJZIIZII8V%A[&AKC8V[P``Y-PQ?ZF3QPL`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VME+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`T-``Q,#4Q-30S,3`V-0`P,C$V-S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^3%A>Z
M+S#`-3;!/3ZT.CNZ24KG?7ZH75['+S;(.3_33U6]3E+(55K57V/I;W3W>'WQ
M=WR],3CG;7/XAHP#`@,_/C]X?GY]@8$Z.SNHVK9MJ'T`<!L#<AT)="(->R<?
M@S<;9RTB<C4PF4@J>STPA$0VC4I1K68AB#A$IEA*H%TPC$%1KV1?L&YEFF]O
ME7:>R:8A@#!GFG!QH'F&LHUXGW^!J8B@RJ<`;!`%;Q48>R<A;"PH=C,N?SHT
MB$$XDD5=JVF/N)4%<!)"F$V7EY:;@6"HCV^;9E#$E']13DVC```^``"C!06U
M"0DT`P.6$1&\&!B\(""W)B:@(B+,-36[,3&U,#!;&!C+.#B]-#2^.3CF1D;6
M0D+004#/0D+#/S_41D;J3T_G4%!@(2'?3D[B4%#,2$C@5U>\2DJ[2DI3(2'9
M6EGE7EZ[3T_D967K:FK49&2@3$S5:&CM=W?:;6W7<G)9+R_UA(3J@8'TB(C-
M='3IA(2D75WWF)@;&!A`/3U54E)H965S<7&6E96BHJ*4E)2,C(R*BHJ)B8EW
M=W=J:FIE965A86%>7EY04%!/3T]&1D9"0D([.SLU-34R,C(O+R\A(2$='1T9
M&1D8&!@1$1$%!07___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!0HM^`````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+U)1$%4"-=C8,`*
M9DIU-TV>-4>L?O;T*1/[02*SI_;T-3>F1#1XS9@V:0)(2+RWK;53LC8KDU.B
MJZ/%M1TH5%1=5U.<%Q#-&E)84E%560848BO(B`ST]0D.RPZ-24Z-CP(*Y>?&
M!?EY^S,GE,<FI26RA`.%1$5XN+F$F=)SV(4$!?CY>(%"%J8FQOHR'J4<GM*&
M3N9F!D`A!VLK2V<C'3=W/4<7>SM;&Z"0HKRLG(*FBI:NAK:ZFJJR$C;/``!S
MZ3$`8-]UB`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O:G`N<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C,U
M`#$P-3$U-#,Q,#8U`#`R,3<Q,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```&`4$Q410```/_____^_]74U<?&Q]35U<;'Q\'"PK*SL]35U.?G
MYN#@W]W=W-75U,W-S,`A`+\A`,$C`\,E!<0H!\DM#<PQ$-(X&-0\'=A!(=]*
M*^).+^Q</O;MZ[\>`\<I"L@H#,XQ%,,Q%LID4NE[9_2'<_:.?/>1@-B%=\$:
M`<`8`;\8`<0R'-L\)ML])N5*->A1.NY90L=M8/61@L=Z;LV`=<B!=^"@EOJV
MJ]6<D_>WKO&_N,RGHMN_N[\5`+\:!<XH%/);2O->3<F5C].ZM_+JZMC4U/CW
M]_[^_OW]_?S\_/O[^_KZ^OGY^?CX^/?W]_;V]O+R\O'Q\>[N[NSL[.OKZ^KJ
MZNGIZ>?GY^7EY>3DY.'AX=K:VMC8V-;6UM34U-+2TM#0T,_/S\[.SLW-S<S,
MS,K*RL?'Q\3$Q+^_O[R\O+N[N[FYN;*RLK"PL*>GIYV=G924E(N+BW]_?___
M_P```````````````````````````````````````````````%6D%:H````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````MDE$050(UV-@P`**
MBO+9&/VCXE-2$F(B`SS=04(%67[>X<ZFQM:Q44'>C#Y`H<*<,(]@"T4M37GU
M$%]&KR"@4%X<4Z"-MBR_L(*.E;M'`#=0B`5HD(F=@)"HA)Z1NW]$/%#(S9N+
MU=!64$1<RD#-)Y0Y%2CD$1R3Y*0A)R8I[6@9%,W'#A0*Y$E,25&RU]5W4'7A
M3DS/!@J!7>1JIJQB+A,1GY:9"Q3B3$Y)@K@HE#<U@R,/FW<`\)LGY^3+BB0`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O:V<N<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#0V`#$P-3$U-#,Q,#8U`#`R,3<P,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/____K60O')-<N<`<J/`]*7"O.].LR+
M`<N.!<^/!\V3#=F=%-R@&/:_/LJ)`,F%`.6D)LN!`=2-#>*=(>NJ+\E[`,V'
M$MV4'>BB*_NV2ORY3<IY`]&#"N6:)MB#%-%C$,I8!=%?)_6"1OB(3\4Z`,D^
M!\5!"=9/&/:`4<M'&/1V1NA?-<0L`^MA.O)U4<$G`=E$(<M!']1/+_5Q4,`A
M`+\A`'@4`'@5`,(C`[\C`\,E!<,F!<`E!<$H"<HM#80?"LPP$,0Q$L8V&(PF
M$=4\'=A!(<H]'Y4N&9\Q&\U$)Z<W(:HZ(^--+^).+Y\W(;`^)M)++[-`*.93
M-;9"*KY'+KM&+;A$+,%),*E`*L-+,==4.,M/-<E.-,5,,^Q</LM/-N]@0M!4
M.K-(,O%D1MQ;0-99/MM<0KY1._1I3>!@1M]@1N1D2>)B2/1K3_5L4.AG3.MI
M3O)M4>]K4/%M4>AK4.=I4,M=1NUP5^QQ5_!W7N!P6?1]9/-\9.]]9>Y]9?:"
M:L`?`+\>`,$A!<HJ#<(J#<PN$,<R&,DY(-]'*]=1.-=2..]=0MQ:0?-E2N1B
M2>)?2/5H3^AE3/-H4.MF3N]I4/5_:.YF4/___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````&S$D8L````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````OTE$050(UV-@P`(LS#TR&BJZVYN;K!W=@E/R
M04(NR?55O4;JJKHMKGZ)><5`(8?(ZMH)2MPL'+(:G?&9)3E`(?_R:67&XJP"
M7#QR>GU%!6E`H8R&RBXM3C%%!1%FY<F%Z;%`H;JJU`YU?AEA"5$FE>G9"1%`
MH9I<KU8#(39>23YI_?ZDJ'"@4&F@DU6CFKP@NY3FI+2XL`"@4+2SK9E-FZ&.
MMLF4]-C0(&^@D+N=J:6]JV_/Q*E9,1$A/I[8O`,`_%HP7'9OO.T`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K:"YP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S(`,3`U,34T,S$P-C4`,#(Q
M-C<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____PQ(6A`X0P!47Q!<;TAL?SBHMWS$TL"LMTC4WNS(TJBXP[41&]5)5Y$Y1
MXDY0\5=9Z%58X%U@]&EKQ7!QZ*FJ\[.TR`X3QC<[P&]QW(Z0SX:)ZJ&C\[.U
M'!2>+22L0#B[44K(6%#%6U/,$0J73$:W%1.</CVL#`N9!PAA#`R:#Q"=$1*=
M&1FE(R2F&1EU*"FR*BNI*2F..SO!,3&8-SBB0D.Y34[..CN;2DJ^65K56EO1
M9VC4;F[4``VH``AI`Q"J!1&L!1*I"16J#1FQ$!VU&"2Q'2F](2W"'RNT&2&&
M&R..(BR9+SO,-4#0*C.D,#JO.$/#-C^X0DW91E+<.D.N1E#,3UG?4%O@4%K:
M5V'::G/DU+RO^.3:S:R=Z]/)_^KAWL&VS)F,SIV1X;6KUJRC[L&X^M+*S()T
MV)6*^ZVB\K.JS4@XT59&S&9;T(!WSR\AZ$8XS$0YY&5:S2,8_VQCSA(-TBHC
MV"PGIR4AP3`LRC4PS3<QTCDTU3HVVCXZYT9`X$0^Y4="_E!*QS\[ZDM&[DY)
M[$U(\E%,_591]E-.\550U$M&_%Y8]EQ7^F)>_6AD_VQH^&IE_VYJS`,#VQ04
MP!04P1@8U"`@W3(O]3XZX3LX_E)0^5!0UDY.____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M.%'(-`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"S241!
M5!C3;<$Q3L1`#`70;WLR$42*5JR$1$\!)Z#E7%L@6@[`&3@--10H-4N!Q$91
M)AZ/S0'@/>`/PCV&(<>ZF$F2G--+PE?>YFAE86&1)`2"G/5D:WVFQV_N2/R'
M<-AW.KY=O]/-Q^TQQ_;`&/JVF\HD-NE\16I(&.UTWK1RS/2YJ^9(\%(F->_<
M93FJ!P@7I<9E[8-IBZ?#R5?"77%7)2(.X3'\-6&OE9/DG+B91PO\XQ=3%UHG
M:HU[M@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VMI+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`T-P`Q,#4Q-30S,3`V-0`P,C$W,#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____$.COZ9VB^BXS+H:*^EIK4QLRF
MH*J8F*B>I,2JKL)788J<H[]48I)@;Z.!C;M^A9^+D:BVO-)078=Q>YR4H,6`
MBJER>9"*DJV?J,2!B)ZIL<MD<)1C<)-S?9I]AI^'D*N<IL&>IKYP=H>1F*R,
MDJ0]4(!58XA47WN'E+9X@IR:IL6HLLQ^A9>[Q=V8G[!O?J!YAZ=J=8YS?IAF
M<(:2G[N3G;.-E*.SNLEU@9F&CZ&ZQ-E!685*88M[B:/`S-W7V<7,UB&[Q`7$
MRQ##RB??YCW$QI+>WX_2T@W=W!VRI@"[IP"PEP.U@@>YB`FN=0#MR'[!;Q2X
M70';@C7#?T>W1`&U.`._3Q_`/PVX,@7#*0##(@7M:%?&%07!&0K+)AC81CC<
M3T'<,2;Y;FK*:69]``!\``#'#@V)"@K0%!#'%!+8&1C.&!B0$1'<'AW@(2'/
M("":&1G5)R?F*ROI+R^D(2'9+R_*+2SM-37P.CJN*BK=.#C/-#3S/C[U0D*X
M,C+X1D;W1D;</S[C0T+A0D+Y2DK#.SOZ34WE1D;J24GH2$CZ3T_[4%#Z4%#N
M3$SQ3D[X45'W45'U4%#M4%#01D;Q5U?23D[U7U[E65GV8F'X9&3S967[:FKZ
M?7O^C(KXE)+___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````MQIR4`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"TM*+VE-B$Q/BHF.R"BH;
M>T%">0US9B1%^/OX1N:7UO=,!@IE5L^<W5V<$18<GU-2US&I"RA4-I5Y2GEV
M>(!?4')5V\3^9J`0T]QI-;E1WLXN3B%-?1-::X%""^:U%%:$NGIZN07.G]4Y
M/14H9,/-QL(I:N'NX:COP,[*80T4,C.TLU47X>,7$-/1,K*WT@,**2IH"\K+
MBO/*Z"J9"TE+:`*%5$TT>.0DE:6XA"T-U(Q-5;!Y!P#*KC*V^'VT[P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;&(N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-3$U-#,Q,#8U`#`R
M,3<P,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\P?(<TH*K`H*?)%1OQ66/Y:6]'"P_WO\-O-S]3.SXN&A\[)RO_^_]74
MU<?&Q]35U<'"POS__L[5T;_)P^SS[KC!NK+"M<O,RRME(^7MY)*GCW:3<'JA
M<8&B>55X3$1I."M<&3=A(?#Q[SU9&6)T/ZNLH.?GYN#@W\W-S+>VK:)U5+6%
M9=RYKM"LHL2XM\P``'\``,X#`]`%!<P%!<T)"<P+"]8-#=@0$-`0$,P0$-(8
M&.$='=@;&W\2$N0A(=0@'\X@()T9&=(C(J<;&^0L+-8I*>XO+[(C(_(U-;\J
M*LHP,)0D).$X.-4V-;PP,/I"0M0Y.<<W-OQ&1N%"0=(]/>I&1L8[._]/3^Y*
M2OY04/E04.5+2_975_I<7+M&1N=86/]H:/]J:OEH:/IT=/=Z>LR[N\R\O,_`
MP/SKZ]W.SL_"PKFMK>#2TO+DY/'DY-[7U__X^/CQ\>ODY-C2TK*MK?WW]_OU
M]>[HZ.SFYNGDY/CW]]W<W/[^_OW]_?S\_/O[^_KZ^OGY^?;V]O7U]?+R\O'Q
M\>[N[NSL[.KJZNCHZ.7EY>'AX=K:VMC8V-34U-+2TL_/S\[.SLW-S<S,S,K*
MRJ>GI____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"/X6JP````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$
M050(UV-@P`*,C)PCDN/\;$P-32P=O$*B@4+VO@EIJ8E!S$Q.[GY1\4DI0"&>
MLNKRJE)>=6WNPI+BHHI*H-#T"7SMM9/$%15$NEOKZMLT@4("C"V]$R5EE93E
M51KJ6GHF`H5JFC0$I\A(J:K)23,V=_%/`PK5=_9/GBHJH:,K)MS8T:<E!!0J
MR,Y,S^#@TM?+XLS/RS'(!0J%NEB;6]FYL;*QQ\6&!0>P`(4<S0R-+6P]`B-C
MPOU]O#U=L7D'`-WZ+_?$(O_D`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]L8RYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-C<S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____4T]1?'>,8EU\4U%=5E1IDI"G
M.35X.S=W0S]_0#QY3$B&8UZ?5U2)3TQZ8%R26UB(<FZH9V28;6J?:VB<:VB:
M8E^-;VR?8E^,='&F<W"C8V",?WNR?GNP?7FN>G>K?7JL@X"SCHN[:VF-D8Z]
ME)'`DY"_7%IV=W68,B]V(R%))")*/SQ^/3IZ0#UZ1D."2D>)+BQ52$6#1D-_
M2$6!2DB#-3-<4D^+3TR%5U2244Z'44^(5%&+03]K/CQE3DQ_6%6,2$9S7UV8
M6UB02DAU1D1N8V&<:6:B8V"87ER25%*"4$Y\5U6%5E2#7UV/7%J*85^1=7*M
M9V69=7*L:6>;>7:P9F256%:`85^+@7ZX?'FP=G2H?WVT@'VT=7.F@7ZU=7.E
M?WVR?GRQ@'ZS@H"Q@H"PB(:W@'ZKCHR\CHRYC8NXDY&_9&-V,S%S0D&#3DUW
M:VJC75R,;&N8?'NL5%1]D)"P24E3,#`Q>'F!-SE",C0S"`D(`P,`"0D''AX;
M&QL9&QH18V%8Y+8AZ+@FM9$@]<<ZZL)&_M10OJ%!X;`=G7D4J808[KHOOI@K
M^LA"RZI*&!4-248^GG80\KLU_,A&_LY/^<I0R*9.*B8=$@\*@W][2DI*$!`0
M!04%____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````NE);6`````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``G2T[25SE#PU5?+TC*T\
MPA*`0MKF$=GI(BZLY09<%NXAL<E`(:."#.5$6YGZ!G%#9R'9I!B@D%NQJJ(7
M#UMM72YO872*@AA0*%(]5=B4KV+>W#EI07'R$OY`H:QT"6M=C9J),ZO9H^2D
M`P6!0IGQCOJ65;-Z^B95JDF%!W@#A4H$3#A*&[M;VB8TE8D6^?$#A8+-./.9
M)C=/F=HQ8W:HKX\34,B&6XNEM:NW?]KT]DYF!U<[;-X!`)N@,;O36"%#````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMP+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,3`V-0`P
M,C$W,#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____'.CNN:WB[>8:QAH_)F:.Q=(&P=(')C)FW@X_6H:VF?8:\CYGBK[K-
MGZGEM+_=KKF;<GS'EJ7;L+ZS@Y.B?XO8K+O;L;_9L;^F=8>H=XEG252H>8JP
M@)&\C9[*G:W>M,-[7&@%$X$##%`)&(4*&(,5(XX=*HXF-)P<)FP@*W4Y1JP\
M2*,V09-)5[E+6+D]2)-,6:]58\!48;Y68[U;9KMM=\<%%X4(&88-'X@1(HXA
M,IPC-)4G,W\U1:LO.XD[2)S+SL[EY^;,F93KM[.+$@SK-RZY+2;/.S/@1C[^
M4TK_6$_R5$SQ6%#[7%3+;FG0=G#8@GW]L:S,"0'-#@7*#0C4%@W;&13>)!OD
M)R'.)1_/)2#:+2?N-2_=-"_R.S7$-"WU0CK*-3"R,"K--3'2.335.C;Z2$+X
M24':/CK@0C[\3$;E1T+J2T;N34G_54_^5E#R4$S]65'V4T[N4TSK3TO[55'Y
M55#I:63VBXC[EI/'IZ;RV]K1"0?+"0G8$!#A'1W<)R/H*B;K+"O/*2>G(R'!
M+RSU/CKX0C[^3DK_44W]55'32TC(2$C,3DO25%']963X967+6%;1;&SA@H#%
MD9#7H)_(FYK'FYK+GY[4J*?.HZ/\TM'Q\?'.SL[___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#U[8G9`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)
M1$%4"-=C8,`"5%2T#,W-=#74E%75-74,3(!",DIB(A+"HK)2TG+R"N**DD`A
MMY3*8->@Z)#0\$CW3!__4J!06^_<>=/GSPBKBVCNZ.HIR@8*,5773FV=7-/?
M$)604UB2FP84FE3E/*6^SVE"8UQ&045>>C)0:&+9[)FSILUI:NGL+L_/2FT'
M"OG%QP2X!,8V)WD7^WIY)GH`A=BX.)C963BY^00$^7E9>82`0K96%I;6-O;Z
MQJ9&CGH.=MK8O`,`;[LR5_.:^.P`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O:W(N<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#0U`#$P-3$U-#,Q,#8U`#`R,3<Q-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___^!/5J40,9Y1:I@A2EX#0&H-
M4]74U<?&QX15FDI$EB`=FYF7UPH*CQ@8FBLKIB\OL3X^L4=(N#L]K)"2V(:(
MOX>*NO'R^O;W_>GJ[\#&QLW2TO#U]=/7U_G\_-35U<'"PK*SLZ2EI=35U*^P
MK\7%O_O[^=?7U7-S<NGIZ.?GYN#@W\W-S).3DO_V\/SU].B6E,ZEI,T!`,H`
M`-`%!=$'!\P.#ML4%,U`/\Q(2-2/CL^JJOCW]\S+R_[^_OW]_?S\_/KZ^OGY
M^?;V]O3T]/+R\O'Q\?#P\.[N[NSL[.KJZN7EY>3DY.'AX=_?W][>WMW=W=K:
MVM34U-+2TM'1T=#0T,_/S\[.SLW-S<S,S,K*RLC(R+^_O[R\O+N[N[FYN;BX
MN+2TM+.SL[*RLK&QL;"PL*>GIZ6EI:2DI*"@H)V=G9N;FYF9F965E924E).3
MDY&1D8N+BXF)B86%A82$A(*"@H"`@']_?WQ\?'IZ>G=W=W)R<FUM;6MK:V-C
M8TI*2D-#0ST]/?___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'0%1\(````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````ODE$050(UV-@P`(J*K*5W5W\0J*BPL)3
MO!WM04+Y&?EY8<&141%AU?7AC,Y`H:+4G.)".2,K2^L`U?)B+4^@4'JP;ZZT
MC;FQF86A;%:,FPY0B)/1)5"&Q<24F97)0-[5)P0H9.NDK1#)S<;.(\BE[^S-
M$0T4<O"*+E,3Y^,7$.)53X[5500*N0?5-FF&BHD(BTIJ5-4E)0"%_$(*&AH3
M?:4D[#U*:_3BTH!"*I%VE9G^GDZ,SM[Q)2E*Z=B\`P"(ZBJN@=(8<P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L:RYP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#4`,3`U,34T,S$P-C4`
M,#(Q-S`W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____!D,`&%81*8(?%7,);K=D%%`*)7X8*VHA/(XO-'4J1)0X188[5:%(
M7*A0491&:;-><+5E=KMJ%U``%T\`S.$UQ-0F\O@^]/I"^_M-__]/YN9)^?E0
MS<D8Z>1&Z-DOU,(ZR*\4V;LKV+8=[LI7R9XA@&49\,=1P8T*PI4S_])JS(@`
MS(D!T(L%S8L)TI08W:,OVJ=![+9(EV$`F64%GFT2P(<=UYLKJGPGSYT^Z+!*
MO)!`^L%>S*-7Q)Y9UZ]HUHD-WJ$ZEW$RNH(NPW80X)U&MF,`MV4!MV<%NVD'
MNVX2Q'LGQH0[XYQ.YZ!1P7HTJ%<-Y(\^EE0;Z)50YI50S%@#LU`%SE\-U&P@
MX8`X\910S%8`SE@#MD\'_:1D]Z!EL44!Y(1*YH90KCT`NDH0Y(%-QF8XXGY1
MUF8ZW7A0MT08R%`FSEDOSEHOJ2L!UVI.I1D`IAT%L"<0K"\8LC<?S$PUV%U&
MJ!H%O#0AKQT-M$0VN"@=H30JI3<MT%9,H0D`G2\HJC@PJS<QUUE1D28AR3HU
MLC@UPTA"P49"U%10F@``H`,#G0,#F@,#H`H)HPH*G@T-J104N20ADB,CF"8F
MH"PLJ#`PKS0TTD1"T$)"O#\^TD9&Q49&R4E)V$]/UD]/S$Q,____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````)>QK]@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"^
M241!5!@99<^Q#@%!%`70-V^&-6(1LC:9B!")1D3##RC\DW_R']024=E$(PH$
M:X7=??.,VBU/[BTNP%\$!-P<1.G,M^QE11+[I8*+&#=O2=7<*U?]&'HQ*"BH
MG%^F'3W6B3'OS@00L"!RRY30YU.N8T:.E+3,EF)/L8J/FGY#^R-,-ZG<(HYJ
MKO4D8BND.;^%SUAB1SHGRXABWI\N.CIC-W10Q$R85NJ?6F5Y`PF6PR`_-'I*
M=Y^A"5:[OSL`7W;S4_Y*W=5P`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VUA+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,3<W-``Q,#4Q-30S,3`V-0`P,C$W,#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!4````-"`,```!Q3-52```#`%!,5$7E``+A``+:``'<``#G``#J``#&``#4
M%0#(!@#3!@#:``#E!0#0``#>`P#E``#I``#H``#C``#_"!C[#ACO$Q7G$`WD
M"0/D"`#F"@#A$P#2&P#;+0K?*PK7%0#C$`#D#P'=$@/@#0+N!0'U`P+S`P3M
M`P+F``#W``3L``+:!0#1#`#2$@#3%P#1&@#('P#!+P#`,P#8/0W''@#8&0#3
M$0#8)0?/$0#M"`+X!`/W!03R!`3L`@/_"0WZ!@;J#@+H(0KQ.AKQ2B#D2AC3
M1`K84A7+10CB3QGI21?Q01CM.13T1B'Q,A;M!@#Y`0'W`0+S`0#K``#^``#V
M``#P``#I#0#A(P#8-@7(0@/$0P'-/0"^)`#$)0#F0@W9-0+=,0/D)`#O&0#V
M!0#^`@'\`@/P``'Y`0#^!@#_!P#R!P#9#0#,(`#+/P'651'.0`#"+@"Z)@#=
M1PS3-@#=+@#?$`#S#0#Z`P#_`0'^`0/X``#R``#N``#U!0#[!0#Q`@#D`@#<
M$@#;,0#<3`_&20:_30:X1@#`0P'1.`#<)0#E#`#]``#X"@#V!@#W`0#T!`#N
M$0#E'0#4*`#)+@#20PG=51G<5!J_,`#7-P?9'P#L$@#U"`#\`P#_`@#_`@+[
M`0+T``#[`@#[``#O!P#A'@+;,PS5/A'7.0S<%P#E#P#J%`#P)0?N-Q7K-!+J
M'`3H!0#X`P#]``+Y``#^!0/]!`+R"@#B&P;;*0O4*PK:(0/M!P#Y#0+N(`OI
M(0KI$@#H`0#Y!`'Q``#T!`/X!@7Y!P7W"`7V#0CU$`KP#0;K!`#X!0'Z`0#X
M`P+W"0;X"@?X!@3W`@'[`P/Y`P3T`0/N``+F`@#J!0+R!`+X!`3^!@?Z`@/Y
M!07T!`7S`P+V`@+[`@;\`P?M`0/H``+7!P#<"`#C!@#E`@#K`0#P!`3N!`/J
M`@#G`P#E!0/C!`#@`0#B``#O`0'F``+@````````````````````````````
M``````````````````````````````````"6&F83````"7!(67,```!(````
M2`!&R6L^````>4E$050HD6-D8`2!__^9&1'@$Z,0(S:@CE74!JMH(*;0:S'&
M5*QJJU"YGU^I,+QG9.S"JG86*YK`"4O&DXP;&:"\'Q\DP?3.-Z\+&0_`%3V7
M`E-@59<9_38#J84)"0L9&8OZ&0OZ/'8S,CZ$JM2X"2*5LUYU^6YA!`!TL1^0
MU'+5^0```!UT15AT8V]M;65N=`!#<F5A=&5D('=I=&@@5&AE($=)35`YA#DE
M`````$E%3D2N0F""`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VUC+G!N9P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`T-``Q,#4Q-30S,3`V-0`P,C$V-S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____'/#W_9VC5L[3!
MPL*RL[/4U=3@X-_=W=S5U=3-S<S-`0#,``!_``#-`0',`0'.`P/,`P/0!07,
M!071!P?0"`C-"0G,"0G4"@K6#0W.#0W8$!"+"@K/$A+;%!38%!3>&!C2&!B4
M$1'A'1W2&QOD(2'4'Q_D)"2=&1GH)B;K*RO8)R?N+R^G(2'=+R_R-37R.#CU
M.CJR*BKA.#CX/C[Z0D+A.SO2-S>[,C+@/S[\1D;G04'^2DK\24G&.SO_34WE
M147N24GL2$C_3T_^4%#R3$S]45'[45'Y4%#^4U/V4%#Q4%#41D;V5U?V65GZ
M7E[I65G]9&3W967_:FK_;&S.I*3,HJ+-I*36K*SAN+C4KZ_NQ\?*JJKZU-3G
MQ,3_VMKYU=7JR,CZV=GXV=G^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;U]?7R
M\O+Q\?'N[N[L[.SKZ^OJZNKHZ.CEY>7DY.3AX>'>WM[;V]O:VMK8V-C6UM;4
MU-32TM+1T='0T-#/S\_.SL[-S<W,S,S*RLK'Q\?$Q,2_O[^\O+RYN;FPL+"G
MIZ?___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#>((?_`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+U)1$%4&--MP3%.`D$4!N!_
MWL[.FYD%Q,0U1J[$!6Q)#">0"DM[&PVQM**F]0(>P#/82`@!`>?M8\<#P/<!
M)PQZ&%S7\KW:)!=BK.('`77_2E?;7;+LV04+PD7_)F_7OXD\LX\V@7!YNY#E
MYJ#.!?;<_H'PY8<_>T&L`G>ZMFEA,<K:.>9<&"(RYOWNTX*JR)2ED?0Z]I'G
M((29(ZAJ(_=NQM,G$/Q#`=6C"!Q/2C(@/)=H5:5Y*_F%Z='@C'_:=4)(5F2=
M^0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:WDN
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U
M-#,Q,#8U`#`R,3<R-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___ZN2FYZ"CMG`RUI%3[6CK)-VAGU4;[FKM<6OOV)88GMB
M?K6KNLB\T%])=J":IG%CB&M?@)F-M#XP:(=\J)2+L'!K@#TQ:E-)?&-:BT(Y
M<%Q4B&]HEWISHC<O:U)*@E=/BEU5E$9`:U1.?%A2@'%IH5]9B')KHG5MI'9O
MI'UVJGQUIWITHS`I9S4N:C4N:3<P;#<P:SDR;CDR;3LT<#PU<3TV<3PU;D$Z
M=4,\>$0]>$,\=$=`>T=`>DM$?DA">$])@E!)@E--AE1-ADY(?3\Z9%M4CUA1
MBE1.@UQ6CF!9DF%:DDA#;51.?DQ'<EQ6B65?EU!+=TY)=&5?EFICFV]HHE=2
M@'!IH5Q7AFYHGF1>CWAQJFYHFW5OI6ACDGARIVQFEGMUJ7-MG7!KFGESI71N
MGGUWJGQVIXN&LXB#KXJ%KS8P;C4O;#0N:C<Q;4A"?F)=ED]+>65B@&9D>3LW
M<SLW<D=#>()_KHJ(IT)`>'-RBH.#F%]FEIFAH**OI[G-M*"ZD:[%FY:?ALBB
M?+F:D.J#;>>*=_.`:ZI92[YI6^F#<NZ(=Y%A6/:WK..JH+=#,\!+.(`Q)<]?
M3==P8;F%?7)(1<.(A+%Q<?___P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````,\#0O`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````OTE$050(UV-@P`)8N4NZ^+AX:_,-C*U=`K72@4+3>J?V]/5/GR&1
M:^FD%):>`12:U-G>T39YX@214GOWFLJD-*"0.!M+-R<33[F9G:):8YUF/%"(
M65ALBF`5.X>5<Z%H2VML)%`HJT*67UHO1U+!.R*[H5XJ'"B4F>Q9EB=O7N`5
M%2/0U"Q4!!32#;`QTC>U]0A-2)>K+E;Q!PI%.YCH`UT4$I>>FBCC%ZP,%'*U
MT#>T=/31T-9)45<-\G7#YAT`1^DOZDS*(R@`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]M9"YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,C,`,3`U,34T,S$P-C4`,#(Q-C<U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____U34V`!>4.$NS
M4&+%9'73`!!:`QJ6`QJ5#2.8'S2C(3*`05:V.DN@.TR>66N_9'?197;/:'O3
M9GC-`!N1!1^3"2*4"AMF$BN9$">($BJ+$BF)&#"<$2)N&C*2'S>@'#*+&2IW
M)SZE,$:J*CR*.$ZP,D24/5&A2%V\1EFK4&7"5VS'7G+,5&:U:GW3:7K%=(7,
M*#Z3=7]2=7LQFI\*J:X/QL@*L[4+O<`1R\T:RLPP?7X^S,P`SLX#S,P%S<T)
MPL(-TM(86ED+Y.0AU-0?N;H;T]0F[NXOX>$X^OI"__]/_OY0^?E0>7@GW-Q(
MU-)&Z^Q>K*@!IJ$!R\@UT\HU]NQ.[^91T,(%ULD-V\T8T,(FZM]&J)D4<&@4
MXM1"Z]U-TL9*E8U)95H#4D@)@6L`@VT'B'8GG(H[>FY!9DD`@%<AICP%L4<0
M_%A&_V!/^V%1X2L=ZSDK]4LZU4$UY4Y"\EI,V!X0Y"$AIQL;L"$A[B\OLB,C
MN28FO"@H\C4UORHJQ"TMP2PLQRXNRC`PS3(QTC0TSS,S^#X^^D)"VCHZX#\^
M_$9&Y4)"_DI*ZD9&_TU-[DE)_T]/_E!0\DQ,_5%1]DY.^U%1^5!0____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````8^0&)@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"L241!5!C3;<%=2D-!#`;0
M+W,G-W#U@C]8L45:T.WYZ`I<H$LH]4$1"OI06I.9)"Y`SP'^(`A6^X?-CWJL
MUB2S/!7@EFM&CR"R81H9!9?R>8A]O[Y1HEE847&X&M+.[@N=.XWLAH*![W+Z
M%I'9&I,V%'#LY"OM[34F8GT.%'A?9!NV[R<ETO82J%CJ,8.6CZ2GA7GOJ&CJ
M1O1QT?N4S=U1899<9SI2&3,\$O_X!9;`5`%+B2FO`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMZ
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q
M-30S,3`V-0`P,C$W,C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___\`ALP`A\P!B,P"B,L#B<X#BLX#B,P%B]`%BLP'B]$)
MBLT-D]8-C<X-C,T0E=@8F]X8E-(=G^$AH>0AHN0?E]4?E]0;>*<:<9TKJ>LG
MG-@B@[,A@+`OKNXOK^XFB+DHBKPUL?(ULO(KD,(JC;\QHMHMD<0NE,<PE\HR
MF<PXI^$XJ>$TG=(SF\\^N/@VG]4VH-1"O/I"O?HZI-I&O_Q!K^<_J=\_JM]"
MKN4ZF,=&LNI&L^I-P_])MNY)M^Y(M.Q/Q/],N_)1P_U.O/91P_M0P/E0P?E0
MN_%7P?9>QOI:N.=DR?UEQ?=JS?\)BL@5D,PKGM,UCKA$K^-$L.%.P_I0Q?Y:
MP?%KS/H8D<8,C+LOJ==5P^Q<P.=;O>%?Q.D?D+4IF+U,ON-AR.L=EK=4P>(4
MCJX8D*X9CZQIRN,@D:A*N=`WH+-`LL@67&,Z@HA4H*=VR]*`S]=5M+M<P<>!
MU-D:7F%%I:ESS<XG:6A9NK9UR,4[G94^H)@ZFH51KH]MNY%"=U1>JG:(S)6.
MR9:"MHJ=UZ5VMWIKEV.#NW>JW)M!:3&LVYJTXZ-NJ5-QJ%&PW95SITZ&MEM\
MJ42_X'6HQ5.4L3;,P`K8RQ#___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M!_A)`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+])1$%4&--MBTT.P4`80+_IS!BTZB?5Q([$SEZ"Q$F<PS'<P4(B
M$DOGD:91"R&$3N=7C35O^?(>P`\(EMW5(-)I)F2%T;`SV!$0?*+-]:($(;C6
M#!Y`P&<2\9-8Q-F>M7TBG.)!XY[-T8A$12^Y60D>H&J9SL8!1KC5#U&1N\JS
M]E)ZZ%Q_*F.*PCB%E16;>M?+\C@Y2J7=6*&E>J_O*!Y&5ZGLMQ*L5(QNPVGC
MQ;E6UBD2'"C!?OM$>6ZL-O"'#U%T54/TWY[?`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O;6<N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#(P`#$P-3$U-#,Q,#8U`#`R,38W-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/_____^_\?&Q]35
MU<;'Q]76U=35U"=]"C2$%$^>+T:&+$Z--3N-&$&/(4V<*TV-,5^K/E:8.E61
M.FRV36:J25V90F^U43=O&TN6)CUU(3]X(T-])D1^*$>"*EFB-4J%+5ZF.E&.
M,V:O0FFP1F&A0FRS2F:G1G&T4&RL3'*U46ZO3FJE3TR'+D^+,%64-5.0-%Z<
M/G*W3W*U4"YN`SYZ#4R('5Z8+U:&,%>&,UR,-F^G0FV?1GJO3WFL4.?GYMW=
MW+D;!<$F$,XW(=Q*-<-&-.A:1M)40NMC4.-@3KM&-\41`,$/`+\0`+0/`,`1
M`;\1`<`3`\D5!<46!<85!\89"L`8"<D=#=$A$-`B%-$G&,PG&-0L'=TQ(=TS
M)MXZ*^(^+^M$->I'.NQ,/NY10O951MM*/O172OI?4/-;3>962?-=3^E83/1=
M4?%=4/!?4?*(?\@G'\=*0L]<5-YR:L`*`\$5#=L_./_^_OKY^?CW]^SKZ]W<
MW-+1T?W]_?KZ^O?W]_;V]O'Q\>SL[.GIZ>'AX=C8V-34U-+2TL_/S\[.SLW-
MS<S,S,O+R[N[N[*RLJ>GIYV=G924E(N+BW]_?____P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````);5GX(````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````J4E$0508TVW!,4Y"41`%
MT#LS=]XG*I9N"8C+T<3":`@5"[!P+P8Z2BJW8$^(P;S\_V:>"]!S@#\$;XC'
MASI\U3H4)^U=@8QGX3B-Q6E6"A0]?E*[CTHS<S8HHKY2>F].&AD-`LLUZY'?
M(J(JF1_$D^\/V],D(E3)3!#DXEX^FZN:9>0$@KN5]B%N9LX^.V>[*&QI"/-B
M<VG].A**C2%?[AIO+^TJSYGXQR^7W$:5?P]R``````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L
M="YP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,#$`,3`U
M,34T,S$P-C4`,#(Q-S$P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````5````#0@#````<4S5
M4@```8!03%1%W=P`W]X`WMX`W=T`VMP`X>``V]H`R,8`^OD(^_H)__X._OT/
M__\6_?L2[.@!__\+__T$__L"__\)__H&\>@`V?\0V?\.V/\/V/\-VO\-W_\1
MW/\.X?\3W?\0SO<%=?\%=?\#=/\$=/\"<_\&=/\.</\/=?\4<O\39/(((N\`
M(>X`(.\`'^T`&>D`'>T`&^L`#]X`!OP`!_T`"/P`%/\`$?P`$_\`$OX`!_(`
M,^(+,^()->0-->0+-N,+..`%-MP`.M\%-]\&+=0`EY`,EY`+E8X*E8X)DXX,
MDX\2D8\4CHX4B8H2@X0-M2X`M"T`LRT`L2\`KS``K3``JBT`I2D`X0T!X`P`
MX`T`X0X`WPL`VPD`^@4,^08,^@4*]P,#^`0#^`0$]@,%\`$$Z0$`Z`$`X@``
MX`$`WP(`V@$`TP``````````````````````````````````````````````
M````````````````````````````````````````````_H&=V@````EP2%ES
M````2````$@`1LEK/@```#Y)1$%4*)%C88`"1B@%!BP<J*(0819V!E0`$65C
M_`^&C!":"2+*A5V4&-M@HM0V%RC,@.3>_R@F<*"*0DP``'IE)O7W!?A!````
M'71%6'1C;VUM96YT`$-R96%T960@=VET:"!4:&4@1TE-4#F$.24`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]L=2YP;F<`````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M,S4`,3`U,34T,S$P-C4`,#(Q-S(P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____T`4&\C4VIYV>U=35Q\;'R,G-QL?+]O?[
MY>;JV-G=R,G,O;[!^/G\Z>KMY^CKU=;9T]370FN_1G##16[`16Z_1W#!2W+`
M47G,4'G)5'K&4W?!5'C!8(C87X;467S&7(')3FRG2F:>9(?07X#%5W:S4W"J
M<9CF<);B8'^]7'JU9X?);Y'69(/`=);=:XO*@:;Q@*7O=IC:87NQ=933B*OS
MA*;K?9[?BJWTA:;K:H6\<H['B:KN@)S6D[/TCZSIE[7TD:[HS<_3Q\G-^?O^
M\O3WU-75Y^?FS```?P``S`$!S@,#S`8&S0D)U@T-S0X.S`X.V!$1U!86E!$1
MTAD9SAD9X1T=BQ(2U!\?Y"(BWB0DG1H:[B\OZS<WV#(RX3DY^D)"NS(RLC,R
M_$='YT%!^$E)QCL[_T]/_E%1^5!0_UA8[%)2[E-3]E=7^UQ<^EY>]V5E_VIJ
MZ6)B_6UMS;Z^T</#S+Z^V\W-S\+"Z-K:W=#0_O'Q]>CHX-34_?'Q\N;FU,K*
M__3T\>;F^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8
MUM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````&8MNS`````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"V241!5!C3;<$Q2@-1$`;@_Y^9MUGW81#/DRIE0,@)
M!"]@+8B6X@T\0\!>.QN+%+E)($AB<#?[WHP'T.\#_B`6N,RY[(^]ORW;U4UZ
M$:!K.O\9AL*KI-=&&*;Y@OVIJFBK;3*'X?6!G)R[4T1#Z2":\;E10ZU>2IBE
M6\'CT\>[PCUJO5>]2R"F(D?.8AVS^&QDY(&8'[[Z,,LY2;C'L#%L=R=G<I/"
M,G@I,'Q7FJ;N;&)CE2#QCU_LNDF9^_9S;P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQV+G!N9P``````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#4Q-30S,3`V-0`P,C$W,C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____!
MI:[@Q,V#$#A2"B.#$3F%$SN'%3V+&$"'&#^(&T%=$RV2($B6)DUE&S6;+%.?
M,%>B,UJ8-%>>-UNQ1VR`-$ZU2W"E1F>:06"Y476F2FJ\57FK3V^S57:Q5'2O
M4W.V6'F:2F:^77^V6GJF4W#(<I"ZG*;%J++2M;_#K+3KT-GNU-WGS]?QVN*"
M##:##SB$$#F#$#F'$SR(%3Z%%3V.'$6.'46*'421($B+($:3(DJ+(4>*(4:0
M)TR2*4Z/*T^A,5F4+E)N(SYU)D*E.5]\+$F$+TUV*D5_+DNJ/F6=.EV>.UZ'
M,U&N0VF--E6)-5.P16N6/%R1.EF3/%NE16>?0V2L26R<0F*E2&F+/5F[57FK
M3F^]5WN_67V00U^V5GB41F+`7("^6W[`78"_78"[6WW`7H&]77^Z6WVW6WRA
M4&V]8X/%:8JX8X&W8H#":HFU8X#$;(O%;HW#<8[)=9/+?)BYFJ6]GJG1N,'6
MO<;FS=:YI*SZ^?KY^/GX]_CW]O?N[>[IZ.GFY>;@W^#5U-74T]3-S,W,R\S^
M_O[+R\O)R<G___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````>0+T?
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+9)1$%4"-=C
M8,`"6%F=$TMS0NU,C3@L!?VBTT%"_%$E!3%.7$;LY@)>4BD90"$>L<)B>6%N
M%D-./E?Q.&4YH)!'MEJ6CQ6;@8FUD&ALJJ(T4*A&3[>22;V\0D.365NGNDH+
M*-10U]S6T=7>VM)8VUG?U-8-%"K+#W.PM;$7"4_++<I358H'"JEX6QCH&_,Z
M!LHD)T0&^;L#A23@+LJ4E0SV=0,*.7$9LIL!7924H1`1$N#I@LT[`%SR*EN4
MOJ'T`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O;F$N<&YG````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#4P`#$P-3$U-#,Q,#8U`#`R,38W,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___\P(#-$0%.$A)-`K,MXR./),4?]?9/ET
M>>Z`@_Z(CZEW@L*4GJY^BJJ1I9-ZD(V'H3`O@3LZ?F9EJP``7@``6P$!/`4%
M9`D)90T-9A(2:!@8<!\?=2<G>S@XB#@XA4%!CT%!BTA(F#L\?%=7H5Y>JEY>
MIUQ=GV1DJ6IJL`$$8UQ=EW!QK2LM6RLM375WH!@>=4E/F`X7;Q4?=!,6,4=.
MBG)YM'Q_G148,$5-BE);F$5/D&EQHH.'FB@K-XG1E&>[<3><056T7U:L7VG$
M<E:S71MG&R)R(R%O(2^4+R9W)BAY*#6?-BM^+"I[*BZ"+BV`+3"%,#"$,#2+
M-#.),S:--D*G0CJ2.D:G1D*<0DJJ2D*80DVP3D:@1DFD24:>1D^O3U"P4$RG
M3$ZJ3E&O45"L4%&L45"J4#*',3:--3^7/C^5/JC5IIS#EXNB>IZSC+;(I)^H
MCWV%:L_6OE=A*'F#3)6A,<;38L&BEMNCG-%=5.^EG_&KI=`^--Y12<Q.1_)J
M8>&.B,X*!=L=%\P?&-(N)^XZ-,]95-N4D<P``,T!`<P%!<P(!<T)"=0*"M8-
M#=@0$.0A(=0@'^@F)NLK*_4Z.O@^/OI"0OQ&1O]/3_Y04,Q86-EH:,.,B___
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````%_Q1D@````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````P4E$050(UV-@P`+$3?55M%3E921$):QY&V?.!@I9
MEI99J"G*2HH9&S2USYC%"12R+Z^P4Y:3TK;BJY\ZG:,V#RBD5URD(R1M(EC=
M,F4:=XEC#E!(6%=#P=",IV[B)/::7+>8$*"0B+J2C4!#\P06KD+7C(2P(*"0
MII'MO-;N?K8JA]CT^(A,/Z"0.7]';Q?SW`+GZ-3D[-!`;Z!09UM/%VNEBV]D
M4DI42("/)U!H<A_3G'PGK_#$M+BL8'\/=VS>`0#/?3('9Q0;W`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M;BYP;F<`````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C0`,3`U,34T,S$P-C4`,#(Q-S$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
M3X&H4(.I5(>M4H2I7(^UE;W;6HNN9YJ^:IBY@*O)4(RS5I&W8)K`;:7*>;'5
MA;O>C<+D@K+1C\/CB[S</9+!/)'`0I;%093"1YO)2I[,4)[)5JC57J_<8K/?
M<+[I>,7O-Y3$.I7&.I;&.I7$.Y7%.Y&_/)&_09S,09O+0IG'0)7#0I3`2Z33
M2Z325Z_=4J715Z[<4:/-9+KG9+GF:[OF9[3=<<3P>\SV>\CQ@,[W?LKR@LST
MQXDGVZ5(TY`XQY%&[+%ES80OY)]0[:A>\*]D\K)HO6``QW0@V8Q`O5T#P&$-
MOV<2O5<%PV@8BD<1IF,J\ZEJL6HRZ9A7W9)9O6P[R%@?UFXXP3P#OS$`P#@)
MO"P(O"P)OS$-O3,0>10`>14`QC05QS<:Q#T?ER\9GC$;IS<AY$TOJ3HCL#XF
MLT`HYE,UM4(JOD<NNT8MN$0LPTLQP$DPR$XTQ4PSRT\V[V!"T%0Z\F1&UED^
M]&9*VUQ"P%$[]&E-WV!&Y&1)]&M/]&Q0Z&=,ZVE.\FU1\6U1[FM0VC\AST(G
MV4\UPD<PRDPT[EH^STXVUU<^Y%U#QE0^Y6))]6M0\&E0[6E0UV%*WV9/\'!8
MY&M5['%:[7ED]81O>!``A!H*]79D\'=EGR\AZF!0____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````<$C\
MZP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"M241!5!C3
M;<$[;L)0$`70.Y\'Q$(@BL@42"EB>GH60DW/'M@5K(>"(N+G(*3$SYX9%@#G
M`"\(ZTCEUV9QM.)G51V''UO&LKY^AW:3D=#\4`P2&$0<7?RW-R6J^JF!0NJ>
M_'F^<Z+>J;`,Q6["^Z'9YTTH37^;#,594O2-KR(DT>8`0_-#G%+)0NQ-YU"X
M%AZ4+DP<9MY"T8W#F'FJ1&;9#(I2(U3T-`MO(SSPQA,HZ$TGK=$_T@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+VYC+G!N9P``````````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C`R,P`Q,#4Q-30S,3`V-0`P,C$V-S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____2-3;.%!G;)BN>(27H.C_6/T/R2D_G
M3%'R458F#7\U'8E',)E:0JAH4;-B3:AK5;(<#%<_,W@J'&\;&I8?'GX``(X&
M!H<$!%4$!%0+"XL,#(D6%I41$FL;&W(G)Z(X.*XZ.K(Z.YQ,3+\[.XE65L1>
M7L%N;LX!!%8$"8P.$Y0>(Z$Q-;!$2+Y15<-05<8`<P`#<`,)>`D->`T8@1@=
MAAT?AQ\;:ALA=2$B=",H?R@OE"\J?BHNB"XXG#@TD30PAS!"J4)&JT9"HD)&
MHT90ME!/LT].L4Y0L%`VD#4B@@5@LS5MEDIUG5%QEE!%9R9-<"U4>#-AA3YO
ME4PA,1!?AR]YICH@,05ME0"'IR&MOA+8WR;,T`72U@WCYT#R]E?-S0#&Q@!(
M2`#,S`/(R`.WMP,]/0$W-P&YN0I45`7.S@V_P`UF9@G>WAC3TR"DI!O8V"=T
M=!A+2Q+?WCB%A2?HZ%![>R_]_62UM4C__FB@H%Z^OG2^OGMU=5^DI)UA7@#;
MUA1'1`?5M!#=OQWWTU[]U6KHJBO(A`KHETC,@4GB)R'K-2_O-36[+"S(,##1
M-#3',C'O/C[W0D+3.SKZ1D;C0D+&.SOG1D;X3DW\3T_H2DG\4%#T3D[V4%#T
M4E'W9&3V9F7___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#1XB9G`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```*Q)1$%4&%=MB[L.`4$40.?>>>RN2A")1.VC_(%$
MH9#X#"4?H/<[LGJBLEZSLWOGX8J24YZ<(\0/($:@E4[M,_,2)2*62G1?9AJC
MW%(?&$Q<]6#FP5N]J[^J0O%8189N2^>:EES-U>9:#J)S-,DQSZ!I%R@Z*1$U
MDB>CD>9)*)%4CTA#(8W1WJ\#JWVFBS&FX\6"20RKR@[C(>A[+='Z&"(K%T]G
M1+[0F_"I_O`&IN]4_=2N3N8`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;'DN<&YG````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C`T`#$P-3$U-#,Q,#8U`#`R,3<R
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```&`4$Q410```/__
M_P!P&@!P&P!&$`%Q&P%Q'`-R'0-Q'05T'P5S'P=V(0ET(@IY)`IX)`U[)PUW
M)@I1&Q!^*A)Z*Q2!+AB%,AA^,!%9(AV(-B&,.A^#-QEB*B:0/QMG+2>(/BN4
M1")R-2%O,R^82"%J,R9W.2AY.S"/1C6=336<33".1BM^/RI[/2Z"0BV`0"IU
M.SJA4CJ@4C"%1#"$1#2+23.)1SZD5CB53C:-2D*G6CJ23C)^1$:J7D&<5C^7
M4T*<5TJM83J'33N'34VO9$:@6TVN9$FD7DBB74^P94^P9D^O9E"P9TRG8E&P
M9TZJ9%&O9U"M9E"L95"L9E"I95"H94:465>N:UZT<EZS<EFH:V2X>&6U>&BZ
M>V:U>&J[?3*'162X=____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$>_[2P````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````G4E$050(UV-@P`)86*0=8D/-Q+B8.(4D-:R]0$+B
M5E%A-E(\S.S\$DH6'OY`(4&]B'@W.0%6-CY1>5,7/U>@D')(=+"F,`<KMXB,
MOKV?MRU0R!%ND+JUEZ^=,5`H)AQND'N`L[DA4"@2;!`OT"`G/U?+."V@4)":
M,`<ST"`#>Q]O6Q-=%:`0PD5`@W14%8%",(,\`YW-C;059+%Y!P#5\QJ8R<Y+
MC`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6\N<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,Q,#8U
M`#`R,3<Q-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___Q^!0RN2436)5$R6:`!P)P-R*@-Q*0-P*P5T+`5S+`5Q+`ET+@ES
M+PU[,PUZ-`I1(Q!^-P]W,Q)Z-Q1Y.!A^/!%9*AA]/1V(0B&,1Q^#0AMG-B>(
M22)R/B%O/"^85"%J.R9W0BAY1#"/436<62M^2"I[1BZ"2RV`2BIU1#"%3C"$
M3C2+4C.)43B56#B563B463:-5$*G9C)^34:J:4&;84*<84JM;3J'5CN'5D:@
M94VN;TFD:4BB:$^P<4BA:%"P<DRG;$ZJ;E&O<E"M<%"I;U"H;T:48E>N=5ZT
M?%ZS?&2X@66U@6BZA6N\AVJ[A@!&&`5T*@9S*PUU,!V(0!^"0"*&0QEB,C*8
M5#*'3SZD83J26$&<8#^773^66T.<83^/65BO=5*B;5RT>5NM=EFH=%RF=&:U
M@6JWA'*_C&FO@&FH?H[*HD:>8DF@9%"J;'&YB'S"DH_-HCB=53203X"^D2:)
M0*'5KQI],H.MC1!W)A5\+!9[+#2.1Z;0KQ9Y*D>F6HZTE9FXGC660ZO&K[[:
MPM#JTR2!+BR'-:2]IAAY'1]^(;S2O#F3-^CWYVBY7S&%&<S5Q]3=SLW4Q_/X
M[?___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#`85:L````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MOTE$050(UV-@P`("`R,L`SP-)'C8N(2D5$T=04+B)KY>9DRU/9P"D@K&]JY`
M(4&M-!^'NH[NB35]S-$V+K9`(44//_?2RFH6UO*61@L7ISB@D%6`IV%G`U_7
MI.22"8[.YKI`H0SOV##1JJ;6R?7M60761MI`(1\[V1#AYBF];5/[B_)CHM2`
M0FXJ(AS!B3G9A16YJ?%ZFDI`(7TQ;K:@\/2RXN+,!%T-97F@D#0O&SM_:&2*
M?U*>D8ZZG`PV[P``?SLND73Z$&,`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]M<"YP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P-#<`,3`U,34T,S$P-C4`,#(Q-S$W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____OK:]M*NTU]#8QL/*:%N%
M?WB5:6&,;6>'C8BCN;3.03M^4TZ'96&)*"-X(R!61T*45%"2;6BU5E*-<FZW
MAX/!FYB_%Q)W(A]V*".#&!9+*29Z+"E[+RM\,R^#-3*&-C."/3J./#B&*BA?
M0CZ*/3I_-C-N,C!G2$60.CAQ5%&A4U"=5E.A0D!]7%BJ6%6D4$V51T2#1D.!
M1$*`2$6$3$F)1$%Z2DB&4D^23DN+4D^14$V-5%&37ENC9F.O7URC:66Q8V"G
M85ZB55*,75J9;VNU;&FQ9V2I<6VW<&VS<6ZT7UV3?7J^?'FZ='*N>':S>7>S
M@'V[A8+!@7Z[;6N2BHBYC8N[='*7F);`IJ3)(R%Y)B1])B1Y+2M]/#J0.SIU
M/3QX34N+5U6<6%:<4$^/5U687%J@3$N$86"H75R>:&:K:VFO<6^X<6^U;FRO
M<7"U86";<W&U962<@'Z^@X'!*RQ\,C)^3DZ%9F:G<7&Q>'B[;V^H;V^0M;6]
MRLK2P\/)O;W";G"H=WFP;6ZA8F.%046)6EV&24USN+G"J*NYJ:NRD9FK>XB7
M<XZIAIRB4&ENP<?(EZ^DOMN_E:]]@)%JRMFUJ:.*NK"0I95NNJ6`RK>4IYN.
M\.CDN*NJN;FY____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````E0QD7@````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```#`241!5`C78V#``J2E-5R"O6OX.M1B
M%`0-'$5!0BH90=5<LV=.G<49KVWOZ044$C#W]^V9PM;:SC&C1=\M+QLHI%58
M6C!]@D1MJ%3?).'<G"R@D(A8D>L<GHJZSN*F:8'NSM9`H1`_A[9^H[B&>MVJ
MR<U.ME9`H1(/S;)>]O+YC9G<$RO3;$R!0OF&BI*\\R*ZN\3GAB>G6N@!A5*4
M96.C?9B96%DBTRW-3!*`0JIR_#+R2CIA40%V0DG&B>K8O`,`U!`QYA6L[+,`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYF+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,3`V
M-0`P,C$W,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___^7S9BHV:D`=0``20`!=@$#=P,#=@,%>`4%=P4)>@D-?PT->PT*
M5`H0?A`2?A(4A103@!,8AA@8A!@171$=BAT?B!\?AR`ABR$991D;:QLFD"8G
MC"<KERLB=B,A<R$A;B$OF"\F>R8H?2@UH34K@BPJ?RHNARXMA"TPB3`J>"HZ
MHSHSC3,XFC@XF3@TCS0PA#`VD38TBC0^HSY"K$(ZECHR@3)&KT9"H$(ZBSL^
MDCX[BSM&I$9-LTU*K$I(ITA)J$E/M$]0M5!,K$Q.KTY)HTE1M%%1LU%0L5!0
MKU!&F$90K5!0K%!;N5M9M5E7LE=>MUY9JUEDO&1DNV1EN65HOFAJOVIWNW=U
MKG6"P()_MW^'O8>+PHN)OHF=U)VBUJ*4PY2(L8BHVJBDT:24M926MI:>OIZ8
MMYB:N9JLR*R^V;[.Z,ZJOJK5[=73ZM/6[=;`S\#$S,3N]^[S^?/Q]/'+S<O3
MU-,@A!\PDR\RBS%!H$`_FSX_ECY,G$MFN66&LX6!KG^#L(&+LXF?O)ZWQ+:_
MR[[4UM/Z^OKY^?GV]O;R\O+N[N[JZNKHZ.CGY^?AX>'>WM[8V-C6UM;4U-30
MT-#/S\_.SL[-S<W,S,S___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#[#^\8`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+])1$%4"-=C8,`"6%FEK/*Z)K2USIP:*:EJX0P2$C4/S>F?TM0X?7*TDJF3
M)U"(3SLH)'M2685U^<18$SL/1Z"0HG>8;]:T7#:APCXF>W>7&J"037B`?LO,
M)$[^N.X$+U=+`Z!0?6"U1-K,9AZQJ(YD7ULC+:!0L(,L;^J,.F$Y?T9F-[,J
M-:"03Z4`1T:1H(R.7W%*K:ZF,E!(3X2+);,])B*^I#316$-%`2@DSLW"GCZA
M)[^@L[?!4%U>&IMW`$@>,",N0S$)`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O;7,N<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U`#`R,3<Q-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___[)K<*Z5IU](6YU_F-S%
MV;BGMY)RELZXT8%7B69;:K>KPGYFE\N^X;.KR6Q>I$`QDEA*GY:+TYN2T71O
MD3XRE%!%HD(YIE))K3\YA%Q3O49`BU=0HUA1I%Q5J65>MF9?MG-KQ'QUSC`I
MES@PH38NF34NF#4NES4OFC8OF3<PF3<PF#HRGCDRFSDRF3LTG3TVGSPUFD0\
MIT$ZHD`ZH#\XFD0\HT0]I$=`J$,\GDE#JTY&L4A"HD])KU1,M%1-LE!*JTY(
MIEA1ME1.JEQ6N4A#CF%:O4Q'E&5>PU--GU%,GE!*F55/HDY)EEQ6KVQES65?
MP65?OFICQ%Y9K7)KRW9PSW5OS7ART7)MQW!JP&YHNWUVTG-MPG]XU'UVT7ES
MS'UWT7UWSWITR%U9F8F#THN&UC0PG#@SG3LVGSPWGFIFO5U9I8)_THB&M6QK
M@$(_HDE'HH6$SV]NCFEIJW9VOH.#REUCNF-ILGA_PX*)S(V4S[7,WY:KN9FU
MP\KI]KS7X<#;XK;4V:?#N:>YJX^=DL/:QXZF>9*F8HV87Y"88)66BK*W8^N'
M<^B.>Y)=4=%F5/2";<)N7_")=^N&=;F!=_>RI>.DF*M=4<%00H$U+=9T9[E)
M/G1%0L-_?O___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````.&,;&X````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)8N(LG\7'REV>H
MZ1K;>X;%`87F]D^=/&WZ/"8Q35/'H,AX9:#0K!E]$WLGS)PCJ%I15UM3I`04
M$F5GF\+#S%N8*5'9U-I8I@@48A46F2U0P,%E;E-5W])0*@\42LV-%C)321>7
ME*YN:V\ND04*I<6Z9*EK&5J[!N3U='2F>`.%DOVM=-0-+)V#(Y*ZN_*]/(!"
M"K;Z&GH6#H'AB0G9.;Y^,D`A)R,-;1,[]]`8Y:@0.1\W*6S>`0"[WC&#6,D>
MLP````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M="YP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U-S4`,3`U,34T,S$P
M-C4`,#(Q-S,P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%:P``<P``<UI:<W-S<WM[>P``>V-C>WM[C(R4E)24E)2<I9R<I:6MI:VM
MK8R,K:VMM;V]O;V]O;W&QL;&QL[.SGM[SH2$UI24UM;>WH2,WM;6WM[>WN_O
MYX2$YXR,YYR<Y\[.Y];6Y][>Y^?GY^_OY^_WY_?WY___[Y24[YRE]X2$]XR4
M]Y24]YR<]Z6M_P``_X2,_XR4_Y24_YR<_Z6M_ZVM_[6U_[V]_\[._];6_][>
M_^?G_^_O__?W____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````,,"OK@````EP2%ES````2````$@`1LEK/@```"-)1$%4&%=CL(,#
M?2A@L+,3DT47DN,6$$97)2J'K@H.!I40``#K+7/9U%''`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N
M;"YP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S$`,3`U
M,34T,S$P-C4`,#(Q-S`U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____BPX/U=35Q\;'R,G-QL?+]O?[Y>;JV-G=R,G,O;[!
M^/G\Z>KMY^CKU=;9T]37(428`#.J`C>K!3BN!3>K"SZM#D.U$$.V&$>S(5+#
M(5&W'$"0(U"P)5&P*56U)$J;,6//*$VC-632*U*F+E6M,ENU-F&_-%RX,EJQ
M.&/$1'3<1G3>0FO)1W+/4'[B4'SA3GC947W=/U^D37/$1VBO68+:3G"Y6GW)
M;I3E!#JL'E+`-V&Z1G',:)#D:(W;:X_:S<_3Q\G-^?O^\O3WU-75Y^?FX,C'
MS```?P``S@,#T`4%S`4%S`@(S0D)U@T-V!`0U!$1SA04TA@8E!$1X1T=WA\?
MY"$AU!\?G1D9[B\OV"TMZS(R\C4UX3@XLB\N^D)"NS(R^$1$_$9&YT%!QCL[
M_T]/_E!0^5!0_U-3[D]/[$Y.^U=7]E=7^EY>Z5Y>]V5E_VIJ_6EIS:ZNS*ZN
MT;.SV[V]S[.SZ,O+W<+"IY.3]=G9_N/C_>/C\MG9\=G9U+^__^CH^/?W_O[^
M_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.
MS<W-S,S,RLK*____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````)XM]D@````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"R241!5!C3;<&]<0(Q$`;0;W].$G,W0$0#)"Z"P"G=$)+8D8<>
MZ`0B)P0X<",D#!YN\)VT6A=@W@/^(:PQ[[IRZX<B30Q!]PRTJ;7'F`MK(R($
MQK&=LCU&#S'&-`D,Q390C9TY$PL1?8&@M@NB,*NEN&JS8;Q_?!X$M;K9F\BV
M`:%C[FGE9U_Y*7"FGO!Z__EU3HLAY3!XK=^*R[48:RZ3D>[9[`K&S>J++&,2
MMAEY;?'$'Y==2@&P9"!A`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VUX+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`T,@`Q,#4Q-30S,3`V-0`P,C$W,C(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____5-3;\EI?[
MFYW@ZNKFZ.C&UL[#RL82>C$GB$0`<R$`1Q0#<"$%<R4)=R@+="D-=2H-=2L*
M4A\/>"T7@388?C81628:?C<?ASP?@CL98RXC@S\A:S8PCTLJ=3\XEE(XDU(X
MDE(R?DA!G%L[B%%(HF)0JFE&E%U0IVA0I6E7KG!>LW=9J'!DN7QFMWUHNH!E
MM'MJNX)POX<`;AX`2!,#<R$ZAT]DMGIFMWSN]O!RA';!RL.ZQ;S1V].)FXR4
MH9;7WMCK\NRTO;7(T,G&SL;W^/=/9DMI>V1^A7M@9UR,E7YB83Z_N[!D4!]J
M63%A64=64$1]=6S8U=)=,!&NIJ'#K*:RJ:B,>WKD(2&G&QNP(2'N+R^R(R.Y
M)B:\*"CR-36_*BK$+2W!+"S'+B[*,##-,C'2-#3/,S/X/C[Z0D+:.CK@/S[\
M1D;E0D+^2DKJ1D;_34WN24G_3T_^4%#R3$S]45'V3D[[45'Y4%#89F;A<'#K
M?'SUBHK5>GKEAX?RDI+_H*#9V-C^_O[]_?W\_/SZ^OKY^?GV]O;R\O+N[N[J
MZNKDY.3AX>'>WM[6UM;4U-32TM+0T-#.SL[-S<W,S,S___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#<8K7C`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+M)1$%4&--MP;\N1$$4
M!^#?S)D_U\CF)K*BV5HM044I%%Y)ME3I>`?/8<MMMB%;TA"%2B*Y9^:<,QZ`
M[P/^<#C=C@L9KT.`?K[F6;X+V.X.U3H13!V5%.&1AY(;T=-*NYOER"#,2_KA
M%ZC_N#^79+SV&$J;ZIE9XWX;'3=XS"NSB$AEOXS\8"#L\7NW?1[3]\'C23VR
M30!/7:A?/6NZN/Q2$03P%`_?=LJQ6&A-5>'!K-ZQZ4V@;FH=__@%&+A<LY1#
M3$$`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M;7DN<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P
M-3$U-#,Q,#8U`#`R,3<R-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/____67F<1%2<-%2<I-4,Y15M9;7L-E:<)G:\1,4N1^
M@\)S>,U?:,=Z@->IKF1:F30GBQD,?CDOBAH1A&UFOG5MP!0+?UE=S3(YH&AQ
MW1(>E!,AE!4AE1LGE2LVG@48ECM)I@`6G0,/71@IE"$SI3A)ME=IRT52FVY]
MU0DDE"0ZF$=:JV%QN'2#Q3],;(Z:LR,N0TI457^+BSY'0YNIF69O8*Z[I&MV
M6;2\CTA.*%UC.9ZE;:FN4[&U0NSL2,YN:\QP;=9W=,QQ;M%V<\QV<^&$@=N!
M?L]Z=\=X=NB0C=N*B.22C]V/C.Z=F_ZKJ?FII_VNK/ROK?&IIOZUL\JCHN1C
M8<Q?7LYB8,QB8/)U<]!F9,UD8\QE8^IT<]9K:=)I:-AP;OR$@M1P;L%E9.5Y
M>,UM;.%X=_B%A-)Q<-1T<O:&A=IX=OZ+BJ=<6^1^?=Y\>_^1D.Z(A^Z)A[)F
M9;!E9/N3D=!Z>+]O;O*/C;QO;NN,BLIX=]6`?MB#@?J8E^&)B-*`?^Z4DOR=
MG/B<FNJ2D>60CO^AH+EU=/F>G?ZCHO:>G<1^??JCH?6>G?^GI<^'ANB8F/^K
MJ?NGIO*AH."5E/*EI/6IJ.">G?ZUM/VWMO*NKNZ^O=6LK/K+R^K`O__2T?G.
MS?___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````!Y,J04````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````OTE$0508TVW!P2Y#41`&X'_F3(][>RD;Z8*-="VE"XG8V!"Q
ML_*2'J`KB5V%]!&ZK0JB:-W.G'NF#\#W`7\0>MUZ2=E7[Z>#C?'5/=\Q.C2-
M.YONC3V-3E;G"8)@SK$U;[RW53%3!L,B-UD3Q9>#_=VJN(;@J]C[_7"FNGHL
MJJP&P6)B@8)Y><E,.0\A>"M9U9EOG\M64MV&X$;-<@CAZ($OW%*"X'#VDSAV
MVHLS^K31L4'P^FTD4:*XU=Y7Q3_6'DE294U7AF4`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N;RYP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`U,34T,S$P-C4`,#(Q-S$V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T;&SXL+$
M\-'3NZ*DQJRNT[BZ]]G<Y\O.Y<G,]-?:]MS?`21BBY:JIK#"!RMI$#1Q$C1N
M'4!\)TA^05^25W2DE:"R!2]IB)BNAY6HEJ6ZH*_#`#!I"C=O#CMQ-EF#/F")
MK+O.&4E^*E6%/V:12G.?68.P9HVW;I*Y8'N9@IRXAIVV)UF-.FJ=.%^(3'NL
M3WBC686S7'Z?8H>I<96V9(2A:(>E;XZK@J7$=9*LD;+1A:.^=(VEE[?5DK'.
MF++)I\+;JL+9L\K?E[;0S8-]\<;"SKR[S3PXS%A5SEM7S&!;]9.0QGAU_J"=
MU(J(]Z6BS```?P``S0$!S@,#T`4%S`4%S0D)U`H*U@T-V!`0BPH*SQ(2WA@8
MTA@8E!$1X1T=Y"$AU"`?G1D9IQL;ZRLKL"$A[B\OLB,CO"@H\C4UORHJQRXN
MN2PK]3HZRC`PLBHJW38US#4RX3@XU38UTC0T^#X^Q#,R^D)"NS(RSSDY_$9&
MY4)"ZD9&_TU-X$5$[DE)_T]/_E!0_E%0]DY.^U%1^5!0TDA%\E-2_5A7\5=6
MZ5E9Z&EF\G!NT6-A^GUZVW)PZ(*`IV!?X(N)\IN9_:.A_:6C_ZJIWL;&____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````*_+-J0````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``H*"
MDGV=Q?C;PP)#HQ*SJIM`0O&5`4ZBXAZ!(9$)Z16-;4"AZ(+N:0XB?$7!$;&I
M976M#4"A2?[3W72$I%S[)DST\9LZ93)0R-;115M10L'8Q-32VL[>Q@HHI*FA
MIB(O*Z>LJV=@I&ZHJ@\4XN%B<M?BE9S!S,+!S<G.Q@H4ZBJ,\383D.[):^[L
MJ*\JSP4*%<>%>9H+RO16-[74E.9DI@&%DL(#O2R$E?H;VVI+\K,S4K!Y!P#M
M"3$,=UP@;P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VUZ+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q
M,#4Q-30S,3`V-0`P,C$W,C,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___\V-39N<W)G:VAM<&V8FYAZN7-ZM70N92<C;@\E
M<!$G<!,J<A<L=!@O>1L^ABL^@2Q'C#10ECU-C#Q9G$=5DT1AI4]=FDQIJE=M
MKEMLJUQRL6%HGUIRK6)XLFF/Q8`M<Q@W?B,]?RI-BSM5D$19E4ABGE%6B$AV
MKV:#O'.'O'B'NGB1Q8)>85T=10MH:F=Y>WB0DH^(BH>HJJ>EIZ2@HI^RO:A<
M=CZMN)EF9V.YNXFYNP"_PR^YN@"GIW)Z>G9T='"$A("4E)!Q<6Z5E9*$A(&@
MH)V?GYR\M@6EH2.QK"J\MS#&P37,R3K8TT7OZ4_EX%:WLTK"OE+R[6C-R5K=
MV6;[]W;O['7Z]WR\M`/$O`W&OA#/R!W2RB&;EANCG2'=UB^NJ"C@V#6YLR[$
MO33JXT+KY$;6ST+;U4;NYU#FWT[JXU"_NGZ\J@F\F06_APJ4=4;9E#VZB$C<
MF4_(>BWPH6C2DF9=)`2O3A?+71_5G'Z[9T''2!A[+A3;=EJ^AG?L<%"&'PK&
M,!*R02K)-!A^$0#40R_83#CE9%6L6$W#%PF0*R%S!P!N"P504%!/3T].3DY&
M1D9"0D(U-34T-#0P,#`O+R\A(2$='1T0$!`-#0T%!04#`P/___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!^-N\,`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```,%)1$%4"-=C8,`"*O0Y-;0UU905>?B4A$0E98!";746[/(2
M@KQ<W/P"PN)2TD"AII9Z>PY95141,74Y+05=':!03W%99P,SBP&KH3&;J8F9
M$5"HT#JWJ+6/8<ZL&5,F]4^</!4H5&UN6=/=.W?VS.F3)_1/8IH&%"HO*:WL
MTK-R='+V<'=U<W`!"C6V-Q?8^OD'AH1'1H2%!@<!A3IJ\^T\8^*2T[.R,U)3
MDA*`0E5Y-E'1L8EI`3F9OC[>7O'8O`,`F^\R)U\Z%OH`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;G`N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,S4W`#$P-3$U-#,Q,#8U`#`R,3<R,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```&`4$Q410```/___\<*"^HZ
M/,DS-,<Z.^E.4M$F,?_K[+(P.]U>:*0!$Z``$[(N0%\`$:T8,G0",:@]:+%.
M>IE#:I5(=54;0)Y6BUT+2FLU8(E">VXJ9TX)25H559I>E]O:VT8$24<.5$(/
M6(5CJ&50>TDK<7UAI5]"D(I]O3,O?[JXWUQ:HUE8E#\_<5M;B3T]2",L?='*
MR=A+1-,0"^%`/,T_.^RAGL^;F=VXM\T!`'\``-$'!\T)"<P,"=L4%)01$>$@
M'M0@'\PA'^@F)M8F(]$E),XJ)^XO+XL?'>PU->`V-J<K*=0V-?I"0KLR,MD]
M//E&1N%!0.I&1OY/3_Y04/E04/%<6;!$0_5>7N!85OUE9/AE9?1E9?%G9OIK
M:^IF9M%K:]>#@^B2DM>(B-.3DLR4E,RFILVMK?W9V=#!P<S(R/'Q\<_/S\S,
MS/___P``````````````````````````````````````````````````````
M`````````````````,^-3J<```!N=%).4___________________________
M____________________________________________________________
M__________________________________________________________\`
MH`4\,P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```".241!
M5`C78V#``BSY1)4U<Q$`)&3G&\TEK((LY!Z6F&YJR,(MH*`!$_)*YLB2,W.T
ML+)E%U2""+'&QD3PBLM+RTA)BLFJ:ND"A:+"`UR8>!3UD<R*C$M*2S$QXE=#
M"(6:9^?D&/@Y,0NIPX2,XU,S,Q(\/?R#V42T(4(.UC:NSO9N/D$A@=Z<$CIZ
MV+P#`%*`+5K5'@Q6`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;G(N<&YG````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0S`#$P-3$U-#,Q,#8U`#`R,3<Q
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_P@EC@HGC@XLDQDTEALXGAXVB2$YC!<G7BU)K"4Y?C9.IT!<O$1<KC]4G3]2
ME%)JOU=PR$M@J59MP%YTP&!UO6V"T`TIA!`KAQ$MAQ$MAA,NA`P<4A0OA14O
MA18PAA@SBQ@RB!@RAAHUCAPXCALUB!TWC"`ZCQ\XBB,]DB5`EBA"FBM$F!TN
M9BI"D"])G"M#C31-GS!'E#!(E#90I"@Z=CI4J28W;CU6ISA/FBY`?3!#@$%:
MJS-&AC=+CC9)B%!KQT9?KT)9HSI.CSA+BDQEN$ICM#Y3ES9(@CU1D4%6F49<
MHT-7FT]GMDA>ID59G%1KN3]1BU=OO$UBIUEROUAOO%!FK%MSPE1JLU9LM5%F
MJT=:E55KL$E;EUYUP5IQN%MQN%ENM%AMLF!VP6!WP5-GIV%WP5!CGUYSNF%W
MOV!VO5)CFV9ZO6R!PW"$R&9YMG*&QW.&Q'B+RF]]I9ZFN\O,S)V=<JJJ@JZN
MBG!O0G5T1W-R1GY]47]^58R+8964;XN*:)R;=ZNJA(>&:+"OB;R[FJ.2'Z64
M(;FI.J^@.LBX3*N>1]7&7L.U6,F[7MS-:=K-=::5)JZ<*[6G3M?(:=O.>___
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$#>
M^X8````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````O$E$050(
MUV-@P`)D92UBBG/]]95EE+2,G,+204)Z045YX29J,@H:!K:!*=E`(4[/@L)D
M*TTY>75=2S_1K"2@$+>PN`@/*S,3"QL7KZ.0(!]0J*6MLJ&NIJJZMKZ\HK6Y
MJ1$H-&UB7]>D]H[)G=V]$Z;V3^D!"N5'\G-(2JGHF+M%Q$?Y>-@#A1+32G,D
M%+5-W4-3$T*\7>R`0LX992720!<%IV=&^WHY6`.%C-GC#%5!+A*+#1!PM3'#
MYAT`,X$NNE0T!LD`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]P82YP;F<`````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(P-#8`,3`U,34T,S$P-C4`,#(Q-S`R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____P;F]T<G-_?W^Y>7F\O3Y9("MYNOS
ML;S-Q<[;GJ2MO;_"]??Z"C1O%$!Z)4Z#9(:RGZ_%T]OFP,;.[_+VY^KN`2]I
M`S-L!35N!S=P#3AO#SQQ$C]T&$)T(4V%)T^!*5"!+UJ1,%F)0FN<2&V<3G&;
M:8NS<9"UGK++W.#E`#%J`S-K!35M"3AN#3UU$$!X#SQP&$5X'4R"'TM]+56#
M,UZ0.&&/3WBG4'>COL+&[>_QRLS.W=[?OL'#OL7)P<+"LK.SDY24S<W,VMG8
MR+^^KPL%MA,-N!80KA0/KQ41KQD4OAX8P2,=Q2<AS#$KQS`KT#4OTSHUVD0^
MW4A"U49!WTQ&NT(_XE)-U$Y)XU5/XE90X%=1WE50X5=3S5%-Y&!<W5U9T']]
MO(%_PYV<[<_.T+NZJ@(`K`4#L@P*N104LA@6R"DFNRXKUCTZN#0TQ4$^X$U*
MUT],X511VZ:ER:FINJ6ER[^_RKZ^T,7%[N+BZ-W=T\G)_?+R^.WM^._O[>;F
M_?S\Q,/#_O[^^_O[^?GY^/CX]O;VZNKJX>'AV-C8U-34S\_/SL[.S,S,O+R\
MN;FYLK*RL+"PIZ>GG9V=BXN+?W]_____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````@EY!#@````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"_241!5`C78V#``J9-FV+'TMY9Z9WNYN$7%!8-
M$G+BUA1F[2[WS'#W#0R)B@4*39W(R2[4U5OAE>GC'QP1$PD4FMS-P272TU>>
MG9635UA<5``4XN&UMK6QLF?*#0B-2TB,#P<*::BKF<H9RB@R5]75UE?7N`*%
M!%45I,7%^02TVAA;&ER<'8!"ELJR.MI2_&9BS8VI2:5-$X!"YD:ZVI(&\BJB
MS>TE^<G]DX!")GK:$OK&2A9LK1UI*66.D[%Y!P!G]S!V15&RO`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V]M+G!N9P``````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#4Q-30S,3`V-0`P,C$W
M,3,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___5-3;H/#WA04*G45+_B(E!H",Z?"-1JC)"ABI6K3=)D#!0F39FNTE?JD1K
MN5`^?25EK4AOOU)PNE(V<AU&ARM.D3)4FC=FMD1QO5$^B!-!BQ=,D!]4F"A)
M?2A1AB]FJ#Q9CS5EG4!UM$QTKDYZMU-!=PGKX^+&.#'$"`#$"0'&#07)$@K.
M%0W5(!CB,RNZ,BSO13[20#KW5$WF4$GS6%',``#+`@'.`P/,`P/0!07,!07-
M"0G6#0W.#0W8$!#/$A+2&!C-&1CA'1W,&QO2'!SD(2'4(!_1'Q_4("#8)R?/
M)R?N+R_;*RO=,"_R-37*,##A.#C2-#3=.3E_(2'Z0D+G04#\1D;E0D+J1D;L
M2$C_3T_^4%#V3D[Y4%#U4%#Q4%#L4%#'0T-_+"SV5U?@4E'^7U_Z7E[]9&3R
M8&#]965_,S/Z967X966=04'_:FK_<G*+04'49&242TOWAH;QA(3&;F[]CX^[
M;V^R<&_IH:'8Q<7,P\/>U=74R\OV[>W.QL;-Q<7_]_?X\/#GW]_[]/3NY^?^
M_O[\_/SZ^OKY^?GR\O+N[N[DY.3AX>'8V-C6UM;4U-32TM+0T-#.SL[-S<W,
MS,S___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"$
M8`0$`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+9)1$%4
M&--ES[M-0T$0!="[=V87"R0[=T*(!'VX"@C(+43H!JB``(D.<$XM9(@4B<1^
MO_7;W1D*\.G@`&<"MK_KQ;Q:J:)5L^8[(E]?6HTBL.9N.X%BF8(,4ZVQ^?[>
M7RH"XM/K\W<^68J?#Q?J]5WP&&_?UMUDACO8//1?Q%4^;J9"T924]<.@*%T_
ME)X,)-UN?J#(_5B.;:`(W=Q&*`Y=:3S\J<3FYF90C*60Y#+,3.Y%\_D'_Z(X
M771-%"4>`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;GHN<&YG````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#0W`#$P-3$U-#,Q,#8U`#`R,3<S,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___[1M<+YTB,*-IIQIA]O"UUY(6YM\
MEZ>.I+>FMH-7AI]PHY)UELRWT(=<EV9;:GUEE[6HPHQQJFU2CW18G\R_X7A>
MJ&1+FVY8I[*IR7)BI&97H7]RN9B+TG5OD3\QDT]"H4Y"H%9*H81YS(E_SIF0
MT#TRE6]FM#XVFE%)K49`BW%HQ7QUS7MTRC`JES4NF#4NES4OFC8OF3@QG#<P
MF3<PF#DRFSDRF3LTG3TVGSTVG#PUFCTWG4$ZHD0]I$=`J$,\GDE#JTA"HD])
MKE1-LDY(I5A1MC\Z@U1.JEQ5N%Q6N6%:O6%;ODQ'DTY)EF5?PEQ6KV5?P5)-
MFU%,F51/G6ICQ%Q7K%I4I%A3HF1>M7)KRUY9J7-MS&->L'1NS75OS79OS7AR
MSVYIP'!JOVUHNWQUT7)MPW-MPGUVT6UGMWUWT7=RR'5OPWYXT7QWSWQVS7IT
MQXN&U8F#T'!NC34QG#@TH#@SFCPWI#XZID=#K$=#CFADQUI6IVUHR'9RT7ET
MTGIUT75RS()_TC@UHT5#HU-1HF]NT5E@M^N(<^B.>_2";<%M7^^)>..CF/>R
MIM!D5*M=4>J$=9);4KF`=[Q*08$T+=-P9K1#/71$0L6!?O___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/.9O34````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````P$E$050(UV-@P`+8!4IZQ/BD.LH-310E`Q*S
M@4(S)T_I[>^;Q:1N5"'*'-]0`!2:-K&KNW/"U!D*+55>.FFJN4`A>2ZV24*<
M(M9E$N(U]2HL&D`A#CFUZ3*MO-R5_#SMV7JR,4"AXN9494W]4B4MW]A,W93P
M2*!048:GK8&QE9-W76-^>EQ$,%"H,-#1S,#2P3TL*2\GJS;4#R@4Y6QA:&[O
M&I20W23,VN:O#11RLS$TM7/QB<[43986#*GVP.8=`!.K,)U6W=K-`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P92YP;F<`````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q
M-S`Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____RPT.TAP?V3(ST#4VQ#H[\F)D^F=H^'5V_&YT_W5ZS)R?U:VOS,G*VM;8
MR\G+[NWN_/W^^OO\RLO,?X>-R,W.W^3DZN[NT-34WN'A]??WV=O;R,K*^/GY
M:9F%RM#-?;"+7J!ICLB7D\29M^V\O.*^4)=0H=FAWM_><I!NJ;JEJKRDT-C-
MBZIX]_CU=X17D91][>WLH9!HHHIXHVI+YN3CL9.'Q)^:P$]`KY.1R```Q@``
M?@``?0``R0,#QP,#Q@,#QP0$QP4%R@<'R`D)R0T-T0\/B0H*RA(2S1@8D!$1
MX"$ATB`?SR`@FAD9I!L;TR<GK"$AZ2\OKR,CI"$AMB8FV#`ON"@H[C4UNRHJ
MOBPLPRXNP"TMQS`PKBHJR3(QQC`PWC@XW3@XSC0TRS,S\SX^]4)"U3HZN#(R
M^49&U#L[XD%`W#\^VS\^X4)"^4I*PSL[^DU-Y49&ZDE)Z$A(^D]/_%!0^E!0
M[DQ,Z$I*W$9&\4Y.^%%1]U%1]5!0]%!0[E!0[5!0T$9&\5=7Y513]5Y>]6!?
MY5E9^F1D^&1D]65E\V5ET5A7_&MK^VIJX65D[F]OS*"@TZBHW+&QXKZ^\]#0
M^??W\>_OT,[.S\[.R<C(^_O[]O;V____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M)/M">`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!
M5`C78V#``FSM_`O[IDG-FBW+E^T3F54.%++SSNQIGRHI("`RLSHXO:P>*.01
MW]%5Q2NFHZW`WYI65%<"%`IMYFABL5"4UU+192^HK<P%"K'UMR0SFRB)&NAI
M<%74Y*<`A;K;<OR8S-5-+8U5N1N*61.!0IVE@6Y./,J&5FKZG"49"=%`H<9P
M3T>'23*:1D+3)^:EQH8!A9*\G&U<)HL+R@G/F)`2$Q$$%/)UM;9WGR(Q=XZT
M66]<5$@`-N\``$JQ,9DBWA,,`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W!F+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`U,``Q,#4Q-30S,3`V-0`P,C$W,#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____&5E?(6UW/:6KCHZ7JK+"WE9?#
M>HF79XEV27N'9YJ2=Z.*?[ED6Z&4C,EY=*.BGM.DI*6^P.>$C-&>HKMU@\JV
MP.OT]?BBK\_W^?O9V]S.T=+O]/7V_?W&S,SEZ^O8WM[*S\_Z___X_?WS^/C3
MV-C(S,S`Q,2NLK+W^_OJ[N[H[.SEZ>G+S\^VN;GO\O+N\?&)BXO/T='Z^_OY
M^OKX^?G0T='/T-#;X-_8W=SQ\O'<W=S5UM7&Q\;X^??-S<G+R\G)R<C+P+;(
MN[3/A&#";DK*O+>\:4[FKIR_GI/@Q;S!43+3=V&_EHS$02V_D(GCGYK*@X''
M@H#4CHO#CHS=HJ#AIZ7\O[SSN+;(``#'``!]``!\``#)`P/+!07(!07("0G1
M#0W3$!#.&!C;'1W@(2'1(!^:&1FD&QOJ+R^O(R/M-36[*BK',##=.#C1-C7X
M0D+X1D;#.SOE1D;]3T_[4%#U4%#R5U=\,3'[:FK)5E;06UN01$3<:6CI>GKU
MBHKB@8"X:&CZDY/UDI'UFYK&?W[SGI[-C(NL>GFXA(/.EY:^EY?[^OKZ^?GV
M]?7U]/3$P\/Z^OKU]?7Q\?'N[N[M[>WJZNKHZ.CEY>7BXN+AX>'=W=W3T]/0
MT-#.SL[)R<F^OK[___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!I`_N?`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"8F(SBJLJ\E,2HN.3TW**
MRH!"E;5-[:V-+,Q,U35U]0W-+4`A(TU=%1TU%[\`9T4%564M;:"0D+G)-&EW
M-Q]_5V]94[.I-D"AB;W6<V2\/-A[?#VE)DV9/1\H-&'R+`L'`2Y.'@Y!B?Z9
M\^R`0GTSYBYP%.7CYN47MI]NZ[00*&1HI22O;BPI)B(N9V"IIZ$/%`KK"&X+
M"@ED98N(#.\.[>H$"J4G1L4EI685EI:7%.3E9F=B\PX`]?HR\:^;_9<`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&@N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,S`#$P-3$U-#,Q,#8U`#`R
M,3<P-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\TC)<U)2LNJK;$-(+X@,<TR0[DT0:\S0+DX1MI%5<U(5N!28=M280D%
M:A81=B<BA3HVE3@UA4M'HT9#E551J5).HP``:@$!;`$!:P$!:@,#;`,#:04%
M;@4%;`<'<0D);@H*<@T-=0T-<1`0>!(2=!04?1@8?A@8>!T=@B$AAA\??28F
MC!D96BLKCB<G@2\ODC4UESHZG#@XD#X^GD)"HD9&I#\_DT%!EDI*J3H[@TU-
MJ4]/JDE)GDQ,HTA(FE!0JE%1JU%1J5!0IU=7J5Y>KFIJMV5EK)B8SU148PT.
M2$5&@Q<;>9"2O'=YB=C:XX&(GL[.N?'QW-W=T<W-Q\_/R[*RL']_?M+2T>'>
MN?_[TMC.BOSXW>OAH<:^DO?OO]3.I]/-J*:CD>?/5OKA9/_J@/;B>\RUB=2^
MLLP``,X#`]`%!=$'!]0*"M8-#=@0$,P1$=L4%-X8&.$='>0A(>@F)J<;&^LK
M*[`A(>XO+[(C([DF)KPH*/(U-;\J*L0M+<$L+,<N+O4Z.LHP,,TR,=4V-=(T
M-,\S,_@^/OI"0MHZ.N`_/OQ&1N5"0OY*2NI&1O]-3>Y)2?]/3_Y04/),3/U1
M4?9.3OM14?E04,Q65LN`?_'Q\>'AX=+2THN+B____P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%`+TV0````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````M$E$
M0508TVW!L4T#01`%T#^S,[,GVUA"0B(S!5`$(<)].*,'6J$&(F=(CI'L'K!$
M2&)\>WL[<R[`O`=<(:SI^V81OW_GP;)EG7T*EOVJQ:F4051-+('QW`G5OE0V
M53&K2+A3)OTIGLW4LM>CH&6=[+'M>B)FBH"`ILBG^W<G$J:("0*/.'_$J^IM
ME^M0VYO@:<LO#TW2W-2KCPT"6K<]2^IF2F4<W<'XVAPHB2Y,A^(>@7]<`#FD
M25H"+9D?`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]P:RYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-#8`,3`U,34T,S$P-C4`,#(Q-S$T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````______[_Q\;'\O'SU-;6NL&^S=?2
MS-;0/'9-,VX^Q=3(0')(1'A,3XI7:)9O5GM::H%LAZ.*%5,:)6`I5(A83790
MCYZ0=Z%YIKJG"DD,)F4G(E(C*UTL28!*AZ*(`$(``#X``#L``4,!`3L!!4@%
M!44%!4(%!3\%!TH'"4D)"4$)"TL+#5`-#4@-#DH.#44-$%,0$%(0$E`2%%(4
M%$\4%E86&%@9&%48%T\7'5T=&$T8'5P=(6(A'UP?(6$A&T@;)V(G(5`A+VXO
M+VTO)E<F+V@O*%DH-7,U*ELJ-7$U+5TM,&,P+EXN.'`X-&@T,&`P-FHV,6`Q
M0H!"0G]"07I!1H)&07A!0GA"1GM&3XI/3HA.3XE/27])3(-,4(E048I14(A0
M3X5/4(502'=(4(1037]-48-16(U85(=45XM758A57HM>:I-J98QE9HAF:HQJ
M:(EH;HYN>IAZDK"2C:F-@IN"HL"BH;NAL,JPK\>OY^_GV^';Q,;$U-74,F4Q
M,&$O-F8U/W0^1WU&Y^?FW=W<^/?W_?W]^OKZ]O;V\?'Q[.SLZ>GIX>'AV-C8
MU-34TM+2S\_/S<W-S,S,N[N[LK*RIZ>GG9V=E)24BXN+?W]_____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````OK*OP@````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``F;-FEZ6F^5GH::@:F3O
M$18/$IHQI2HGW$[+4D?7QB4X*A$H-'-J3V6*HUZ0H+YY:&9T0BQ0:%H_4T6#
ML92XB(FT$$=&7!-0B)FQL]1:G8O-S-Z#3R([PA\HU-;14JRMR,/*Z18<DQP9
MZ`,4:N_N*U)1%JYE%TU+E^.MEP4*=;5.+%32-,UCJ2XOD1?P=@4*]4Z8G*]A
M:.O%SUTC*>;K[@04JILTN<#`RCDD*;6Y,<!3Q@&;=P!!`#%!916*JP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!L+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R-0`Q,#4Q-30S,3`V-0`P
M,C$W,3(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____'P<+__O_&Q\?@X-_-S<S,``#-`0',`0'.`P/,`P/0!07,!071!P?-
M"0G4"@K6#0W.#0W8$!#/$A+;%!3>&!C2&!CA'1WD(2'4(!_,'A[.("#H)B:G
M&QOK*RO8)R?-)26P(2'N+R_6*BJR(R.Y)B;=,"^\*"CR-36_*BK$+2W!+"S'
M+B[U.CK*,##-,C'A.#C5-C72-#3/,S/X/C[A.3GZ0D+:.CK@/S[4.CK\1D;E
M0D+^2DKJ1D;_34WN24GL2$C_3T_^4%#R3$SN2TO]45'V3D[[45'Y4%#Q4%#*
M1T;534WZ75WG65C]9&3J75W_:6CY:&CZ='3X>WO8T='0R<G,Q<7RZ^ODW=W2
MS,S_^?G^^/C\]O;V\/#EW]_AV]O2S<W=W-S^_O[]_?W\_/S[^_OZ^OKY^?GX
M^/CW]_?V]O;U]?7R\O+Q\?'N[N[L[.SKZ^OIZ>GHZ.CGY^?DY.3AX>'>WM[;
MV]O8V-C6UM;4U-32TM+1T='0T-#/S\_.SL[-S<W,S,R[N[NRLK*GIZ>=G9V4
ME)2+BXM_?W____\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!&.8BH`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*Y)
M1$%4&--MP3M*!$$0!N"_:[NZ9\;'PA[-S%A4\!!&)H8F!J)X-#.7!4$9Q.FI
M1Y<'T.\#_DBXA]_ZS5$I,+76^DL&NE_YR(QN+O)\#4+XIXS,*=15GBXK"+X\
M3'.A.W-3N:B/2*#S#8DC(@<')7K-.&OZL9<T[+9#3MT"&3J_S4L,HC&-K34#
M0=^_UUZX;H=JJZD@8_^U&G,^/BFIB;B!<&BR89Y.:UE^S-WPCU]2_U[R:=1"
M;P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O<6$N<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,C(S`#$P-3$U-#,Q,#8U`#`R,38W-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```&`4$Q410```/___V,%*F,)+&D-,60.+V40,7,8
M/&X8.FX9.FP<.W8@08$N3HPU5Y="8Y!!8(M#7X=+8HA098I2:)-;<8U9;9)C
M=:%TA:AZC+>1H.C;X%\`)V$!*5\!)UX!)V(#*F,%+&(%+&4'+F@*,6L-,VX0
M-W$4.FH5-W08/G@=0G@=0WPA1UP;-H`F2W\F2H0K4&,A/(DO5&8C/FLF0FTH
M1(TU66\J1GLP3G8N2W0M2G$L2)$Z7G@P3GHR3WXT4GXT4WPS494^88`U5)0^
M88`V5)A"9H0Z6)M&:8H_78Y"89Y*;)Y*;9)&9:!-;Y9)::%/<:)0<II,;*%1
M<I]0<)Q.;J!1<K^2I+6?J+2AJ;>FK:N0G,"IL[JEKKZLM-G)T.O;XO_^_\?&
MQ]35U<;'Q]35U.?GYMW=W/CW]_W]_?KZ^O?W]_;V]O'Q\>SL[.GIZ>'AX=C8
MV-34U-+2TL_/S\[.SLW-S<S,S+N[N[*RLJ>GIYV=G924E(N+BW]_?____P``
M`*0//4T````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````K$E$
M0508TVW,L0W",!"%X;/OS@G!!4J'Z&BR",.P!#LP"AT2,]`Q`!(2$K0@B&/[
M;!Q1PE]^TGL`/RG8@-QC?W!SSVR:=K(C@"35/G='3T1F5B-HR-*G53HMU%="
M(1D>)#%F@VP;SK[0;3M%E?,5N;:LW;N06?NGT%+S.'-#*J1HVN9\06YK$WP8
MB0;4.NK.5AR]CT,AM`B"ZFR-=KT+4NB%D`RA*D=!4HKPIP\CITA:`^XBPP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O<&TN<&YG````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U`#`R,3<Q,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___YM[?))^?^+0TMJX
MO9J+D"XYECE`BE16:[R]QXV5TFIUMX*,S#)%GC5(HS=)GS='D5%EPCM)BUQK
ML%MGHB8ZE2<[E2H^E"D\CRU`DSE/K4-5ID=:K$98JE1FM%UON&=YRFQ^SE]N
MKCI#:G*$RW2%R&Y\MV]\LS9&A#A(A3M)?T]AIT%->TM7@$A4>6!IA8J5MEID
M?9*8HVQT@9B>I8F.DYR>GV1N<:Z]O96:FM78V-+5U=35U82-A[B\N3Q40$]A
M4EAP68B:B6UR;6AL:,O-RWN-=)B;E6EN869L6I^BF'^"=:&ECZ.FDF)E3V9I
M4ZNNE*&CD'AZ8H:(<X^1?8""8IV??X:':8V.=[*R@*ZNE)220:.A78&`2XF'
M49>69J*A=;BWAZBC/:^I1(%]-Y",2;>T;+>S;K"M;;NX@<&R`JV?"+FM%=3&
M(^[?+^G:-<*V+LB_._GM4.[A3N794.+63XZ',]#&3(%[+\.Z2.G>6=W358N%
M-JND1N+98<&X4Z6?2:2>3HF%3<&\>,_`)96*(.?7-;6I+??G/JRA,J^D-L6Z
M1I*)-,W"4S@O&:Q]&(M_9,*5.+%<!:E9"K=L(;11`,9=-=QV5KLY&:XC$+$G
M$:2-BKBDH^70SZPB(,V[N[VVMO___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````!"0?HX````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`(<7)R8N-7D
M^24DI01DA115@4*.=LZLO`H&GIKZ,2;*OH9*0*'^.1/=>>3T4OT%PV+53;TU
M@$+,"^=9ZO`%Y-0:-35XM&2(`(7,;=VX9+2R<X/S"ORJ2\P2@$+6-O;&XMIM
M<2GY-='%Z:(10"&6!7/9=,4JTZHZZY/*(AOC@4(SIL^<S^F57!0>%6@5ZM/A
M"A2:-&'R+':+UO;2K*#$NL)F8:#0U"G39G-(AU1D]O5T=_66JV#S#@"WTC+Q
MV/7R9`````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P<BYP
M;F<`````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T
M,S$P-C4`,#(Q-S$V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____N!05RC4VLV5FGQ8GL'>"APPJ1Q$MR+;`4"A)FGV6:D!V
M73]]4SI]-BM[GIG**R9:54^5>7.T=G&P>72OCXK&EY/&2$./1$!UAH'#<W"C
M>WBAY>3R1$"+6E>@CHO"V-?J5%*<145^75ZF&AU43U*9EYO&J*_#\??]X.#?
MSZRGS8%[S)..RY.0U)R9QP<`>`0!Q`T(RSDU\4Y)\U=3ZU10Q5E6SE]<\YZ;
M]*.@S8B&UY22Y*.A\;*PU)Z<X*FGK82#[;BVN(^-Q)F7^,7#X;2R^\K(\L/!
MRJ:ESZNJV;:U\M+1WL'`^]W<\-/2O@``Q0,#PP8#P0<#P@4%OP4%R0T-R1`-
MRQ`0S!@4QA@8U!T=U"$=UR$AV"@DEQD9GAT;XB\OXC(OJ28CY34UM2PJYCPX
MP3,PP#`PUC@X[T5"[D)"R#HW\$9&O3L[X$E&WT9&VTA%]%)/\T]/\U!0[E!0
M[E)0ZU=7Q%-1QE53]6IJV6QJS6AGYWU[\XV+X(2"^):5\I63O8F(QY*1^;R[
MZ+"O];NZSZ*AYL/#_-S<_O[^_?W]^_O[^/CX]?7U\O+R[N[N[.SLZ^OKZ.CH
MWM[>V]O;V-C8U-34T='1S\_/SL[.S<W-S,S,Q,3$N;FY____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````H/&#NP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```#!241!5`C78V#``C@,X_.JRC.C0@-"(F)3<DN`0JI<+%:6]37F%946
MU;5U#8U`(4%E=<V)TV;-F3U]RJ1>QIX)0"%):2D%3FU/3R_O#I]./W]?H)",
MK+@\'VN0461<FHFI66$.4$A`452"GSTP+#HQN[BT@#D#*"0F(B3'K6-M8VO7
MTM9JW]P$%!)64M.8,V/JY+ZN[GZMF7/G`854>-ET]?0=G%S=/=S:79P=@4(\
M3`;!X3%)645E^<;IJ<D)V+P#`(6D,?<&J6\]`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+W!T+G!N9P``````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`S-0`Q,#4Q-30S,3`V-0`P,C$W,C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____0-3;*9&7`76B2
MJYLZ>3L`6@``5P``.0``.``#7`,%704)7PD-:0T*0PH8:A@12Q$?<!\95!DA
M7"$J9BHX@S@R;S([>#M(CTA0F%!&A$9>I%Y>H%Y9EUEDIV1JKVIEI65JJ6H3
M9!(P?"]FIF4)905GJ61NK6@Z?R=;H$AXK5<V=0-KGD!5<`)/8!&;JE-^@B9[
M?@UV=R=Q<4%85AV(AU?#H1FTFCR2:#_.;1W6=2?'8Q?%7!"T2025/@>Y20?#
M31*>3BG?5BO(,PVB.R2_4CR;9EJJH)[$%`'(&P>](A3A*B''``#)`0'(`P/+
M!07(!07*"0G."@K0#0W3$!#6%!38&!C/&!C<'1W@(2'3'Q^D&QOB)B;E*RNL
M(2'M+R_J+R_I+R^O(R.V)B:X*"CN-37M-37L-36[*BJ^+"S#+B[`+2W',##O
M.CK),C'&,##@.#C1-C7.-#3+,S/T/C[S/C[W0D+U0D+5.CKX1D;W1D;</S[;
M/S[A0D+Y2DKF1D;Z34WE1D;J24G[3T_Z3T_[4%#Z4%#N3$SQ3D[X45'W45'U
M4%#T4%#V45&K7%NM9&3___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#2H-\+`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+9)1$%4&--MC+T-PC`01L_V
MV<XE1("(*$"P`"/0L@X+4-,R#A(-"[`(/Z)``AQBGQ.2&E[Y]'T/X`<!).@Y
M&2_/%2NM\U%O(T%8G')]\RP1DV%F`$&C-=1<M4:E"S(E2-`FI7[?OEF9`5&L
M6H56)2>SDD_,\J1QW2H/LMH=#R+:06JJ;6R59Q;[IG%4$+ER[=M\R+RZ+ATN
M4O(^Q$[QG7G^F$VZD/OXT!XY!G4QQ9!T^?)U'>$/7WB"1QIOPN=:`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<'DN
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,W`#$P-3$U
M-#,Q,#8U`#`R,3<S,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___X@;',6WN:.>GYR3EK64H,VWO["+F:J:H+^?K,O)RK^U
MO,&ROKNLO>CEZS<VF4Q*L%54Q&!>OP``A`4%B`4%A@<'APD)B0\/BQ`0DA,3
MDA@8D"$AGR,CGR4EEQ\?>"$A?2@HD2HJDB@HB"<G@C4UL#4UKBXNEBXND2XN
MC#0TFS@XI34UECP]I$9'O3L[GTA(O$)"JU!0P4Y.NDM+LE55P$)"CE%1JDI*
MF%%1HEY>L6UNRVQLPG)RRV]OPO?W^O7U^,_/TL3$Q\+"Q>;FZ.3DYM+2U,7%
MQ[JZO,7&R?+S]??Z^O'T]._R\LG,S/O]_?K\_.'CX]W?W\[0T,/%Q6^J;&B>
M8EVB37Z<=_S]^^3DXM+2T,C(QO?W]O;V]?7U].?GYM+2T<K*R=O6U<<``'P`
M`,@#`\L%!<@%!<@)"=`-#=,0$,X8&)`1$=P='>`A(<\?'\HB(9H9&<HB(LXF
M)<HH*.DO+^TU-=@R,MTX./5"0K@R,OA&1N)!0>5%1-,_/\,[._I/3_I04/10
M4*X\//-65O)75_5>7OID9.I?7^A>7O-E9?=H:/MJ:N5L;/AX>-;+R]C1T<O%
MQ?GS\_CR\N_IZ>[HZ.WGY^+<W/KU]=#,S/KZ^O___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````!N_780````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````N$E$0508TVW!L4T#01`%T/]G9\=GK^Y`LFSG9(24X`8LT0150$1`
M$Q1``XB,P#DYN6-+QA><?+<[2P'P'O`'\8"V:R]]GW-0;:(]"=#,TS@,)4L(
MLQ`)P>MFJ4'BHNVZZZLN&12RKB[-<]"7ICCE"XK[]V*<;">/6X\Y"A3)"V=O
MF67<?4;A!&(;,VG[;+Q+HY`?"C]_+ZO='.36SUZK0W$\V0]C6,T'^L6G`D%?
MJ*:+=`AT(2O^\0M):CXGC?'3?`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]S82YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P-#<`,3`U,34T,S$P-C4`,#(Q-S`V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____@ZV$`'0``',`
M`$D``$@``7$!`W8#`W0#!7@%!78%!G@&!G8&!W4'"7@)"G@*"W<+#7\-#7T-
M#7H-#WT/"E,*$((0$GT2$WL3%'H4&(88&($8$5L1'8L=&GT:'8D='(0<(9`A
M'X<?&VL;&609)(<E)8@E)XLG*Y0K(G4C(7(A+YLO(6TA+YHO)GHF+I(N*'LH
M-:`U*X$L*GXJ+8,M+H4N+X<O,(@P*G<J,(<P-(XT,XLS.)@X.)<X-(TT-H\V
M/J,^/J$^0JI".I0Z,H`R0*)`1JY&0IY"0Y]#.HH[0)5`.XH[1J)&2:=)2*5(
M1J%&3:]-2:9)4+103[)/3:U-3*I,4+!03ZY/4;%14*]03JI.4:]11I=&4*Q0
M5+%43Z103)Y,3Z-/5[%75[!77;9=7[=?7K9>7[1?6:A93I-.9+MD7[!?8+!@
M9;AE:KYJ:+MH6Z-;5YQ75)=4:+=H=+]T::QI>L)Z:Z9K9IYF=+)T;ZIO;ZAO
M:)UHA<B%ALB&;J)N;:%MB,B(<*1P@;N!=J=VB,"(>:5Y@:V!H-2@K,^LL]>S
M,)$O,HDQ-H\U09Y`/YH^/Y@^6[=:9KAE;;5LIL.E____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````C`@##@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```#`241!5`C78V#``EC95+WR
MD^UDN)FYQ)6,W(.!0FRRKGEIGNJ2@KS""GK.(>%`(3'+S/*NBN+:AJ+"EHS`
M2#^@D&YLP92IK5GM3-55W74Q81.`0C[Y*8D=C97--65MG?71'M9`H<GI_6KR
M@E*B<DX1D^)]'2R`0MG^&B+L[`+2FHZA,4$NO<9`H;@>"4X^<^^$G-*FW(DV
MIOI`(5L9;A8>10.WF-22)'LS0VV@D#(_,X>0G(YS2%1`GY6)E@HV[P``V:`M
MR[S@Y1,`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-B
M+G!N9P``````````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q
M-30S,3`V-0`P,C$W,#$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___\G0X]266[`R>$!)X40-)(*(%8?094J0'E0;;ERA+*&
MD:T#+(8#*X0),(,2.(H9,6<I2Y@Z5YHZ58](:+`G.%U(9JE.::-7=+5$6XQR
MC,9B=Z528H=\D\:*H-!]D;VELLZXQ>($+(`&+GT+,G\,,7P.-(`2-X(;/XDK
M3)`?,EDX69TE.V=$9:9(9J5:=[1C@+UGA<%IA;]MB<%D>ZBAL]D>/WH]6XU,
M9HXU47%`5F1395]N?F@P?@UNLE!%CR%)E"9?ICYGITE@I3IFK$)RLT]LJDQ&
MCATZ;!M`="%>HC5-@RQ2BC!7D#19DC9FH4)RLTIJI49TM$UVM4]UM5%WM5%R
MKTYSKTX_AQ!#=B-:GB]'?"9)?BA+@"I/A2U1ARY4C#%3B3!6CC-9DC58D#1K
MK4)>ESIOL$9CG3YCG#YKI49NJ4EWM5!QK$QWM%%VLE!?GRN`N4:#CW9+A0./
MOU%GF12)LR^LRTIM>$E\F@6XSE";KQB^RC5X?C>@I@#9W$V0D#VSLV"QK@>K
MJ#O*PQVFGB#,O`#-O0',O076Q0W8R1"RI134QA_HV";HW#KZ[4+=T#S&LP#,
MN0/-N@G3P1ODT"'%M2+KVBOXYC[\ZT;^[E#ZZ4_.N`74O0K___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````PVRL_`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```,%)1$%4"-=C8,`"F,4$1>19]#555?C9+)IFS08*:>M*R9DH:*FK
M\`G83IPPIQHHQ,ZIJ"3.I*',:M4R8V9#J3-02-94VD!"AE>M<FI??T6H>R90
MB,=,4D>8V[JM>UIMD7UX@!]0R-A0C\.\;FY7:[FK6T&0OR]0R$A4R*:G8UY-
MH5-P?DYZH@]0B,NR<7)[<YFC2V!87E9R?`Q0J'AZYZ2J2`?OC-R(@-2$6"^@
M4.^4^A([C^BTD(+LE*2X*$]LW@$`R3$Q]5E`CD``````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O<F\N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#`S`#$P-3$U-#,Q,#8U`#`R,3<Q,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___P`E?P,G@0,G
M@`TPA1]`D#A6HCI4DE!MM&1_PV6`P``G?0`83@4L?PDN@0HC61(VAA@\BA$J
M81]"CADR:B=)DR$Z<S!1F2I$?4%@ICM5D$AHK%!OLE=VN%Y\O5ETL62!PFB$
MQ&:!OVJ&Q1`R=1`Q=!0U>!<X>!P]?R9%@CA9GS)-ACQ9DD9BG51OI6F#MG6-
MOLVR`,RR`,RT`,RU`,VS`<RR`<ZV`\ZW`\RT`\RS!=&W!\&J!\VS"<*K"=2\
M"M2]"M:\#<ZW#<*K#=B_$,:O#MO$%-[%&,VW%]*Z&.'''<6P&>3-(>3.(=2_
M'^C/)M;`).O2*^[8+^[9+\ZZ+?+9->'-./CC/OKB0OSE1O[J2O_H3_[J4-W+
M1OGE4.W;7-"U!?7<.L^M!=6S#=V\&.?&)O'1-?K;0NG.1O[@3?793OS@4<PK
M$-4W'=]%*^E3.LM+-?%?1MM80NAB3/!H4?1F3YXF&Z8L(:DN(Z\R)K(S*.5#
M-;4U*KHY+;<W++TZ+L(^,<`\,,A!-,4_,\I"-NY10L]'.O!51M5)/M5+/MI/
M0M]21O-;3>-62?-=3_->4.M;3N=93/)?4?!?4>Y=4-<M(>([+\`Z,,@^-.Q)
M/O)52N-32?-;4.Y:4/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````,UZ5?H````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````G$E$0508TVV,NP[",`P`
M;2=U0@6(!?$-7>BO\<LL2`P,J!5YVZ0SW'@Z'<`/"`?PRS2'Y9VOX_38^QL!
M\,6HQ#5:1!S=``2&5]6P)N,1C1M25^Y,*B$4YEZQU*[LITJ+>=XY))*T5;Y4
ME63OO;)8LH(%:54;>7:V#TJ5KFHMB@[]*9&^6MM>Q]P$#7,DU5-M6_7LACR9
M_A9MHO"'+P=F4B>9(#_3`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S
M9"YP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`U
M,34T,S$P-C4`,#(Q-S$P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____UCY`S,/&.38YT]'3(B,C]_KZ\?3TW^+BT];6SM'1
M^OS\X>/CSM#0XN/C[/#OFJ^>)G`I`$```SL#"6()!2H%#6D-#F,."D<*$FT2
M&&T8&&P8'W8@'V<?"1T))WLG(6`A*6\I*FTJ.(PX.(@X.WT[2)5(4)U01HE&
M4)M05Z)77J=>9*QD:*]H:K!JA:.%)"@DH;&A<7)Q\/'PR,G(,(,O08]`6IM9
M9JME:9)C'T81(BH`-C8U1T=&6EI9O+JUM(%DDD$R;`<`QP``R`,#RP4%R`4%
MR`D)T`T-TQ`0SA@8PQ@8Q1D9W!T=X"$ASQ\?G1D9RR$AQB,CZ2\OU2XN[34U
MW3@X]4)"^$9&XD%!PSL[^D]/^U!0]5!0\%-3\E=7^%Y>]V%AYUM;Z%Q<]V5E
M]&5D^VIJR\/#QKZ^XMK:U<W-^/'Q[^CH[>;FV]75_/S\]_?W]O;V\O+RZ^OK
MY^?GY>7EWM[>UM;6TM+2T='1Q,3$NKJZ<7%Q9V=G86%A4%!03T]/3DY.1D9&
M0D)"/S\_/CX^-34U-#0T,#`P+R\O+BXN*BHJ*"@H(2$A'1T=&QL;$!`0#0T-
M!04%`P,#____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````?!8M%@````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"_241!5`C78V#``FR<`Z/3$\*]W5W<O/S#(F.!0L+63JF)40$>
M+JZ>?B$1,7%`(4EE"\=DIF`?WZ#0J/BDM!2@D**FGI:5`W-F1G96;DY.7CY0
M2$U?6U5:2)"/BU.`G8>#EQLH9*EC+BLJ85!17E)84%1::0H4TE57$%<R8JW@
M-RDL+JNJK@$*:9A)B1BRM#76UQK7V3?9M0*%5&3$&"9/[&MO;FAJZ>CN[0,*
MR<DS3)G4W]72V-!LV]G#-@&;=P`8!3`=Z>/820````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W-E+G!N9P``````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,3`V-0`P,C$W,3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\#&[P2++LF
M.JHP1\HM0K0Z4>,_5<Y*8^M,8^%1:>M09N!D96LS2;\`(J\`(Z\!([$#)+$*
M++8*('@8.L`F1\PK3,XJ09T^7MQ&9>(Z4K--:^1/;.50:]ID?.AE?>,`%VL!
M):P$)ZX%*;`%**\&*:T'*[0(*Z@)+*8*+*X.,;81-+D1,J@6.;P9.K42*7\8
M-Z(>0,(B1,8@0+@@/Z\@/J@:,8@G2<D<-)$A.IHC/9PP4M`B.9(H0Z4U5]0J
M1*<O2J\[7-@Q3+(U4;HY5\8V4[Q#8]T^7<PS2Z9'9^!`7,9#7\M,:^))9M5'
M9-!0;^-,:=91;^-1<.-1;^).;-M-:]A2<>)1;MY"6[1'8;Y9<M-I@^<5-9E7
M<<=MA=5XC]R!A8BIK*UO<W.>HJ*2EI9X>WN4EY>3EI:#AH:>H:%W>7)Q<%#6
MN`WAQ!W4NB#NTR_*M##5O3;ZX$+GSD#JTD;_Y4_YX%#ZXE[XXF7-K0J]KFC.
MP(#'HP_%H0_)I!#!GA+%HA3*J!7$I!_-K"+&IR.NE"36MB["IS"QF"W/LC;-
MLCNYHCW8O4G>PT^:B#NGE$7NTV3(LE2@D$BNGE>FF5^RI&?*NWBXJF^@E&''
MN7S*O8+6R9+___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````'<B3]`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"%!7-
MI1,F3C)555+1,;;W"@8)&7@JQ/?UZ`HH:QO9N`=$`(5$)*+EX[HZ-02%1<4E
M94+\@$*V43%RD:UMFNIZ%DZ^X6'>0*&9<V9/F]#8T#]Y2O7TFEDSI@*%*BM*
M\JOJZG/S"HK+RDN+"H%"21EIO#FUS=F)J5DIZ9EIR4`A'E9FIMBF#C%V3FXN
M#CXV%J"0J[X:OV%+MX=44*B/BZ.=%5#(1$M)R*R]-U`VPM_-V<':$IMW`.(K
M,/B2N%,A`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M<V<N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0R`#$P
M-3$U-#,Q,#8U`#`R,3<P-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___\'"PK*SL]35U.#@W]W=W-75U,W-S+\A`,$B`;\B
M`<$C`\,E!<$F!<$H"<<J"LDM#<(K#<PP$-$X&,<W&-4\'=A!(=]**^).+^93
M-==4..Q</NA:/N]@0O%D1M97/O1I3>1D2?1K3_5M4.]K4/%M4>UO5NUP5W]U
M<__P[<`?`+\A`\0E!\(H"L4L#\(M$,0L$LXR%,XX&\@Y'<DZ']Q")MI'*\Y&
M+9<R(8XP(.E6.JI!+MA4/LM3//-E2NAE3/-J4/)K4=UB2O5R6=5F4\)=3-]M
M6?B)=?>1@'U-1=&/A,R[N.]_;>N#<_&)>>B&>+=K8/F4AN2-@/NSJ7]?6J:(
MA-3%P]7'Q<J]N_GJZ,-[<O6?E,Z\NM;$POCEX^'0SN;6U.[>W/KJZ(N`?\V[
MNNK;VO?HY_[^_OW]_?S\_/O[^_KZ^OGY^?CX^/;V]O7U]?+R\O'Q\>[N[NSL
M[.OKZ^KJZNCHZ.7EY>3DY.'AX=[>WMO;V]K:VMC8V-;6UM34U-+2TM'1T=#0
MT,_/S\[.SLW-S<S,S,K*RL?'Q\3$Q+^_O[R\O+FYN;"PL*>GI____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````.C%[TL````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````NTE$0508TVW+/0Y!012&X3/GS)GA)HA"(@H)M4)O'?8@-J"@
M4E)(KD)O,S9!HA&)A.LW<<\,UZAYRR??!_"3@NXC:1ZW-TF=-IJ8UP29JJ9E
MU@='_!4\(700Y7[9>*4)B>@%&JZEC!]I+4/68?;>`L(Y[Y(D0VUX;WA'];!J
M/`M1<5]6B*U5NWE5@;`266R(DW3>ST5+"<=\;!"\]TYZ)K;C::#<D(*\1,#8
M$:,*-&%X>R]NP79F<:#@3Q_81T(T59I5?@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S:2YP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P,S4`,3`U,34T,S$P-C4`,#(Q-S$S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____BXJ=H:&T
M7%YUI:>]TM/<*C%1:W*2<WR;ZNSSG*2\97BF=XFQ8V=O'CMP`"9F!2MJ!2MI
M"BYG$#9T%3=N(4:"(41[-5B3,U6+-%*#1FFA06"20F&3,DIP.U6!05V)4'&G
M3FVA572F3VR:4&V;0E5S:H6P9&Y^"BYF$C9N'T1[+D^`,DUV.%1_/EV)1F>:
M6'>F6GBCI;?1`"YK`S!N"35Q#3IW'4F$+UJ4,%.!-EF)0FNC.%B$.5F$1FJ<
M3W:K4'6H0V*,2FF47H"P9H:R;(JR:H.F>Y>^>9.W@)O`CIFHK[W/ZO#VY^?F
MNAH*MQL-OAX/NQX0N!T0N"(5QRD:P"<9PC`BS#8ITSHKPC<KF"TDHS(HKSHO
MVD@[HS4LX4P^ND(VKSTSTTY!Q4@]ND0ZQ$H_[%U0YUI.UU9*V5M0[V99YV-6
M[&5:YV5;IT,^VV1>I!T8I1\:J20>JBTHM#`KPD$\G#LWNTA#T%1/L4E%P%51
MTF1?VVIET6=B?'AXB(2$_O[^_/S\^_O[^OKZ^?GY^/CX]O;V\O+R[N[NZ^OK
MY.3DX>'AWM[>V-C8UM;6U-34TM+2T-#0SL[.S<W-S,S,?W]_____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````7$UNVP````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"V241!5!C3;8T[#@%1
M%$#O[\U($(U*HY#068/6"FQ%(Q*+L`0KT(N&!6AL`"&81'S"O'NOZ3GE*<X!
M^`%A.FRT%J,0!#2J?GQ,<'P_E_E:&$S-XEB``+7;L1ZC%T9'$P&!F>$FS*/?
MZEF=^BLK6LVK6<*&3,0)YKH7:/NV5C8D1!:TZ'N&D%5.LDL.M_0"YRN^3P*#
M3S0G0GY5W?U1V@CL[KF22)I*IKE&+XXO-6$*I8!1$2G"'[Z,BU<BH@YSC@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W)U+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T,0`Q
M,#4Q-30S,3`V-0`P,C$W,C,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___^L#1BL$!JQ%!ZR'BC),CRB+S?!.D.M-S[714^W
M/47&25'B55[85U_B7&786F*\("O;XNJ\Q<Y\@HBBJ*[J\OH@;K,N=+(Q;:(X
M=:M4FME/C\E8F]>UO\BTOL?'T-C4W>7BZ_,`6J0%7Z@)6J$)6J`0:;$09JP2
M8J@58:08:ZX;:ZTA>+XN@<0R?\(G8)`T>K0X@\`V?KA&E]E%C]!"BL4[>:Q`
M@+=&BL)0G=Q.F-52G]U0D<I7G=9,B;IJK.%II]UNKN/9X>CG[_;8W^7K\O@`
M7J<#8*D%7J4)8ZD)8:<-:;(,8J<==[X=<K8?<[0OA\PUB<PP=Z\W@;Q"E]E"
MDM)!C<A&D<Q/H-]0G=I3FM-8HMU7G-->I=UFJ=ZWP<G#S-/&Q\?,``#(``#)
M`P/0!07,!07("0G1#0W8$!#2&!C<'1WD(2'2(!^D&QNP(2'J+R^O(R.\*"CR
M-36[*BK'+B[',##A.#C2-#31-C7V0D+\1D;E0D+F1D;^4%#[3T_V3D[U4%#^
M_O[\_/SZ^OKY^?GW]_?V]O;R\O+N[N[GY^?DY.3AX>'8V-C6UM;4U-32TM+0
MT-#.SL[-S<W,S,R[N[N=G9V4E)1_?W____\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````>[B43`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+I)1$%4&--MP4U*`@$8!N#W^\D)8B`BH19)!!.M,O)27L*=
MX+9MJX[2`8($H3;"!!&V<Y-:XWP_'4"?!]A!>$2\/$T.5.$6WN:(@<QJ+"((
MS["1@'!*=^2]?,YU2;2Z?5T*KB]PKK.BN[K_[6-P)%^*@NRMZ;V3U%7=^6A;
M*&ZR:;9>*8M4%/.KJ>)S;B>6NCSK+/BR_5Z`</SGD5RN53@C(QK%\,=,5(I#
M83-W?V!LW%E8"Q7WR$SL\0\BY%9)M@IE-P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<VLN<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#0W`#$P-3$U-#,Q,#8U`#`R,3<R,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\H#!+P/
M$LX2$[<F)^$P,L(M+LTS-/`\/O%,3?Q14O!04=5/4,=-3\I45<QB9,0-%,AT
M=\RTM;`:(_;"Q=.^O^72T_GFYYL/'9PC,[5)6)XJ/(DJ/XI)8ZEZD(]>>'M5
M=TPS6U]3=E%$;6I<AWAKDWINE(A]H&]DB%Y5>F]EBTU%:%1,;T`W8D5";$%+
M>SY2@86&B`HS<C5;E#15A$9LHCM7@4YQHU=YJVJ)M?;X^^[P\^'CYM36V0$N
M;3!4@SA?DS9:BT)MI4%GG"Y);$9LGD)DE$]XK4QRHU!WJE!UJ%R`KUZ"L6*$
MLF:'M"%/BB=4B2]BGDYOF5Q^J51QEG67P//U]^;HZLC,SZNMKN'DY<;'Q_?R
M\<QB7\P``,X#`]`%!<P%!<T)"=8-#<P0$-(8&-@;&N$='=0@']`D(<TA(:<;
M&[`A(>XO+[(C([PH*/(U-=LP,+\J*L<N+M(U,LHP,.$X.-4V-=(T-/I"0MT^
M//Q&1MX_/^5"0OQ*2NI&1O]/3_Y04/9.3OE04.M14,Q)1\R_O_[^_OS\_/KZ
M^OGY^?;V]O+R\N[N[N3DY.'AX=C8V-;6UM+2TM#0T,[.SLS,S+N[NYV=G924
ME']_?____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!RX]DT````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(UV-@P`)F
MS9H1P]@S8?*T:5,F]O=V=H"$9DZ/E1`7$VZ?.FE"7Q=C-U#(*"I:M)67/Y4O
MTL[6QCH\`BCD&AHF7RT@E"T5Z.CIXQ<2#!0RM[)4*&V+RY(),#'SMG`W!0KY
M^[HH,TO*"LH%.7MXN3DY`(4T-%64].R-#115U=2UM71U@$(\12Q,(OJ&TISU
MW%RU'.RL0*'RM*3XQ'2VPIJFYKK*DH)<H%!F<GQ"2D9>56-+0T59<7X.-N\`
M`.&N,5K$\W''`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]S;"YP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#``
M,3`U,34T,S$P-C4`,#(Q-S$R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____U=35Q\;'R<K-^_S^^?K\ZNOMU-77RLO-R<K,
MOK_!Q\G+]_G[\_7WYNCJV=O=S]'3`%F=!5VA!5R>#6>I$&>J&&FG'W&M(7:W
M&UJ()W"G(5^/*7&G+76L*&B:-8?&+G&D,'6H.(*[-'FN.8"W-GFM1I;20HF_
M3Y[84)S63I?/2I#$0G>>4(Z\2H"H7:#248BR79;";*S=:Z?3<:_=`%R?`UZ@
M"6&A'76U(F23+X;$*FV=-GZQ0I711I#%4)S3;JG4Z.KKUMC9U-75HJ2AVMW8
M;J!!?[1/?K%0B+=>C;EE.'4`(TD`.W<#/WD)1(`-2H`72G\7-5P14XT=48<?
M4H<?/V894H4B9)TO7Y,M:Z(U=:Q";Z(_9I4Z6($R8XP[6GXX@+%1@ZY9C;M@
MA*];CKMCC+)HFL)T.W8`)4H`0'L%/WD%2H003H086I(A.5H8:9HX>[!&@[50
MA;-7E<!JQ<C"^?OW[.[JS]'-RLS'R<O&Q<?"^/KU]_GT[O#KX>/>UMC3U-;1
M[.WIY^?F^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8
MUM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````IU%20````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"Y241!5!C3;<$]3@)1%`;0[_Z\&=`1H4`+HXEA"VY`W8T)
MG14E#:%P-ZZ#QFAI#,1&I##1:-[,_9X+T'.`/P0WV/7')8*AJN_'<N?85,WV
M+08Y5#W9D\`Q^:A.VS:;)K>D9P6.QPLVS)*]QT+)*PB,R\H<$>RZXIZFBODB
MWQO($C$SNTT`JJM>O_'1\'"0#NKKO7T(+G<_W[2Z=M/"0CXXUI]!L;:M3:(+
M!AQ?YY3GB=KVJ/#UA"_XQR\T9$U]F9V9U0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1C+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`T-0`Q,#4Q-30S,3`V-0`P,C$W,#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^\4E36
M=G?6>WVP@8+JK*V<453=<W?6>'QP*"VG/4/"8F>N76+:?8*?,SO&H:2XD)6V
MA8UE0$=G14RE>8/*K;:38G.-5VJ;>8B-8W;"GZ_-L<%A5V&PJ+=[=8:WLLN+
MAZXW.6Q05(`1'5HN.G(S/7-R?:E46G0`$U@.'UYK>*@''6`A-WHR0WQ-8:%>
M;Z,*(F0-)642*&44*VX6+6L8+W`=-74A-W4O1H8I/'4N070M/W(T1W\P0W8T
M1WPU2'T_4HA'7)="58Q19:!'6(=5::!!3WE3999-7(9>;98`&EP`&UP`&EL!
M'%T!&EP#'%X#'5X%'V`%'U\'(6(((V0))&4)(F$*)&8-)V<0*FH2*V@4+FX9
M,G(8,&P=-G4A.GD?-W$;+5HF/WTG/7<K1((B-60A,V$O1X8O2(8F.6@H.VLR
M284U38HP1GTJ/6TK/F\Z4HXP0W4^5I(X3H0V2GU"695"6I5&7IE&7IA*89M&
M6Y`]3WQ(79)%68Q)7I-09Y]/99Y/9IY.9)I19YY099Q09IQ-8I9099ED=ZE6
M;IN,A6&OJ(:IF56^JV;HR67@Q&N*@VSNOUG,KF?&KWZZIWSJN5[*FUV*6%C<
MH:#___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````YS5,;````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+Y)1$%4"-=C8,`"
M1&0U>!6DQ;IT?(.B$G(K&X!"PC-8^=AF"HEK!42:9Y0UM0&%N-A9.)B9N/E5
M(F)SG-Q:ZH%"\@(RG'*"4FIA)@Z3)TSQ<`0*B2JJ\RA;24J8ZKI.FS35TQXH
MI&U0IV2L&:IJ8=G>/[VOQ@XHU%F;8N3O9VB66JS?T]NM5P`4ZLB+#O0)B4DN
MK'+QFNANDP44*HD+]@:YJ**AV=G6.CL=*)08[A,8&9]9WMA:75J4GY:$S3L`
ME44P],R#A@0`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O<V\N<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,V
M`#$P-3$U-#,Q,#8U`#`R,3<R,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___\W2UR=MJRINJRUPK"YPJR]QK#%ULC!RK3!Q
MK#)TKS-TKC1TK35TK3AWKSI[M2=1=SU^N#UZL4.$OBY9?T)^M$F(P4V,Q4B#
MN#IGD3=BB$Z(O%:4S$^(O$N"LT!OF4-RG%J8T%>4RC]JDDEYI&"?UUZ<TTM[
MIU^<TU>/P4U^JD^`K&6BV%&"KEV4QE>+N5.$L6BEW%Z5QEF-NUB+N6BDVFNG
MW6^KXEZ2P&ZJWV^JWV:<S&.7Q5F'L%J'L'6NXFZDU&VBTFN@SW:OXW>OXG.J
MVW&GUW>OX7:LWG:MWG:LW6:4OG2HUWJNW&>2N7NNW'FHTHFZYH:UX(N[YW2:
MO)7!Z9.[WX:GQ9V_WIBNPJW"U;/(V[G.X2=MJBMOJQQ&:S)SK#-TK3E]N3=X
ML4B*Q$-^LD^0R4B#MT>`LD=WH5:/P%*%L4AUG%:)ME2'LU%^I6:<RW*MX7&L
MX&:<RG.NXFJ@SW6OXG:PXV:8Q'>PXG:OX'>OX'2IUWNRXH"SX("TX(:XY'^@
MO(FHP[?3Z\+(S>'AX=;6UO___P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$"LC,D````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````MTE$050(UV-@P`(2$J3M0@*,Q1+9N(4D-*VK0$*B!<$-
M-AE)\9P"XDKF%5Y`(<'<P$8G&9Y,>0X163.'&D>@D(I/D*]66EQ3<[*R;I&'
MNRU0R#[$3U_,/ZJ5*2:\V-6MT``H%%QO(\G+$MK>%FE4[EUFD@,4:G22XV=G
MCHB.;;&H=K3,UP8*U68+<[&F5*:KA=6YV^;I9`&%("Y*5;<J=2LQU5-5``IE
M\+&!7>3BZ6QBJ*$HA<T[`,R@*5O\"I0C`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T9RYP;F<`````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C4`,3`U,34T,S$P-C4`,#(Q-S$Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____S`<+
MSQ88BQ,4TB,EV"DJW3(SYT5&QSP^X5!2]EM<]E]@^G-T['!Q_X2&`&T``&L`
M`V\#!7@%!6\%"7$)#7\-#7@-$'D0&'\8'8@='84='X$?(8@A&V8;(G`C+Y@O
M+Y4O-9PU*GDJ-9@U,(4P,((P-HTV0J="0J1"1J9&1J!&3[!/1IU&3ZU/4*U0
M4*Q04*I0$7T0(XLA-8LT-HLU2*I&0YM"4:]03ZE.7GHZ-U4$;:@,=:X0@KD@
MDL@RJMQ2J-A3:J,#-E(";*4&HM5%=:8#>:H(=Z@)@[03@[`;D<`D<Y8C?:$J
MH<\XAZLPFL,[C[4WKMM)G\=$M-Y3KM=0H\L=E;H%I<<9L]<PE[(OH+PUPN1"
MJ\D^R^Q1OMU-RNE5F[P,L]0JP^(^M=!"SNQ.QN%0S^Q5I;<.Q\P(QLP*S-$.
MRL\9V-TU[?%6S,P(S<T)U-01V]L;WMX?Z.@MZ^LRN;DKQ,0R]?5`^/A$S\\Y
MX.!$_OY0__]3[NY/\O)2_?U7^_M7E(LCI8L(P9X(OYT(PJ$3S:\MXL9-]-EI
MSJ04?P``?P,#S`<'S0X.?PH*U"(BIR$AE"DIYT1#G2XNQD%!^E]?_VMK^&IJ
MU')R]Y>7LGEXNX:%\;*R_]W=_>GIZ>GI____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````"-74^```
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"N241!5!C3;<&Q
M30-!$`70F=E_Z_6)D(R`"I`#5T!&/]A=@`CI@@)(:,"!B0F0D)"<64Y`Q][\
M3P'PGMD?;G=:>FQ6[ST+AD4=7F&E--[FS7.-R;UV-]CV$7*VM7L$@'R!W9.:
M<CJ,WZ-'B.:VK,F>U_M+/YZ',W>P!V923^50VQ?Z3(.=)$E7%Z5$B-0;[%.B
M8CP#H%DI@WW\D!Y1$$Z2,MANZC&@MJ',[92S[!^_4M14_##5CND`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W-R+G!N9P``````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38R
M-@`Q,#4Q-30S,3`V-0`P,C$W,S$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````D````."`,`
M``#*2L::```#`%!,5$4``/______________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________]S/I7:`````G123E/_`.6W,$H````!8DM'1/^E
M!_+%````"7!(67,```!(````2`!&R6L^````(4E$05085V-D``)&.`$F(2P$
M#6(R(=BD`B2]")/1;`,3``60`!-WOR^^`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W1H+G!N9P``````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`S-P`Q,#4Q-30S,3`V-0`P,C$W,34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#___\U**=)/+M-0JUF6\9_=-Z*@.&'
M?=QX<+F!>KZGH..&@+:=E]"MI^*OJ>(E%Z0D%Z,M'ZHL'Z0M(*4N(:<N(:4N
M(J4P(Z<P)*@P)*4S)JHZ+;8Z+:\[+[$_,K4[+ZM`-:Y,/\1&.K1+/[Y00\-(
M/;)%/*0^-HY:3LI>4M)52KM=4LQ52[EB5M%63+122:U=4L!93[9L8-MD6<MK
M8-=F6\QN8MEA5\%N8]EQ9MQE6\594*QJ8,IV:]UR9]5P9=)V:]QV:]AE7+ES
M:=)Y;]:`=]R(?N)X<;E]=KZ(@<B7D-9\=ZR5C\R.B<&SK>VVL.W0SO+)Q^?9
MU_G7U?;<VOBHILVEH\AP;X?*R>2AH,>@G\:SLMC!P.6RL=/*R>F4E*W.SLG-
MS<C,S,=_?WSY^?3AX=S6UM&4E)'___OZ^O;N[NKGY^/4U-"[N[CW]_1\)!-[
M(Q/%.1_)/23%/2312"_,3#7=5S^8/BWK:5+;9U+V>6+'8U#(95+!8E#Y@6O(
M9U;0;ESP@V_;>VK0=V:D7E+YDX"N:%OIC'JZ<63&>FS0@W3UFXKEE8;ZI)3T
MH9+^_O[\_/SV]O;R\O+EY>7DY.3AX>'8V-C2TM+0T-#,S,S'Q\>\O+RPL+#_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!!MW$9`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```+A)1$%4&--MSKT.`5$0AN&9V3E[=N.GH1%1
M*+96:*A<C!MP"V["]2B4"HVH)42$E4BLQ<Z9X_0\Y?LU'\`/A!G:.)&7J"(%
M/&=XL"NOA`5J[(WW`B$E=W'U-WNI\$)8"VG397<J2F<Y3NO6'X"@O=+\^1$3
M&9M:K<J0UI-EL1?#1Y-:U!(A`FK:>^S4M`SC^[%MY`1IYS1\C4>#<];;[OI)
M%GXMB,!KX,.I"''*<!-!)L.$E?JPP1]?'K!-P,)IPML`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=6$N<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(R`#$P-3$U-#,Q,#8U`#`R
M,3<P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___T"KS$&KS$*KS$2MSD:PT4:OT$6LS$BMS4NSU$ZVUDNOSE"XV%*ZVTVP
MSS1VBUB^WE2TTCM_E%S!X6#%Y&+(Z%JWU$2(G6C,ZTJ1IV7`W''3\G36]56<
MLGK:^&[&X5ZENW'%WW;,YX+@_H'?_&>PQX;B_X;A_8#7\HCC_XCB_H;>^7*]
MU(C@^X+6\8K<]I#A^H?2Z9;E_Y7D_9GG_REK?T.MS4.LS&"\V&W0[GW=^G[4
M[GW2[)3@]T>MPDRQQDNNPU:ZSUFVR67&VW?5Z6NZRW/'V8;A]'O,W6NQP(WD
M]HC<[H[>[I[H^+S#%[[%&;W$'L;-(]'8,L;---_F1+[$0<C.1^SR5MK?4MWC
M6/'W8NSQ8NWS;^SQ=<S&`,W(`<S'`<['`\S&`]#*!<S&!='+!\W'"=3."M;/
M#<[)#=C2$,_)$MO5%-[9&-+-&.';'>3>(=3/'^CB)J>B&^OF*]C3)["K(>[H
M+[*N([FU)MW7+[RW*/+L-;^Z*L3`+<&^+,?#+O7O.LK%,,W),>'<.-70-=+-
M-,_*,_CS/OKT0MK6.N#;/OSW1N7@0O[X2NKE1O_Z3>[J2>SH2/_Y3_[Y4/+M
M3/WX4?;Q3OOW4?GS4/'L4/WX9/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/+;:<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````JTE$
M0508&6W(L1+!0!``T-W<W>Z12112H-<:E=+__X"2`H4Q#$,DN<MMSO6\\@'\
M0-C`L9STSU<3%%D>T4X#[,O9^]VV`34O\8&@X%-,0SXZK^8WYL;3Y(BPF%*X
MU774UC)K=`<-:QU]-0R89:@4BJ2J8N@E#69I!HF@8=N>ZC9:XLI:YUR`#.*E
M<0,94Q")E]ZGNM8N&*/'.6'7.Y%4]\XK8[A@TW5!4OWQ!<=`4$JNB"%U````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]T;BYP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-#8`,3`U,34T,S$P-C4`,#(Q-S(S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____S,?(P"``P"$`OR$`>!4`PB,#
MOR,#PR4%PR8%P20%P"4%P2@)RBT-PBP-A!\*S"\0S#`0Q#$2QS48QC88C"81
MU3P=V$$ARCT?E2\9GS$;S40GIS<AJCHCXTXOXDXOGS<AL#XFTDLOLT`HYE,U
MMD(JOD<NNT8MN$0LP4DPJ4`JPTLQUU,XUU0XRT\UR4XTQ4PS[%P^RT\V[V!"
MT%0ZLT@R\61&W%M`UED^\V=*VUQ"OE$[OE([]&E-X&!&WV!&Y&1)XF)(]&M/
M]6U0Z&=,ZVE.\FU1[VM0\6U1Z&M0YVI0RUU&[7%7['%7\'=>X'!9]'UD\WQD
M[WUE[GUE]H)J\=W9P28(Q20)R2L-P2H-PBT0TC@=QS@=R3L@WT@KSD,KYE,W
MUU(X[UY"W%I!\61)XF%(]6I/\FA.Z&5,\VI0ZV=.[FE0\VM3]6]5]7]H^JN>
MR[2POQL!P1P#V#HAR38?TD0OZ5$Z\V90\&91QVE;UGQNRWINSW]RRGQPXY.&
M^:B<XI^6WIR3[+"HU*&:W*BAS9Z7S;*N^N3AR'YUU8R#RH9]RHN$\]+.T;:S
MR[2QYL;#S+>UZ]73U-'1^/CXV]O;____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````,.*D4`````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``MC8I&Q#?75%N%DYA214
MS5U`0F)F(?XII='AQ9'B"B;.'D`A`>V`H+2$NL+VVIAX(SM/1Z"0HD^^=UD-
M4T_?U/IR*W=72Z"03:A?4NS$SK:NQK",+#=K`Z!0L+]%7%1_=TM3<T=>CH.Q
M%E`HT$F&OZAJ<NND*065CJ8ZFD`A+V5A#N:(Z@F]#;F9EH8:2D`A/5$>5B[!
MDL34BFQK`W456:"0)"\+.Y^X?'*ZA[V^EIJ<-#;O``"C^2W*>@37W@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-Y+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38U-0`Q,#4Q-30S,3`V-0`P
M,C$W-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!8````-"`,```":>VY1```#`%!,5$4`
M````_P!"0D*$_X2,_XRE_Z6M_ZV]_[W&_\;.SG/.SL[._\[6UM;6_];>``#>
MWM[G_^?O``#O_^_W``#WQL;W]_?W__?_``#_SL[_____________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__]F%TE`````"7!(67,```!(````2`!&R6L^````4TE$0508TV,0Q`+XF!C$
ML0!A!A*%)<"`$X4286"0!`(!7A8.,1#%S"L$XDM"A"59&3E`%!LC.Y@K"E7-
M+012+<0!A%#5/%P\_#P@P`^GN;@8:`D`>J0.G@+];PP`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1O+G!N
M9P``````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(S-@`Q,#4Q-30S
M,3`V-0`P,C$W,C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```!
M@%!,5$4```#____'P\2GI*7AWM_&Q\?&#@#&#P#&$`#&$0#'$0''$@'&$0'&
M$@+'$P/&$P/)%07&%07+%P?'&`G-&0K-&@K0'`W0'0W/'0W&&PW2(!#)(1+5
M)!38)QC8*!C-)QC,)AC;+!W>,"'/+A^C)AOB-2;A-2;E.BNK+"'H/B^N+B.U
M,B;7/2^W,RCL0S7L1#6Z-2K3/3"]."S#.B[`.2WO2#KO23K(/C'%/##%/3#.
M033-033*/S/R3#[R33[<1CC00C700C;T44+51SKW54;V54;;2S[@3T+X6$KE
M4T;D4D;Y6TWI5DGI5TGY7$_Y74_B5$CY7E#Q6T[M6$SM64SX7U'T75#T7E#V
M7U'L75#Q:%W1:V-^2T?VO[K=R<?ZY.+&#0'&$`/(%PW(&@W))AK/*Q_3,2?(
M,2:0(QNM,RO<0SB)+2C024#G44BX2T-]-"_D8UOX;&3C;&/WAW_TAG[ZD8O\
MFI/_[.N<6%7^T,[UR<?2MK7LTM'Q[NY_?W____]3'TI4`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+=)1$%4"-=C8,`"ZO(K6,NCLN0%
M.02DE/1<`H%",1EYL?$!J<(<?.**FD[^X4"A[,R"TAK#9!XN$5EU6^\(7Z`0
M<W19;5Q*(J>0C*J91VBP&U"(J;**I5J2#6B0ODM@D+LU4*BDN"@GG9=/#&10
MF)>C)5"H,#<M*8%;5$[=SCO"Q]G<""@4J2/-#S1(S=0C-,3-QD0;*&2O(,@.
M<I$KT"`K8UT-H)`RT$420(/\PCP=+`RT5+!Y!P"BH25W/GG7=`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W1P+G!N9P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-``Q
M,#4Q-30S,3`V-0`P,C$W,C,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___^7-SR+?X!Z:FU&/4&BGJ"LJJM%0$/5U-5\>GX`
M.Z4!/*8!.Z4#/:<%0*D%/Z8)0:<*0ZT-1J\-1*P02K(84;@83JX=5;LA6K\?
M5+0K8L8O9LHU:\TX:L,^<]1"=]=&>]E-@-Q)>,Y/@=U0@]U0@-A1@MI%;K=<
M@\@K6*67J<:4I<&9JL:DM="*F*ZRPMW!T>O-W/3$TNG,W/2SP=:]O[[V^??E
MZ.8`=```<@`#=`,%>`4%=@4)=@D(9P@(9@@-?0T0?A`8@A@=BAT8<!@ABR$?
MA!\;:1LB<R,A;B$OFB\H>2@UG#4J?2HN@BXPAC`XF#@VD3<TBC1"J4(UAC5&
MJD9"FT)&H49&GT=/L4]0KU!0KE!.J4X_@C]9KEE.E4Y5H%5HNFAHM&ANO6[5
MV-7Z_/KS]?.MKZWJZ^K3U-,E@20VCC5'BT9:HUG9V]C)RLC2CU^Z:SZ.C(M`
M(!221#!Z85N)+1JVBX(Z-32D54BS>&VI=6MO/C=?6%>N4T[-96#0<W!Y%!-/
M$A):'1W;<7!C6EI#/3V4C8U44%!S;V^/BXNTLK*PKZ_^_O[\_/SZ^OKY^?GV
M]O;R\O+N[N[JZNKEY>7DY.3AX>'8V-C6UM;2TM+0T-#.SL[,S,S*RLK___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````U.-:C`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+U)1$%4&--MP;]*@F$4!^#?^?-FHA8$ED/W('1EH0XM@4.;
M0Q'=2$N7$*232X(N04M#H'R@\7WO><_I`NIY@#\(DY/I3?VRK^NL1ZJJ&\;I
M_KKS$-9D41$1`H,\C+@Q4A%A*2#<LB5_-B)B$B=>*-J5'A[OSKRX6:BF!6-Z
MWWTJ%!ZEC$3&"L(LPJLMI[=A+*^L\SH77'Z\KS\'7_5%X/SX)_66BEW5F*PT
MMQ,W._MV,`ZY<.+44LK]$L7QCU_>>5+:P);=6@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=6<N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#,V`#$P-3$U-#,Q,#8U`#`R,3<Q-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\><GKV`
M@\G`R*VGK;:RMKB[OBPP+$Y335)743L_.DI.24E-2&5H9`,(`0\3#2DM)S,W
M,;*SKE153F%B6K"R`&5F`+"R`Z2F`[6W!ZVO#;6W$KJ\%'EZ$:^Q'];8,:2F
M)L?)+\3&+Z^Q+=O>/+F[,\G+/J"A,N+D2MO=3.7G4=K=4-;84-K;7MK;9<S,
M`*.D``0$``("`,W,`<S,`=#0!<S,!=34"J6F"<[.#=C8$(N+"M[>&-+2&.3D
M(;FZ'>OK*]C8)["P(;R\*/+R-<?'+K*R*N'A.-+2-/CX/OS\1N7E0O__3>[N
M2>SL2-760O[^4/;V3OO[4<7&0=O<3^GI6?W]9`D)!104$!P<&"4E(1P<&4I*
M1CL[.#@X-5144%I:5ST].VUM:JRIH[V<7]"=9<1F)Z-2(=9N+^Y^.MMY/OB,
M2NR)3/>04>R+4,]Z1L-'`,1*`\1-"<Q3#<E3$M1=&==A'<U@'Z%,&^%K)N5R
M+ZQ5([A>*L-F,,UM-?*"0N)_1O>,3_&+4/F>:+XB#<,N&-1-.<9(->Y=1]A6
M0[Q,.^EC3O%F4>EK5_-\:N%$-=QO9#PC(4DS,4\Y-UM$0F!)1VM24&M347=A
M7WUH9B@+"2@-"UQ"0HIT=/___P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*8L&-4````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````MTE$0508&66//0X!
M411&[WWOOH<P1J%0Z"02B4*BM0D+FSU8@NBU-B`:C4(D?AHAF#'S[L?4<\I3
MG.0056":TLBSAD+W0S:B=F%)L]OU%&W"Y7STNPZV5Z99,^;TF>80)PWK\Y70
MN-Z]?5L/Y8[<C8&2T$#0`Q*+!+%`2Q6CD`8[:(0:JX*8VA"`O,Z7+S:HO5.F
M\2<K5*QU8A"@X2#4?V>9=^*]YV\(BK^:Y,K&BC-E"`CKR@[1#[G86)GWV'_^
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]T<BYP;F<`````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S(`
M,3`U,34T,S$P-C4`,#(Q-S(R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____T#4VPSH[^KN\\?;VXN?FR```QP``QP$`Q@``
M?0``?```R`$!QP$!R0,#R`,#Q@0$RP4%R@4%R`4%QP4%S`<'R`D)QPD)S@H*
MT0T-T`T-R0T-B`H*TQ`0UA04RA86V1@8V!@8SA@8S1@8D!$1QAD9W!T=VQT=
MX"$AWR$AT"`?SQ\?FAD9I!L;XB8FR"4EY2LKR"<GK"$AZB\OZ2\OKR,CI"$A
MS"LKMB8FV#`ON"@H[34U[#4UNRHJOBPLPRXNP"TMQS`PKBHJ[SHZR3(QQC`P
MRC(RW3@XT38USC0TRS,S\SX^]D)"]4)"U3HZN#(R^$9&]T9&W#\^VS\^XD%!
MX4)"^4I*YD9&PSL[^DU-Y49&TT%!ZDE)^T]/^D]/^U!0^E!0[DQ,\4Y.^%%1
M]U%1]5!0]%!0]E%1[5!0Z$]/T$E)\E=7]5Y>Y5E9^61DRE%1T%14]&5EQU)2
M\V5E^VIJQE=7]8"`^X>'^(F)Z(.#QW!PSWIZW9B8V):6TZ.CR;Z^[>CH____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````10]`'0````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"S241!5`C78V#``KAY="-+<SR413B$Y#1M`A.`0CRJ`26Y
MH3KB'`+2ZJ9^\6E`(5GGO,JJ&!D^7DDE0Y^HU%B@D'DV2V-=@2"GF+R^2WA*
M4C!0B+F"M59%5,U=3LLV*#$YS`LH5%3.5B/!852H`30H/9K)#2B4GU7?4&P@
MJ0@T*"/6W]4>*)1II5!6;0$Q*,3;T1(HY*$BRB4,,\C!VA@HI"W.SB^E;N(;
MEQ;AZ61GIH?-.P"G_R@Y(G682@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1T+G!N9P``````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,3`V-0`P,C$W,C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___]!04(!
M`@,J+"US=WF+C8X0$Q2QM+5,4U43%QA[?X`J+S!065N,E9=X?7YW?7Y57%T]
M149F;W`O,C*2F)A-4%`Z.SLT-36=GY]M;FXV-C63DY*KJJEQ;V["(@#`(0"_
M(0#"(P/!(P._(P/&)@7#)@7")07`)07!*`G*+0W)+0W"+`W.,1#,,1#$,1+1
M-QC&-AC5/!W;02'+/1_-1"??2BOC3B_B3B^?-R&P/2;22R_I5#6X1"SI5SK!
M23##2C'85#C)3C3L7#[+3S;O8$+S9$;<6T#663[S9TK;7$*_43OT:4WD9$GB
M8DCW;5#T:T_H9TSS;%#K:4[R;5'O:U#Q;5'H:U#P=U[T?63P?67V@FJ_'P''
M(@9]%@3$)`>$'0K'*Q'7/2'(.2"]0BWO7$*M13/?7T;+6T;Z<%GK;5?-9U3-
M9E6G7U/RCGW/A'?#?7#NFXWADH6\>F]Y3TC_L*+<GY3.E8OXO+&.;&;LN[+>
MM*S!&`#()`K+,!C4.!_K43G233KS74;=6D7P95#Z?VS;?6_$D8GOO;7>.R:I
M,"&5D9%S<7%E965>7EY145%.3DY-34U*2DI(2$A"0D(^/CXP,#`K*RLG)R<=
M'1T9&1D2$A(-#0T%!04#`P/___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#;'83#````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"
M2GAFB4O)%M6IRZOJ&MNX^0.%XBH%>_N8V+)KE+6-+%P#0H%""6G5HI-GL,OE
MU!J8.?N$^0*%+#-:JX1GSV-F;>NT\PP)]``*>4=G-;<+,<SEZLYK"@KV<@(*
M146X)R<6<,Z9*2)9VI+N8@\4BO0SU8F)+>>=/G4B1V&C@RU0*-Q:7T4AOKY,
M8%*_F$Q^BA50R-%00U%-+ZFA@F_"%`GNXBZ@D(FF@I*6D7EJ9@>_]#26GEQL
MW@$`YZ\Q8P-"D1P`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O=6LN<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P
M`#$P-3$U-#,Q,#8U`#`R,3<Q-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___[QB8[IB9+ER<^R6F/*ZNZXK,*\O,[$Z/[A'
M2]9D:.%M<>5S>.!P==F#AJUL;L*2E-RHJM*GJ<FIJOG;W/7;W*<H,*<N-J@\
M0[Y%3:]!2+E&3K%#2K!&2VPK+\!.5<136M%;8M1=9=%=9<Y;8Y-*3]=Q>-UV
M?=-Q=LI]@>:=H<ZBI>;%Q\BXN9H.&)P1')L1&YX3'9P3'9T7(:4;):@?*:,C
M+)\B*Z8G,;$K-;4O.:@L-<`\1K,Y0L1%3LY/6-!47<!/5Z=%3,-26M1<9=%C
M:]9J<L&@H^[)S./"Q<2GJNK*S9U*5I9<9<1ZAG)`2;"8G<VSN.O3V)UC<:AP
M?I>"A\"KL,"EK+:?I=6[PMK`Q^;,T\:SN.S8WGY8<)J`D8]MAK6AL4U/>Z*C
MM%)5=!TI<$90C"DN2E=@FF1KE:FLO0437&AOD*:LR**IQU%@E6-MD(B0KC9'
M?5QLH6UWF8F3M"`W=B8\>FI[KG6"IA`P=$YFG%1LH5%GEG.$J6AWF(Z?Q-/9
MY^GL\PTN<@XC3BM#<W6+N'%_G)"2EDUDC+B]QD1:?JVXRI^HM\C2XJVQMIJM
MO]'B\<'+T^3O]^?#PGI24L6,C*V#@\REI<6AH?#.SN_0T-+`P,^^OOSIZ?3C
MX____P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(^_JFX````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````P4E$050(UV-@P`+DIW5V5&86<7'DYE1G^;/.!PIE!`@L
MZ"\HY60O+$_49&MN!`JU]B1I3YW<)R&>$LJ_8%)[#5`H+#Q.5T=DEH6YL)"/
M6$QT$%#(6<--QM)8W\C,VM[15=5)&BBD[JY@8V)H8&IEZZ"LXB(K"10*CHKP
M]A"<:2<U6]33*S8R$"A46S=1CSDD6U&I:<H<K82N-J!0??=TN?B**FZ>_)+>
M>2Q^J4"AN4R^R2UI97R\>>G%#1-FJ&'S#@"1.3+P$R&;GP````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T=BYP;F<`````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`,#(Q-S(V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____MWY_
MQ(F+LIFOH8FBN:B\VL7?74ACEGVBB&J:N*G&Q[7;8UEQ?&.EMZS/R+WK;F*T
M;VF:E(SADHO=9F*41D6V.CNV7VG+7XZX9I:]ILSKK<[I<Y^ZE[[6;)^\FLCC
MDK_8H=#L<*2_>*O&E,CBG,_IIM3LD,7==I^QFLWDI-;MJ=KQCZBT=*.V=:&S
MC\+6>Z6V=9VME<'3J-GMH,[BK-SQI]?JH,[AK=WQ;ZB\;J6Y=:[#<ZS`<*>[
M<ZF^<*6Y<ZF]<::Z=*J^>:_#<Z>Z?;/'>J_#?;+%@+7(>:N^?*_!A+C+B[_3
MB\#3BK_2B+O.B+O-C\/69XR:DL;9<)>F;I6CE\K<FLW@C;O,F\W@HM3FE,'2
MJ=GKKMWOJ]CIK]WNKMOKJ-/B;J>Z<*BZ>*_!@;C+@+;(@K/$B;W.A[C(G='C
MN.+P<:JZB[;#I]CGHM#=K-SJ@:BQ@*6HD+>YK]G<LMS?H<C*B[.TBJ^JL-O-
MJM+%N^37ILW`D+*FO.33EKFGO^;0Q.7$Q>C"Q.>_P^6\F[F0J<B=HL"6I,*9
MP>"PI\.4S>JOT^^PZX5LZ8YXE&19YZV@OU`]T650]()LJUQ-WGAF[XIY^+JO
MPVQ?[(5VNH=_P$P]@3,I<TI*____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````_`]Q)@``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#`
M`CAX16<*\/!+R*?8N_EJ%?8"A>9-F#U]QD1F)CTK]T#5_,8RH-#<J?U3^B;/
MF:1OXZ-1U=QC"A028F.?Q<W")Z:<;J#6TJ1D#!1B%1:9)BC.R:7B%Q5KIEY>
M`A22D9;3E964RLL,-X^+5^AL`PKE%&39)N>FIH5$)R1:M%<8`H62(KT<K)T]
M@[)UZKL4&XJ,@$(QWD[6CA[^$2:6I;4=E9IA0*$,5VL[EX!P[9K6ZNZZXM!@
M;-X!`)O0,=Y=#YV;`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W9A+G!N9P``````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T
M-P`Q,#4Q-30S,3`V-0`P,C$W,3$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#___^TFYVXKK32T=*JJ:W`P,;0T-3BXN3/TM*R
ML[.JJZOCY>&$EF>XOJO0U<:7H'^VO*1\AUF+EU.?J6YY?6.RMYC&RK'&Q\#&
MRY_:WKS+SIG3U;?+S+G-S<#8V,O\_/#1T<CKZ^'AX=C2TM#N[NW5U=30SY'4
MRQ_,O`!_=@!_=P#.O@/-O0G6Q@V+@0K,O!#AT1V=DAG>SR?2Q27NWR^GG2'A
MU3C'O#O&NSOZ[D_QYE#]\63X[67,R[[,R[_U].C__O/,N`#,N0!_=`#-N@',
MN0'.N@/,N`/,N0/0O07,N@71O@?-N@G4P`K.NPW.O`W8QA#-O`_/O1+/OA+;
MQQ30OQ/-O1?2P1B4B!'6Q1ODT2'4PQ_4Q"#8QR?=S"_HV#.RI2KAT3CATCB[
MKS+RXD+GUT#GUT'LW4CQXE#4QT;VYU?VZ%?ZZU[IVUG][F3_\&CWZF7_\6K_
M\FJQJ(*=G)OIZ.?2R\>ACX:RJJFPF)CNZ^O(Q<7^_O[]_?W\_/SZ^OKY^?GV
M]O;R\O+JZNKEY>7DY.3@X.#8V-C6UM;0T-#.SL[,S,S*RLK'Q\?$Q,2_O[^\
MO+RYN;FVMK:PL+"GIZ?___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")B1;6`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```,!)1$%4"-=C8,`"M%V,+(MSDDWL>[HZVIKK:X%"6I$I
MA;GI,>%VW9WM90V,C4`A_<2\_(PX?P,Y=@D^`7X>5:"0659!9GR(1Y`BFZB0
M"*^P+%#(HB@[*<+;*4R>@U.P1$Q<!2ADFYL6Z^OL'J4L(ZU>P<PZ&2ADDQ$7
MX.;J9ZPD)5G.5%G*#12RC@_V=/8)37"HK:NNJNF?!!0RC_!V]@J,3E6H;6IE
MZ9LX!2BDH:NIHV=H:N78V*+6.X%K*C;O``!(?B_>QXU^(@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O='<N<&YG````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C$S`#$P-3$U-#,Q,#8U`#`R,3<R-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```&`4$Q410```/___\(!
M`\,"!,(&",<("<\1$]\='M4U-LE#1M]H:JD$":D%"ZL+$+80%;0B)M]@9.KH
MZ;BMMS,1."L,-#$4.IR/H#PD2B8--JRGL8V*D)"$GC0B2E-#9U)%8H)TE"43
M/C$G/UY/<FYA@')K?$8W7%=*:Q(')1X,/8%XD$$X4A0+)AL1+RP>2D`Y3FUB
MA#(I2`\')"481UE0<#4J54Q#:XV&HQL20O7U],P``,T!`<P!`<X#`\P#`]`%
M!<P%!=$'!\T)"=0*"M8-#<X-#=@0$,\2$ML4%-X8&-(8&.$='>0A(=0@'^@F
M)J<;&^LK*]@G)[`A(>XO+[(C([DF)MTP+[PH*/(U-;\J*L0M+<$L+,<N+O4Z
M.LHP,,TR,>$X.-4V-=(T-,\S,_@^/OI"0MHZ.N`_/OQ&1N5"0OY*2NI&1O]-
M3>Y)2>Q(2/]/3_Y04/),3/U14?9.3OM14?E04/%04/UD9/___P``````````
M`````````````````````-U*<:<````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````I$E$05085VW.NPW",!2%X>O'O0XAD4#*#DS`*#`%R[`!
M:]%"@U"@2>1G;..@='#*K_AU`'[&8">%-AW=7GM4U&RJ,X=:]YT9<DH"4;4*
M@4-8Y:L4*3-"W"JT($&*9H@*)4=LB:(O]&;29Q\"D_6:F`F%>G*4$N-L#NG+
MH=#)W$>3*U)S*!RGDL\/[1(MH1A\H>?H)L1OR`878Z&7]<LC:Z=8Z,\^C6U(
MK:U(5&8`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O='HN<&YG````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0U`#$P-3$U-#,Q,#8U`#`R
M,3<S-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___YB(CXI_DW=JA%10CUY;D&IGIFYKIF9EJF9EIRTM9#,S:S4U;3DY<CL[
M=#T]=S\_>4)"?4%!>T1$@$='A$9&@DI*B$E)AEM<H%14DF1EK%=7EEM;FF%A
MHV1DI5)5ID5'B%=9JE%3FU16GF!CKV!CKDY/C0E/(5F2;"QJ/VJ<>25C-U6-
M95"'7A16)"E5,Q(\&R-@,!E$(B%,*DN!5D-Q34]^66>;<G&B>VZ>>'*C?7.C
M?0@Q$#)?.T-Z3CMH1&&4:V*1:VV?=S]V1A\@'R9=&5J&3#MI(XRM=5-L$XN<
M3G-\(!H:&&UJ#'-O#Z>@4(=^('=A!Y%Z(@P*`W)8!2TG%*V848EW1G98#55"
M$)AY*GAA)Z:+1&14*[B<5(-U45@]`DXW!54_$*F%-;.43\:G9*R266%:2CPX
M+UI74#`B"3(E#4D_+QL0`)AY2;:=?!82#:.*;*B2>1(."D].33LY.`(``"(A
M(5!04$]/3T9&1D)"0CX^/CHZ.C4U-2\O+RLK*R8F)B$A(1T='1@8&!04%!(2
M$A`0$`T-#0H*"@D)"0<'!P4%!0,#`P$!`?___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/M\HW(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````ODE$
M050(UV-@P`)L;4W,;!SMC33<_),KZJLK04+&#E86ICKZ7D$Y+0TU55E`(4,[
M)V<]+0^_Q)+6QMK2A'2@D(&YI:Z+3VA>3UM3749\,1M0R,Q:TSTPJ;RWH[D^
M(HU961$HI&WA'9S-T-?9DAE;P*$B+@(4\@R(*>SO[_*-2V52DU07$P0*A>>V
M]S'TA$47L:O*28D*\P&%REI[&7JC4EB4I.5E)(3X>8!"KMT,(9'YK`J<7++B
M(@*\W-B\`P#BFBV6Q!N2YP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]V92YP;F<`````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P,38`,3`U,34T,S$P-C4`,#(Q-S$Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____PS%"K`$7K@49L@D=LQ0GO18J
MRR<[HR<VKBX]V3I.N#1$R$!0XTQ>UTU>XU)DV5)B$AJ:&R.<,CJY,3>:0TO&
M353"3E7!6%_2#!69#QB>&"*H'RBJ+36J.$.\1E#3-SZD.T2G/T>P3EG0:7#5
M:&_3#1NG%R6E'2NT'RRK("ZJ*CBT,#VG-#^O-D.Q15+,0DW!1E/$4%S74%S1
M5V+27FK6:G3=9G'6"!FA$R*4%B65&BNE&RF9'"N;(3"H)#.D,D3$+CZP*32!
M05##04_`.D>K153`2%6R56/+86_<5F/#6VG,6V?$4UZL=H'3(S6H87'9QL@3
MS,P`SLX#T-`%S,P%S<T)P<$*O[\*UM8-V-@0PL,6TM(8X>$=@X(1Y.0AU-0?
MTM,A[NXO\O(USLXOW^`TX>$X^OI"_/Q&Y^=![>U&__]/_OY0^?E0M+,[]?55
MX^10]O97Y.11\?)9^OI>__]J\.]L:V<`:&8`UM)EB($P7ULPNK)A/CTT1#(3
MS```S@,#T`4%S`4%S0D)U@T-V!`0TA@8X1T=Y"$AU"`?IQL;L"$A[B\OLB,C
MO"@H\C4UORHJQRXNRC`PX3@XU38UTC0T^D)"_$9&Y4)"ZD9&_T]/_E!0]DY.
M^5!07EY>____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B`BR[`````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"G241!5!A798_+#L%0%$7W>=Q6@@81<Q%_
M:.([^#XC(HAG4:U[[L'8VK,UV5G`'X1Y9F4>'\_:.`L:=,%PG[3]U31&042%
MP-C:RN+[S2&U?@0HUF=*=64D?`DL;A"0WU;[6)Q>Q7'CF^:V4XQ2[S$8[B+;
MN-X7YB!,R^Q..7'%TKUVTOU`Z%\U.3.)L*?O*L*RC,8J>4LI6C2;,9[V>]-<
M^"O<_3\'^`"<?%A)LMKIZ@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9G+G!N9P``````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,3`V-0`P
M,C$W,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____<H**]5%N<45;5<WC6?(&*5UK(IJBG-#W<<WS(:&^O8FG7?(/HIZRP
M@H:H.T=P)R_;?XBZB)#.K[1E0DJH?8=D1$RUF:"?:GB=87*<;WZZG;#-M,65
M>HUE6F*RHK&\LL@O(UB1BK!;5GU`/&]X=X@L,&<]0W4G,G`Y17TT1(1"4I1,
M7)]N>JL`$UP=,GH9*FDO1(TJ.W@^49DX2(-18Z1K>:L#&F(*(6T-)&L4*G08
M+7,A-X`A-70O1(E"59([2GD\2WE>;Z=D=JT`&6``&F`!&F$#'6,%'V8'(6<)
M(F4*(FD*(V@0*7`1*6T8,'`=-GHA.GXA.GT;+5XF/X(G/7LK0X4A,V4F.6PH
M.VXU38\P1H(K/G0U38XJ/7`M0'8N07<P1'HZ4I,V2H%"6)I"6II*89]&6Y-%
M69%)7IA(79=/9:).8YY09:!099U4:*-27'<`&V(`&V$!'6(#'6(%(&<%'V0-
M)VL0*F\2*VP4+G,?-W4B-6<O2(DP1'DT28`X3HA&7IU&7IP_5(M/9J)09Z-0
M9Z)09I\;.6UF<H<K1W9/9HQC>J`V6X%<AWZ#C8AFC&UOE'%,BDIEGUELB&5K
M<VFFSXZ%MF2,P&J!OE5\ME"LS8JLTWZ4N&6!C%O___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!/WKTQ`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)
M1$%4"-=C8,`"Q.4+>11E1'I]73W]@J*;VX!"HNS\0GQ,PI+J%A4&]JFM'4`A
M018V+E9F`4XER\[)4_K-LH!":ARRO`H2TAK^UMVSYT[2;0$*B2F;<ZO8R4EI
MVO;-F#-1IP$HI.><J6JH7Z9E;-0S<_I4TWJ@D$MVF)5[B8]-N,F$>;/F.\4"
MA?)CJDJ+O*I#D],+NJ8Y)D0"A1H#RMW**X/CFMIS';03HR*`0C7>Q1X5@75I
M.7D9*4GQM2'8O`,`%C$RGX,2GRP`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O=7,N<&YG````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#,U`#$P-3$U-#,Q,#8U`#`R,3<R-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___\%A8\9G:,5K;<]R=-R!@].!
M@K!L;>J1D\9]?M:,C?.@H?.CI,--4KY:7L!B9:YA9.Z*C=%Z?M:!A.B:G+I)
M4+M25[U46;916,9=8L%@9=)L<:)77.!\@;EJ;NZ3F.:.D\)S>;=H<+V"B-*G
MKEQ3J2<>A#$HBEU6JF)=G"8B8TM&GW=RP8N&S1T:6#8RE5-/F61AMV]LOH!]
MS8%^R8F&T!035QH86"`?:3(P=#8U?4I)IT9%D%M:IVQKP7-RO7]^SST]AG%R
MR&9GHW%ZN*6LWZBOX&!KKHR5R\MH8LQH8\QN:-:`>^N;EL>#@?NPK<,S,\4V
M-L@[.LT_/]A.3LE-3,M14>9?7]5=7?)P<,]B8N)M;?=[>_)Z>MAP<.]_?\UO
M;^:`@-MZ>OB,C.V)B=9[>\MV=?B0D,-R<<YY>?*0D-!]?>.+B_>:F?*7E[MU
M==V,C+MW=\>`?_";F]2+BL6"@NJ=G/BFILR)B<6%A,.#@^F=G>B=G<R+B_2G
MI\2'ALR-C?6JJM:5E=^<G/BPL.^JJM>;FN.DI,R5E,>1D<:1D:!U=<J5E:Q_
M?_&SL^6JJM"<F\22DKB)B=.>GLV<F_*YN/B]O>BQL?6]O.*OKM^LK/;`P/&\
MO.R[N_?(Q_K+R____P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"D`Y7$````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````MDE$0508TV7/O7'"0!`&T&]_[E:')`:&
M,23.';H75T`!!`2,(U?C4IRZ"@\1D1G02&#I]EP`KX,'/""\)CXWPVUW)S83
MHJVB(JG;\^G+B4E8"(INX_??N)Y>9!:LXO*I6$P24G^Q'Q95S0Y%+W6?2[L,
M(=9"_@?%NLBS3-^=2AK(<X$B>1&WMV"FYC<O`#Y,%RPAIJ9]JF?["H15-7%A
MYFY.UWF^-$?%^S`6BRE&RF.FT0^/'_P#H0,\OO_$$'@`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]V:2YP;F<`````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S$P-C4`
M,#(Q-S$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____QTQ/OF-FQE1>7BD^;CA7:#!5>#YIS\[/X^/DX.#AQL;'%")P`15;
M!QUG!1]EV.#JHKK4TMKCEL+MFZ.K6*'B>+GSI<[UH;[8N]KX@I2DN<[BO<?0
M;*?8=JS;992[:YO#A[WJCZ6WT^;VL\+/Y.KO996[=ZW1O\S5Q\K+RM'3R\S,
MLK.SMM+1;X!_I<JWT]O7XNCEY?'ILL*VJ]2R)I(S3:91`)<`%I,6'XX@U-74
MC:^+<:A?J,F=QLS$FKN"B[1LI\!TOLR:X^G2J:Z6D*@LGZX]MKV'YN^)X>:4
M[?&MEYX3GZ4NYNU&O,$_K+(]]OB\Q,:7PL0`A(81U-DU\/10Z^U-ZNQ/O<!`
MP\9.JZQ&U]A:Z^UDY>AD='4ZXN-UZNU\W^!WZ^R*U-:$\O2<Q\B`Y^F7UM>1
M\/&Q[_#!L[0%Y.4KT-$O]?5`[N\^\O%,X^1(W=U>P<&&>GIDX>'#]?7:UM;)
M\?'ISL['\?'MG)R9W=W<]?)<J*=S>GE4OJ\JO;%!L:A=[NWCYM6-TM'-OII$
MBXJ)U*B!L5X9TF!/RE93]O;V\?'QX>'AV-C8UM;6U-34TM+2T-#0S\_/SL[.
MS<W-S,S,RLK*Q\?'Q,3$O[^_O+R\N;FYL+"PIZ>G____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````P`S?0P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!
M241!5`C78V#``NI+JGD8>[B#BG4F]W-5E04"A>)#HM,S2R=&!E>69R3%120"
MA=KK8F(+HT1]?5P]<O+#DYN!0M)"+D6Y`0)\_+SZ>05>:I)`(04)4UO_;%9V
M-HZF,`,1846@D)*4G95-6B=3=U>+L9B<K#I02$70WM+,O8&9I:-63UY32QDH
MU%O#:6[AEM+8YNGMI#UEUER@4-^DZ2:.#LZA?@GB&JTSY\P#"EE/FSYU@J%1
M5FJ%C.J,V;KSL7D'`/OV,D@/-2*$`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W9N+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`T,P`Q,#4Q-30S,3`V-0`P,C$W,C(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____0-3;#.COZ9VC0U@W9WAC;
MX!WEZRO*QP73SQ#IW"_(K0/6N13YWDK&IP#?P"'LR#7'G`7,H0?SPC['@P#.
M<@K(8P'B?";'2@'U@D+WAT;O=SK'-@#-2AC?42'Q>$[Z<5#3,!#X;%',&P?'
M$0#(%PG8-R_O1#K*&A+6&13B+";'``#&``!]``!\``#(`0''`0'(`P/&`P/&
M!P/+!07*!07(!07'!07("0G'"@G."@K0#0W)#0V("@K3$!#*$A+8&!C.&!C-
M&!B0$1'<'1W;'1W@(2'0(!_/'Q_/("":&1FC&QO3)R?E*RNL(2'I+R^N(R.D
M(2&U)B;8,"^X*"CM-37L-36Z*BJ]+"S#+B[`+2VN*BK),C'&,##=.#C.-#3+
M,S/S/C[0-C7U0D+5.CJX,C+X1D;W1D;B04#;/S[B04'A0D+Y2DK#.SOZ34WE
M1D;J24GH2$CZ3T_Z4$_Z4%#N3$SQ3D[X45'W45'T4%#V45'M4%#01D;R5U?Q
M5U?U7E[E65GY9&3X9&3T967S967[:FK___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````">2[G.`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+Q)1$%4"-=C8,`"]/2]\]KJXIW,=4SM
MW</22X%"^BYIK0W9GFJJ1C:N`2G%54`ANYC&YB)?6TEQ:T>_I/S*0J!04"U+
MC;JFB:BPEK9&;D59%E"(N:T^7DZ(GY-+0%"ZM#PG`2C4TI#I927+P\K.+552
M5<`4!Q1J`AID:"#&QB&27UV8&AL)%*H)<3#64>&5D.%3+LM*C`X&"L4[6^B:
M*<F'9R@JY"1$A?H#A3PL=8QLW$`N*DB.BPCTP>8=`)9$+7":)4+B`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=7DN<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,Q,#8U
M`#`R,3<S,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___^3H\]#1U(F9P)VMU*R\XK_-[Y:<J\K2Y<3+W'F.O(67OY6IU(^A
MR7%_GH^>O[K,\Z*RU+?([;G*[YRIQ<+1]*"MR9ZJQ:>RS+?"V\71ZZRVS;G$
MW-7@^:BQQ=3>]<'*WL#)W:NRP;6\S-OC]=[F^':-NW>.O'Z5PGR2OGZ4P'V2
MO("5OX><R(NAS8.7P8:9P8ZBRX^BR9RPV9"BR'J*J:2XXJF^Z(24M)>IS*R_
MYY:GRK3(\*B[X+/&[;C+\:J[W[K,\++#YKW.\9NHPZFVT:*NQ[;#W:NWT*:P
MQ-'=]JJTR,?2Z=?B^+2]T+"YR]#:[\_8ZJ&HMM??[[>]R<'%S>?K\\3'S=37
MW>[Q]_S]__CY^XVBRIFPVH*4M8N=OZ>ZWK/'[:^YS,?/WKK`R[S!RMC=YLG-
MU-38W^[R^>SP]\+'S[W"RLS1V=G>YNOP^,'$R:^SN<K.U-#4VO/W_>?K\>;J
M\,/)T<#%S/#U_.'F[?#U^[F]PM_CZ,C*S/3V^.?IZ]K<WLK,SLG+S>SM[M?8
MV-W6NOKTV7]U5O_UU<:_J8M]5G]U6*>;>)V2<O;HP.OAQN'8OJ^*+I)S)[B4
M.?S4<-*P7OG2>._/A/;8D>*W7<?&Q-+2TG]_?____P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````)N<6EP````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MP4E$050(UV-@P`+F]?9W,S))24J(BKMY2'O+`84ZITR=U<%IRL)CR,?*)B+&
M#A3JF3Q[QL2VYOH6YJ;&ANB85J!0W_1I,]MEN'4,C$RL'9R<A8!"<[HF3)H;
MZNKN*>NKX!>HF`P4RBY(KTA-J\S(K,XJC:HK+@0*N23&:JEK:.K'6=@FV5DE
MQ`.%RDK"<G-S\O+#JVK*(R-JBX!"7`'R7C[^2D&J:B$I*LK!'$`A8UTM;3U>
M<WM!84<;`4LS?FS>`0#O8S&IIS^),P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]W<RYP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P,3<`,3`U,34T,S$P-C4`,#(Q-S,Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____VAT>T#4VMP`.N`$/N`43
MO`<5O0T=Q1`>T4%.YEYJYF5QLP`1M`,4LPD9N2`O&06Q#`&Y#P6[$PFZ(AC!
M)1O!0CJ[85GG<FKQ9EW2"@"]"0&\>WKR``!]``!\`P/,#0W-"@J('Q_3'!R:
M*2G3(2&G.#CA+2V01D;35E;H2DJX9&3X1TBN:&K]:6GU:6GS?7W[<W/E=W?B
M?'W#$A7.043;B(KPRP``QP``Q@``S0$!RP$!S`,#R`,#Q@,#RP4%R@4%QP4%
MS`<'R`D)TPH*T@H*T`T-S0T-TQ`0RA(2V104UA04W1@8V!@8S1@8W!T=VQT=
MXR$AX"$AWR$AT"`?HQL;XB8FUR<GY2LKK"$AZ2\OKB,CM28FV#`ON"@H[34U
M[#4UNBHJO2PLPRXNP"TM[SHZR3(QQC`PW3@XSC0TRS,S\SX^T#8U]4)"U3HZ
M^$9&]T9&VS\^X4)"^4I*^DU-ZTA(Y49&ZDE)^D]/^E!0[DQ,\4Y.^%%1]U%1
M]%!0]E%1[5!0_61D____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````97%I=`````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"H241!5!C3;<P[$H(P%(7A2R3<FX`.
M-)8NPC6Y!I=@[1JM*!A'D$?(X\8PEGK:\\T/\+,,3IFL0Z>?_9F4WM?Z)B!3
MZ/GH(TM$.B@).>RDM#PSITLU*%<0D'M?5G740JH]4;!)]2(*'V@6J,LB&I/4
M-`SS:M_+FI!T=T[J.CY>8]14-8C&7%Q2L1V60*A3R%G/6ZOMC:."OB'K0E+=
MM.0%X1:RS,'#GWT`9#U.K7;&=WH`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+WEE+G!N9P``
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,3`V
M-0`P,C$W,3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____5U-7'QL<B(R/4U=7!PL(?(!]]?GV"@X(V-C5M;6SGY^;-S<S?
MUM//Q,'3S,K,P+W"(0!Y%`#&)07#)07/,!#!+0_*-AC#-AK;02&7+AG20B7I
M4S7.33/?5#C94SCT9$:J1S/`43OM94KW;%#N<%?E;%3B:U/Q=5SX@FK@=V+T
MA&[]\_'\\O#QY^7^]?/QZ.:_'0!Z%`!X$@#!(`/!)`G)*0W`+`_(-!>,)!'5
M.!V%)1/).1_B2B_O7$*S1C+<6$'T:$_O:%#U<EGP=%[N>F70Q,++O[W:SLSG
MV]G<T<_TZ>>FGIWX]_?^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;R\O+N[N[L
M[.SKZ^OJZNKEY>7DY.3AX>'>WM[:VMK8V-C6UM;4U-32TM+0T-#.SL[-S<W,
MS,S*RLI_?W]\?'QO;V]A86%@8&!=75U86%A145%04%!/3T].3DY-34U(2$A&
M1D9"0D)!04$]/3T[.SLX.#@U-34T-#0P,#`O+R\N+BXJ*BHH*"@A(2$='1T;
M&QL8&!@0$!`-#0T)"0D%!04#`P/___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#BO.<T`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+])1$%4"-=C8,`"C(6EE;74%"1$A43$I&0558%")E8.;JZ.MF9&IN;6=O9.
MSD`A&R5M'0TY20MQ2QEY%1=-=:"0KX"!OC>_AZ"[IY>/KIXA'U"(F3$L+B4C
M(S4Q-CS0/RPF!2CD%\S#FIZ1EA07$<P8$LV4"10*B$Q,RTA/CH\*90R*2.!E
M`PIEY99555>6YN=P<&9SYQ44`H5JVKL9NCM::LN+2BKJ&IM;@$+L70P]G:T-
M%<5%Y5SU32QMV+P#`/Q*+2HF'D7T`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O>F$N<&YG````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0V`#$P-3$U-#,Q,#8U`#`R,3<Q-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___\H3%.%B8]1H:MYP<NN!
M@OB1DO^<GNZ3E?N=GLUW>O;4U3LZ.[[&_K>^\D)>]U!I^F!X^W2&[I2=S[S%
M_2$WK2@_N"Y&PS1-ST)<X4]L^DYH\H&*N8N4Q**LW[.]\ALUI"(^KRI&NS!-
MQC94T49EYE!O]<#&V]38YWB-@LS9TH6;CY*GFIBJGZ[!M;'#N**VJ:FZKW>.
M?CM90!P['TUA3P`D```C```@```7```3``$A`0,F`P,D`P,?`P4J!04D!04C
M!0<E!PDL"0HM"@TS#1`P$!(P$A$G$1@T&!T]'2$^(1\Z'QDM&2=!)R])+S51
M-31,-#)(,C!%,$9B1D)<0DAD2#9+-D):0E!J4$YG3D9<1D]G3U!G4%YV7F5]
M961Y9+F]N0$=`!(O$1TZ&QP[&#-.+TUH24%7.@PK`6EV89:FC9>FCH.2>8N;
M@7R*<XV;A')_:7N(<KF_M'"!62]&!4!6$CU4`"LY`)&@4(N9.'B&#8***IVC
M&+.Y+ZVR">3E:&]N"K6U)XN*(*ZM.+NZ4(R,1FYN5TQ,0",C(8&`2,<``,@#
M`\L%!<@%!=`-#=,0$,X8&-P='>`A(>DO+^TU-?5"0OA&1OI/3_M04/504,>H
MJ&9E96IJ:F1D9%Y>7O___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-#1?BL````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````OTE$0508&67/L0X!01"`X9VY67OG
MB$9)J$1$:'02CR-JG6=0H)-X!YU*IU+**54*(0[=Y7;%W=C3^LMO,I.,$'^!
MZ'/Y%IWC69*@XR#BD,3@(%OL=B?Q%!%L@H37TX^X<JR-1QD@6W(ER>?9[2R;
M0"G@)P!17-P3HW>NDG8&J5F3F",P8BY')!6DC'81P[=Y!1Y550+$:"Q=C=[K
M0MW;7I3/43X['X4GXS?\E>.H-Y/)*(AUN[0)P2OPK[]O+'P!M@%(A*&WGJT`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Y=2YP;F<`
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#(`,3`U,34T,S$P
M-C4`,#(Q-S,S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____U=35Q\;'W.+RI*R_N\/7M;S-U-SOS-/D`"=Z`!A,!"I]!"I\
M"2Y^##*$#"18'4*2+5&?0&.N06"D3W"X2VJM2FFK4'"U4W.X98+`G::[HJO`
MK;;*B(Z<NL'1U=WNS-/C`"EZ`!E,`RI\!2U_!2U]#32%#S2"$#B(&#V($2I?
M&D"/(4B6'T*+&3-H*4N2+U2A-5JF*T5\.%J>0F:P,DV$1FNS.E>/3W&X4'.Y
M5W:V7GR[6G:P98&\:H?#R=+EL[K(U-75Y^?FV-;5P+Z]I"D`I2L#IC`)KC4-
MN40=L$0?BS<;ED`CR%8OH4<JK$\PM58UU6="R6=&W')/UW%0JUU%S,G(^O?V
M]O/R[>KIZ^CGZ>;EHB0`IBD%I"D%L#00K#D8O$0AJD`AJD(CDCHAKT8HGD(H
MRU8UJ$DNN5(TL$TQLE`TOU8XUV=&Q%]"QV-%VV]0U&M.H%0^OV9+U718M61,
MQ7%8WX-GUH!GX(=MUH-JTL[-S<G(S,C'R\?&_OKYW=G8U]/3^_CX^/?W_O[^
M_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.
MS<W-S,S,RLK*____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````2Z7.2@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"[241!5!C3;<$]:D)1$`;0;W[N>XKA8;`2M!`+.Y>6SLHJ".)^TL7>K"!@
MHHB(A1H0,4;4W)F;!9AS@#N$-A[*>;R>8Q35$&3"V)3RS#YNZS7S1H474(12
M/K?&)?%7DU:L#D91O.6']^^B6GQV?RJ',@CBHTP49AYC4@U/C.?AZXO`/9GU
M17H!A,&T\\O)P\PZ4][5]F/%I;Z])M&L+K>6-Y;=L>)X<B>+[D)F]GB$8F%.
M3*I,[BEYPC_^`/M+4G<4[1MG`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V%F+G!N9P``````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`T-P`Q,#4Q-30S,3`V-0`P,C$V-S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#____5U-7'QL<B(R-45574
MU=6XN;D`6P``.0``.``%8`40:A`12Q$==!T22!(A>2$951DOA"\UBC4XB3DX
MA#A"E$(R;S)&F48R;#)!BD$Z>CM)ETE0GU!/G4]0FU!7HU=3F5-2EU)7GE=;
MHUM>HUYEIF5JK6IAGF%MK6T?(!^?HY_S^//H[>C6V];2U]+T^/3H[.C,T,SV
M^?996EG0T=`0:`T;;!@[?S<07@4?9A`T<1\O:QF]PKHY:A9'<QE-;!)#7@-(
M8`E#5P`Z.CGGY^;$Q,/DX]*^MI(A(!VOG7*VJ(5];4M:0Q5\937"HF&)=U*Y
MI'L[.34R,2^^O+@P)A1-/2%E42R3>$:LC%*3>U"WG&RVG6^WH7C4NX[ERYN\
MIX+'LHSNV;%G7DZ^KI'DU\#EVL7`G%^[FF:ZH'9Y:E'9OY3JTJO@R:3*N)K+
MOJM.24(;%A#BVM!,249245#X]_?^_O[Z^OKY^?GV]O;T]/3JZNKEY>7DY.3B
MXN+AX>'2TM+.SL[-S<W*RLK#P\-/3T](2$A"0D(\/#PX.#@V-C8T-#0P,#`O
M+R\N+BXJ*BHH*"@A(2$='1T;&QL8&!@/#P\-#0T,#`P)"0D%!04#`P/___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"'E#XU`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`".#D%I=651<TM
M.;AY!(0E9(%"7+SB:JI2UD[.CF9\0F)R\D`A?DD-324+.RL;!WL1&0451:"0
MMI&QH;ZWEVV@A[^[@8ZN'E"(F;&ROB$S(3^O*#>GK+*F`2A46N[*UA03G9B>
M&I]44<W4#!2JJFML"4F)C,V(RTZK-75C!PJ9N$R:.CW4-]PG((NUK:.K%RC4
M.64FP\S",+^(J.2"[KX)$X%"6C,89DWS#&YO+2D.ZNEGF8S-.P"1LC`[PE*8
MEP````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92\`````````
M````````````````````````````````````````````````````````````
M`#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q
M,#8V`#`R,#0S,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+VUS97AC96PN<&YG````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`S-C``,3`U,34T,S$P-C4`,#(R-3<R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`0#````[=WB4@```!A03%1%A(2$____`````(0`QL;&````````````
M7'!?*@````AT4DY3_________P#>@[U9`````6)+1T0'%F&(ZP````EP2%ES
M````2````$@`1LEK/@```%U)1$%4"-<ERC$.@#`,0]$4([%BE1-T84V/`,J!
M*C'D^B3MGZPGBP^)#A<?C#8759[*<@M0`+8F72-[7ODJL#.&!]D4!*6H]O4!
M@LB4H)[GP8HRQV6/+<ER6):CS7X6"!?/#3/"*`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]O
M;V]?=W)I=&5R+G!N9P``````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S$T`#$P
M-3$U-#,Q,#8U`#`R,S,R,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=
MXE(````84$Q418"`@````/___\#`P```_____________VQ_OY0````(=%).
M4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P```$@```!(`$;)
M:SX````Y241!5`C78RAG``-QAG(F)2!0AC(8F*$,)C##Q<4)+@)1XP($SN@B
M3LH$U3@IH:AA-@8!($,0#,0!FX$4[.R<8@,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O=FED96\N<&YG````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,U,P`Q,#4Q-30S,3`V-0`P
M,C(R-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````#U!,5$4`
M``"9F9G,S,S___\```"I?@Z8`````7123E,`0.;89@````%B2T=$`(@%'4@`
M```)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03#"C8D"./````54E$
M051XVDW,T0V`,`B$X1NAU2X`L@$+:'O[S^1I6N/_](4``*HJ4'MFVL)1)LB)
M#)2%:CK*&FC=NUTM<))N(P+8W(V:H'F_!@6JH:OOSP_:=G_`MQMG4Q%?H/RN
M'`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M:6UE+WAM;"YP;F<`````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`T,#,`,3`U,34T,S$P-C4`,#(Q-S,P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`0#````[=WB4@```#!03%1%@("`____P,#`````
M`("``/__``"``(````#_````````````````````````````(0U&O0```!!T
M4DY3____________________`.`C71D````!8DM'1`\8N@#9````"7!(67,`
M``!(````2`!&R6L^````4$E$050(UV/XP``"_/\9/@B"@`*,H<@/91@;`QF*
M(BZ"BL(,'T03'4,24X$,-4%7]T0Q99"(2P581%!1+`VL!JQ+$,1P`0)'`B)0
MQF=C"```4UT@!ZCE6@@`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O;6EM92]O;V]?:6UP<F5S<RYP;F<`````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,S0W`#$P-3$U-#,Q,#8V`#`R,S0W-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`$`P```.W=XE(````84$Q418"`@````/___\#`P(```(``@```____
M_]`NP0`````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9
M<P```$@```!(`$;):SX```!4241!5`C78RAG``-QAG(F)2!0!C*8C4$`R&`4
M!`&0E!!02AC,<'%6A3",C5*A(F:B8(8P4!.8`=($9B@I"X,-9%)2$(`R#`V-
M(`QA92$4NP0A=@$`2YT3$4_`"FT`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M<V]U<F-E+7!Y=&AO;BYP;F<`````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8P-P`Q
M,#4Q-30S,3`V-@`P,C,W-38`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````8%!,5$4A(0!"0@````![>P`Y.0!C8P![>WL``/]:6@"$A`!">P!C
MG``AW@``_P``>P`A6@``O0``.0!"O0"]```Y```YO0`AG`![``#_________
M______________________]ZPAV+````('123E/_____________________
M____________________`%Q<&^T````!8DM'1!\%#1"]````"7!(67,```!(
M````2`!&R6L^````E$E$050H4U7/P9+",`P#4$7!["IQ6Q*@'/7_?\FA909T
MTSMX+-@&"OP);-9+#7[#M?Z5'ZC_-<"3P")):A'''90(J>>R2K1M;+WWO(U<
MI6+;&)DYQAQSGF#>'UL.9A<.N#]S)?:NXQ>\7B3+\NF$'T9+*4B3!&S>%BE"
M`444V)RI(]$:87.?.=L^9R%IV.:Z#?(<\P8R8Q`;&X]WE@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VUS<&]W97)P;VEN
M="YP;F<`````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,S8`,3`U,34T,S$P-C8`
M,#(S-S`R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```,!03%1%
M@7^`P;_`__[_?X&``0$`___B___C___]P,"^=W15__.S__'/__#/__#1@$``
MI64E_]V\>CX<GV-!TE(1TU,2>SP;?#T<?3X=?#T>H6)!H6)#KBX`K2T`K"P`
MJ2H)SD\N`0``_____O[^P<'!P,#`@8&!@("``0$!````````````````````
M````````````````````````````````````````````````````````````
M````````````````SW^?Z@```$!T4DY3____________________________
M________________________________________________________`,)[
ML40````!8DM'1#\^8S!U````"7!(67,```!(````2`!&R6L^````JTE$0508
MTU6/6Q+"(`Q%8WU0V[2@*!5%:BIB=\'^=V6@CC,>?N#.X4X"*:6X`!#Y`3F@
M0E5%3J"7@S5\_$@44TP@&RPH3S0S8-!I/_H1;0B!P@P6M5->>1QR3\B&P>W^
MS["XV[%Q_AEWC>A.V:C%TG&S1CLT-`D1WN`58MMV72/KNG2,WIKCX7J1O1"E
M@T=?\X5"AE:/$DPT+>M,2Q"YORY&>)8O+UYA,W_Y`+N]'=>Z37F-`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VUS=V]R
M9"YP;F<`````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-C``,3`U,34T
M,S$P-C8`,#(R-#0V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@``
M`!A03%1%A(2$____``````#_QL;&````````````^T&S=0````AT4DY3____
M_____P#>@[U9`````6)+1T0'%F&(ZP````EP2%ES````2````$@`1LEK/@``
M`%U)1$%4"-<EC;$-P#`(!$F:U)@L@"E2V\H"MCR0.]8/3ZXZ3D)/OBFXG'QS
M<#IUP,=#&K=PK7]98Y*IB7%(:[W,$:)F)I#6YUM6%E%ACA+O60R@8.)&^;>R
M+`"IR0<XL1=[)^+'7`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]B:6YA<GDN<&YG````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-34S`#$P-3$U-#,Q,#8V`#`R,C0R
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q410```#`P
M,$)"0EA86&YN;G!P<+R><[RB>XR)AIF9F;VHA[RME+ZVK[RWL<"OD<*SFL.Z
MI\;!MN7,I^G5N,[.SM[>WNW=Q^[@R>CBV?'GUNKJZO3MXO?RZ_W]_0``````
M`'\NN@\````?=%).4________________________________________P#-
M&780`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```'E)1$%4
M*%--RN$6@B`,AF&-;Z:8)XT,B:W[O\QFIP'OX<=XMNZC.4OG[@?[V>(F5T"T
M-T2E`.E[RM0;$$1&PJ6`*,B^C,T%A/FXU0N-<YH;8.9T-$"ZIUB!F!+AY0T8
MF5)$J)"A?^!JD%.,(83'\(=M6]?[[/U@T->^=8H2J96!G?$`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O:'1M;"YP;F<`````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C(T-P`Q,#4Q-30S,3`V-@`P,C(Q,#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-
M``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4`
M``#____JZNLS3VTU46](87Q6;89T@I%ZAY6*E)^XP,G`Q\\Q3FPU46X[5G(^
M6'-"77A#77A$77='7WA0:(!7;H9>=(MD>8^=JK>/F*&ZPLJ]Q<W*T-;0U=I\
MB).,EI_&S=/8W-_>X>/L[>U+2TG^_O[]_?W[^_OQ\?'N[N[M[>WL[.SKZ^OJ
MZNKHZ.CFYN;EY>7DY.3CX^/@X.#%Q<7$Q,3#P\/"PL+!P<'`P,"_O[^^OKZ]
MO;V\O+R[N[NXN+BVMK:UM;6TM+2SL[.RLK*QL;&HJ*B@H*",C(R*BHJ%A85V
M=G9L;&Q=75U45%134U-`0$`G)R<F)B8='1T7%Q<6%A;___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!),<WO````5W123E/_________________________________________
M____________________________________________________________
M_____________P"^8S7C````"7!(67,```L2```+$@'2W7[\````KDE$050H
MST70U1:"0!2%X5EVC-W8+1:(K0-*V(B*ROL_B@C'Y7_YW>V-#`/],KXA`S6M
M6N,%^D$GF'*YL[/V'@%48E2]Z"E=KG=D0\:?"^-"\MQX`^`:SN,JIND)0+KL
MBX>P=].;VM"BH@$';=:?`73+"6=D*XJ#!4!_""T!Q)>D'35)EU<`#T91%95A
MGFL`65=NI]M.WQ$`AF79T8CC.,&&.2&$YP6S@P7_^=8!'PK-+=,D-RAA````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]V8V%R
M9"YP;F<`````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S(Q`#$P-3$U
M-#,Q,#8V`#`R,C(S,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M``#`4$Q410(*'@)&`EIJ<F::`I:BKK:^QLG.UH21FIIF,L[6WLZ:9AHF,MKB
MZBHR.O[.FC9"3K[*TN+FZO[^SHJ6HDY:8K[&SN;JZD9.6M3;XPH2)MK>ZI.>
MJKO"R\O2V^KJZL+*U%-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;
M[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;
M[U-;[U-;[U-;[U-;[U-;[U-;[_X:OA$````1=%).4___________________
M__\`):V98@````%B2T=$/SYC,'4````)<$A9<P```$@```!(`$;):SX```"-
M241!5!C37<_1$H(@$`70#125R*0R2-C=___+%G1H\C[<AS-W8!:64V!1-:]P
MOUT_``LH:GF[B"#0E^2\,N+4_6`?I0(AA!28G+6.VH(-V<<\'HLD&X'9'M#W
M*S-2',>-GNT-)*VUJN#S:G"*!2XT%&`V&+?->_EV!^R`G)?:`;LD%U"M82C7
MP'^=S_\"M:X/EKA23J(`````245.1*Y"8((`````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;V]O7V1R87<N<&YG````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q,P`Q,#4Q-30S,3`V-@`P,C(W
M-#,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````,%!,5$6`@(``
M``#____`P,``_____P```(```/^`@```@`#________________________!
M9+?3````$'123E/___________________\`X"-=&0````%B2T=$#QBZ`-D`
M```)<$A9<P```$@```!(`$;):SX```!8241!5`C78_C/``;R#/^9E(!`&<00
M-A8V!#-,0D*"%4`,4Q<7929^L$B06@%$1"D]$20B$J16)@Q6#!0`ZS)2#1.&
M,AJ5(8R(2<JH)L/L8C8&`2!#$`SD`4,R(+#$1;^O`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]M:6UE+W)P;2YP;F<`````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$T,S<`,3`U,34T,S$P-C8`,#(Q-S,W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```8!03%1%6%A8WM[>O+>QF9F9____
MZNKJ;6UM_/S\<'!PSL[.,#`PB8F):VMK0D)"2TQ+5EA66UU;9&1D:6EI3D].
MOJ*@XK*P]O7UXN#>CXF$;F]N(2(A2TU+<W-SS,S,[^_OTK^^P&AEP5%-W,?"
MY^#9OK:O4E-2!P<&'R`?W]_?_O[^^_CUOD9"NT`[SLB_O*Z7)B8E`@("_O[]
M^OCT^/3LC4I&CA<4MH1]````#`P,1D=&Q,3$9&)>B()XP+6CO*N0=GEVOKNX
MCHZ+&QP;MK"H%Q<7LZJ<$!`0S;ZIO*B*?WYZOK:JO+">NZR5O*:%!P<'4E)2
MR<2^WMC.R+^SULNZU<BSTL.LT,"ES[N>O*-_].WA\NC8\.30[M[([-J_Z=:X
MY]&PY<RGO*%XQL&VQ+VLP[BCPK.:P*^1OZJ(OJ5_O:!VO)YS____________
M____________________________________________________________
M____________-&\K2P```(!T4DY3________________________________
M____________________________________________________________
M____________________________________________________________
M_________________P`X!4MG`````6)+1T1_2+]QY0````EP2%ES````2```
M`$@`1LEK/@```*Q)1$%4*)%-SBT.PD`0!>#WTL(V502!`]<$0W#T!@2'K>8B
MFYX`C\)BJVHP:`@7J(-@4&#X*=O";KND3\W[Q,Q0`HA1YU=H@+JQ<)2TX&A@
M42K9`(?,2]$`".52:5C2YMJ[4Z[T=.Z?!H8N#,@H'F9`8"#CF'.S8V3Z,V-(
M3E,<)@KNIT7N&<Z0>GSX]=J=`:"+E_<6>9M;??;(6\<>3NK'(@N;"A:PL*[`
MQS]?H^$R$+Q;>[(`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]C86QC+G!N9P``````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`S,38`,3`U,34T,S$P-C8`,#(R-S$R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`0#````[=WB4@```!A03%1%@("`````____
MP,#```"`@`"```#_____5NRGX0````AT4DY3_________P#>@[U9`````6)+
M1T0'%F&(ZP````EP2%ES````2````$@`1LEK/@```#M)1$%4"-=C*&<``W&&
M<B8E(%`&,8Q!`,0P8&9@,$8345+"+6("$PF!BAB&0$720E!UP>QBAHD(@H$X
M`-C\%8G7+=6F`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]E;F-R>7!T:6]N+G!N9P``````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,S`V`#$P-3$U-#,Q,#8V`#`R,S,R-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`P```"@M#U,```$.4$Q410````0#`@4$`P@("`D)"0L+!Q,1
M#AH3"Q86%AP<'"`='!X>'B\I(2LK*RTM+2XN+C@X.$U-38%:*W)R<JIO*Z1Q
M-GIZ>JQQ+JUS,J!W1*-[2X2$A*1^3JB!3+1^/J>"4J>"4[B`/JJ$5:N'6*R'
M6+J$0JN(6+J&1[R'1KR(2;J)2Z^-7JV-9+R*3+"-7[V,3J61=KZ-4)N7E,:6
M7<>;9*BCGLJ?:*JJJLND<<ZD<,VF;LVF=M"F=,RG>]"H=,^K?+&QL<^L>\VL
M@\ZM@]2L>=6N?M*RB=6RA-BUC+R\O+Z^OM:ZE,#`P,'`P,+"PMJ^FN#"GN'"
MG.#$H-_$H^'$H.+%H>/&HM+2TMO;VP```'M`2!X````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!(L
M!'X.`?D```",=$58=$-O;6UE;G0`365N=2US:7IE9"!I8V]N"CT]/3T]/3T]
M/3T*"BAC*2`R,#`S($IA:W5B("=J:6UM86,G(%-T96EN97(L(`IH='1P.B\O
M:FEM;6%C+FUU<VEC:&%L;"YC>@H*8W)E871E9"!W:71H('1H92!'24U0+`IH
M='1P.B\O=W=W+F=I;7`N;W)G9XK'1P```)E)1$%4>-IC8,`.(H$`B<LM%AX1
MX2G,#!>0]A+@Y!1TD(;Q^?Q80!2_.4P7KP^8Q>$+$V`SXF)E9&3B,66'VF`0
M%!SL[^_O;2T$41(9ZF&F(B^O(*4I#A4(<]5SM[=WM-`0@0J$V)@HR<C(2*K"
M5`1:ZK@Y.3G;*DI`!0)<K+25E=5D->2@`G;&AH9:6OJZZJ*1")]!`#9_`P``
MXAT7BJ?_70````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?;6%T:"YP;F<`````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,C0V`#$P-3$U-#,Q,#8V`#`R,C<T,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(!````+7Z-^H````"8DM'1`"`1S6@$@````EP2%ES
M````2````$@`1LEK/@```$I)1$%4*,^UD$D.@#`,Q/QTGI:?F4,IJ#!5$1+Q
M,=9D060S@T(34M4HU(V'L$Q0!F)":QRM/*(KSG>XE"\)BQU>7/'K)RMR"CA#
M=AJU@3HN%F2X`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O;6%I;"YP;F<`````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C(V,@`Q,#4Q-30S,3`V-@`P,C(P-C``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,`
M`/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$63DX]+2TG[^_BE
MI:/W]_7Z^OG`P+^-C(:\N[?Y^/2VM*[<VM3;V=/:V-*1D(W[^O?Z^?;IY^+B
MW]B0C8?=VM3:U]'Y]_/X]O+W]?'R\.R3DI#=V=+=VM7IYN'CW]F-BXCZ^/7W
M]?+KZ>;W]?/O[>N7E)*RL;&AH*#____^_O[]_?W[^_OZ^OKQ\?'M[>WKZ^OJ
MZNKHZ.CFYN;EY>7DY.3CX^/BXN+@X.#/S\_*RLK$Q,3#P\/!P<&^OKZ]O;V\
MO+R[N[NMK:VHJ*BCHZ.@H*"?GY^>GIZ=G9V<G)R;FYN:FIJ%A85V=G9K:VM=
M75U`0$`>'AX6%A8!`0$```#___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"XM7$8````
M57123E/_____________________________________________________
M__________________________________________________________\`
ML*$'SP````EP2%ES```+$P``"Q,!`)J<&````+M)1$%4*%-%SM="PC`80.$:
M9FUE+]DC`BU6@::RERVT(J(D>?]GX0]2.)??U9$XN\3])*9IFCZ:WP3`MNU9
M[],7`,,P-H?C+Z/T"HZS_?A^.#'<%`+P]@[UQPSC"!6@[US7];PI`'ZD`@8B
M<R$`_U``[VMO$K(4$`L*&!)B6=8:H!C*`$R6JS7D_$4[KRV`ZSIC`93./9<`
M.*?=N(00DN5:TH<75$CDZXU*+?4/[2=55;.*4JZ&+\#I/7X&[EX[218*2T0`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]A=61I;RYP;F<`````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S<R`#$P-3$U-#,Q,#8V`#`R
M,C(S-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````84$Q410``
M`+V]`(2$A/__`,;&QO___P```````(ZE7?$````(=%).4_________\`WH.]
M60````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!G241!5!@9
M!<&Q#<,@%$71!\)R&P5E`5*\-@T3V$R`_A[@YJZ?<P2L$Q#PSH!@_VY`4-LP
M%KN7\(-VG25L]!E=85"]9CD,JJ/GPZTI?:?"H)5Z"8-8M82-(+7P@V"];F,!
M*0,"U@G\`<FQ)<?GX)S1`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O8V]M<')E<W-E9"YP;F<`````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,S-``Q,#4Q-30S,3`V-@`P,C,S,#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3```#`%!,5$4`!```!0``!`<`!`L`
M`@X,$B`*#!FS33:`+QQV.B\(``!/5F!M@YA8?YY^L--QK=*+S.Q3E*H`-#W-
M+0G_I83_LY[_P+%:%`PK```9```+```!!!,`"!\`#"L`$2X58'.2W>``)A/3
M&@B_%`/+."ZM+2"*%@"W1B2<*`"A,P!K$P"06#=723[T__\`"@RHT<D`#@#'
M&Q'_T,K_OKG_TL;_X\/_PH?_P6K_LU+_T';TI%T=``#S].8-(!ZHO;BA)1W_
MX-K_Y>+_X-'_^<__XYKZMD?_Q$7_O4CJOV,-"@#R__H`!PZTP\H*``"D,R/_
MU\C_[N3_\=KVZ+?NVH3[RT__QCOVP$+MSV\`!P#@^?8`!Q^WOML4``BG'@#_
MX,'_Z=#_[\SLR8_FOF;_P47_N#/]ND7AMV41#`#N_?\``#.RL^P2`!ZI+`#_
MW+#^NI7TQ9GTSHW[S77_O$7_T5+_T&.I?30&`0#<[O\`$D"TP?8+`">'-@#_
M\;W_X;/NTJ#<P'_TT'K_QEOQKS^_A2+0KVC,[NT`%R:ATN$`"0QY0!4D```5
M```-```:#@`1`0`]&@`;```+`@``$`0`#0P?55>3R,(=1S$`!`Q$4EM<;GAI
M?H^)I;N3N-.(LLB*K[<`'A0`!R,`#S(`"#(`"#,`""D`$R4`"B9RD[(`"0<4
M.T(`%B9&;X4`"",M3F\`!2E'9(PN4F``#"(>5F\`$"M#=I$`#B8L2V``!1L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"9$],?```!`'12
M3E/_________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________________\`4_<')0````%B2T=$
M_Z4'\L4````)<$A9<P```$@```!(`$;):SX```!I241!5"C/8_S/``*,$/`3
MR/K/P<CXC1LJP/B6@5&8$07<8^%'%6!`$SC,P,*'(N##0$@+?H':%K``Q-"U
M(8R,$\$J&,%.GP%3E0`58%@(Y/QG8HQB@`F`P'+&"`:$P$JHG@`6J#0'S%H`
M(L`3M3##,7D`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]T
M97AT+G!N9P``````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S$U`#$P
M-3$U-#,Q,#8V`#`R,C$Q-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=
MXE(````/4$Q410```(2$A,;&QO___P```"QEJ`8````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,+
M"=NXI18````W241!5'C:8V!@<``!!@8&%D,@,`$RA)U!`"@D;`P$1B@,$Q<3
M9W01%S)$8`PA)1``,EA<0(`!`/E<%6K<DNOA`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U<F-E+6,N<&YG
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,R,0`Q,#4Q-30S,3`V-@`P
M,C(V-3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````&%!,5$6$
MA(3___\```#&QL8``(0```````````"+Z11]````"'123E/_________`-Z#
MO5D````!8DM'1`<688CK````"7!(67,```!(````2`!&R6L^````/DE$050(
MUV,H9P"!\G*&<D9!04$A=AA#`,904H<P!(7!#!<7"$/$4<01G2&(2PJN"V$.
ME,%L#`)`AA(8J`,`HQ04*-AK*I,`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-O=7)C92UH+G!N9P``````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`S,38`,3`U,34T,S$P-C8`,#(R-C8Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`0#````[=WB4@```!A03%1%A(2$____````QL;&
M``"$````````````B^D4?0````AT4DY3_________P#>@[U9`````6)+1T0'
M%F&(ZP````EP2%ES````2````$@`1LEK/@```#M)1$%4"-=C*&<`@?)RAG)&
M04%!(7880P#&4%(',D0<!06%41DN+C`1$4>B&4`#!5$8S,8@`&0H@8$Z`+-&
M%%YG-GY_`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O;6EM92]S;W5R8V4M:F%V82YP;F<`````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P-38T`#$P-3$U-#,Q,#8V`#`R,S,V,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,```!@4$Q412$A(4)"0@```$(A(5)24O][>_\Y.7LA
M(;U:6O\``-X``+V]O9PY.9P``%I:6C$Q,?___X2$A)Q[>Z6$A)R<G&MK:\[.
MSM[>WN_O[XR,C*VMK5-;[U-;[U-;[U-;[U-;[Z*F.OL````@=%).4_______
M__________________________________\`7%P;[0````%B2T=$'P4-$+T`
M```)<$A9<P```$@```!(`$;):SX```"!241!5"@5!<%)0@(!$`2PZA(71+1=
M![WD_[\T"4`&"&`:($#:`@'2-DP$I&T'G8`T=VU,&Y#3_<-C8YH@TZ?[\W/'
MS(297%[.Y^OK6T*D^[X?U^OG?@69)-^[/S^[ER!I>]G=W3V*S#3'[N[N4<0D
M>_N=^;X=19!CPIS^!D$FT(%_Q&L17+=09/L`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M:6UA9V4N<&YG````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0S-``Q
M,#4Q-30S,3`V-@`P,C(R,3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#M
MW>)2````,%!,5$6$A(3____&QL;_``"$``````"$A```_P``A```````````
M```````````````````"80_+````$'123E/___________________\`X"-=
M&0````%B2T=$#QBZ`-D````)<$A9<P```$@```!(`$;):SX```!I241!5`C7
M-<W!"8`P#`70Z@*:2!W`@PNT>TC5H#>ET!FZ@EO').(_/?X/Q#D-,[L&`+#[
MT7,T>-H$XSP7#(MKD*@,46[&HY:P"/"H]WYI<T[MJL#T$%J3H!@PYP^>Z)M`
M?PC:22,@R\4OQ/XE#[E,VE8`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-O=7)C92UC<'`N
M<&YG````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,S$`,3`U,34T,S$P-C8`
M,#(S,C$Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```!A03%1%
MA(2$____QL;&``````"$____________W#H^*0````AT4DY3_________P#>
M@[U9`````6)+1T0'%F&(ZP````EP2%ES````2````$@`1LEK/@```$9)1$%4
M"-=C*&<`@?)RAG)&04%!(7880P#*$#8VAS`$A4`,$1=!$3##1<31Q0G*@(K`
MU"!$8&K@NN#FP!A,2B``9!B#@3D`\/H5@E-&L54`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6EM92]I8V%L96YD87(N<&YG````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-S(S`#$P-3$U-#,Q,#8V`#`R,S`V,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,```#`4$Q410```!86%BLK*R\O
M+T-#0U5556AH:'5U=7Y]>']]>)-".*=%/H!_>=1-08*!?(.!?(6$?^>>/(J*
MBI&0B9*0BIR:E)V;E:">F*.@FJ6DG:>GIZRIHZZMI;2QJK2QJ[:VML#`P,K*
MRL_/S]C5S=G6SM75U=[;U>#?U^+AV^7CW^;EX/___[V]O0``````````````
M````````````````````````````````````````````````````````````
M`+9I(J\````M=%).4___________________________________________
M________________`*7O"_T````!8DM'1#\^8S!U````"7!(67,```!(````
M2`!&R6L^````<TE$0508TV/000,,Y`@P(`.0`*.4$#L;*RL+"PLS$UB`05M;
M45M;05M;7EL9(J`DPRDC(R`#)$6@*M3%M30EE97%E&4@`JIR?')RO-S<W'(P
M%1IB:LK<@H)<*"JXN;BX8"J4Y7AD9/B`ADI+,&!U&"&_``#DAQXB-H^QR```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VUI;64O<&1F+G!N9P``````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C,Q-@`Q,#4Q-30S,3`V-@`P,C$W,#<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3```#`%!,5$4```"`````@`"`@````("``(``@(#`
MP,#`W,"FRO`$!`0("`@,#`P1$1$6%A8<'!PB(B(I*2E5555-34U"0D(Y.3G_
M?(#_4%#6`)/,[/_OUL;GY]:MJ9`S``!F``"9``#,````,P`S,P!F,P"9,P#,
M,P#_,P``9@`S9@!F9@"99@#,9@#_9@``F0`SF0!FF0"9F0#,F0#_F0``S``S
MS`!FS`"9S`#,S`#_S`!F_P"9_P#,_P```#,S`#-F`#.9`#/,`#/_`#,`,S,S
M,S-F,S.9,S/,,S/_,S,`9C,S9C-F9C.99C/,9C/_9C,`F3,SF3-FF3.9F3/,
MF3/_F3,`S#,SS#-FS#.9S#/,S#/_S#,S_S-F_S.9_S/,_S/__S,``&8S`&9F
M`&:9`&;,`&;_`&8`,V8S,V9F,V:9,V;,,V;_,V8`9F8S9F9F9F:99F;,9F8`
MF68SF69FF6:9F6;,F6;_F68`S&8SS&:9S&;,S&;_S&8`_V8S_V:9_V;,_V;_
M`,S,`/\`F9F9,YF9`)G,`)D``)DS,YEF`)G,,YG_`)D`9IDS9IEF,YF99IG,
M9IG_,YDSF9EFF9F9F9G,F9G_F9D`S)DSS)EFS&:9S)G,S)G_S)D`_YDS_YEF
MS)F9_YG,_YG__YD``,PS`)EF`,R9`,S,`,P`,YDS,\QF,\R9,\S,,\S_,\P`
M9LPS9LQF9IF99LS,9LS_9ID`F<PSF<QFF<R9F<S,F<S_F<P`S,PSS,QFS,R9
MS,S,S,S_S,P`_\PS_\QF_YF9_\S,_\S__\PS`,QF`/^9`/\`,\PS,_]F,_^9
M,__,,___,_\`9O\S9O]F9LR99O_,9O__9LP`F?\SF?]FF?^9F?_,F?__F?\`
MS/\SS/]FS/^9S/_,S/__S/\S__]F_\R9___,____9F9F_V;__V9F9O__9O]F
M__^E`"%?7U]W=W>&AH:6EI;+R\NRLK+7U]?=W=WCX^/JZNKQ\?'X^/C_^_"@
MH*2`@(#_````_P#__P```/__`/\`______]8(DZW```!`'123E/_________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________\`4_<')0````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```!;241!5"B178[+#4`A"`2Y>;$.^R^,9$,%
MO"6BPIN+[O`)XN[R8`AAR5Q2JT*Q^*P#!6F"U(D47#KC!U@70W\"BBYTMUPQ
M$#W`$2,"5%7VZ;G@CK!D3;R<HI[[`;J9E,,3;AF'`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]P:'`N<&YG````
M`````````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,U`#$P-3$U-#,Q,#8V
M`#`R,3<R,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-
M00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8
M```7;Y)?Q48```,`4$Q417M[>P```+W&QO___WN$A'N$O3E"6H2,O92<QN_O
M]][G[ZVUUM[>[_?W_T)"6HR4QL;&WK6]UKV]WHR4O<[6YYRESCDY.1@A*1@A
M(3E"0IR<I?___________________R`@("$A(2(B(B,C(R0D)"4E)28F)B<G
M)R@H*"DI*2HJ*BLK*RPL+"TM+2XN+B\O+S`P,#$Q,3(R,C,S,S0T-#4U-38V
M-C<W-S@X.#DY.3HZ.CL[.SP\/#T]/3X^/C\_/T!`0$%!04)"0D-#0T1$1$5%
M149&1D='1TA(2$E)24I*2DM+2TQ,3$U-34Y.3D]/3U!04%%145)24E-34U14
M5%5555965E=75UA86%E965I:6EM;6UQ<7%U=75Y>7E]?7V!@8&%A86)B8F-C
M8V1D9&5E969F9F=G9VAH:&EI:6IJ:FMK:VQL;&UM;6YN;F]O;W!P<'%Q<7)R
M<G-S<W1T='5U=79V=G=W=WAX>'EY>7IZ>GM[>WQ\?'U]?7Y^?G]_?X"`@(&!
M@8*"@H.#@X2$A(6%A8:&AH>'AXB(B(F)B8J*BHN+BXR,C(V-C8Z.CH^/CY"0
MD)&1D9*2DI.3DY24E)65E9:6EI>7EYB8F)F9F9J:FIN;FYR<G)V=G9Z>GI^?
MGZ"@H*&AH:*BHJ.CHZ2DI*6EI::FIJ>GIZBHJ*FIJ:JJJJNKJZRLK*VMK:ZN
MKJ^OK["PL+&QL;*RLK.SL[2TM+6UM;:VMK>WM[BXN+FYN;JZNKN[N[R\O+V]
MO;Z^OK^_O\#`P,'!P<+"PL/#P\3$Q,7%Q<;&QL?'Q\C(R,G)R<K*RLO+R\S,
MS,W-S<[.SL_/S]#0T-'1T=+2TM/3T]34U-75U=;6UM?7U]C8V-G9V=K:VMO;
MV]S<W-W=W=[>WM_?W^#@X.'AX>+BXN/CX^3DY.7EY>;FYN?GY^CHZ.GIZ>KJ
MZNOKZ^SL[.WM[>[N[N_O[_#P\/'Q\?+R\O/S\_3T]/7U]?;V]O?W]_CX^/GY
M^?KZ^OO[^_S\_/W]_?[^_O___P?&#&T````@=%).4___________________
M______________________\`7%P;[0````EP2%ES```+$P``"Q,!`)J<&```
M`%M)1$%4*,^=CTD.@"`,`$M(6P51W+WQ_U\:D+)<G>-DVK00(JH"GP!!A!:*
MR`/Z5Z$ZHL`$02D0>1@--86=F-U<"^L6]&M3L#>X+=V.'8^3+OE%4>)^Y%NY
M(&1>N;`((X7<,/$`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+W-C<FEP="UJ<RYP;F<`````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`S-C``,3`U,34T,S$P-C8`,#(S,#4Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`0#````[=WB4@```!A03%1%A(2$````QL;&__\`____A(0`____
M____XQ?5>0````AT4DY3_________P#>@[U9`````6)+1T0'%F&(ZP````EP
M2%ES````2````$@`1LEK/@```%U)1$%4"-=C8(``1@;V\G(&(*$(Q`4F)HI@
M!DMHD(`XD%'@8J+(!&:XA@H*@J3`2L!JF$.#Q%%U,3"&.H$5.PF(&($8+(;,
MSF"I`B5&)8AB0:`Q0`:3$A@H,@A"`0"`MQ:2ZAP4%P````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM
M92]D96(N<&YG````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(R
M`#$P-3$U-#,Q,#8V`#`R,38V,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,```#`4$Q410```#`P,$)"0EA86&QL;'!P<)H``*X``+8``;HJ*KDI
M,KM:6<```,HY.<)?6L5E9=IY>+R><[RB>XR)AIF9F;VHA[RME+NTK;RWL<N2
MA<*2DL"OD<*SFL.XH]RJI^"PK^2TM,;!N.7,I^C5M\O*R=3.QMG0P]W=W>S<
MQ.;>U.[@R>GBU_'EU.KIZ?/MXO;Q[/S\_```````````````````````````
M`````````````````````````````````*7-XI<````R=%).4___________
M______________________________________________________\`#5"8
M[P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"M241!5!C3
M1<[I$H(@&(5A[4LCQ6U<RW))QPT0O/^;BR6G]Q<\<V;`.F1P)L^6AEE5008G
M,"%CCI"BP0TPBKEP1I'9"ESL^3[RVM2Y7C1@=V1L#CS&JE0!NH$(HK;%(R>E
M`GQ`$,VLPSVCA5X<$#ZYB-%$2?%;=%X;XW*EFUFX(!K?+R>Z++EY!00G*Y'W
MP0"Z[WRG=!F&CP'YTV:CVR`A,0!]^'B_ZCI/3K#_?0%D5AQ)$7Q5A`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO````````````````````````````````````````````````
M`````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,Q,#8V`#`R,#4W-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]M;V]N+P``````````````````
M````````````````````````````````````````````,#`T,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C8`,#(Q-30T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO
M;VXO9G5L;&UO;VXN<&YG````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8W,0`Q,#4Q
M-30S,3`V-@`P,C0Q,3$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```#`````P"`,```!@W`FU
M```#`%!,5$4`_P`Q,3$Y.3E"0D)*2DI24E):6EIC8V-K:VMS<W-[>WN$A(2,
MC(R4E)2<G)REI:6MK:VUM;6]O;W&QL;.SL[6UM;>WM[GY^?O[^_W]_?_____
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________\`_P#?3]G<```!`'123E/_____________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________\`4_<')0````%B2T=$_Z4'\L4````)<$A9<P```$@```!(`$;)
M:SX```-&241!5$C'Q9;-<MQ&$(,!]'!74JI<Y3BR_?Y/%TO))7\V.=-`#E[9
MLJ4XR2$5'GC@\"MPNMG`,/AWE_!?`^/YQV]C0C\^L\*G>[A=;0`).,YW?P>\
MV?L(0(P8BZ?K\>.W@+?[86,3:+NV3D[DE\@7P*OW'%RF>04O#F"-0'7_%\"+
M_4:3>PO6:0346L7>RMN[YZKT8MW@-]@*D^G:NH5)KYOJYQ1>'*?M^!```EE+
MYWUN@;]K;<#]D\:].%CSN.")U<N9;4R=DOSP-?#]`?4R"0CI9'!ODLP?.YAY
M?/_E)[W^!6":,$,`@U$F0,:\&7&,7Q\K'$`A)8N2QB@N5.(0A.?.T]AO'U7I
M]@-%,1`9Q!&NM4(A8;JF;Z[6[X\4/H"ZK()$L"\Y-50UQ'6D>YWG[6<%`]4(
M6$D@9`S/KHK&WH#A]WW^;GU2>&5@.A00!J6AM.T0O0P"3._2)X7##$`:*E24
M7LD8RZ<1D%`(]CH_*+R901)(H+`-@,`X;5MIU!!"TM%\__*B$//28)LJ+@2Z
M(D8&79WT&.1D'P\`/MZ&W*D]"PP656(%:GJ[FD?XN0]$")"B"#LILJ$"[+I&
M?XBI6O0%H*P07D&"(MH\<Q)RB*M>@%43.5T`E<W`"*&L"!BJ2DQ&'0\'8_B3
M0FH"3!PPCBAKM-@0;.9L'[@><2YE?4==I@`A";+WB33C=@6G0?>B-!XZG:*#
M@-!`9['65)!TF$:&XZS^M`=0<@(B7C:@:A[%CUM"4T5TP+L'X#3A@-2TL25&
M&H,DFF0O<CLM??R7!`!W'-L88YPV)8-P(UO1:4,=5)"JVC[/0ZTQ(@4HI>$`
M0>1LA*E%!1IWCV;Z96SIF#[5%+H:=24FPE&$$?CT\^.9WB@@AS-7C$R#4HE>
M$@$'E](_.-_=:P,&Z(R%K:NV#09!.@#00U\YWZLES&F>L\:9JS:B`Z.1D,'I
M_BMO57J[KB7MB<<H`#)H`0U@NW_BK3_L&&Z4*;)0(9TT'(+UTS-V?SN7FH.Q
M5$!0L"<`8?ST;#Z\WF<5A@-*)@EW`F+<_U5DO6R@"&=0'TW<!!_%R9-0?#LG
M**,H)`%!W7T[=M\NQRP(-*AW_R"G@3=!GK[Z#>#_/9S\"2QI0,AM3G5,````
M`$E%3D2N0F""````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]M;V]N+VQA
M<W1Q=6%R=&5R+G!N9P``````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,V-3``,3`U,34T,S$P
M-C8`,#(T-C(R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````P````,`@#````8-P)M0```P!0
M3%1%`````/\`"`@($!`0&!@8(2$A*2DI,3$Q.3DY0D)"2DI*4E)26EI:8V-C
M:VMK<W-S>WM[A(2$C(R,E)24G)R<I:6EK:VMM;6UO;V]QL;&SL[.UM;6WM[>
MY^?G[^_O]_?W________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____`/\`S$R#=P```0!T4DY3____________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____`%/W!R4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^```#
M-4E$051(Q[66RW(41Q!%S\VJZI&`P.'PBQ"/__\N),!X91P>C6:F*J\7U1(:
MD+"]H!>]Z([3E8^;-UOF_UW!]P;J0P_?)&00;Q]XIZ]R>+7;#VH$1G5S]6_`
M;]LQDBC1;`\MY^7R6\#%]1:CB%)-+79NT"ER`OS\5Q8;H:65'D7TFJ'R[A'@
M^;8E-@(M9^'".#9&*]DN'ZC2ZS]OVC"`9?D8BQVQC^Q/RGB@#V\^W9`"8RQY
M9.ZWNT$_7U*\^AKX=$VDC2S`T`]C]#Y\+,V,BR^!7[:0,B"PR1I]A!3:[L']
M\.(4>/E),B8,(*1#J9(1Y7A(2\>?3H#K`3+J8B72@64C\KC74O<O[P$O_@Y`
MN`B$C5M1&LA@9-_Y;+F^!VRQ-!$!\DCE*#5JJ8I^\.C][/#RK@^ONV6!//LH
M21Y$M=I^I(QW8_.TWP$W?59RUFC6:4!8ZCU#)CQNEK@+:><[A0@)\.B*/&84
M)$*2<M=O@=>'^^+2>DQI+4J+&EC2((Z[7]>01FKF@'`8#"J*1HE>ACUJ%4>-
MXWI"3L$A3279QIFI**HE)+?S,RQY/2&Q;,T4/#4O=[>2<CEG[)R*TN7U!,>*
M&XR0D4)A>Z#-8I%1C)<5"(21Y\<-$E($#H&'2UJU*G(-J<RIN<UC7AE@A4F6
M',?#64MN0RJWP9LY"S)VV@RGK%9CC$%178'+@E)(:(8T^^ATIABFIM-]W.7`
M1L@8L%>1>&8DND>Z2#W1U:V6GMRD5POQO,OK>".-+C7UB,]:>E^F7.ZD)\]^
M9EH#BG$II7V>A[.9M+36U6#!($))=`6H7GT&GC83X+$.`\BV(T*'*)EIN5S=
MF[BWSX@,K($]M805H=&CK.+1B0E\/"<2.RR0@BBS(X1[0CKBU"J?'[O"LT8"
M27A$*)+I/O7RU,@NGU>/*(2%D>S9$Z(4`^W]EU;Y^[."+<^<$6O9/%+2\O[K
MI?C'#^W6!V;2SLS1Q[`4[Q[:HA]_V.1LWO0!C"E1I/KAL97UXW8ZV?2!VFH@
MU"X?7XH7V]TZ'$)16E/$U;?7[HO]?JQ^&76S?+E$']C3<'%S[*!:-Q_^RV)?
M-]C;1WX=]-W_9OX!P[GRZMC(SY(`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]N97=M;V]N
M+G!N9P```````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S8W`#$P-3$U-#,Q,#8V`#`R
M,S<T,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````,````#`(`P```&#<";4```,`4$Q410``
M``#_``@("!`0$!@8&"$A(2DI*3$Q,3DY.4)"0DI*2E)24EI:6F-C8VMK:W-S
M<WM[>X2$A(R,C)24E)R<G*6EI:VMK;6UM;V]O<;&QL[.SM;6UM[>WN?GY___
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________________________P#_
M`!0ZQ*8```$`=%).4___________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________________________P!3
M]P<E`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```H1)1$%4
M2,?%EMMNVS`01`/.G)&E.(Z3^%(URO]_9OM`TI9S:_M4PH`A@$<[L]SEZN[7
M/ZZ[_P,L\^GX<OCQ\^^`U^?[`"!G>_XC<-H.EB3+=BE,S\MWP/PH5`#;-MAA
M.GX-O*!@6P9LZLKV]0O@H0Q@R2IR3*5,QN-GP+)UE5\DJ;V_AAM6LB[`VX,-
M4BF2FVE9$B:>SA^`G1RY7")(5BF2'!+&^1UPD&RKU/U%-:N25)P`][?`3ZH`
M-\*VVBH&B!]O@'VQ+?FNJ;%5XTF2,>`?*^!LN[ZTO=@VJ&G",@/;%;"UZ**J
M71OU1ZF8X.,%6#8R;CJNHE0379,`["_`P6J:^J_I,TUBD<UT`>[5-QEC(ZE8
M4HW@[FINP(+<D5804N-;B'KH3PV8)=G"MGH!B6`(U%.4730UX-P"@&S3_!J2
M(;8DZE\:<*PR`:]\5J(W:R@22P4.5)%54T^H(80,L5Q##`TXH4LRO3(?`B0(
MB(N[I+FVF6KJ&Y".),$XV.,EK5[5D&34^CEMV0*SZP>W<>LQ&5E&G:"Z0#+V
MJ0./N'0]ZKJ@6H"D%EJ6#LP#;9]4>M'>V,;&#]?RGN)Z9.KUK>JZR\)F>+D"
MSX12#ZYWI@DX79;)N&J@MPEC5%Q::5LUI]@)&')8]_2)*$AWZG>927*193S=
M7C.[&$HIQ2U)21("P1CG?`LL(PR6"Y(#R3!<(S@\O;_YSJ.=B-H32886HS;A
M;OEP&1\'QQA<Y5>B'<;#\LEU?]IX-1323!N3Z_Z;^3!/=IS@MKV9R'[Y:F3M
MX;9.`:;3-T-QWK6TUZHC&9]?OQ^[Y_T8D@S#$,;=^R'ZZ6"?G[;C9C/>/YV6
MO_]T>%O^V\?);^ALK>9:B)W&`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO9FER<W1Q=6%R=&5R
M+G!N9P`````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8Q-P`Q,#4Q-30S,3`V-@`P,C4P,3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```#`````P"`,```!@W`FU```#`%!,5$4`_P`("`@0
M$!`8&!@A(2$I*2DQ,3$Y.3E"0D)*2DI24E):6EIC8V-K:VMS<W-[>WN$A(2,
MC(R4E)2<G)REI:6MK:VUM;6]O;W&QL;.SL[6UM;>WM[GY^?_____________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________________________\`_P`7E1!G
M```!`'123E/_________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________________________\`4_<')0``
M``%B2T=$_Z4'\L4````)<$A9<P```$@```!(`$;):SX```,<241!5$C'Q99?
M;]U$%,1_<W;M&Y)`$1%M"LGW_V!-@]16XB$$W=B[9WA8W^0V30L\("Q;EM8[
M.^?_6.;?7<%_#:@O+5YE<ZK&[0O?]*4/;_9+-TJ(^?3#WP&N]^O:,I$%29E.
M3F^^`;C>K]FL3&,0)CR=??PJX'+O26O/9B5&VY;YU?N7`1?+26E>FMTDI0`L
M2^7\XTN`B[;C/AI6[QI.8"P4Y<FL.#J_1L\&0@$)3ML(O-R__@)PL:BLRR/<
MLNT$'!#KW=MG@#<+T==$2,)(LB4@4X;U[NJS3/_Z)^J]*U*0B!R[D<&8V-]]
MQK"`Y!(.I%)J&2$R1C;&NK\\8OAEKY!%2F$K.Q*V9`N'C2+_.&+8HU"0R"@2
MI0')+J"TP>Q?/S$82J91L4U)3&)0>#"E`BV/#&\ZK)TXU$(HCJ++P9\GP)K8
M!HA:YUJ#[&FP!18@P.O;S:3K!0P$J7#)'F%)QAHE"S+&^XTA?7`DTRIA2XKQ
M(#`2R#QL#&8LUNS=Y2';B`H0EB&,A$4[^"`L+(44=-L*L"$Q$1K[+%\-@()`
MRM9$SQ(%:Q+##,6H#B''QA"5-,[>+;EEE)@B-*)C(X0EY)O-I`"!,YW8745%
MA]82*#P:MFP,[[8\V5BF2&VQMEAL/MI(T\%I%W(<$I7LG9*61D"?TH!/'J,4
M!:?!V>BYNHC<AL:6/F''?`#LH@82A;;T6M03/Q83Y"B-V-T<`#=1IUKJ--=B
M3Y`)4]C',T72[JD?2JO5$882F2:%)6ES?2#*IR?`;;$CM"Q-4X_B8G?K4`1*
M`,Z.A\"T1IK%;NXAM\>J&S>6YT_'0^#]5&L8Z)[-''6:RQ8DC3Z*\V>C\K(%
MZYK:N9<=:WA=VI8\X?#Y[\\4*-SKZ4,+K8XL$RG""%)`GIX_'Y6WL]<5B'F>
M2)G1XF/\Q<D/[[X8QK^=E-68$FD10U-LD[#[\>8%%;V=:XM**44)(22/U]FK
MFZ](UL\V1>HN\KKTCI&G\P]?U>F/WTWTGCEZW"#%]S]]^*;L7K=TJN"^+JW,
M]9F(OJ33<&5#;Y[F=_]$V/_OGY._`,#`[ZJKZ]A2`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+P``````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C8`,#(S-#0Q`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O````````````````````````````````````````
M```P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,3`V-@`P,C0R,C(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T-RYP;F<`````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-S0V`#$P-3$U-#,Q,#8V`#`R-3$W,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%P```!<(!@```.`JU*`````'=$E-10?4`0P."!-T-(1-````!F)+1T0`_P#_
M`/^@O:>3````"7!(67,```L2```+$@'2W7[\```%<TE$051(QX65VW,3=13'
MO]E[FGO:IDF:WJ`IK5#*50='QV%0T!E]<N#1\6]P1%]U?%"??."=$8<''WSP
MB9$6H6#+H`B.M*4M+2G-I;FG:9/=)KN;7<\N3D&!\LOL;+*;_9QSON=\?^O`
M2Y;1:G33:12F^A/]<IEF:_N>@SYP<'2PGP/L/;HTQ[!2ZLG]G<%G"?JV`]I)
M0R]#TV3HFK)]7Y3<8!B)*"+Q_726KM+ETQ2@LB.<P`%`GS*T_"N*7(3<,*&J
M39B&`8?#`8;EP/$\6&AP.44*Y`'#AXGHG*3'/[0".%X`CE+&Y]7&VJE:O0IE
M2X-IFMA2M@C*V`%8E@4O"E`;3:I(0\`G(MC>!4'JM@)8%7S\`GCM*O3R\5(E
M2V#5!EM%6F?3-)!-I<`+@ITYQPMV,,-HP>?SH+>G!ZP0L21ZS_&<K/?)]<*=
M=&I1*!2J**P[X!:;4#3I<8!F`9L*`TEDH%37X`OZ$8N%X/5ZH<@U1*,!A,-]
MU.>(RCTG\:_^N#,C,)P?+E\G1GM\X#@6AI6]=9#>EN:R+./^[!Q6LCED"TD<
M.]J'5JN%U&H.[>T=$+B6\`S\YJV[:.\<(`!#4,YB498<&/I2DQNH5JN8&!^'
M4J^A5B^#9^KHB71#;7;9E>77,NC?W8^0I.,_\/$KU_;,+RSVQH>&$0@&[%F2
M905;6PVPE/WFQB;6URM(KMS%ZX=C"'0>@4M4(9#^O"C9#,GI1+5202A4`_,T
M/)E,'V<Y\5"5`,5\CIID4*;KT'7-KD)35>1S>;0Y?:3S;H1#3H0B47`"3_>:
MMJE$2;(GR%K;<&JD*(K\0+5:ML=,536L)!+8W*PAD5C![[=N(I7.8#691B&?
M1F)I`0U%MJ%RK09)<L+M]4&@"JQQ!8FR+4MB)1TQ#?VSI>5'5%(7!6MA@V08
MC,=)%H6"Z4AE"/IPF:K)06FT(YO)P%NOP^OWPT]-M/K#TWAZ?0&8#M<3.,^S
MWTU>GX;'YT.I5(%*QF@V5?P],PN)-*W598)N/#8U(U)`S9:IS>6RG[=ZTM);
M-/<L_`$_!7HJ\WMSR\.]O3UV<QH-A5QG0&^1M=LD^'TN9',YY-;2MNTE=S^:
MN@][]HW:)K(,I9&,EIE\@7:XW1V4`W-]6_-T>A7KE%DRE<'"@V5RFQ>Q[BZJ
M0$>E*A-`A-]/!HE$:#0E)+,R,O3?9H,FB>5LN#7_H<X@;6(>2XMO;'BE7.R>
MG5N4\H6BW4@G/>SV>)#.%+%$@0K%HFVD-I>;LC,1CL;`2^VX='76OLXP#C*0
MM8$Q<'D&FJ;#^05AK]FR3-V\_6DAO]9?+A5)!C=84<34]#2*N2P,F+:>09I[
MJ[$T4F28!LU_':7"&J:G;N/XB3=H3^F&SQ\E\<5O&;;M2]CS0BM7*.L,RYI6
M7?E\A@S4@2I!LVM):G"`++V`Q+)!.YX+\N8&5>5%B_35=`/S*W6<X*.TQPPV
MX.#/$?WK9UX6ER>GYZ_\>7>8K58P=N@`9A\\Q.&](WA02N"=L7.X/#&"]/I^
M'!N-@W=[,;^8P)EWQS8Z0I%K@4"/)HBN,__?2KA_#73Z_E(J/-P=1M_A`W"0
M&?8;^+DK)!Z)]7\?"P=7P6,$!X?B&**M8<-PX(-8#+OB@Y\XG=[S+WKA,`1V
MW5M,OO_7HXR_IR,(,]B)WR9^17O0^Y92^B542>>Q^LB#KF@9\5U1I%7@QO@5
MRZEG14&X@!T60T9YL\ZP']VY,6G/*ZO3T^H&U*WQ0%_\HC`S<PKERFN8OLZA
MN55#E>:]36`P.KJW1*^RUDYPCF48>$P->P9BB._NO^1TB@'UX-:QCJX?<>&'
M`(Z^>A*R4L>^`W4,C8Q='&SI1Y2AOGQ'P#N!EZQ_`"(<=I4@?G\V`````$E%
M3D2N0F""```````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S$N<&YG````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,C(`,3`U,34T,S$P-C8`
M,#(U,#8T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%
M!]0!#`TZ&N+>UL$````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2
M`=+=?OP```1?241!5$B)[91?3-M5%,?WZ+,Q,5DT\N2;\<7,9#&+;A))IE/9
M&&$P!TR@T(Z_A?X!A#+@5V"%_A$H'<46^@_:THV.EK$"!=8"\D_*O]+0ED7%
MP6"P`2V.L*_71C`SX\'$!TT\R<W)/;GW<T^^YYQ[[-C_]J^U*E&]BL'DFCJM
M]U3_"-`Y/!+>:Q\,BNMD09W!#(=S&%K]+5`"<;"A45'J]?K?^]M0A]-YW=C>
M3I575*X4\BA\6R^#4J5#J]X(N5(-@:@.:9EYX)55KJ2DTJD^NYUR.!R4G?@.
MLYERNQ>H9\_VWCX$[N_O'P\$`I->KW>RG**>DP6*ST=V#A-Y+#:8N0164@)I
M@PPL%@NTU#0PTC.@4"K!YA:`SZ\`C\<+W6EKTV-]_7'$(9R\%+:QL0F'PPDV
MFPV!0`!K5Q>YQ$=I:2G$8C%8>2S8>GI045&!S*SLD)=()"@J*D9-30V:FUN0
ME9U#Y'/.!H+!=P[A.SN!L)F9671:+"&@7J]'1T<'A&()R9J%-K(O*RN#S6:#
M3M>*@H)"J-6:T*,9F=DDI@OM$Y+I6%[^I>8%G54Z?027Z*LWFJ#6:*'1:$B6
MO9#+FT)0H5`(H4@$E4J%_O[^D`0RV4U(I5+$7DF`DLB3D96#F$0&ZF1-NUM;
MVV<.](Y0J+2/JFL;H=:VDHS-H(CFOT.X^070&PS@<#@H+BY&?7T]2-$(M`%W
M.CO!X>;C6GHZ&N5R7/HJ$9%QR2BAJN#U^2(.X&]=YPN6)#(%&II:D)A$P\78
M*SC[Q05$QL0C_FL:N`221F>`<2T=<?%7$143A_"(LSAQ\A1BK](1<2X2'Y^+
M0E(&!^55(OC\_C\+.N]>D'(JA:#S2(=PBY'(+,+I<]$(_^PBHAE,<$F<_4TY
M\OA"I.<6XO/H>)S\Y$M\$/XISE].010]%PFT###SBV&U6A<V-S??/83WS[C#
MY*X%?$C/1IN!Z-[5`YFR!4)Y"V)NJI#)YH+Z3H/S(AE$DEIHC;=1(FV"0%@+
M1FDUDIM;089-86PWQ3]\N'+BA8*Z5M9/BP9'422N]5E&IY_GBNKA7O#`/.M%
M8H,"T^X%3#WX"6/$^XBO-EG0<;<[,#8QO9QKL:/N]IW-W=W="R^=ROO^G^>U
M]WHQ,C+6G-WMV$NKJL:B;PF6D0D,C(QBP.5!DK(5W?>=,#@F<:E9C[ZAX67G
MN,NJM=GWIERNRR\%KZQO,O*'7#N)G$(,C$Z`V6Z%SFB$=7P:*4H][MKZ4-4]
MA'@BP\24Z]=J2S]R%2WP+/IPP]*'2JT^>.1?(IGPU*0:.E%21OD#@:")3*OI
M\<833_G@!-)OB#`WYT;C\"0,O78L+2V=V=K>-@6#NP],/4XDJ-O1-SEU--RU
MNE%C&_]A3:%0G#J(3;H\[UOF%G\T=W8YM[:V:!M/G]+(WT,C;?OZ'^W[T<CT
M_!/#T/?P^/R51\+)P5?W]O;>^&M\=?71<5+YUXZZM[:V_J;?OQ1&SKUR)/P_
M:;\!A6TA6]/JZ=4`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,BYP;F<`````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C,R-P`Q,#4Q-30S,3`V-@`P,C4P-S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!<````7"`8```#@*M2@````!W1)344'U`$,#@$X"4K&1`````9B2T=$`/\`
M_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!&1)1$%42(GME%U,FE<8
MQWNYZV7)DF;+O-K=LINE2YIES>K,3#:WM+8ZK:T?M8K?K0HJ:A5$7D0J`A,0
ME8*"**!$J:`6OPO5^C696F$%M-M<M:*V*K@:^]\KF2Y=ZL6276S)GIN3]SGG
M^9W_^WR<$R?^MW^M\012548NW=!EOJOZ1X"VT0<A_8,C?I%$YF_5WX'5-HH6
M70<XMX3^VGH%R^7R?/2WH5:;K:RMO9U@5W!7BAD$:B1U4*HTT.K;T:!4@R<0
M(S6+!D8Y=R4Y)8T8&!@@;#8;,30T1!B-1L+A<!(O7NR]?P3<W]\_Z?/YIETN
MUS2;(%ZRV00(@H/LG%S0\O*12R5AS#)(:V7D=QZ2*2E(S\B"0J%$/KT(%145
M8#*99`P!G4X/KW<]]`A.WA2TL;$)J]4&&HT&'H\'<W<W.!P.6"P6A$)AP&_I
MZP.'!&7=R`[L'?A+2DK!KZY&4U,3;F3GX)[--N?S^S\X@N_L^()F9^?0U64*
M!&FU6G1V=D(@_`XYU#QH=3J4EY?#8K&@I;45A47%4*N;(1*)`A>UM+2@N;D9
M\4EI6%[^E?]*GE4:;2B]M!QZ0P?4S1KRH(94.0"Y_#8)94,@$*):((!*I0*9
M6Y0R&)#)ZB"12A$=<R6@.BN;BJB$=(AE\MVMK>W@PWR'*E2:I_P:60!\H/A`
M_=#P,.B%1=#K]2@HH*.TE`&Q1().HQ%2:2U,)E-@/S,S"_7U#8B.3<3YF"0P
MB4JXW.[00_A[99Q;B\):):0-34BX1D'$I5B<BXA"V,4KB$ND@$XO1%I:.C(R
M,A$3=Q47(J,0$OHE3IT^@TM74Q$:=AZ??Q6.Q,Q\L'D"N#V>/POZ<,$A+>`*
MD,:H0#:=@?C<FSC[=22"PR(0D4X%G<E!?C$+-$XU,JDW\4UD'$Y_<0Z?A(0A
M_'(R+J91$4_)0@Z]%&:SV;&YN?GA$7QH=B&HP>[`F93K9#\;H.[N0ZVR"?SZ
M1GQ;I\;U_"(0MS4(%]9!(*J!IJT#3.EM5%6+D<[B(ZFQ%4*Q3*'3M\4]>;)R
MZI6"VE>\9P4CXR@1B=VF<?M+FE`"A],)XYP+";4*V!<<F%GZ&1/DZB;7*H,)
MQIY>W\34[#+5-`1QQYW-W=W="Z^=RGN>7QYJ[O9C;&RB,;O7NI?*K<*/[D68
MQB8Q//8`PW8GKBFUZ"7G0&^=1G2C#H/W1Y>MDS/F9LOPWHS=?OFUX!7O9GKA
M??M.//GKP^-3R&TWHT7?AIZ).5!(8(^E'Y6]5L1*Y9B<L?]612K-5:C@?.1&
MI6D07(W6?^Q;(IIR\E/T76"6<SP^G]]`3JMA?>.9DSTRA4R>$//S"Z@?G8:^
M?Q`>CR=X:WO;X/?O+AGZ;(A7MV-@>N9XN'UU@V^9_'Y-+I=_>NB;MCL_-LT_
M^LG8U6W;VMJB;#Q_3B'?'@K9MF__T;Z?C?VP\*QM=!Q.SR+W6#AY\,V]O;UW
M_NI?77UZDJS\6\?%K:UYWUUZ_#C(N[[^QK'P_Z3]#NY%(78IO;S5`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\R,W@R,R\S+G!N9P```````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S`P`#$P-3$U-#,Q,#8V
M`#`R-3`V,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-
M10?4`0P.!2OIF$*>````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+
M$@'2W7[\```$34E$051(Q]75RV\;=1`'\._N;]>[F]AQ[&2SJ>V$Q"GN(T%)
M$:6HJJI&JN!0U"(A@:JJ'."(>J"%?X`;$E)/E`-"<$-4A0-2RR-$"A52TU9J
MG+2TC1L[B1V_[7C?+WMM3AQ*XQ:)"_RN(WTTFOG-#/!_?=33@LGE9"00")UP
MFJWSY6H-+,?"LRV`HN!C65"$@<#[(`U)\#'D1JE<^G@@'-Z2)*GU5+Q<+A]Z
MF%J[TNK0L;[^('H$`0Q#0'6`=J<-FB:P'1N.XZ)8+$&5ZWAN)(J]B<3[HBA>
M`@"F&WYG:>F-WN!`+,#S8`D!R]"@"0%+"#3=@*+*N'WS!BS3P'9#0:O51JO9
MPD0\?@Y`=SR=3A^]>^_AAVU513@4!"@"3;<`=,`R#!K;#11+!:164]BW-X'H
ML-BF"7,]/CX&@>>R?SD[XE]^]34M2A$F&HVAN)5'9'04FJ9#$#CP'`?;L:'*
M&F*Q73AS^NT%01"N"H+PZ=\=>B?\U,E3GS4:,@C+P&EWD"^44:Q442I4D$YG
M8)@F-G);L"P+GN<M[@1WQ=<W-N*YK0(:L@)9UI!97T>HSP^WY2*;+^'V[66D
M5E?ANBT00KK^MB?*8EG6A=/OO,N*4@2V[<#03=BNB]54&C1%P71LR(H*"A1J
MU6UXGM<5?R+S;R]_?R04EH@D#<,P3%2J=50K=9B&"9JB4,R7H32V01$?:MMU
M7+WV8U37M;Y_A"_>6L*`**)6K>/1HPPHFL+H:!0^E@6A:03\/>@`"`;[0!$.
MRROWSBXL7'_QF?C<_+PODUEC4P_NP[0MM-L>]NW9C6;3Q<9F#NO9'`C#0!P2
MP?$\^OM#R!:K6%KYX^+<_'QO5]RRK%[7;5[B>?:$;3O0516&IN'^@U4DDRLH
M%;(P31->VT.KV01#*`Q)0Q!Z>O#S+W,S6X72@N=YNW=L*,,P(CIXK]%04*E4
MX.,X]/;ZH<C;*!;RX'@.FJ:!81DXM@6:)@!%@V884!2-I>3*2_OW/'\<P-H3
MB\OS/+*YF;LP]^O")[\U&NALKB,6'(0Y%(:_44>SG8,HWL2#I`9C^"RB#(UP
M7Q@U'XN@7%O;,SZNS\X>4R.1R%N$D/)CF1-"/%TWU>D#,V!*14P<?@7%=@>1
M'AY:-0TQ]`5B0V5\7I80F)C`[/0,LH8!UC(7=X\</3,Y.97I6G/;=H8SZ[D/
M?J_+B`T.P/2`I*K#4FH8[+L,73%P9R6$B3$'8;11E$TL*3HL0U_8"7X,7[R5
MY%>R^42^7H/(<U#<)OAJ'FKM&P2$G_##M9?1I(]C>2V"@?X0JK8!L>4HLT<.
MWW_FA/;[_6CY?)@-"A@;&STGJW=?5]WKKTWL_P[S-T9P\-";\/AAS!R4K:D7
M)L]O%LL@=&]-DJ0KS\1'1G=M^55MG*(Z:+KNIJ$IONDIXUB^,,N)@R<+\?C4
MJP[%&(%HO)U()++_^@;*<N.C]%KJ8JU6._"?.]!_`M&T_1.&-X+T`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0N<&YG````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(R-S(`,3`U,34T,S$P-C8`,#(U,#<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```7````%P@&````X"K4H`````=T24U%!]0!#`X()B*'0&X````&8DM'1`#_
M`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1'241!5$C'U97+;QM5
M&,7/O&PGL>OX%;NVD[1.<*LF55-$J:"H(JBBBZ(6":E20=W`$G5!"_\`.R2D
MKB@+A&"'BHJ$D%H>(5):$$E+2>RT2H)CYV$[CL?OQXS'GO&#ST8L2N,&B0V,
M=.611_=WSSWG^^X%_J\/\Z2/@6#`;3)9SM2T^F4QG8:@TZ&A*IUI.D$`P_'H
M-0AP#CC!\_RL*";?MUFM<:?367\B7!3%XRNA\(UZB_'NZ>]'C\$`@><[$QJM
M%CB.@Z)445-K2&YOHU3(87C0@X-^_]L.A^-:F\%W@\\O++QJ--N\)H+R!")E
M?PZ.15FN()\KX-[=7U"IR,CGBZC7FZAK#8SX?)=H>G=X)!(Y^>#ARKO-4@F#
M_68P#`M9ECO?V@L4\GEL)Q((_1["H8,'X'4YFBS'W_'M'Z8=ZJ-_<7:$?_K9
MYZS=N9?W>+P0">+V#D*29!AH%P:]'M5J%<5B&5[O7KQ^X?Q,3T_/31H?_IW#
M[@0_=_;<1P7:JB#P4!M-;&V+2";3I#:)<"1"5E00C6VAJBAH-!IS.X&[PM<W
M-GRQ>`*Y0@GY0A%KZ^LPFXU0ZQKB6R+NW0^2)<L49KT3;+?G,5L41;ERX>*;
M@L/E1JU:@RQ5"*)A934"EF%(;14%6K2M*Y/.M95WA3^F_,OK7[]@L3LYE],%
MB:HBG<XBE<I`H458*L1$0NP$RG`",KDL;M[ZUB-)Y3W_"#Y[_S?8[':D,GFL
MKJZ!85D,#7DZ_K/T;C+V47<P9!/Q.!V"BP\OSLS<>7I7^-3TM&XMLBJ$EI<Z
MH36;#1P\,`)-4[&Q&<=F-`9.X##@L%+E],!JL2*VG<9"<.DJS>WK"B>O^U15
MO68P"&>J;:_+!1IE+"V'$`@L(I6(0FDO2!YK-96"9.`8&`!5"K[_86HBGDC.
MD/^C.P9*S>%`BWFKW6VBF(*>:MIH,E%X622IUO4&/<KE$BD7.J%RU*GD&:AY
MZ(?!0B#XS*$#3YTB5/BQ@XM6Y38W8U>F?KS]P>U<#JWH&CP6.Q2[#:9\%EHK
M!KO]+I8#9<BNB_#P+*QF&S*4A;F0"?OW[Y->FIPLN=WN\U2>XB/*Z8^&)%5*
M$T<GP"<3&#WQ'!+-%CR].DBI==BLG\`[(.+CE!,FWP@FCTP@1C;Q57ENU'/R
MC;&Q\;6N=4X^NT*K&^_\G,UCG-3*M28"Y+E%`RF\#JDH8SYIP<AP#74TL5VH
M8%XIX[!6F=D)_$B@<[\N&!:C<7\\FX&#_"VJ*@SI+90R7\#4\QV^N?4L-/84
M@F$W;/T6I*HR'%JM.'GB^:5=.[3?V(NZ3L"DN1?[]@U=*I8>O%)2?SH]<N@K
M3,\.X=CQU]#2NW#T6%$9/SQV.4SGC9[MR]#%<&-7^."@-VXLE?<S3`N:JFY*
MY:+NR)CTXE9B4N^PGTWX?.,OTTDB&[VC3;_?'_W7=V"AD'\O$@Y=S60R1_]S
M%_0?:KSYDAO1_F``````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,C-X,C,O-2YP;F<````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,W-``Q,#4Q-30S,3`V
M-@`P,C4P-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)
M344'U`$,#@@YKX]-FP````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``
M"Q(!TMU^_```!(E)1$%42,?=E4E,&V<4QW.*JJ8'#CWU$''KL;=$RJ%*155%
M:E5%;9I(M($$`L5E"1#,8H*-V6R"L3TVB_$V-EXPBUEL4XP)F-7&E8VQ30HI
M!+$(C$&J0(2E+/KW@U91$.H2M:>,].D;??/F]][\WS(7+KSUEYBJN9SR,#?:
MY?%>_E^`FYN;[ZY%(BD"J3REFJK;Y0MKT./HWU72^I2YV;D/_Q-\<-A5)Y$W
MHD&M0W?O`+S^23A'W*BDY*#JE3Y3JSGJC:&3@4"4J$YQ/9-9,&LCT,E@"&W6
M7G3^^!2:9@LZ[0.(9^3@9FS2/IM;IN66\3_^U_`)_Z2675X%?4L'^H=<L#H&
M42R0@55.P6RQPSDZCK0\+CZ_DXA/OO@&=^XF',Z]F+_[C^#CX^.HX=&Q_=)*
M$8%XX!AT067L`%^JAMK8#H_7#W&#%@D9!1#+]9`H#$C.9!'IM)OA\%K"J,OS
M_CFH3M_T7@E/>*^SV^ZK%M?`:+:BU>J`WFR#4-:(K,=\E`IEX)(O>/"0A1JE
M'CY_$/Y`"+:^(=0H-*>Y4>E,JW*%ZLH9N#\0E#'9//"H!IC:;9#K6M%BZ<60
MZR=(54;$,7(A(D[J-,TPMED0FGJ&V=E9#!")3%UV]/2/H(7LC!P.*JJ$SU=6
M5C\Z!>_N[E:45PJ.^1(EI$H#QCR^4T.;8PC-G3THY%$H(JMO<`S!J9\1"$[!
MWC\,?9L-S.(JL,J$&!OWD7>-N)V0#F8A&UZO]\8I?&%A012?G`I*KH.IHYOH
M.HDZVH32:AE^8')17:M&Z-DTIF>>DXBGT$UDJ!#+$9^:CQNW[B,YFPUV90V2
M,@N)/0>YCXLQX??_`7^YO5U!26N/LPLXJ%7I<%+;^:5"W+J7AL^^BL/W684P
M$"EH?3-4^I;3'-Q/S\>G-[]#S)>QR,CE@%E4`2:['(F,##0H5/MK:VLQKS1?
M#J_))&8+&CLL>%(E0![QGL$L0)%`#"95A]2,+)3PJI#ZB(78^"3D%_/Q(#4;
MC(P<XM0$0U,S.,4E4*KI+:)WW)F$:GN<T0+:@'JEBD1/(Y<8>GT^M$_.(($O
MADI-0ZLW@M;JB`T-]<@XNNQ]&!P:1@FM`U5;#X>C#^%P>/I<*<YLOG0Y)P*P
M$X-$F1:W241JC1:2!@7XU6(,N#U(%U`PM+:AH\^)Q$HA:)T.C21B*=T(M]N-
MB8F)W.WM[;-U_F+CUY@"[_1Z(HN#KJ=.I)!D<DK+2?:U8$KJ(1"*4$+:_FN>
M"*,N-R1Z,_@*-0S&)CPB/4$UM1[N[^_S=G9VKIZ+6C.S)&+TCB([CW44^F6N
M8'IQ>6M\W'.85OX$L?F%$%,2)).*X:HTB$36?^OM=\(?#,+<U85,DA--BWGO
M+UO>/K\JJF^W[-!:?<JKX34UPVNRV"`E6EJMMA,M;7M[>QU'1T=7R#TL%@L4
M1'\&FPM_:&K@[^;)M</#PV]?/SLX.+BZLK*RO+BXB*6E)279+_YI>W%C8T-Y
MTIWS\_,(A4(@<__Z&X]>`OJ`.(DFZ]+KY^OKZY>VMK:B"30Z$HF</'_G[?KO
M_@ZS-5'U%_W%?@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\V+G!N9P``````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,S4Q`#$P-3$U-#,Q,#8V`#`R-3`W,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````%P```!<(!@```.`JU*`````'=$E-10?4`0P."0]Y+NE#````!F)+1T0`
M_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$=DE$051(Q^64ZT^;
M91C&]TT_:C*SQ2_N#S`Q?AE&C7-3!\;)W)@CL@%C,.T&*[@,"AOC6*2401F'
MMD"!O4!+Z8E"H92VG$HIAU):#J6%KH@K4"HE@`8Y2';Y4..298FZZ"=]DCOO
M\SYY\[N?][ZN^SYTZ#^]RGF"UQAIZ<>HQJ9C=KO]I7\%.N=R7:"$$AJGO-)<
MSJN"L%F.4FYU@6UR\N-_!#:81B*K*?%&K4@.E48/B]6&?M,H>+5",-F<Q;Y^
M0XO7ZWWEA<$=&GU"617U*_^A&-(V#:AF)23*3LC(OKM_$$)I*R*_N87L//:.
M6"*C,G.8?S\)B\/=KA7*H-;U87#8#+6^'R*Y"OU&$WH-)A26UX#.R,8EDN#,
M^0BD9S&I/P5ZO2N'JVNHHP3&S<HO?B)OUZ&KUXC6SA[4"!4DY-#W&<&M:40L
M_2[*!$*T:;K)LQ&I605/!HPF;E)*QE&W^_O#S\%U/7T.GH!"";<F4`JA3`5%
MAS8`26`PD70W'SF%7,2G9*.^20:[PXGI&0<ZNPV0M&J0DU\,1F8^5&KM\M;6
MUO&GX-$Q2U1N8=EF15T39"H-FA7M:%)T8,1BQ4.Q$M$WDG&_3`!M[T"@YA/3
M=A(S:._J04DEA6[#8."OTIC%B+YV`Y-3]MF]O;VW`O"DU$S.P4</JAI@MMC0
MTJ%#K:@%Q3P*M^\5H%[<0LZM@=N.3TRA7JH"D\-';-*=0&)!HPR9K-+`_G1H
M&*JJJ[&PL!`2@'=V:3GW\HI`'`*E6H?\4@$24G(0?I6.Z\F9T/8,0$=NW4XL
MJ2)UOIW!0EC4=9P,C<"7,3>1D,K$5[&)B$U@X--SX>#Q^9B?G_\=OK&Q^<:(
MQ3:=R'Z`.%*WD+/A>._49SA^(@3O7H[%Q:_C<3X\$N?"+^.+:W0$7Z$AZ(/3
M>.=$,(*B:7@__P%.!G^.T+"+B(J^@A:E<L?O7_LH`/?M[KWM6=^X6;6\ADOJ
M'K"*BHFO6U$G5^`3PS@B647@B:6HD\AP=<B&TR5\(B`+>=QJI/`%N%!9AV]S
MOX-$K8%>KV\CS17U5%#:VAZG8LD/\\0D!`V-D`R-(LWW,S2DSBKB[7(!\;5[
M!;FF,?2,C**2HB"U3N&2<Q%250?QO@'QSL>@R=MAM5I+G[%ALO,'3DQ%)>H5
M+;`NKV!BR8MXO1'I11PX?*N8]BRA:L@,.OL^[$XGIOSK,,\O(*&N`36B)AB6
M?>"WJL%@L4$&6\<S<.++,Q:+A5O_>`5G!ZUH$(D.!,&T<Q9LWR8B2/L;AX:Q
MN+B(U>T=!%MFD5$OA-OMAI$D/C6Y@&RBUR.W6^/W^U]]KHGV@9>=O^RP%>;Q
M;>G@\.X=EP>UK2K85G[<%^FZMPLG'"@A7G:Z7%#//MINZ.W?SYAQH[E+BR['
MW*YI>'1[<_.GN+^<+9<]ZV_&C=GG>&()4=U//SA+G/>J;RE4&!H>5A^\:S>W
MZ#$VUXY0V0:7R_7A"TU&`@TB\53UI:6E(Z0L-(_'<^2/,Y_/%[6ZNDHCW?CZ
M"\'_W^LWJ\Q!*,SHX7<`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S<N<&YG````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-S(`,3`U,34T,S$P
M-C8`,#(U,3`P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T
M24U%!]0!#`X)+:Q.J*<````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(`
M``L2`=+=?OP```3'241!5$C'W95=3)-7',:]WY9X,1>CB9+L8EFR9":[<4NV
M)6YLN@G;Q(P%A2%HJ%I=87:T(J"EK:58V]*6\O:%?KS]+FW?0EM*H7PY*()\
M^%%IL!0EPZDH6#53!QO/7EFVS.F\,+OR)"<G.1>_\S__YSG/6;'BA1XC(Z.K
M?C@B2..5'TN[,CV][G^!SL_/;X]T];)L3O<9A48'E99$I*OGOLGF8BTL++SQ
MW."[=^_FFAWNE,GN09.W&=T]O0B&PG!Z_2BM/(ZC`O'(Y&22OA"[2-^[=X^>
MGIZFIZ8NT[.SLZ\]$QR+3[`M#L^B4D?!W=(*AZ<%!35:O*[T89]8B=7:%JPT
M]^+-@A*LEUD@L/OPKBX`CMD#K]>;]DPX97,^4)-F^-NZT!\]C9Z^*#@*$NEZ
M/[:4G<1'IA`VL,OQ#JL4Z4H+,A1F;*%"(-S-F)B8>!(^-S?W*F6QKDXDI^JJ
MI(HE!]V*]IY^^,/=,#E]X$K5*+8$D"^J!9MTX>M=^U"M(E%M]*#F=`('Y034
M=?6UJOK&=7/S\Z\\!N_K'XB31BNDRGJX_6%0KA8T,Y43YB8<KJI!(8>/.D\8
MWPMET+5TXJA$!H*RPD!9$!B[A)R"O:@0R5!:(49O7S3,"+YV&7SNW/D\H51^
M1Z.WP^8)PA-HAX'IX^#(6?A"G>`<%B%[-QON0`A<WA%T_!A%-],NJ5*%JN-2
M=$4'4<*O@*NY#04'>*A1J'%]]N;F93BGM$*N)$R0:8V(#HX@&.F!WNZ%CG*"
M6RE!+6&`O%8-0D="*!+#9K>#)$FP#G*QOX0/J\V![-P"%)=58>>>`Q!*3F`R
M.?4GW!_JD/,%$BCJC?"U1IA#]#C(%R*WJ!@[BDK@H@-P-'DADRM@LMJ7J^7R
MRI#U31Z^R,Z'4%R-3&;-+>)@#[L81(,>UZY?W_R7I]</#8_&CA$.;-I3CL^W
MY2#K6Q;>3\]$1DXA,GA:?):U$QS^,6S=+\"G&5G(RLG'QH\S\6%Z!HH8X/9=
M;.PL9-TGR(;;L5C,P#!7_BVH>VHAC>L>Q5?[RJ"IT^+L^0O,=6UH]'7@@ZIF
M5,M5B,1OXI-*.T*A-G3T#T.JT*"[NQL7+HXS@I?"2_L:&.A+3U@Q=7^AEFPY
MQ?18#)%,C1IE'=P>+PA/")E[>3@U-`I'7VS9EA,_WT:1[1Q(LP,#`P-PT\W@
M'2Z'P^E".!Q^W.>IATMKC_?=OGQ(W02+W8G=/#&V9N=!JS?CA'<`I(&"S=^.
M[^3F9>M1_4F\?8!`K58'KE`.\4D-:)I.)1*7QB8G$VL>@_?\]+M\4^/E9?%.
MC\7`%JE`D(W@&R+8>,B`\J-5$#$B2^L-T!N,J+?Z4%)9C?93`]A6%T5A)=.R
M2(1^ZG/7C#V4?RDP0B*M^>W&C1O\F9F9.]=NSCW8[[NRM'D'"R:*`F$PH:%1
M#Y?+!8%0B&!K*P:G4]C`<\+D#OPZ/C[^UE/AJ51*WMG9^4LP&&3]<[\M'!Y[
M5*E*K89$4@W*;(;19$*XO1W)9'*$R9&'1J,13")V_6=0+2TMO;>XN+CCW_M,
M?&YG)BL>CY]Y5+5:HX'LI!QFBQ7Q^'C^K5NW\A@PB\F2-<^=[<SAJP:'AH:;
MW.YX(I$8MCN<:5>OSKS\XOZ]?P!QNF5#<63?I@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O."YP;F<`````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C$V,``Q,#4Q-30S,3`V-@`P,C4P-S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@H#6[7VJP````9B2T=$
M`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_````_U)1$%42,?ME%U,
MFU48QY>H\<ID1A.],KLS\6)9XD=V8U)-U"V.&&_<$C5A;FI5DADZ`Q,W8*)-
ML*64!<KZ34O[]D/6#V@I:Z"#KO2+"MU&`[*F@$A9^9#O0BG\?=XWMHE1TUUJ
MXG-SWO/DO+_S/__G.>?0H?_C7QD[.SN"6"QF2R:3MH6%!1L;(R,CMG@\;AL?
M'[=E,AF;W^^W34Q,O/6W@'P^_\KZ^CIO<7&11P!>.IWF1OJ11X#^%XRW\$EC
M"][0]^(992]>K)?BJ$B+=]H,>$]IQ9O-&JA4*OY?P+E<[M3JZNI2(I%`(!#`
MX.`@0J$0V'DJE4(P&$29(X37*JI09@_BY;-?X-6J[W"R1HA3>@_*##=Q1E"-
M<#CLV=[>KBR"]_?W'\]FL_*9F1EXO5[H]7IH-!IT=76!C@HZ*@:'AM#@C>"T
MH`;?]/CQ8?E9Z!@SKBDUJ.T=Q@6-%?P+7\+C\6!N;FZ*Q#Y1L.,$V8')R4D.
MWMG9":52Q8T.AP/1:!2>OCZ8`C_AXXN7P-P*XWV"B]KD^*KZ:R@<'E34U$&G
MTV%@8`#3T]/8W=V5%.&;FYM@E?M\/G1T=*"IJ0D223/K(=QN-SIT>MST#^,\
M_S,P=B><[EZHC&9\^GD%M`8&#4(A9#(9G$XG=](BG&QYFN`VUMO^_GY.L4*A
M@%:KA=5JY=2P&[#SRDH!?A")(&UI(5@[&AL;4555!:/1B/;V=D0B$5!#@`07
MX2=H)U!78&QLC+/&9#+!8##`;#;#Y7*AN[L;<KD<0E(HD4@XJ$!P$6JU&K5U
M=6BB'&L+VPSD.<CS(OPP330K*RO[U+=<45JO*]'6)N,LLE@LW'$55(?FEFM@
M&`:UM75H;6V%W6Y'J^PZZJ]^R_W'BB.1^Z3\^S^U(ZD7KZVM,?/IA;FR*RIH
M]$:V%3WD(4/%9OI"<>]5N0D#/I^7S4U-33&Q.^.>F@X/S@LNY\D.ANQE6,X_
MWL:EU<W7NX;BN?O))+:S.\<*><?0J&5D[!Z6EY>/%W*)V<PQ7SP)7R"<+7G-
ML[G\4U?,P1N,O?>`E#2098_^85W[!]*>`ZWE!GY;6R_"HS_/)\2=+M@=SG=+
MOR&Y/;[(?1<*G0FSL[/51<MR>XS+'_LU$!@64GV>*^1MH<FT0&J`2"SFE83_
MDEGA)^[/(!R)ODW^<Y!<_N"1AIZ$I5']XQH5J[RX]L'R8Y,SZ871.W<-U(*'
M2\*/USOXIR\U(Q*-^@JYO?Q!N3J0@E2MQ\;&1ETA?V_V@>:,V(&/SIT3E@2S
M80Y.\>U>/^;GYXMP\OOYS-(RGVXPG[Y?*N132^L:AW\4_MNW'P[./CA4R"/T
MD#U;:BU[L\FF(UM;6T\^%/P_%;\#;:TM9R1/3*(`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\Y+G!N9P``````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C(V`#$P-3$U-#,Q
M,#8V`#`R-3$P,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'
M=$E-10?4`0P."A389G-L````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2
M```+$@'2W7[\```#(TE$051(Q^U534P341">=K=_M*FEK>D?6&M#RD\T)(:;
MP8,:#T2/&B_$:X_&&(U'3\9$8^3BP8/QX$$$B7(P0M&8&)$8@E);+99B(:B5
MMMMV6PK;=IUY=!L@!#T;)WG=M_-FOOGF9U\!_LL_)2IE4RZ73^%Z)`@"%(M%
MIM-H-*#7ZX'C.+:8@TH%LBS#^OHZK*VM0:5286<FDXF>`T:C\3'NI[:`(V!T
M86&A/1Z/0RJ58J`VFPT\'@_;;Y9JM0JB*$(NEV.+R!`1A\,!75U=:;O=?AX#
MC:K)&*-?6EU=]1$3E4H-/,\SAI(D`>H98*U68VP)J%`HL``ZG0XL%@M;M"<;
MS-Z&9\?(AZ<?3-.-8#J*CF^,%0$1"*5=*I68(P4C4`I<)\7L2%<O+?,EVP:X
M6JU^@`YG*`@94A`"T&JU+`L\;Y2&',F&GA24%@&2K=/I9%DH_>'K9<P@H$1-
ML5JMS)E8*.6A?3Z?;]1;84:-I3W9$"$")9TB"G@''A@INL%@8`Y4:V),I<`)
MV'"L`U)0);`B1(S\2:?H64/1\3E&3IC-9@%3DSY]%^#;KQ7P^_V%0"`@>+U>
M84^S79Q9_`G98E%N;6T5W&ZWX'*Y"K+6"*\C,<!WR>?S"5B6602_O>/@BV+I
MXL!HJ/)P:$A.)!+=BGXV'+O\=NJ]G$PF1Q1=_&O2^^)#;.;JK3MR.IU^LAV+
MWZZ8FHY(7KX*G1W=@\@F66]B\/[(V+7%5!+\)L-UQ=9B-5_(1<*5<R>/2YCU
MP'8L]>872:KTYSC^QG!H@IN+Q:9Q=C/UQO5Z;&:MUV+^@64J*O:I;.'L>/C+
MX?FEQ2J6=6)7Y@C>=-!MTUE/]R4#;6V3BCX<F8>BAH/]3L?=GIZ>647?;#)`
M7W?GY(&6EO&=2KR%^?";&;@7>@G9;'8>&_MJ8_1J)Y96A*.#8R&(1J.-\<#Y
MOO+LW4?K7#;C+HKBT$[@6Y@;]/C1"!EP'6IOZ#A./98OB#=]3M,1I\/Q.1@,
MUN^B<HF3)7DOS^W#WEAVO15)\&[IQ%NQ%V=V&6?[Z9^N5/RP^O$*:");[,_R
M_S^9OY+?L3F6MH6:6FT`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R]N82YP;F<`````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C`P`#$P
M-3$U-#,Q,#8V`#`R-3,Q-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P."BF`#C]]````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```$#4E$051(QZU524NC611-45V;`J$:;&QZ%7"E
MX,*%&'#A3GJ;6KF1PEIHH#<BBJ(_(+@0)8)1-\ZS\FG$67'6<HSS/$_@F,0I
M:M3;YSPZ4K21ML$//K[AO7?NO>><^YY.]\9K<W/SR\[.SI_[^_M?=.]]]??W
M&P8&!F1P<-#P+H`S,S-_'!\?^XO(;^/CX\;*RDII:6DQ\OOZ^MI_>7E9[_%X
M?OU/H(N+"S_<ILO+2[WWW]34E'UE967XX>%A_.SL3%I;6V5[>UL>'Q_'3T]/
MAT=&1@1C9L[ENJNK*Q."^KT`W]W=U2\N+LKHZ.B/R<G)3T]/3S$`<H(&.3HZ
MDKV]/1D>'A8$%(#(_/R\='=W"^:9[7;[IQ^XYN;FA#@OP-?6UC[8;+:O[>WM
M)Z#`#4`/`1L:&J2FID;JZNHD-S=7BHJ*9&AH2.KKZ[V!/*C.3<H`ON)VNW]_
ME1YDI"%SZ>OK4Z#%Q<4*J*.C0]K:VM3M#=33TR/@G3H(DEIP.IVAKW&NW=S<
MV!'9.38V)A:+1<K+RQ45_)Z8F!`&Y1,,2&]OKY25E4E5595*`IP[L?;[QL:&
MOR]:EF`WEJ:HR,_/5QD3C$(R`$%I1])275VM."=-T$G0!VIL=75UZ07X[>WM
M-W+,C#(S,R4M+4TB(R.%CHB-C15-TR0[.UM*2DJDL+!0@H.#A3Q#)S5&JCAW
M?7W]V\]T&.!G`[K/",X$[U):6BK)R<D2$A(B"0D)$A45I4`3$Q,56%Q<G$1$
M1$A\?+QT=G9*;6VMS,[."M<C<R.$-A!7!U!5-DND^A2,8J6FIDI,3(S*.C`P
M4+*RLB0I*4EI$!X>+M'1T1(6%B9-34W/]-&VI+2QL5&(JW.Y7`Y$<\"K+B^7
M>7EY"MQD,DE.3HX$!`1(2DJ*I*>GJ_&@H"`U%AH:*AD9&>H?`>DPB.Z"-1W$
M?:8';<P.$S82Q;1:K>I)$<UFL_IF5>29]D0RJD*"PX8"E\C=W1V;2N_+WY:N
MKB[%:4%!@2J/`K%<ZL".7%A84&Z:GIX6-)K07:3D'Y\KJSH<#LL+<#A%PW:Z
M=W)RHK*B@"SUWSXG**OY&9@!N57`BG94H/EL).QVX>?GYZM4WEL^*V%6M"@!
MV97-S<W*?A23.C$8*-%>;7OL)1\`^A433RHJ*M0BMK:79]+$;J1X#,;_K)#S
M*"0L:8/C/OH$/S@XT+-L`N/=AJU40T`G,V0',A"!F"T:18&C*YWW]_<:JK$Q
M..99X>_/OMK?#]R:\#2!&I4!JK!39+J(6K`72`'V$!40WW;.@RX?T2-6;LT8
MT[_I)()(&DXB"PX'/=QB)"U+2TLNV@W!+*CFF6<<$I^QA>A1R2__^\B#H`;R
MC8".=S^@D:EA:VM+#@\/_WKKFK\!A.A,H4.A^H,`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$P
M+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(R-S0`,3`U,34T,S$P-C8`,#(U,34R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`TW'<D4/2\`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1)241!
M5$C'[9-=3-IG%,9[O>QBUTN6F39ILHNNO=J2;=G:U2PN[46;-JFF:I5M\M>J
M5="J59E6IVA5!/P`Y4L004'`+Q0_)RJ*THFBH,8/T`ZFE<IF%;3.9__>N'6M
MS;+MLD_RYDW.^Y[?.4].SHD3;_1?Q.961=^AIQ%Z0T_T_P)TNESOS#KFM,4L
MKI8GJM]7JC20*=7[Q64<K7%HY,M_#;8['">;M&VSQ1P^&G5ZR%OU8*M:H"+O
MT'PV0I*S]B6:-G_3R(2_QS1&5PZ/^^>=+O_N[N[[KP7KN_M/RA3JT1)N#>3J
M-F@[>A##JL&'54VXFIZ+4Y).G*I4X8/P!)PME8#"+,?'=1V0M7?!Y7(%O19>
MQ*J\6E!6!7W/CQ@RF3$V_A!,62,BQ"J$,8IPHT**\Z'1"`[]!C=9M2!T`XCD
MRF$<-OVZO?WTO9>`?K__[:EI6U2=K"%*H=+L5]360:OOA:;=@!II(S(><)`C
M58#(RD%*>0W"*/&H$$C!4VJ@L"_B5DP\RCB5DJR<_"BOU_O1"W"!1!;$$TI1
M+9)#TJ!&7:,.3;I.M!GZ4<:O0UQJ%H2*1E#CDZ!L:0-/(`:GLAK5-4+TC9I!
M)-)121:CW<M#<TO'_-[>_MDCN%K782EB\U$E;D#OH`GUJE9T]AG1/3""YW%J
M`@T"H1BTU'2,CIDQ,3Z.G+Q"9##RH6[6X@&+"RG94"21@H*B$CB=SI`C.#TS
MS\&ME4'6U(J'D],0RE4HKQ8A*:L0S/)J-*IU4*E49`$1#`8#.KNZ0(E-PK7P
M;V'HZ</M5`8(6A:BX^C(8Y9@>7GY3_B`<<1RFYX))E>(:K$"=_-8"*<FX_(-
M"A+O_0"A5(G,[!RP>6*D9=]'>'0,SH=<P>=?7T/L'3JN1\3@%I$$2AP-=7)E
M8'-S\^(1_-&3W:!:RQ.<#F,@G;0:6R#`%3*!EEV`3]/K\55H#!AL"<XE\!%!
MH2*7R4)P6`PHU'ADE@EQAF"#R,B=:-9J%1Z/)_*%@4IG`D&I[2Y<CF5@UNF!
MN-V(:=L,#(L[.)>I0XN^&Y.K/MP5=,$Q-X?>J14T&P;@=GN0W+*",&83IJ:G
MB5>O^M:^R6"V87+*AI2N=5Q*X\&YNH:A!3?8]1K,N[=`;QC'H&4&,QL!A%2,
M0]G:O;2QM2VZKQB$KJ.K<WU]_:V7P%O^WR\2;9Z-J._+\9-C"1=*AU!$;N?\
M+[^!*C#";+%";=_&&;H<PQ-6B"R;^"Q5A)4U-]36#?":^YX='!Q$O++K>OL>
MZPO^/-)R"@\>^Y[Z1V9=_K5'/S^K-&\A.$-$VK4A4;.([XKEL-GG4J>=&WZ3
M=>[`Y=W!);X59:H!_['KKEG88Y4J##LRF8SXBYL(1H_;Q^&+73L[.UKWQF/M
MIM>K)9?C]//WP\/#1.NJ+T#ED;.P+_0?"R<M?1((!&[^/4Y._3IY+AR7Y_/Y
M(I>6E@CRS[LGWNB?Z@^1+`,I'!=0I`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,3$N<&YG````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,V,@`Q
M,#4Q-30S,3`V-@`P,C4Q-3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@
M*M2@````!W1)344'U`$,#@P;'H/)>P````9B2T=$`/\`_P#_H+VGDP````EP
M2%ES```+$@``"Q(!TMU^_```!'])1$%42,?ME5M,FF<8Q[MD,<NNW,6276W>
M[69)=[%L-TOF#MF:9>G:=6FLL4:Q'FH[8^N<4PG5>)A8)X+B/(&@*"(J*`*B
M4A!!!`45100\H18T'O!\C/WOE24F;=JF:7:U[$W>?/F>-\_O>][_^W_>[\*%
M_\?K#HO5^@TU.S^!FEN8X%E\'/VO0-?7UXO5&JV$55ZU5"<40]@B18-8>MS4
M(I&<G)Q\]5K0W=W=8(?3Q2\JK7Q252>"O*L'1M,0!H>LZ%+K4,BJ`IW!/M89
M!NWC$_;0]8V-X%>&&TW#_-+J.E3RF]`F4T+<K@"WL14BJ1+R'BW4&AW^8%3@
MQS`*J%FYJ*SA\E]-"E(%HYQSR&^2H%NCQY#%"OV`"<U2.=1]>I@MHRBIY",Y
M(P^9>0Q$WTW#M7#*$YU>7WYZ>OKV<Z&K:VM7^0W-4=V/^BR,OSAHE"@@[^U#
MG;@#C"H!\IG5X(O:P:H6X%92.NC,2O0/#D&M,Z)6*$%U;0-$;3)>#IT1M;V]
M_>E3\#IALX/-$:",R"&2*L`A"9T]_\#3<HH1>X\&>AD7J5D/4<,38-0V#J?3
MA;X!,]H4:C2T=(#-J<=O#PK`KN8QSL&J7DU^`;/BE$FJDBAZ(%,]@J"E$P:S
M%?SF=MRCTI%=R,:`>81`)P*SSV`.Z)]-9^)/-@=#([;`#B)OIZ*$77.XO[__
M=0">FD%C,"IX*.>)B*9C$,NZP*H1(+>X$DGI>6@D58T0H-TQA0G[),0=JL!:
M-)'G2G@,4F@%H)=R<"N9BIA?TL`BLA)I+@7@]DE'?AHM[S3W(0O5]6+D%+$1
MFYR.:Y&)N'PC'B45?#2VRE#%%T(@;L>#PC)<C[Z++W\(P[=7;N(FJ?;L0Y%Q
M28BY<Q\=<B6(G2^=2^/U>AV\^@8DDFU^=_EG1$3%(2R"0IZQN)V4"DK2KPA+
MR40X)1Z4N#N!^=/U"-R(C$%48@HH&=F@TK(@E;9C=77529QS\1Q..N[JPN+C
M*./HN$76*<?LW!RX&@/DJE[8;+;RZ;GY/:5:BV&+!7KK*,J)5(,F,\;')V`9
MM:%7VP>W>YKG\_FBCH^/GW;+QM9.$*=_*(,K41RNK*P8-K=WT[F]^GU12QO(
M>UA3C\ZO-5G.JOJ>KS7&%W(:L+"X-.&:7\@5])LQ[_$H#PX.GN]S`G]'[Y[O
M*JMOQ/3,C$;9;PJ=<+B\ON45V]'1T45!E\8O4W;#/CGYA<DZUNB>F05Q1+K!
M.O8[5ZF&PS$E>6%GNCU+[\UX%IU>KP_;.SMQ<L>,IZRN"<O+R[4K:VNT*??,
MB=?GJU5:Q]\ODJI@()VZL[O[N6]EE:0M'?E\RQ^]$)ZIU(70!&WHZE%CU>__
MI-_A=K7*E8?D.D@JEJJ$3.)[Z\A(EEAK"&Y6J6$9&;78',Y0@=:(UE[-P4OO
M%,.T)T1K'2-=YSRK]BURP)_M[>U%GJV97+-"O6GX+)Y%XD%$I@1BM0]=GL6/
MS?8I3+K<+X>3A#<W-S=#MK:V0LC!O/',VKOD4,_BP<_$@_Q^?PC)^^"_]7O\
M&Z$45R?2<+VP`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q
M,BYP;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-#`Q`#$P-3$U-#,Q,#8V`#`R-3$T-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.#!,06$%)
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$CDE$
M051(B>V4:4S3=QC'3?9FV;+,EV9+C.]\L1AUFS%;,N-!,C<U1F`S$X59CI6J
M`^E0*$6@'5=+:0O(56C%TG(4VD);2D^@AY3C7TJA%#:M"L.AX(#,"0G#[WZ0
MS*5S2[9LKY8][[[_X_/<SY8M_WD3B"NV7V)F[#":S-O_%>"]^].O!":"]&*!
MB'Z]IOZIL*(&*K7VZ89VNMP[_Q'<UN>JK)0JT-"D0H_#!:]O%%9[+XI$56!Q
M^-3MT-W2OPTU=-NV&LWVAOS2RF?RU@ZT=1HA;5)#U=F-=IT)/<Y;J*AMP">?
M,Y[QQ54KE;7U%_\RO%A4?;!06+4)M?0Z<<LS"+7>1.!&N&X-H*/+`N(826G9
MB#R;A&-19]94;>IS?PI<65EYR3?JWW;CIGR;1F<,%(NKH3?WP61WH;7#B.J&
M%C1INHAV(J=0A.2T:U"VZXE3,S8"J:Z[L30Q^0V-4R3<]N.3)Z^%P5W]`SNT
M>B-J97)<KVN$4FW8A+9HC>!52)&0D@U6O@B97PO!9!=`;[)B<NI;#'E'H3/W
M0JI0(5]0#C:7#Y.M3Q@&-UE[JO-X92BO5T!GZH%4V8XN2R_<@UX(:V[B')V)
MAF8-R88\\PS!/S8.RN>'O%6+"HD<@UX_U`8SODAC(XM3./7PT:/=S^&9.=R@
MF#2IKE&%$?_89LHRTL2\$C(9)%H#B71DU(^)X"2<_4.0-+8AJT"$F,0OD<+B
M0J94(XUD]!GM$M*S<D!1U-'G<(FL(9AR]1HD-UO10LJ1R[N.I%0VHN,N@,LO
MAWM@&-W67G29;6A4=8!Q)0_'3]-PY&0,8AGIH),>G$U,Q9GX"V!>9<'G\_T&
MOS?]W7!*F001L8DX>#(:!Z)CL'///NR).(&=N][&J<N9V/_!(1Q+3D7$\4B\
M^U$D=K]W$'L/?XQ]QZ*PY]!1'(A)P*YW]J.FIG;U^[FY(\_AP87%N,QN)TXD
M,,"OJ0.KJ`3Q9`JB.#S0V%R<ES8C[CP-)8I6G*8E(:Y9A\.1IT'[*@/)Z2PP
M:I7XE%L"3F'I,MGLV+"&!N?F$UFD)&4$7.VF8.UU@&OK1VIN`0Q];EC)K*M(
MK9OM#F@]PTA6:)&>7XA24D*[TP5FIQV,O'SX_?Y@&'A]??U-ZV2(<@Q14'D#
MB"?3426]@<%`$`:R--D6-VJ;5>`-CB.!G0/'\`C<U`A$%B=HE?60*908#DZ1
M91N8N7,G]%88_,'R$R';02&;)X"@QX,K10+P]%9<YI=!/NC#6;$$_#H94I4=
MX`C+D:>S0=JN15:'%2Q1)3C:;A3*%/!ZO9JUM;77P^!EPT$AHZD359+ZG^\^
MG%_I'Y\`V^1",CL7XIY^I/!%\(T'5B="]U>,E'\]OKF3W!8)`O>F5QW4Z%J6
M9PQ,%AM.ITM`X"^'P5N]`:%,H_O);+;0-_3M'Y;M0KT%75;;*C'-\O*R9FEI
MZ=6-=W+O1+]0K8/'XZ$6%Q>W*GR3&6*;&VJ-YL'\X\<?OG!72,W?)QYC?M7D
MSKRQL+!`)\#8WW]+G)T*A4+TF9F9S7M._ML[.SN[H5\$_V]_9+\`*`(]>IE\
M'_4`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$S+G!N9P``````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V-#8`
M,3`U,34T,S$P-C8`,#(U,34W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`X,"P,TV1\````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```,S241!5$C'[96[3QM9%,9345/2;90F3:3M
M]@](FFU7VCJB3)4F'5II)0)-B(-B#(I)=KU>.R$$S.`'21QL`[;QC#WCU]@>
MV_)CQH_Q&T.R08`5].5XD%8I(D4H%"FXTM%<S>-W[_>=<^Y<N7(Y?L@1B\7N
M;>_L,,%@D-G?W[=^-S`C9:_)2BV32DE'I7+Y4[?;1:U6QXX_A*TM_U$^GY\2
M17'DW&!55:^E4FDVDRU`KC2@-CM:#.=%N8X5VSLL+;M@L;R8HP5^/1<\F\UF
M9$5!M]-!J]-#0JIA*Y`&RV?1:+;A\R?QV&##DV?K>&*TMC<W/6%9ED>_"::7
M;@K1^*#1ZJ+5[J)8Z4`0Z_"S.=35%LJRBC4'B\VM."*Q`AA'`+I'!@0"@>C>
MWM[UKT+[_;Z.$K:42,3K9;D"J5!#,JL@)!3QQA.'T\V#C1;@>!.AX*!45'2Z
M/2BU%H28B%<KJ_!Z?7PD$EDZ/#R\_>5N?XKP@I(O5E&BC_AX#MML"B6E`4[(
MP?B7"X[7')+I,L*"I%E#N]24I/,5RD<;:J,)+IHG%7.TB/?XX.#@E@9/)!*S
M::F`MR0U6ZAJD<R44%::\/A%,*Y=9')E]/M[!.VAJK;I>1ENGX!7C)_>KR`N
M%L$X6<P\G(/!8$`NESM+--DQ*Y,5*:F$9JL#4:H@R&:POL'"Y@BB4E71)0MZ
MO9Z6AT!8PK\OO9@WVF&RN,FR"*PO?9JZASH]%A860*5Z!O_PX?UMGN??A]@P
M?-N[<+[>AMGJI(IX3F'5[@6"+%B619B/POR<P:S>@IE'9CS]>P4VAA9P>;!N
M=^'^_:FA]WE2^?/_OI.'O]GM]O%P.!)-))+@>0&[NR%P7!A)403E!-2I6%VU
MX<&#&9C^,6-BX@],34U#I],-YN<7QHU&X_B007WRRU>K9C`8C!X?'X]]_/C?
M&-DP1JK&3DY.M&NU6IU96UN#T^F$V6S&<$Y`+"XN'EW$&?/G\O(R3"83=:=%
MBR&<X[COAU,-7]W8V(A[O1[H]7JL4&U/3DZ25:MW+^2$I+-DU.UV8WIZ&@S#
M')#'#"FZ<2'PT]/3D4:C<2<4"MVA1OG]\H=T[O$9ZMG!0%<JZC<`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$T+G!N9P``````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(Q,3``,3`U,34T,S$P-C8`,#(U,30S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````7````
M%P@&````X"K4H`````=T24U%!]0!#`TX)6:.F7X````&8DM'1`#_`/\`_Z"]
MIY,````)<$A9<P``"Q(```L2`=+=?OP```/5241!5$C'W95)3QMG&,?3<UNI
MAT:J>DBH>N!2J5^AQWR`''JAXM**0SX$2E1%J`O!"20@$XR)%V(;,"44&WN\
M.U[Q.IZQ/7BWQVMM5H-,^.<9#D55BU2:GO)*(XU&S_M[_L\Z-VZ\UZ=<+M]T
MN]U#)I-IJ-ELWOI?H/O[^W?3Z?18L5@,)I-)^/T!))/LL=EL'CL]/1W^S^!N
M]X\1GL_U6$Y`O5Y'I],!J48XDH!*;8#3Z0IW.NU?KPTFV+U<+C>HUFIH-%O(
MYD6P?`D[\5V4RB*VF3"F9PUX_$1^'@A&^HE$XMZ_AE,J^C51)+5M5,0V0O$R
MMNUQ)+D<ZHT6S$P4SY4F:/4N_#*IA%R^,*"ZC%P)[/5ZG_I\OL]$49R))Y+G
MA7(=TI,21/@B13A]/'8+-82B`I977`A%,L@51`1W>"B7ED'%)D0O0N?KP\/#
MC_\"+Q9+7"+!(L7QR.P6X8]F$6'SL'M9+"TST*UY8/>DL+;A18B`K58+K78;
MY6H3E6H=/E\`IFT[13$/CN,F_P3G\_GO(C%V+Q!-@\V4$(SR</N3J(I-4IK%
ML_E7L-IW4*J(R!<J!&X3N`,^6X3+QZ)::T`D6[N;Q4\_RS`Q,7$)=SJ=D^EL
M'HPK?@$0\C7$N0+\X0Q6-EXC&.8(4$>;E$K@!%_`IB4$I<8"Q0LSO($4-DU!
MZ%8\%_#Q\?%+>":3F8S%XDCQ.>1+500B`C;-82A4%JBT%A3IFUAOH-%HH%9O
M8=L1P^SS5WCT6`^-SHXM9@<KO[DI+:]Q__Z/,!@,EW`JP&T:E+C%8CU6:Y8Q
M)9O!_((*LB=RR&1/H=,;\$*E@5ZO[QN-ZV>S<PN8?JK`HRDYV3XCVT7J_64L
M+:F.+19+/)7B;O^M8[:VML8((!F!>A=6*X-`(("#@P//T=&19C`8W*74/*"N
M\'B]7FBU6KA<+J33&3@<#I!(^=G9V8?_V(XT=<.Q6"RL4"@N+EJM5K`L*TWG
MM_U^_TN:T(5NMSM-H_\%M>WHZNIJCW8.:!V0H"5DLP+V]O:&KNQW4K]*Z@]>
MOM0UZ!T$130:[3*,K;VVMB8I/:=(M)5*1:G1:-[,S<U!I]-!$(0>.8Z0X\^O
MA%-Q1RC$'^QV^QVZ])`N;%"!H%&KL;Z^CLW-WT&#`EH/&QZ/YR'/\S:'PPE*
MU>JU=@SE^`,*^7N&8:1B7B@T&HV0U-+W4<FFV6S=$H3=;TCQ5]>%?R+58&9F
M!E-34U"K-:!42&F2>G[TG7<ZI6F8TA"4'"PN+EXXH6+BY.3DW>'2H65VTV:S
MA:@S.*K''5(^1%%]]/[^>]\";%1GSQ!(7:H`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O,34N<&YG```````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,W-@`Q,#4Q-30S,3`V-@`P,C4Q
M-C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,
M#3@U>SF)&@````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^
M_````HM)1$%42,?M5$M/FE$0]2>XZ**KINONVG311=.PZ4_HIHO^A*9ITKU)
M33X38XU$>4=!P0`^$(,1#7&A$B`\?!"*@!+!5,)#`4D04#F=F;1=V)=-EWJ3
M&\B]=\Z<.7/FZ^FY6[=O=;O=1Y>7EZJ3DQ-5(I%012(1U=75U?W_!7U+H,K%
MQ<7GX^-C;&YN8F-C`TZG$^5RV0-`H3?*V=F9DDPF%4JHT-G[GX#H\!ZSH<>:
M=KN]5:E4MG*Y7)/`T6JUX//Y,#\_#Z_7B\G)22PO+Z-6JX$2X_3T%&MK:\CG
M\_S;HO@/U\&3!`YB(>P"@0#FYN90K591*I4$W.UV_]@#`P/8W=U%.IT&287]
M_7W8[7;8;+8:X;S^)3BS"85"$FBQ6.!P.+"SLP.CT0BKU8KIZ6D!X;MBL8C#
MPT.$PV%),C4UA86%A;K'XWES'=S%Y4>C46BU6HR/CPL@,^)SKH1+'QD9$6"]
M7H]&HR&5S<[.2LS@X""&AH9B+I?KW77P7M*JCW1+,I!.IY.@6"RV117UD:Y&
M8B3`Z^OK4@V]%\E65U=!#96[B8F)AW]RR&-*T$ZE4L**_I>VM[<#F4PFSOVH
MU^NRN2]T)M50=>VCHZ-G9``;)7OP6W"6AQ*`]2=?BX[#P\-223:;%;:L-3/G
MWHR-C6%O;Z]#[Y__U=L,SL"=3@?!8)`U%'=PDIF9&4G(/E]969&F:S0:F$PF
M=IGK)N"]M%OL7VXF64M<,CHZ"K_?+\TM%`I86EJ"P6!@C3EIM]EL?KK19!+X
MQV^35^3!869FL_D+Z:GPQ)(,[O[^?BPN+CK4:C4WW?+/XT\LGY)_512LHF8]
M^7Y.S7MU<'!P'H_'7]+=.7UK7MQ]@6_!^@I1C9DT(N>@20````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,C-X,C,O,38N<&YG```````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q,@`Q,#4Q-30S,3`V
M-@`P,C4Q-3$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)
M344'U`$,#3D+HT.E\`````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``
M"Q(!TMU^_```!%=)1$%42,?=E<U/8F<4QF?119MVT29-%[.I::8[TW0ULYU-
M&Q===-%%TZ09E_T'IIE58[NQ3L>QMA.U*HK.("`,%T3Y$!'Y%`%1P,M%$$&X
M<$'Y%+#1T3X]]RZFF3AIS:1)DY*\BS<G]W>>]SD?7+OVO_RUV^WK>WOIKF*Q
M.!8.ASFGR\7Q/!]:65GI.CL[>^N5P<?'K5NY')_G=M,XJE30Z710.JS"[0U`
MIUM`)!*1UVKU+UX%W,WSA>1^EH=0KJ)0JH(7JN#V>*0R`K3,*J9G&6@TVH8@
M"`PE[KXR/),]:`J'%;1(K7#8@"^8@M$2P$:(HWL-2[80!H?5&!EG,#`P0B]A
M6F3=/R>H-^I?[[#Q9WFA`IX4QY(%N`-)V-T127T\F<=CU2HL]C!"D306+>OX
M]=$XK%8K<WIZ^CF==RY!J]4:$][:VDHFDXUL7D`PDH(_O`N;*P*5SBF=%6<4
M*JT3UI4@#H_J:+8ZR/!'8!,9F$S6QK+-7E$JE6RU6KW[')S+Y6Z&PK%BE,MB
M+RO`&XC!Y@QA/U>")Q#'\(@6^B4?V%T>,3:#YO$Q6NT3'/!E28!P6,=1M0F'
M)X8?!P8Q.CHZ]!R^O;T]%&73,)C7L9<I($&%"^_L@R4+]"8?%LP^I/9YM#LG
M$E02$(SCJ<&%:84%T7@&GO4=/%;:<?_^,/KZ^EZ$9[(Y@F51*-?@"R2P:-W`
MC&(9<_,KU((U'+?:Z+3;*%<:,),M(Q,&//A9B0FY"1HQR1,+]$8W%7@(8V-C
M?\&IE7I8-G[D]OIA--F@TYLQ/CF'!P_',?2+#":+'?95%X+!$!Q.+Q2J!3P<
MEN.G01E^FYB#6FN$SF"&4J7!U-3442*1Z'FAH,UF\]-,)G-"KZ#BF*03Y[@_
M4JE4AR83%HL%L[.S6%HR02:;`L/HX?6NP^WVP._W2W&93`:7R]7SLL%Y<VMK
M>Y(:ACYP8V%A`9N;FP*IZ%U;6X/1:(39;,;,S`RT6BUBT:@_G4Y;/!X/LMDL
M5E=7Z3C$1'<NP3F.ZW(ZG:1L20)H-!K0_2XEN&&WV_UB3(3J]09,3T^+D%[:
M+[.A4`@JE1IJM5H20'?N$KQ4*EVG4<X'@D%,3LI:#,.4#0;#QV*,>O]M4AT6
M;2&%:;J#EMIWU6KE&U)>WMW=C8A@LN9;EF7??>ET`KA%P60\'G>TVYU^@@R3
M3?=R^=R]\F'YPWJ]WD_0CPJ%`@J%(@@.VIJ.1J/Y`7W73^?6WX[_^?EY]\7%
M>2_MB@.M]BGFY^=!MH`*_1XE?^WBXF)"]'AC8T.JB\/A`-GSR947%^WLVU1U
M/%',P>?S25Z3E^L$_S(6B]66EY<AJE=07.P6LO3W*\/I^;<CD:BD3%0M0@X.
M#M;%&+7B5V*'B(67R^52G-;'U>'T]-?S^?SW*I6*HT7$>;U>KE:KW1!C9,&C
MQ<5%6*S6(A7PF4*A&*$9>?]?^>NCOG^#K!DBSV_:;+8?=#K=9__)?_"?)CGK
M5*S"R:4`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q-RYP;F<`````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,C<T`#$P-3$U-#,Q,#8V`#`R-3$V,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````%P```!<(!@```.`JU*`````'=$E-10?4`0P-.1[.GD$;````!F)+1T0`
M_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$24E$051(Q]75RV]4
M=13`\>]]S=SI=-II9Z;3=OJP!5H0#,5(4#&&1J,+#!@7&D+41)>&A:#_@#L3
M$U:2N#"Z(U%<L$`3:F-!@]@`+>71TL?T-:_;SGOFOF;FSKAR@;1@XD9_VY-\
M<G+.[YP#_]<G/"XX?7NZV^=K.VI5:Z<W-C91W"Z<B@D(N!0%09)I4A7"'6%D
M6?Y=TU*?!=K;8^%PN/987-.T0W/S2Q>J#7I:6OTT>504148`ZO4&HB1A6Q:F
M;9-*)BGFL_3W1M@]-/11*!0Z!R!OA]^:FGJSN370XU-5%$E"D65D24:61,JZ
M03:;Y\;D-<JZ3BY7H%:K4ZTZ[!@</`5LCR\M+;U\Y^[<)_5BD5Z_'T$0*.DZ
M`B#+,OELCD0JP=S</'MV#]'3&:J+DGQU<*`?C^I>^\O9$O_ZFV_%4+A+[H[T
MD(HGB?1%,$HZ;H^*ZG9C61;%?)F>GBY.GGAGPN/Q7/)X/%_\W1&WPH\?._YE
M+E=`5F0J]1KQA(:6TD@F-!:7HNBFP=IZ#,LT<1SG^E;PMOCRRLK@>BQ!+E^B
MD"\2C2[C\_NH5"O$8TENW)QA_L$<=J6&)$G;_K9'RF*:YID3[WV@A#J[L2T+
MO:QC5RH\6(@B"B*V99/+%V@`Z<TLCN-LBS^2^?GO+[[4%@A+G>%.RKK!1CJ#
MIFUBE`T$()Y(DL]F$407Z6R&2S_^%"F72RW_")^<O$$@&&1C,\/"0A1!$.CO
M[\6ER$BB2+/7"X#?WP*RB]MW[KX[,7'UV2?B8^/CKH6%>65A=A;#-*G7Z^P9
MWD6U6B&ZLL;*VCJ2(A'J".%6FVCS!UA/I+DY,WMV;'S<NRUNFJ:W4JF>\S:Y
MCYJ6C5XLHI>*W)^=8WIZALUD#,,P<!R':K6*+$%'.(3:Y&'L\N616"(UX3C.
MSBT;*LMRB`8?YO)YM-0&;E7%Z_51*!1(QM=PJVY*Y1*2+&-;)J(HT1!$1$5!
M%$6FIF\_]_3PKE>!Q4<6E^,XTNKJ^IFQGZ]\?B6;I;&V3*0UB-713G,N0Z6^
M3E?7;]R[:5`*OT]$%FEO#9!6)%KSF<7A@8'RZ.B18G=W]]N2)&D/92Y)DE,N
M&\61`R-(J02[#K]`HMX@TN2BK-TG&/R*G@Z-<_$N?#MV<&3_?F*&B6P9UW=&
M.D_NW;LONFW-+<ONC"ZO?_QK)D=OL!W=@>EB":.0H=W_`^6"P=1,@/Z^&NW4
M2>5-;A5*F.72Q%;P0_CU/Z;5F=7X4#R3)JBJY*HVZF:,8OH[?$V_</'2\]C"
MJ]R+A@FTM;%AZX2J=F'T\(OWGSBA?E\S-;>+4;^'@:?Z3A6*A3=*]N3K`\/G
M&;\6X>"AMZB[.SEPL&#NV[?W]&)2P]WB38?#X0M/Q'O[NF+-Q=*`(#2H5BJK
M>JG@&MF7.Y+47G&'@L<2@X//O%81)+VE=V=]:&AH[5_?P'P^]^G2XOS9=#I]
MX#]WH/\$#D[\&K/RT'<`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S$X+G!N9P``````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-38`,3`U,34T,S$P
M-C8`,#(U,38S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T
M24U%!]0!#`TY+NA'<;<````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(`
M``L2`=+=?OP```1[241!5$C'Y93K3]I7&,?[;GNY)5W:[,WZ!RQ9]F(V6=*U
MZ5IMMNFTZV8Z[[,7M5[:U5M=JY-YOV'5(B)604&*B""""**`B"`BJ*!8BG-#
M112C;G%>9OK=D64F39-M9GNUG>0DYW?RR^<YS_-]OL^Q8__I16M@OI&>0SG%
M:FL_9;?;7_E7H$^=SBLL#C^!6L<PU=`?@\/K1`V-46J=G+SPC\!:O3&*R>)N
MM'`%D,C[8;98H=&/@M[,04$9=4&MT79Y/)[7C@R6R?N3ZQ@MO]);>.CHEH/U
M1`2^N!<"<E9IAM'&%R$J(1WYA64[/+Z`E4<I^/M!2JFT[6:.`#*E&L,&$WK[
M->!V]D"CTV-0JT=%+1.IV11$W+R+C\.NXD%^`>M/@1[/\G%Z$_NDWF"B?5M4
M^;RS1X&^01U$O2HPVP1H(KM?K0.MJ0WQJ3FH97+0+5>AMK$5]_)+GP_I]+3;
MF0].NES?'W\)KAQ0SSQBLE%-:_*GSQ5(()0J"(2+Y*P"W/ZF!)2*>B2EYX'=
M+H!]9A8V^PQD)"N^6`Y*<26R\HH@D2F6MK:V`@[!HV/FZ/S2FLVZ)JX?S!/V
MH%THA=%L10M/A)BD3'\IE"23?O40)J9LF+!-HZ=O`-4-+*A(J50:'7(*JA!S
M/8D$M<_N[>V]XX??R<ZCUI"?'C):,4J`(ID235PAJNI9N)M;"C:O"\:Q<4S/
M.#!NM:&U0X)"*@/Q:3F(3LSPE^U^435BR?E2\&4P&ALQ/S]_R0_O[5-0<PLK
M4<=@H4NJ1,E#)FYE4A#^51H2,_*@&!CRO[BG3T7:4H5T$O"SZ&2<#XG$YW$I
M2,G^#E?CTQ"?G(60L"NHI],Q-S?W.WQC8_,MXYC5EEI"10RE!!^%AN/LQ6"\
M=S8([T?&XXOKMQ`6'D5V)$*OI2$H]B8"SES$Z0\"$1!U`V?*ZW$N,!@AE\,1
M'1.++I%HQ^=;^]`/]^[NO>M>WTAA+*TA0CJ(TLI*\$5B-'<*<4$]AJCB<M3S
M^&CF"Q"GMR"PFDX$+$$AK1'I]$:$TIMQIZ`8[=)>*)7]W<1<T8>")JSM41\M
M^F":F`23W0;^R"CN>7^&S#0.L59'VHWT]=PR"D?,4!F-:&"QT&&90H1C`1T2
M*=1:+5*FYW&#>,%BL=2\T(89CA^H\70FV,(N6):685WTX)9R"/<KJS#C787-
MO0B&80QI%56P.QR8\JW#-#>/Y.96(GP[M$M>T,529)64@0PVZ0MPTI>?F,UF
M&OO'97RJ&P>+PSD0!#;'+,J\F_B2V%^G-\#M=F-U>P=!8P[DLCEPN5S0D<#G
M)^>17UZ%9RZ7W.?SO?Z2B?:!5QV_[)0)3>;MCF'#;H[3C<=B":S+*_M<I6J[
M?&(&U<2A#J<3LMEGVZT#FOW<:1>>]"D@GY[=U1M'MS<W?[KVE[,ETKW^=J)Y
M^FD=ET]4]Z4>W*6Y/+*O.R48,1AD!]^*S:W4.*MSAR/JAM/I/'>DR;BRLG*:
M@`]57UQ</+&PL)!`2G/BCSNOUQN]NKJ:0-SXYI'@_^_U&R"R0/$/&$#S````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3DN<&YG````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`W,0`Q,#4Q-30S,3`V-@`P,C4Q-38`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!<````7"`8```#@*M2@````!W1)344'U`$,#3H#AK5^`0````9B2T=$
M`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_````\9)1$%42(GMT$MO
ME&4`Q?'_<WG?N5`[':!3IBW:5EM%Q=``B8$8MFY$71H_@QM7FA@7^BW<N"-*
MC'&CQ`5B(\19`&Y$:VF!XI1.IYW,[9UY;\_%!1O#!W!A^&W.[B3GP%/_*P+`
M6OO"P^T'/ZROKQ^WUF*MI5ZO?SE5K5ZX?>O6TLNOO(H`[MRYPYFS9TG3,5M;
M]TCB,<>?723+4J+A`"D5UCIJ,S66EU<N*FOMBG/NDB<YB7.Z7`KUHYUMW6@T
MSIXXL3R]N;FN=W9:>F&AKAN-&SH>C_31(Y-Z8F)"!QK]\]6K>FY^5J^L+.A2
MN:#;^VW]YQ_K>G9N[I+,LFPICN,SPB>LK5WEYLW;G#^W2K_7H=MI42HJFLTF
MH4X(`X')A_1[>US^^BL.]MM8:TGB!)-'_'KC%PIAF;<N7OQN9F9F2\;C,?OM
M%EG2)1H>L/U@BT*0(:4E37IX%]/KM$F3"&-B6H_:S-4G>>/<21J-!H<FGJ$_
M&)(G/0;]`SJ=#I7*U#O%8G%#ZD!_M']P@,E'X'/B48QW.=9:O(O!YR2C`<X.
MP1O^WM[AQRO7F:E5>??M\]R]^SL/[VT""<YFM%J[/-K9811%R"S++^SNMO!V
M3*52I%HMDJ9=HJB/,3&E(CAA4<+@7<J++\T0%BV7O_F>V6,35"H%HN$`08X0
MAD&_Q^;F)LV=)MI:2Y(D]`<QIU<7R3++VK7?Z!R,:&ZW.;4ZS_OOO<[>7HN_
M-IJ</G6(,ZL++"]5V;B[1:O5X[GC5?;;NPRC".^FZ/>ZM-MM1*O5\FO7?F*O
M=9_]O2;..H;]F'*I2'5J"B=R.MTN4912+I28/E+%D-/M];!6$10GF2B72=,!
M@V',T>DZ<_/S+"X^CQ9"X(5`B@+3M46DLQRK>8S)<=9@#50GJDR5+=Z#M98@
M+%.O50@"#5*CM4:JHR`U2$4A+%`JE]&%0H$CAP\3#08XDX('O$/G&<8:A`_!
M@W4.`"DE2H<HI4`(E-;HL$!0**&4QEJ#D!*M%5IK?6^Z-K.49AFC*,(8@S4Y
M+D]QQN"<!<`YAU0*[QQ"2KP'I21""*14""%16A.$!28G)ZG79Q'Q>/QFG,17
M1J,1@\$0:RW69&29(<_2QZ528DR&$`+G/5IIK/,$08!SCB`("<+@\2JEJ50J
MU&HUA+7VL#'F->_]%\ZYXT`(X+UWQACGO1=*J<![GSGG0B"34H9""`!OK4VE
ME*'6&AZ?:I127BGUB>`)UMJ/@3*P`5P'%H$/@,^`3_^5`/>54A]::S\'QD`7
M^%8IU7ZR]ZG_QC_99PMM!`.^V@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\R,"YP;F<`````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C`S`#$P-3$U-#,Q
M,#8V`#`R-3$T-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'
M=$E-10?4`0P-.BU:8W/.````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2
M```+$@'2W7[\```#$$E$051(B>U32T\3413^9N;.HYVV4Q[R2`DL)""F1$S4
M1(PA)FQ,7/@/C"Y<N6/CSI6)>Q/CSH4[-R[<L7"A!(A&7CY0@:A0*"!!:*<S
MG4[;\9R1,0TN7&LXZ<GM/??<[WSGNV>`(_NO3#H<R.5RV;<?/K8&00`A!`;Z
M^C:325.>F)QNL]TRAK(GJR?Z^R8X=W)J>OC+1E[K[FBO7[PP_.*OX"^GII^N
M*\FKD"34/!=6J?@VU902&]`'_%H=<=_Q,KIR?77M6U7*''_D2L+44:M^7YB[
M<>OFM<>-6'*Y7-9]W[_CNNYLL5B<=4K.I?BQ5KQ[,X_%5_/X^G5MT#;,@?7\
M-A9G9J&VM^LS[Y8>*%;30R1,\_7X<^BZ*I!(W?^TM#Q+.,]*I5)'K5;3A2S+
M=QW'&=O>WD:A4,#69AZGLH/8;S719K6A9-O(Q!6\7UM!;T)#?TS!W,Y.NOMX
M-V2[A'3=P?SX./;W;.M3RACR7&>HIZ<G7Z_7+\O$?HRJ@#:ALTX90T>K96%I
M)8?/RVM(RD1,UY&F6%R6H"LRF@T59KU"Y&.X,CJ"$U0LJ`=PZ5V(+.C-;@N2
M!;N[NQ1T?S^":Q>1^[:*\^=.HUKU2/X`5B(.DH_.)52\"LH$T-'9B1_[-IJ:
MT["HL*II2"83!`P&'Q$:!5*I5#@9I!4,8NTXM,8,Z)J`4`+D\YL8S/:'LN4W
MMQ"+QRBW"%GJQ,B%L]!4E2@%4(4"5L&C00A5L&T[V-O;`W?`+14*^W#+7MA#
M5Z83FJ:'9S6:%+[H."[,A$E%)3BN!Z]2086\6*0.TBER"RTM+:$+B4:.9YI=
M(2VY/?J%G3"P[U<@D\ZRK)"#SA('[Q,08XI)*@3%8WHS5.I`493PC.VW+#0U
MH>ZL*S-D-FP,U&B_2"AA?@A`)!B4]QQG)[YAGN#++(=-8^6Z3@@<=<*%(I"H
MPZ@8QSG&^6P1:\Z)\EF6>[&8,2J$<L;WDV%R=(&!HN1H/?R_D7'4D6$8O#X)
M/W\"ZZ4+71%8=#G:-Q9I-&87@3?:09&%/RX<V;]M/P%6'IYA15G6S`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\R,2YP;F<`````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P
M-3$U-#,Q,#8V`#`R-3$T-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P-.P.?KD]`````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```#M4E$051(B>V4RV]491R&G^\[Y\R<Z=POK<,P
M7#K3B`(B"QJA5A$,\<+*#2Y,C"O7^G^8Z-;$E0L71C>&BQH(!;Q!);4DB%IM
MZ+3T>N;6]LS,.><[WW%1(?X-A&?U+GYY\^2W>.$)CQ7B89B>OFF[V]WC0DC\
M(+SC#[:.C-8/^'8\,=]8F'MFT'<I5VKW"\5B8>;VC8P0`J*(8FDW@[Z+V^L"
MD"_LYL3$Y))IFG^;#\L[[;5R.J6O;FVY[-U[Z,M.LWFN[3QP=^\9FRIDO+/D
MP/.V?PC\9&U/.:I(*;!,@_7F*I81,K;/(B)B97V99M/Y!/A0/BQO-=<QC9"U
MY?NTV^USZ2&X>?.G9,_MG$W8'OFTQG$6)J5A5JY,W>/S+RYCQWWNWOV-P&LS
M-S?/IY^=Y_R%JRPM+KVC@F#BD?D+)TZ=65N^0S:7H]U:I3B:QG$Z;'8=VAL.
M81BBM(6[[7)B\C4>-.[Q8#UD^M=_.'SX$&8\1KWV-.E,B5*I.*RUSDB`0;__
M;J3YR-T.&*N/$>D>B42:;K>+L[["W/P:=_]8Q8S%F9V^@;>UP?BQ0WSU]77B
M]A"F:5,?W4NM5L;M;2&$N"0-8]942N6ZG=:;BXL+&;>ON';]-K=^_H7AXOO$
M9$0JE69B<A)OX)%(V/PU\PV52IY;T[^SLKC$2Q/'2"2R7+\VPW=7ICCP[!&4
M4J>!@U)K?;S3W7Q[<?Y/"","9?!<O8J4-ME\B4QFF(L7+O/MQ<LH9:+C1?:,
M'J35ZG+RY1<IYY-H%;)_M,[I5TXQ/CY.W$[,``O"][S7&XN-2S].?4][8Y5&
MH\'^D016JL1\8YF1D3*-N5G&JB5D:A<K3H=JM4H0^`AIT''62*93#*7RJ$@2
M^#XG7WUC]?FC1]\RA1#$8C%2R2&"ED>M%*-:SN/U>U@C,2RC0^UHG4HI1VO3
M)1U)I+>"T@)?:8:38%L1W<XRRDRPJUHCE\MLJB#HFUIK>J[+5M>AD(J3*Y:Q
M3`,Q9!$5D@@$&E`:,JDDJ506A$`(0`A"#:$PJ402925Y:E^=8J%PT4XD9DW#
M-#<+A>)&J;Q_>'MM'@]%)`P,*8DB3>`/4"I`:PV`0&''#"Q#((5$"K#0*`R$
M]A`(I)3_W0*]7N_CIK/Q@;.ZA!JXZ#"`""(=$.D0`!WI1ULA!1A2(!`(PT!*
M$\.*8R6SE';M:V:SN?=B\?AY`:"4&O,]KQKX'BH,48%'I#5:1SL&.S.R\XK_
M(W8LI6%A62:F&2-NVSW+LF[QA,>/?P$7!*F'6&3[=`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(R
M+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$W,3$`,3`U,34T,S$P-C8`,#(U,34P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X+,A-PQ]``
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```-6241!
M5$B)[51=;R)E%'Z&F6&``::1*BT%AM1MPFZ[75,;W5@3HUTOUKU;C=?^A/T%
M)OX8;S0QQICHE2'67G3CWIBN@+$KU78H'0:H98;Y8L;SOEA,XS_8[$D(`^][
MGG/.\SQG@!?Q7(5P]7!Q<9$R#.-NN]W&SLX.NMTN^]O7-.U9O]^OI]/IOX?#
MX<`TS=KV]C9\WX<D20C#$.:Y.0>LU6I.<:GX^!IXUS`^^_G)DT^3R20FDPD$
M@1_9BXN+C<%@\,"Q;4.2Y6?9;/;M.(XY\'@\!A7%>:^'4FD%01A`EJ36[KU[
M-UFR=`7^1Z?S\>7E)0>E*:"J*G*YG'IP</!@8V,=AX>'I7*Y7&*`BJ+`MFUT
M.AU4JU48IZ<HK:S@UZ=/(4KB?(K$U0-+4C,J]O?W,!J-D$@(R.?S1(^!?$YC
MA3C@T=$1[YHUL;FY"<>Q$4Y#6):%Z72*^_<_^#^XKNL8VV-\^/`C^)Y+%R-.
M3Z52Y9.P;F.Z5WRY0%P*$$41]7H=J90"+:_AUJV;G)I6JW4=G$31W8F3[IL]
M'!]WL+Z^`==U>3=;6UOH6WT.IB1E>&,+2?HF;G%R<H*D+,.Q+]%L-K&_U\#R
M4C$=3:?Z'#R*HD?M5E-???4&>KUS:-H"F+!]TX1,R8RR(`@X;2EU@;I-$34R
MTP%J-@<EE<%RL8@[=VY3(5LGP1_]1PNIO[R\!'?BXKW=730:/V!`W9X1W[^U
M6S@[,\AN9Q@-^WC]S;<(]!>P*;NG?V$X&$"F2914&JLWZMC[L<'M.7>+D$B@
M0FK_^7L3WWSY$];T$@+?0:%6@&\=HU90$)%H&='!]U]]CM5JB6B*\-I:":$W
MA#L<X;NOOT`017CGW??GG$NSQF,:VX->7D+E%8V``L2D/',$449G(8D9\[6X
MNW6;\\_.V">.!;)CA3<H2`HJU?)U<$D4C6QNP;,459F0D)[/@!,(`Q^NYW'P
MJY"E!#DG"8FL*B9$7I(5]L,8D2`1YV/>T+4-)2&:`\NLCRP30_*YST$])@=E
M1[R8\._MF)*9MV<_9K0J2@HY,H*^NF:]5%C\A`SQ[1R<%N"-P/<SK%.;W,'>
M'2&M<\SJ1U.27N2+)<S<1:L>8E89W#ELR3*9-++9G"-*TF.\B.<O_@'9;99C
M?N6NW`````!)14Y$KD)@@@``````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S(S+G!N9P``````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-#8`,3`U,34T,S$P-C8`,#(U,34S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`T[
M*#,2M@`````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP`
M``'S241!5$B)[9+)CA)1%(9_JAH(0S$V0S%);!-(H-N-07KKRL?0MW#E"_@6
M+GP`HXD+,9U(NA,W+@D+`B1@F"D(\^@Y)ZE.]QN8R-G<FUOG_N?[_UO`J4[U
M3Y3%W&RWV_/I='I6J53>]_O]:ZO5BN/QB,UF`[O=CMUN!YO-AO5Z#8O%`I_/
MAUJMAE`HA&@TBF:S*7V:YD&Q^/*3P^'X<&:*D]#/U6J5+9?+<+E<F,_G(MCM
M=F5?*!30Z7203"9Q=WL+/1:3/DW34"J5L%PN07#(YR]Q=75YPYK*0QLLPF1,
MG4JE0-.1R63@\7A`@T4L'`[CG&@;C0:\7B_J];J<^_U^`;BX>/J'[GU\)+[?
M[[%8+*0QD4C(RI04%W*YG%!QCZ(HR&:SB$0BXLR,28_I2*?31)[_Y70Z?S\2
MYVPGDXG8U*,Z#,.0(8/!`*JJWF?O=KMEY<'T-N*DU6I!550&^D+NWYJ:RN%P
M*-+%.\KL"9,ST6@\$O)>KR>7F78X',H0/N=(&((?DUU4JU6Y1T!?B=XPQ2UD
M]3D->#>;S5C@&5E]T6ZW$0@$)":R"/[&KG@?HX=D4A8F%P9E_FT\'K^B.+;T
M-F_B\?CW>W$\*!+.D*UK)J6!\NMQ<:Y\QL5OP.?\=Y"343`8_$S$KZE_0T`_
M<*I3_6?U%TN*\1^R2?GJ`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S(T+G!N9P``````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,C4`,3`U,34T,S$P-C8`
M,#(U,34Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%
M!]0!#`T[.5FBEO(````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2
M`=+=?OP```'B241!5$B)[5+)JE)Q'/X\'A5G<9X3#!04[^8BWFVK'J/>HE4O
MT%NTZ`&BH$5&D""T:2DN1`4-G`><QW[?'T[<^P9!?IO_]..;S@%NN.&?@,G8
M'(_'X'*YU!N-QMO1:/1@L5APO5YQ.!Q@L]EP.IU@M5JQW^]A,IG@\_G0:K40
M"H40C4;1[7;5N\?C0:52^6"WV]_I!KD0_=CM=OE:K0:7TXG5>DU!#(=#K&5?
M+I<Q&`R03"91K]<1B\7@E#FWVXUJM8KM=@LQAV*QB%*I])V<VN,8)*$S75RG
MTVDX'`[D<CGE1H35.1P.(Q@,*J=>KQ?M=EN),`D-9+/9W^+Z_1/R\_F,S6:C
M!NF.:RJ54NX+A0(6BX6:T30-^7Q>B;`JHZ9X/(Y,)D/G/\7$KR?D[)8$C,G(
ML]E,B8S'8YC-9B7"[ETNEUHIS#>*]'H]-2.&/DGZUP:G=KE<*D)<E\Z>L18.
M3Z=31<*^>::SR60"7=?5/2NA"=;#%,UF$Y%(!//Y_+.XGQOD)HEZ)P)O5JL5
M"9Y+U/M^OP^_WZ]J8L]\8RKN&9].22Q"\TZG\T52OI`ZCO)M7B42B:]_R?$(
M0IP3]P_L5035KT6P5]X1K(?W_#NDBFD@$/@HCE_*_$$,?<,--_QG^`,_EO$=
M7&0H,P````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S(U+G!N9P``````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S0`,3`U,34T
M,S$P-C8`,#(U,34R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H```
M``=T24U%!]0!#`X`#ZCL4@H````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``
M"Q(```L2`=+=?OP```.I241!5$B)[91+3%QE%,=_<^=Q9^X,<X?R&)!Y`65X
MM$"%"2E%&Q%CM:EIXM*HL7%O5R[<N3!JHC&N3$P7)BYTT[2)QEA;`RLBJ9:*
M@X5"H<[08889F)?#,*\[UV^(+NS*M>$DYW[W?.?U/^=\.7!$1_1?R9#-9H.?
MKNQ<^FPEAU8W<%;.LVRPDRX9.6[2>?^TE_?"*::T')X3O;RSDL>^M\>5J4Z^
MWJY0V4VS9[&RF-=0ZS4N^^VIR^=&/CD,/CL[^\+GU;;OK\5UC*OK.'<BY,]?
M0(MN8W&W,7;_'EO#_1CF%E%G1ED.)S`_T<+(7HIT5SN9!UM4>OP<9$M(#AO>
M1*(\HR4_>/O5ISZ4TNDT!4E#3R49^/TJ_LP:%8%`F;LNSAQW(C'BI3R/!+JE
M0@WUYUN,W+_!ZB\_L97?(UNI43`;,-V^C7WQ)INMQ^1L\N#=1"(Q;6K`/R:^
MOE`08^`M]-_NTM6E(K_Y.G^6ZM22&]BLX^2=,F:K!=EEP]8=I'UWGGW%1-XB
M(=E,Z(([U3H&=Q/Q6PD6%O8Y#!X2BM):C.AW5[%H15YZ\0+AN\L\>S;$:J"'
MH38G]^K;^.P2OTK0/7228L')20OD9(TNNY$E@TY0;67$;N)AI4(^G\=4*I7P
MF*''*)SZW30IHA*SSN:#)8:?&R6M6ND7@_VC7&+<J5'V^!BI%-!L$AY9(FJ5
M&5;,*"<"^+M5MF)Q%)'0Z6Q!*A:+:#MB2.D$6K6,0S9CBS_"5"MCW(Y@JQ:1
MXU&T^`:6K55>N_@TQ]N:T5(QE$P"2R:&O+W.\V<&:)$5%JY=Q^TJTMO;BVEZ
M>II(),+I;C-)>Q?CX^-$HU&FGO3@40R,>27<QBHA?XU`<Q--U5UVX[OX]0W:
M#0%J<AJWH0UW+2E:FF'25V7TU"DF)B8P=79V4B@4T'6=@X,#&G+C!7F]7IJ;
MFU$4Y1#%VOHZ'H\'3=,.[QL`G$XG=5VTLSN`5^CFY^</_<],3MX4-F')8K',
MY7*Y*YE,!K/9_*75:KU1K59QN]T$`H'-4"A$K5:C/QC$Y_-]K*KJG5@L1E#(
M@X.##`[TT]O3LYE*I1!QF)F9*??U]?TH0,5,(GA9H/BF4JF\+(9;M-OM7PG4
M:9O-]HK+Y7I#)#DO*KK8VMJJ"MT/#H?CH?")"38*?;CQ*D357PB?2^+N7$='
MQ[<"X$?_V@-B#4PT5L'?_Z[]_?UG1$)'0Q:M&!()QOZQ%7*[X`X>(V$?%&Q]
M_/Z(_B?T%_0&DE6L-_9.`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C8N<&YG
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C(Q,@`Q,#4Q-30S,3`V-@`P,C4Q-3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@`CFC0^Z0````9B
M2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!!=)1$%42(GM
M5$E/6U<8Y2=D4W55J;LNN^BBFW33-@IJU2[;31=1I2(K"6K:)D0D$0TE,34)
MF#`$@J7@,(2$4$R#L?$4!T_8&#_C><#P/#^,8^/A&<RDTP^K)9NJ2M,N<Z6G
M>^^[3^>>[YSSOKJZ-^-U1Z%8^M3C\0BBL9B`UF__+Z`[.SLGLMFL;''1FO1Z
MO3"9S`B'5Q7_"32=YL[[_/X=D]E2-1I-"(37H#>[H-3:(;XS@$AD;>2UP9<=
MS([+XT>:V\#FBQR":TG,JFS0/F<@GS>@I_>N7ZE4?O"O@0\/#ULTSXR';#P-
M-I:`V>[%TWD+AA\\QN`]">Y+1]'2*L38^,.8;<GN#`1#SD0B>>J5P!/)Y,=/
MIF?W3$M>3,\:<4-X%]=_Z<*#D3',S2DANB7&F6\;<+;Q(E5B@4)MP)Q2O6>S
M.\[L[^^_][>@J52J4Z%43:C4NJ1:OXAY/8/VCB$,#(U`KE!CJU#`]O8V<EM%
MS*D,:/R^"0V"<^@?E&)R>AY3,CEBL9B=+GCK&)0V)^+QQ/"RPWD86D_![6=K
M^HHZ)9B6_8[\5@'%,H]5=@.!2`J,)PIN,T]5F='6?@_?-33BJZ^_P?G&'TBJ
M<83"X7>/P8E1O<OE!C%')OL"P4B<RK5!HS.@4"R"KVPCF2F2]A%H%ER(K'-D
M<A&S\TL8&I9C=$*#-F$?/OO\2S1?N0:69<7D6WT-?)UEZUUN/\5M';-*`[IZ
MQ]`NN@.'TX,$ET<\G8,ODH&)P*V.$))<#I:E,!Y-+6#%%T,TD87%'B0)NW'R
MY$<0B6[!X_%RI5+IDSJ>+[^_8#"%FJ^V4FD7<%/X*YPK;H364EAR1<!X6>B,
M;DC'-)#)K=`:O)B1F^$+LJB0!R6^@CB12*8YF,Q6C#Z<PH\7+\.^O(P:>S)*
M//%H$GJ##58FA$AT`T=I<7K7L)DOT3J$`<E38AP@D!PX+HLRSZ-0XA$FGPQ6
M'XJE,OE3@N:Y&Y>:V]#=W8._LGUIQ>6J^D)Q&&P^TII'B.7@"Z=@M`6)\6*-
M:2Y?1*52J8%ZZ5NYV@[IN`KW1U5PN%BHGCDQ*3/@IZ;K:&JZC&-C-S*9`!N-
M8Y681!.;Q#98DT$B56)FSE*[<(MBR)?+2&WDH=0QZ!N<@;AW"A.DOU++U.12
MZ6PX>^X";MP4O@0O%`I?D!%[OTW/H']`@IZ^(73<[D%K6P=:?A9B6#J.@4$)
MS:-X_&0&G>(^='4/TCQ$/UHGA:`3W3W]$'7<QI6KUZ#5ZEZ"'PW*\VDNDY&M
MK+AD%,_P42>TV^U@&`8.A\-RM/<'`O#Y?+!:K?2.@5ZOAT*A@,UF2SN=3AF=
MR2B.LFJU*ONG'O,A/8*]O:K@X.!`0.MW_IQK^]W=73K;$_`\+Z"J!=2>3[]2
M?WDS_@"EY9'"QOVJ10````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\R-RYP;F<`````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#,P`#$P-3$U
M-#,Q,#8V`#`R-3$U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*``
M```'=$E-10?4`0P.`00F);K#````!F)+1T0`_P#_`/^@O:>3````"7!(67,`
M``L2```+$@'2W7[\```$I4E$051(Q\V527,;512%LV#!-EM8X+^0+5O^!RL6
M5(H%&RBR@H(B184D<N(8B(GCQ$:)+%N6+%F6;,UR:[!DM6;UJ*E;\V1;DFU9
MT^&UBHT34I`*"[KJ]>OQN_>>>UZ]:]?^#P<PO4V&2IG?%?0^IN,Y,LS3<9^9
M#(^9\?!D,AX>8T+FZ>B4P71(QN@&^?;Z6\+'=Z;C'@:]`D[J$30D+RH%#RIY
M#^KD^J061K_#8'+9(>R1E9P^^+=9WU*R.VE$49=]D+)>\!D[1,:!+..$3.XK
M11\*K`/EG`^#OJ0$</XS>#K^3`$W9`IRSHNBZ$:>=Q&P'7S2BI!+C73(`)8V
M@8D8D3S4@:/UZ+4YD&J=;ZR`:'A].CRV*AE+@@<%WHV"X$:)!,D1>)@R@`[:
MX-W78'?U.T3<:R3(#I(D6.90B]%%E;#'G[])9[.B<9%W0DC9(&8<2-!V)*(N
MQ&@?6%Y$,,+`X?9#O?`-W'H5,J2"=,2$@&T%$N<A[`OY;[.?CL\9I7EYSD%^
M,"-RN`]!%'':[:)_?HX$D\>6Z0`V%PW3SBZ<YF=(A?1(!'4(VI;A-\YCT%7T
M'\Z]!E?LIKA"2%EQ1&WA*$*C5&NA6*HCFLK!ZJ012XFHMSI(L0+T&RN@]I\C
MX%J?]6)?_3U:I00PN9A[U2$?C0:=0D&1)&%%P+V!7<L^PC$.)FL8.J,/>\Y#
M9#A%&A9[KA@,9A^VS2[$,UDXG"Z8U'<@"T&EL4>OPE67YRV2P1^@[!K8K5MP
M'X2P:7#C]Q4#]FP4HO$D/%X**ZMZW)U?A5KK`BN4(%7;",=SV#::P68BF$Y&
MS&N9][OU0C@41#+#X2"8P(;!":?+AT@LC5*YBE:KA6J]CA"=QOV'S[&^L8VB
M)!.9VH@D"7PW"%\@C,O+BZOPL[.S&]E<H=SMG^&XVT<LD8'+&T"I4D&CV4**
ME^$/LPA%.92K=1+X``\6M;BG>@R-U@`A)\.P&X!YSX?CD].K\&ZWJ^*$`BKU
M-JC##%YJ=TA6)=0)6*HT$4G)<%))%*0RQ'P)&IT7%OL1T=V/7Y<T6%/K<4B+
M2+)Y\(+P"KS7_4JKW1Q\?>M;W/SB2[@]7K!B"8P@(13+P>Y-$AA-`#Q,EO#,
MCDH%E5H#:0)\M/@8RT_7\,.//R,0"%R%CX;#3P+!8,.X8X&'"I%&%>#V)T@`
MB3B&QY/G%NAW?#B*\@B&&=3J3;0['5*%##Y'*FPTD23KX-[\;Z!I^BJ\U^NI
MHK$8T34-7RB%@EQ!/)U#7JK"1>30&0]F&;;:K5D/<L4*T9^'5N^%FXJ#$V7L
M.:*X_=,"'`['5?A@,%!Q'`]>+"*;+X//EF;:;YG(4M<ZD2^6T22N:!+'2.7&
MS/N+2]M8^$5/O@E`L^4AST*X<_<1*,I_%3Z93#[N=#I5CA=F7M[<,F+YF0;S
M"ZODAT5LZO0PF79@-IM@<SA)$]?(NS6HB"67GJB)]]?Q8ET']8N72*72-U];
M_L/A\$.>Y^?:[?;36JW.R++,B-D\PW$,4ZWD3ZOE/&J5'&1)G+!,FDDD4XS?
M'V18EF,:S6;\P<.%.8O%,A>/1]][VVWOT[_VSW??0_^KXT^TJJ_'_D_#20``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(X+G!N
M9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,Q,#,`,3`U,34T,S$P-C8`,#(U,34S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X!%#N2JJ<````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```70241!5$C'
MK55K3--7',6X+,XE+IFO96X+R3YLF=O<3+81=0_=S#!;XF,1T$T<ZK`3H@@B
M#(R!30'!\BA0Y"WR!L>CT!=("[:45RFTA9:6`GU`2TM+>0D%BF>7)O/#<(G+
MO,D_]\O_=^ZYY_Q^][BY/>.:LNL"#`8M#`:]A]OS7C83UU[/R$99><7_!P<<
MP;9)L])JG:!AQ>QN55&FR[)\H1J0]V%EU-WAF*)9+&;E\O)R\-\U3J=S,_EV
MK`%S.A>\!P:Z*2-:+<4^95__V&F*5?6DHX%3A*5'0DR)/T5)_/OH$B;AL>,!
MAI59J*LMA<.Q$+NR/+'>9M513"93R^+B(G4-^/+BV`F=ZBY8M6G0:H<9<!K4
M=KD7BFE[H11X8ZIA$XJC7D5QRAY,2K\!(_-#\-@W@!6CVC'=S&AIRD"KJ!5Z
MO<Y]#;C#7KMNWIP8:.OY&L6I!R&L]X>F\1/0`S<AQ&<+?`]MQO<'WH&OUWY<
MH^S&5=]M4/`\L:#QAKQN)Q(3HB<Z.SN.C8T9UCU5Y\<K<Y1%<PXFV2^!'K0-
M4>=>1^B1C;AV<CMBPXZ!RRJ'4J5&34T%0G[>!7[::Q@L>1%)D;L@ES6K`>=G
M3S'/&6JU*'N&U&V&&7,^U,QW$7UF.W[SWX/:DA3P&ZL@D72A6Z9&98T`?S):
MD'@S%#?.;$5V^!9PB[[$XG0IYF9&#7-S,]7_!#\Y9ZFJ5/(.H>G.6\BY]@8*
M;^Y"9P<?XNYN%!85(2T]`_'49-#2<R%LDZ%_0(N<V[^@-&(K1-EO@Y'M@=+\
M"'*#7N4:]BL.F?O25`D,#_>A.FH3.!D_("X^'M3$1#!9+/3V2L%D-R`Y)16Y
M>;GH%,M0<B\=ETZ\AZMG=^/RN:^01KV*(8WR]!-0^T2'1Z_PHH=:1#EJT\1!
M5+@7[.LOX^:5[\#B-D&NT,`T;H'9,@$CV:5]:MQ.SL;%H'#$Q-.1GED$OD`"
M*?F/?B<'2<G)TQP..U^CT7BX6<=YD#:?AK1F)ZIB7L'Y8SL0>&H?&-6E,)K&
M":@5<I4![=T#Z)"H,#HV#F9#)Z@I90@-CT5H6!38#<W0CIHA;.]!5DX>8F+^
M@$JE@IMYM,Y#(?3?SZE.T*<E1B+C3C8*[A5@?-P,J]7F*NJ4#H,GD&%$;X1A
MS(R:^C945`O(+D)*6@%NW4J`4CV"!KX$M4PA,K-R(&QMC71)0QZCI+BX6R@L
M*2-ZYJ-'IL#@B`D#0V,0RT;0+%*@2=`'F5(+#J\'576MT`P;7'(-#!I07E&%
MF+@XI-%SD9Q6@B3:70@$0JR^!Q]TB;OZDVFI$+2V0=[7#YEB""+Q`.0$C"^4
M(Z^P@;2?""UM"K`;NS`X9(#59G-)IAL=AW[4Z*IC<IH1>?T&&$P^&IMX<+--
MVCPY7`XQI0M-+5+"3@<9,4W<J\:8R4)T[$=!<0,D4C4FK%:8S1878YW!A/:N
M?G!Y$@)N@FI0CWIN%X)#PLCM[Z&/'$8D&?7D\_E0J(8@[%`2$RU0:0P$?)`<
M)D-UG8CHJ75UB\W%=H*8JT1Y53,R\Q@H+&U"([\'%54"L!](<-S+&[34]%42
MY6X+"XZ#/;U2)XO-1J]<@3[24@_;%;A/)C$KCXG\0C89^1$,:_6K0>$RM8[3
MCI3T^TBD51*YA,1(,>D8(>J8C?#Q\49M;>TJ$4^7H4M+BV>;>(VSEX/\<>%7
M/T1$1"(L+!1!%P[C^-$O$'KI"$+.?PY_GX\0?-$/(8&'$13P(ZY<"49```6!
M`6=QZB<O^/F=`IU.A]%HU!`O/WXR3+,S4]Z,FDI*5G8.A<5B47LE0E04A",O
MFPJ%O!KB^F^1&O8F:`D!$#7349(7AKC8:'"Y7+`Y;"JCIB)#WM<'G4X728#W
M_&L*D9ML6%EQ1)M,>J79;'0ET;R1.EU./X`VT</I^=E^=^N$CJ94:9@DC=Q)
MN&P@-1M)*KD3X!?^<^PMS;;;N36_@XRU_;D']/PC2X!..[BJ9\"SUOP%ROJO
MY-O;JI@`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R.2YP;F<`````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,3<W`#$P-3$U-#,Q,#8V`#`R-3$V-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````%P```!<(!@```.`JU*`````'=$E-10?4`0P.`2;S1?LG````!F)+1T0`
M_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$#$E$051(Q[V5.6^=
M51"&GSGG?,OY?#<O%SMVY"4$"R$B\@.H0XUD*!`E$D4J&B00582@2$.+1(40
M5?@!X1=0`&F00BSAQ#:Y<;Q=W\W?_;9S*!P[()8$H3#5*8X>S<P[\PX\PY"G
M_>B]^P2P0"JB/OQ/<.?*2?'ELA?Y6GP!WJ\""G"(K'L,HLR&][RME.D^-=S[
MZAU<OH8?O^;+$44^P'F'1R$XM-)H8U%!'22ZB40W1)DOG@CWWGV`&W^,&ZDB
MW64X[#/.2ZJJPCF/T4(4Q8AWV"3!UF9!-QS*?B2B/OU;^$G&V><NWU/#_D,&
MHQ3G%=EX#!Z<<R@E1'%$,<[)BY)6(V)F;AD3SSI4_*Z(/JO`_+['N'S-ESVU
MT[G+WL&0K'"@-$H4KJH8#7H$VB`XE`ZHO&=OO\MA=\C*JE*A;:\Y5WYSJH$\
M`M>KLK@QZ.]=N;]YFZWM'?+JI/SFY`RU6I,@"%!*H;5FT.^1CC.\!R@YW-EB
MLE7CPNHEGCNW\JW6>DTI,SC-_-KAX?Z5.[=_HG=T0!#7F;8)UEJ2Q!*&!A.$
M1%&,#F)B.\'Q:$A1%GCG$1%Z>[^R\<LZ:>ZOS,TM7`/>.X5_J<2_Z5T^CU)$
M44P8!$2!X(J4H]XN46S)[`0FK"'*X+W'.T_E*HPQ5!X&_3YFMT-MH@:/YI:J
MJMZHG)M3ZD1?K12138B2!CJ(R<<9PT$?5Y:D@T.*<9\\'U.4Q8D6PP'W-^[@
MJXR5E>>9G&H_AH]&Q_;!@X=J.$P1!*4U(A`80V`4L8VQ-B:9:*"U0BN(HQ!<
M15ED:*4P48(23Q('A&'XAVGY;&GQW.O#;F=I>VN;LB@8IRWR;(Q2"B<QB&)[
MZQ[][CY)O8D.8BHON*IDG`Z)8\/"^5FLM0Y(S^"MUN2F*P?IZL4%LOXN1P<=
M2ETP+`?@/;B*X=$!!P\[E&5!HS%-E$R0-)LTVFWJ-J3=.,_R\B(F"-=/O>=L
MSE$A4^U9%N<:J%Z'V/68B#3[G4V.!WV,:*:"G-QGS$W'--K3F+A.8W::]#C#
M5QDVJ>/E,?+L)=Z_9<+&C[-+B_S\PW<\Z&QB:W7R+*-_U*59;[+TXLM,3,X0
MV9@BRPEMS'@T!&69FVMBHA:(V3C+]VSUQ=Q#XIN-F8LL7;I$7I7T>T>,TF,\
MX$4P880([&_>Q5<EB."<IY$(]<D%4`G>R]4_P94R751X`UUWJZ^\R@N7+^-%
M"$4AH@B3":JR(K8)\ZLOT9R=1>&IV9"I]CQBF@X)KHO(SI-=L1JH^W=OL7[K
M>^(@)K`U;',:K4`;39PD-&>FJ;?F$=-ZLBO^E9\7Z0''_2Y9FIY4J#5Q8HEK
MK4<]3D"9ZR+F_7]WB82OO*\N_/,EDJLBLB.BQO_K#7VF\1O]9^:]9@A8)P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S,P+G!N9P``````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W-3``,3`U,34T,S$P
M-C8`,#(U,34S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T
M24U%!]0!#`X"$!?2/7T````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(`
M``L2`=+=?OP```5U241!5$C'K95K3)-G%,?Q%@+QFKG$>9EU,4MT^^!T.LST
MT[(YOQ"9;LO,,N>'92R2;3&;R0;3Q1L3D0K(15NP@)0"0BTMM%KNK10HM%!:
M>H72*WW[]D*ITM(+_[V0C&2#)2[S24Z>Y,GS_,YY3O[GG(2$%UQ3?NLYF\T"
MN\V:DO"RUY1;Y!?P&*CEL/\_'`B?]WI=6M)-%"!.T`)C&0%.R6GHM"HUXG;:
M;#A0X"8);2P6.__7FW@\_@IEVY;`8M&9SW6C\O2)B?%T_Y1_U5S,F:U3%$(L
M8B'R7(KGBGU@Y^R%7'H+<^$.6/1E$#35(AJ-9,>CQ"J?=R+=19!=D4CTUA)X
M)#SYA5E7A29N*2P6<Q-B-D-`?0HU](,P2$YAJG43V)<V0E">@JCI&`3,=]$N
MO`;$G8:07]C4*;X#B50*J\U)6P)_[A.M"#DN9WCD1\$I/(X!X7<PMQU$T8\;
M</'+S;CR]2;\D+8)OWR['^+\O;B>L1UJ\8=XID^#BO\VZ'G72;F\_Q.[P[GB
M7_(<2H\2Y0@($G'W_&;D9[R&MDO)&+FQ!HJ"K9`P/H9"4HN^'C&J6=EH9^Z'
MB9T$>M8AC*@Z#4#TO66@T9_=+JURW-AK"Q*5&&M^"Y4_K<=XX6H$JU>B[^X^
MJ/I;8-2K01!NRDB,F:W@5%<B)_,$'I5_A-!4'8+3#ELP&.3^$W[:ZZBO-TC2
M\)2Y$Q59.^!BK$:D824&60<P+*L#29*P.PG(ATSHZ1^EX';T#NJ17]2(0GH.
M:LK.@E.1"?7(L':I6L(:6L3/@5MZ%,+?UV.N-@$>3B*Z&K,PZ2)`N#TPF9T4
M6`>ERH1)P@-1FP(-/"D>MRMPCU&!VIHR*@AW@)+C5PM0+]&7HI1^GS(F_2;-
M;[H&)?<(-'EK(:&_B6;&":A5<HP:K!C16O"T7P]>2Q^Z9:-HZU*!URQ;^`%)
M>F"VV"$0"-#<W$RI1L;1:#0I"=[)5HQ(S\(HW`L//PF<W]:AY<8^R+KY&!H:
MAF)D#)+>48Q/3"Y$6,H40*XT8$"IH\X<\/E\L#D(:*D`W&Z2^IT=5>Q'Z._O
M1X+7P4T9E9Y,\=D$:N=()L2,`WA2=QW=/2HH*?#\9;76C%&]!<U/!M`A&095
M+/!X/!34A<%A$_BB/G#Y3Q<<M'4-HZBD'*+'8BSF/!HVG)EQ%<(H.H0.7C:,
M!ATL-B>5C@F(.Y5@58OQI'T0;M(+D@+/6X]<#R9+B(+B1M1Q)90#&;@"&>Y7
M5*.KLP.+:O$XN%.#CS]#)_L(NLH.P\0[`TGC)0C9%U%9>AEW<K-067P!K3PZ
MQ`^O0B9FHH9%1\F=6R@I+@6S)!O%1;?QL($'+I<'A4*1NZCS8(!03OG&;"%_
M!29XN]!V90,EQV1,5R<BP$D"29F;4L\T-PD^-K57K<50P08TY.Y&1_UQ&-65
M4"JZ;'J#D2\4MFS1:-2)?Y/C7(Q(C]DO8*)^/9B9.Z!D[`9Y?R-\Y6L0>K`"
MX0<)F&:M@INY#LZJ;?#Q$B$I7@M&7BI"STS+5^A"]'/3K\?\#7IC:PJJ"D]B
MJ/L"`@.'T9Z_!9TY-%C8;Z`U;R=4I;M@KWT5O)N4XX$/X._=@_K;[T`HY)$S
M,S.IR\+CL8#6I+X''O<N)2EBL2M6YAZ$IO-31+JW0IRW#E4W]V-6_3[*KN[!
MZ!`+T;#6X#7GDPUL.J1220G5KI.7[>=ZG3S=Y7*DS\[.+NGGL;%4/,S;#G[#
MKYA[SD=OQQ]H%0ML\ZF(Q2*IXR9%R;P\0^$0[84FD8NP:UVNR85)%"&+`_7W
MCJ&WMSN`V#B-)*T%.N/X8I.B`DJ.1J,TJO17_^>Q-QOL\XMX5V`T&?TO?4"'
M0^0YJ]4$A\-Y[D7?_`GE`WS[XO>XBP````!)14Y$KD)@@@``````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S$N<&YG````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C$R-``Q,#4Q-30S,3`V-@`P,C4Q-#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@(BWP5L_0````9B2T=$
M`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_````^%)1$%42,?%E;UN
MG$44AI\S,]___GCCC6-,9&$++8DB(M%P"[X!2DJZ]$@@1(6@B"@I:%$D&FZ`
M:T`"A"(D3`C&2>S8:WOC_7;WV^]G9BB\B8D")`(A3CUZ-//..<^!_[#D10]Z
M;S\&$J`0T>__*[AW90_4+7RYB:_`VP&@`(?(-A*#A'=!;B#JH8B>OQ#<N_H=
MW.PMW'3+UR/J>HIS;L'V&*7008H$2Z"[(-%-4<&[SX5[;]_#YA_1'*EJ=D@^
MJRAKCW/@G,=H(0P#E&]($T.<K4!PT:$['XCH3_X2?G;CZ>=NOJLF^8A\+GBO
M*8H"P>.L12DACB+*JJ*I:[HM37_E)4RZ[M"M3T%]^#@B>2IC-_^29KB5CW;)
M"T7=`"(H$:KYC.'>`\(X1:J"(&N##O#.LMP+65M_#<(UD&A#5+##(L1%J5NX
MV595##G)/77M`(=28`)#/9]CO<,$AN'!/8[NWT%IC0EC]O=&Y"?WP)X"_K/'
M1'.>2;7IZQ-FLY*R;#!*$$")8,N",(IX^?(Z6BNXO,%\.@'7X!"LM>S<^86K
M[3XFZV[^";S&-05UXQ'O<(U#*8VM2D9[]S%I1A!&*/$$44(0)UCG$#E[V<EP
MCV(RHIV<=Z0Z'Q`[J!I'57ML8S'&$$8AX^,C=K9OL[_S,TU9,AOG>#S>.^JR
MH"I+O#+43C.=3`$_6`S<D\P3O%/5O.3TT2D*C[46O,4U%28(4"*$<<Q\.L%6
M%=H$U$4.WA,$(29.::P%O%I,\I-8"D2YIJ[4]'A(%*>T>SV<K<F6>KQRY3I1
MDG*TO\OAW6W6UE_%EAV4#DC;'42'1'&*T1H0!Q1/;G[F"K6=)!&A%O+#?8I\
M3%TV:*5HM3ODPP,>;O_(+#_EZ,$NX^$!01"3=+HHI4BRE%:G"\CV8_><?ZB$
M1&F'+`LYNI_SZ&"?5K?+\=X]IODI2A1::9(XH[VR2K=_"1U&"R%`DB;$:1M4
MS+/=(N%='?6O7+J\RNUOON7PP0Y)NTM5S<E'(]J=+NN#UVE=6"9*$NJJ)DP2
MYI,92FM6+W4Q<7\ALS]TRUFYMU'9U^W^!AO7!A2-97PZ8CJ=X3R(*$P4(Z(X
M_NU7O&L`P3E'%EM:2VMG$D-N/`,7%8U0Z5<$*^[*&V\RN'X-=(`Q$2A-D&2X
MNB9*4U8'5^E>7`$1L@26^WTD7'%(=!-1#Y]OQ?I0[>_<YJ?O?R`R*4'2)NDM
MH[5@M"=.(I8NM,F6UL[`NOOW5GS6YY.M:G9(,1Y1%C,\&JTU<1H2MWJ8:!G,
MTHO[_.E-)+?PU29^#MX/%@,"8L9(N/>/-M%S=BC`=R+Z"_[/^AW/#=+CZ#O!
MY@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\S,BYP;F<`````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#4U`#$P-3$U-#,Q
M,#8V`#`R-3$U-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'
M=$E-10?4`0P.`C5<UNDZ````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2
M```+$@'2W7[\```$NDE$051(QZU5;6Q3911NV21S"(85,IR&%)Q@8F*4$-9`
M^($F@OX@P"\UD:F)N(08$P-F$),MB`X_\*-#)R`;Q"%SN'7MQ@9;[3YHN[*M
M7=?>]>-VW=I[^[FN[;JMW=I1']_;%=2T1$QVDR=OV[SW.:?/><XY/-Y#/FZ7
M740`[N0M]]/;^9F(`-RY+(1^GTL2"GK$2'J%0:^:4DEW(^#NI;CO"PM1<7#*
M:X['XQ_=NY],)@4$3V80^;RNU;1%6\8RMK)())(#+)8,#S:QU,#7B$=[X+=5
M@98)P(Y6X,^$$N/6WZ%45".16*A*)!(Y)%#9I-_52SZ?S2"?G@X):;,2`]V?
M@'7J94AZ:#]S$;KFI^'7[H?YYDY,2G)!M6W#]-AA6.7;H%<>`W=O=C8DTRJ_
MA6FD%1ZW4YA!/C<WR_=ZF$/ZVR<#EEM;85._`:?J59P_7H"J=]?BT[<$J'P]
M'^(C!6BH?`I]/ZX&J]X+EBJ'Z=9+,/YQ(#`\U'6(*,#/JC$G17#20%-MS\/X
M\TI4O+T!/QQY#*I3N0A=XB-^E8=('1^Z+U:BY<0:*,YMA?W:XYAH$8`>;:&Y
M][-;S>V0..PJ-AKZ#>:NEW'BS0+4?Y"'Z"]\0$+BWO@'I#S,7^5CZ,PJR+\2
M8$0FPGRD&=$YAIV9"4LRR"?L1K%&?AQW&C?C0OE2QBGB5D(F)^@C4*4A7PH2
MO\:'\5PAS(W/P=!>@F[9>[!:-.8,\D2<%<X&.^#0[$/5.VM34J0REJ<)APD,
M!'J"?@(%+Q68_2D//>(G,-J^'3['%42FW:7W28E]1)J>:I%1=>R@UW8&5,<N
MG"+%XS1.2="7)K:18([\I5.?#MC.(_]N!4R7BF'OW)FR:\"MI+A&(Y86\3SN
M<=SN/`V5=`],DO5P-I)"$E=PQ4N1J]+9CN<!G@U+`0SIWSLY:7BX<[80T](<
MT%(!5,V[T=U1`<9!@\<R%E'WC>,B'Z.@N`89:MJ.TX<%*5?\*W,Z)VOFL?H5
M,-<6@VI],=5@/J>"4MPX*7).6/\>$_%XI#3L:P(MWX6+Q]:E[):AN3Y]WBLJ
M<4WP\J.PUF\"T[\/L>DN)!<]F4W$,B:SLN,HM-(7(*_9@IN5!9C_#[?<;>!C
MJKX(QGHAAAHW8;"['(S3+,[2_D%))&QG%V::28N7H.7T.FB)C^._9O&Y9(DX
M6+L*YKJ-\&KV@NL/F^4VZV+')0_L4&:BFQZ3%6'LZAKTGW\6ANI"L#5Y*5=P
M1>8TYJ3@,J:O%,-]_1&2S`[,S=@?W*%D$O+'Z)%#!D5IP-BQ`X[A#Q&A#F"P
MMA!4W298:I^!AKC">*$8XPU;H+M<!-^=UV!2[,=$UT;HU>+`PGQL?U;R8'"*
M3,4>#/1^CDD_DYZ*%Z!K6IJ*7N4>^"4K,=RP%3[=01AEF^&T5./N(DOK!J[+
M-/*/H1MHK0F'0OE9UAA#YOEPF<_K+(O%8O?G^4C_EXC/]2#,?@]'VWK0ZO>Q
M&.O#Z.`W4/=<9+E[8S8J9]QNJ`E.>1"+1H4/M8FXX@0F7:E-9!KZ[J"V_14P
MUI8(DGYA(.`6V\>,]XM'ED0^@9`@]W^O/+U6(E(KJN!S&\++OJ!#(;_(Q=+P
M^YQ''_:=OP#`$A@^_)^$)0````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,S+G!N9P``
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(Q,C0`,3`U,34T,S$P-C8`,#(U,34Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X#"6JBI/P````&8DM'
M1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```/A241!5$C'Q97)
M;EU%$(:_ZN[39_(='-_$X2H)LH5N$C%(;'@%OP!+ENRR1P(A5@@6$4L6;%&D
M;'@!7H*`B!!R!NPX\1#/=SY]SNEFX>N8*$`B$*+6I:]+?__U%_R'):_:&$+]
M!9`"$Q']R;^"!U_,@[I%*)8)#D+=`Q3@$5E%$A#[$.0&HK9%]/25X,&7'^+'
M[^-'*Z$\HBQ'>%\3T`@U6FE,E"-1"W0+)+XI*OKHI?`0ZH^IAY]3[2DWWF$P
M=KC24WOP7J%U(+81*E2DJ2'-+T!TWJ.;GXKH+_\2/IOX&S]]I(:#?893A0^*
MR62"B.#K&A$A22Q5X7!E22M7="YV,>D5CY[["M1GIQ+)<QK[Z6VJO97!X3J#
MB:+T)RV"4$W'[&X^QB0YXB;8O(%H0^T]G7E+]\I5L%V0>$E4M,;L@V:E;N''
M*V[RE(-!P%4!O$<)V$APQ90Z!*+(L+>SP=[C^XC6F#AA:_.(P<$&U,=`^/J4
M:,XT<<NA/&0\GE(4%48)("@1RFF%M3'=2U=06A$N+U&,AQ`\H?+4=<7:O0=<
M;W0P>6OY3^`EOAKC*I`0\%6-*$5=>@Z>/";*,B)K(8"-,R*;$.KZ!&(M!T\W
MF0P/::1GCE1G"U+W7.6IRD!=E6ACB!-+?V^7]?L_L[5VC[(HF(X&A."!@"LF
ME*X@B*;TFM%P!(3>;.&>:9X2O'+3@N.C/DK`^QJ\IZH<1EN4"'&24(Q&>'?R
M>#D>$$(@BB*B)*.J:B"HV28_DV6"*%^53HWW=XGBA+ESYZBKBF:K373M+>(D
M9W]K@YT'JW1??X.H;*),1-IH@8ZP28Z)(D`\,'DV^4E6Z-4TC3%&,=C=9CKH
M4SF'TIJY1HOAW@[;]WYA.NJS^V2=_LXVUB3DS29:*=(\9:[1`&3U-'O./E0B
MXJQ%GAGV-@8<[FS1:+79WWS$L'],I`U*1<0VI77A-9J=18R-3]U`EF4D60-4
MPHMN$?M0QPO7%B]=Y.Z=']A^LD[6:%*Z*?W#`YK--I=[;].87R#)4IPKB=,4
M-QJAM>;\8A.3=&9A]@>WG)3_`)5_W^@LL73U*D55,3P^9#0>XWT`T=@D16G-
M_OIO!%\1$&H/6>*9:W=/0@RY\0)<5'R(RKXC6O37WGV/WCMO$D1AM489@\TR
M?.6P:<K%WG5:YQ=!($]J%A8ZB+W@D?@FHK9?GHKECMI:N\NO/_Y$;')LUB!M
M+Z"U0FM/FB:TS\V1M[LG8-WZ^U1\,<^'*V[\E$G_"#<9$<2@E"+)+,G</"9>
M`--^]3Q__A+)+8);)DPAA-YL04!,'[&;_^@2O>2&`MP1T=_R?];OFD+6UU#>
M\8@`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O,S0N<&YG````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8V,P`Q,#4Q-30S
M,3`V-@`P,C4Q-C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````
M!W1)344'U`$,#@,;F1O5M`````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+
M$@``"Q(!TMU^_```!4!)1$%42,>ME6ML4V48QXM#42)&(QB-R"I&$C[Y@02G
MX0/&1"8XQ!%C_.(E49DAQ(PPO$#"N+@M#`7*"*";;$-<F!G=I9N#;:5;=^FZ
M=FMWNI[UG&W=N?3T]-[#UJWM5OZ^98*2\0$33O+/\YZ3]_S.<Y[W??^/2O6`
MET<<SR)".JH>]G6CM3B+".GX4(`^6="&0Y(&*5D=]/8YNNLW(^#I<B`EJ>/Q
MF"84]-*)1&+OG?FI5.I9HA<7@62OM((='<P3!39/490,8/YUFT4K#/>?0"+6
M"=]H$4:;5D&BBW`K8<3$:!UZ;YQ$,ADO3B:3&:&0G.?SB9UD_-,B>#@<5C-T
M)\R&@Q`XJI%DQ_CX<ECK7H%O<`><S6]"T"[#B.XU1-E/0%_?`%O7/J3G34V%
M&H>ZC\-I:R9KPJD7P4FV2[P>/M=F/!!@6]?#U?LE_-:=,)W-!'-A#2*7GH?R
M^W/@*U9CN&(=G+5K()H_A.0Z`JH]!\.&+R`*C&9N+OG$(C@IPUY2OV(//\18
M=5M!77T;0W6?8^QZ/J2^0DB6D_#9SB`P?/9V9(T_8Z3G+&R&(HP9\\$Z]8C'
M9S$_/W_X'C!9A`)9%N,NV@0WVP);=PD<+=]`,!;`-W048>8T%+$!4=D()6A'
M).""C^L&2UW'\$`3&'LS),$"O]\#18G&Y^;F#I':+[L#/RE);AC;2V%LR8.Y
MJ0"B?@^4@5V(VS_&[,A'F&6_0LQ=@&FQ!-/")02Y)@AT,^@A'>R6>E"6.EA,
M?X)E;)B9F0'Y0/9=>#P^`P_?`:KG,.RM1R#T%R-,%4*A?\`4NQ^QR7S$A'Q,
M\_MPDSV&(%,&C_T"V(%JV$U7X#"5@6?;<%.)I$L#PLQ63=T,[XZ$Q+@LVC$^
M<A%6_2$P'0<A]1^%,GH44Q.%B(G?84;:A[A<<#O&N&\198[#Z_@%$P._P=Y;
M#=9:`?=()7R>`01D6DM.\B:5Y!F'L:T$/;J=H%IV@+Y&%K']`/C>8_#;2Q!V
ME2+*%T'Q%&'*5X(H5XCPV$%$G87PVDZ#,Y=AJ.T$N,Y=H'2;T5W_%KJN'0+/
MN:`2>"9+W_Q]ELS?<'#4<0PVD3U<DPU1MPVR/@>2>3O9'43VG`4-D>>#6^'O
M(=)O`W]U,YPUVV!OV8))JA@^P>!(\R8GZ7]M(AF/?!J5:S':M@G4J<>1JB&[
M4Z="RJ#"+1.1A=Q;23239YUD?(V,ZU60RU?`4?4R.-.[B$7;D)KS+#Y$HC!*
M][3NAJ5Q`T:J,A&M6@9<)9!6`FDC0"-1#QEW+(#1H$+BCPQP!$Q=SH2Y]E58
M#/O)Z79J%L&CT;!6B7#"3+0!KI:-L&F>0K3R4=RZ0D`D0S3_(]U"QHG+C\!]
M_AD,EJ^%V+<%BK\6+KI+$`6W]KXNF#8K8=+`3-:MA+OZ2;!5J^'Y]6D$RQ]#
M\M(2(A64BTMOEX*[J"9_N`YBW6,8;GP#L>DQ)OW^?<%I;QD?<^12AL\"CK\V
M@AO<@ZF1]V"I6`6F4HVQZG48*%L)ZGPF)FK68[CR!?CZ<D!WY,*C?XELQS.!
M^.S,]OO"0Z'@@BMVEB`4\-SCBMZ!]^'M?`<RR=)&P+[!7#B;UL+C+,7\G,A8
M35<:3>W[834WG`N'0\L7P06!6\$0/_=YN3QR?/_CYZ5(3!L0X4YADOBYN_=K
M)&/=H,P:]'=5".EYX^-TAGO"<2X4E!"+Q=0/U(E$?D(;\(N:=.>AS6<^&&K)
M!N_2*NG.%`A(&H:QW5T\8E3+B=1$2_]WRZ.L35DF_8^0/;;(0V_0X;`_2^09
M^&1N]X.^\S?D6(B<6E=?V@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-2YP;F<`
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,C8V`#$P-3$U-#,Q,#8V`#`R-3$V,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.`S+;J4W8````!F)+
M1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$0TE$051(Q]65
MRVM<91C&GW.96R:33.::S$QB,DTGU:2T$6VQ%'$@Z*)BQ$4AB`JZE"YL]1]P
M)PA=F84@NM-*$01#01,8JM)833))$Y,FD\EE[O<Y9\Z9,_?QG1$7-9E&<*,'
MSF(NW^]]ON=]OO<#_J\/\[@?_:M^A\'0=Z54K5U/)5/0:'B4*W6PJ$.E4H'A
M>'1I5;#;[%#Q_+U$(OZAR60*V^WVVF/AB43BXM9VX':UR;AZ>XW0Z;0M0'M!
MH]D$RW$HETI0RF7$8W&(^0R&!YT8\WC>M5JMLRT&WPF^M+SRJL%H=AFT6O`$
M:H'YULNQD.0BLMD<?KM_#[(L(YL34*LU4*W4X':[K]'RSO#=W=WG'ZQOO2^*
M(@:-1C`,@P)!6JI;17*Y'&*Q*!YN;>.I,V-P]EL;#,O?/>4>ADZK.?R+<RS\
ML\^_8*WV`=[A="$1B\'A=$(J2&UKM!H-2F2'D"_`Z1K`S,Q5GTZGFZ/WX[]S
MV./@TZ],?Y++Y=LV5.H-1,C36#)-:A,([`91+)9P&(Z@I"BHU^N+QX$[PO?V
M]]VA<`PY042K2'!O'Z:>;E2J582B<?RZY,?VUA8EIP:.^M'I.6*+HB@W9MY\
M6V6U.VC[9<A2D2!54'+`L"S*Y0KR>;$=M'0JVU+>$7Y$^:VOO[G<9[9S=GL_
M):&(9#J#)%E2E!5PU-%(:T?9#,"ID,YF\=W<':<D%7K^$7SQ_@K,%@M2J0QV
M=H+MI`P-.:%6\01G8>CN:O_/:"0>K\*#]?4W?+Z[3Y\(GU]84.\$ME4[FYLH
M4K,:C3K.C(VB6JU@[R",O<,P.&JRU6:ATZI#7Z\)^Y$4EM<V;M):?4<X>:TG
M/V?U.LT5I>5U0:3X%;"Y^1"K_C4DHX>4DF*[8(5\Y\@C6[\->GT7?OA^_GPX
M&O>1_Z/'-I1B9Z4FO9/+Y\GC%-1J#?3=!HB"@%CDD)1J4)`*;>4EI?1G2L@R
MEF8,RS)87EE]YLFQTU.$"AP97%25.S@(W9B?]WWDHQ/8W`_"U6>&8K6@.Y=!
MI1'"@&,1&TL%%.QOP4E[-O6:D5;SZ,UG`F,CPY+7ZQ4=#L=5*IQX1#E]49>D
MHGAN<A)L/(K3EYY#M-&`JXL4)_=@,7\*ERV.V?``#*=&X#TWB1"EB5?DQ='!
M@=?'QR>"'3VG3/<']T+O_9C)8=!B@DSQ]8L29"%#"F]!$HI8637CB<$:3&@B
MEJ?/0@&*+/F.`S\"7_S%KUT[B'@BF32L-`F%2AG:5`AB^DL8NN[@V[F+*#-3
MV`C:83;V(5628:F5!>_E2[^?>$*-AF[4-&IXC3H,#P]=RPO"RT+YYY=&/%]A
MX2<GGKWP&AJ:?DQ>$)2)L^/7#VC.<*P^31?#[1/A@T,#X6ZQ,,(P39K+E0-9
M$M3G)Z078LDIC=4V'76[S[Y883BY9VBTX?%X#O_U'9C/YS[8#6S?3*?3D_^Y
M"_H/WO3Y]MDGKW``````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S,V+G!N9P``````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V-#$`,3`U,34T
M,S$P-C8`,#(U,38P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H```
M``=T24U%!]0!#`X$#2*.]B(````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``
M"Q(```L2`=+=?OP```4N241!5$C'K95K3)-7&,??]VT+WICS,K-D48O+S-R7
MS<5HM_G%F&Q^F4[]M)F-;(D;R]RF+DYW\X+!*%-#&E$$'$,-S(H4*"HXH("E
M4&ZEI?3R4B[MVRLMO4!KH:7\=RIL+BE+7.))3D[.R3F_\YS_<Y[GH:BG;';;
MH(AT)$;J63=%?;:HN2X;#?>SGPW<[;))?6-.,>).X9CSH4Y9N15>1XLN,9^<
MG!#[QER&Z>GHX;_WQ^.Q%:2_E`1R.6UIK+$[D[,.9`:#01[9M$7=>8?K[SB/
M:+@9;O-9&*N7@^L_@9FH`L.F<BB;KF`Z&JY%/+S:YW-F>D:MS;'8Y(4D>"#@
M%PX8F]'1=!R<I;<:<0<[:BF$KF(-/%WO8^CN)K@J^3#?W8B`X4,8&]]$3]-W
MP'@?0@&G4MV:`[U&!H?=(DR"AT(AVNFP[E$__-G#UJ[#0.M'\*FV0W4A%0,Y
M`H2+&$P74WA4P&`L+P7N&WPX:[8@4+4;;-E;\!:\#D?=Z0-$`7I>C1-2>$<U
MK%'V&NPE`@SG+42@@,;D61K.;!J/<AFX3M*(9M$(_T##>SP-@:,"1'^D$,I.
MQT1+42TQ<EGR5[./2"U#;5S85PYGR]LPBP4(%=.8J:`P=9[!I7T+,72$!^D^
M'@;V,VC9RV#X"QJU>WEP[Z?1^/GS:)%<A-_GN9L$'QG4B#L:#J&K/!V-Y]-@
MO\1@Y@X%U!$IKBZ`[$L^V)]X*/N4A_:O!2C<GXK!7QCD92R")4N`O`,OX-ZM
MSV`RJ@Q)\.BD13CAJX.U]3U(CRV%^RH#R`B\@<#_H%%UB`?U.1YN'>2A^Q2#
MBD-\#(MI7,ODPW:91NFI-;"Q10@&'!E/_K+;)FIONB#2MA[>[1PXA[Y[6Y&;
ML023-VB@AL`5%")R"K]_GPJ39#$DQ/K^8@:EQW@PE?!0?I@XMIQ!V:^K8=.?
M1B(>$@%'OK2(<MB'T?S@#!15VV&H6`ES60HN?KP8D7_!PVT,.LI285<NA:HT
M!1XY'R.R%*B+%L!RF8&F,`VJ?#[T%<NAK'@'\MK3L%I,H#@K*WI0<U+DM#3J
M;+H3Z)"\@3/[TN`LG).EF<*,BD),0V-:ST-,2R.N)J^I)[^HDD;H.@/#M5=@
MN+,15G+>;9'K$CS+B/%)FIB:"F3X714P-FU%WK<KT7*<AQDI@?\Y:SW(!="0
MWC,W3ZQ741@M7@+#]9?!*7<@'*A'/.9(#B*K16]0U'Z#SNK-:+B\'K>/+$.H
MA$A3/0>2ST'E<W.R'BME8+^Y!OH;Z]`I24>7_`B)[G[Q/.'ODP;]0UPD6`E]
MS29(LY:C_L226>TKJ5F):N;&REDP5_`<<6XZW&T[,.ZY#9/^(6>S#4O_,T)M
M(TVL6;H*YM(TM.9O0/?%%<1I*>05#*(WB7.)QEXB1<)B7<DZ.&\+H)5M06C<
MS";.SPLFF9!F6>T>;<,GGK[[FS'2>Q#CN@_05K0*?;\)821.4^2L@C9_+49N
MO0IMR8MPJ]Z%0;X+EH;5Z%6*/>'0Q,YYX6-C7J')T(2VABQX/;;'6=%M+4"/
M=#U<G3LQJMB&T4H!U)(-\/3L@DZV%L/]8I)R.5:MDE2WUQ^%NJ/ZBM_G6S1/
M&;.2?*[.=+NLF9%()"F?![A<6&0K85)FDGD+^CIRH9#G<XE]+-O/&S)KK_C&
M'(A$'@F?JA+9N"&IUV-_7(D,73F[>^YM@]4D#2+N%GH\#O'0H.8?YQ&#%L5B
M4T)R&?]_E[S>;JFH77X&;H?6_\P+M-\_*K)S`R"E[*NG/?,7<L4*);F3%*<`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S<N<&YG
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C$W,@`Q,#4Q-30S,3`V-@`P,C4Q-C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@0JAX1#20````9B
M2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!`=)1$%42,?=
ME5M,$V84QWU:ML1%'Q:2+9FIB2%Q03<R,F9HL&RQF#!8`84QH8#CEF&Y="HE
MPF"ZT!80<.CDKD"12UO:"JR"M.5B`4M+[P5:-!CIF"F3`@-DA/SWR3L(8T_[
MDO-V\CN7_SGGV[?O?_M>OIS?;W<\H2C[!BB#PR,49?_@IO4_&J8,:;04L]5*
M65Q<I&QL;'CL"CRF-YS1&LQWS>-V##W60J,W87AT#"-:/;1&RZ;I369,V!V8
MG+0;;+;QE-G9V7??""9.,0]5`^Z^82UTY@E,/GT.Q[034\^<&)^:ALTQ#:UI
M'*,&*R1=/:BMO8.>7B7<"PMUVX))F0=%8DF36C,&O=4.H\T!B_TI@3XC\!GH
M3#9T]:CP73(+T<QXQ)]/`(_/AT:CP>KJ:NNV<(5"26MJ;H/XOAPC.B.L!#QJ
MM&V::=R!'M4C"-JDJ*BLA%*I(M#1]=[>7H[3Z>20Q`YL"R\L*@Z]7E8.H;0+
MG=T*DJD5,KD*`Z];1%K1K1I`<=EM='1T3JRLK'RROKY^?,="/M9H5UEL#IJ$
M4D@Z'Z"Q50;9;PHTBSM047</9;_6(/'[3+0*1?I=CU]1<<EJ4BH;=0(AJNJ;
M<:/B#@1"&>XVM^-F[3VP+N:!<386-V]5[`[N<#P1A$5$@\W)`Y^4GE=P'5FY
M7%SEE:.XO!H7KQ0@+OD'1$0G(S0LPMXWJ#ZT8SBOL%22_1,?[.RK)$`^./E\
M\$IOH_16':KK6\#)X^/LN20P$](0$Y^"O&M<[H[AD=_&22)CDDAVF8B.3T5U
M0PM^J:S'I1PN<G\N03[W!E+9.:0UN8B*34%<(LMI-%GZWPAN:!0<.74Z9#2(
M$;F9W;GX"^"552"1E877`3.R\@F\%"GIV4B[E$NJX"$V*1VLC,M_M[2*J%N"
MR4B])VAJ&?(/"(37<1]\^AD5?OYT!-"#X>U#!95&1_@W3$0Q$Q#$B"*"1B/H
MZP@$?A6.$]0OD,Z^+-D23F;U`U+>\]0+:?C\A!\^]O;!21H-#$8H:`%?PNN8
M%SP]/7#TZ&&<H@?"_V0`0D(8"`X.05CX&;1+I*_(=C*W##`S,^.K5JOM8K$8
M#8V-:&L3_E555<TMY%^Q<:]]A**"=_!C3M0KD4@DD\OE9$.KRF6R^RKBUZ33
MZ;AK:VN^V_:=.'BYW6X:.5RTN;D__12*!\$=DJ`7^I']L.C>1K\B:9[X>"PO
M+].6EI;>(J?V$+&#NUXFEVLVU*@O@<-\`#65#/3W',;P8.3\GC\)(C!#IZF>
MFS!^B(==[V-,1VZ,AH,Q;?/>X2/J#.Z4Y0BZI+[HEM<XEY>7)`L+?^2X7#/T
M/<-?_,[C&K294"C:K41H[__T[R1B>4XY)DZ[7*YC_Y;Q#_TTM4]SXYG=````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\S."YP;F<`````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3<W`#$P-3$U
M-#,Q,#8V`#`R-3$V-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*``
M```'=$E-10?4`0P.!0*K*MKR````!F)+1T0`_P#_`/^@O:>3````"7!(67,`
M``L2```+$@'2W7[\```$#$E$051(Q]V5:TR35QC'_;1LB8M^6$BV9*9F"YEQ
M;G-S800BQ<7*(C!*@&X"Q:%8#)2;,$H$`<U:*G(92+B#0L%26DH11+JVK-0"
M*RVE]`*T8'#0,0.3VP`9(?^=\1V$L4][DW_>\^$YO_.<YW8.'/C??B]>S!^T
M.R8HRIY>BJ:OGZ)4:R@J(O63/DJO3D\Q6VR4I:4ERN;FILN>P(/&H2#]D/F>
M><0.K<X(G7$8?0.#Z-<;H3=9MF0D&K4[,#9F'[+:1J)G9F;>?"68&(7+53T+
MZCX]#.91C#V=@F/2B8E?G1@9GX3-,0G]\`@&ABQH[9"CNKH6<H4*"XN+-3N"
MR34/-TND#5K=((S6,9AL=EC&)@CT&<:?3<,P;$.'O!M1T3$(8T;B8B0+.7P^
M=#H=UM;6FG:$*Y4JJJ!1!$E;)_H-)ECM3S%@LFUI>,0!>?<3-#1)459>#I6J
MFT`'-A0*!<?I='*(8X=VA-_.S:7G%1:CN;4#[5W*+4_;'JO0\T^(2"CDW1KP
M\TO0]K!]='5U]9.-C8V/=IW(7W3ZM;BD5`A$4DC;'Z.^20;9(P6$DH<HJVU$
M46D-HJ[&HTDD-NZY_'+OY*^Q8I-0(VA&59T0/Y;50M`LP[T'+;A;W8BXY$S0
M0YBX6U*Z-SBI:4%@2#@2.5G@%Y0BBYN'[S.XN,DOPIWB2B1?YR+BRC4$A4;!
MC\ZP_ZS1'MDUG,O/EZ9E\Y&8EHTDSDUP,OG(*2A#04DU*N\_0%IF#@&SP+S,
M1NC%J\BZQ>7M&LZX$"'])CR*>)>`L$@V`0I15'$?*>D\9-S*0Q:O$+'7,L!.
MO@%&.`L1EV*<IF&K^I7@NGK!^V=]_`>^\@O>VA@:&0M^83E8[%0PF-&(2\DD
M\`)$QW/(.H/<*@??L>+`3DS]2]@D]MP63$KJ+4&#L/>T]SD</_$93KEYPL.+
MAC,T?WSZN2<\J30$,4)Q@7D)YP,8"`@.P_FO0^#C&PAWCS-(2$R1;@LGM?J.
MV6*9BF$GX0MW#WQ\\A2\J-Z@TP-!]?Z2''@<KJXN.';L*,[2SN&TES=\_>GP
M\_-'4%`P6J2M+TEW,K<]8'IZVDVKU=HE$@GJZNLA$C7_65%1P;O-OV[[(?L#
MY'+?P(WT;U^*Q6)99V<GZ="*8IFLK9O8->@-!M[Z^KK;CG$G!A\N+"Q0R>"B
MSLW]X:%2=?FU2WV?&_L/PF)X'6KEE7EBX[*RLD)=7EY^C8S:(T2']]Q,L[,S
M=),Q'P[S(525!T`M/XH^#6-^WX\$27"`05<Y-VIZ%S]UO(U!`YDQ.@[Y-^P?
MWJ]-X(U;WT-'JSNZ.JN<*RO+TL7%W]/GYJ9H^X8__RV'-Z2/AU+98B6)/OF?
MOITD6:[CCE&?V=G9$_^6\3>Y([5`@0`(*P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,Y+G!N
M9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(S-S0`,3`U,34T,S$P-C8`,#(U,38V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X%%%_^;Z,````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```2)241!5$C'
M[91K3)ME%,=)_&(TQGTDFBS[Q@>SC&G(HHD+VTBVR'09$(D#`<O`PE`N'7)I
MN96Q0KF\M$"AY5(*E#LMM)3>"[0%RJ4M8&DA.M@$%,4IS>8@0?;W`1.T&I,9
M_60\W\[SG/=WSGO^YSE^?O]Y*^<+3W["R#ZEUNA._BO`U=75%URN)7I9936=
M+Y(\H6J%Z)4IGASZ%NM$P#^"CYO-`J&X`VU=?3":)^"87X!^U(+2ZGKDLSGV
MU;6UJK\-56F-)]1ZDZ2D4O"THW<(,L4(6KIDZ%=H(%=J,&J9!$\DP?MQR4^K
M^'6[`E%SRC/#RW@-P1RJ`7U#:NC'K+#:9B$;UJ)/H89U:AI#(WJ45`F0F)&'
ML.A$A$;<V.\94'SXE\#=W=WG'(LN?W&[U%^N'%GB\D50Z<>/VM`SJ(90TH,N
MF0I:DP4%G&K0&?GHE(V0I'J4\D1H:);LN)=7:.S2*O]'CQ^_Y`,G%9T:)-6)
M2(_KFMH(:!B]I/*>P1&4UXF1D,H$LX2'W!(*&<P[4&D-6%[Y`K..!2BU8VB1
M]J&D@@]F<3FTQG'*!ZXSC#84<6M0VRPEP:,0=PZ0RL=@G7:@6MB&&/IM2+KE
MOYY-S6#1M03[_"(Z^A2H:6S'#$DB4^GP<08+3#9GY;OM[3/'\)R"8@]/U(;&
MCCXX%UR0]@\3$0=16"Y`SAT**HV!G"_"[5F&96J6Q/6#=9>'&PFI2,TI1FN7
M'(R\NPB/348FLP!VN_W*,;Q)+/&D9N5#U-9[U.-";AT2TYF(B$L!F_S1H:@:
MPQA4.A,.)^C69T6X&DG#I6M1B$G*/-(@.C$-'\0G@Y&5B_GY^=_@][_:F$OE
M-R(D)@'!UR)P/CP*`8%!"`QY%P&G7\?UM!R<>_L"0NEI"+D:AJ!WPG'FS6"<
MO1B*H-`(!%ZX@O/1-W'ZC7,0BD1[6UM;EX[AGNT?8W,U%KR7F((*81-R2BM`
MH^H1SN:"QF+C(W$WXFCQJ)#V(I*6B-@N)2Z&18)V.QM)F;F@-[0CDEV*XK(J
M[_K&1HR/H)ZM[00F:4E-8PL:)NQDOLU@FZ:16LC!L'D2.C+?_;8Y=)O,&)J:
M0Y)T$.GL$E21B3)9K&`H3$AB<XC0+H\/^.#@X%7]RGV[>=:!?H<+\438^I96
M3+L\4$_.(%\_`5%G#[@S+MQD%<`\Y\2$W0E*;P%-T`RQM!-SGA5,VJ;7[]U;
M?<T'_LW.(XIEMB./6XF*41NR2BM1KC(BO9R/]IEY1/.;P&UJ13JIMKB:CR*E
M$2W]<K`4!N3P!&`/:L!IE<+I=,KW]_=?]H'S[6XJN4N!^L;FG]>^W=ZUN=Q@
M::U(8A6"9YK"IUP*"TON/??J@UVU??$@OEN!6J$(G@?K>^..A7VF[7,PF"Q8
MK=9*`G_>!][K6*+$<N5/.IV>?NA_^8/71)%G/6(P[A&3>[U>^<[.SHN'=^U.
M]Q0UH(3-9K.3LQ,=#D\VSSB!`9GL:_)P+O]IKY">OT4R1OUNS[SR_<.']!VO
M-^:/L239=;+GZ60BCO8Y^>[LYN;FH7_9[W][%OL%#P$]K13M"Z4`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O-#`N<&YG````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,U,0`Q,#4Q
M-30S,3`V-@`P,C4Q-3$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@
M````!W1)344'U`$,#@8%'F,<D@````9B2T=$`/\`_P#_H+VGDP````EP2%ES
M```+$@``"Q(!TMU^_```!'9)1$%42,?ME%M,VG<4QWU<]M0L>UJVI`][7+(L
M6]HL:W:Q=6W3J+,QUMA+M!5'M5:[5J>UXKPAH/)'4014!/&"@"`(7O@+`B(4
M`<5:M6+K939;ZFUU\1:,?O>O#Z9-:](T>UIVDM_+[_<[GW-^WW/.+R3D?WM7
M\XV.G6(4L>FY!4SZDYG9A'\%NK*RRK78'5J^2/)4KE"C5:5!8ZLZV-#4IEU;
M6PM])^C&YN:1R:EI67E5[9ZXL0V&7C.<;B_N>X;1:QD`BQ"BF$T$^P><XW[_
MZ/=4H"-O#7=[?++JND:(9`JTZ[NAII:D10-E1Q>ZR7Z0%CM*"`'"+R0@BU$(
M@;A!]E;@%UGPA?7;4H46I'40'M\('"XW5!38;'5@R#<,GE"*M.QBW&/RD'`C
M"Y&Q5_?ZS%9!,!A\_XW0Y965*+E"%4\!?+R:!K1HC#"2=C0J]>")Y"BIJ(6L
M38?*VB;0TNZ"Q1-BP.5!G\T)::L6-6()%.TZ:7%I93PEZ[%7X$T*]61571,$
M=7+J^=VHIQP,)AN:57ID%7"1="L'G"H),O/+4"MM@?_!0TP%`K`[A]#1;=F_
M5TWY9N:Q(!"*B`.PR6QE<BI$N_RZ9F@-)G3V6M&D-E!%]$&NU.$7!@OYI55P
M#@UCY,'8/MCJN(\NTHI\3B7*!1)XA_UH:&G'Y>L9*"GG;R\M+9W<A__**"((
MH0PU#0H,>?U4`7OP(E`15TAI6X1FM1[#_C&,3S["PXE)J/2]**0Z)B'U+B)B
M:;B3QP&;7P]:>@[BDS-0P.+B\?3TF7UXX/$,,X_)W2TLXT,L5Z&`RC(I/1OG
MKR0C*BX1/+%L/X!8VHIFC0&_L2L1DW`#H>%Q./73)5S\^3;B;V;C2E(:XN+I
MX%7R,3LS<^9`FF?+J\*"M@Z<N$;'C^<B$'XU&9\=^P9GH^,0R>;C>.AI7*"E
M(NS./9SX(0R1,1?QY>D(?/U=&,Y?NXFSA1Q<2DQ"+H.!09=[BBKJYP?P^N&I
MH\56#\[1Z)`J-2BK;T13<ROXQCY$B^7@<'G0]SN03E2CMDX"@4J'LAHAJJK$
M2%48D"*L@T;;(36;+?&+BTNO=LOO?_WM;"?-:&U3HL@ZA"0N'Y-3`9#^<62P
M"9!.-TI-`["X/3!YQT!O[T%[5^\3AWM$PI`V0ZW3/=_<W(Q^K<<75]=.,KT3
MBQD$'TZ?'S1U%])R&+!X1L'NL<%BLT-$!8P1-J#'TH]*TH&H$@+603>4GC$T
M]IAW*(TOOW&`U(_FB12S"XG74S`].Q\4*U30=QK!'QQ!+(N'KAX2N=UVT`J9
MT&H[,@TV!RHH:;H'/*!K3."UJ;<.'7G=U#R1449`*!+-4GH=I\98^?2/9UI6
MK_7Y[:Q<S,[->YPN=]!H-$X&`H$OMK:VM.OKZUHUZ=A.I.2SNUR'PS<V-HGQ
MB8GESD[#MR_O>[W>$9O-YJ2>_.GZQD8"]>]\]?+Y[-S<GR:2Q,+"`N=0^.[N
MW@<[.SL?OU:+Q:6/J/7A87[+R\N?S,W-'Z7NO!?RG[)_`-QH,85F,;7Y````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T,2YP
M;F<``````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,S$T`#$P-3$U-#,Q,#8V`#`R-3$U,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.!AJ3:Q%G````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$64E$051(
MQ]V5RT]C=13'9^%"HPM-C(O92,RX(\;5L)V-AH4+%RZ,B1F6_@-C9F70#2/.
M@(P30)X%*7U.G_1!'Y2^2UM:2NF[I2V][>W[00L&AO'KN5TP,4P4C8F)37[I
MO;]S[^><W_<\[HT;_\M?K]>[F4YG!EBV/!L(!&(VFRU6*#!^D\DT<'Y^_L8_
M!G>.CX>."DPAGLR@5F_@Y.0$E5H#-J<7,ID*H5"(UV@V/_O;X&ZW.\@4B\E,
MKH!RM8YBN8$"6T<LS2"58R&5F\%;E4$LD;99EI63X\%KP[.Y?(>M-M`].05;
M;</M3T&M]V+''Z/[)C1&'QY-B3`]K\"#\9_I)(INL5C\:P?-5N?+@TCL&1<I
M0Q&'$T4XO"ELV4-@:"^:*&!-:(;>',!N*(,-O0<_/9F#7K\I/SL[^Y366U>@
MC49#'@@$@XE$LITOE.`+I>#93<!DW8=09NTODS4$H70;FR8?JK46CGL]Y)@:
M(O$LM#I#VV#<J@L$@@BQ[EV"CXZ.;OL#!Z5P+-_7U.$]@-'JQV&^3-=13$U+
MH-"X$$DR"$<.T3GNHML[19ZI8B>0`%MIH-;HP.((X\'W$YB9F9F\A%/F)_>C
M&2AU;F1R)<0S#`('AX@D&-KS0*5S(758[.>@1U63I@!<OBB>JNQ8YNNQ'\W"
MX8G@%X$)X^./,3HZ^@*^M[<WF<D=$2R'$D7A]L6QL;F#%;X!ZV(S54P3Q]T>
MJ.Y1)CFT1B\E4XF'DP(L\+00*VW@K>FAV+`3?`*SL[,OX%1*P]%HM&9WNJ'6
MFB!3ZC&WL(Z'$W/X\?$2M'HSS!8;?#X_+%87^$(E)J:6\<.C1<S.KT,D44.N
MU&%=(,'2TE(M'H\/_[%I.IV/L]GL:3`8A%:K[:]H+/9;*I4ZL=IL7#5@=745
M&QH-%A<7(9<KX*1@['8'/!X/V?7]?;O=/ORRQGF=Y%G@X/0`5"H5=G=W68IB
M9'O;"K5:W7>XLK("J52*<#CL2:?3>@Z>R^6PM;4%B\7".;I[!4ZR#%BMUDN`
M1"(!S9)[Y."6V6SV<#8.JE`HL+R\C!VO=X3FRZK?[X=0*()()*(`-D#WL2OP
M<KE\L\2R!:_7BX6%Q:Y<+J\HE<H/.5LRF7Q3I],%.%DHNDPBF>"2^TVC4?_*
MX7!4$HE$B#L92?,U!?GV2[L3P%`D$DG2`Q9*\AA!ITBF^S3`[E<JU?=;K=88
M03^@5@>WZO4::&I:6NW.>_3>&*VA/VW_BXN+P>?/+T98MI272I]"+!;#9#(C
MN+?W#CE_A>SSG,9<$KF\<#J?G9U_=.W!Q3#,'=(;:VMK<+E<?:U]/I^;X)]3
M(IL&@Z$?.9^_#I(%).FOUX8WF\T[U+7]R"B9!.%S%>'F;!J-Y@N'PPGZ!X_'
MZ]MI?%P?3D=_M5`H?"L4"F,TB&).IS-&#F]Q-JJ0)QQXTV`H40*?D>/I=KO]
M[K_RZ:.Z?RU\<##I]?EN&XW&[V0RV2?_R3?X=ZS@ZV>FK"_/`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S0R+G!N9P``````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,3(`,3`U
M,34T,S$P-C8`,#(U,34P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4
MH`````=T24U%!]0!#`X&+\78U40````&8DM'1`#_`/\`_Z"]IY,````)<$A9
M<P``"Q(```L2`=+=?OP```17241!5$C'W97);QMU%,=[X`""`TB(0R]$J-PB
MQ*FY]@+*@0,'#@@)D2/_0%%/*'")&MJ8E"I)6YLZ(8Z=V-CQ$N]+O#NVXP7O
M6^QX;(^=>!P[MH.2IGQYXT,KE`H"0D)BI)\TOWDSG_=^W[?,E2O_RVLP&%PM
M%DMC+-M<BD0B&:?+E6&86MAJM8Z=G9V]]H_!O>/CB6JUQF1R)1RVVQ@.AV@>
M<'!Z@E`J-8C'XV*NT_GD;X/[_?YXK5[/E\H,6`(R+(=ZLXU\J89"F85"9<?C
M%14VY(IN@V55@^%P_-+P<F6_Q[;:&`R&!#^"+UR`UAC$3CA#^PZV+"'<G=_`
MP@,%;L\NTDDV^_5Z_:\='!T=?9Y,99XPC39%RR&1J\,3+,#NCJ'&MI'.,5B5
MV6"R1;`;+V'+&,`/]Q_":#2I3D]//Z;UQ@4HQW54D4@TFLOENQ6&12A>@'\W
M"ZLS!IG226N;[N.0*;9ALH9Q<'B$X_X0Y5H;R6P%>H.Y:[;8VU*I-,5QW,UG
MX&JU>CT<2302F0IIVJ!(DS`[PRCMLW2?QOR"`IM;/J3S#!+I,BC9Z)-D^[46
M`I$<&B3=`=>#PY/`S.TY+"XN"I[!*?."1'H/FP8?BI4&LB4&D>0>4B2!VA"`
MAI[G]^KH#T\(>D+OL/"&TE"H77@L,>(7<NCV)_&3U(K9V7N8GIY^#H_&8H*]
M2I5@%31:'?A#6>A,.Q"OF2&1VZ@$.R1!G\`#M-I=&$B6!:$&=[Z70KBLAUSM
M(2<F;.K<!)_#TM+2<SB5TF0JG3YT>_W0ZBU0J@UX*%S#'<$C".Z)H#?98+.[
M$`J'X7#Y()%I,#<OQG=W17CP:`WK<NWH&ZE4#I'HQ\-L-COYQZ;I]3XLE\LG
MT6@4>KU^M.BEWPK%PI`ZDZ\&K*RL8&MKBP=`I=J$EX)QNST(!`)D-])S$5PN
MU^2+&N?56"PFY.%NMQL:C0:[N[LL.9C:WMZ&5JL=.5Q>7H9"H4`BD0@4BT4C
M#Z]4*K#;[7`X'+RC+R[`T^GTF-/I'$7&`^1R.1_%37)PS6:S!7@;#U6KU1"+
MQ=@)!J=HOJR$22J9;!WKZ^L4@`ZTSUR`-YO-J]3*3#`8A%`HZJM4JA:!WN=M
M^7S^=8/!$.%EH5.4:$_=._B:X]I?>CR>5BZ7B_,G(VF^HB#??&%W`IA(I5)Y
M>L%!@VJ&(/,DTZTJP]QJM5KO4O?.$/0]:G7PJ]T^!$U-1[?7>X>^FZ$U\:?M
M?WY^/O[TZ?D4RS;V%8J?L;&Q`1JQH'R\1<Y?(OLC7F,^B7Q>>)U/S\X^N/3@
MJM5J-TAOK*ZNPN?SC;0.A4)^@G]*B>R8S6;0U(1$LC:J%I+TUTO#.YW.#>K:
M4624S!&$HO7S-JJ8SSP>[RCQ?&)Y.XV/R\/IZ"\S#/.-3";+T"#*>+W>##F\
MQMNH0N[K=#H83:8&)?")1")9Z':[;_\KOSZJ^U<2R:0@&`I=MU@LWRJ5RH_^
MDW_P[Q$`ZU'+(%&-`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#,N
M<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,Q-``Q,#4Q-30S,3`V-@`P,C4Q-3,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@<%!W@MTP``
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!%E)1$%4
M2,?=5<M/8W44GG^`A0M=N)J%"^/&S$+Y`UPX*U<FKHSQL<#$S.@H.I(!@T`+
M89B+C$(!*0R4/BCM;>F[I72`/G@4H;PNPS-06IY)>79@>'R>\XN1><1(HG'A
M36[:G'OO=\[YON^<WY4K_\LKF\V^NK2T='5U=5632"24B8D))9/9B8<CL9?_
M$?#>WEYN,IE*SLS,8V%Q$=O;V]C<W,2CV7D$>Z+#(R-C>8>'A^]?"@S`*W3+
M9V=G<F]OK]S5U35KL5CA]@00Z.Z!UQ>DWX>0[4[H]#*J[S>AJ:EYQV@TRF-C
M8[++Y9*#P:`\-#0DGYR<?/H\!5<W-C80#H?1TM*"LK(RM+?K4:92H:*B`K6U
M=;A[MPJ<\,>2$JA4:AB-)GJGG?ZKT-:F0W5U-2HK*Y')9*07P%=65F`P&.@C
M(X'5PN5RX]X]27RLT^G0T-"`4"@D8E555=#K]51]$R1)$O'2TE*83*;-HZ.C
M=YX!)TY=@4!``!,E,)O-<+O=J*FY3Q7]A-;65FBU6G1W=Z.CHX-`M:*0YN9F
MJ-5JD-BB6[?'-S<U-9WS)W`ZG7Y[<&@X;;4Y8;/9$(E$(,LR!@<'H2ZO@-%D
M0F-CHZC4[_>3H#U_5*U%$R4L+2V#Q^.!ID$+AR>*H?C(!2U34U-2_+<$?JE_
M`*ML0U]?GZBRO[\?M[^_`Z?3B?KZ>E$Q=V>Q6$17)#Q4Z@IH-/3,;,7/=0;8
M'#&8S)8+\)F9&>G1["SZPP/0M1MP\ZMO\<6-?'SRV0U\5U"..X7%*"XN06%1
M$0H+BW#KFP)\3,\^_.ASY-]6HZ"P'+?R?X#.Z".,!!P.QP4X"7"=JM^*1*+$
MF1^VK@#T1@>U29P^L%`W3O@#(=')P,``[,YN-&H[45GU*SV783#9$0Q%$'H8
M)K?%MF@>KC_M\2^/CX^S6UM;@@+R*W%J0"(QCD4:(/(PS)V=@N=.^O5ZO52$
M%Y%H##Y_@$1M`?E;Q*E(Y?D!DL[/ST$3QRT)OEE,N]T.15&$F.P2=E%'AUD4
M,#P\C%0J)7QNM5I!IA"=+2PLI,CGUYX!I\G$W-R<&`SV,[N"!VIG9P?3T]/"
MHGPS&`L[/S\OBNDAY[#`'&.7C8^/8W=W5WH:/(?`WWS\^'&2P>KJZKC*=#0:
MS7+2T]-3[F2![4DQ3$Y.@BFD_2/\S47Q7'"7R63R+8KGO+!?B)I<`E.3%=MI
MJ#RT$=-<?2P6P_KZNI:3D#:B([8K:\/TD"%.Z'TU)50?'!R\]%?+ZSVZ0Y1D
ME$&X55X#3!.[A!:2$-CK]8GI9'$Y$5'T]64V8QX+RU20,`*4AX9Y;FUMP\;&
M)M$2$^+Z?#XL+R\+`]!6?$)7[M^!OT'@>03^Y#";%>[0:#2T7VH$-=0^2!<1
M9]NQ:^+Q.//,X.]>IOHB2C!-"11:P0IQJHR.CM()E%$X1@D4HBA%4\W[9(5.
M**;J@W_M^"/1KNWO[TLDX.MK:VL2^?VU__P,_AT7XT2ZJUNW!P````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\T-"YP;F<`````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S4P`#$P
M-3$U-#,Q,#8V`#`R-3$V,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P.!Q?TP5R;````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```%=4E$051(QZU5:TR39QBMHD%1#,O\870S$!,W
MW8^ITXWI_+4L9#$AT[&Y+<M<S)*QL"U&,Y.I4T>F;`%$+@)"N74K4,"67K!(
MN?7"K906:$OI!=I26OCZ]4)!+KV>?309R09+7.:;G.3[\;XG)^<YWWEHM&<\
M<UYKALUFP;3-EDQ[WF?.*?0*>&5@L>K^/SFP<MGMGM613J(`82+1-Y'A8S[X
M!`:]6H/P=&+`[RL@"$+G]_LO__4F$@F_2&'?.K)0:.G\N&XPW6(QIWN]WIA(
MR)&E4Q9#U%J-P*(,BZHCJ,U^!8.R'$3\7;#J*R#@L1`,!K+"02+&X[:D$TY2
M'`P&<]>1!U8<GYK'?P>7_1!6JYF'D,TPI_D8=;EOPB!-P[PP'K6W$\"K.(G@
M1`H$]&/H%-X!P@[#LK>5)^DH05__`&SVV<1UY(N>UDW+]LQO78.GP2IZ'PKA
M-S!WG,"#2PFX^?EN9'[Y`BZ=2\"UKX]!E'\8=[_;!W5["I[JSV*4_QKR[]TF
M%8K!<XX98M._^+R<'B0JX1/$XN'EW2B\LA^B6W$8RXF!(G\O>N@I4$I8D/>*
MP*S.@HA^%,;:[<B[<0+JT6X#$'QK`]+@#R0QIC(;^VT+3@9,+8=1<R4>DX5;
M,<_<#'G9ZU`./(%1K\$LX03E+2;,4ZACUB#KQU0T5Z5@>:X!"_-VV\+"`N>?
MY)^Y[4V-!NF'D)8GH?KZRYAYN`7^QLU05!_'2&\C7"X2]ADG!H<GT#LP1I';
MT#^D1V%),XKN9Z.N\B+J&;>@48_HUJ=E19L8F*N'0_8.A#_O0H1%@ZLN%A+V
M3YB9)2BU+A@F[9#)QZ$:-6&&<*&U0PDV7X:V+A7*RAEH;*B$BR1\5!R_B)*Z
MB8%DE>S[9%//5V>]IKM0<DY"D[L3TKR#:"G_`)H1.;1Z*]3C%O3(]>`^'H"D
M3X,.R2CUW8=)BQVDRP6S=1H\'A^"EA9(97WU6JTVF>:>:8=:=A'&UD-P\;>C
M_L8."'X[@CX)'\,CPU!2*J64#9-6!YYT*E%*%V!098!"I8\2>SR>U?A!9YB"
MDW3#9)X&@]D,N5P.FMO.21[K^2C98Q-H')KK:"L[CB<-=R'N'85*/1&]K-:9
M,4:I;VE3H$LV0@V5I&;@BI(.#1O!$_:#P^_!F,&*#O$(2LN9:&]OPYKGP17#
MA>69?!B%Q]'%S8+1,`ZKS8'1,4M4<353A+;.H:BZ51M6T:O0@UXM1$$Q&PT<
M*=B"/FH&O:BN8:"[NP-K:7'9.7/*UC2(F:?079D,$_<"I.Q;$-;>!*,T$T4Y
M-\`HOHH.;AY$3;^@3T1'74T>2HIR45)<"GI)%HJ*\M#0Q`6;P\70D#)G+><+
M/D+E\UILRUX&S-PDB#(3,%NY`_/UL2!9<7!&L0WSG.WP,+?!5[43P_E4'>0>
MA.31&1@U#*B48IM>;^0+A8_W:+6:V+_%,1(FTD/VJ[`T[@*=ROI0V0$XJQ+@
MJ=R*4"T-_C]HF*N*@;,R'G;&/GB;=T!:'`]Z[AD\7;!L_(=&U4?F]P<\;+U5
M?!KEN><Q++F*.<7;Z,S?@_:"`S!6)$&<EPA-:1*F6;O!S3X`<O`]>/H/H?'^
M$;2T",BEI:74#<G#(9_.I*E`,YL.DB2BK3BO30/SWAO0BM,0D.R%B,H_(_LH
M5K2G4''G58P-5R&XHC.XS?GDH]H\R&32$JJNXS;L<[U>G3XSZTJG%D"TS\>5
MA6M]'II(15/>2^`_NH;($A\#7;^B7<2UK5H1#@=2)TW*$I)T8G%Q,?&9-A%!
M3*]MH@!9[&LJ>Q?]?9T^A"83/:[I`KUQ<JVD*$%Q%!(I;/G/:\^_,.`5<C)A
M-!J\SWU!KRR3&5-3)MCMCHQG??,GKW9]%J'\UM$`````245.1*Y"8((`````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0U
M+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,P,C0`,3`U,34T,S$P-C8`,#(U,34T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X'*JRI$(H`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```6A241!
M5$B)E95;3)IG',9[L=LF6[*[7:P7N]JR9+O9DMWL;C%;MK7=4FL/-IW6KMJU
MVFJMMBH>*-9#43R`"B(J"BA\@(#(00%%1$0\5"B>L;I6JU)/U2KR[(6E::QK
MFWW)DS??]^7]/?_O_S[O^QTY\IXKN/_B$Z*(M^B[]\U_%SB%J",86,'NUA0V
MUSQA;6]XL?]R'L&]I27RGDE4^'^@WP3W-SV!W96=C54G%O^VX;&O&W.SEK`>
M^WJP\+@7JXN]V%D?P_[>2I#,J24Z^GYX8*U@[\44EI[TP#?;'9;78\`CMP%C
MHUJ,>TR8FC21>SW<(VU87K`B&/"#P(7O-"`OTX(O9_?]2WT$:@E#0O#I*3.!
MZ6#6\^&TMZ*_5XQAIP(NAPRC@Q3\B_VO#&K?!HX-!M;W-_W#F)DV8W*\BXR6
M,#PTVJT2&#0UZ+4T05A+1Z>6!\]#W;\F_1)L^8>(P8:/<#Y[$_P1D3:P/8VG
M\UWA%DQX.S%!#":\!EC-33`;ZTE[].%[HY8+0SL7HT/J,-QBK,/,N`[[NT]"
MU3/?A!\+!E;Q<F,8OAESN"*'G4*G3@"AL!IRI0)22@J^@`>=AD>^0DRJE6)H
M@(*]1P2]N@J]7;78VYIX"WQO&<^?V3$]V84N0Q/*V97@"IJ@;->CK]])-`!5
MNP&,(A8*BW*AH+APD-Z'U&T40"%Y@(W5$83C2_;'(?CB?#=L5BE*6"6HXC>B
M1:Z!L%4!OE`"D4P%0Y<%"I46UU+OXE14%#(RDF'4U<-F$4)#E6%C)=3WE9!!
MQ"'XS+@1G`H&1!(INLQ6]`\X8>ZQ04+`H;'+8D4:C8[$M!S0"Q_@0EP\TK-H
M<-A:26LX9%%'"7S]('S]^?*QE6>3Z"4+Q^'RT2I7HXVTH*%)@C(.%XSB,C0V
M2Y!;6(*$Y#L0R]I@=SBATAI0PN:!Q<I'@Z`<:\NN5Y%\#9^8F*(J.&Q4U51!
MUJ9%O9@*PX5B*=)I#,3?3$-I!0>W,O/(<SW&W!X\?.B&4J.#7*4#MUZ$K'O%
M4,IJ$=C;%!'XAV'PPOS<U]SZIH6J.B&D2@W46B-$4B6ZK7WARD/`BNHZN(:&
MPU"[8Q#Z3A,$C4W(S+L/-3%3JCMP\VX>3ITYAX%!U^NTK"PO,\LK.<2]&5:;
M'5*Y"D7,,F0SF+A-NT?,R#;W>.!V/X)ST(4J7CU2[M)PYH]+.!N;`'H!,_QE
M5Y/3$!U[&3:[XS5\?6W]:%EE=4<!LQR<V@;D%[,0EY"$$V<NX'3T1;"K^:@C
M:0G%LD$DQ=6D%!R/.H^($[\C\L(EQ%]+0E3,%<1<34;LE82=X9'1E`,Y]\[,
MW:*5U2`V_AHNW<G!3\=/XDH6`S_\<A*QMVGX\;=(1!/`V8N7\3,Q/167@%_)
M&!6?B,CST8A)IR$UDX9&L2S[T+GB&'%[4MEU:&YIA<;4#0Z_`44*/>+BXT`7
MU"'RW&EP.0RDI:<BHZ0"D0G7(6RN)"H'NY:'&Q4\*-3:7?_JZJ<'P*0M7YHL
MUOEB%@=\J0H/RBJ@=X[B1F8N)`H)R;84!J,<)545<`W(4<WG(3WC#LH;):`4
M2LCZ7,AB%$+58?SS4-5C[D=,D=%,,FM$J5)/5CT'4H4ZG)8:>3OH;"X:E>VX
M7E@.<4L+5"H*%-6";`(/Q;.5!,`QX!PBJ?O\`'AG>^U[DW=Z[:\L.LDTY<\N
M9FVP!"(D%91"()8AN[89#)(<?G,+<@I+4:;J1":]`&UD\V3D%X,M52,Q.S^4
M>>I0U>/C$Q&4R8KT/`9F9WULXA[#EU"!Q+R"4$44U::!TS6(S4U_)=GZMON"
M%I1SJK#]XGD'245CI8A"4F9N(#3OO^`?3TYZJ:EI[U/2^R]"SW1&TTVG:PA3
M,[YOR1Z(V-KTA_[T'RPM/:&9>ZP8'AXRA4X]W]S\5_T#@[#UV;</@<GU#W!1
M$"W&DDY\`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T-BYP;F<`
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-S8R`#$P-3$U-#,Q,#8V`#`R-3$V-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.!SJQ'@#N````!F)+
M1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```%?TE$051(QXU5
M6TR:9QANLHLE2Y8E2W:SF^YZ-\MVM>QJ2;.L%\NR72Y9>K?,;$O69HM-L[8V
MZ5I=M46M5CR#EI/4`EI%%!20\X^<!>0L@J+(00&Q*#Q[P:Y)NYZ^Y/U/W_<]
MW_,^[^$_=>H5`ZB^C=KA6=0>JU$M`,>[J!VE&O>&U;]5BR*@<I8>/CWUIH,6
M?T,;!U#-$W8,1R4WBCD&Q:SAY$YV?."AN3`=F`:1"-&>+]X$^#1JE7NUR@9*
M^15L;^J1B.NQL;[\U!)Q'3(I#?9WC:@4[;0\00<<;)%+G[T:O%8I'Y5CV,LP
MB*_K&Q;P+V+-IVJ8SZ-`.*ANV*IK#I'`'$I9,VV+/SG@)1[0Q"5B7"UFC0V&
MH8`:OM5Y+,Q+8-"*8-:+H57QL&*1P+DR!3LC;9C'-OGD@$T0!NM%P!]2D):+
M.1>B80U6K`HL+TE@MS$X*.41#$8Q)9-"-LG&`V$_'@AZ8;-(X7;,P&Z5P>>2
MXNA@K1[D8[I\]3QX$XZSV$XLPF*8A-EL1B@<1R:[A[W]`G;2&222*<BD,G!'
M>C`R>)>\$<)+,ED,8BPJ1I';UE&`MTF>\MEGP:N%IN-R$"OF:3",!?F]$U"O
M+X9EO0-+&C-BZTF8S`YT=_6@B]6!078WU"HA>7@?,Y(^1'S3E$'1>IK^\!SX
M7E,^S6!9/4>@)61S>XA$-V&Q^J%:M&!](T7LLY#*E!!-/()69X=(),5@_R!T
M:C[FI@>A47)1/0P3\PJ>`N?R^Q_D<EEFQ3R#:'2#V*Z3!6$P>;"DMF)6KH;-
M'L#BD@%"T316O9&&7(ED&G:'!R,#'>"/=4,NH](H^^M9<P+^N%(Y[71Z/&[/
M&OS^(#S>,)0J!BYW`$:3#5RND)A.DQQNJ%3+"(0H_P_*R)!G[M40-K=VZ*`<
MG$XW1OI:42E14&N/3\`CT0C+Z?*3FS9B%"#&(1B,#F*U`[W1"1[O(59L+HI!
M@>0J-@(;",6ATUO!YTOA#\0:@5]0&L"^VX;=E+->L>,-<*/1P-I*[<#F\".U
MO4N+-XBEEW0V$F,YO:^C4"PUV.X7BK`P+HC%LQ@<&,;H*&FMT((OD%$L5.`,
M]V)GFV2A?M,`WR^4SMGLJWLD#4PF"^;D2G!&QW&GG87>NWW0Z2SP>%9AL]D:
M<9B<G$8_>PC=G9T8'>'3^RP$/"$D#Z<A&._#_GZRGNR?/`UH/+[YO4ZGYU@9
M!GWW[N&O/W_![S__B#]^/8>62Q?`:F]%UYUVM-VX2<\W</W*>5R^>!ZW;[62
MW02[^SKN<SJ13`1?7*%+:G.35JO'P\D'$'!9:+UV'BW-/^%*\\]H^_LJKE[\
M#4.#P^CL(*#A-LH0%@24(9JE!9*)BDXOQ^%A04'@[SX#;'-XW],9&(E"H:0"
M8C#&&<&4A(.AGLOH_*<9M]M:B/4UL'O:P1UEPT'EKJ$>(Q:.P^?S8E(\@0DA
M'[%8O/E_K`G\]()25^9RN%614`B!0()T.EG+[JQ6]&H1V+TL='60)+=:T$\2
M&#1">)QRB'ALC(]Q2/>I>EPJN7S>\=)V.RM72J:FYM)RN4*2S69CAX>'7;7:
M,<.89C1Z[1PVDT[LI`(X*"21R6Q2.X@'ME+I*8/1BO1NINF5O9P\^-KK]7X;
MBV]]I]&:=^L5N1:(+%2.*A_5&UNI5+PP*U=1AXS`:K5#K[>T4G6_1?G?=%`N
M?_S:/U$BN?6YR63-CW'Y&!D:;J1>H5B4UN>BL0VIU>K`_/PB!'P>Y;QU0*=;
M?N>UH/\-A]/]I4)!FWEC6%C04OF+$([$C?4YI5)ME,EF$(E$,#PT`/&$&/XU
M?^<;@Y,D[QM,=I%8R`&7,X9'C^0(AL)GZG,NE^N,7#Y/K$7@\R80"@51*.R7
M7X3S+P2?0<3OJ-56`````$E%3D2N0F""```````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S`N<&YG````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R-C$`,3`U,34T
M,S$P-C8`,#(U,#8U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H```
M``=T24U%!]0!#`TW!=IXI7D````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``
M"Q(```L2`=+=?OP```0^241!5$C'U97+;QM5%,8_SXSM<>S$3MRQ$]L)L1/L
M0HB:($H%10A+%2R*6B2D2A&B"UBB+FCA'V"'A-0598$0K!"@(B2DEDJ-D-4N
M$EIHG*9*B&L[\?L=C^WQ:R9V.![$HB1ND-C`6%<SOC/W=\_]SG?/!?ZOE^9Q
M+U=65QU#@Y;3+46Y6,CGH=?IT%84:#0:Z#@6&I;#`*^#S6:'EF.7<OG\1]9A
M2])NM^\^%I[+Y4YLA")7.WMP#9DM,!AX`G#J@$ZW"Y9ET6RUT)9E9#-95,4=
M/#'NP%&O]SU!$*[T&%P_^+V5E3>,9JMK@.?!L0QT6DX%<M1J4AWELH@[ORRA
MT>@]5["K=-%IMS#E=E^@X?WAD4CDY;4'OW_0K59AL9A)!D8%J@-(#K%<1B:=
MP</-$)X^ZH-K5.@R+'?+,^V%8<`0_XMS(/R++[]B!/L8YW"ZD$NGX70Y(1&<
MY_7@]7JT6FU4*C7J'\/"PKF`P6"X1NV3OW.8@^!GSYS]M+=LEM-"[@+)3![9
M;`&93`[A2)2D:"&62*#9;*+3Z2P?!.X+W]K>]B22&8B5BJIM=&L;9K,),CDE
MF<SB[F]!51)9WE7ST._:)PM%<VGA_#M:P>Y`FY9?EQKD"`6;H0@8AE'[1+&J
M&JU8V.E%WA>^+_+OOOWAI>$1.VNWCT*J-Y`OEI#/%]&@9PW]DJD,RCLE@-6A
M2/=KUW]R2E)MZ!_!E^[>@U404"B4$'H8!4,;9F+""2U9D6$T,)F,ZG<6"_$X
M/5;7'KP="-QZ]E#XXN*B+KH5UH8VUM5D[74[\/F>A*+(V(XE$8O'52L*-@%Z
M/8]ARS`2Z0*"J^N7::RQ+YQ@1EE6KO!Z[G3/:E*M2JV&C8U-!(/WR9)Q<@FY
M@R94*`<LJX'-;B-?#^#&S9MSR4PV0/I/'YA0CN,$2M*[9;&"7);J".U,HW$0
M57),)A6G_WK:2+7>=V@U6W^ZA"1CM%HUT13`<T_YO*<(%=Y7N&A6-A9+7%I<
M#'P<V"E#$X_":1E!@_0WE4OD]P0$81D;00GUL?-PTII'S%84=1S,8BGL<T]*
M?K^_ZG`XSM'$N4<BIXZ.)#6JQ^;GP6;3F#[Y`M)4H)P#/*3\%JPCG\-ER^&S
MG!V#'C?\<_.(U^O0MAO+4T['6\_,S$3[:MYJR:/1K>3[MTMEN(Y842?[!JL2
M&I421?@-I$H=]^X/8VJRC1'-'C)B`ROTOBE)@8/`C\#O_!KDUQ(I;ZI4A$#Z
MBE1*^7P*M>+7&#3<P(_7GX?"G,)JV`$KN237JD-0VA7_R1?7#]VA0T8>HUH6
M_B$>DY,3%\3*VNLU^?9KGIGO\?/R!(Z?>!,=?@QSQ\O-F=F9BQ&J,WK&6*2#
MX>JA\/%Q5])4K;DUM&1%EF/U>E5W;%9Z)97RZX]8SZ0]GME790U7-SG=79_7
M&__79Z`HEC^,A$.7B\7B_'_N@/X#RG'V`-Z*9CP`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O````````
M```````````````````````````````````P,#0P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-@`P,C0R,C(`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\T-RYP;F<``````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#8V`#$P-3$U-#,Q,#8V
M`#`R-3$V,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/````\A)1$%46(6=E[MK5$$4A[?Q3[$2\R?XZ"TLK(/86%EH)T(:;10DC95&
M[$1!",%"E(@!"XN(BHB"$$5<L)"U%,''N-]LOO'<V;DWK,79N?,XK]^<Q^PH
MI32"_OS^D1CSY,;-M?3ATSAMW+DRV[U[;R.=.7<^/7U\:[:P<O%R.G3D:/HV
M^3I;F),!_Z/-)^GE]GH:\8&,ZZMG9S*.'3^1^9>6#OYCD3[N;*5W;QXF1^26
M341MOWB=Q2$**G8B%M.@Y9.G$W,D_/K^:G;@ZNJUO'EJ^4#27*EC`YO2_(&?
MXS3^_*P8B?AR``Z,?/M^)X.(.D"`J=C`)@2H;.)%,1(.#N$B`.$>ZLH!7...
M=),#!2BY(H%#N1W06]MZGB_C_H/]V89>'#IW._4`&R9?-@LQA]HX57B!E83'
M>"Z)0.>RO7#A`D]"CF^=YRJ-*\:"D@12"#$(F3,2?S!@C0AV[D&HN0L(H"+L
MH(H`&`V%SDUC*H<X##.C`IDK""$P1B"+!9=NKV=_,1G_N;*5"X<SH['6NK'\
MPSWK.UHFDWTEK`S.%G-O'+3RH\Z3A0/)(&)],)#8Y*#))^K.$1:%-)F-0".2
MNX_1R!I"Y@3`8/F)$<EH81D,90[+3&PX-Y@8K6G-PL?5J1E&B'5<B(ED42R1
M:-V)>2!AM@D4M<\)(&A@L#;)G*ON-"(1`I,`=US`5)+'!(+XAEE2N\P=$#E,
MTG`0%Q0BM;*Q<XTB;).(S4*B)JA=YHX`FQ;$-\0Z<ZQCCJ!F<P$##K`)>*0V
M&2D#P+82J9/.')`!9@A&]AA[T]EJ!"-@9LW3:X,`%&;._%<]&*H1&<C=E&^1
M^T.U9"$#ZAI3]YY8`:16'1I\(0PI;BF-<<E(KL:Y:Y:@EB%[*H?)(F"VD9)^
M0R2).>_<&J@A]D)1T9!!Y0BK:V--==WTF6@M@2S&5C&-&#2@5AY+9*MDYD3=
M+5JB5'<"R#51:"JW(B(X&J)G>J]RSF.`PH4^UN]8SSG7:P"P4'I\GF@$2E08
M*R_KU$%*5BS;*JH#4X.:5\!"+*KV04?)N8;"`P*^WNH&%+NZ@=@,0AL2WOG.
M@ERKFY7&>LYK\/&F]UZ'Z=O[K+`GQ0=>K=#'7OQOH@'1J-C\-`;/>_^)Z$%L
M2;&CQC65^BUY5CF^B5LOLF8E),#H/J(`Y+0V.S7?>&G#<<^@9(XA>,N=TX3Z
M>L"<`1RTB)C?&`/\&F>;U`#VS`Q?R'LI;!H`$P+T&D-$PK13J=]&O,J!'6,6
M[:[%`!79NUG+97.JC#\+/MLP3LCCV:&>/T1_`99N(H<L2MTD`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$N<&YG````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(T-C``,3`U,34T,S$P-C8`,#(U,#8W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$PDE$0518P^V7Z4M4813&_3>B
M0(B^1-2'("(J*-H3"UHH4[!%:DRS:=$F'`;&##7+24TJHYPLV\6P()M,G3)-
MTRPQB:%%2:,%10T3"CGY.\.].;E@)'V(/KQS[WV7YYSW+,\Y$R0B08.'^=+4
M]$+,";O=+E;K'DE-3?6O6G;N%(O%(LZ,XX'GS2/9I_/$9G?Z,<Y?*9+\_`M2
M554MH6';)&AZZ%J9NRA$3N3D2(#8D8;^?/OV77)S<W4D.9VR(6R3:K%RU1K_
MKJO5]=+;VRO.HG*)]U3)JW?O9=^Y&[\A8GPV/*ZME;KZ9W+V8J$,V7"GI$38
MX/%XU*!145'RO+'1KV1_?[\4%!0(YL?B6(SK+EZZ7%Z_>>.'F3%KCK2WMTOR
MX10I+B[6TR9"1V>W/'G=*ODE%6H'=W&YY)RY).-WS3\"("ZBK?$R)@"LX?/Y
M-$RP`A;!X3:;3>+BXM1T&(``("#2CZ;+AP\??R+%[#TH7J]7>GJ^J$/BXQ/$
M[7;KH:ZN+K4_P8U%\<?6738ARDR`D#5ADIYU2APIF1JY"U:LEX+KMR0Y+4.]
MRSJ!'!F=H._L`=@$:/G<H7<-OUNIR(0H+@H_EBEM;1]EW:U[NIYT\_;04,E^
MZE-UC4E+S0MI:6F5CNYNP3:&C2(J&Q3\[[GQ'P"P'G!H3/PV``?+RLHU1P'`
M]Y\^?991`3H[.R4F-E;#ER>12+@6%A9J*#//._.1F[?H"`#`[VR$1PE;XIWX
M9Q[&X/#5:]=TC3VP10!`8E*:,@:24!\`$HG$0B,.D0,DV^QY"S6<30!2EM3E
M(%K`1Q`95^``H$B<&#Q9]Y`'Y(4)P/TQ',FTW6K7#7Q#30`S1W(QSSN92[H'
M7"'F9;L2'_Q&GI,\\$.H^XH@@.2ZYZDTDRK`"R0*QG*5UFCE(`NY+]^X,N'&
M734@+C78-```Z6R@LE!EHAO?JE0C^Y#*/-_#QD%$<JJYT-#H4PNC%81AS$,J
M47:'_(/9^%^!OZH`L?Z@\I%66[*,5J+B8;48%9BZ.*X*D#20"+P`/]#^03@\
M(1^HS1">F96EO&'43RHXS`5&<W.S5CV>Y!M\8E2W(4)9X*9D,G3(0<@(((@*
M`-@-HH+QX!36J/HH`1,P[W*Y_,D]H"1KL*)!;.S[VM<WO`*T%MP2<W*0I\''
M*,4-H5E<P9,UYG$'P`CD'>6A(2R'LC`)10#K#*XN`<+I(S$MK`HH0C$;8`"@
M$+="*(*XO=%,L<[M.8,B]$1&@\4[9[42#90WE!A24!CX%N'T1/@6[;DQ_@R>
M,M7LB9C'S`"B'$^*#`K0?$V8%*RU@SF:,.88G*7WHC0,JP`#\VR[7RO\JT`P
MA^;M=YB`S"T[DJV`*,*-6.>;-<"G+5EM"D7I!<XCBL,%L2#E9L0LH$^+.)FG
M0?32]U9+"7^1,#%$3Z68OR-6;Z!E:*`I--X?5-3*[M/GU`U\DZI4$(J%T>.-
MFH:NZB85CG_I*"E3,S>&:R!2XW*]->HB(ICB:"A#UMPL*A6:RB5[$[0*M;:T
MZ1\'@G5,/,#-`<!LF`B-24D&F9'H;5#3$W0HQ_<*QR&IJZM3`2A%#64_EL!R
M(7F7M:J/^2_"KZWOK[$QV'>C#10F>T9JYOX7H\'C!YP_HI,V%(05`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O,BYP;F<````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0T-P`Q,#4Q-30S,3`V
M-@`P,C4P-S4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!
M34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P```2Y241!5%C#[9?92Y1A%,;]-XJ@BRXKBH*Z2*AH5RIHH4PITH@IS6QQ
MH29CVDRQ;%%CDD:31!&MT(O,A;1,TZDL492A14DC$T4+"PHY^3O#^^7DDI)T
M$5V\\WW?NSSO69]SQD]$_(8/ZZ6IN5FLB>-VNT0=.B2)B8G>59O-)@S'Q4N^
MYZTCJ<XLB;,[O!@W\^Y(=G:VU-34ROJ@,/&;NV&S+%D1*%?2T\7GVK&&_GS[
M]EV<3J<.A\,AVX)VJ!0!&S9Y=^75/I.!@0%QW"F3Z+(:>?7NO1QQ%4SBBJG9
M\*3>+4^?O9`;MPIEQ(9[)27B=KNEM+14#1H:&BHO&QN]0@X.#JJE,#\6QV(N
METM6KEXKK]^\\<+,F;]0.CL[Y<S9!"DJ*M+3%D)/;[^X7[=+SKUJM4-6T0-)
MR\B3J5/SCP"(B_U1T3(A`*SA\7@D-35-G8Y%<'AL7)Q$1D:JZ3```4!`8,X/
M'[I^(G'3P^K'\NG39W5(='2,FI=#?7U]DI"0(`0W%L4?NP_$"E%F`01N"I*D
MJQERXER*1NZR@*V24U`L9\]?5.^R3B#OVA>C[^P!V`)HZ^Y178-+'BDR(8J+
M@B]<D8Z.+ME27*[KN&J$#:X^]ZCWS:2MKDG:VMJEI[]?L(VQ44AU@X+_/3?^
M`P!1L2<U)B8-P,'*RBK-40#P_<>/W3(N0$]OKX1'1&CX\B02DY.3I;"P4$.9
M>=Z9)ZP9/@#XG8V$+V%+O+.)^=S<7#V<GY^O:^R!+7P`CI\ZKXS!38@/`(E$
M8B$1A\@!OA?[+]=PM@!()%*WHJ)"I8"/(#)4(#L!Y<;I,V?I'O*`O+``T!_#
MD4Q[H^RZ@6]`&<R17,SS'G[DF*:[CPKAK9U*?/`;>4[RM'K>ROJL/.$"DJNL
MM-I**A\OD"@8*Z6\3BL'68B^?./*F((2-2`N-6SJ`\#M6)K*0I79W_A6;S79
MQZW,\SUJ'(2<2;06&AH]:F&D@C#,/*2RQQXO_V`V_A?@KPI`K%/[2%T:`%J)
MRD>U8BHP'#"E`I`TD`B\`#_0_D$X/"$?J,U<GG+YLO*&J9]4<)@+C):6%L7A
M24(BJ*EN(RYE`4W)9.B0<@D9`011`0"[050P'IS"&E4?(6`"YEEG+T*R!HXA
M-O9]^?IU=`%H+=`2*3G($^GA8Y@0#:%97,$3!D%8W`$P%_+.1=`0ED,8F`2%
ML,[PZN)S.8TFI@4(4"[%;(`!@$!HI;0U=!':FV:*=;3G#'/T1*;!XIVS.\/V
M:7E#B!$%A8%OH70Z?'R+]&B,/VFJ#*4S;RJ6&109!&#?M!DSM78P1Q,V;Y&_
MSG.6W@N<405@8)ZPBGKA7P47<\C_:+P%R.$U2:D*BB!HQ#K?[&=]]JJ-^LU`
M@:6.),5!0:Q'N1DS"^C30JYEJANH1Y02@@X30_14"G];A&J@96BH*33O#ROK
MY:#3I6[@FU2E@E`L3(\W;AJFU#3IY?B7CI(RM6![L`8B->YZ59T5P11'(PQ9
M<_=VN=!4KCH<HU6HO:U#7/?+-5@GQ`-H#@!FPT1(3$HRR(QC50UJ>@(,X?A>
M%W]:_P!Q'J&HH>S'$E@N,#-7N_X)_T7XM?7]-3:&^VZ\@<!D#P+]+T:_&S\`
M*$*BKOP`QU$`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S+G!N9P``````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R-#4S`#$P-3$U-#,Q,#8V`#`R-3`W,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T
M=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!+U)1$%46,/5EW](U'<8QPWV
M1_TU]E=!!2-F!%%4^R/&_C`&"UDDD2LCZX^M;MAL:#-7'%EYV971D5Y:K7E;
MYHJ=6=G21-.@-*$?&I(&BD5E1$>7'$R0"O?L7D]\SKON>U=WHXW^>/Q\O]_[
M?)[G_7D^S_O]?$P1D91PTS_E[@KIN3,@HZ.CK[[F_KA-2@\<D=",H:%'\CPP
M8?Q#E(^!P4$Y47MF?$;-Z7HI*G&]^O#BQ4MI;&R074>]T3ZZ>OKDSN!]N3OT
M6.KJ&R,G?)[VI3A=%7*VJ55XC@@Z-C8F4Z?/D+D+%DK:%^DR>^ZG.D:%*-CT
MC5C"CF>AA[Z^7NGN[9>^_KLZ7FQKBPP!:GYHN=0NI"K*`\E@!R0V$`A$3LA:
M8Y.OEJV6G<XRG<!N(B;P@:VESIJCMB@]0VKKZL8Q?-_:+MB-SDEBR\D)_1B!
MH>?Z)Q)WF\F:Y4<.E(,=N'=?'C[V:>X:6BXKO,R5V6*W.\3O]UM7%!/.-[?*
MI<YK4N4]*Z?/-^M[]OI<\?E\\8_R]Y->L1?OE?+#'AU)ZW[W+V+2?*RZ.KX#
M4KS6EJ<+'/L.*EPJF;/!(;;PLS2)Z:#VU`7977XPM/_?3LZ1OT=2)-/AU-.G
M&F(B.%%=+X45A^29?UBJJHXK[=9D+Y8MOVX6"M%J\;L[QO_?`=SJ[+ZM"D$1
MH1(DE=K@M_!ZB%K,67,*J!L.J$2(6E#XDU8B1TQAQ71`$4%W%G=<ZU($1,4!
M<AEW"\@3FD@$:I^Z8#%&]#?FH/)HE98Q"SPU7N4!?+!MW*K0W^B`>D<]*5\6
M508+BA%[O80M'<`#G.1O<>ABN@*$,F0B#S$=D#@F,9G%./MV0X&2BA%4:)G1
MTR@',&_:QS-5]-*7+E>M1P@11)H!(P[XS=(!?<=6^;.*,OI+(I\.?2"+TJ8K
M0^E:D"KF%MSN&CG>U*R-BP;VH'^B9&7-%[?K(_$]\:OJQDUB[I\M,C+RE]8`
MBY!H:)VQ=HFBNA(LX[?B`M';FE*EJ_NFO!]T_L\!#`\'E.VT8>0!PE);&'GN
MZ+BJWT@A$D)UP-%_!0#]@9L$1%J0&C3*&))#,*-?:!ES,/@,Q_>[7`J20DD(
M`!+DW./2W9D@.`8(@0C(.[O&"`:I<O."+'242&FI4_LAQ04/$@:`C!EB4=8$
M,ZT>(P-&.]DM;9\UX9>@I&L`)\@`#9DC("`ZPS,!>>>9[H]HH81<#P%@[AY)
M`R#U1G\0-'2:0`3A'2-H:=F1T.T!V27]2*_5/28A`*02YQB."4@0```$0'0<
M[D/(MU%B5)B+%)EX_;P3`H`#36<P.`Z1=&1.SSEX)'PW=R;`,3(',(S\3O8`
MF!``4H_D$YQ44@/LSNP0XQNIYME<VJAZ@C,"#`,`/AAC:8$E*L2;(UAW[`])
MWU2H@/)^L.M[QG<Y2B^"K=JV6H4_<\44^;JH6"^!%"!K:0[,A?\>CT<%R@I$
M3+5#=.`Y3."L-YQIT':%D^(=*_7665?[H5XB\S=.5OYSL6QI:I?-WG-ZF4BJ
M")%9>B(!06T<TFQ1LB+[/`VNO;*L1)LN&4!PPN<FS0)V`<?#'?!OCV-[J@;F
MSLV9&JT_U7Q1N_T[;T90JO?VK;<6F/>F'?\#G)Z9?J=?)*(`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S0N<&YG````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T,S(`,3`U,34T,S$P
M-C8`,#(U,#<Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G
M04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQ
MR64\```$K$E$0518P]67;4R-81C'L_G`)_.)S7RBS6:,OICYD-G(&+)&"&/*
MLK/0*F\)'4F-,RIY[1`)I8Y0:R>R4=H:A57>)AL9SASM;-H:EHO?U9XZQWG)
MR3`?KN[G><Y]7]?_ON[K_[_N0D0DQ-WT3T[N$7GX^+ET=W?W?C4EI4GVH>/2
M-Z.CXXU\=@WI_^#EXT7[2RDNM?7/*"ZOD+0,2^^'+U^^2E55I>P]6>+MH^E1
MFSQI?R7M'>_D<D6EYX09X;-EOR5?;-4WA&>/H#T]/3)F[#B9'#9-PF=%R,3)
M83IZA4A*7"L^80>ROH>VME9I:GTJ;<_:=;Q16^L9`M0DL.96G9`J+P\D@QV0
M6)?+Y3DA>F6<S(M<+GLR#^L$=N,Q@0]8Z(1):C,C%DEI65D_!M/-.L'N-0R7
MN/CXOA\],#QJ'"\!MSE8\_F1`S4.]O5;A^:NLN:VPHM:&B/;4S/$Z73ZKB@F
M5-IORJV&1BF\>$7*K]OU?77L1G$X'(&/LOA\J:2F9TG.,:N.I/5@[BDQTEQX
M]FQ@!Z282"PP'\A3N%1RPJ:MZA";-CU<_#JP7;;+OIP\W3^\.'-ADGSK"I$H
M<Z:>/M7@%P'P4XX<E8_.3BDH*%+:K8R9(UM/)PN%>*K\RE\\QG_O`&XU-+=H
M`6&H!$5%;?";>SUX+>:L.07(:50BSTDI6[02.6(*RZ\#B@BZ$[F^L4E'HN(`
MN0RX!>0)320"M5]25J6+,:(/F(/\$P5:QBRP%I4H#^!#?$**0A_0`?6.>E*^
ML:9MDO^CH!BQGTO8IP-X,&_Q&DG<9M;%.(-0!IG(@U\')(Y)3&8QSM9M2%)2
M,8(*+3/TU,L!S$/?863$@DA]1N,10YH!(P[XS:<#^DY<_@D59?2WPF:7#QU#
M96;X6&4H[(14?K>0EULDYZKMVKAH8*^>#9/HZ*F2:QDICO=.5=V`231=JY&N
MKD]:`RQ"HJ'UPE7S%=6='V7\2UP@>FUUJ#0UWY?_@\Y_'4!GITO93AM&'B`L
MM861Y_KZN_J-%'+R5`<<_2T`Z`_<)""7`^0%C3(,R4%Z,-0#+6,.!I_A^$&+
M14%2*$$!0((R]UMT=T8`'`/$$$W>V35&,$A%*S.;,R0[.U/[(<4%#X(&@(Q!
M+!2*LB:8T>HQ0ZT)SFYI^ZQQOP0-N@9P@@S0D#D".(;.\$Q``/!,]T>T$"^N
MAP`P[AZ#!D#J#?U!T-!I`A&$=XR@63G'5>BXV2&[I!_I]76/"0H`J<0YAF,"
M$@0```$0'8>&@7PCXR@Q*KP\UJ29^/F\@P*``XS@.$32.0+.F2/A.X!X!APC
M<P##2!<C>]QX@@)`ZI%\@I-*:H`^8_0:C&^DFF?CTD9`@C,"#!8``!^,_K3`
M)RK$FR-85WA)YB:F*"`<\KYP?;S2BV#+=JY0X8]:,EJBTM+U$D@!LI;FP%SX
M;[5:5:!\@?"K=H@./(<)W#HWV*JT7>$D??=2O766E8[02^3FA%'*?RZ6-=5U
MDEQRU>]E<D``R"P]D8"@-AS2;%&RM!U3-+CVRL,9VG3)`(+C/G?0+&`7<-S=
M`?_VF'>%:F#NW)RIH?6(%.,?;T90JK7EP2\+S'_3CK\#8(F9DT9^-`L`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-2YP;F<`````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C4P-``Q,#4Q-30S,3`V-@`P,C4P-S(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F
M='=A<F4`061O8F4@26UA9V5296%D>7')93P```36241!5%C#[9?93U-1$,;Y
M>WS3%Z/QQ27&F*#1Q"6*&K$N(.X;BA)Q(;D8%%$,99%`*9NX4,6E+A`%+2J(
M-2"6`L%$'U`,#_)"@F-_TYRF%PI!C8E1'PZ]]]PY,]^9Y9LA3D3BHI?^:7_]
M6G8=M:2DM#R\>[&X0KK>OI6D_1GAC9&1$7G9VBH^G\]^/J+#W]$IBU<FBFYD
M6+F2F')(SZ,K;MJ,F6)9E@P/#TOD2/1">IQ.5WFEW&MLDORR&LG(=DJPIU<J
M;]R1%1M3PE+NVPV2YBR2S<U^.7(\4S9XO++$.J=FQIF("7O*`@6%Q3*A@'7>
MJ0!QPO0Y\\0FD.!(4M1KM^Y7Y-P"!ZE`7V^O7A%/]??WR\,G/ID;OT8%<7A8
M?<AS@X.#XO%X!!P\LZ<:SOA[]6%%:KHXG"XAF&=<%?)SU_R9%7.SY46;I&7F
M2G-+F[JEN+).JJY<E2DI6+EFG1ZLO?5`SN:[Y$6;7TIK/.K"BNMW]7=T=-1^
M1S:L"T6:<!QF%9;7JK"_HTN,JS6;K#`RW&S+Z;(;81<?3#VLD5R=O$LV.;9(
M=IY3YB]:JBD^:\%2J:VK5QF6[0KK2JK$ZWNNAV_>]DK6^0MZ#=Y=5?5"-N3E
M75(94PVV*T3[H:&A05CFG>\D@0G^[P_CGZ-@Y]X#\N'#1_EA!5`+3@L$`O+J
M35>$I::D@`0AUB0.Z9Q]Z;*&DQJ%U"95,#0TI,)D&EF9F5,@G5WOE!JI!U*;
M?(BI8%E"DA*R^UJ]T@?6.>C8DZXH@L%N1<5W%!F"BC@+:U@FW_G=GGI*GZE&
MJK/^P1.MC7>!H)*7(2Y5P`N:<1B6$:0*<2*\!`(0X@=:1_*!8W8%Y/:ARNM:
M(,"FI)-/6UI$.)4B8L4O7RV-CYLD8</&2'@C/L`Y%!"''S]K4PN$LKGYJ<#]
M1`8?(3,P,&`OIA,=_6J=YN!VNY44<1+O<$%6B&I1=NI^H]#?QD4!0;3RD2J<
M[=BF"A;NWJ?LX_5Z50'7BID'T5IYY@`D;_9@GH[.3MO>7U3._Q8`BIW63K+3
M7B!_ZI/\9#8)=@?EMP&@>LIK;FIM4Z)U=Q]IC3-.P#3\9N65:,51LJ3M+P,@
MI2E?N("I`Y*!5#`(H9CICYL##`"4/KS!-\#`H7CMAP%0@+!<J;M:1P-NS,(@
M"])B\0UZQ""&S71`W4%H`*:Y4]C,)WAM0@"P`>T#9N26&&3$@&IYAMQ1RNTQ
M!@!X"_XF%Z`=>)M?0+"/+F3P$,T"FH;GQI$A+`%[<B,40WXH,B",VTE`O@,$
M0"QR@G>&)\(`94/IY(+QDJ%Y%@`(J0T`\69T(>8P+G$WDR_NQ3,H)*Z`0"GN
MSKGHU%\`<CMRP,CA):J#A0[THI^9BXJ*F0,%H1O#YG@$8H;E7:[PZ$N(&(F+
M:Z_I/IQKAC64XGX2KKJZ6L^:_S&(/6,5K87<F#`'OHY^DYY/7U0)RIFY^9\#
MU+09@&",A`(@0)G-3=\"/)W$R):55NBM`4-#F+0*,+RC[[.6#3=H";S7+DLE
M:"L*M6$F4/B`4&W.*9)5WB:].15#GFQ*2U=/(4^#!3SNGQ(/Y+=WR_KTD\IJ
M8X4@F=RJ&@6CDTOHAH2#.)K)UO12ON$A/,&,'3T*_Q(38@@C8SOZV#+&((O*
MF$SV?S<TZSM[#L`OP#39_P````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\S,G@S,B\V+G!N9P``````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#,W`#$P-3$U-#,Q
M,#8V`#`R-3$P,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$
M9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y
M<<EE/```!+%)1$%46,/ME]M+$W`4QWWKK3\@>JR'B`J"B*(>RK(;$51T(2NE
M&V47Z&I)5S/*TJ!98D@FF:6"76:M9""H&8M&(KF<EJ5K+M>Z*]$H3GW.^,TM
M5UE11/7P<[^=G7-^WW-^YWS/SS@1B8M<^F?YNFUR]9I=PH*4+?LD[W2Q\*F"
M!<U>R3AP0+Q>;[1]V.1Z5:W,7+`LY&/]INVR9>\1B9^5*%.FS0BI87O1Y>XY
M)7(U-C9*+Y]9N85BR2^2G0<MNEI;6^6*O5J25ZT/:=GM=AG9_D;![]ZW7RS>
M@'1W=XO'X^D-,R;L/BML2]TA7U0H*KLL)\^4*;@A(T9+E$*%K5*JZQR:S%NW
MG:J$@2J\?/E*0R1U>$")/1DDW+@!'4$AS-+24IGTZ+G4U-;*VO0,Z>?[T)-)
MA\,AF9F9LLOU0./?E'E$@L&@?'^8/[)B"C>F90@UP<76.>N%&O/Y?/)-!PUW
M77*J^((:\WF\X+Q4U=R4><D;Y(*M2M.'LYA53-&1ML+22VH("G+>Y&Y6X_3L
M/$F8O33L9'Q\0BC-QE/3ZRXY]+!#CEERM.`3.KITSR+]R)*2DV5BN4UR\_+%
M:K7V9)G4US<T2*HG(%RLT^G4\N23DL1!04&!M+6U"??*M7TUB8%`(*R``[,'
M\N^YQC_#04YNOG;$=SN@[V`19WV#F,*"*/KD@,:ED,HK*K4W:5HJ$68<,W5N
M3$=17X!,&5-MIHP/6T[*JHU[=`^RF,2'(:QPKKQ"RBY=4R?4/_`I8>Z?</@=
ME&NWIVO?AQT`V\"E[CD11QBQ0(/1COW9>M"<)6NTK,,.$`"/TSB9>,D#\'$$
M1R%;O'JK[EE1#EAP%+P)-0UTN'5/T@:[.W4L$":-Q!Y^,_R@QBL?OU`!L=*%
M]`+D1T,Q2D@<!_`[#3=O_OSH9H(U)[1TJF<Z[4;76SE;4ZN=^/Z30MH#K^X9
M&N0BLMG"(<"BD`<#T"`PR-C/]G5IR\>\QB^U,O`CY8:J_[)V_G<`4(.T&@4-
M.T`[?*>UD%$AOP0`O<P<@QAH2P@!JJ)567R_X;BM8)B%/,@894R@GP;`P1`-
M!Q!Q2TN+$BU[R(?!BXS#&<SH0SB&4T:-G2`P>Y\!0'$,W<*BT&2'%@U!$ZDA
M+-B.Q1X]R(S#`>IJ<BME`-*\Q'A/HL=5,;=C`B`:T)->Z)/#>7=RJ'&,0W1@
M0Y@2&1GA0/8\A/@.8#)B=&`8?,*F/$D(L-?[#>;$@(@YW!CQ,@8]QBPB@V$X
ME/13(\@H1I,-ZH`%[P$$.ZX$\-`Z5&X>&5%7`"I`C-FP65/*'?+B-6OHY.DR
M><4:C8+?S"=.D1M]\SD\ZX0NH\LH@,EY9YFK"!_>^2XH[?ZGFIJTXA(U0!&Y
MZXE?#?*JJA4<3JYX.Z6DW2=^OU_EXQ8F:F3H(B<K/."0';7:=!)\3N11`)+N
M-*GSE)04G08X!@SO;J+`$9,!(/Q>=J\Y2A]=;``PY6"6@N2*"(K:6)2:IKJ?
M/Y1[M07SB]G&H<8`1_0U<XYI2[0\#IAQ_([-Z#OWU8:)C`Q]LC3(%OKOC9KZ
M(2)*]+R08256'?&1HX[)#!@R$_F"K7S5+?W=S[0F>![_'T9_/("/V;C3JE)*
MTOT`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S<N<&YG````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(U-S8`,3`U,34T,S$P-C8`,#(U,3`U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O
M9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%$$E$0518P^V636A45Q3'
M`]*=.W'AQHW%@HHMN!"5;FJJ$"I(BU^-"P5CV@9M-`F*41/BD,:*2F8B4<=H
M/IIOTR1,!\F@44<EC<EH1]O1HC9JC4K\*H-3-&*._DZXX[R\9]*X$,$NSLR[
M[]U[[CG_<_[_>Y-$)"G1]&?)R@R9G)8E<U(6#[[-V%`@6_*WR;+4Y8,O^OO[
MI;2T5*Y>^\NZ/N[C:/L)^=@?%GV1D94KRU:OEWD+%LF"1:F2A*-M+I?T]?5)
M?$FB[=BY2VP^=^ZM%,Q35B-9F_*E^62'7/OWN1">3NBY^;?D[=HG&<5U:N,W
MGY*"HAW.6P2#0?L6PYEEP/ZOG5#5Z)/5:W)D>CBJ0'Z4YWX5`Q^/!3ODT[DI
M&CTX'O:U"9@F1:-136_AUVGBK6S0-"D#J/%-/30U_2RAT#DA75;]VMFIY=$M
M]IQ_H@]SJ^\)$[.RLV7"]DOBF$5O[RT9-LTW,<>7M$!#LT]C/1)HEXVNW5)8
M]*.$+_XA`P,#FH^C@P</'RH20%;3?$1Q3?DV6XHO]JJ3%G]`*FX_%8_'8W7`
M1";0HRPTBT&*]O+[_>+U>K4Q`:K(O5_H?$M/'[_[5,-L"P2T4(?.7%<6Y)R(
MR:;<S;H[3DB#L26"?YX,R*1Y*\3?\;M6FSYE![A175VMBW%&9)DYN?9N!)C$
ME]`%(W3R-2R)1")OJ8SOA@.:A5+2_*-R`(6H,UU(S0T/`140#<".#J`;G4@;
M0UC8G;PV+\YPQDA>HK#8./!+X*0:)-]_X[&L^L$M4S^9J8Z1K/3B,GL?T+(L
MH&&,?)`_\I&SQ26KTM*EMJU=M0ZE8`[_%LW!P>FS(0T=7I0<J)!#Y>4J$+0V
M#FGUSY+GZS.XQ!W@#>`P"(,FE=<T:L_CD`B-NJ-=M#..+1A,3/<J66*QF(*$
M/(/VV/0:,94)AR_(K*]6.G.!?N<`@#30E/^6*X^TG.@>+(4;X$%*%@=3?GJF
MN\_(]&C>'[I[--_%+J^FD;RU3NKJZU4L8:<M`FI-N'3=_5B_3)G]N:;!9*.T
MO!\:?MS!T';%&30F?%+#&3@@>:,B4V55E8+Z;M/Y_0F`(J)1,`0F<.!U=7>K
M<L!13O61M.N-`J`)<`Y)H"4;$@0B,::^2WN?CAM7>%#'&&W,&*,3OW`WR0>E
M/AL'1@R`%H;"'5V_J4(AJ%AG5TCU8=WEJ)[<$.[[T&V5/;B"H1N9G3<DM<HO
M:X)_ZGA$&@`A3*YM:!*CK62-VO%L[HMDCSAQF"->:PMWJVR@=*@@):%<_#.'
MS3FG*1U*F!A(?'.$"J@1;J25#<F:#7E&GY!;OK$I,(<CEY7HZ%-SJT\O<!<B
MEU0Y\,4W;A($P+]9BQ0SUQ(`60&WR98-J3478+Z!"%D0(/<\U`6T,'0.[4,X
MN(<3$`B1,4CPS,88J##&OZT$-!S7&1J+JPXU)7K.!Y[)FLR0?L8X(NB)*=_I
MF,R8SSPS)@BN2KQ#F`GVM8<RMKW[F4Q;NG%PLY=0@@+1DB%&1Q,<'<TQTA@X
MHW4E4WJ(<Y=U'!TDQ%H:EA)!Y6&;D'/GRY*@0HEQM-+1-!<.N3%2`IXI`4@Q
MI@S4=-J^.XJ&.8K)G&.*8"G;L%=TS?RE`Z!C`[(#+CA.)EQ3@=X<B-`/AE!S
MN$[IR)0U(/%-ZRT]C4'-Z5)I"\`<86SN-!''9$5GFT8C.].$J"*G-IN3*7/Q
M-^J;W7\QT"$SLPE!,7:"^/_3<"1[`5E)DG>LPM'^`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O."YP;F<`````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q-@`Q,#4Q-30S
M,3`V-@`P,C4P-S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````
M!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D
M>7')93P```1@241!5%C#[9==3%17$,=]KX^^]KVF)C;XT(1':Y2T)M6D$8QM
M%#^JI*P&J5AUK4TD-FM<OP`7W&QJB!O672+9"MM`)8TDHA*(4+&LB$4$":"@
M1$%"I-/^AISE7O:B^)$:C0]G[SWGS)WYSYR9_YR=(R)SK$-_^OKZ9*7[@'P2
M;9Q<+2TME8J*"G&Y7';QQ">VA9&1$1D8&)"/=QT47>CL[)18+*;?=W5US4*'
MHT!]?;T</7I,ZNKJY/O=;@G&SLNJ]`QI;6V=DL0PS_'Q<7T"9O8F7ET`^P1P
MP>4!^7#U)GU&H]%)#&P6%Q<+`;U^_Y$L34M33PB."HR-C4EM;:T*^/U^\7J]
M4EY>+C4U-<E>5%Z)VURU8>"Y/.M'L<Y?CYNOI*"IJ4EPDI"0%C@+O'@\;H>(
M$`<="`0D%`H)A]_1T2&^FX.RQ>N3A2F+-&PY):=U3L1Z>WNGHC0\/*P?H8!0
M1B(1G2-(UG@\'@F'PY*;FZN*"/'0T)`]S&0/&;LN>X="9/QY_2]9N^E;?0?1
MV?,7)#,S4S!HCL+F\WS/)<U1,__IU&]B/3/VGQG$[.UY"8&)B0E;L,ZU=LD>
MMUO^WV-\RQ68Y*)0*2].A^,S96930,1)#(3),-*5CTUU0Y,+M[KETQ49"<JS
M*2"!H$^RD+SG^,Y55LKG7Z^70XT=TM#0H"A([65?I=M0:'&390A`?M`'Z7K"
M5R(;7-N41LA`4IIW]E&`BPD$**"(#/=0=2#)S\_7^J`6H!H(FG?D<5L5&/^O
M-C<K"A3P1`%YCU*LXQ*$QCYE;JL%)@1NR;Z@!H\8M+>WRY?>*HV^F7^1']%`
MCXZ..E/6O<$'"6B,PD#0%O';W7=GKH4GXT]EU<8<6S$15"NCXLJ,"KK[!VV;
MWP0:Q,JNT_>3%*3L/2LM+2UBA6MU!__?T6I\#^"-`&AK:Y.YY9,418E^5!#6
M^0>G_I#/,K?H?-Z1,N6!M),1?2\H*'QV%IIRIJ%";:;)0C+P`I1&66,<HZ[F
M?N7'-0=]DGWQEG;OK?L]NK9Q<Y:NK?DE*M_57M,]"(KK@;5-V@@9XRB'2S`(
MZ3`,`"@0PC)7S]B=(>7;'PX7"2T3(X7^@-!:84&WQZLR\*^A4)R#\)/N5P"@
M7?3T]"C38=#<UJ!/*(4YD<$3YM?B-[1/PY!5U372?NMOO4EP_2,"._)V*F"N
M(^@(!H,*'"<=`7`U@2EA$]!BC(\8W'68LPX`WJ%L/$4Y0)ACE#GG;=8!@2,8
MYQTGDP"8'*`O@!`C&*4KX6U149'FA/5(>`<`<ABGV2`+8/:1,T"8$WYT<]16
MBIPQT^\_?"SP*U[1)IQD6F[<_D]IW''/_WNS]B>GZ]2LRO!`Z(+X2L.):Z1U
MX$'JX8N:\4[@`,_W9:$S\E(\P'$<#U7KF9.<T_='GHPYKB=XHON>@J=T7PI`
MZOY?97W>SUH12>">_J/>4X).T:%O+CYVR;'YOE`$R%9S]7F1P?'PK?F[^+X9
M/6_\"Y94&YT>3C\/`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Y+G!N9P``
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,C(T`#$P-3$U-#,Q,#8V`#`R-3`W-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13
M;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!"9)1$%46,/MELM+U%$4
MQ_UC@C8M6K2*-E&X2JC^A8A:15244(985M9",)+!U)@9:WR_'\/X0`<1DY04
MWYJ8F>B,3-H,XHR.I_F<^/WFK5$1(2[._.;>>^ZYY_D])T-$,F))?\K+RV5Q
M<5'XZD9149'4UM='-Y*NQ&VLK*S(Q,2$#`P,R/;VMF1XO5ZQV^W2VMHJ'"I;
M.+PG6UM;DE)&RD?0J:"@0#HZ.J2KJTLZ.SNEHJ)"QL?'HYPC(R,J$D:^O/WK
M3_PY0TU-C3B=3IF;FU,G5E962E]?WT\=PN&PU-;6"@[MZ>E1"QH;&]4*4P*F
ME924Z$%=79U45U=+?W]_E*''_4$716^:]-OJ<DN<#F=N9^O&J>LW)';]=\S\
M-P)V=W<UB>KK&\S<F9Z>EOGY>9F<F)3AX6$9&AI2SW!&4BPM+<7'FF0C&/@7
MOW=W=ZM;$8I;"8[#X1"+Q2(M+2W)`J!`8$M.G#TGL7O.2.",_Y_FE^3D^4Q)
MZP/W^X^RNKIJ,GS;V(AC)GZ;FYOI!1AJI:/EY67Y3\-X"`2$0B%QN]U26EJJ
M20/"S,S,:"92X;.SLYIDH&-5597NQPGP>#S2V]LK-IM-@`?@@(L(&1T=U30&
M*\G.IJ8F_<^CI@"2`Z;BXF(%0`09\`%QD?SG=;1H:VN38#`8%1`(!%1MX(1\
MYQ54;FYNUKK@(K6`B0B`=V=G)RH`:<"L/5)(:%%65J9%!&$2@JE"*I4]*A>P
M2XK"W99^M=E8>]:_Q>4^YU1MVC#>?_+</-S;VY/3N4_--9AQ[U%^^EJ@YSS,
MRS,9@L&0::=1ZGGY^PAX4>U2;#;6+]^VJ].,]5-[NPP.#J87@".-KI>*.#-"
M=\B*Z4B!OZX`N4MM^WP^`66H'(/H.&MK:[J_OKZ>1`Q&G,,'P;<1Z4QDH%&Z
M^RH`X\+"@L(9&$!=@`O\!XT`$:8@\!"HFYJ:4EP`1\;&QK2#`W7<!\6,3D\]
M@7"@&)TO5AGS<?`1C0%?P!D$`Y@*"PMUND((>PQ3C`A`)(B'4-`/Y(/H^DP$
MH""$\GS9=[E<BE7,L"D]@+NP#'!GQ.!11@F\P)J'L`XKL=8@`_!1C+MX"P3E
M'D;@2?:036C!M118%M98P8"+$8S&6&VU6M65*(%U6(U%".4_EO/%(WB&9L+_
M6#A'%C+I5$8W2O(`2G#H]_LUF?(M#LF\<DV;"/%F8H.PA*GMV>M*N7@G6Y4C
M=.SS)4]P]>-7-KV/=XQDC`7H`\OPNS\@XY$D2X6ATY.?Q&)]%]=_$FGCNU_O
M)SYZH`*AT(X\>.N4XUF7M,4FGM.K&`2OWKRE%9!XOO+5H_>/7<C:5\&T"OA\
MF_+YRW)<LL22W=$AERTVR<G)27GN]?KT_F\C(;V1.;DS9C9.#,V'"":0L*D>
MS[4VZ!Q-3ASU@O]>@1_F3F"]!M[#D0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+VYA+G!N9P``````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W,#$`,3`U,34T
M,S$P-C8`,#(U,S(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@``
M``1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A
M9'EQR64\```%4TE$0518P[V7QTID41"&?0)?P$=PY\)7<.G"E2MW(KAP*8BX
M$5%$!#&A8LZ8Q8`Y8,XY1\R".<>:^<HY[>WIMJ='G1DXX_7><RK\]==?1P\1
M\;`N_:^WMU<*"@ID>GI:/'9W=V5H:$C:V]NEO+S\;5M+2XODY>7)R,B(_7F;
MC?#P<(F/CQ=]T=;6)M[>WN+O[R_)R<EOVSC?T-`@MB/6E9:6)C<W-V)G<W9V
M5K*SLV5F9D924E(D.#A88]S<W'S;1=!965DR/CZNFX:'AZ6VME9N;V\=PR2Z
MR\M+>Q>NENUA8F)"'AX>."E/3T_V%IJ:FH1`P2HW-U<.#@[D_/S\/4W`C(J*
M4D#GYN:DL;%12%<W$'U969F$A(1(966E>'IZ2E%1D?3T]$A&1L:;G_S\?"T)
M*4Y.3NJ&DI*2=Q?=W=VRO[\O-34U`O9L=,AB;V]/7*;YT2(NMW!:75W54O!\
M='2D,5,K,KZZNA)8]/KZJM_)P<'`R\N+/#X^*HYU=75:S[&Q,34*]?KZ^B0G
M)T<1^_7/W@"'J1;P>7EYR?+RLA:&Y_3T=/'S\U-#&"`BIQ%@`!0I6E55E41&
M1LK&QH8$!04I_+":8M[=W3DG$_1;6%B0Q,1$&1P<5!Q(A9^%A87J8&EI23X$
M\?3T5#\>'A[J03A57U^O'6(%KK2TU'TZTTENE?&SR^5'@/R4@>/C8RTT9:.\
MO!L='75-Y>KJ:MT`VSH[.[4A`18RG9R<"$W+=\JYLK+B',2UM369FII2X@`>
M:@/Z"`DR!+FBHZ,=RTC]\<R&L+`P#9V0H3$1\(Q1^MI*(IL!6`C_\00+(4QH
M:*@:I,?QBM'BXF+M]=345,<4+BXNM%E\?'S$U]?WYQ</9>/6UI;*3&!@H%14
M5"C!<&@SP"%RQ0/>,8!X8P!5W]G9L1D$:/;19-`=%;)%`.K(/YX`C$/@$1$1
MH9*)<0"E%XPNV%(@5Q20#70C85(-#F(,(`<&!E142(.6=U9&[42F!S7'B%GP
M`N/,)*MW.P.@&QL;JQV(5X2#LB&_>(=45(3\G1I@')EGL*"%F0(='1VJC43'
M-XS]<3H9R4('S\[.]'E]??WO91WPK)/LV_4`O>0F\<_TY$^+F4/5OS4`"F0=
M&U8X*?3U];7"BL3`#-@""L_/S_J>8M.KUG8S=;7>?EPB@"/80U-`@OO[>T$D
M41>H24,@'B@,U*5UH2Y=AF`PA0B&&PU,I(5!"CMNEX`)11"()]J((G%/X"J)
M'K!`Q<@=]#9!T2^\6UQ<E+BX..UHMTJ`6G.83+:WMU7ZDI*2=$ACD*X&!62"
M;Q@V<H&$LH?`^OO[M0R9F9DJJ2@EBS/TI$L$J"4UI0P(67-SLRHD:LCS_/R\
M/J,0=`%7#^YG!(WL\@W908JYY[`/^-$O!H<#`@P]1A'9`1D-ST\S(#!$`%PA
M<<8-`R>4@[)P:T:R`P("='%39Q_VJ#T+9`F<!4H(##[QK=,(9J.!..<@8HHZ
M$P!PF@"`V\P&[K9D#%I`S3NFF`F4L4#I("4DY8:#<TK`]1&?^'8H`3!1?S;'
MQ,0HZZDK@5%GZD@F0$Y]^0EBL!UN&*[0*0P[$.0\P^OWUG3@`)O(""V`-$0+
MU$R_KJXN;2\63LS=E66<\HUNX.[&U(`;V.!Z3K!PB.3<:D/*09T@$M,%33!_
MB!`4QEI;6W4!+U`SVOF=*RP(<!XN.1.V#P.@/F0`P8B6KF"A"V29D)"@<+,H
M"<C@G`Q!@HD-*1F\*!\\@+AHRI=F`0C`:!0.XZ@:?``1G/..&K,/+?G]/,&8
M:^:W#2/*0*<XT_C_,@VY9?+'Q%=L_`!M65P(O0_*A`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O5%=#;&]G
M;U\S,G!X+G!N9P`````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-#4P-0`Q,#4Q-30S,3`V-@`P,C<Q,C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```"L````@"`8```'\G;&5````!&=!34$``-;8U$]8,@```!ET15AT
M4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```C7241!5%C#K5@+4)7'
M%5[;&F*;-FG:3NO8229M,[:-S7223!IK,TEKC/A$34#!BHJ)2`6BP8AB)!:C
MYM&H$V.-RLL'ET=X/X3+6P5%07PA&A`113&(#U!!`N'T.[M[?_Y[>6A)=N:[
M^_^[9\]_]NQY[15B88H0,RSB%^_ED`TB,%,(X9<JQ'0+B3<3B9M8GD4_#\G3
M$S,L]-*6@_3\Y@/T<5&-GL`R<FCBW6Q,X!MV_.?%:S;@*:F6657/@TF5C?38
MVD(:_I]]>O"M-#N^8MJNYX7P3U68LDN*]LN0?#K6T$)55^^0"+*2P7K)'OTM
M/T7<UMY%'=1%Z_)J#(Y55UMEW[T_N?EHRCUWG1I:VJFD_B9M*[U`FP[6&8N,
M/9LPR.'='JR'(7@PZ\(1(,Q2Q-B<',!&>$.-M]OI"C`YLER-_2M9:<>V04F\
M-$O"UD9N.@CE9I+P39'$Q@:9N.,;HJ'OYU-XV05CP1,?[H5^=_<D%MY)%)!Q
MAIKO=A!K1G@GD[7J&N%P>A(75C?1QJ):*H7:=I354_*I!EJYYPR)V7$FXA56
M/M8>)F-WU+XI6G7VNOP+\$B_>C;@&O42<QJ_]3!-"RN5F!)>2I-"2VFR!C_S
MF&W>!4BJ_`HVE=,$58_M9FPS#9M2V#\",[LQYPLI=CNK5K??K,O'$61UTZBC
M,/1@;W,VQG_?3KE0XNBPPY1Y^JJB=HV2B]-/7Z'$B@;*@_9KFUKIZ8W%U,*G
MXAE['XS=HVG_^1L46GJ1A',XW81%]=5&?+)?<1L?<1^,I^Y2%(]_(/L7/BN1
M_9-K"ND67&[2CC+Y'I!62=ZIE51SK96$?UHOC/G(M7-+QB]O([$H3>I6S$^$
M#:%?DJ'>?9)AB!CS1;\@2<VYPC@G1AJ,![^3(08'I)M,:'F6M`QM>_\WG)9D
M.)A;8":;R`F3)6P"E@*K@-^;B&N!""`)N*3'INC^KWKM1P8?PX9]DL7#0=9^
MXT9?D"%B>18[2["]<X#IAGVUY+*MQ#!\!CN#"S`U7('?S?.C/SV@%#LOD:5^
MP@A6$AXQ0H=]%:08?JER0<57M^EWZ_?1R"W*,CBQ&#0K$+$7IZL(^':ZL(_:
M[IKI<I,7<8CW324QZG/)["G8:D<7:'R2NFG@=4-`QTQ[VJV-J<X5TD6!9S84
M$6>W8>L*Z+7=Y4I2-KM`%5F9]L%[,0VPGJ&?!>>05WP%I9QJI'^$*>._W=Y)
MY8B)PBN.GOU,Z;'NVAWZW@I(NB+['I+ZI="1^F:9X5H18(:%Y%+[-UTJ"+WP
M7\GL<83O+\&06P0"KQ.D[9^IZVX[G]]<?)[VU5ZC<3N.DO"(YL.@\9%'J.YF
MFYR_@1TX!=V+J0YQ'C'':7Y"!8EQ8=*%K8ADQ>>ODZ7\LI2NHJ&97D05(<:&
MW<=!(=_])#B7+!57)//@G&I:HW-X7DV3["/++\E^978U"3?+O0]*S(B6"VJO
MMU$4I+*U^)/J(ZFH1;KTV*K<LW3GZTX:]$Z&`U.;\7O&*J8<G5ZWL(>0>`/P
MC"'QSQC]'*?&.5)Q&N4(AL`]+O2(9"JC%6!$*2Y^'@C*NDX#:.S>L!H!U2E^
M1B1"ZH6G##@$PFGLPE]_V*W=L:_Y'^G^Q[IW`AX4>M$UP`4(`&*`1#W>I'L?
MW?L#H9H!.?2EO=<%IC#(-9F8O'-F]"EUZG>!UJZN7M'F@%:'OJV/=39T<AA@
MKWT[O0K)F(_BMQ`N$DCNNXBQ85:<T$%='>YTMJIX+JCMP6.S8&FOA)(8`^=S
MCH`3`F[1ZAE>+\:&DQ@=*BL"\49"3QX2&!^YA<(.7Y3?-!)*CXK+5`V8?<PF
MK(Q1YO!M"M%B$<)X0#KRPRU)ZXV(P6WHZGS9CX]0P7/[H3KZ*8(JYQ.[@LK,
M"W/?#[3:"3ML38$=!BXL@\=1"O_AHT)%BRC#[?W\L[KL.2A[EZV'9!A$(E,%
M>&_"8IXCE%E86U#IM<[J55@^OH4I*J!P\IN+(_-.4(%F5BR)2;@?+4XCS]CC
M,(%(J4TQ)XY&?+!7T@Y?DX]P>5;6\<(+/-RQ>;<HQ=,]1FY0;@2UVK<7]N6M
MY&XY)I_#CM3+/NY$`UFK&^5S=M55>4<(R3\GWR?BKI.NG3(0]P?)XZUTV8]!
M+2+',T[3(RL5_Y;V3D4S(9(&ZPO@P(7EG4,#G9WP6GANHDX\K#UN_C$G4,,D
M&-'VV*5F>A1'J]:JM!IBK9;]GS<6R7[4^OTR$]K:#]@T\)TA[^9\2V%1LHA%
MZ?3#8"O]:E6>M+NG^"[G$DFO?%Y""Y-.TH*T,_1K=J`QH>1A.2X%<8LZ1GPK
MGKX+^7YV+$T,+Y-FY!QZB&;O/BZS[M]@TP\%95,@9U6O>'):EOD=:-8CVM""
M<_@1.M_<1FOA1$6XG*PM/$=/?Z(TY@%S>1'.Q&WT]E)Y_URL36%6S$FJ;+Q%
MVP\K4_KCF@**/'J9NKIT5>2?^AW8[#0XT'QYUZ8)J(?%G]93P84;5'ZI159%
M<V)/TDG\\<"MIND.38@HI:NM7\OWHY>;:3;,I/Z6JIX28$(AJ%F:,,^EQ_H#
M=51VL07EVV9YAQD"+0]`V.AN85TM*N0@1&THKJ.I.\OI.1P?%YO/`#-C3]`,
M",P7)#=49Z];CM*SFP[0H*5[Y-R(#<6R/N?W*3C^Q]86T-J]->2#6]NCJ#??
MRSM+P04UJG;759Y-V*&(K68(^=\/EQZF&QU7'9RYC`SFLE.%+LXV7AIS3<_R
M_0O[N7D.='-[66>C@T(>T$ZY.E]^5U4POKHL6I"DJAF[=,;E$:=;UB[J+P@@
MA1[(_6N@=S8I)`O'2N3:S>'&V3N8D+$4SXMQC5K4#P+O@Z9?0#$!&>I[R[+Z
ME@D_U<!P8`=0!CP$5`)^0*=.B3/U>(=^7PT$F<JXNT"5?A\#N)K2J2<P03_'
M:/K)IOE_`R--[UL`9_U\&6@!BH%&F]0\\2HPPB3`2B!;EVE/ZOM]+O`QD&E:
M-Q0XJM]?T_.OZ@]8@.?TQI?IV_-6K9Q&X$O@36"4_J_@$!`(N`.+-<\2W6?]
M#V*[0^-\C+@O`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O,3`N<&YG```````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0Q,@`Q,#4Q-30S,3`V-@`P,C4Q
M-#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8
MU$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```2<
M241!5%B%[9=;2)1!%,=]ZJ7G@GHH>BGH`D&!&('UT!9(5!24D5!TTTH"L<R@
MJW;'RC*\8!1>BM(HTS:Z*-9:MFD9Q&H@;49;VV:26*:6>?)WEMEVW2VVR"CH
M87:^;[Z9<\[\Y_\_9S9"1"+\F^_!LC%5;E57>U^R3A9+=G:VM#Q_[AUH;V\7
MV]U[4O_P4>!ZGXW2R]=D>$Z9Z,#!X_D2EY`B>_8=D*UIAR0B*MHB1S,SI>-#
MIP2X_5[3GZZN+KE:52,9.042&[="3=E<+V5U0J)WUJ&Z;MEA=<K4P@ZI>>R4
MY(+;,F*OXR=<_)X)JQ,WRZ9M:0H`+7K7X6\Q%)TY)Z`S/W:EE-KM<J^V5G?@
MF\`665UW_[ZB/F?!$D7/Z71ZS2<EITAO;Z].\'@\TM?7I[U:`(/>/I&DRO>R
MIOR-0KSJ0HO\OFW^L@$8`Y5NV^[(AJ04"=L`>-ZQUTMS<[,<R\Z5^6O72^)U
MN\R,6:CH\`RW@@S`$#Q:KU>I`:"%>^!-%&"?E7=**BNKI/%)<R#,--`;&;U4
M/XP:.U$7CHF<K12<-'6Z+%F9J#V.IL3&R_F2DD"V+<PJD\Z>SVJ$<\HO*M'W
M47,W"GRF9QPE!6'`(?L/NMWND*`Y'(Z@\<$[QG_<`$D,]BD;^\\>'H1MH+&I
M28^PN+1<AEQXH#JEAQ.H'+6[7*Y@)II6<*[,ESE3FSRR/"U39LR*D6ES%LF6
MA\\$OO3T?`HVD)=_2KUA`._I1W(U^;$5&,BW[0>/J1YX;FMK^\9$O!&VR9YP
M'<J2X:$T.B"K\$R/9HC*9\!X9B%>T`/;@.\5%17:XQE%H@D:SP%;B,QUJM41
MB],UY-'Q^:I&WND!D7'><6CH[C,P;4N1BH?2842$>`B7=Q(BBIVP;&>PF$B,
M+*0X$'+.7;<B/2ZO51,+/=PX:VN2@<+3'R90^$`6KX1/3[A\QP@+AZZ_&%J-
MZ-U_,)2<F1-J_"\5TY]L_VX`:!=9H=6!B7Y0`J#6H2"T?J/:YI,J=8X`2![(
M%;U#6\9,VB+%45`&:B"L`"BT5&N3I;CH$`#!1#6\E<GK-@M72Y['6_K3GO6!
MUDW&>6;,TN#1"D\A_JD`B!R(3:;#,0'Q3@"G6UZKX77I^V7?E5K-.0F;=FN@
MS-E=4B;E_1(E<8%46$>`0V`F!UVRWE1C/+-S8"<0,B9&7[6^5<BYO+[H%SF<
M(.60EN`(=QC>^6YL$2!715,4`IP;J,GE]$"&4YXQ0"`88/?,X:QQAB/.F,8:
M-L$\',,#PQWLD\I!RAQ'0`#D0HC$3@P*D`MC+"1R2AO.081Y-',D.,:X*8&@
M1!`TUO+=].3>D$=@=W5K]J9VL"-*P<E2JS*>`',:.F58:K4:H3QP-29)@P1&
MG[K>:!UF/KF7RL!\<YG[(0>H`.YWG5I*67SBT2?]S\$.D!#?(1O.2.YG'1\E
M9D>Q[^)N@N-O`?8(D._?<QX0P+NN+UK/N%UBH+&U1RQY7N?LC'>0`5KCW`2'
M<Y##.7S@G?E\A[!A)2**ZKSD#"DL+`Q:8(+#.:3"`0J`X?Y7''\4<3XW?FO0
M]U_.A(/5_@?P%=K%O%^('P1C`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q,2YP;F<`````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,S<T`#$P-3$U-#,Q,#8V`#`R-3$U-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````(```
M`"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!
M9&]B92!);6%G95)E861Y<<EE/```!(Y)1$%46,/ME]M+U%$0Q_UW>NHEZ"'H
MI4"B>BA((RKH?C$CS,I2,4JTL,CL0FI*ZJZFNRZY:YK5FJ6)=[34+EMFY`TD
M43-$128_LYQU%W79REZJA[/G]_N=.7.?[\R&B4B8_]*?B8D)*714B.]#\I4;
MTM75)2>3TKQD4U-3>CH[.QMXWW?%]N"A[#@8Z^615UPFV04V.7`B4>`5]NE+
MOY[T]O;.2PFV]"?GGD5LY4_D:F:^I*1GR>ON=^*N;9#CIQ+F*2<G)V5T=%0Z
M.SLEQ5JJSZ&+6!X"%,3FUK8V<5<_DP`"M'4]KE%G;-UY1'IZ/JH%2I!X(57>
M>7KT$.>4.*MD_>;MZLKQ\7$O&TR*JVF6F9D9,>:R^T00EK-)R>J@L\YJX7WY
MS/PE!F-C8Y)OO2^N*K>0&Q@:,H/+&=GRI.:EYJ"CO$JZW[R5W$*'>BDN-4-6
MK5DG"QBTO^J2.WG%ZNN,K`)Y_Z%'TK.MZLK6CD[U>T-+NR;F[9Q"==;NHV?4
MDSY.63GW9&O*=96P8N5J73QOB8K5W:R-D?MD6^0.N9:>+@%%,3+V3:)C3JMZ
M0T-#0N5<L%=(0V.C?B-%V`G3HC[@H*.C0TQALF,S.PG`7EI=)[5U]?+GP_@7
M,,#CU%M32YN"D7%B2`QBXB]J39)])!;I7&1WRMH-$?)U9$2",D`:&4?Z-C:W
MBK/"F\J'8\\KGI%$)B\"&)`T2$%BOMTE5V[G*A:S2%DNPPAM2&6T!"U\#/B0
M<=>J1023VJ96K8,7]2UZD5IA04>=0`OL^!@@@8O8C=2(O3'2U]>G1<1%HSZ+
M\\A]QV73MEWS#`8&!K1`3"&Q(R'\V&GO<_BF^>)*2%5:RGV!$\%U_$%I&S"D
M+BXYG\KP\+`^0[-H%$!-<TC\_8L)#<F%PDKWXE%@#0X.B6$$/A-S@ZY)<R##
M#I`LF0=QY^(#2A<L6%#>V1;Y"ZOQWU0`N*$7TP2HVV!PLRP*T&G!-TJRV%&F
MN4S.LRA5,("&RNSA=+E\D\-O*T`]4/<T5-`*X>YGS[5CTX#YQEC)R,9WT`I(
M!`8,+!05E\@O*4`A8K7I^`AA+RI[)#=S[^M"./@+@(-T@!4*J$)SR^YZJEYC
M-O$?F994@+@24^#2:BM32YG]P&C#%,',*2`F9]""D%CZ\8-'$92=D03%4-AT
M%F9(FL/^Z%,+YS<2JL!>K@,00F`$KL.`*1EK38/`_2B#$/#>X_$H]D.#4O!`
M")"-02C`SEWRA!"15P$*@+Q<P.TD%)V''=>2!URD+V(Y?0-KH,'E6,HP!AUA
M@([%'81BM>'-GIIV50P\!H2`.*$(E@'`]`U<R]A=6NK01993!20=-'L.'16+
MQ>(]F^O![)F9F;JXB^51YY+T'MZB,TQ/3P<?H>D_Q-]HR>"76/)0ZYY.:>:T
M6S:7KS>SH,%C]"[>/_</:B\SG2;D*J#MH+$90RIK&S7&_IE,;\=")E'>R1=B
M[4_#&30_I4!"59V6CFEEHQ/?=<PE;D:AF\['^LV,O#I7S/U#\Z?!W?#R_]<4
MD@*,!+@Y&)K]#(T)X_]NN-3Z`6!#\]4O#565`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S$R+G!N9P``````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-C8`,3`U,34T,S$P-C8`,#(U
M,34W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6
MV-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$
MR$E$0518P^V7RTO4413'_0N"H$V+((@@6M2F1;0HJ$4D08O"WA32PS)CL*:B
M4<LLL\2HA#+L99D2FI&C93H:.EJ.IJ/E6#88U?2@(A0*7(B<^ISA_II?,X9%
M052+Z]PY<^^YY_7]GF.<B,1%+OU375,OE\MNB&.7*RP]D%<@N?F%LF;SCK`@
MU]LI@X.#LJ6KWW[?TE'NOBUG+I:("F;,GB=S%BZ3Q2LV2OS2E1*WU>&4#:5N
M\3:WB'4E<G$@2B?VE%1424U#BYPOO2Y/G_;K]^U[#X9/G:SVJ-%EY162W.B7
M-5FYXO/YY..G3]%FQC1[S`=.G2F440\0O+/%Y>H>?ML.Y)^[(D1G^?ID(;`/
M>A[)]9N>KW'(.UVD/R+DH(E<I]\?5E/?Z)74^C9Y_?J5"G$U\<C)L(:,EFX9
M&1F1I*0D>?;\A::(5-76ULF/N_DS*Z:PI;5=<`Q[>P(!S=^>S*,R)@7;4O=J
MTJOKFH3P-33[M!XWI^ZS]D-#0Q(S$:RFNSX-YZ8=67+M1I7&G'7JXE6M'E?V
M"3%AIV`L!85M#V7:S%E:22O2#LJD*5,UHLL2$G2?U!O23\X@1X%E`6G@TK;6
M7LG)R9'T_`+9V=@A+I=+UA55R`6/5V,!$BC=[NYNNPLH,`+\HXXCXQ(,!JWO
M@.'WI_'/40#.*:8?5D"^01"1;^_H5%)[^^[=V"HQ,66/%A0*0#A4256"3VK@
MNPH"O8_T$J7,)]5'^1JPHR@F\1E6X!#U3SE3LLG.`_J)&^0?!2PLM%4B6D$;
MAT">J7M?^WWIZWNBBN$BR!D%N`EI6PHPG8CS.J_B+PIQ`YI'MF#)*I6S!['@
MPN9"8N4=V>1(U4!MK+VGG#5QTF19GW]>9L]?I"\NR<K3C*`,^K(IV)V6H6#J
MZ.E5_X*OWLC[#Q\46!"B`1E[0&8+(A<A01"Y_U:3^KWJ>*$B$K(\6N;6BV8?
ME04@"Y."1"!;?#<,95!:%P@J)PP/#TN5/Z#[*`7\:`2A4,AV@-^,+'+_%\'Y
MWS*`XJ7_`ST0`F8!.X,#,C/Z_'(#@"KX!>?T.B8D\,XH`<[Y3C>&PISIV8HT
MH/QMQ?V4`88?>8!%AX*E\1ZY(1PBP:.<A\$@'Q`-!3"]C=D`P$A(BTM*U1NX
ME8?P%D^A3933^1D7V#O2#NMC/(Z1@<=!94:,,O=)$?H@LLBV:WL<WL4+P@LS
MZHSRI2/PJ%$,G>(AS,B<@JS=_T`?U/T7'7S'8!XT9X@2>C$2<C0MRF8`A,@%
M+.9Q+F*(\9++QDNF11XE)?0^4L)9$PWJ@$5?P"E8&#G&8X"93FP&P'T8L/9F
ML_(]:V[*;OT<-WZ"S%R<H!3/'CG4;_8HY3?.(&>QG[X@WCIC]I#RP,!`;`-@
M=E@=,J8E$"J\A=E7'SLM3J=3+C2VB:.@2/=4.CDE](=N>[470=C4$%ZRD#-7
M(V<B'+4(NYZ]U'Z$=4R+-#DND3]Z$]5_J;5+'Z%0Z0YF@@2"&`(7,`P:.6W*
MR-$S*@KNA]ZJ]POCXS7'F54-0DU0R2BCGU^M\>B8RK[2[=;>1X[9<Y?1%L/2
M*SV:=SC#R&FHD5TKR@#"E)*9;?UW85)"(R4EA!0%>$/OC%224=^J?92TF=Q^
M*R>"_YO1'VG`9];8JKFJ`)J0`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3,N<&YG````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C$Q,@`Q,#4Q-30S,3`V-@`P,C4Q-#0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```"``
M```@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`
M061O8F4@26UA9V5296%D>7')93P```/<241!5%C#[9==3U-9%(;YG5SQ"[C@
M1M-$0DP8$S_&*5I0-*C$D0&U.L1`K+50E`J5'J58;*M06Z5XAK9DF!`2$O)Z
MGD5:(`4%0>,8+W;.[C[[K,]WO6NU05+#]E7;+"]75#MXE2VH5"J)9\.>G^PX
M</\I*9E,;LJX_?=3L08?QG7^C\ZMJRTM+=I5QIY*<H6/FLFZ>O?>U8>BJZY+
M5W=*6%GY5VMK:]K8V-"C<%B]O;T'5''X"T]CCBKELGJNWU/=A5PNI_P'5Y'8
MK'IZP[8O>Y?M0C0:%:&?3N7-O7QQ2>?\`^H//E$ZG=X4L[Z^+M=UA:M=79=J
M+NYJI.,DY//Y='1N'DH`#DY-3>E``E*SKU7V\$<TAA\Y<J:SRLP5=>I,GTZ?
MOE8#6IT`4%AT2QH,Q01R"./-_HBBXS,67I)$_)>6-N_Y?"<,/#4D)9P72J7G
M%1I-JO/*`T_[I`KO%\V:\43&<D,2GSW/:GHFK<;&1E4JY2\'"9.'AH84B434
MUM8FXG+@+(!QQW'T_=/X/Q=`T"`'*NG`2!R?G/4*MF1Y3F7>Z>+%@/8E@`*&
M1OEX;'+.Z)!B[P@$#5S4\F<%Q.-Q([Y,SM6$DS=(@SRX%?AB&6"J$P#*YO-%
M*QQ@FWE3,.A",X^CCEE!#;R>6_`L7#)NVD&<%`O2T8*@_OL3FDG-J>2Y4JV%
M6W=&-3@\8<5ULV]$34U-6P+NW@U:L.).UEY2N@B##7E2E9RA)!Q)*'CO@4Z>
M;*^G;E*VNKIJ)K/G.3#@56%/CU7?=J[;-Y!BL9BZN[M-R'8VW;<`,@.M4<;-
MS<WZ*BB'0B%S[2>MQE\&?#<#J&4JB[I?_+AHK,,9]$5ET7GV0MJA#%A86+`:
MH/&R4$RGAJEX4OZ<0T30WN4K075T!.HZ^%<9,#(Z5E,*Q\(KS(I0Y7!XVECO
MOY5EB\3(DU>Z\>=C&R?&GJ6MB5\(].G8L>,6N7T90`BA#CQFSJK.R$XJI\F7
M;XU&F1P@-Q:_,03%L*5-$MX(PAB"L2R8]J_^.]:>($WD;T_5UB3L6<G(@="A
MD2GC;AB6KO)FOF#3(<UB\&'"N!Z>Y\P45C97-4U\1Q.!NB'4BK=>).=M7F)@
MA\KI7CL,P&N$H8R>4)U;"2<4CH>T-=X3=A02(19*B5#U#EA@5?\I<%8=U,#'
MK@944P#*8>XS9W^WR_0-]CQ9[>V_*=#9Y9WYU=K::DS/;XB:?'/.XBZ*N$]3
MIQ]SE_8"L(^,!_+YO/Q^O^46PU'"GM:#4MY]4R*B7?'?"^^)'DT3L+''^R]Q
MPY$Q&@HQA+`3";S?:Z+]U0M^*`,^`9EV8S[GXV39`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\Q-"YP;F<``````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S,S`#$P-3$U-#,Q,#8V`#`R
M-3$U,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``
MUMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```
M!&U)1$%46,/EE_]/DG$0Q_LC_4_\H>7<<LXL*YKFET8YBU5:,EVRG)'X/40I
M0%`T4!$E!124S,TYW2Y>9P]"((2MK=4/YWB>YSYW][E[W_O.:R)R+5_TS_+R
MBOC\(0D$`N=OWT\&))5*R>RGT(6JV6R6W)$B&]'ME+3<>WFNX?%X961T7DQM
M_5)34W.N9K5:I>!(OMCM=BFRF=Q+B^V]2WH'IF3*N2CI=$IV=_?D^O4;%YJ]
MO;UR<G(BD4A$RH89B\6*7923@@?GAP]RJ0*!C8QZ)11)Y)*04]A)I"2R%9<7
MKR?DRW9"-K>3PCM5.#HZDJ65=>EZ\E8V8W'->(_%H>7(63@[.Y.-C8V<68?#
M(1:+I?B:P\/#4EM;>_DUJ7#9:UY%2KYTN1:T5OO[:3DXV)=GEC?B6UB0B@;`
M'>F*QI*R&$[*N'-%?S][X="TD;ZN1T^$I!08F)R<%.N04[TMAF/B#V[J,SG'
M*`=M[]P*RF`H*OT#LW+[CJDXBS:;3<#C]/1,-OQ].3P\5"5^`V(01\M0NY)7
M"(?#^J&[NUL]@QT,DGU0B$&,_%(5,,9A"M[3\U2JJL)OE_'O,$#2R`%]7I4!
ML."<#THZBT*02-W;VSOEZ]=,923&XW$M']T]/;>FX,'@P\Y![5=HJ*P!M]NM
MT(467-Y-A34-#BJ!,I&UMK;*\?%Q(9!`'LJP``="JUL*6R`]-N71*/:RD7U>
MW\Y&N*<]8@!*#8!YK!O<@\?%X*I>QR!V6)4KP:S/^R:DH:'AP@`]0++F?:OZ
M$59+9ML9&L*H\0XG1#0P,*0]49`#C/"!1F$DT+*GIZ<:`5>`Q^@)@\M*)I&.
M:VIJDD0BH4HDR^@\EVM.<4'HD$U)`_`"`GCJZNH$DB191,!O'!C&*R*1:Q`V
M!Y&JH8QG<$'(^01253.5\_SWM//_$P"%I#,8<`9KL+S0$30`.TDE[KI2`)E,
M1M%$:](`D`)L`^N$L^1`^_+-YU]7VGK<,RCU]?5%X^M*`=!]&#<XDALSL:&Z
MD3&_LM:WPXR^'Y]9T@G.E@27LN.T=_8IA_Z\F%T:`*W/;9FG\`:W9=)[@QOB
M7EA3&F1U9=-">"80'+^R3LC6EQT-E$D`B2$P)26"<AFOE*KD8*>^4.C$W)*,
MC']4[H4A65##ZULZ4DB[S>Y1KH85>9?^L0#AE$P@G(.2H5Y*R'=*Q$IR[WZ[
MTE11`'`8J::N</I!YD`'PLSLLMC'?,KGC"6"(>TX-/B>,H$%0P<L(`2!\(Z,
M8>ONW0=*N"5+0&I(/Y3-(*5^C#`V,@XV-]\6D\DDK#X\M[2T*-GRW-C8I&=:
MV\PJ-QMNZ7?T23W?T(M&HY7)F'KA&!Z%P0$1SXBQ?Y42VA!]SD&C7`B'9)<I
MD+]6_A*9=W1TJ',R88P9!*#2(0`*1P1L&$>?<PBU9J+PC@`8D+_-A("5X.AU
M@B((1A>_"21?%]Z`#\H15%7.N0$X0/AOQ-A<C17XYV'[QV8!5$P`9(&:`S2"
M*)7B?V<8_2GY#CCYA/UD@;Z]`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$U+G!N9P``````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$W-S<`,3`U,34T,S$P-C8`,#(U,38V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````@
M````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E
M`$%D;V)E($EM86=E4F5A9'EQR64\```#D4E$0518P^V61TME612%Z^\Y=^30
MB2,%%4',*`9P8$Z8LV(.B()9,8L1<Q8#YH`YK.+;]+-]96J[I)H&A<N[]WCV
M.6NGM=</23^>/T\OZ^OK>EJ(B(A075V=[N[NG+<[F7R\L+BX**>%R\M+O6KR
MZA&/CX_JZ>G1VMJ:TM/3%1(2HL[.3AT?'_^]\^'A024E)1H:&M+@X*`\/#P^
M<<77;0!'0T.#7FP`?5]?GT9&1I28F*CM[6UM;&S(R<V)B0E;N+JZTNWMK4I+
M2YV\4'U]O2T6%A;*V]M;[X+<W]_7U[GYQP^PNB-L1**EI47=W=V*C8U59F:F
MB//AX:'FY^>5FYOKG.O[^WLU-36IH*#@:7-S<[,5!Y63G9VMZ^MK*YCDY&1%
M1T>_6BPB)^0B+"Q,?GY^]@V:MK8V965EV<'OQ@"#\_-SN;FYR=75U0PXP,7%
M18V-C1\?\)]GX?N`7])Y<W.CZ>GI%ZE[\P",Z':JDJK+S\]71T>'IJ:F[)LR
M+RHJTN[NKAWNU/`8I:2DJ+R\W-@!+NWM[=7L[*QB8F*L/]+2TG1Q<:'@X.`7
M_:[3TU,KW82$!.,;;AP?'[>:AT&HQJ.C(P4$!"@H*$@U-34O>V%A84%E967:
MV=F1@\#'QL:L-X!\<G)BO5%14?$FX]@&N@__'0&D-^!V=W=W?1A$?/3Q\3&?
MX7>@`WMU=55Q<7$Z.#AXMYD,`9'&B``27$B%>,3'Q^M?%1(QX)?T?3?3US_?
M`/X_`&@PF@I*@VA@J^KJ:B4E)5F;T[W,SK^XTQJ2=_BCO[_?.OK9W]N=C!$7
M00G0XN;FYI,\</P?>8!6&A@84$Y.CFDFI&%[>[N\O+PT.3EI_`-][.WMV??P
M\+"I,T]/3R>"?Q4`7H(<*D%KS<W-*3P\W(Q'1T=-;L#)@8&!ZNKJ4E14E`U]
MI$A5594Q)P_#`39=65DQ^D7DPNGL?2\%=CF,"FI^_?W]#3W&CM`2)40\G.?K
MZZO4U%13T$2,/3RMK:W&P$0";80F^E0-P+S+R\N6#BX\.SNS<,[,S%A46'.`
MP6/F">E`O3&4`,2@>JZB/S64'8=30'A665EIAT9&1JJVMM;"O;6U90,+0,A)
MP@W@O+P\+2TM6;'^XZ'^6CH`0M7C%3DN+BZVRU&*=`#I`B2>4GA,2^HE(R/#
M`*-C'=/DM]J0PB27=`:%2$1^W8.@0$#P'AH:ZB0>OIGP&\!;ST^E:'82NLVI
M<0````!)14Y$KD)@@@`N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$V+G!N9P``
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(T-S4`,3`U,34T,S$P-C8`,#(U,38S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O
M9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$STE$0518P]67;4^2813'
M_9)^"M_XKOG&<A:96F$;38I2<KG1@TT7N<A!]L"B!E-(`PHS*B+-*`-$IY[\
M';UX\`:RIV5N%Q?<]W6=Q__YGV.+B+14+_U86ODJ6UM;TM'1L?O49K/)^/B$
M.)W.W0?;VYM2<\4BXUGTM=RZ_41/M02#01D8."?V@4%)I5(5H:%02"PR9F//
M)9YX)1:9=_S/Y/J$?V<]D-QJ7K"S4-J0OC[[[BGT>#P>O6EV],;C\5H3<83]
MT\I*8S_J^L4J%HM2+!;$Y7))W0/Y0E'&[P3%>R\L3I>WHB*=3DLLD5:KO;Z0
M%'8DC7BF)!1^68F#P^&0[NX3XC@_*$-#P]+3<T9\/E_E@'$MF4Q*>WN[9+-9
M\7J]M9'$;W82V=759743-29HYO"!XG#@.)FUNOI-<[6:+\KKM\OR,#2G'I^_
M<$WPH:&`<#@LB41"(K$%O31^-R27KDPJL-Q7?4(B/BQ_D3?OEP4W3%K+8$@N
MO)-\L20^?U@O\+M4*DEI;4VF@S&Q.V[(:;M'<X#@WEZ[%8\S,S,R/3VMEH!>
M\YTT((@<%0JU<*@1P(']/F+ZYN:FKKV_EKFYN<99(%`D.1`(E,OFU*E>`5(H
M``1-L_#;:3P<`O`W]R6G@(*3-C8VY,`"HM&H@$9JD(40\M_9V:DI;"J`J$,[
M;S*?)?`XKF!"`!4^Z8_(6;M;,IF,-0L@SEP.1N)Z&+09>L@NK<CZ^KH*OGES
M0M,)/LH"(K,)Y9/H_()J3:4_BJUO1&F$BUC!.V`.]P!U7"H+H/)>+G[0JD,0
MN(?#\9G+7.@[.ZIUP#L$P<\5`3M!<[O=,CHZJF0!\L`[IL)34##LSB7>TSHL
M01P;&]/B(0NFO"DB3$48P:-J23$*+0(XR#*DP3XU-:4XV*L)Z>_O5Z$(JI=&
M+2(3798I''J!Z6O5E5@72'#"/BUJ"<]@W!\BD2#A)X'DMW&!P%73=4,!7":@
M[,:"MK8VM>)PEO,_,0!,$5?"PFI&%W_$`(#[./A4_(^BDOOZ3:$&`5"7E&$D
MMB@7+]T0VJ^AHS]B`#B>3Z14$7,%^ZOT)_$%9K5A7K_U4"`26&CFQ5NM]Z/=
ME[7>3_:X%'G[<7]@`V!DO(&98*CD8E:5,`;>#^Y2'@1$^R<RT!YD@X&9I9QV
M<)X/.B^7AQ&8K:D!A-FT?U@L%'FA\R&",`*&1PE4"=\2>J(!NU'M*"`UI`##
M.4_*\OF"<C'\?.1(AY*>Q0`J'V]0P"C!)(`G>(SW4"WO6'`S)(]@*!<<<`9#
M&6:A7XSDN^%QGA$EIK^Z\QN"X#+&908D%H;<GGRJWI+78R>&E.\Q#&/!"+@P
MX>8<BH_;AE49SUA,VF"%;M3:VJH#=$,,,,)P@%*#TND!&$>(B0H[I0<^8&=8
MB^A!>8`.%@=XW(7-X%9^<[8Z]$WG2P8S+K,3+HPPY(Q@!FIZ#..3^<^#Z%6W
M"4H5Q1B`8M/@Z%E-#<!#%D)!+QZ:6;1ZH9S^Q3L48Q@`K)YWZ2``DQTY/U6&
MI,*T'Z*"0,*NT\=.B=9K(J2!U+'P%I#^-A,"-*QG-L!K%K]-Z^?#=&]F:?""
M<G!$"O?&XE\W@"B@C#"29X:7>N,B.<<PTD;.48Y!]<CGKW1#/#;SO(G2?]&.
MOP,$WIQ`.QEF<P````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O,3<N<&YG````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0T-@`Q,#4Q-30S
M,3`V-@`P,C4Q-C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````
M!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D
M>7')93P```2X241!5%C#U9?M:]5E&,<71-@_H$'4FQ("T1?V0J07&T2QC,P8
MM4P+0F?J6#[,Y>-`3W-NZ"%WW,J'<YK;TMICTW:89SI!G8(/,[4M3%I@B^K0
M:1QH,#+6MWTNN;<=S\,\$PU?7+M_O]^Y[^OZWM=]?;_7O0Q)&>/-_E3X*G7E
M^QL:&AJZ_77EVBTJ_V2O1F?T]_^BOZ./C'V(\W&][Z:^:&@9FW&H^8B*MWMO
M?[AUZQ\%@VWZ>']]O(]+5WK%\K[^W]38VA8[X87,E[3#6ZGFM@[Q'!-T>'A8
M3S[]C&;-GJ.L%[,U8];S-L:%*%SSOA+"3F6C#[V]/>KNN:[>&WTV'N_LC`T!
M:A+8<>*,2%6<!Y+1VMZAU>L]BD:CL1-R%^=IWH)WM+5TM\@\NXF9P`>V-OVY
MF699K[RNAJ:F,0PK1^)B%\\]KKSERT=_C,%P]<*S2KG-R5K"CQRH.]B??PU;
M[H*A4P8OYZU%VKBY1)%()'%%,>&;T`F=/'=>M8>;[/!Y?V_IAPJ'PZF/D@6;
MMI6IXK.`C:1UE^^`7)H/UM2D=D"*B<0"S\X]!I=*YFQPB,V9FZFD#EH:0]I>
ML<?V_V/?3ZH^/-/8D^,IM=.G&I(B.%33JJ+*3_5G9$"!0,`6+E[TLM9_ODX4
MXH'FKQ_@,?[_#N#6V<O7K(`P5(*BHC;X;7P]Q"WFK#D%R.DJD>?"HH^L$CEB
M"BNI`XH(5A.YZWRWC43%`7*9<@O($YI(!&J_OBEHBS&B3YB#JOU^*V,6^&N_
M-!Y0WLL*-ACT"1U0[Z@GY;MD19&J_+6VF.<[2SBA`WB`$X2+Q70%".7(1!Z2
M.D`GF<1D%N.,R)"*$51HF=/3.`<P#WV'D3CB&2%$$&D&IOLC#K)?>R.Q`_I.
M7M4^$V7TM[4EI#_Z'U56YE/&4-@)J9)NP>>K4VU[R!H7#>SF#U.4FSM;.\NF
M*OQ[Q%0W91+SCW9H</`OJP$6(=%^?YWFO_NJH3H]4L9WQ06B=[9/5_?E2WHX
MZ/S``0P,1(WM$!9Y@+#4%D:>N[K.VC=2R,E3'7#TG@"@/X&Z!@O(Y0!Y0:.<
M(3E(#X9Z.#G"X#,<W^7U&D@*)2T`2%#I#J_MS@7`,4"<:/+.KC&"0:K\587R
M>$I47EYJ_9#B@@=I`T#&()8IU$A9$\RU>LRI-<'9+6V?->,O09.N`9P@`S1D
MCH"`Z`S/!.2=9[H_HH42<CT$@+M[3!H`J7?Z@Z"ATP0B".^8NWJXFQVB1_J1
MWD3WF+0`D,JRBKUF:#H!"0(`@@*(CD/#0+Z=$J/""Y?F6R;N/.^T`)!ZG!`<
MA^P.F>.<.1+>W9T)<.X;8!A91_8`F!8`4H_D$YQ4`H3=N1UB?"/5/+M+&U5/
M<$:`80#`!V,R+4B("O'F")8<_$K9:XH,T*J"3?8^?]D'1B^"O;UEH:KW/::<
M-Y]03O$VNP12@*RE.3`7_G/70Z`2@4BJ=H@./(<)W#I7M`2M7>%D:_%<_3N8
MH6-'I]@E<G7!-.,_%TN8L:[^2-++Y(0`4#%Z(@%![1S2;%$R%YQ>Z=M=8DV7
M#"`XR+.;.VD6L`LX/MX!__:XP-4U4^U,G=8WAH[;>-^;$93J^>[;NQ:8AZ8=
M_P?X>YFMXT&F[0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q."YP;F<`
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-#<P`#$P-3$U-#,Q,#8V`#`R-3$V,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13
M;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!,I)1$%46,/MEN]ODU44
MQ_?.=_X!QI>:D)CP@A@,`6(TX/P1-<$@&+=D2T3$ZF*R.,L@HN.75%!CQ2D2
M)P&9RPBHVQS.QB6L3FMHF(-U[2K3T71U3170+<9&\W6?4^ZSEE4<&`U17]P^
M3\]SSKG?<^XYWW,K)%44+_M9\^0SZCH:DB?P/=VD-_:UB:<)5H^DM77;-J52
MJ5)[S^3CWK#N7?U(P4==_7HU/+]3R^ZO5N5=]Q34TNFTWH\E9G8I7D-#0YKE
M<U?S/@7?VJ]-.X*V1D='U14ZIMJU=06M4"BD!:F?##SP@NF<IJ:FRL,L"WO.
M"O6-3?I#A0/M'VKO@4.&8][\A2I1Z.SNT;'^B"7SR^-1BP`#4SAW[KR%2.KP
M@!+O9)!P*ZX;SXLP#[:^IV7?_J"^<%A/;-ZJ:S*_S60R$HDH$`CHV=AIB[\^
ML%/Y?%Z7'^:5K+)"\D5-<+#]T0%18YE,1G_JX.2IF&4"8YZ[WVY5;]_G6EE3
MIR/=O98^G)6M8HJ.M+6T'C'#IS9N5W_DN.*)$3/>_-(>*TKG9,GME84T.T_Q
M'R>UXYMQO1I\S2KJCO%)>V>1?F0UM;5:?.@CO?[F7G5T=,QDF=0/#`[*G\J)
M@XU&HU:>/"E)'+2TM&AL;$R<*\=VR23F<CE/`0?N'<C_S#%>'0[(-!UQV0[H
MNU>:WU%T8%`4%G6QJ6F+YN2`QL7@<&>/52)-2R7"C(ON7%G64<D?(%/&5)LK
MXQ>#>[2V_CE[A]_*$A^&L$+KX4ZU?W#4G%#_!O\"$1(.WT'I6]]D?>\Y`"J+
M^*E[=L011E^='"Z0^[11XY:7#<4#U>NLK#T'"/A`P[`S\9('X.,(CD)6O:[!
MWEDE#EAPE-_O-VJZ_HN$O9.T&Q,3-A8(DT;B'7YS_&#&CZ;/FH!8Z4)Z`?*C
MH1@E)(X-^+[Q]+@>7+6JM)E@S=N2$^:93OML\F>]VQ>V[OMU6@$CFHJA02Z*
MF\T+`1:%/!B`#H%#QON*S*2U?&PXKDM68C:;]12`7]SBCJK_9>W\WP%`#=+0
M%#2-3MOQGQY&1H7\+0#H9^88Q$!;0@CT-JW*XC_S#S#,0F8?HXP>^,L`V!B2
M80,B3B:31K2\(^>R@XS-&<SH0SB.4VY>=*O-T#D#@.(P@(S=_8*-7*2.L&`[
M%N]$#9FQ.4!C\:3<<;F;&/=)_'%4S.VR`(B&*$@O9VS$/GW?8U/G&(=$"!O"
ME,C("!O"$%R$^`]@?#D=&`:_L"E7$BAKUOT-YL0`Q&R.(4`8"$2),8OTPS!L
M2OJI$604(WJDGCI@P7L`P0XYX&%CJ-Q=,DJ.`%2`6/A8G1[V;[`S9''K9=VT
M_&XM7_.X18'</9D5R)VN>\X/!+6@>;^GR^8P.?<L=Q3>YA._Y'5FFD<!L>%@
MFQF@B#SV7=8,=G_RJ8'#25=Z0FUG,H)[D2]YJ,HB0Q<Y6>$"AXSO7/PN)O(2
M`#4GXEK:T"B?SV?3('L!#/=N(L$1DP$@?&\?'BG11Q<;`%2^L,M`<D0$16V0
M470OOBC/:@OF%[.-39T!CNAKYAS3EFBY'##C^([-+2>^-ALF,C+TR=(-W6'=
M5U5EA7A%1%25.FNCG!8J'J1<A0%#9HIOL#WGIW1MXGNK":['_P^CJQ[`[RZB
MTU6*<M;2`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S$Y+G!N9P``````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U,#(`,3`U,34T
M,S$P-C8`,#(U,34U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@``
M``1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A
M9'EQR64\```$U$E$0518P^V7_VO551C'/_]$_B2%15"_E1`D0H@1007U0U%0
M^$,DI"&*D>4T'#F=>KTZ;YMMZA6W<9UW[&ZV9:X[W!>WZ=TF;KG):FO3@:.;
MSKL[R@L;C*?/ZWTYU^LL"93PA_WPW'/.<\YY/N<\YWF_G^=Z9N;EBWY6O?*R
M+7_Q!1L>'C1O=G;6GG_N6?OH_7>MN+`@NVQN;LXRF8S$N\]&_^4>;9E)IZVO
MK\>\UN;]-CEV2K)MZY:[^VGYP'TV_O%<@Y>;K"U>94\]N=2>>7J9968&+72H
M1.+-S\_;D>_*[%A9B94?W&MEP3UVM/2`588K+%)=^1\_\7`+.$,BT27'<?'F
ML]_;VV^]83AD:&C(O*[S[591&K#1X0[C-C_4'S:\S4WPEE=:&C*\%=Q98*=K
M=ZN_<L5+:BM/'#>OH2&F:W(]I+PDH"M'(]7&G`Z"2W&O:YVK.=_#7_/_,9!*
MI:S_TCGK[FRS6/2$C8WTZ]%Q'<%UY\]KBB4$7S-N;V\W&>"RQX\=M2N7:JS\
M4)%<.7JUT98L>4(Z#"0Z(Q8LWFHM9\LLM&^79:;/RQA&Y$'>(K@_H,F#>W;J
M38JV;;;"+]9+Z(.(P*Y"S6N-O[[F9"1[CY&17V4M'H];76U4;T0H$I(\9J0J
MK!9]K*[.&D\W:.W$Q(0])J^P:,"\B>NCQE/NV%Z@I[EPH4,M2`?5J=LWK#Y6
M(_B!=-#_^FNKLY$(]-*IWQ1YA"A@GK[UB]5&H])?[&RR5U>OM'/Q>OMJ\P;K
MO=BLS02@#"2324O?ZI,!:(+094Q4TD(`Z".5`44B88W!\?%Q8=Y+)!(V<[,U
M:\"/<3&S/^9KM'"0V-2?@_6=`<(8(QXAW-MY1$+<?[[N8P'J]HV8R`L0T3]5
MM=TV?+;.JL-?2P]-"4S$-%S%D1&`M&_'EAR0')C0.S`!)`P,#`QD@02<PQ6'
M)=P9CG<\3PO75X2"F@=D.!APB7?A5CI"XT]GA#10)^3YY`(2Z8-2I*FI44CL
M[NZ^FY]<LG*RD&$7ZA'V+(+IT<CB`>X93$Y.*FL@!#OQ2IR+LGQZ0H^.,`3'
MC(E_QB17Z(K*"9!@BS7$/?'O["(@,,=&_%!%H+CSU^_B/M(9V9GQIVL_%`?\
MD1S3&&+!@)N'?-I:?U0?T%$AT0?V".!T>UD'KV*/"^4.P"TAV?34%551,!LH
MA@:I#V$QR@3FJ16AA*&?6S3F0&XMND_6?*`2#:[!(W@`3F8>'L8#?"]7/O$#
M'[$X?;-+Y00'$`]/]^@`W))R@WD.`-FQCC$'@'H12(\+L*^X:*,^")]!P>A@
MT:)O"O5L?%,E(JY'07F22;78=/*,A<N_U`<8\P1DF8[XMQHS%SJP27UT',[-
MH8>N79]]/`-4CXX\0-HC1O"$JGD.0&#A5D['!W&C$T?GW)J6?P[<##>3.]P<
M'GCOG3<UQQJ*+SZ&\.;H:!F[0(601<1T2`E,0/L(3^#JXEQ!YB<G\HK+.4X8
M,T\^4BKQ]V*#6CI7G_EIA"RHFLT?TU<^(@:`"\^`6YA@`>+R%(;T7\0W3&Y2
MSLK[B-.[P]-W>_(/`+2=D,JI!W(P=*EG:FKJ'@'/+.20"/!Q&*=/,"W4Y\^S
M%SNN1>`,GOZ!?R*81%S_W_0+^_FZ!]E9S`6/S0'^!MQG"""'$\3O`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C`N<&YG
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C(Q,P`Q,#4Q-30S,3`V-@`P,C4Q-#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT
M4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```0=241!5%C#[9?=3Y17
M$,;W__.JT9O><*&)%S9-:XQ-#!AK;0RM&%0@(@1E5S1",91*6ZW6^($@+/O!
MY\)V%U^Z+.RRKA!2""7`X_YF/6\Q-G)A8TSE36;/UYR9.7-FGC,;D!383O;S
MRYV[ZNKN420:56!S<U.MH>O*Y_,J%@NOL_M;WC[A>3.*1")J:VM3%*$[;GF#
M`3,&!@8TG2^:.5?;KLE;>*ZJXZ?4U]=?MG-Z>EKQ>%R3DY-*)!)*I],:'Q^W
M^9U5_#<,L[.SPH$]/_\JQM=N=LEG*!:+JKU0I]]^?Z!3U76J/MNHBOU?ZH?.
M;JVMK2FPM+1D7N($<W-SQE18R.M*Z(9RN9P"BXN+=J2)B0E-34T9P9Q,)L7F
M]W#,]R.`^\0EUSLZ=::]1U]4UI@7&N^'=?['N_K\6+4:NFYI[X$C2I4VX%+V
MF``VCHZ.6L34U=7K4E.K_DA[%C6UYYNL_?J;&GG/TCIT^$1ISY;=!9Y=7EZ6
M"<"E"!D9&;$%HIBY5"IE+A\;&[.UH:$A/7[<:V'(O`G`E&PV:_<S/#QL3.%P
M6(.#@T;TL<X1Z8$2%)B`#^,6=@7\,R"KH4PF:ZD6;.^T*V8-5-N>Z:\)6%]?
MMU!^LK*EBL^J2DG=:/T]>_<KO*'2O2>L)1()=7A]`0R(*H+D^=];Z@_'+)SY
M'CY\9&W-V7K%DYY!R^$CE38/YID`.B[Z^"Y>;#4PYWL%4I83(`MH>OO./3_<
MB>+`RLJ*;0!R9KQG!E:$=3`8LA<!."878M&XYN>RMAZ+Q2PW-C8VRI#(9B9(
M*&`9JT@DAU\(`+HY)LF$0WT+\`&>=AD)(_CN`)`^:Q"F.^S/9#)E`604&M&"
M9/SALM!EI<M$QF0L@GT+=G/AW07L&O#_-0#L:TX6?6J(>_9"S\_G=/I22,$_
M5VV>MJKEAIX.#!DZ=73>U+G><5WQ_C*B7]\4U%L-``X*A8*E.YE*1@-]E`$H
M^^[[6L,0UIC/E>:_^K;6*H%SC<UZ\6H,;#Y(I-0_LV!5&,8P_^G!HU8-@`;`
M"<CHEQ9T@!.J,7#&02O"^2+18=M\\O0%`_26RR&;IY(#6D%-/G@P],5BT4J3
M3_95.,PV6&:=B@+BH*"P01&O"7`,,P8`AN"7,X`B*7BU_#1!E)/L&1V;,'QW
MCX:K.V_]U&UCZB$,XL-0W@3DNTH3J#<X=V@,PK(`(G,%6(KE$%YA'0`%_NT?
M0,DSW#M\X7`9WB$.PI@*SOWU@!AS!3P;(#E>-P]@!0.\P`**<)&S%I3G34$P
M8SSD"CGZ/$X0\0&QQAY:QM1B'`B"GWW()IC-`'X("JQ'P?8GQ3TKM,RAR"EU
M"AT_A+)_FX<?HU#L"GP7B'XZ,,`;W*^K,K830>,(C^U$\*VNKKXA!T*^GP6[
M2/C1&_`25AR\G/W8>:T`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\R,2YP;F<`````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C(Q`#$P-3$U
M-#,Q,#8V`#`R-3$T-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(`
M```$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E
M861Y<<EE/```!"-)1$%46,/MEM]/5%<0Q_E_^M@'?3%-VL0'3:SVI<;6U!A-
M:@SJ`XT5%Q&I@I42=7$-".O"`EG015HJ9+6*)*)L-4B*/[`%Q?!#+4BP$10A
M?N4SFW/A5DQ,Y,&8?9@]>\^9F?L]<V>^,QF2,N:+_202+6+]O;$NM1N/E&A\
M;%2WNY-^=<_$MW'M6E+W^GKU6V.-\)5Q("=+P<.%BM=%%0F7O8./!14P??!W
MLZ8GNK1IPSI;>[H3<RYCP8#:(P&UAG-,VBKSU!HMT.7SC7JW5[R_0D?'5?7W
M]^O7AJ@)0200GL)?UQOTU9I5RL_.U.C(O_ILV5*UGCNIF9F95.BY&K+B\R5Z
M,C*H1%/*BWEHO7C>KNBN>?%DOEWS;,4!+>(MWD<6ST&LMEP[MV]40WV)OEGW
MM:V3HRV65'L"NRR,R;;CNG<KII4KEIM8&#$F85':].UJA8KS+)S2J)+M9W7B
M6*%"/V>I<%^V?8?[O9U:^NDG]A+/04_/'46"^Y6W;:T:0]DZF+7>)%F=JZ.[
MUIOPS'DH+].0XO#%\^<I!T_'Q^W#Q<N+4E+ZDTZ%]HHT1>J#N]54FFO"]VNN
M#5G=?&!?(>U`&53R_]>N&YT:'AZVZN:9?.$_0A+Y$4PGS8#TI>I9X[']FIR8
ML+1],E#GI3//T:JJ.0=X@^PN_5&OD:&K1GADVZL7W98PL9I*JPW2G7-2G/3W
M',#(Y#XY/OG?/U8/*+%W)&>S=U9V-%\7FD\;`IC&')#/'+"B#"?A'8-#A?GV
M5CH#AIP/#?29,?$P!\"'^BF4VL,[K&@HGOJB+<9CKK`X=RO7\Q"\G)HRR.?*
M]WCD-Y_G(4'']X[S*29?#(@^C<Q5(Y7HJI%*I,1=);94%EG3X,7I6E@D!VD`
M'Q^`^*FP--VBDB.YHMTEFH)Z.19716F)<2!<R#,ZCD,HQ(&>L%'>H[XJ.^<9
M+KG;=<*>.6.M#@<\'ED0`","W+KU^^]TIN%T:D08:S,N911CV@(4PNP(60$,
M$,7%Q=:PL6=*H/NCPS2&/6>`8MP`N`\`&W`O"J^F>HV;*\H*;""%@QGK`C]D
MVAETBG-IT(`R54!%3';0,;KNA<Z^.O*+709]P/HBP`UNW;QIK,I+X&]&1IB3
MV>;9TR&;=^`P9AN&;X3_G7^V:>V77QAE\Q\:Y_;QTH!-*.A@ASV`B"H#K:^E
M08R$E^_,`,6$CU/X'P$43G'`_N[-*XWN`8@N9^@X6_3<_OP]HHL>[=`'@/#3
M'[@M#`YSTQZ@_O:J?:DV,-L2^(]T1/?:X(;PG[TK-04FEVL/F6`+\SMQGX@H
MN5;B^P2N]]KWG`V=]:'HG$.$/8`U'__Q#3&`LWT,0`L!Q-:UHC<`.!!,$)0>
M"DP6CQ\.FCP<?*#A@3EQSZQO$V>+'_SA%_\N]&DF3`-P\AKN5?,@PH8&S@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(R+G!N
M9P``````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(R,#8`,3`U,34T,S$P-C8`,#(U,34P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58
M=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$&$E$0518P^V7[T]3
M9Q3'^;>,_X")^H8Y$DQTV:+;-)@8=2&!!$R3D70R3&=3K:FUM`.!KA8[-K8:
M8.,W2#!!K.6'&$R5!",)<4Y#<-_Q.?7>]0I+3.3%LO3%X7GNO:??<Y[SG/,]
MAPI)%:5B?Y:7ES4R,J*)\8GBV[JZ.CU]\D2-#0U>=?<GGA?KZ^L"8VIJ2FMK
M:T7`VMI:+2TMR7>^\3TP=E1H;6U5?7V=LMFLFIJ:U-O;JT`@H,6%A:+64+9;
M?<FP,JT!_1@/*ML9UF^9[Y6?O:OW,_'A"NET6KE<3OE\WH1@$$A7X=-/CFAT
M=-0\YP.G.'OF3%'A]:M7XI@GO_Q"D4A$?[QX86LP>*FHL+&QH8&;4?6GKMHQ
M>V]<T>UD1+_W=&H73_$ALGL`[>WM0FIJ:I3)9-3<?$$^GT\S,S.:FY^W,(;#
M80L?X20I/`#I5)=E(0HH`L8*T/3TM/K[^S6_!=3\C5][]^S1[+U[_P!L;FZJ
M)YE0Y<%]NGRAT23H;]#Y<R=,ZD]_;FLRTJ*:8T=U]/`A=;3%O1[,YW,&TG8M
MI/#%K[<)@`[PU8!?Z/_';J$,H`JRCTH>WJ)%G@<'!^5D*'D"PU',CG@`X%(`
MJ'2RC11FA1+)Q.KJ:AT_?DR)1,+>0[,>`%*8?(=;V%=5?6Q6.KNZC!T`HB8`
MF;T_*[_?[P6`O.$=\AWVA)AP'<!FWU?&JGA7755I`.AZ``(M?OLAUL?&QO3G
MRY<&@*LM+=^:1U0I%4F<.!9Q<0$*RX\,U:R]+1SVOW2$K,"@;9XI)*>8($,7
M``Z'RU%T!`(TKF\+N438=S.NX9YVT0L\`%#IQ%"?52*5]FXEEI8XDNI("+8M
MU\(N`90=^'\Y0'4Q&4(<4!Q[F"CU0\HZ,9P(/_#,U`=3P5AP"`QU_7I,T6C4
MY1#HCT8-*8$9B\7<N6='!U"$!N'3`_OWV<K@-#<W9R1UZ*-*`V7LQ"%GD()O
MZ?X0EC-+\NQ@0/+HX,3*RLJ_.P`+0IV3DY,J%`IFG"C0'2!\3H4!'`V%0G9Z
MC,&F.(@NWS'"-]X3&9X9:HD0!]C1`>@U^%W`#&$865Q8M'#B.2O3-R<FE*7S
M3^VIS\P`X2:"Z-(3P."JF(-@8?CR^;-5_?7FC;8Y`#G>&1]Q)WONFPZ$8(CP
MTP]8B00GA];)E=755;L.0HZSM`:,$SDB2H[0"G&.]N`P^38':`OC`S]I[->D
M*T.9N`:[H[:.]B1,AF_%[)TCSC=:A2,#Z;BU#^8U1V[_?,MF,J<3>!P@+$\+
MCRU,#.``T(/H4\Z>WL2$^*[0M_C_A$$>AW"PU$GGM]UM$<,GUW9,0IS`._H;
M]TVOYRH>+BYLA3!O8:0B.`5[[IUO"'O>T_-S;^5![K[ID=#</;BE]U]FPK(#
MR-^H^?F+$(W;>@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O,C,N<&YG````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38P-P`Q,#4Q
M-30S,3`V-@`P,C4Q-34`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB
M````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V52
M96%D>7')93P```,9241!5%C#[5=+2[)!&/5G]"O"=;1R$?6%F\!E$`3M*I((
MHB*RH`L80?A*)70A4RJM#"J*BBB%H@L*%6%98!>Q"+\HQ6[G\SS013!P]>7B
M70PR\\Z<.?/,,^<Y:@!HOC=-QH&ZNCK4U]=#K]=#D]V2M(&=G1V4EI9B:VL+
MV2W)..'Z^AIE965H:VN#T^D4.JVMK5`4!=DAY,*$BHH*M+2TP./QX$])"3H[
M.]'3T_,5&*O5BH.#`Y27EX.1FYR<Q,S,#'+E%/\78']_'R<G)]C8V)"034Q,
M8&1D1/K'Q\=@M(Z.CF3.VMI:>I28,0T-#5A86,#HZ"B:FYMA-IME\?3T-"HK
M*U%04`"3R838WQA>7EZ^`)+))"XN+D`&0T-#TN;GY]'5U87>WEY,34WAYN9&
M4I&;7%U=(4>#J`+D`L#X^+ADX?+R,KQ>+X+!(!87%^5QVVPV^/U^26T^>";?
M)\#KZZND[.SLK&1C4U,3BHN+45-3(V`.AT.:-Z6O%$=%L2`>CW\!/#\_RQN8
MFYN3'9VIR2Z72T29H.WM)DEM,NCN[L;P\'!Z*C\^/LJ#>7IZPM[>GE#T^7QP
MN]VXO+Q$45$1#`8#QL;&Y#VDQ>#M[0VQ6$P6\'P\-Y\J)Y(-`?BHSL_/$0@$
M)#8Y?(TJP.\TE8!*(*U#6:0PA<-A5%55B;;4UM:BKZ]/9)#NBM6>GI'?Z+2J
MJZMAM]NAT^DP,#`@4LHU5$?J,PNYT6B4=70&BF*5(I^1`(7M_OX>Z^OK0H#`
MM'84./IE2FM'1X>`4E*IDG1V]#$<Z^_O1WY^/E965E!86(C-S<V4%+?+FJ6E
MI93BNL3;_!@!^I7=W5T!H(<Y#9[*J4B$&_'$U'A*-ITR_0^)K*ZNXO#P4`H(
M(T,'32_$*#0V-L)BL2`4"HG]R7@%[^_O2"02B$0BPGIP<%`DG:#TK:P3=&8$
M9D%A[6`X281U@M\I_UJM5C9AU,[.SB0R>7EYV-[>_ORWD%42,A?N[N[P\/`@
MQ&YO;Z6&\HH^QME8AY@ST6A4?MGG_?(:/[`X]KV?VZ]`):`2^(WV#R5(^$;I
MX4,Z`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C0N<&YG````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38P
M,@`Q,#4Q-30S,3`V-@`P,C4Q-3$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8`
M``$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P```,4241!5%C#[5=+2ZI1%/5G]"^:1R,'(4&3!LV$
M(&AF8400J80&/2`))"T*,K"T,LJ$C*2BT"#1C,`>](0>2D5(I*$]UG5MZ"$8
M.+HY<'#0<_S.^O999^^UEPH`BI]#47!!J]6BO;T==75U4!2W)6\A%`JAMK86
M@4``Q6TI^,#M[2WJZ^O1W=V-F9D9"8??K58KBD,HA0<:&QNAU^NQM+0DI/3V
M]F)@8.";&)O-AF@T"K5:#3(W.SN+A84%E,HI_B_`[NXNCH^/L;FY*91-3T_#
M;K?+_/#P$&3KX.``1T='6%]?SV>)&=/1T8'EY65,3DY"I]-A<'!0-KO=;C0U
M-:&JJ@I&HQ')9!*OKZ_?`)E,!I>7EV`$8V-C,KQ>+_KZ^F`VFS$W-P>^P.5R
MR4MN;FY0HB26`4H!P.%P2!:NKJXB&`SBY.0$/I]/BGM\?!S[^_N2VBQX)M\7
MP-O;&[:VMN!97)1L[.KJ@DJE0DM+BX`YG4X9P9R^BB`.#R.=3G\#9+-9J0&/
MQR-O=+F<F)^?%_U9S(&:3$9)[;WH'OK[^S$Q,9&?RL_/SU(PJ50*D4A$0MS>
MWI;0KZ^O45-3@X:&!CD>ZR&/@_?W=ZDN;N#Y>&Z6*A]D-`1@45U<7`@'Y*:$
MK[$,\#>C'$`Y@+P)99'"='5UA>;F9M&6UM96#`T-B0Q2W=CMZ1GY&YV61J.!
M8VH*2J42HZ.C(J7<0W6D/K.1M[6UR3XZ`WK+>#R.@@%0V!X?'[&QL2$!3.6`
M#7J#"!S],J6UIZ='0.TY2:5*TMG1QW#-8K&@LK(2?K\?U=75HO$FDTGVK/A6
MX,Y)-+W-KPS0KX3#80'@QM/34XR,C$@@?!%/3!;8-`P&@_@?:OO:VAIBL9@T
M$#+#4](+D87.SDX,YQK(^?FYV)^"5_#Q\8&7EQ<D$@F)FE12T@E*W\H^06=&
M8$H[>P?I9.]@G^#OM/`\/66?AOCL[$R8J:BHP,[.SM>_A:*2D+GP\/"`IZ<G
M">S^_EYZ**_H<YV#?8@Y<W=W)Y^<\WYYC9]87/LY+^TJ*`=0#N`OQC^Z/?@V
M)HTVF0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C4N<&YG````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C(Q-@`Q,#4Q-30S,3`V-@`P,C4Q-30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```"``
M```@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`
M061O8F4@26UA9V5296%D>7')93P```0@241!5%C#[99_:-1U&,>_3BJ%R#^B
M$@DC,-3*)"'_Z@?8@EA0ZJR<]'LY.E!2\_RG(Z$-;!T2)Q<RSW*U9JMM@9PZ
MVS&-K>G@AIOK4I19;!CLXM*A<;C5>'>OY_AL=V[$H)*0^^/#Y_-Y/L_W_7F^
MS^=YWL_C2?)RAS>E8-VV.AV].&+#F]XG>8*E*\JT:LMV+5D;4GGP\#0PIE2X
M^_6`9FYJU*RR#?)V=NC.!4ODQ2_*ZTAEM:JJJE1?7Z^FIB:E4BD%`@$-#@X*
M^?2N^(\5L!9',,]X*6*&S6@X*QP4B43D=5[^4YO]?C'CK5T'VK2GZR<%(BT*
MA\/RHM&H_5H\'I?/YU,BD;"#6"RFZ_07UP?`.Y*4]UY,MY2\JZ(]I\3^V5"S
MBIZHMC4R/.3.O,IC\BKV3SAAV_DKFO_HR^;;XM!W8K_N_9WV$?NU+=V:O3*L
M%UO.:L/`5=-=WW_%@L8`>!`>"%<35;@8ES.(JF`PJ-+24HNV]O9VT^&LO[\_
M"X`2'XV-C9D2LM'145-FG4PFE4ZG[3W9\Y;L_T>O4`#XAP#D*QD.;UF89GB+
MJ&.]/-1H(<OY_(:>O%!_J[(V&P<$#L*-^UN,-NXMJ\@"0'Q'?[:P7?%DL6[^
MK,T`N&ANL%9%]_DG`%9_WFV*Y,`C6T.6`\2\K_<7W5/\JJW7?!73XA*_EOF_
MEO](WP0`>5#9V&LA#"]Q&^:QWEY3*ZH#Z_"W'08,7[&_[?X7L@#$-<GADH2D
M`13?.,J&PQB`<Q$RU@9`TKCD(*$X)/M(,.0`(6/.Y7X2;/P926-FTI,#0`%@
M)D.QCMF=.48MA/*_!%`PX,8P8'AX6(N^/*';]\;'!^R4*WNPIE-]`[\9%[!_
M<U=40Y?3>OK@&:,[&(UJGA[YPPHP^M4'NK2TH3</H^Y80I,,(,6MY\N4?'I`
M>`*R049797TAYQENI6=D#67.K#LN[^,NTX5&S9!,.W%K3:L9!'VZ[]"YZ:-O
MLCH9)H0U\@QX^.2O6O;#)9L71\_810_T7;+QT+FT$3H@BWSOF&S.:[NUH'M(
M=^QHU5W/5)BW&!C"/+?I1S-@WNG?C<.AY<>^.&A[#(`H\PRH&QI1Q;ZX2E:5
M&V<]_TJY(D-7]=261O.(6]-OLH::JSL3QNW4`BC<R7D^Y/"_^XZ^"?VJG@N3
M#8"J#QT_I<T?-)L!,"^,B^RY-T)F0'/;]U8;,`SYPL??MMX6>?=`2B?.)^U]
MN?3#W9]HQZ>M=BGGAWL&;-#WXD6>E#O&#>"/$5`2N)@R@`P6A]5IQ-B[4H$>
ME[.G$G!&(#M=/`KC8ZPK-0SNH%[QPY-Z,P[YR#5W`+*GN`'"'H-8(P<$F2M#
MG+D.$QUP6%.&.`<'X]&C)$W)`P`ZT%Q9[@<,0-T?7"O_NYR_%J?`A`4#&'\!
MJ%B>"3*=/4P`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\R-BYP;F<``````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#0S`#$P-3$U-#,Q,#8V`#`R
M-3$U-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``
MUMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```
M!+5)1$%46(7=E\M/4U$0QOECV/(/:-SJ1MWH2A/?<8&&Q`17:GPDOH(!%7P@
MOE#*0\!'42D(1-``2M$4I!*H1%Y%"L4"[6V!X,AOFG,5VT2B2(*+P[V]]]R9
M;[Z9^>:0(B(I/R_]XR@IE\?/WXK]X'Z10SJZ?'(QKR*^[?29+$E//R@9&8<6
M?V]_$IP(B?T@%`I),!210L<+X3XE$`A(9N9A.7+TF%X3;"2UR7K=UB7K-VR4
MR>FP;-RT6<Z>S_F!$XR^S\/B'Y\2*QK33<[J%@UFZ2[^?L.P_XN4/WDE61=R
M)&'#X-"0$LFFLHK'XG[GE;FYN7@4+:VM4O^J0Z;#$6E]WZ]1-+?U:LBZ87Y^
M7JI>N*6G;UBMQ&(Q&0E,R.QL3-:L71?WDYN;)R=.GA+2=/MNB5S.NZ%47[N>
MOPP\_+$!K]<K+.`MV0`!DU-HJVMT:SS$EIU[4SP>C[C=[0G&XA48#$K7IQ%Y
MT^Z3*S>JA"(.34[)IX&`?!X:%RJ4Y]0P]&[9LE46&8`]\X)\N#O[-#>.!XWB
M:O!(45F#(HM&HS(X\E6JGKGDUNT[ZLB&8EF6>O-\'-"/\/AM?DXBD8@:I4S(
M(\9N%KK405I:6G)BX&)F9D9A4C+F-PCHJY5)XRHW`%D5%972Z_,)-;)D`VRF
M?+E21*3R7%;^T@U4/GFN78^&E3YLU#Z@6';OV2<T_J\I3#!`_U(PV[;O5-FD
MN*A`JA0IH3^HP@0#KII:50R48^_^#.T#I(7*1%X()_M2L2H(90\WM@$Z#V@8
MP$,P-*V>/_0&M*0I9YH,9/0&Z&@JJE,-A,/3<BCSN#92=76U=/>-VLW$2,`(
MUV@L+MDL9A#Z3I\H#(AZV=PI73U^<=:TJ&3R(5XC5E2%$&2\H[7[!\>49#I2
M#1`3<=(P&.*EMV=`?UL+7NA04DHW,C#HQKIZ]V+1=#J?JI*:19RH/*2A2N:>
MX6B&&XZ3MC*:S=4LD!`69%.EJZ"95G*M3@"T&G.*Q?T_!4"WH"3T.QI75U<O
M`_Y151QJGO:E)&F690=`;PR/CJDBH9&!\7']C7.$A],9"QVA1Y""90504O9(
MG75T]VFT:`H+D29JFA/-12Y1.I208P2@^(YCTL_*]UL`1`G5:"Z"A1&$#6E!
M\%RU30H$/:*A[;5`/R<&ACY*`1A4\UZI4U-TM<"AZ3/'P@0`O&`#YVAH-G2C
M9T3+H<BR(BK3..1`C,Z3!K2-^W#$4A#HW+%3^?8X0](`A/I22TD!0!,'5XJ+
M"+-S"]7(CET'Q.ETJF&&"U?DGEG!>1;))_]?QB;%W=&O\X(4L8?_$/3Y`H.P
MP#$H-355&8)E4[0V$J)'9!'>0'!*P3`".KO[=0R0#A0?AY7/WJBR$RV.80!U
M9QZCP[#$&`%`I\^OK<KY#)8`3H`P`K,V`$2[J:E)G3.'<&CF$$=/&&!>X9Q<
M4V@<UC%*J^+41$QJS&$0D'S'5"5=,,0[V*"`%^6#J0$J/5TOY)_H^=!,58R=
MS2I6`P`%%,PQE0$*&Q0LCME''?`M-D@7:691H#!`W25M#<8V9P5S*H<9%KFC
M)A`C"HIE[MG'._.>:T%!@2[N>8\]\Z\#P&%]177_CZ3XOP?P'1!X=9BG7P_2
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(W+G!N9P``````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(W,#4`,3`U,34T,S$P-C8`,#(U,38Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````@
M````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E
M`$%D;V)E($EM86=E4F5A9'EQR64\```%5TE$0518P]67WU,;513'^0-UIG]$
M'5^<Z8,C3XJ,/E2+=JR=4FO-6%K!*=0@:4D)$*'0D-"&0E)#VL2=`@$:0E)^
M9NQ$D^-^3KR;+)M0F4Z=Z<-A-W?O/>=[?GW/I4-$.II%_ZQDIV5TZ#O9LL;K
MJXO)IY+-9F5^R:HO9)]M2K%4DL?I%?=Y1\?&RGU)Q4=$%^:"E^26_[9,SB3M
MWS7I2&=7Y:?!WW0A%HLUGZ_)86%>MM=G1?[>%Y=./H3';LK^X:&@X5[PJL2F
M!J1A-%^4]8U-25D%V=EY(<#\LN>R)!*+#1/E<EGV=IY+^:`@Z?2R5*O5AH;C
MI/&C6E:`X`&P!R0!3"^.RO0O/9*,#CF;=(.U/"'6VI9$'V4$P$1I-3%D-M3$
M?],GUV[X-<`?G.F4?&E'`J,3]0V[>[L:N7QA6Z/7US\I@_Z(E/8.&AL2J:RJ
MSE@YR6T4Y(>^,=WD8,#G[6)1X[">LS2Y7C=;2LWE\O%Q:DKH\[6HI!^'))N:
ME&=/IO3WDT1(2NM3'H6N0+.)>#Z8NZN"7[/SOXOOZX^$ND(IA5"M['I=H`HS
M2T'I[[^N%4,0[H2B6D%$[U9@5I;2JQ((C&BR7(E"".N?+U]J_`D80M%'XVE5
M<+&W7Z[Z^C3\I,533-V??B(3DV&))S-Z<#@X[Z2#])!DRI2R!5D^O^5.$R7*
MAIG84ST8"C_4G')P='Q!SGXUH$\.ST06W`I>1]ZT@A,7DBVUBE0.,EHT-"!/
M?K/^:@5V,>6L>TXE_K$<UM\(1=9,-RTKD6*B$CG`,W#]<^WNA9D!;6*E(GM?
M"P4UA8H5ZI\RAO5@`$IYY$JGT@7*FNFBH<#V#ZM8@0TH7RJ.G%-$/P\..TA0
MUAP/!SZ044"13,^EM&@H+.J?XH)R(`[<\E`O"A@)-`I3@+HW_8!UJG#_8%]1
MH>Q%<<VM`(;A([1,,U&^6*:1H"P4G/VB1Q@U=*4A/$<!'[`,GT-^\,##9$X;
MQS06`>4["'#%I8"(TXDT"%%G\Z7O?]4VIAM!@3LH9L_IT^^[%40B$>UQ-A%U
MK-"-N(0[**1#"2K!]2@@!AR$B?`1GW$%:TP$T)R_,*2*B8M'@1$8":OXSA@C
MVM`XBN+Q1\*(^[_;^<W+"3;7ZBV`T)`(%6W>$6V1X_GGY(1F*S;\1+\:QD"@
M&P8?:U`03RY8RE_*&J\&<ZQAC*+4T!.228VKF-Z'()B'`+&28[IF6&<S&_RW
M[]L#:<O(&$4I8HR;"&"$:YM6J%WNW&]NG'M/[E[K4L,`@1JA0":Z7JO^$Z/;
M2#&.$6Y51@G&Z#6:DE9!Z&IZCA[SWXDIVPWXSBD``'*.Z```8.U`>$:*R;4)
M)0P)`\#3YJX"Q6`4MH"[$;[?#H45!/<70#-!#(<#Y.@T.0*@GG<,(^05!3_Z
M>I4],`@=X3'>8@QPY[^YHBS#S1$ZXPGCP$!<G)D-W)<`UJH>7&BX=<&+'$0!
M#`T3,Q]@(E@85H(S#4_ROI"T%-B%;R\ZI,S\("H``#SIXN;>%@`TAX&_*A45
M``P.C^N$PPC&$-;Q$*6D`MKD.^]$@BCQ9'1PF2-]?`.(F4\M`8"XM_>RG/FP
M2]YY]Y0*(2;O##?(GH@PIU#(5,!S)@4CA]`S#$QDN-<QYR!^AB'"?P#U*+0`
M@-?,-:+`#1.T&.5B@$$3;MZ9-JRS1@0(.9Z9*'&>8C6I(&I$#!!M`9`"\LPA
MO.*)%^JE#0:/"2^*48JG)C5$B;00!3/Z>#=79%.81`,;[8O0OB9CF$*D<BDJ
M!.3DM+O[,^$>3JJ0KH\[=1_"'O92L'0&>\V:D:/>O\8T-)?>9GE+Q_$_]\G_
MSA!07.0`````245.1*Y"8((`````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O,C@N<&YG```````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$P-@`Q,#4Q-30S,3`V-@`P
M,C4Q-38`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$`
M`-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M``78241!5%C#M9==;%15$,?W00-1PQLF^&AB\,$00W@QAO"@B0W&D!@U8#&$
MJ$TPM&FPA@^#-`0J8HJ!5"@2V$1D@6R,P`;::DNUI=5^!-A"J753!&6Q7^NV
M6-#"Q?'^YCK7N]VU7X2'L^?><^?,F?G/S'_.AD0DQ+AQ8TB8]26VY1%I_/:X
ME+PU5T+#OY^3CHL7I*.S1^I.G_;$J[XY*ZE42II:+WD+P:$_.U;,U/VZ<'#]
M3+F2')"/RH]X6U"(#A86+5HX1L???\@[!:_)SXF8;G<<Q_OP5_JXQ"MFR-:R
M#^65EU^0D9$1036S"O3U#TJLID4BT>^DKJ%#3>P?&)2W"PJRS631W/;-'F_X
M#S\T121]X461N]?T[`R!6^>?ED,?/R7%+SVD>*5./)@I@`?U#=]+.!Q68$'J
MW3?S/*3.Q9Z1Q<_-4\OQY'SG52G;]JE<OGI=-X0BAR/2V]NG"[B)RSP#+UI#
M)T]5:ZSV[#NI'^J;NU20-;3Z7J`%1/_7S5R##95[/Y-)X83PSO(/A(`"R]8U
M3RH<R_)FR^7&9[W\N!-7*XCI&`6.PB.WRG7CJOSYTMK\M223OTI3>T+V?UZM
ML)$`W6?R-!BW;X]*A@4D;_O^!;*W^&%%AV0`A/106G;MCLC2UU?*%T>K%&:4
M?K*SXC\%"'UU[)B4EI;Z$'<FDHHH[UA@\"/#9M8*"XN\TXD5T*.(C9SR9:Q9
MDK_UJQ5L),@[=D4U/,A2#830=P&?B3RH@T/9YF4Z+U[XF&Q:^[QF"ZF,I1LV
M;)2>GAZ9.)W=B*!T4F',-7!ITO62:]2?*IJ&`C?&^,F<B,V15'^C/@==@2VR
M%+34O"H_=B<TVVK#CVOUDHD4ZNB9!T2M<3%A)L&R%-R],Z""($]E4[1D),)$
MXGKM?/T^%E3]&>CK$@8UP.98]("&B?A3IN0`ZUH/;KI;&F=8T-LP1TJ6SY;H
MD4H_*\FXDI+WE,8B![>I5<A45T6S%=R\5B2_[)ZAZ0D)DX&,]OA/FD#4`[5`
MFO.N>*'@4ENAHDW90KNVD3K`='(!(B>-V3@X-*S%1$G[C(.9)VKJM`JMD!!2
MWOI7$77!LUE#,:D"8HJO`(:Y+6>[M6`XD:)J:(JK%90W,L:>'*8]"[0Y";^#
M[&FD:+T,_VD<#/H3_*#MAQ\E;'>#L0\^8[(IMS44&<$;K2D&Q!4W^``O4KJ'
MPOE*8203R07`A'9?Y78-LZ5SC@)Q_/9%;EC:XMJ4JY%6&\RZ*2L8=[@5RG6"
M2$Q;Q^0-<#05@GV9S*>Q@FO02[!%-D@94S#`T:+&JR`;PA30R_OK\J4[7JX%
M/=KZJ-(-0:::6,.HV.$E&FAT!?>WM;7Z/#XA`B@B`6@&D`#O,`WW#*@)0J!T
MYSTQRQ^L<\MC79NG:Q!&HX>K%P9,(02.MG#X#X)!.71F`Z])=Y12+U0P]8+G
M?*<Y@PXS3BBKBS.1`=ZAQ!5&A\D9U!)U1#D0%EB,/DS=,:AP!O1`A4,EV]>_
MH?NX*4#DW$WH&!@X%HF<V0U\;`)2$.`@2`S2H]CMVL%M@0/IY7S',*B&0E^S
M.E^1`WZ>00VNST+@SYM7-+&P$.^A9F)-+($3)=P@.(R#&;`MQ,`,_'R#IB!0
MNP<Q>$;&N!+#UJXK5E;B.>,"R2#[$8"!@17/(%@C5>)M5`_<&`%KL<X[G&F$
M2RNTCL9W#."ZA!SKVOF#(2`VP,A'B)9W\Y:V`-3T$Q3`]@SK-1P<O(N9L2!C
M.8-S<,;JXHTJRT6<,_P;$(<"I[4+#F8S!YBGS&P&:CQBS0ZTG,!H.@MR&&TR
MR&,T+1LG"2N\X/_9(;D0M/ABE#5$\QI/S9C@P08Q8<,X!B'`"/;QS(P^;J48
MP;Z,$$"G0$6"V$"0L#"3S:S1ZLAJWDE4O@.M93LW5]!D-CT<:C.Z@'Z<=I@Y
M,(Q*J:VJ4`.YW5&JL"-$A6+^QPVGN[Q;H2M'\AIO!/7DZ@_3[X;N85`MG@;_
M?MZG;IA[T!TITWO1\0^*?2%,<=<(1@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S(Y+G!N9P``````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V,C``,3`U,34T,S$P-C8`,#(U,34W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/
M6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%(DE$
M0518P\V7ST\;5Q#'\R?VUERJ7GJIU$.4`Z<JAZI5$RG)H25-'%5Q!):($W!D
MXEA@8](-.(XA!H/!$&,"`8L:*GXUB0B$['0_LWYK+[9C4-4?AV&7?>_-S/O.
MS'?&YT3D7*/HG^WU47F6",K1GW/NU^G\"UE;*4IZ+.E^.-B>D.FAVR)'5?]Y
M3\?*DB4+DX.B'Q)#$7DYGY%RN20';VM'@I?.RT8I)=X13QRE<E01^?"'^'1B
MWK*&92X_INZ@[D4N*\G$8.WD\8[$NB]*Z/LO)'+M:RD\N2O%?%)L^_B$F_:A
MR/$;7?"9^)34__GXSG70D68-CM=<?GDA)>69N$P_ZQ<UQP9V1P?NRDS.DL79
MM*Q7UF1NOB#62,3=L+>W*Z!562OI!@3T;USIJ@,UDP@H^EQQ[-YE62M;&JNZ
M#XZ#@6\_EX?=%Z2Z;$EYBD#8)Z&V%0.]3<MKMA3;T]09)W/`@82,J:RF/6@V
M*Y,:??O@57L/#@_VY.E(2/I"`8D]"BL2!!W8%A>+,IX>UP3H"_XL4]F$_XY@
M3:9P,#=AR5)I5I]@#?XD)`K!GPP"XJW-BA^DMSLEU1X,7)6!\*\R_/B^1/IN
MZ>:>7WY4>1SM52]?YOJ]JW@*\(([$@[2$GEP^2L-";$KIL.:)J^+0\T)WY2R
M3L)MS#^4S,!UE7*FUPV\'K3/$L;.\D\K.',BN6!2XZ;X7*DV)5!K!;6JW5Q)
M>EE(Y6RMC\O>AN4J:@NB@_[QNY(OA1$H;JF0U"HOY2,U)2<4X/;KY2E-H($'
M/<IAI._JZK*F,BE,*O,]&KXE^[MU)?J'M(0V2--,>D33&F8H+TZJ`E,/I/-O
MHW%->;YY"M"(`A;)=VK!BH=4";4P.YO3PWA":E-,AX?OZPJR&4M=QSJ'X:?"
M9$H+!F_XWRBA5F!=/^,XZ--3*!@\02@<K)EBXNZCR3Y)#0;<T)X$D0B,!B]I
MX0S=[M)B@N\A0JJ/:!!2Y=R6Q>0D3S9^50_>^>%+K4J:!-6(8BJ1<&*H36^P
M-<;W;WZC98R";.RF4IEA6JBN`ZG:FL:4+M8G'MU0/J?OZKU;I'/+`E$7V0R-
M(]IG6A?5?\\'_ZH#"@UP-,)CA&_.FAOA3W/0V0A-QPJ7GR#]][LY#2H"S2"\
M0S>LD6;>I*-!/R,A>H:5VZJJ$`,4@:&JA6DWIQ%#6ZRQAV^4ZNI\S&TD'IF>
M,HD,(V,8_J.Y4M8(+,0L`VOQI.3IY*:'4NZ\(^R''BE]1@.FQ,8";'*`1<B'
MCFZ48Q!CS(D0%H0$61F>W:C^+ML[VRJ\,TJP!X$5>7*^O^<G&8[U*K&QM^V4
M"*U"E>:VT"O&<8K#".M0;2X=UY$#NL4I!,XVK,D3^H5A04*=<)#A?S.6^!Q@
M5.0`D',`)W#`3,@8H$%@&`>`UC0-J%L'<N<=PZ"%XPAH0N&P<MJ*RIM]?U_T
M(?#QP[XJ@;XY1'P;.Q6"<IZ@PI.X<SL<QOG&'`%%+H.N_I[OA/D+&VT=T))S
MRH>L9R2"Q>%3YBG(.)\*2N%I2-=H&ZPWSF'LA<`1*H+DHV*>/PG7^+CJC>_M
MR[`V6FR5HMJ+C`'F;X2?.MU=G^D3!W"*P8^N@9,X2.M!,$YH&%/JS>`TLUT-
M">J8]H1!>AS"NQ$:INDXH,*O"44+XTX#Q0'(J7YS6SKR0!,9.8[`@,7G=]0!
MC`(_,)N9B9OSKB.P\\Z-74:L=F3#T_<`Y?\=\7Y4MI2J1\&G[0E_HY.9P;?S
M`/R_;L=_`6PE[R)C.[;9`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S`N<&YG````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,S`R-0`Q,#4Q-30S,3`V-@`P,C4Q-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```"`````@
M"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O
M8F4@26UA9V5296%D>7')93P```6G241!5%B%G9=?;!15%,:WAI`H"1$Q-N'9
M%[3*FT]B8DR,"<J+45.C/DC4Q!@U:DQ(3!\T6-((*HJT)6I1,"&LI;;1MC:R
M%G7%EE+H4MLNM!1LV=VR"[5U2>JX'._O#'>8V5GH;A].[\[,O>?O=[YS&Q&1
M"#(_-R>L^M!1MU*0-U]<)Y'\;+\,#Y^4O?L/26+TK+L]?GB/M&RY6R5B=5C1
M/]N?O5G/ZXMLYPII[?A=TIF,C$].FVU7YN6MVC6R]8V::V8],1]?>?DY.7.J
M0S\6"@7W0_YBEQ3V1229/"5_)L_)I=E+\O'.5L%YW7"DNU;&=ZV2Z(>/2.-[
M#\OWW[PKS;L^D):6+\-N8@(-`;=O)-X/HO]W=+U(84H6%A:"&N;B:S4M?^^N
MDI[O]@BQ!S:,M"R70F>5Y'(Y30H1>)D:CCTD6UZX3?H'DQH6V6+CU/1Y:6BH
M1XTCW=''-<1/ZS=IF*QU;V_4,JF)WKTU\E_B'DFWKY.%'V^7W,F-GJ->%!1#
M\EURW3!+2CXJC8V-H4,E%5`OG*:@N$.U2<<S&ZHU?QJU,R27L_ND[IW-Q95P
M-"#)?Z09H?#IKV_2XI,1A.QPD*SYBW'-`P/>$ZWWR;'WEVE1)J<R"N+?^L8D
M]FM".KKZ-=56&4`)YL!H10')NI#-ZN;]WQY611SB'<\4$66??]6MV`TDQ+FP
M6:AZ8IL;QI6H*_P&KK/1*@&ZA!Q*8B8UXL5%'<=.-&@RGW_B3LT-A><@7=+6
M=K!,.)N*V%@7+6,I\3?.DA3$?GAU"0I,-31&LTZTK9+<S"_ZVQ\*>0@I(+L`
M![3%FJKEG\2#FG4:Q8DO$_7&Y(255@M[8#ZR$0A#7`#J[([ERC!48*9WO7XO
M3JI70@3,PZO4GOZ%P_P@TGXP)0UQ"I+^N5HM<[A]VUUZ*#.3E9[8H"H:2$PJ
M"NOK/Y-#/W6'%<R,O:8NX\'@D4[O$+!E!;IX<SZ5T:8:&#CJ]L)(WTN"=4BK
M^?75V@,<9J4/L(HG8`*AN>`NR,VC)-L'\:Y/O(-T(%;93#@V!-XA**)J>GCJ
M]`XYT+1)NW'TBYH``?+>/L/W2H@FA%`[`P["()'^3K3=""9@)W!2$HF4D'H3
M"@C$$ZK!VK?[5KD\4:LX4-H+*W"DM]<M3<')N*UKZLT!.!WE]OOD>&RQZ>1X
M&U)_W.O!%AJKN!O/)%L#J*M8P0W%="AA^5&Y%"ESHYL6>Z&QN`,V0,(?)6A@
MKY\R*G#`T:8F*G^A*"P\37'A:FWHOCMT\,'9=),6W3A%T<&KG_@Y3^N5JF-)
MKX`<[8E!Z`C%#(C^YEODL?M7*];!-+\1G(`#F$B\9WAR!J?1P_BRO5]F"1R]
M2-!83&B,</WC!D1303KT"!T*\5CF8J:2/3B5QH-;"$)9W9>1ZSC@2';Z@'H/
MBV.`"4]DMK-QAO<8M5<&>`>>&1J>4/Z![2`S>`>!.B@+$X/2%&>B)+JI)Q.@
MV#@18X!H$?_UP][P>`=3<K^VE,PSMRR+K<!,R\^?4V#A(:B&AD@?ER3&$F1(
MQ(GC<56.,<0:AEGM=87AP>3!&0SY+U8X3HEPG+TXQ+=`]$20^JM'44VJ`2!1
MV&BH-2L*$101'091;`UBC,@I"6=QD',X;<\`3,H6<(!V8;*!7!`/F*83[3HW
M,,@!HK1*$=[9Z#".(_[,(!CD'6=QEA7^8&\`A&1`^_\J#KC_@V10#Q;L6`$3
MK%;H%EVO[J%T7$T`,:"FQ`P!`(BSB[>AF5E,$O!`%E`$*!E-W#QQB):TPC/O
M^<X_"A"4WH6:7`Z`W,IF0J[PM`US3[TU]R4<@HA0R-6&2Q?_C1`Y8,5!OEMF
M9,)SADM[:O!1;47_C;;R66!*PO]JJ@2'S#-,1Y1//_6`'#]VT"V;,>KM*]+!
MO"@U'Y8\Q3"6'GI2P53.+;K,$E0F1%4,JDKE?_!K,%,X$CKY`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,Q+G!N9P``````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V-C$`
M,3`U,34T,S$P-C8`,#(U,34U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```%0TE$0518P]67[4];=13']Q<:WQA?:+)7OE%?+)K%
M:$QFW+)I1F)<AH*ZS6G9&`XVVC';TL(HT"'EJ;!>Z`,/`[LG"'%J<'-T9[_/
M^=U[:<MM`8T:7QP*M_=WSO=\?^=\S^&0B!RJ-OVQOMHOH_'SLOTX;9\69OID
M[M9WXDS?M`^>K"=E.MHN\L="[7G?QW(Q)<YDK]@'6UD9[#PELR,=(L\>V=>^
M^>AU*9<&Q#_BVY.B<$*>KDF-3[X`RHH34W,F>F0,%)7?W9/F1%_KN])Y\K!T
MGWY#,<]GXR+/G];!-"<`PA>U(9K8SA_;CRW`K5R`!P/R;O&6+.4'I92]*=G;
M/0K0?Z&\."2EN:@LY6(R/]XM^:E>V5B\YKU0D<E4AQ*3Z#@NZ9[/92)Q7N)7
M3NQXN)-H5?9)<>1JBZR5AN3/S505DP8@]%X[>T0>+*4T!)[KTC0/GFV(;&]*
M<)J!5O$][<V3=\!0LO6P7U:7AX6Z6)Q/ROW5,;E7C,KSWS)-$)@\.,B!NX4!
M*:^,:`'<'@@I(Z/A%LG/QF0XTFXOHS;'BCZ$G;PI7#XIPO"Y]Y52N'?&NF0F
M?44F1W]09\I'#0+C(!W^0L8CK5*<CLBCM6%Q1B_+M\=>E<AG;TGBXC%%!XKB
M9,A/9<>!J0]R;/_@%0D=?TV->\/93YV?*`+*9"47"2CX^I(EG6Q(QJ^>U,K(
MI]OLQ>O!RD&N<6_[IQT<N)`LF9HK=ZT-F-7BLJSO=E9[V.W:^TLQOPJI"2KQ
MUW+4.FI(HF$?.:0"O<-8+M.KS4P1Y2>Z=SG9R=4H)9)`&2,/1!T,GU&-[#KS
MIC@S/ZJ\JA)4]8.?-Y)+1(KEYT)2EN?Z9&TAH9\4$8[05\J;8+4.C$=4';@/
M2E:8+IXZ;.L_>4$/(CO8C=`)2VQ-,YG&X"6:!NDE5]2%W^D!$-%`I,'HV.W`
ML$_IHE=`QD`2^^JH]D3_N0\U`!I!>]MVKN.`&^!%VM@[B-[3B2""`\BEG8.;
MR3P$)@."_.E*AL3BU'49_OYCY24_F]1`#6:#E3.NK*OE;76`-I`_Z2`T*)8G
M)(TUT2"A==%R6AD]_V4E;/.F4O?53$"D6!AEF,Z9X*;Z[_7@7P10L;<''7#)
M950;E/&=WG!S#3J8H.'4U2=$GY[=7.W3UL.8'GPB-WRGPX\+YXQ>^D$%T0O,
M85.6U"T!Z"(41K<PTY*%.W$U3[;*RR/"'L+88D%B^N@@:2*F>RAR5C/%,1*'
MU&'H)89.L*HA+FQ$=#!2@"`A>SRC:YFAR@H^JQHP&(`;G`-DC2.R5`!FNT(*
MR%(W+CK;K$&Z1IB_43X6+$`@&[`$",1K/'K6*D``B("1DM..9Y2PF^",X`0D
MF`8R"DGV.O3C7UNM0K-=8WIPCD\,#6>V6S%HN)ZY^YNA'GK)G%&$(_YFA200
M6:I<,67<;0,PGIRS10,*\V8`DTE73F0<8=D]TKS"VU24T\DVW9.F^B]H4/20
MHBK-]/H3BFG%=P!!@!%<Q!?])#A`O%V*$:`+F0+8:`3`K0%3M6@G.@K5.(0!
M5)WI1A#N&?/&!@`PWE4`D3:MEX?W,EI'`*"@=92ZZWMC,7?K8'WALDX%;]&[
MWGI$C6WQR_=>UD_F%Z#8(F$)D'.I2WHM6J0F>-$9M(N`?__[V>U`:9B@CZ'X
MTW=>TAG'/P($]XR!"5-<%8PP>6"+X$[FAG8)XF2U(%B4FJN@*T:T)54,"((.
M73JM-!<R82U4NH'?80(6R%C;CL!U=_[79H$W'NEC_:>R:FWT+6?OF'<(NL^9
M\#<FF;?X5MO_<!R_`+R2^CNG?["7`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,S(N<&YG```````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C<T-``Q,#4Q-30S,3`V-@`P,C4Q-C``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```5V241!5%C#
MM9=-;%15%,=?*:V(42'12$*C"7XL6!%#="$+7;!18T+<Z%823-Q@T,1HXDHD
M!%'C`JP"30S8-FB;EM9IA;;HT`\[:8#:BNV4*"W8CU&IM75J6J?']SOWW=?[
MG`\&&A>W[9NY[]QS_^?__Y]33T0\ULS,C/!;'R3NR>RQ$I&$9[[1A_$-TKKO
M`;.]K_.`/OS5N]I\X"[]\?RVN^3@*QM-T$O-]VDP`G>??,QL&ZZY7;JJ[G&.
MM6MI6G@C.=RK7V8RF2#)/ZX*<:7-,^%BGO1\?+?,S<V:#:WUNZ3ZG<WZ!6=)
MHR==1Q^6R<GQ[#0YPEX[.P?)<R]65_P+^7,Z(9*Y*NET.AKA0E^[YI`\4"HU
MN\OEV^.;HQL&ZM>)U'DA(%+KA9N\CL879>IDJ;E!LL0L?W/JU&II/WW"A#G7
M\)0LG?`,#OY*599+3]TCRTARM<S8#AFJWBJ_MSXAX\G=LK"P$(4:4`I>,]_J
M:'I9BL*)NI"K+,W*].1'6FW*/].P2M-+M9>)_-.O56BI>2Z[$LJ`^4^52&??
M+C.PQ9SE0W?XU0KI[W@Z4HPP`%7B1(JA+R0"6'^^360@P-\/"E`Y02(J`:@D
M;-(7!H*5"$I0:P(LS>W/3:;YN5[=6/W6@Z9N=<&J-;6CX-^U[?2W+F8'^.7:
M6'BO2]^?DA_/[Y79B3<T$TXTA3<OGHD=*I[.3?7O%E?&7,L5SBT%N!&)\@;X
MYLPG6NN+]?=+:B(NN(5[%=PB*T#SEZ\;._'9AO[2`]L5=737W;#5H.^S-!Y[
M328GKN4&D1>QFY>>W2A5N\K5%:]\N$K>?&&#3)W=)A@:!V5=`:7].O6#<O[)
M+>NU[DHF2V.?"S"4X-#=LC"2`<Y0N6>-(9#UMX3#0C\@ECS54B:]YXYD!X#?
MI*[,:PLHC`Z2):&;PL;!AL>-N]D`(`Y(>)#:;YVC`[\K:)`@"S!9;/+4O\EX
M^OKU93"@J_:$6F_9PZV8XB:#9.5:&>W>KB6.7.'RR*":">F%7M`6O!A?]@/\
MKN?SBD@EG#(NRM?'MN@IB7UK32:!&@%VZ,A#QGY]GN1D(EF@.*Z"G:%[4#]?
M]:B6+SVR0ZW,M;-(@-Z>9K&9N($Z&Y^1L9&#8>DX"/`*:L&J$-KB$_P].CIR
M\[:.-ES6W5)?*+1HF:R5Q"AZ([C1>UQ+@#J0V+TEGP/AC6Z>-P&L@EM%W7!1
M\&F*.SRP7PN,]'ZJOT.U.=2W4S];F#NN+&%F<8V?9)@A<M4Q9U:X"S>[TKY>
M@]$<<)J6]^]5P\">T#W29?',@/+5>W=J0JB-A`8O?*:MCC@D<!,E6%3!H'<\
M@EZ)S?%;W<H1F=OZ^`XE']ZS206)FD\?VF1<W4$D;P)0'ID#-9+G96ZJS=H>
M&O/".2FTBGCP'`M\V-^+&R!BC)QQ@LN`9O_%3BF,@&]4P`>,0$MG"`W>'NH:
M'79KIX>$DTB0!)>@+<VF]D9,,$P`9E,?1(]K*-'\UL.BOCJLVYN[AV/3V+6U
M;)N$1:/1V#=VQH0&86FR*(=N#=$C=LYB,J%>L!IC!7YZ8@3ZA'-S#K9-QTT@
M:(,T(#P5!(A);'?$SBH!&L:]8"YLAM64(9RS8O\I@[M<'C@=P*+)5/#W_&^%
M94@Y5/_4RF_>\`#IT>AT[+1$=!N^78W+:@!Z#N?_%>1++(8&".B.)`6=D`$P
MW5FJM8-(L!E64U/(!;P<Q.)O9,>A-$U@UPG$1P4UY6LD.1,``>2";+03^<,4
MGC`]^8$.7+0X';J".8G;DR"?M1^MD+'8&FU_O`/D=N;0:6\EO0#6ZECLCXE:
M(O\`N`)*.)Y^YB?+0>[X[-IQKOZPHFY(DT=6Q4S1_TL[1E+Y_O\K=OT+\`K`
M,@5>Q@H`````245.1*Y"8((`````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,RYP;F<`````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-C4P
M`#$P-3$U-#,Q,#8V`#`R-3$U-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!3I)1$%46,/5E]MO&U40QOL?PA.\('A#0KQ4((&0
M*E4JY58J)$HCTJ(&"&YPZ=6Y-78<)PV.F]I*7#O9Q':<JYM>HX@(%%H:=SB_
M.;L;K[-V$A`@'B:[WMTS\\V<;[XY.2(B1QI-_VRL)223Z)*=K8Q]6BD,2G&L
M6YR[-^V#IT]&)#]T3N3W4G"][V-Y84SFIF)B'VP7)!7]1(KIBR+/']O/OCO^
MBJQ74^(O\>UI55@ASVH2\,D+H*S,)=3FLU=E,FY0U']S5YH5`QWO2O2CU^7R
MJ3<5<ZD8%WGQK`FF60$07@1#M+'='SM;%N"V$^+!@%RMWI*E\JB"O7O[J@+T
M/UA?O"75F;@L.W'-@"IM+%[W/JC+U/A%+4PR<D(RU[Z47+)+$M&3NQYFDQU:
M_=@7;\G$E=.R:FK]Q^9X0R4-P'/'7I7K9X_*PZ5Q*4\;#,9S4YKFP?,-D9U-
M"4\SU.J^I_WKY"TP)=E^-"RUY;3`B\7YE#Q8FY3["T/RXM=<&P0F#Q:R8+62
MDGLK::WI[51$*S(1.ZW[F^X[;S<CF&-='U+O^?R`7B%A[X4/M*34WIF\)(7,
M)9F:N*S.M!X!!,8!WK-]9Z4R'9/'-5/-3(]`7LH__/UQ10>*A:F(G\JN`\,/
M<F0[NC]\30UJ5@VB.]%/%0%L6)GK"R%\,V4-FEHA(MDK'RLSRIE.N_&ZL'Z8
M;=S?_FD'AR:2+:;FREYK`Q:47+;J>YT%%[M=^V`IKBRD06E4F+BU/F0=M2RB
MJ3YR"`,]"B-!,]E>W3Y(I%W6Y&0W5Z.41&0Q_0J11GO/:/?_=.9M92CRJDK0
MT`]^WD@N4>'_O8JY+PQ(K934*R3"$?H*O0D6=&`\HNI.[H;V`8NZ/WM#%^9'
MNG0ALH/U1T[:P@::R30&']$TY$VNJ`OW]`"(:"!28'3L=6"J#W71J^790;6'
MU5&)GW]/Y7KXPC&9&>]1C:"];3LWU8`=X$/:F(4T$WI/)U9RUZ24BVEQ57-#
MF\D\!"81OS7V]?LOZY!8-*W]\P\GM"O+Q1$-U&(V6#ECRVACVCI[LT/S)YUR
M?E`5RQ.2UIIHD-"Z:#GB@I[_LM)K\X:I!VHF($(61AFF<R:\J?Y[/?@7`=3M
M[E$.:LEF-!HEXYWN<'L-.IR@X=35)T2?GMU<&]#6H^$Q[I$;WNGP8\-9HYM^
M6$'T`K/8T!+>$H`N0M=0&UJRXB35$!`,&?/.(?-%<YJ:C=E!TD9,]U'D@F9*
M8"8U@3$"8>@$1S7$A>ZD@Y$"!`GIXQE#F!FJ5<%G0P.&`W"#LT#5S62Z,)M0
M"?"N9(DAFPQPP/$;Y?..$$@G`QP0B!<-K0H0`B)DI#C:\8P2@N",HQWW!$,Q
M44BR!T`V\8T^\XX?WA&$=5P!@88SVZT8M#R>N><W4WK*2\;L)X[XS1&2(&2)
M7&$$0_L!X:2C^AXIYS?FS0`FDQXYD7&$9>](\XBWJ2CS(YURIZ]3IH?MP0H]
M1.(15LA%8*85*@T0!!C!17PIMP(R7("<$)(1D.G_R@6PT0J`RP'#6K23(Q&E
M1D^I`,%UNID@D`WSYHUG?(L!'KX\NI]30@(`0NLH=8_OK<7<Y<&3TH^:G7?0
MN]%Q5(W3(J.&*_,+4)1?Y[@!R>!C6S`F"%70@X"__P<YVX'25((^!L2I=UX*
MS#G/&)ADS%91$28/U6+VS>7ZE:2(D]6"<%%JKX*N&-&6L!@`!!WK^5S+S)2&
MJ`3DGDI0!3+6MB-PTY[_M5G@C4?Z6/^I;#@V^N;8/>8;@AYP)OR-2>8=?!OM
M?SB._P2#Z?J/-<BB#0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S,T+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(W-3``,3`U,34T,S$P-C8`,#(U,34W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%>DE$0518
MP[6736Q4513'QX4?+(PA,>I2%KIQP<:/C<N*QHVR48R)2XNX(Y@H*T43#`%#
M##8@")$HV&AI0TFGM68B#.T$G,DPE+9,RP"=TND4+'4RC\ZDZ?1X?^?UOGF/
MF6G'$A=G/MZ[[]YS_N=__N>\D(B$L$*A('R[?Z(;)1=^1_C6.^/]VV3VY@X9
M.-GJ+K\8W2M_[%LOD@RY%_RF'SP_>'R+NVGZS(N2'_E,"O&M,M#YDKLL_>-C
M\M?A)ZK'>K94E-'P,S*63NC-2J7BWIBZ=56RD1U2&GU7G.PGDA]KE\3Y8Y*?
MSKD+>CL_EM2!IT1Z0E*)FDOM(8G]]&QU@=\XPH9=ZX,TB`N+17^5?V['12I9
MF9^?#^Z02I[5P`$`&PBW"A'H`GYP`2!*XQ^*<^-+&4^<%/#4,"-=[\M(]YLR
M%?M4$;\]TJJ_03#2?\P]YUQ7BX:F(9I0"7FPX_DJDH2VE-TLX[^\+'/A5Q7[
MA86%(-2`LF*8C0R4F\()=-57D]"YF?T2/?JT1']^17(=#ZM[T[\_*K*8TBST
MGG@[B"-P@.6-3*=$NW>ZB*3WRKW<:07_[MU9R5V/2NIBM]P<Z9>9F0D)L+A<
M+LOTY'E]&-8X8SN5-:6ICSQCPXGX$671V-#WXCC%^_AH4HS+P.VQ*NF:A9][
M0R<VRI*SISZ92LX%79C8L][=R&>7OWE2\8`5!HS:#28G)SR2#5_NE:NIW1H&
MIW.BFWCWP4A?6_-T/G-J5W-IK&?^PEG3!JN1J.$&&J/)RE#7AN4BG!5_*+;6
M`AMPFLJ)8=N5CL>E/+Q)44<<$"1%W["4;W]=!$[F1+APK?TMK[JMP4[J%D]J
M/""%G`[#8.*=Q"XI9`ZJ^X6YC'Y#8:@,8Z&V)QF6RG_V?2&QW[;+G7-;I7SI
M/4\$,3;S:#QX0.*Q;H\S"@CI@CCIWNUZ.K7@KP/^YZ]\IP^C1WCA>8#N`!(:
M=.W4!UX(Z)/5**M3W,M'7M?LH&6$X@$(70>^7E?5KF1M,5$/$X,MFN(`B)G,
MJ(H)7MAJ]"JRIUJ)Z!UI]1/,E\9%Z?OV.;G>]HC<^^&A0"7R/W7X!>4%/*G+
M1+S0BBM^KG*&PK(A#]+,R`I2YI>SP`:DQGK"1F#"1A<,>>`'*;0'`=Z*M6"K
M$(F#9/;!_UR-L-,VB#65\VI&R\0>9(^F%X*;57(K"5`'$ONCM)6Q6N0-'4`J
MB"JHAHN"3I-<2HX$4QW(#@UO-+Y-KRT4CRA+J!*_\.,,?:]>'NMZA1-$QN:0
M'D&@NS*?46V9_>N4V];XS\3`?9[1:C-TAGWLP_"``TT@L*@B`=1(&(>C@4P_
M",WPV:]4E1C3Z-2("NNL<0W9HR0PA`?Z<YT4HF!^+0TXP`T@0G"!$.6F#%3A
MC$0R82&35BJ9MNS$Y4RWZ1B!X91UA*A)G?TFM?SV<R3@`!<1\'SVD$9[*;Q;
M)10I9;2PIH<N:[7*+;^-Y-K[K`<I$*`),`Z"&GNC_9SER3%PLXB&0-28A9O#
M%7*S(4T!(UIKD`[C=_'6/F\-AX$`#I`*=<8,_:B25HXY`S0"<HZ1(R"$U;P=
M#!U_329/;U*C#T"N7/R-%8UU&,J-CM)?Z;/LR=X@T)"$P(+GM@)@O*?LOA9A
MS?8:[[^O==@.P)L)Y4K4Y=+?*Y<AZ=#Z-W,(T!(1I54S[/4TL.7[6I;F<+H)
MY<M>O/!`P/M']88*Q7!$5/0P-N(-CDUQIIX.T&VY#_2,L+0PGJ>!<GC32J@C
MO*E_2E&]-<,4392Q'RAI<4ZR1?,,O$2.@PQBW"-UO*7P#)`3""GU3[1KZ@6P
MUAT99]V9PAP`N8@2MNLUXRQ#3KW#*/%Z_>&!NB$J1W3-3-'_2SNF;!N]_S5K
M_P*:/E,\&85R_`````!)14Y$KD)@@@``````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S4N<&YG````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0T
M-0`Q,#4Q-30S,3`V-@`P,C4Q-C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8`
M``$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P```2W241!5%C#U9=O:-5E%,<7],+>]+("$X*R7HB^
ML!<2O5@1Q408PL196A"ZFERRV9S&6#3GG%MZT6VNENVF;2E=-]<<=\Q[=1)M
M#OPSR]I"HPFVJ"[=UJ#!4!G?_!QYMGN]OWOUWK#PQ=GS_)[[/.><YYSS_9YG
M.9)RXL7^U#?LU84??M34U-3-5=\[%:K;W:R9'6-CO^CJ7_?-+B3IN#AZ10</
M=\[N:#O2I?>V^V\N7+MV73T](6W;%TS6<>[;$7%\=.PWM7>%$C<\F_NB=OB;
M="04$?,$H]/3TYH[[W$M6KQ$S[^0IP6+GK8QR43IQM?EZ78ZF9F,C`QK:/BB
M1BZ-VGBBKR_1!%[S0^1DOPA5D@:"T7WLN$JV5&EB8B)Q0^&:(BU=_HHJ:_:(
MR'.;A`TL<+7Y3RTTR<W+U^&.CED??"?ZA9P=?$!%Q<4S/R;X<.',$TI[S6S%
M<Y&$NL3^_&O48A>*?&7N%:Q<K?+R*L5B,>^*8@/A.CEX1BW!+RWY''ZM:(.B
MT6CZ5'Y^**CRK;6J_RA@(V'=U?B)7)CW'VA-KX`08XD#VSYH-'>IY.(-FTTA
MLN297*54T-D>UO;Z1KO_3Z.7M?_00D-/066U99]J2.G!P<^Z5+;W0_T9&U<@
M$+"#:U:_I"V?;A*%Z'7X[J7Q_U<`MDZ=_\X*"($E*"IJ@]_BZR'I,+DF"[";
MJT3FI66;K1)),8664@%%!*JQ/'!ZR$:LH@"Z3'L%Z`E.I'218$>/'4:P?ML8
M-.UKL3+F0*`M:#@`#U0BKM]6`?4.>U*^ZWSOJJFEU4;DUA+V5``.4`)Q<9BN
M`*`<F(A#2@7P))O8S&&4K5U?:J!BQ"NXS/%ID@*0]^AC3QKIH0BNAP@A1)H!
M(PKREBWW5D#?*6KZV$B9/'=UAO7'V/UZ+G>>(11T`JJ45VAH:%-K;]@:%PWL
MRJ4Y*BQ<K)VU#RGZ>\Q8-VT0?=T134[^;=8Y!$6W-+<I_]5EYM77@Z?O#,Y8
M[^N=KZ'SYW1OP/D_=V!\?,+0#F`'!DX98)E37\39K1%",D]U@-%_Y0#\`S;A
M(]X`T`L<Y03*@7H0V,/1$0*>P?@NO]^<I%`R<@`*JMGAM]LY`RC&$4>:?'-K
M!&.`JN3M,E555:NNKL;Z(<4%#C)V`!H[VA,VAD(1QERK1QQ;8YS;TO8Y$_\(
MRKH&4`(-T)!)`0;A&>88Y)LYW1_2@@EY'N*`>WMD[0"A=_P#H<'3&,((WP@$
MYXSSLH-V"3_4Z_6.R<@!0EE;WVR"8@QB!`<PBD-T'-Y#T+=C8ECXY74^B\2M
M^<[(`4*/$HRC$$J'YBS/-U+".@XQQSE&]N`,([\3/1S,R`%"#^5CG%#B"+=S
M-T18(]3,W:.-MHEQ1AQ#T(,.'$G%!9Y>0=ZD8.V!+Y2WL<P4`2N^\]]XT^"%
ML545-YZ<@0=5L.(1>P`B%"!G:0[L!?^\]2`H+R=2LAVD`\Y!`J_.]9TA:U<H
MV?K^2DU/YNA8]QQ[1):\];#AGX=EI+=?FX)'[3&151'"8O1$#.*U4TBSA<DJ
M*Q:8<7IEPYYJ:[I$`,*)WYLU"K@%&(]7P+\]SC`A)Z>.Z]O#QVV\Z\T(2`U_
M_\T=$\P]TX[_`8&KF9@2S6#L`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\S-BYP;F<``````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S,V`#$P-3$U-#,Q,#8V`#`R-3$V-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!7!)1$%4
M6,.UETMHG%44Q[\\:C9B2T$1P>)&J]"MCX5NM+BH8G7AVHU@!`N"8"C=J+38
M"$T0:4I(I8C&%!NCC0.IF6([:1Z,#2%MF=`D!-HF)A-J,\:,G8%Q<KR_<^=.
M[F2^&<<4%V>^^SWNN>?Q/_]S)A"1`%E=716N>B/10')?6-$WZ:XZ6;N^7?H_
MV64_'Q_^3&\RE^OM`U_T)]<92/)P@U4ZU?^@2#R0Z]U-,OK=,_8S;L9/;O>.
M=;*>$G;,3,?U93Z?LR]2*W,R>J11)!;('^V-NL;&=#IM/QCH:Y;3'^\1B03Z
MD?0&,G'R*4DF%\O-Y`CG=KD-4L$O9&3HC/R9^E4D/R^93*94P\3X>9D]OD,(
M`,8M?+I3<D/M&V[._="D!A(=O#BROU%^/K';?H`'!$8_B)GP)0+)G@F$3;]$
M3]ESAL[N$^DVRZ@5CAO[_HF-(W!M_>8;,M/SM*R<>UX69S\H&EKT@J!4=;.2
M8&--<2(O:FL^+:GDYYKM:]\\*:E(@^2G]EH';T<T"^=Z]I=G`@3D[WXILYU-
MUF$3E7=??D!RS8'</E`G%U^ID[Y7Z_7^Z)M[RGTD2P`.`"LH#`B/O=4@F<%`
MI:.Y7N\!R_3XVP+42F-@4CSRXW/V(X<JHX2\Z#5J44:DU].MX6#*I./ZX:F6
MQZT;O07IMKE;/ETOPP/-Q=-+%/RV<*OHU]35?IE+M,K:4HM:PHDDWFV,#9ZH
M'<X#/[75EL8P\0MG2PKP=TL*U$>3E<F^7;*\."2PA>]*:!"!K-+)WU>TE/Z:
M?$FC#AI)KUJ32N@UN;00'D2J"@@GCC9*]G"=ID^KW,B=CL?TV=I'.Z3,!2H-
M[LK.OJ:;R7VVI5[.'[I/JQ\(`V>NEPTB9V82Y19@6N^'C<7"ASJ@$)")$K@&
MA4`Z?JFK7`$D0/$H\F(6_Q>Z'E(%K@90T/9^DV4WIP#>(4B4;8D"0_YT!<IX
M87";\M;:5X$&EE@1]-3*RD8P@&OK.X]N<)<KI$2AL$R!73NV4^9']VJ*2UP@
M*)#)U-EGY=L#VZP5T<+&J-V,8OANK.<1\5DJ\,$!UT(H^+JY&FD6F`].0I&(
M%50<KA`\ZIY&R$:P08JA,I_.2A3$QR+%IN84L1'7*&V7.@XB>%5KP54AV(`G
M6,_?FO[OM*Y$ZQ7.EOI"-:%E(O>BH^8/B1N]Q\\Z`$9\+UD3PG_SO*(!4`5>
M^6R(,GB:Y))0$DSI03M4"6V&9_0U4*(X-0U2I;"?&2(LCZ%6P2YXAG*4T1QH
M_M'V^W5"@G&T_Q7HBC7D00U0TC<NO"@R\KK<B!S27LD[UC6G0,-G"@8(,ZMP
MX-)QRU3P`50'K?',K;G2M5TG1]P][Y8/[BY)8:@!0!Z/"34E3T$6O>TM4(*A
M!D@9BH0V4,Z:*V2FSPQQ\ZSKO8>+ZZ\[]JGN*Y/#4CT"AJC()V%$@2-X=SC\
M1!2@6*C5K;ER$"DB:CR#W]T:S/@D6#2`L``0BIZ0XSW4B^"1AMX94!A7H.C.
M@PT:)=88X@")^%CAGF_11Y-U_1&@E]"Y&_'HPJ`:8L4`'=']",0W4;TO<8^]
MS1Z,AU/A4W2BVQ^QRU(`^&`OD.L\P8C-&-!(Q#QC8IM:A]<!7#3Q.IOYO3H(
MB8#6O\D5-4WSP@@:74F+B520PL%XSN$(Y:NZ#`<`P,VC>D6&8CBZ>ZE!<TLZ
M[EQ\0172HD@+AQ`9A#73)^]IFLQ"^G_,1`6<5&HDH080`<H%1M,!"C8SG)!*
MMNDL0&DR=&&0_K\Q8<=`_@;PCM3!ENPAY#@"\/R)=DN]`-2J$C,F:CF9`\`*
M4;HZT6V?&6,9<L(F8L`7UA_NJ1O2Y/&NEBGZ?VG'>.7/N5N1?P`F#Y\BR6S/
M&@````!)14Y$KD)@@@``````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,W+G!N9P``````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S
M,C(`,3`U,34T,S$P-C8`,#(U,34U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&
M```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E
M($EM86=E4F5A9'EQR64\```$9$E$0518P]V7<6C491C'!_XA8?XC_>$_1@0J
M!(FAK<16V!!"&S34_E`H!C41$@J[9.YFSO.J3<=Q:,/FTC6WI6UI7:QY0VHF
M%S57RYW-Q=QP-1IU8+#58+#Q;9]'WGFWZ[Q=FP;]\>Q][]W[/N_S/L_S_3[/
M+TM25KS8G^'A85WN[E55U;&;JZ\5[5-E=9VF=B!_QN8E+B3HZ.D;4.7[M;=V
MO%?3H#=*_+<6PN&P$HXXN7'C#T7:.]1V,:*QL;'$2]8\D:N#P2J=;0Z+>8*&
MT=%1+;E_J98N?TCY6[8J>\U36IV]-MG,O=[M&A\?5Y+9MY.$'^>_:!-RZ?O.
MY%>TMD7T7;1'%[]NE]?K55=7--&&ZI,?V1-W%?F3;=CE\6K+UI?LF=L*7M&3
M3S^3>,6*1QY3O"1M<'*]9[Y2OH+X3??!C/R0D9^<U#>>54=7M_I^&3(A/\@Q
MUNH;0PH$@LG!=O)R8:&:/FE6YY6K.G6FQ0Z;^R8]E=8"T@EWOAVHU/ZW*E1<
M6F'S@AT>Y6UZ,;T"LHC-Q")P](0I*]Y_2#M>W6,9751:KNKCM:F3J:RL3#S!
MX_$8IC9L?%9Y&Q?8G/0X?.1=F[OWIW0BP"2FH5!(OP_,4\91N!+MU*S"..L\
MF!,%G9>CQ@X`$(R1"WU]O9J8F+@]I(>&AO1EI,,RCRP<^/4W=??V*]+199E(
M)%"84@$)Q`$4?/O#CY:1*"2\/M\!BPQ12JG@TY;SJFEHM(/,4<08SX8IGQ"+
MQ2R%(3\H!)XY>KQ!15Z?^2*M`L@0!27^0]KY^C[Y#AZQD53.S5V?7L'N-]\Q
MT(`'&!T!4&`"2:L@+_]YVPCF4<+-6`&X`-7Z#9M3,Q)D]\"#R_3PBI7&ZW`]
MZ(0`.<C_^<TE_ZA@<'#04$BX'/I`8OYSZP1*B3],-#T:*3,Q'+I7R+G/BS-'
M8S"PW0[7U6R:5/!!9@I:6PK5_M4]FBFDDQ9&1D9$0MTU./_G?'+7#*#>@U$8
M`@'DT9_ZK6XQ(O&%T/4*U#@8!"Q#5?_*@-J3=5-*$2YW%\-W"&LP$!>"1JM(
MDZ!A=-B`4#/ND0`/M1#%"%QY]5J_D2L\Z;P`<T$!4"$OIG-#IC-X1A[@,&T?
M?2?NQXUP*RT#PH70):TL%R.\'@/F)`>H`'`178)[':W&X:H3=C'K\';PV(=&
MNQ`@O(779FT`;J<=X1+X'2_0FC#W%/NMG70>@'6A<5B7$:]14&=E`$IX#<I1
MC&OQ`"%PA8:&%Z/XS8@',-K5#RI9?!LT8P/(>KX'7"G@5:Y0.3=C((;M]9?K
M0'G`#.+3!L%#C.Q#SZG339JQ`<`$]P,?:A/?']2I[.Q'K:SFY.1,K2]>O&A*
M^#_KB-N',"<G0$1&(<!UM!_P.K6.WC>^VEQH76B-(U7GXZ:;%8<SU()X%,TI
M%:/PLS,KI;^R%*Q8I9(]C]O\7/,VW5$JQGVGZPO$EP["Y=!J+';="C8,=T<-
M^/G::GUSX3[Y2E^P</ROJN'?,7>6M)5#!3,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X
M,S(O,S@N<&YG```````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q,P`Q,#4Q-30S,3`V-@`P,C4Q-38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8
M,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```1=241!
M5%C#Q9=;;,MQ%,>7>/"`2#QY$2)!(B$$0V(1)/.P$#/!XDZ,N#RX%+.2T;G,
MT-1=D8T9QMPJFZV$(167R5BQB8V-Q4(3DHTE2[8</D?^U:ZZMFP\G/Y__?U_
MOW,_WW/^42(2Y4OZ4U]?+\]>OA:[W?YS=U5RJAP\GBW>$]!73R?_#3\>%54U
M<O3$R5\G#F>>E76;MOW:<#J=XG?%H,^?OXCK48D4WW-)4U.3OY#18R9(ALTN
ME_.+A+4?A\;&1NG5NY_T&S!0IDY+E.C18V78B#&!:FXV+Y'FYF8)4+LM\OMS
MH]@E-VX5R^,GI8%6\/*)NUSNW7\D9K-9RLK<_CH<.W5>332EI`7JL,9DENES
MEJJ9LQ:ND+'C)_J+&#QTI/A2P`&#JBLZ2U`KB%]K'X3EAXC\9%!V[F4I*7LA
M5>_KE,@/<HR],Q<<8K7:`H-MT.*D),F[DB^ESRODW*4"O8S[EJ_:*"$U()UP
MYXZ]AR1U^VY)V9JAZT7+ULFDA#FA&9!%'"86UB-9R@PF2">C6=LS<X(G4WIZ
MNF""R632FHJ-C95)<5UT37KL/W!0UX;]09U(81)3A\,AGVHZ2<11>.XN;?-2
MQ^=!NS`H?>96=*``J3%RH;*J2EI:6MHNZ;JZ.KGM*M',(PMK/GR4EZ_?B*ND
M3#.12,`P*`,2B`LP>/#TA68D#`FOQ9*FD2%*01E<O7Y3LG+.ZT76,.)96%04
M.A,]'H^F,.`'A(`SX&JRV:*^",D`,(0!M')MJE@R#NB3]/9%D:`,UF_>J47#
M!30@[\G_A)F+E$(RF!@W50N(FH<)A!84%XQX'Y0!8`>^#QH\1'&==71TM*K.
M1=Y3K9.G3/M]'M36UFH5$BZC^JC$^"GCA"HE_B!1ZV@$S<0B1U>!"@M2(J]&
MFW6)7CZ=E?"#P<G(&#BO)\G#N]TEW)(.V&AH:!`2ZI^5\W_'DW^F`/V>&@52
M0`F*W/WJC?8MT(.UT0C+*ZN]LP(]#@2AEH&J/U+@5/9I%013".$(02AX![$'
M`B$P<?8\+1Z*AJ=1&P!JQ#,2Q</8!V,(:PT+P4G#"R`7$``48C&3&]0:P2/R
M`)<9^U``]^-&L)61`4(@@,4HRSR"\.F)\U2!=LD!.@!8M.]HI@I#"*,&_\%I
MI@=0TW;LK!=V<3E>^VL%L)IQ!"$@*58FIZ;KFCF3<1*%\`"C2US\0D5=X!RB
MH?Z5`K@>:V`.Q$.XF!`8C6;UAC15BO\HA@=0FMX1/V.^=C+?,2AL!<AZO@>,
M5@`SHU$9;F8/B^E^:;NLJBB?-A`>XLDY^)S+S9.P%:!,4(#+]":^/_KT[:^]
MB6$O)B;&N]^S9P\O\9Y]",4Y!W&'G*`B(@H!KF/\`-?I=<R^OMWFCK.;#HYT
MG8MY/SL.=^@%OE74KE`,PVN7AHA\BQ+;GF&R:>,H71?FSPH[Z_](`=R7F[-`
M^-*!$`ZL>CS5VK#?OBWO6`7>50[7'FW9,E?#\5^:44?1=Q@UEHTW7)8S````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S.2YP;F<`````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M-#8S`#$P-3$U-#,Q,#8V`#`R-3$V-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````(````"`(
M!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B
M92!);6%G95)E861Y<<EE/```!,5)1$%46,/ME\MOS%$4Q_L72"0V%A*)2,0"
M"PNQ($$B&F)!/(J@\2AMDTG'8"BC1@GC$2;JT5!%-$T]HJ/H4]IIJZ,Z-9@6
M$UUX1,*F"4D737/T<R;W9WZFE2&(8''-Z?F=>^YY?L^1)B)IB4?_J:JNETL5
ME>+8NC/.]1X]*SY_L:S<Z(PS?,&P]/;VRJ9'+^WW+1U7`]5RYL(54<:D:3-E
M^MS%LF#Y!DE?M%S2-CM<LJXL(,'F%K&N)!X$DG1B3_FU2KG;T"(E93>DIZ='
M[<QU%\:E_%5U8H2RFSIEI=<GH5!(/G[ZE&SFD&:G+.`OOBC#"F!<\:4*=0^_
M;0+<)#I+UV:+YZ!?'C_MDINW:[_$X?"I4OT($T$3N7"X,ZZFKC$H>8UA>?WF
MC3)Q-?/@B;B&W:T1&1@8D*RL+!4@1:2JIJ96OM_-'SE#,DG#B=,7I+TS(D^C
M4<V?I\`K*2G(<>[0I%?5-LG)\V72T!S2>MR8YU&:B/7U]4F2`JJ#@]"-._=D
M@],KUV[>TIA'GG1+46FY5L^.PF-"7@@SEEH*SH4>RX3)4[62EN7ODS'CQFM$
M%R]9HG16]+7^(@--WBP+2`.7<MJZQ.?SR2[_:<V;.W^WK"Z]+B5U08T%G4#I
M1B(1NPLH,`S\HXX3XQ*+Q:R_:89?G\8_1P%]3O%_MP)GOE?H(")/-0)J[S]\
M2*T2,W.W:T&A@`X'*JE*"H<:^*:":%>WUKVY;$J9HJ$Z430D\'%H'A"!,N42
MT)'MVJN_#SO""H8HX&"AK1+1NK7`IT)8P,O4?:C]H3Q__D)?!^0!9Q3@)J!M
M*<!T(L[KO(J_*,0-8![>[(49RH>F8^D+FPN9@<$.=.1IH-;7W%?,&CUFK*SQ
MGY=IL^;IBPN]1]3TN>GI"E\V!30.S=0QV+X(Q=Z^T]316,[Z!PHHAD;6%D0N
M`H)TY)X[3>IWQO%B%08L#U4$;'12%FA9D)1.I&4OMW:(V^U6M*V-QA03H&]U
M1I5.4M#?WV\QC6_F\,WP$NF_J)W_+0-H->8_K4>[!5M#VK?T,3RS^OQT`VA5
M^I<^9]:Q##'G6"4`$/YN:6M7%'+D']"VI7&^KK@?,L#@(P]PF%"`+-[#-X!#
M),`/Y!F^@`\=#01@8,H&T(R`TN4K90*RLR;P$-ZBB-4`Y:P*'&B\YC$>Q\CH
MLY@B(T:9^Z0(?0!9XMBU/0[NX@7A)<>ZHPQ.!!XUBH%3/`09V5G@$1$>)%70
M'`Q&EY$A2NC%2,#1C"B;`8`<%["8Q[F((0P%O.0RA_"37QXE)>P_\(B<B09U
MP&$N8`AS$3[&8X#93FP&@'<8L.IVL^(]9T;.-OT=,7*43)F_5"$>&C[0;VB4
M\@T9^!SHB7/2+1E#`\I@[Y`&@.R@.E5L1@+>LFNM.')*7"Z7E#2&Q#'8>@`V
MW\@IZ2NL#NHL`K"I(;SDP&>OAH_<L$48?O5.YQ'6L2TRY+A$_C`$94P*'BDJ
M*M+I8#9(6A!#P`*60<-G3!D^>H;M`A['>Z8E!><)U.O@HY)1QCPOOUNGJRET
M92"@LX_*AN8NJRV&<7>+]X!BAN&SM29.K20#"%-NP7[K?Q<F)0Q24D)(48`W
M)G_F>!K:=(Z2DL1ONVI:+7[*B]G_8?2[SV=A5:K<*A;`+P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S0P+G!N9P``````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-3<`,3`U,34T,S$P-C8`,#(U,38P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/
M6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$P4E$
M0518P^V7W4N3<13'_1^Z[*X@(B*H&XE>($LHQ(O(RJBPPLJ24MC,DI:E94FM
M-\ND,GIQN=@2;5-++)B%ZT6#9<MF9F`OA$'@15T(==KGC-]2MVJ&W507OSU[
MGM]YSOF>M^_Y/4DBDC1\Z<^GSY_E:EV31!^4'3TMP>YNL18?CHB=KJP4N]TN
M#H=CY/O15USU7EF=8XGHN'BM7L[7N"4[WR;[#AV3I&G39TCVYBWB\7B_6_G9
MTI_J*PYQ>5K$7G5)RHZ?E4"P1WSW'DE^87%$ZDR@5TZV=<CVT#OQMOCT?Y;_
MR1A,C(\``/'Y84=GU,6H`&@!1S"6KLV55WU]LLVZ*P*2Z/2\>*6;;.#N@K25
M&DKN54/&\N4R,/!!H^^[VRY/@T'I?OX\HH$8?/GR58K]7;KZ7K\1:XM?QL_-
MWU(P.#@H#J=+/#=O"[5AW;U?$E9`LEM]?G6TWMNBSIIZ*BJKD!G)*1*C(-`5
M5"$LGCA7(R]Z>_5**#L#71K.]@>=*E-YH5:59^7N%)!&-9T[7RW)&9DR;_$R
MF3!QDN9BZJS9FCBNR2EI>DW/R%(Y4D/[1!58W4WR]MU[F;EF@^:,&FZ]TR:I
M!;O4E3G96W7?6=<0ZP(O#*\?$@YL+`P7ME@L,C0T)'\^C7^!`G)/#]*<M!OY
M3E@!9>MLN*7=31-37+7N&UH?\12-N+$?/R7W.P):OE@G_]!JCG6OE%=42]K*
MC=K/,0K(+4V#Q4MNCQ(@7,RB9.D/E(*&4@:EJ9$H;&J?)D()=4\?P)X@H%=8
MR)D^P:7O$R!L`>TT"U97;<B5_O[76HV\R#[P66:?7HDJ@)*6E%?(Y*G3M!>8
M`-S/GCM?>X#K](7IVDPII4=D46JJ$*\10<P\4:4!I"MQ@1?Q$_KDOKFY6:HJ
M:[6Y8H((,=)`#(>2TE*I>Q:&'@CH?2@4DDV/0]J938&GZE:,`@2PX'*YM66!
M#U<;:R@EH$NJ'?'K@*DYNFT--YIG*!XM]Y=TX[\)`+K977)0:Y2"'LW=XPZ`
M:H+?:$FF"HW!;&/1JG``;,/(HI3'`NBGF_`!?0]'P(D8IZ&@.0C%/(/B>`Z?
M0,#P!'-TXI19>D3X+0#&:^@/AC-,QSF69RS^0Q\0.$P'60$`61:'+:)64%@4
M,T[C`B"OA-)XAZ=P\V675Q7B*88YIQ`9]I2?PPR)IU`M5/,R?*5.```X,UF8
M,@P'CLHQ`"@H#'$`0BE*R#4*4(2W9D`8[L<(?(]AJ,K1T*B@T($<-<$]`'",
M9QQU2`\<.0(`A8-7`$$8$%Q)`\]YD=R:FL`;9/B:`""@V",-R#%P>(?!A->`
M01=7SE4X&+<&G`^#RN+,%CB5\8`29@BYY`RVPMNJ,V:/K43O(6GV;3:;MB>'
M-^[S\BRR[8Q#Y?E/AT#Z',7BU@"#C3,VGT.<U?CF6._KT)P1H8&/@U+JO*Z>
M,FX`"P#R3L<<:&A38^:<1UHR#QZ6LO+R7Q<ARO$<]'CM[^G7PSZ>:BV$_[./
M<3H$8WP0X2D`V,<X^TR>JIHFG8/414)MR%#-V%$DYI/$G%98?)Y9'_=H\5#M
M1(J^)^1$PL@"C$A=N=JHD5N\;KT6:$(`4/JC,)DC]/#<_8HY.48E(O]_&GX#
MGO"_%G7-31T`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#$N<&YG````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C4P,``Q,#4Q-30S,3`V-@`P,C4Q-#8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```"`````@
M"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O
M8F4@26UA9V5296%D>7')93P```32241!5%C#U9?[3Y)A%,?Y)_TW_-7YB\TN
MK-1Y::-%F8F;;DBSM*R&&AG#O$$(FDB)1EGDM%)Z`9WKU.?H@R]RF4U;Q?;X
MP/L^S[E^S_<<'2+BL"_]L[F](P<'!]+8V'CXU.ETRO#PL+C=[L,'/WX<2,F5
M,AGS\76Y_VA:3SE"H9!T=5V7SJZ;DDJECH5.3Q^=L-]?B"]*8N6ME,E\^NR5
M#(X$Q#<2E&]92[#3RN6EI?7ZX2GT>+U>O6EV]"82B5(3<81]:WN[NA\5_6+E
M<CEA=7=W2\4#62LGPX^G9'1L7MS=CXY5I--IB:^DQ2KLZTNL[_=-R$SXS7$<
M7"Z77+I\15PWW'+W;J]<O=HN?K__^(!Q+9E,2GU]O60R&1D='2V-)'ZSD\CF
MYN9R-U%C@F8.GRH.IXY3,1S9K&2VODGVNR6KZ<\2G%E2CV_<&A1\J"H@'`YK
M[B*+:_+BY:(\?#HK=_J>*+`\_7Y-`H+?;6Q):&I63%J+8$BN?M`8^P,1O<#O
MO4)!\OF\!$(+TNFZ)VWM7O%XQU1P:VM'.1ZCT:A,3DZJ):#7?"<-"")'EF65
MP*%$``=.^HCII(9U]'$L+2U5SP*!(LF!0*!8-M>NM0B00@$@J)F%,Z?QWQ"`
MOU^^[N@:>O!0]O?WY=0"8K&8[.SN:@VR8)#VSGYI:FK2%-84,#LWI[3S[N.7
M7^!)*)@00(5#30C:V-@HST*AD->4H7DJDM##H,W00V9S^Y<;!16,2Z03?!0%
M1!96E$]BRVNJE2)RMGB41O;V]M0*W@%SN`>HXU)1`&:_6?^D58<@<`^'XS,%
MQ(76C@'E(MXA"'XN"J"$/1Z/#`P,*%F`//".J?`4A0.[<XGWM(ZR(`X-#6GQ
MD`53WA01IB*,X%&UI!B%90(XR#*DP3X^/JZ]B>SP:6MK4Z&F1DZF48O(1)=E
M"H=>8/J:O1(K`@E.0`OF&L%8PK.CDJZ-1(*$GP22W\8%`F>GZZH"N$Q`V8T%
M-`.L^#?+^:\80':!`F%AU:*+<S&`(J<7T5[X3H>``*C+7:N@O>SVG7M"^S5T
M="X&X.GKE90JHN>QKZ:W9.QY3!NF[WY0(!*X(+K\7NO]PJ4>K7?(!.2=Q/VI
M#8"-\0:2@:&2ZQE5,A==D^=3AY3'N[4/FQ((QI7V(!L,_+3Y53LXSV_>ZBD.
M(S!;30,(,^R%4"AP)K*L\R&AQP@8GLZ.=_`M,RG1\$_,"=6.`J8!(@*E<AY'
MF%/@8OBYH:%12:_,`$"%8A0PFY!C/`G'4^H]5-OG?:9>PLV0/(*A7';.8"C#
M+/2+D7PW/,XSHL3T5W%^0Q!<QK@,J%!L'Y+(ZT5GK_(]AF$L&`$7A'LB&--S
M*.8<RGA&&H@06/'Y1J2NKD['G:H8@.\X`'U#Z?0`C"/$H)^=T@,?L#.L!6]"
M>8`.%@=XW(7-X%9^<]8>^IKS)8,9E]D)E_V_"P0S4--C&)_,.Z)G;Q-T!11C
M`(I-@Z-GU30`#UD(`[UX:&91^T(Y_8MWG,4P<&.?=^D@`),=.;]5AK:)4J."
M0,).9P'9E9H(:2!U++P%G&=F0H"&];`<7K/X;5H_?TSW!CO@!>5FQJ[40W_+
M``2@C#"29X87/#W)_^0<PT@;.4<Y1E0BGS_2#5%V-+LX3)3^BW;\$R/1G%L+
M\Q6\`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\T,BYP;F<``````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#<W`#$P-3$U-#,Q,#8V`#`R-3$V
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC4
M3U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!-%)
M1$%46,/5EUE/DU$0AOLG^17<<*7A!B4*(J`""<1JD45M+"AJ`9="6@@6V4I*
M"]*B14`11)"MU)801Y^!4S[H$H@8L<GAM-]WSJSOO#/81,1F7?IG96U3]O;V
MI+BX>/]I>7FYN-UNL=OM^P]^_MR3(U<R9(R%Y^1IUY">LOG]?JFMK9.:VML2
MB\4.A0X-'9RPWI\(3THD^D$R9+[RCDF;VR?M[@'9V(H+=NXD4E)95;=_"CTN
METMOFAV]D4CDJ(DXPKZZMI;;CZQ^L1*)A+`<#H=D/1#?V9'G+P:ENV=,[(ZN
M0Q4+"PL2BL[+3C*E+Y'RH.VU#`?>'\:AOKY>KEPMD_H&NS0U-4M%Q4WQ>#R'
M!XQK,S,S4E14),O+R]+=W7TTDOC-3B)+2TLSW42-"9HY?*(XG#A.9FUO;\O2
MMPW9BB=D[M-7&1B>4H\;[K0)/N04$`@$-'?CD[/2_S8LG:]&I+'UI0*K^:%'
MPX?@^<55\0^.B$EK&@S1V&=%2(\OH!?XG4S^T(L(K&EX(C=J7-+J\JK@JJI;
MF7@,!H/2W]^OEH!>\YTT((P<D7$K'(X(X,!Q'[&`U+`./K:IJ:G<62!0)-GG
M\Z7+YOKU2@%2*``$>;/PQVD\'P+P=WU]78N_XUFG[.[NRHD%A$(AV=S:DN#T
M)\4"0LA_24F)IC"O@)'14:6=^2\;XO-'T@*H\-?>":FI>RB+BXN964@FDYHR
M+@^.1P0>`VV&'I96ODLJE5+!N$0ZP4=:P/A$5/DD-#VK6F,+*U)>>5]IA(M8
MP3M@CAM`'9?2`JB\]W-+6G4(`O=P.(>YS(6J6TYQMGOU'8+@Y[0`2KBEI46<
M3J>2!<@#[Y@*3U$XL#N7>$_KR`AB1T>'%@]9,.5-$6$JP@@>54N*49@A@(,L
M0QKLO;V]VIO(#I_JZFH5:FKD>!JUB$QT6:9PZ`6FKUDK,2N0X`2T8*X1C"4\
M.RCI_$@D2/A)(/EM7"!P5KK.*8#+!)3=6%!86*A6G,]R_B<&D%V@0%A8^>CB
M3`R`7NA%WC=!+7B@1I>@U"C#0'A6[C8^%MJOH:,S,0!/WT5CJ@2E*(0H/'UA
M;9CM3P<$(L$H^(]ZOW2E26GK6H5#D7<<]R<V`$;&&T@&AF)'R6CPH_0-[E,>
MSVC_WH&PTAYD@X'0'QV<Y[?OW$L/(S!;7@,(,^T?H;#8\/BTSH>$'B.8M%H>
M]2A5PK>$OK<OJ.Q&M:.`U!`1#.'\ZD9<(P@7P\\7+A8KZ648`*BP&@6,$I`\
MGJ!DYN.R4BUC!5["S;Q#L,$!9S"481;ZQ4B^<Y9H\8PH,?UEG=\0!)<Q+C,@
MH=@Z),'CE\N:E.]-E,!(_#<V3+@YA^*KUYI5&<]8&`!6'K>[I:"@0,>=G!B`
M[S@`?4/I]`",`Q.$EU!3>N`#=H:UX$TH#]#!X@"/N[`9W,IOSEI#GW>^9##C
M,COALOYW@6`&:GH,XY-Y1_2L;8*J03$&H-@T.'I67@/PD(4PT(N'9A:U+I33
MOWC'60P#-]9YEPX",-F1<ZHRM$R4&A4$$G8Z"^G(UD1(`ZECF5'VCYD0H&$]
M+(?7+'Z;UL\?T[W!#DI1;F;L;#WT5`8@`&6$D3PSO.#I<?XGYQA&VL@YRC$B
M&_G\E6Z(LH/9Q6:B]%^TXU][EIPZ2RNLPP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0S+G!N9P``````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(V-#$`,3`U,34T,S$P-C8`,#(U,34V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````@````
M(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D
M;V)E($EM86=E4F5A9'EQR64\```%,TE$0518P\W7[4O65Q@'\/ZYL5<-Q]B;
MUEX5>Q'$6FQK4A2-E13(,#>C4J?NSM)6EBF:.+,[0UPFXCVW#(E%&:W9`Q$2
M]G!MG^-^ZB]UDU@LX?A[.N=Z^%[?ZWO.O28BUBP>Z5]E966TM;7%SIT[Y]X6
M"H5H;FZ.??OVS;UX\>)%&/-+<C8>/WX<EFS?OB-V[]X=:P8&!J*GIR>.U!6B
M5"K-36ML;$RSEM@8'1V-J:FI6!+7T=:S<?WZ]:BHJ$@KAX:&HJ:F)EI.%>=F
MS<[.1EU=73Q[]BQ8>?CP8?3V]L;5JU<73(G[VK5K:=+$Q$3D7/S3F+]Y\N1)
M3$]/Q\"EP:5!UM;6IL"ZNKIBV[;RV+-G3\(M3;A]^W8*Z-&C1RF+WV[<2(%N
MVK1I`8=#AP['X2/?I5$X>BRA=O+DR?D)*7<PNE975R<+@X.#.21#$3LZ.J)8
M+*9X7LXBQ6#X.#P\O'H<5HT3DU`^?OQX@$6\DC'.M'?&9U_L3?53GI&1D4"3
MG`&QGSY].CH[.Z.[NSO6?;`^(0%"X\2)'Z*AH2'*R\M3KA>*%Q<,0&5D=#R!
M;^%;;Z^-3S\O3UAOV+!A_MU[[W\8Z]9OC*\J:J/T\U0>1>%7556E"'2`$('5
MU]<7_?W]B4B0QNY;MVX%:BP!\?GSYVD1>AH9A[#OSIT[*45_N+UL%5!6)+@-
M2#D_??HT[MV[EW`054:`UU+&-\@`P`#W^Q_3\=/E*[$J`P`$$``Q[UCKJ;^(
M=#8.?',PL5"C`K*EI27:V]L3N#D#$%8F[486,<Y05M7(&(H3.C['`P]XSC(/
M)J,Q0[PBD/<447K8F4MA>'@D*O97ICKSNG7KUN0)YS'1,Z\?;_DD-5-?<33.
M]9Y?B(!5>:]]Y]W$]\U;ODS\SX9W>D$/N%+4G#934OS7<89P88'W(FEK.Q/?
MUAQ.5YA0OUP**H#[%EF`Z_8&!N@#?-!9L\W,S*0Y.0.:B#*:(#3/-AK@Z0GH
M9PY@-#DYF>1M"0]:6ULCVRPTE:'>(J#'JF4AX\M*&B,^6L"S!7(6G506A[ZL
M`:'S)`WA9\+A_N;-FZG,F4ZLJ`>,V`3T@F<ID#P;]V(Y?W/:^7\)`//!89<;
M'_\E_OY[?0&@CH/!A8&Q5&2DOG]_8="MGA^O)/G)Z/;*`>@46Q#&-#4U)1%P
MZD("8D":/*.F:Z9"!`-U-8IV1EGL\VRMN=3(7NFDLV(`HB>L#.MY`3"@&SG5
MXMYQRKA`.3/?X)2N9E?SL5BYRLK*8FQL;.4VX-@.3]7I*#E4;PZA(GL[/H?U
M]?4I8PUJ+OTQ+PN4'GNV$_A&@TEHV]G!C#?Y`)#JUXG).'"PD)2/45%S2J/T
MYL:/-J<LO9>A.9X%[A[,3KJ"=DPQ'WI$T;;T??/YZ#HW%HU-A5CV%`IR<)7&
M)Q,2B"7BVH:.^+JZ-?;N+Z3[*R.E-"<3#)O$Q:%2TGES=NPZF*[6VCPZNB]%
M?_%R6H.H=^_>C16EC(`B(L)DL(+<(MT@0_N%\L@>U*3/Z<X[<ZFU>U!#RG$P
M*ZE2KJBEF?0I!R:#D6.!<");;6:OY0C!&%9SZ'EG<Y,$S54^'+'>/#:4X\&#
M!RMW@2"4`PH9RQGB(/NI!"G!R,X6E)T>M1?GYA!_7!$P#EG_\B^A50D19P:(
M96Y3A`S#63!0XU!`>,&A3/')]U=1PIQQM<,%,,H\ZW<UAI82^`9N]88>;N"*
MP%Y9BK/CLGHRZ)<6=82`3!<'Z5`#'?7V'>3X\&^R_)_N;$X3V5F%%BQ7\S=N
M._X39[1NYG*QC/(`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O-#0N<&YG```````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`S-P`Q,#4Q-30S,3`V-@`P,C4Q
M-3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8
MU$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```6Q
M241!5%C#K9=+;%1E%,?'ADADH4$0$M9N#%5<L$03-\("V?@@-;"QB20L;*($
M<:.)2FS`!SZPE01I(2$AU%(Z";0TME!"0<;2PK2%MO1A'W:F[5C2.DWJM3U\
MOW/]+O?.W+%3PN+TSOWN]SB/__]_OD9$)(+-3$\+3WV)?ORD8!^\NUXBZ7LQ
MZ>SLD!.G&B5^9\"=WM)<*34'"^78_O7N@-_TS]<[G]#U.C!1OT*JHU<ED4Q*
MW^"HF;8P(WN*UDGI^X4/CO7,?"S9_88,]$;UX\+"O/LA_5>=.)41Z>GME:Z>
M(9F:FI)O#U<+SNN$:_5%TE>V4JJ^V2+EG[TJYTY^*D?*OI2*BF/9;G*$#3O;
M!\D1EXW^G^Z71.9'9&YN+KC#=,MSFI;QL@)I.%LIQ!Z8<+OB<9D__YBD4BE-
M"A'@BT[HNK19/B]^2F+M/>H<V6+B'R-)*2TM91M'ZJM>UQ!_^*)8P^3YR;YM
M6B8]HOW,1ODW_KS<^;E0YBZLEE3'-L]1+PJ*(>DZR1EFJ*6KI+R\7/+*$_7"
M:0J*.U3[WB\%LF/K6LV?XL.Y);.3)]UYP0T<#4AF#VE&*'SB1(%B<&)R4HM/
M=O9]N%?(FK\8#SPPX"49-_8OTZ*P@`VNQ+JEZ7*;1.MBFFI2S#>`$LR!V94-
M2!:GLO!4=;/6@T6,\4X1V>SH\7HM9B`ASL1'0M7C7STM"Z<C`0.NY`3H$G)6
M$L<375Y<U+'[Y@%-YCMO/JNYH?`LA"4U-6?RA+.IB(UUT3*&&=G/FR]AUG3N
MO8?8P%1#8S3/_IJ5DAJ_K+_]H9"'K`W(+JH!VGX]O$[^[GA%L]YX_$5QKBX3
M]<;DA.>?8\F0))J/3`3""!>`@N$H#!48OKA)OV<FU2LA!N;15>H.?]$P0)0<
M=T&D?#`ES=(4I>O%M7HRBY%>D,?""TTW=:/6^*"B#R(U7ZH-`5)WB0P<6JX>
MM%T[[RT"MG8Q925^2-7:^KO+A=O7=PFG(UH_ECRCA(%$/.$!V,<3%F-P!.U"
MW#Q)LCQHJ?O>6P@#.97)A(,7;,88QD9431>/W/U.JGXJ5C:B:WX!9-R^H_<\
M"2&+SH"#,$@D@N)G(N]6G<!)*!(!#OPF%!"(-U0#CV)'5LAL?Y&+$Y^<!22-
MF/D][R1=ZIIZLP!-!Q^V=(-]3>(G60A!'*]]C?WV@@R/#.EO9&S);!SHJ0Z@
M;LD;_*\9AA)68V/#HI1_!`XXFC=_9Z=8%`I(^.6!W\Q=+/(<#CA*:J+R%XK"
M)N)O:7'1:B7T]35Z#T"S89,6W3A%T<&K7_A9#_7"ZACJ%9"#GAR('+$Q#0(X
MOK9IE6(=3/,;PPDT@([$.,V3-307]@'>EOMYEL#1BP3$HD-S"#J!/D(LGG`$
MAB(\:`5&3R5[]EK`&H)05?=E)(<#CDR.GE;O47%[&R4RRVR<89Q#T5G*A.Z@
M,[<Z^Y6+J!U*B.Y@2`=EH6-0FLQ,A**;>M(!K+C;PXF8*&W$]G"$S=[P&$,I
M[?V:[[QSRX(U.!WH:>F9(046'H)J9(CT<4FB+2&&1-S1WJ*;<QAF[STHJ[VN
MT#SH/#C#063)WH7(C'6<N3C$MT#T1#`VW*"H)M4`D'02#4]DG2<;8FQ$=!S(
MQO9`#B-R2L):'&0=3MLUT#?03RQ=Z&S0"\0#IM%XK?8-#J3.1&DWQ1CC0$IC
M^Z\_,Q@',L9:>UO$`>9F:3"&(^"`^S](IM5:+%">3(,M/`$K1NFXFI!%0$V)
M:0(`T'\ER4U#T[/H)."!+,`&0$EKXN:)0_8P*,D[XWQ/U&Z05'2UKL<)-,`V
ME+R4D"L\M*'OZ3\6YKZ$0PC1E:.K]&I#[^2_$2('K#C(=ZN,='C6<&D?:]NJ
M5/3?:)?>"PPU]3]5-L$A\X[2$>7;VU^6]AON59)#O7D9>]`;POK#PW=#<QC]
M`3#E<XM^].WXOZ@R0;54NP]/!#!]NSW/*@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S0U+G!N9P``````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(Q,C0`,3`U,34T,S$P-C8`,#(U,34T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```#YDE$0518
MA:67NX]-412'[S^#_T%!K95(]!I*E001G4*H)"021D$QF7@4%"(F,BC,A&0(
M,A//D&@4,X50L/GV]9U9>Y]]S[W)%/N>=?99C]]:>SWV':641G'EG[>O'Z07
MRS?SRAOW[B^F,V?/I?E;=[<VKEXZG:[<6"CE.QV?/BYECC^_?Z31UR^?T\7+
M<VGUY:N4?KU+HPM/5O/7W7OVIDZ$!3NB0.`)=\?`1SX`@W7PT)'T^.&U]'/C
MV5@:.,=/GLH?L04#[_OV'Q@S``+;?(!&`+K`,&EUQ/=OBQG'A_65_`37%L,_
MQ"!W&<@B,M@&Y*.EI]F#._/GQY&"@<`0X,-'3V1PRRO/LQ>987-C,ZVMK>>/
MAA7W"B_X@)N$EW/#1,>@_]C7?[3TW(P+VRQ"C?LL/'6_&2<%$6J%!%A=>/XK
MZV4#PB8D80(V<*&C(J)69(L*8"`(Q)JD,#G8,\0&212=`@*D1<+.$R'.A'<5
M\0YO+Z$18-,SVKEC5WZB!)I]:'DPUBG@L-',D6')]&4/9ES#;V@RAG,O3@%H
M*($V`62RJ*5C#LQ4#S/72YT/1-DDXGCCV0\K"+5%3M@E>+Y_<WLX$Q56B$42
MQ2RLE12P+?MHU<SD%*!C$I4(@G68B+PGH'53.:+H*5"0;.-)6M,=6`C'=M)3
M`$R2AV3BB0*>9""*R4(0-A4`S]8+,Q9YDE@HHA[L6^P7"H`K9*W:W"PD7+'0
M4)+'A0KLZRQHA$EEF.V0%I,ES7[A`A_KRH/FR3O^6XFL(@^L.BSB"O2QZPLY
M6%B'MDM!6WB=`OS!=P3QU<9"23-+@`R-6U9FIX!HVK9M^C!#LP_M4+1'%`J`
M'>L=%X#H,1$#:7O%MOJ!LV':VE8_F630017G3FO5/6@(T%3C-K;:B)TB7JQ:
M>Q3^$)!!K^OFV`)!:CHXZ04L&D8$PGL<[X,`ZG!'KP1A36@L7@-B\XT`X&^!
MF!IV%9#I+++<'F.?H4QL4O$:$9>1FAD`9X>@73$V/)Y>-[WVL;Q^V7:0C8-`
M`.V)4@'0.(;LLG89`=AY-4P4H.'S#L"><]';]40`-!`]UD#=ZE7J1=.+ES/#
M9438%S1\_HWH'8%]4J5.-<>$@PHE\'@#-`\$ZS`S(C5HC@;99@[`B'"\*?+N
M2&'QKE=Q=CL]Y7,D13!>#AV&S2.(_VD8/1IUWV&!(OFDV?=VJJR3R"$[V(@(
MC>5DR`FQBGFG/$THO.=,V7-B&4&`^>^%??8&6S'&0>UY0YO5*",Z[FM$'H\+
M@Y''_3C`FP"BEYY/5(8'7FJ@X2>3><*C+#*3]J<.HTG#`N$A#Y`!=&T$F=9^
MO?X"S>DYVPF\&UL`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#8N<&YG````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$U
M-@`Q,#4Q-30S,3`V-@`P,C4Q-C(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8`
M``$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P```0`241!5%B%I9<]:Q5!%(;S.ZVU\@?8"H)@%Q"K
M-%9I8A%0JQ`43+!0HHU78R$F@E=0B49B2'`=]YFYS^[9CWMO@L5A=W;.QWL^
M9W8EI;22J?J9>.;%_MOM^E$EGOG#WNM).OYUDCX>3LN'M;7U=//&M73O[NI,
MOJ_CW?ZG]&!]-?TYV4LKCQX_28AL;;_,8EGAW[,/Z=6+S?3[]#3HJ,T>'NQF
MTSR_3PN4A@$82!_].$[80"UV&H8[MV^EZU>O)&QBBS7(&H:OWXXR;MXW-C:3
MWP.&@J/X4PT9\`F`$IZT#+44H,[.S[,9P#W=NM]Z<?#^8?H\_9*#@7V\R`R`
MW-EYEEV#@6CSQ`.\:;R``1?9P(348"B+*G\D!F!`J.,%(&%B8S*9S(M#FUO<
MQ'5R(K$N[H_$R4#"9%+QF*P;%MXAHM*-8P@V0I0)J2-L1,/(0"A`&4HZN:92
M""-"O*,(OU&P^_Q-3A+[Q``#!*M10*FQ@568$>0IL]^L;-990:Q7JPPFH-HU
M$&OB$M,U&D2@FW@L&UBJA2<(^=;NC:01/T$!&H+'-Q3PCF5B$?G'ZR#VAA1R
MOT1!$9Q;1+,!,K>08")@%I-3PC6*HI*.`H2Q!F.L0-<6458R<ZEC'6&8<B_6
M:^L#1010)="PE&M8;)`%BP=%I,[:0`D(G)L#!0@P+B`4H,PAR#O?$&X5S"J1
M_H9B+UC.-A?DH*<N.@J`B77'+DH@F!5TRMMHY1B9N<"F<&54F,I#`/]M;Y"1
MUDX,8(:1)HK$,/1)(/&?8`_2"#1\@P$!HATC#V'`>`T*"=@P.X^Q@H!6;6?X
M;+)!):K9D5Q@5EEI;/6%S63`2C66#/GM0MWH+"CG0$&E*V-*%LR#Q3."7I!L
M]3ZU<V1\EEP"0-4YJ!P/\RC.H.X<&@*YD.$QH_&R$,=-?^U!.`_(?..S,$>#
MSKA<4?4^%46Q>"EA/[XKPY,^P)$^B*6>(XQ".A6#'K!4)^2![-3R*(P1<1"C
MIPMBP>4$1@0P"'E=<%0Z4YQT_<,[SF#!>$*TQTHU-.YM3:\U2#MY*\`XK>7:
MMHNW"88A@+W7>*HXR[UE-8;QTJF*8@PZ>E'L\<0>"OFN$5/#VHN]([U,GJH9
M\\AZL>H`8)"B!$8,^XYQO3:\,2UZ&\\,9R8@_:8L>_Z2#&H@CCVO@QP#?5*Y
M[QI5)I+79N]K7K,6MB&H8<2(9W#_C%*A_R?Q?FZN(?2P#S]Y7WHU,^\B]9>!
M64#NXB&)(=XQ1!3B+5SC4/RS6'H:25:VD6C#5F:[0P>C@+.W?5+$=(#7HGB&
M7OHL\,8K];TP;0!EKP6]7/=2AE@+=(61`=18M/P!L([^&X!U87&U]3$$&EO0
M?\)%1S'T#TC4ZR"`R",G`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\P+G!N9P```````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#0U`#$P-3$U-#,Q,#8V`#`R-3`W,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!+=)1$%4
M6,/5EU],TU<4QS'9PWQ:]N02,U\FB8G![,^#,3ZPQ;AHIFA"E"GZL`A31P@X
M+%N(?SM$66P"5>:<=((,,OZ#H;!VU;C)2$!$#>"FPV7*LME821-)B!H\^CGF
M0FM_+99E+CP<[OW=WGO.N>>>[_<<$D0D(53T3ZGSJ%R^>EW&QL:>KF9]NDN*
M2[Z6B1W#PW_)_>"LR84('=>'AJ2ZKFER1W5CB^P^X'BZ\.#!0W&WN^6+;VHC
M=?1>&9!?A_Z4&\/_2'U+6_B&I<G+Y:"C3!K;O,(\S.CX^+C,G?>&+'I[L20O
M6R$+%[VC8X2)O!T?B:7;L61B,C`X*'W]O\G@M1LZ>L_^%&X"KPD@/Q"J"`T$
MH_4'G^1^9I=@,!B^(6U3IJQ<NU'V%94(D><V81M8X&J)"Y)4WENY1NH:&B9]
M^,1W7I`+7;,E<]NVB1_#?+C2,U]B7G.Z8KG(@_*PO_]Q4V[][=?8M7G/J7NI
MZ].EH,`N@4#`.J/80+C.=O7(R9IF?7P.IV=DB=_OC_V4-=_52<'^0U)ZS*4C
M83WL/"$FS!65E;$5$.+-F3EZP/[E$7673.9M4(@L7I(L414TU7OD0.F1B?N?
MK$F21Z,)DKJO4%^?;(CJ`>[;CGXE=P,C4EY>I;#;E/Z^Y'^[4TC$$XW-+_`9
M_W\%8*NKKU\3"($E2"YR@]]"\R'B,&_-*P!.#I&)S/-L^9J)/#&\%%4!202J
ML=S9?5%'K*(`NHQY!>@)3B1UD=H&MQY&L#YE#,J.EVL:<\!55:LX``];LVWJ
M^I0*R'?8D_3-R/I<RIXD%"/R;`I;*@`'*(&X.(PR`&7`1!RB*O#Y?+J)S1Q&
MV9;M>0HJ1KR"R]AGJ0#DP>\@$D7,(4((D6+`B()5J]=8*Z#N9)8=5U*&4%J:
M/')G^"5Y-_EU12A5"U!%O8+3626G.CQ:N$B4F]=>EK2TM\3I>%7\MP/*NC&#
MF'7:*Z.C]]0ZAZ!H8)VR^0/UZN>N[N>#,];/M"?*Q;Y>F1EP?N$.C(P$%>T`
MMK/S%P4L<X0XFS5"""^3'6#T7SD`_X!-^(CF`'J!HXQ`.5`/`GO`9>Q!P#,8
M/^QP*`A(E+@<@(**#CKT=L8(BG'$D";?W!K!&*#*S;&)W5XHQ<5%6@])+O;&
M[0`TUNKV*$.1UH#)E'K$L#7&N2UEGS.A3="T<P`ET``%F2?`(#S#'(-\,Z?Z
M0UJ0%^TA#IC>8]H.$'K#/Q`:/(TAC/"-F-;#=';0+N&'>JWZF+@<()0TZ8=*
MCZEB#&($!S"*0U0<"@;T;9@8%J:1(A+/OG=<#J``P3@*H71H3M_YR9.P;GHF
MG&-D#\XP4L6('AU/7`X0>B@?XX22'.!VYH8(:X2:N6G:,(AQ1AQ#<``=C-&X
MP-(KR)LGV%+QO:S885.'@!7?*1]O57AA[,-=&Y3X4]>]I@T@0@)REN+`7O#O
M<KF4H*R<B,IVD`XX!PETG=N;W%JN4+)_[WKM.AOJ7M$F,C=[CN*?QM+;<5[R
M:ENC-I-3.@#!4!,QB-=&(<46)MM=\*8:UUI94JA%EPA`.*%[IXT";@'&0Q7P
M;X]]3Z(:IN?F30W7UWM^U&K_GQ<C(#70?^FY"6;&E./'82:9OY$3:9``````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]S=6YR:7-E+P``````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C8`,#(R,C8T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W-U;G)I<V4O<W5N<FES92YP;F<`````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#4S-@`Q,#4Q-30S,3`V-@`P,C0T-C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!P````-"`,```"-6?Z8````8%!,5$7LL)W]CW5<5"3_^?CP
MPPK_633_<T__]"C\QK?]X]K_X1:?DH#_.A:0?D'_[NN^D'G__S/___\`````
M``````````````````````````````````````````````````";3&N?````
M"7!(67,```!(````2`!&R6L^````I$E$0508TWV041+#(`@%000Q40SWOVPQ
M21L[G>G[0I=5%/Q/8*F1[SVF!=ZU-G-4)X;%5`E*ZM;461U:7:`QQS+Z!9V-
M&CK1<ZQQ-*LX#!LAVO2?@4S"'7M/D3Y<V-RK?J9%AI3SMFVYIQTIVIM<$*3Z
MG@*5,G$"Q]:`+E@1PPM4CHES&@WMO!/4R*GW\(Z9$K#'TVQ"86;$]&;'J2JR
MT-?W_>0%8@\1.PU_F@0`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]S=6YR:7-E+W-U;G-E="YP;F<`````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`U,S``,3`U,34T,S$P-C8`,#(T,S`V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````>
M````#P@#````Q&2/K@```&!03%1%_NWJ^589_V%'_WHD_X-N_SP;;C@@_<W%
M_K2GU;2IBV-+Q3P,NJ*8J8M^_):"TI*"_YDS____````````````````````
M````````````````````````````````````"C*J_P````EP2%ES````2```
M`$@`1LEK/@```)Y)1$%4&-.5D%D.PR`,1&W7"Y`"]?TO6T,6-6T5*?,!EAXS
M`X!?"F[@1NN>Z"\V"63NE$[8>*X.8D[F2>"$`0FFAYK'A.VK&S`,T9@[]&G>
MX[<8H'#U6E2UU.P\TB!]7(TIZR(86O09Z<!".TX,7A7Q,82H.1JD'>'&G'7`
M5R@.E"X,6W>R451PLI4O=7..!XD0MW+0X%BL$=W\\U^]`8P`%O+N'3;C````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M;&%R9V5?;&5F="YP;F<`````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S$W`#$P
M-3$U-#,Q,#8V`#`R,S0Q,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````"P```"$(`P```#A%
MH40````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U
M,```ZF```#J8```7;Y)?Q48```,`4$Q410```/_______P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$C*MP<````#=%).4___`-?*
M#4$````)<$A9<P``"Q,```L3`0":G!@````J241!5"C/8V!"``:\;")(!L)L
M!L)L!BC`PV8@@DV,.42YARA_$4?B#V<`AVL!^=D"F,(`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO;&5F="YP;F<`````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M-S$Q`#$P-3$U-#,Q,#8V`#`R,C(S,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````"P````L(
M`P```)YRAQ0````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\`
M`(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410```/_______P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$C*MP<````#=%).
M4___`-?*#4$````)<$A9<P``"Q,```L3`0":G!@````D241!5!C38V!"``9T
MD@'!9D"P&:``R&9`8B.+HZA',0>5A```*]0`J35R@;X`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO9&]W;BYP;F<`````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-S`V`#$P-3$U-#,Q,#8V`#`R,C(U,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M"P````L(`P```)YRAQ0````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`
M@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410```/______
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$C*MP<`
M```#=%).4___`-?*#4$````)<$A9<P``"Q,```L3`0":G!@````A241!5!C3
M8V!"``8PP<!`/)L!!D#B,"98#92)J1>%A```*]0`J;U8DOT`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?<FEG:'0N<&YG````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q-S$W`#$P-3$U-#,Q,#8V`#`R,S4W-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````"P```"$(`P```#A%H40````$9T%-00``L8Y\^U&3````(&-(4DT`
M`'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410``
M`/_______P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$C*MP<````#=%).4___`-?*#4$````)<$A9<P``"Q,```L3`0":G!@````J
M241!5"C/8V!"``:\;*)(!F+8#'C9#%!`#)N!"#8^<XAQ#]'^(H+$'\X`AVL!
M^9V+B'T`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=7`N<&YG````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q-S$Q`#$P-3$U-#,Q,#8V`#`R,3<R,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````"P````L(`P```)YRAQ0````$9T%-00``L8Y\^U&3````
M(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`
M4$Q410```/_______P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$C*MP<````#=%).4___`-?*#4$````)<$A9<P``"Q,```L3`0":
MG!@````D241!5!A78V!"``9TDH$!0D&88`X#E`GB,,"80`ZZ>J+84```*]0`
MJ;="X4$`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?=7`N<&YG````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S$W`#$P-3$U-#,Q,#8V`#`R,S$P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````(0````L(`P```,8-%`T````$9T%-00``L8Y\
M^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?
MQ48```,`4$Q410```/_______P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$C*MP<````#=%).4___`-?*#4$````)<$A9<P``"Q,`
M``L3`0":G!@````J241!5"C/8V`B!!C0^0P,^%0PP`!V%0RH`%T%`S:`4,&`
M&Y#H#KJIP`H`<:T!^2R^!8``````245.1*Y"8((`````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?9&]W
M;BYP;F<``````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S(U`#$P-3$U-#,Q,#8V
M`#`R,S0R-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(0````L(`P```,8-%`T````$9T%-
M00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8
M```7;Y)?Q48```,`4$Q410```/_______P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$C*MP<````#=%).4___`-?*#4$````)<$A9
M<P``"Q,```L3`0":G!@````P241!5"C/8V1B(``8D57\@S&8!D3%/]S.9(*;
M\0^'-(HM_[!)D^Y2B"(F/"&&%0``X2@)(EX](BD`````245.1*Y"8((`````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO<FEG
M:'0N<&YG````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S$P`#$P-3$U
M-#,Q,#8V`#`R,C0Q,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````"P````L(`P```)YRAQ0`
M```$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```
MZF```#J8```7;Y)?Q48```,`4$Q410```/_______P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$C*MP<````#=%).4___`-?*#4$`
M```)<$A9<P``"Q,```L3`0":G!@````C241!5!C38V!"``9,D@&9S0!F,T`!
M,IL!31Q9/88Y2"0$```KU`"IC'3)$@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R\`````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#8W`#`R,3$T-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+VQI;G5X+F=I9@``````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,V-#``,3`U,34T,S$P-C8`,#(R-S<Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y83P`1P#W
M`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`
M9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`
MS/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S
M,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PS
MF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F
M`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF
M9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F
M_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9
M,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9
MS&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,
M`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,
MF6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,
M____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_
M9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_
MS/___P#__S/__V;__YG__\S____XOR0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````A^00!``#8`"P`````/`!'```(_@"Q"1Q(L*#!@U!6'%S(L*%#A@D!
M2)P(X,##BQ@;LJ#(4:+"C"`Q;NPX<<4*B2%3-B1)T4J@DP!4RB08@.5$*U9,
M`O@X4Z7-DC`ELNB9<N1/DD1#'K69%&3-I4$E0FF*\:E.BB9S1MU)]6)-*ZQ>
MMF1%UDK'K@\#K&!U[5J@FV39LMJ*UF$`L"[G2@QD+6>@L!SK-@P0R,H!L##_
MGES+*K#@A2QP[BRU0H4**ZLF*J;X>.'=N2K^C$HU:M0?%22<L"KEN'-!%@%6
M`<J3JG9M5:/RD%KUI+7K@37_D&J6BAFJ9LB1JU+EQ/=O;!OSC"*.BEERY*E4
M`7+^F\6*T:E0_E6_GDI4;HY#GPO<B&>4\>3A1<D?U7SG8O7K`521GJK9*/E^
M^"%<*55(Y-))^$%W`"FD4"$:@`&24@HTJZBP4V$`!(#?1H'(`LAL>>11!2"E
MD-666?:AI%X``9C"RBJEA/AA*:M`T]8UK!S`D8;=W=5**V2M(N0J;-UXS2PH
M4I3>8[`%4&20+[(BBY%MZ<5=5QP:&5>15!Z9Y$1+HK41%%QV:2:.)(79U$:$
MG>DFCA:>A65-:[UYII5R)@6;1X%0:4V956X)&$D\$F74"G^U8J0U76[Y%RLH
M;J5F44\!\)>=5`JZF(Z<]6046)B:^:=;)2G94P`'U-1GJ&Y:>96*_BK!ME&=
MK+IIEDE132K24ZO6>N9;.@55:$@!S`JHKUH&%56LO"+KIC7*FAH2F[1VJ2BR
MT98T+8L[/>MLDE$->]&LEK;Z;:F=BN01`,?>V*Z=7U[)D%75-NKL6RQEM">N
M[SK;%KY(J4M1O\Y:@^]6,6&4D!-4D*!"OP3[:0TT]2G)8D:!D+(<()<]Z6];
MSX1<L40DL.!=1J6,UHPJ>:A01;LVLKH<RQVIE4=&TL%7A0KU(FM-:31W5,5R
M%UDA"G+6^=<<HOY:8PUIJ>!!`D<JD$(:0_OE(1IQQEPW"I]3^FK-*J6EX@=J
M$ZF0ARKE+20:,TE/9QW<R!5H8,14PEC:_G]X..&W$Z*-)LI"?C0#]^%)6]=?
M*7$"`"JK>O]7VA^!E]8,*JF4<I`HQ1UN..+6!6U@K12:QXQYDAMC#.*JD&(0
MYYZ#3G=V%:]PK9DQMP5-*>V=7IHHJG?]^=4%_?%YXK+W-XJ%)%A1ZRHK]+YZ
M\,P([_DHK@_T=NS)9Y?'$X#<;N=<)+2W.G*KT_VYX:-I+I`?[E6?]/&(US9A
MJ`:?I`+\LC/3N>?^`<1`^">_^76/0;F[4Y)48#K$K>]X_AG%0`#!N?3!S8*@
MBR`52F0F((DE;02<FW&J<[B]$21G7<-@_[K&'!4\X5%D"40@(L(1)Q#P>.*Q
MCC%05Y`\<(XX@?-#6@'3-PJI36TI$K'A*-*'P=)DSR!_P$,>_"`?U%V'?N;I
MVQ&7DIH'':YKS/@/1JI`!2E63F[8$46(&L<1A#FL/:6)6VY40H4ZXJ&*DO.#
M%GER$2E6T3Q_H`)1R.@$/$01#WUS0DI4X"#*_2$/@J3*WYS@0IFH@&%XJ&."
MGA,0```[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]F<F%N8RYJ<&<`````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$R-C<T`#$P-3$U-#,Q,#8V`#`R,C<T-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_V/_@`!!*1DE&``$!```!
M``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q
M008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+C
MY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&
M!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/K+_@Y@TCQ?K7[</_!,\?#B3X;S_$/0
M/A1^UMXB\+:!\4)M4M=!\53VVH?!BWU;P]8WFD3)?V>O7GA:7Q'=Z?>PV>L1
M6,>GW5WJ&EOI\5S<VWY!_LQ?M<?#CQ;^T%\#/C7^W%X%\;_L^?L^?`+QIKW_
M``A7C?1M)U3XT?L_?$O]L*UU+0_!MA%J_P`5_AQX,U71K71?A#IWB34M=\+7
M5KKUWX=NO&\E[J<OB"]B\-G3M3_4K]HW_@C=X%^)7C32/C%\&/VD_P!I#X:_
M&'P#H^M:?\+)_BQ\1M9_:I^&WAI_$'AW4O#_`(EBG\)?M$7/Q$\1-8^,K>^$
M?B"T3QM/80Q1QM9Z9)/;PO7Z<^"_@+X'TC]GOQ!^S1\*;/PUX'\&S?##QG\-
MM'L_#NE+!X:\.7VN:;JFGW^HCP]I=Q';B>'6M7U#5;JRFNX634KJ>1K@WI3S
M?Y2XT\1.%<[JT\?A<)7Q,\7@HY94JU(SRW.,FPM=5X9@XXE4LPP%6%:EB(1P
M\/8XZ5.JL?5IRPM186K6_H_ASPTXFR>EB(YC6H86.`FLPPM.$J6/P&:8J,Z3
MP])T%6P6,IU*52DIUJLJV%BE'"4YQQ%*=:-'\5/@;^S)K?\`P7AL_B+^VM^W
ME^U;\2?V5_\`@F9J'QLL?V<_V5O@3\/O$VG_``ZD^,%[_P`)M;^$/!7BSQU<
M^*+3Q=X'37=;^*.N>%M"TV[U;2?&6KZK\1;;Q'X/T-_"&A^'?#EYK/-_\%-?
M^#?_`."O_!)KX':U^W%^SE8:O^UY\%OA!I=S!\5_V5OVOM4UCQ3HT.M?$);G
MX<^'_CSX4OO@SH_P\TG4[WX?ZWXE\(OXA\)^-/"S:?\`\(/;^+=<L?&^A^([
M3PU>:'];?L+_`+:'[$O[/W[*?P=_X)H_\%G/A?>?`/Q5^PS\74U[X"_$SXF>
M$?BW+\!/CUK?P1^(&IZ[X%^,_P`'?B#H_AZS^UZGHEUXC9;OPYJ?F:'JV@7T
M'GK>VNM:UX1T32_X*]_\%R_@#^V?\)]1_P"":O\`P3<T/QO^V1\6OVJ7TOP;
MXXUOX=>$[S3O"NC?!F8G6/B,O@WQ/XO;2%?Q_+I6G-I]IKNH^&-3^'O@RS3Q
M'KGBK58+G1+73;S^B,MP/#F#X<H8?+EA:'#\<%>%;"XGV%%X>-&]7$RQN'G1
MY*KIPE.MC/:PJW4YU*J=V?A>.Q><8C.:U;&>VJ9K+%/GIUZ/MJBJRJKDH+#5
MHU>:"G*,:6&Y)QLXQC!W2?W%_P`$W_\`@D1_P1Z^`_AGXM_\$^KWP5\(/VN_
MVJOA3X,^%OBC]L;Q=\5/APNM^)[F\^,.EW7B7P6_AVYU[3[S2O!'@^?3M)^U
M>%_"?@#7[C4="T*71[_QEJFJ>)O$-YKFLVOV0M!^%G_!)S_@IM^T]^Q'X&-O
M\#/^">/Q$_8XLO\`@H3X=NOBGX[L+3X8?!KXO^'?B[X0^`?QCL_"7COQO/%J
M6D>#/%6C^)OACJ.L:1XQ\8ZM8^&M;T6S_P"$??3+'Q`]@N-X&_X+V_\`!+7X
M=?M#?&"?]HSX+?%C]AO]L1O`/PWT/XQK\4/A+I7BGQ=XXT?0/!5WXV\#^&)?
M'?P%USXIQ>+KG3%\17F@^!;3Q?\`V!XOUJ76-%TNTT2UFF;1M'_GQ_;J\;_!
M_P#;X_X*%?%+XQ?M;?L&?M1>(O&7QQ^#C?`C_@DW^S'J>@>,?A?XM^+>H_"/
M7[K3[GQ?\;=/\-_$#PS\2?`&I^*_B'XQU?Q)IMSXHTGPUX#\'?`^Q\5:KKJ^
M)=>TGPSJVL]>-SG!X'#8>O&^85L=*G]1PN6>QKXG,7*-.3E@XSKTZ=>%'#3^
MLUJKK1A#!TZF(<HPC9<V&RZOBJU6DW'"T\-&3Q-;'2G2HX51YDE7<:<ITY5:
MR]C3A&G*4J\X4K-R;/[G_P#AXQ_P3W_Z/N_8U_\`$G_@E_\`-Q17^>9HO_!G
MO_P5,U+1])U'4?%7[,/A[4+_`$VQO;[0-2^)?B*[U'0[RZM8I[K1[^ZT7P-J
MFCW-[ID\CV5U<:3J>HZ9-/!))87UW:M%<2%>OS/O_P"4Y_Y^OX=M?/Y?3_P.
M*[?=O\ODS]:OB=\"/V_/^"7O_!0S]B+]DC1_V[[C]HW]E#]IIOB%<>#M,_:0
M\#0ZG\1=!T#X3KX=\1?$7P1J/Q,T71+_`,0:OXR'@NYE;X6:Q<>*--\)_;?,
MT74_!V@6<=C/J'Z7_#_]GGQMX/\`&7Q_NO!_QAA^'VD_''XQ>`_BYHMWX5\#
MG4/%OA?6[&R\&:3\4M+UJ_\`'GBCQOX.UZS^*FA^";#PG;R^&?`7@#_A#=)U
M+4=8MXM5\;RMXP/W_P#\%?/V//BK^T[\!?`/Q'_9H69_VM_V1/BMH'[0'[/V
ME+XH_P"$2L/B#/I\<WAWXH_!C7=7N)5TJVT;XN_"_5O$GA5Y=41+-]4?2K'4
MK^Q\/W^O&;\Z_@%^T3X(_;>_9UE^('P=\5^*OASJ'B72_$/A35"+'0H_B=\$
MOB-IS7VA:QINJZ#XBT[Q!X>_X2CP7XAM9Y;2+6M'UOPMKRV=O>&TUC0;[9<?
MRSXQY'5R;,\)C\LP6#P.49A0IX7'5J6`P<J,L9#'?7H5\;2IX62J<[4(1E6I
MUJV(CA<13JNK&O*-7^F?"/-</GN48_*<SQN,QN<X.6)Q.64:V/Q2J/!ULN^H
M5,-A)UL2HPC3NYRIP=*G0EB*%>BX3P_/AOKCX[?%']F'P-X1N;;]IKXB_`CP
M=X'U"_TG2KNV^.GBWP!X;\*:AJ\JS:QHFGW4'C^^M]$N]2E.DW&JZ3;2?Z5,
MFBW5_;Q>9:O/'^*7Q!\2_P#!$[]HSXP1?$7X<_M\VO[('Q?^&G@'4_@[-\1?
MV??VA;?]DBP\3?#"[\7:WXC/@K0M5\:Z%8_"KQWX;B\;:EJ7C8ZQ\-;2YNM4
MU*XTC6M2UO4M'3P_O^X_V:?^"=W['?P%U+6?%]]\-;;XO?&?QAI\$7Q%^/7Q
M\O;_`.+_`,3O'U_%,EUJ.J:CJGCB\UC2?#DFMW;27VJ:1X`T;P?HMRUC81?V
M9>W$%@D'WGXM^$'P8^)>@VF@>./A=\-_'?ANUT*^\,Z?I7BGPAX=\0:58>'+
MNU73[C0=+BNM/GCL]+ELX$LWLK/[/9^6JQ"WC6(-7X_@\PR7(J[CA,;Q153C
M4ISQN%JX'+:$O:4HPKI996IYE'%T:CYZ<5B,7A9NG&E7G3A47L*?UN893G.,
M2AC\!DM*2<*L,-7ABL;52ISYJ7+CZ4\#&E.'*I2>'H5H1FZE"-64?WD_'/V1
MOV6OV8/V;O`1NOV9?#^B3:?\3+/1_%'B#XLQ>)[SXC>-OC0]W'=7VE^,?%WQ
M8UC4-=UWXA+?1ZU?ZCHTS:Y<Z'86NMS1^%[/3=&D%E'X;_P4A^%_Q(C\*_"G
M]L_]G;3+C4/VH?V"/&E[\=?AAID.I7EM#X]^'SV-K#^T-\&IM&M='\16^N3?
M%WX5:9>>&]+TV'3[76H?$J:/_8?B/06DNH[W[L^&WPR^'?P;\&:/\._A/X)\
M,?#WX?\`AW^T!H?@SP9I%MHGAC1H[_4+O4KJ+3=%LX[>WT^"YU+4;N[VVZ1Q
M1O>,+9(FC\I?S"^*1^)'_!77QS=_L3?LM0^(-)_8STWQ@FC?MS_ML6UEJ6G^
M!O$7@SPOJ;0^.OV5?V==<OO#YTCXC_$?QM>>3HOBOQWX3\07FB?#+1;35(?$
M-IJB:[I.FZGZG`.%XCS[CW`X_(JV,Q6)PF8T\;B<TQ\GST<MC45&K/,)JK.+
M=;!2GAGA*=:;K*4Z%'FIJ4H^/Q9B,ERGA/%87-J6'H4<5@ZF'HY?@XI*IC90
MC5C'"Q<(\OLL7&%?VU2"=.ZK5'[5KF_7[X:_\%??V-/BC\.?`'Q,T.;]H&RT
M3XB^"O"OCK1[.^_95_:)U"^M-+\7:%8>(-/MKR_\*_#?Q)X7O;J"TU"&*XN_
M#?B+7]!N9D>;1]:U73WM[Z<K[6^&G[.OP4^$GPX^'_PI\$?#;PCI_@SX9>"?
M"GP]\(V%QX?TB]N++PQX+T*P\-Z!:3WD]DT]W-;:5IMI#+<S,99W1I9"7<FB
MO[P]G+_G_6^ZAY?]./7[_(_E+G7_`#[I_?5\O^GOD_O\C^93P/\`\%\/V]?@
M[=WDG[8W[#7PJ^)G@S3-;:ZUWQK^QQ\0O%.E>,-+\$1^%GNKJ_\`#WP3^+\.
MLR^/]1TSQ+I]]%=/!\5_"DVH:;?V=GX?T#5[W3FO-8_*/_@I5\<M=^/?_!5W
M]GWQY_P0C3P)J?B/XE_L[>%?C)^TK\5/AC9:UI?PU^(6L_$_Q#XRU;3Q^U[I
MUS';^!I+[PEX-2SNBWB70X?BEHWB_P`7:AX1N)?^%B>'_#^@Z#_17XM_8KTC
M5?!@\1P"%[IK.'4VLI@;G9OFF"RQ1-!=V\NZTN%OKF]N6AE%OFW>*P,4]Q+^
M`/PX^('A;_@E+_P43^+'AZ[^`/Q%\<?`[]L+X8>%OC)XI\2?"/X?:SXOU/X0
M>)?A'J_B+PWXPUD>'?#WS>)_!5Q)XTT;Q+\1+BRTY_$.DW_B;0KRWTS7GU>/
M^T/F^,5C8\-YI4RW*:&?8^&&DL-E>+IQK4,5S\D*RJ49RBL4H475Q$<*W_M-
M6G2I4VJG(W[_``K/!_V]ERQV98K*,&\0G7S#!5'1Q.'<$YT71K)?[/SUHTZ4
ML3::P].=2M*,XQE$].^-7[37_!87]A+X'GX^_M-^`_V(_BU\)O`5EH>M_%'5
MO"?B7XE^`_'EQ<^*?%</AFR^''A]#I5_H4/B6VUG5M,TBQ\0Q>#]8T7[*GVK
M5;>1R]]-]"?M2?\`!6?XO?L;_L[_`/#1'CG]A#X@VWA36-8\.:1X6U'Q7^U#
M^QZGA7Q9XA\3S"272]&U/X4_&?XT^./$6IP:+8ZIKDECX;^&VNWUE::6VHZX
M?#F@MJFIQ_`7_!;7_@IU^QO^T)^RO\`/AW\$/CKX<\;:'XJ_:L\-ZA\9?!\D
M?CGPM?Z=\-?A#IWBB36O#WQ:^$.HZ+HWQ+AT.\\?77@W5-$T?Q/X&&CZYJ7A
M*&_TX22:?::E8_+_`/P2.^`&@_M"?!_]H7X:?%GP5I7QA_8M?XKVNI_L_P!E
MXYLO$<5AI/B+4]$UF?QS-\,K?6K#2/&/@^SM(]=TS3XO%F@3:5<+J<GB>ZT]
M[F9O%MQ-^0\$>'63\4Y)'->+>&89;F3S+'TU@<+3Q^21>&HU*4(T\7@HUXRH
M26(AB:?[FGAVJ+I1BDXJ;_3>+_$+.<HS&>4Y!Q#6S#+%@L&_K6,E@,XJ*NX2
ME*KA<=+#RG)NDZ,I<]:LY5E6<IN,E&/W+X0_;J^`W[8EKXEU7]OO_@I'(G[.
M5YK&JZ]:?L3_`+`7[+7[:-[KGQ5T*#7-,O-/^"_Q-_:[D^!_A'4=4TYAIE[X
M0UO3/AC<^`I?'7_"1W'B'5?'G@;1X1H-C^YGP1_X+C?\$QO@)X)^&OP7TGX$
M?M?_`+(/P/\`"_AV[\.?#J;QM^P]\;/#?PUTNP\,VIN9-#TI/!GA[QIX@U/5
MKJ65YKNXM]$U2^U'6;V;4->OVO\`4)[R?\@_V>O'?B#]D']H;P7_`,$]OB9K
M,GB?X8^,?`&N>*OV-_BCJSI;>(K[1?!,L'_"2?L[>*TMH+F+5O$OP\\/.^N>
M'/&MW_9\>K^$(;#3M2^V^)&BBF_9WP3X<M=3>#SA;R,KIN=C$D9D^TND4?VV
M18K:WC23<9KJ2=255C%,;>)9K?\`<LHR3*<APBP63Y=@\NPZ:E*GA*$:2G/E
MC%U*KC:=:M*$8QE6K2G4DHPYI244?C^89GF&:UWB<RQF)QE9JRGB*KFX1NVH
M03]RG3C*3<:=.,(1NU%*]ST.Y_X..?\`@B[8W%Q9:C^VUHFDZA9S2VM_I>L?
M!?\`:0T?5]-O;>1H;K3]5TG4_@[::EI>HV<Z26]]IVH6MM?65S'+;7=O#/%)
M&I7;77[+7A^XNKF=O#W@F[:>XFF:ZN[.075R9)&<W%R#87!^T3%O,FS/.?,9
MLS2_?8KT]7LU;I[KVTZW\_ZLS@NO/^K>7]?)GU-XC`_X1'Q(V!N&EW8#8&0&
MTW4"P!Z@$JI(Z$J">@K^57]M75M4T[_@KI_P2]L]/U+4+"TU[PO^V[I.N6MG
M>7-K;:UI</PJMM<ATW5H()$BU'3XM;T71]8CL[Q9K9-5TG3=06,7=A:S1%%3
M3^W_`(H_^FJ8_L4_\'_MTC[C\>^"/!>M:;J%AK/A#POJUCJFDWMKJ5GJ>@:3
M?VNHVTUYI]K+;WUO=6DL-W!+;:CJ%M)%<))&\%]>0LICNIU?N?#NFZ=IFBZ1
M;:;I]EI]M!IMI'!;V-K!:00QM;6X:.**"...-&$,0*HJJ1%&"/D7!13?\2/^
M"I_Z53&O@E_BC^4S\J_^"L[OI4'_``3U\3:6[:;XDL/^"E/[..@V/B"P8V>M
MV>A^*-*^(-KXFT:TU:W,=_;Z5XBMK*SM]=TZ&X2SU>"TMHM0AN(X(E3]Y?AE
M'&WBSP[;-&C6TVO-;S6[*I@EMVU*8-!)$08Y(2%4&)E*$`97@445IT7J_P`H
MDGWKX?FEFT'1)II9)99=(TV2661V>221[.%GDD=B6=W8EG=B69B2222:***R
M73Y?^XS-=/E_[C/_V0``````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D979I
M;"YG:68`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C(U`#$P-3$U-#,Q
M,#8V`#`R,C<S-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6%``$``]P`````````S``!F``"9``#,``#_`#,``#,S
M`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,
M`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S
M,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,
M,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S
M,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,
M9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS
M9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,
MF0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DS
MF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,
MF?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8S
MS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,
MS,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S
M_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,
M_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(?D$`0``V``L`````$``0```"/X`
ML0D<2+"@0"L&$RI<R+"A0Q8."4*,2+'BP!46)UK<V+`$QX\@#7JT&""D28%)
M-I8\&3*E18PL0;:A8Q$*E)@?D[39N!/GQB>0-D;RN1$*I"<$;2I-&.DFT8J0
MV`QL`ZEJ538C!T)RV5"CSZK8H$2"1*MLV:IM8&*+&G$E43:0D,`U2Y=65:1K
MI3I4ZS.)7+)UZQX%&K2K5YQ/2``.3#<J$K!=GPHDS#AP5,@%O?+U2;6RY\(%
MW;*0(7FMY\\&62`4J'K@X9!`3U?6*Y'@:H%N3R997/DR7=JL-;8>F-MDY\^4
MS4*:8ULM"\TXYU:>$ZC4'-ZT>AY4:P4ZRR=L//Y?"G3M6J#KRFFKAFG%"NG@
M)Z%0Q6[VDI[RY4M=,LL&+ILD[<$D0W>NW=:25<J==1]^Y>D!6%5VL='>1.W9
M9B!(5IR'8'C+L<)@>:S,<=99$E8XX4!75'@2>=>PHL=U_EGAX8?7P.6;74],
MN((5SEEQ!4LS@J@'>"0<8`6-(5Y%5E4[MG<B-JI=^-$**[`(8B`K'`#`D1\&
M<E42_;6!5)1.-DG@25IRV:)U;)!0)8.L!&(C$@DY:>>9)V5Y12O76&?5?X%4
M%^AU2W)5T(!./B?9')?\:=5E$)*HD)VE8;.;HX]F*FF=[E6*37^@_@EJ?X]M
M.M"E.;Z&TWR/]I=I5/YS;470;F6Q\82J,4'X((*-Q>J40-)!L@(2O_H$GJ;T
MG7570;[%!1=GF;*!Q%^\9:K=0$;9:",DQ89TG')63?O@M+8F!&95<L4J)4=&
M*4OBDJ5">E1!\CWZ6+CK<O2@MOLJN>\3-UT:X:C]&1K2L/`^46IZ-C:F)(DE
MW'O59C*1H*T)]$7*V&+<?FHQJ?EN%!7"TB;;J\96X57RLC%1]5?#GOV'S1.L
M0M+&KVD]`3!1K$K7&YT.M?$D43K])1M>#$&1(YZ2A7?:<@XET22N,?D\74-0
M`.BDIPM[QAQ#*;6P=:6N?O:U0B6PIZ)DNUDM6+<$/>$2I:7YQZM@"RD]$'7=
MDBTY*G8&8SO'KXB&;%*[=CFJ7+<L)`$F&SVN331VO-J<T*/:D5D:K7<#=NVL
M2YX=)=4FQ=IU69\7-!_29K)];ZA^!PWU06/[!(7%2KH*Z]D+Z;QWHCC5*VJK
M5J7NT-`LL=J33J]:[JE#)S!$QQRC!EY:0```.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;&ES82YG:68`
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$P-@`Q,#4Q-30S,3`V-@`P
M,C(U-38`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`S
MF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,
M``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`
MF3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9
M`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_
MF3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F
M`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,
MF6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS
M`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9
MF9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P`
M`,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQF
MF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_
M`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\S
MF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,
M`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"'Y!`$``-@`+``````@`"````C^`+$)'$BP
MH,&#"!,J7*@0``F##QDV'*6"H`J*$A,":(81V\5F%062`)!QH(IF'%5\Y/CP
M8D2-`&("6(FR)DJ5HYJ]1$@BI\V?0%'N1'@RJ%&A#'L>-:IB),F$19<&'374
MHD^I/SL6C$D3Z,657T>M0`C@*E`G8E6NR$E"!8`5@<8>[&ISU!-6UZZQ>B(6
M+RLK@:H*I`MR!=Z\>@TC9B67*%"*?Q%?,VPE+ZN0<\W65+S8L-_&!@FCM'N8
M\<P53:%JIE@TK8JU'$>->LJ31-N;%(^J="N11$K9(#77U*JP9\69K`G+%@Q1
MY%76#FU++SDX*U7J$#6GQCY0IF;F&0$D!#KMDSAWF:P8HYX-7B)7SRO>!N;N
M7'9,N/CI8Y/)OS]MA`$!`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]E;&UE<F9U9&0N9VEF````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,S`S`#$P-3$U-#,Q,#8V`#`R,S4W-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$@`"``]P`````````S
M``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,
M`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S
M`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,
M,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS
M,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,
M9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS
M9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,
M9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68S
MF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,
MF<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,S
MS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,
MS)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S
M_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,
M_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S
M__]F__^9___,____^+\D````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(?D$
M`0``V``L`````"``(```"/X`25092+!@%0#8$BI<R'"A0(,&232<V/`AQ((2
M)Y+(6/$B1(X)-PX$J5"D1XP`4CY4<5"C18\J6%:1Z21FRXIR7AJ4.;.*DRJD
MGI%Z0C*DG)P0;0Z426K5LZ>E2*G`B;2@TIY`A3[5*I4AB:-5L2X=&)14T*=F
MA8+\"I;$$YX%SY("M#5/GJ<K'((]ZM9J5K1;`ZLMN3<GSY]G!2M>Q9'M415F
MW_Y53)DQ8;!/MCJE_.SNUB=!+1M]G)ASYQ6ET#Y9L8I48[!(3&M^LLISGE5`
M\UZ6XT0V6E;0;+/*XUKOT=B^]5BS)IRX[M%RD*/-DSJP<E95GCJQ<K<K]-YH
M2:&56E%:#RLKK)_5E#LUI)/HX8F3<"+7[@K;3JBC;4P"N=D\*KR766";;46*
M7<^(5M)9\AU%7V`'0NA9<0Q!UEH>CCUX(&+3I>9=1>1)M5=F@!Q8FUW$"=4>
M1=AL5-B#SY1RVW!FK5"41N^-N)6,U$F%!(L5;83$<:69Y<1&&P%9$D%(0H:6
MC3D>J62+?LV$8DPNYC0E-@#L--*1,:G`%D@!`0`[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=A<F9I96QD
M+F=I9@``````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,#0`,3`U,34T,S$P-C8`
M,#(S-#`S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`
M,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`
MS```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S
M`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\S
MF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S
M_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F
M9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9F
MS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9
M,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9
MF9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,
M``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,
M9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,
M_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_
M,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__
MS`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````A^00!``#8`"P`````(``@```(_@"Q"1PH
M$(!!$@03DC`((*'#@0P!S$'HD$2>B`\=1B0Q46$>%1@S$C0X<>(EBM@LJBAI
M4.1(`"0NJ8B)DD0G$BI.MG0ID*.*3IU.3D3",2;0E2AYVNPTDT31B4Y_WN1)
M,*83H$"=S+F*U<E)JCU/7L(:U"A6L4D?PLQS<\4*IVX!N(7[%NC"C`N7KF#%
MRBW?O7T!PSSIM");ICA97;OVEP3@Q:Q`2OU:-:L?%:BJ\.V;Z5,FP*RJH%+A
MY^I=B#`Q4T'%6H5K%2L^K7B-F?7JG*>Q#<8L;32JWJQ1.0G^VW=OJ36/_G9-
MW#73VJU5'+<[<&FGX=&=!]O^G#EKKKD/HF;='@PH^?/FMX/?61"`BO/PXZ/?
MGKM])_GXS_\,1KGRS:5.Y,=5)X.E5=U"!NV''V(,&4@0$@==DM]V.@&`A$A.
M$356@!-J=5!:3ME$F((35CA6B"F51=A8[TT8S$\K&N4484Z99).+N$$U(T).
M884@"2Z6EY>/%-W('4SW!7E3DD*&Y9571@;YXB5/4@9320N1I>6696'94'L1
MA2GFF"$%!``[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O<F5I+FIP9P``````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,#8W-0`Q,#4Q-30S,3`V-@`P,C(T,S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#ZL^!GQ-\::M\#?!7Q7?3]&TC6O#>J_$V^
M\,V%GJ-QI.IV6E^)_!_CKP%X1UK0[N.:_?7?B49O%.F:K+I\LYN?$/B.&+S=
MC>0L/EOQ:^(]Q\+/V:)=+DU*XF\3>+]=TSX(P:[XA?3Y]<\66'A6SA\.>*/&
M`>QL[*VCL[#3-,UOP_X:TVUMH-,\.6]U<3>'K'3=6U+4=2O.5\&_$FS\(_LV
M>%'TY;5Y?AQ<^,_'K6;$0>7XOU37)M*^&5B/L\;0PMH^K:S!K)'V.:2*;2],
MG13'!/!=_(7B#3/%WQU^!-D_@_4F.A?LN_LU1_%+QOJ=P;K5]0\07?CGQG=:
M3J=]IMY>6EC;3>(M.M[/6O%CE$MHO+@NV>-86'E_NV)AEV283#YS%T:*P.!H
M8>4XQC%IR48VO\[;/UL?CF483,LTQ+BX5)^VKUN1OF?+3234?1=.NGJ?IE\4
M?'*VWQX_96\$Z9([:3>ZCJ/C)(E^SPZ;-8W'@^+P;X3FN+?RPLL%I87MT+:-
M2@2X(N(&CF`:N^^'GQ8@\1_##QS\4X9FN+"/6_B=K&GAP2HM_`5[J4%A#@$,
M8[ZUM+,S*K`S332&%H$9(T_+#XE?$'Q-I'C7X%S>*-/U0>)/@%\./!W@CQUK
M!@:UMKGQ#X!\4:AJS-81FXFB"^+OAQIS>-=-8ZG>R2:?8:@5AG#11Q?2?[,7
MQ&\&ZI^QMJ,<FIP65CJWC#P3X5T;/_'UJ1^,'B;P5;^%K.W4DJ=2U^+5YY[M
M_+,,L,%V%MXSEA]%E/$66X[#494,3"$ISA&4TU=*3C=WUV6K_P`K&&9Y36PM
M2,:\G:4HQ;=[Q3<5_E?Y;ZW^^[;6=:\$_#OX>M<DZIK]M+\-=!U5]4A2]'V[
M4=>TCP[JY:V`@6YE@;7+R2UAE$D;0VL27,=TBS";T#3?&GAK0M:L1JEKI6OV
M^I'QA\//&/P_GL_[0M/BAX$EFDD^)7P\UO4+EI7NKVXT6^U#5=`:Y>270O$B
MV%Y;.ME;R:?-\_?'HZUK'C_X1>';"ZAT;P1X#^+?@[XH?&3QD;M(=*L?"OAR
M#77T30)WS\TGBW5]-O=?>)29)O#OA/47MC;3ZOIM[9^;_#WXF2:IX4_9_P#B
M!K^EZKI/C77?#G[6?Q:U3P=+'!)J%G;>'8[W3KZ*Z7R"L5^\#Z?IF90UQ]HE
ME>)T*CR\\VQ609]A<?D,,12QU:-5PUDI23=DFK-?::UMND]#FIX+%Y966+A.
M5?#QDI[)QBHN,KK3I:_W71W_`(S_`."KO@;X5^,/%GPPL/B#\!==L?AQXEUW
MP%9:WXE\"^)$\1ZS:>#]4NO#UOJOB!-.U_3M/36]1ATY+O55L=/L+-;^:X%K
M96L`2",KT\?"'X0^+0/%>H_#'P->ZAXG`\0W]Y/X8T6ZGN[S6O\`B975S-<M
M8.UQ+//<O+).SNTKNTA9BQ)*_&7X>8F+<57JI)M)*3LDFE9>]T5[?+S/IUQ7
M2:3YHZV?V>O+^=_Q\C^>C0/%?C;2_#GC_P"&WB"P-GX@/C'7%E@ANO*NCXA\
M$:G9W&IZ?;++,?LQM46VU2WM929C:@_Z0)")E^BOV1Y?$_ACP!XCT^7]E3P7
M\9?^%\>+[[P9\*O%'Q6\07VG?"SPQX1\$^%O'?Q*U)O&M_X?M;C6=0U.\\,W
ME]X,\->"]'N8-6\0^,[W2+#3I!-.MM-#^USX0T?P=^T-\0-8BT$P3>)#X<^*
M<&H689X_^$DUG2&T#7M1AAE,L+_;]0TBZ&J6S1R1S0F!-J$LS_IM_P`$6/B3
MX/\`&5UXZ_9D\0ZKILB^$_'6B_%3P7X=U*6UL+O3_#.L07%KJUII40M%*:OI
M^N>'M'UC2[^T6'5=/7Q'9-:WT4YBFCKQ269Y+P)EMH3Q#EB*4\PD^9^WIU)0
MC255K[$6TU9Z75S7PXS6MFT<LQ]&O*-"4%.?);X9\JF_A>\6]?/N?EW^R_8:
M!^W!I5XFD>!O"W[-/COXU?!G7_$VG?"7PKXM\9>/?!FI?&O]G?Q3JF@:+JWB
M6'XE37WB3P/J/CSX;ZOK6GV6A6.L17.F^!R]^\5Y/#E_<_A3\%9OA1\5OC5\
M&=3T-M1\*?L^Z?\`#CXO)H*71.L-K6F^-M%L/@[+I,\NG6FDJFD+XB\06[SW
M=NEN@\%P3/<VD-G=-/\`U'?LT?L&?LS_`+(7ASQ?X2^$O@_7+[2_'GBRZ\5:
MU=^-M4@\3Z^L]YI%SH/]E:/X@DT^RU73]-@TZ]NH+<I>/JDGGLE[JEU!B(>D
M:'\'O@?K?C+Q1\3?">DZ/J7BO4H-&^'WB_Q-IE^^LBYN_AW=Z[IA\)7=JMPJ
ME]/UK5?$5U=K<7,K+?,K+)"L91OPFAQ#Q-A,+F=+#3]@K4I86-.?\*,I0NJ:
M=WM=:W;\GJ?J6<Y'D6:2]V525VELU?X;]K-MZ::;G\UGQ9^+'AOX<>-_AY\#
M?CG\1/V>OAAK6L^.M9^)7BKPUXXTGXS>.-7^(M[HUB-"\%_#^X\!^"=)TWQ[
M%X,T/PG?PF+4]-TO7["R\-65Q<S^(+RXDN[^YA4>+])^#.@?M$ZU=_#7Q3X>
M\;?%F\LH/B!\'?B'HOB[P/HWPI^*Q^+.DWMFVGW"0ZOX>G\5_$;QWX3AFL)-
M3UFXT:TT+0DUS3;>>QO9;SZ;_P""C/\`P1M^(7Q:_:!^"GQM_8STGP5\/O&O
M@S4M>O\`QO\`$^W\>V7@?XT0^)+OQ-80Z;XNT35I/"VKZCJVJ:5HK3V5KH<N
MIII>H6BII[PQ/+]J6Y^TW_P30^"?[&O['O\`P4%\5^$/%YTS0?C%I.@R_#/X
M8:5IA\-?#_X<:[96_A_PAX8T;P=I(ECM+/QGXXU2VNOB+\2M3LO+/B#6&O-0
ML;71+"40+Z>09SG6"Q='%X6KB(YA4Q%&>*Y7>=5*M!R3O=6<59Z:OF:>B0\[
MX:R7+\#A*-"K1KT'@ZDL70AK7IR5-O\`?3;<6E:[MJUT1X3\"/VB=3M?@?\`
M!JVN"TT]M\*?AW!/-)`)I)9H?"&CQR2O*3F5Y'5F:0\NQ+'DT5^4?P]^-_\`
MPBO@'P/X7-GX\NCX;\'^&M!-U;>'99;:Y.CZ+9:>;BWD!8203?9_,B<$AXV5
MLG.:*_IM<08Z24G@Y7DDW[O5V?Z_GV9_/#PF5W=I4[7TLW:UXVMKMM_6_P!;
M?MQ>%]<UOP?IOC?2YIH-8\*Z1K^G7]HD:W-Q+HVK0BXTF]N"BJ7_`+.UF`21
MMOCBCM;N]5D\R2.:'Q#]C;QKXH\'?MD_#+XE^%!;1VMU9:-H.N:;&=-T_4/&
M4WBNW'B7PQHNC:G=J;>WU75?^$<T[P_;Z9=HTM\([2UM;RRN9&O1^DVJV&GZ
M]I]UH^HV5IJ5GJ]A+HNJV$ZRR1ZCIET2D^GSB.:*X\F9'>#_`$>>WN!'(PBG
MCEV2+^/GC3X,3?LZWGB#7/$,^M^*/#'BSQW8:!X5\2Z)+-=:S:>&M+T#2KKP
M)J-UI=K;EM/\0>'DUWQ#!'=:9:VUW>2:?I<>G10WD<TEYS^),H9MAYY.L2I9
M?4IIN,FO9Q]BE*E!R2T2DDEJG\CXWP5XQCA/892ZC<:3A3A1OLKQCRKJ[K3?
M7\O[VGUNY\6>!(WTR2UM[Z."T@G&KW[Z=;6U[.T,EY8:M<6D5W-:S16#S>3#
M$\<MY<(OV6=`5%>$_L8>&OA1\-O@Y9_"OP)X]@^(UY;^+_B9\0?$,^KI?:%X
MBU76?B9\1O$?C+66NX=1M[*YU)=%U/Q%>:-I%]`88CX=M+""6&\O4EU"X_-[
M_@F%_P`%%])^(OB;P_\`L_?'067P\^/OBSPM9Z_X&.HZUGP]^T)\+/">JZIX
M;\(?$;X::G:1/HVO:[;W>ES:;XP\,KJ%GXOTB\T:]U(6DL5_8V</[V7&Y;6[
MNIXXTMI+)SJMW=SZ;#=6.GV:M/OU/6Y]-MM,LK&W5&N(XI->LYT12UQ'(0]?
MRI0RZI'%8Q?6INI2J02A.5J*IPE'E4>C2M>^MTD?V%.&*IX9U'1]C'%/EH^U
M7(XQE9:72MO=6U6FNB,G5+NTL(=3>^U73=%L=*LI-0O]:U`SP:/I5O;Q&YE%
MQ.)TFG2-(S+<(DXDD6-A$R,5(_E&_P""G/[4$G[:?[0?AK]FBS;5H_V6?@OH
MUS\0?B9XPT;49K?_`(7'XFN--N9?%&G>&;5);J.TTCP=I-M/X)T:[FM[F]N-
M=U.WC@NY[DHH^^O^"G7_``4O^$_ASX5ZC\*OA+J]QXUU[Q#%K6K:QXVTF1X_
MACX0\.^%YK>UU]],\2RV*+\3O$MC:C5IQI_@PZIH4-Y;06^LZG8VWVB4_@K^
MS?J.H>$K3P7CPBBZAX@\+:7X_P#$9UDW>J6&AWVGZAHFL^`/"E_J7VF(W8L?
M'-W'\3?%ME9/#;ZT^E6FF1_8[075M=?KG#.799E<7GV;8S!-33G"-64??DK-
M12NE9M)+Y:6/S?C'/Z628&OEM36HZ-12C?6HW"W*VWS-2V>MK,_8?PW\,O@]
M:^'=`MO^$"\/Z']GT72H/[%3PUXAU!-'\JQ@C_LM;_\`X2=/MRZ?M^R+>;5^
MTB$3;1OP"OS7N-1U*XN)Y[[Q]XMN+V::66\N(M6N8(Y[J1V>XFCA@$<,*2RL
M[I%#&D4:L$C14`4%?1_\14RQ/2C@4M+;;+EMU\OZUM_-2XGEI_PG+IT?]S\O
MT]3Z!DFF5+]EED5DM9V1E=@RL()&#*0058,`P((((!ZBOD+_`(*AW-QIO[$?
M[16IZ=/-8:EIFC?#R_TW4;*5[6^T^^@OB(+VQNX&CN+2[A"((KF"2.:,*NQQ
MM&"BJXF_W"O_`(D?#>#_`/R6.&_[#<+_`.GZ1_-/^TOXV\9^'-(^$-[X>\7>
M)]!O/`?Q$U^_\#W>BZ_JNEW/@R_N;/P]?7%[X4GL;N"7P[=W%ZBWD]SI#V<T
MMTJW$CM,`X_JN\5?&3XO>/-%_8$\!>.?BI\2/&?@7QIJOP@LO&/@OQ9XX\3^
M(O"?BRSU/Q)H=GJ5IXE\.:QJEYH^NVVH6EU<VM[!JEG=17=M<3P3I)%+(K%%
M?@M3_=\=_P!S'_I<C_3_`(X_W;)/^PC"?^G*)N?\%B[:VM?B)\)]!MK>"WT.
MT_9M\516FC011PZ5:QP:OK*01V^G1JMG"D*HBQ)'"JQJJA``H`Y>/]QH7@B"
M#]S`GPWTW9#%^[B7_0;;[L:;47H.BCH/0445X'%G_)*9=_U]H_\`IRF?RCXP
M_P#(]E_B_6)BT445\$?DCW^:_.!__]D`````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]G<F]V97(N:G!G````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,3(U
M`#$P-3$U-#,Q,#8V`#`R,S$U,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(
M`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)
M"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1
MH0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::G
MJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U
M]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/XA-0\/75E<21-)*KR7#I:0SQ/!]H>=XU3R&D"^<SR$1*L6
MXLSJ`"U036>JVP$,\+PRLJ*(QN5\-+M3:A`8N\D91`!EF#*!D$5^W/\`P2A_
MX)U:E_P4F_:AE^'FLZM=^%O@W\/--_X6%\:?$EC+(VJ-X=$]I:V7AC3+FWCE
M2/Q#KEU=I&K;DC72K36[E1NM"R?I3_P7^_9"\)?L&?#CX%>'?@G\.?#^B>%?
MB'J.O^'H?%__``BFE:Y+H&G>#[>!?#WAF'6K]EDL=5U]-4N;QK^5S?WUO9:C
M?V4<MI87LD/R&?U\!EN;T,GPE3GQ;:]O.M/V<*-)V=-QE&]VTM4[*]K=#[O`
MSGB:,L5B4XT(1BE&DE*<M(WTEVNK63\]+'\E\.M:]I0F17N_)EP+JWN!(/,\
MHH'MG#8V,-RL<C<H4@CK69JVJR:O=BY>,VRJL=O%9[VEAQ(H1W,BDA6\MV4!
MB.77N1G]X_V,OV/-3_:%_P""=_[8W[27Q+T/2X_#OP"TO7XO!7Q'U>S*SW][
M:>&;_4M5T*QO6BAAU%=#U--)T^">V>9)?[4BRV\PJ_XN'PMJ$PMKR6"STZ*S
M0R)`0!#'+A(HX;?<`;J:99H;J8`L;=`H<`."?3R*&:YM/'8*G7C[/#7_`'WM
M7*C*]KWFTK.-DI1UMW[:XVIE=%X98-8S$8K%<BPN$]A%U)U%;VG.HJ\87MRO
M=I,]F\%?![XV?#3X3Z+^TMX>M-1T[1SXG@TO1O%6FP0WL_A/R8[M_P"U[F62
M-X='NB+=K*QN[EDD>:]CLK,->7ELI_M"_P"#9S]M[]I_XX#X\?`/XT^(-;^(
M_P`.OA-X%T+Q%X+^(>O:?]JU_P`(ZY?:G'877P^O]=:&(:E8ZY9SQZ[HMBWF
M7]I'I-VL@`:OYLO^"?W[?7QN_81M/$V@S?"[PW\:/@M\0=/ND\5?"KXT^&=2
MN_!6K03&".\FTK4_*2W@BN(P4D60W-K<Z?-?PP6\NH263)^W7P@_X.+O@Q\(
MOAQ?>#_`W[!/A7X4PPRQ7MGX;^#_`(I\-^&/!.H7ESN6:?56?P2\\NH1!EB?
M4[V#45%J;6TM!YB7;)Y&=\&YSC*7L<+A<OQO._\`>%B)Q<)OEYDE!._+JMU=
MO5Z:^C#%PPM>C+&2Q.7PY(QKX7%8=Q4)12O*E*249.6ZYM/4_L[DUNQ,CEM5
MLT8NQ9/^$@EBV$L<KY17,6T\>6?N8V]J*_A>U#_@Y%^*DE_?26?[*W@>*S>\
MN7M8[CQ5XFN9X[9IG:!)[F!+2&XF2(JLD\-K;12N&DCMX481J5\JO"3BYV=H
M=/\`E]/^[Y_U;TMV_P"LF1W_`-WQSUW5+#V?PZKWMG9_TSJ_^#9[]K?X/?`W
MXD_M%_!CXAZMX+\(:Q\<;+P'XH\!>(/$\\6@+K]QX';Q'IVH^#;#6;Z6WA@U
M*_37X[VTL1(S7L5B66)SY;5_7'^T9XG_`&.?B+\)=:TS]IFQ^#WC?X<0R1:[
M>Z7\7G\.77@ZWOM,B%VFKF;Q0K165S;_`"V=E>Z<&>=I)K=5DAEN%K_*.\2:
MS%J&IVNJA;:U-G:VT.FVR;$9?(54GE^56FMGD8[A<0A)5#$!PDC!K=UX[NM6
MM+JSO+[59O*MUMM/BUC5[O4K2.$[7F@BCEN8+98&>-7'GN\F]$4(P=B/TS/_
M``VI9WG-;-GFE6A&JJ<>6,:>BI[KF;3L[Z/RZ,^&R_/:M#`RP\<-2YI2=ZO/
M/FMI;W?AV2W6I_1;_P`%A?\`@IW\(OB)\.]-_86_86\)^"O"/[,7AJ_M9?&-
M[\,/#J>&?"GBS6[>]DN]/^'/AW3-*334USP]#>V5KJ^J^(4T>8>+-<@T,:?J
M$MA97\,W3?L*_L1^#?A5X!TKQQ\2O"/A/Q1\9_$MK!KD\WBO0;+7[3X<6MWY
M%Q!X>\.Z9JUM<V4>O6UD=.;7]3GA687UY<V43H+6[2OY^_V0M&3QO^TQ\(-!
MU-3>Z.WBR"]GM)X2%N+31;2ZU>6VEMD#6X25K%886+%V+!$R'-?V!Z3=N/M2
M[Q"T:P)<2P8ECB=D`FC8*&6-"8[=G9MH4F(-CS%SCCZ5'AS"4LCRZHXQK+FK
M8B,G[2<JC3DVT[.[6VRZ']=_1JX(P/$5',^,L[PE+&RP6,IY;@54IP<*+IT/
M:RJQ5OCYK1>EK-M]$=A>>;%:_P!G)I.BMIB1&6VTU]*TVXTRT)C:*4MIFQ]+
MNC,LS';#!&L,9=!(F2C?CO\`MO?L&^$-?\/:W\3/A/X6T?1/&MM93ZSJO@S0
M+6;2?#GCN=6832G3X1);1:HC2K)#)9OR5D@6,F<8_6K4-6$(C2[$DD<:Y6:W
M;9<#<A`:!R=D;[2Q#2?)L##.<5Y)XLU^RM["5KJ_C^SPQRF!%VLC+,&B'V]F
M)#R(\JEIHSY*X*L0S*#XN%S>OE;<U6E&-*4;4G.3C*7NN4VW=WF]TM-#^H>*
M_#+AWC')L5E6.R3!)UJ=/V&)HT(4\12G4@G[2%2*3;O;W962M9:'\8ESXL\.
M6EQ/:WDVHV=Y;32V]U:-:78:UN87:.>V(90P,$JM$0P!!7D`\45^Y7B7]E?X
M-:SXCU_6%T6T5=6UK5=24+%%M"WU]/=`#Y>@$N![45]4N-Y67[S=+[3Z\O\`
M\E_5M?XBJ_1QE"K4A'%8_EA4G&/[SI&5E]KLETZ^;O\`AIXNT/Q!X6U.XTWQ
M+I>J^'M1@NKN5](UO3KK2K^SAEEC!\^UN(H1%&9618.!O##R]PS6(+VW53%+
M&1(!G!&&P,<A2,X^89X[J,\YK]2?VI?VC_"7BS7I[?XR_!W6(+@S1P0ZD#I`
MO%>$$F33=8M%4B*-7):VN\DADD?#(F?R8\1ZCI;ZQJLWA=KN'1;J_GN;."[D
M222*($(@N6P6DN-K?)+%^Y*"0=2N./A[C59W@_:U\&Z=7DC-JE*<L.G+E;CS
MO7W7I*VJ:LTFC\3XJX1Q_"..Q&78SW:]&HXPIUDX5)PO[LVDK7DDWIH]]K7^
MFOV2?&NE^!/VC_A/XEO;AK.R@\5VEG>S72,UG%:ZDDMA-)<C@M!&MP7?!!54
MWDA%<U_6\_B7PO#<Q1+<&ZGU)6>UU))#$);>Y(EB.FX80PP^7;(PDG)^7;@X
M<9_AJ36KQ65EG,9CDCD$D1\J3S(I4DC\N88,;I(B2@A@2(RO\7/[!?L\?M]I
M-X7LO#GQ'O3;>*]&2WT_3-?N+EX;35],BC$"1W$@)%O<0JZ`;BOF(DDA)*UP
M\3JI5C0QF#IQE*,(6BI-IM)<ROO=>6B[]OZA^BUXCY!P]3S3ACB+&RP5/,<3
M'&9=[1Q4)XQ452JTY<SLJ>JE?>^ZMJ?OMK7C[P]:.B12M-+$IFC0;HHKB[CQ
M`OGRR$+<S!)I/F@)C(W'J!7RW\3?B'H-MH^IWEW>SR3QW"2"VL9%=[<DLA,4
MBLR1F.5XT=YL1)OV,0[J#^?/C#]L+3+5YETJ6*YA@N(HU,-U<WT=Q+,CS-/;
M2,#')&OEE6:-FVE@.A-?"/Q+_:DU34);EK.66&YEN;PB/S)`KF0X6.>-C\D;
M`^:I(^_$F#SBOB:6%S/&591K4E&G5Y6Y<TM-8WM?HGU_-Z']1\7^,G!W#675
M)X?-L-C,7!1<*=*I&5ZE."BJ7N-NRT5U9[]#]"9OCGJ$,TL7VK1QY4LD>+A2
MUP-CE<3L"`9N/WI'!?<1Q17X<3^.-?N)YKA]9U/?/+),^#+C=*[.V..F6.**
M^C63RLM%LNJ_N?Y?GV/Y#J>/>(G4G)8"5I3E)6E5^U)-6^]6^7?3]B_VVK"Q
M?X:ZB[65HSP(AA=K:$M"6L)\F)BA,9.!G81G`STK\,]-`.GVF0#EWSQUY;K1
M17A>&O\`R),7_CJ?G3.3Z57_`"6^$_Z]83_VXN2JHG("@#9T``_N^E3!W5H"
MK,I$B$%6((.UN1@BBBONU_N4?\3_`#B?S13_`.1UDO\`V$5O_;3H8;R\9T4W
M5R5#`@&>4@':XR`7P."1QV)KGIF:2])D9G)N!DN2Q/#=2Q-%%<]'X5_V]^<3
MV<?_`+U/_L+?YHZ98X\#]VG0?PKZ?2BBBJ73Y?\`N,^DCM'TC^5,_]D`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]P=69F+FIP9P``````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`W-C(V`#$P-3$U-#,Q,#8V`#`R,C8Q-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/D+X->%KWXL>)WL;87.FZ%I
MSAO$FNS)#&=,M/+,<,-L2RQWUW>)%-::;9Q03EY2OFA(DN67]1]<T71O#WP\
MT+3E7[!96]BMJBNN!;VEO/;BTDD9G17,\EPUQ*ZC<TTSRR$RNY;\&OV2O`7Q
M^^,/[8LNG^!_BCXR\`_"'X51>#_'WCVTT_5]8E\(Z]IM@MG?6?A_5=!M-;L=
M-UB^\9:G>ZQX4MVU"'47\/V-YK7B=["YLM+N[&3]I/B1=:A\0O'&F^#M,F:X
MGU:66"Q@\^:*SM8;"R2_OI3:1*MM,MG#9RSQ^:\$48@A$+I$T9KZS-<$L!D5
M#`86G*KFF?T:?LXPMSTJ-3E<9.HO=BY7TBY)KEDY66IS8"MBZF>/%YC*6"PF
M2RG)0JJ=+VE;V,9KGI5%&;C*$HU:<DG3G"K2G"<HRT_*?]J77O&6M_M-^$?!
M'P(\#O\`$O7=4\&OK?Q`M;%/(72K>>>2S\.ZB=7U"_L-%TMYX=$EBG;5[D)>
MM_9T=K_ILD+#WG1?V8/BM+8PW.JVV@:;<B(M<6EQJXN)%:5<K&5LK2ZMMR.K
M%C!(X5EW`[H5(_2#P_\`"C1/AM$OAW0+"QNO%.L70N/$'B:'2H;;6/$VK1?)
M92:C)))-=74=A90C2='BO+R>+2-+B73M,%M96R1-9U^273C/;D(WV:81J8XX
MF+Q)(!.P;:1+(P9VD9G8%`RF0I))CY+%\-X+)L)A<+C:DZF+IX=*:C*$;RC[
M\];R=1IRTE'F7(H.Z/J<MXCQ&9XFMB,(H_5J]=3@YV;A3<8PI2C%/W8R<'+E
MDD^>4[I7L?DSXV^%7C'P,BWOB#3GDL"]M%'J=I)%>6JW+M>.KRAD$MM$(X)G
M^T2V;E6-OAR9$AKS%(HHXLEIGGC/S#<Q42^1^ZE:-F$ZKYOF;2T>61@\*K()
M<?KC=:?;:U:W=IJ%I#/%.IM9+6\1+N`VP@5`)(7#1S![ABI:6,KN98S,R]?S
MU^./PON/AUJ]OJ=A)%-X<UO4+P6P2&&"+2;J0221Z4T8NK@F."S2[FLYU2(!
M;.2/RK<P;Z_+L7B(4,4H1C*$*LIJFY..DHZ\M_A;ZQ;:V::;:/U#"PE6PTGM
M6A&+J0TY4^6,ER]M59ZOXK+JCR46<;`,#=`,`P"@2*`><*ZH5=1G`<$AAR"0
M<T51CUQ1&@34K)E"*%8R;2R[1ABJP,JDC!VJS*,X!(P:*M5:3L^6H[V?\6GK
M\'][KI]_D5[+_IW/[H^7][R_K6_UM^P%<0^!/V.3\1+2<:GXV^,OBS71K@M&
M@L?[(TKX;R)9Z+8ZE=!6O9KR74_$WB.Y?=$((K-[`KLD($OIG_!,;XD^(?V@
M?B3^U5\2O$F@6">&OAKXCT/P#\-'96NT6.VO/&%AXLU:SUN]B0R7.L/)H#SF
MP:*!(;&.U0S1RV\[?E?^R]^U?8?#CX(7/P:\0V6K7!TKQ!KVL^$M5T>ULVBN
MK'Q1*;_7;74FU*[LKBWE>[MXY[7;!.\/G3QH;:&"V#_MQ_P1W^"=W\-?V,C>
M7<ZSZAX\\3^+-9OKPK,@N5L?&.OV`=Q($0.4L8$8P11K)/'*&():OZAR"CAL
M8\MJ\\:]3"99AE4BTW.C65*,9IW;Y9/$.<VGTD[6;2/YV\3<\Q.8<2\4YHU*
MGA<PS[&4L+=*-*K@5*&'R^,(QC%*G3R^E0IVCRJ*A!**::?T]JW]M0:]?Z];
MVC0KY5Y%:WD*2M"'M;`6\D`F614-S+:SEVWLSQLPR$&47X5_9_TOX\:[:>+M
M4^.?A^X\"ZCJ&OW=WIFA:AXZT/Q1;KI#:9X?\F[LT\/ZOK4&DI)J4.L-!H(D
MAFTXR29A9)H)W^_OBI+'8VUFZ.YDTV2Y-O$WE@(MW(R74S1A0=TL:[SYHDVK
MLC38%KX"^(W[5GPA^$7BCP#X-^(=YXL\.:A\09-9N;7Q;=:5I4OP[TQ;*^T6
M!-,U/6)-<_M&RU0-J37$MI#H<UA%ILMG=K=*YN+=?"XNRW#U,?3J5N:5>E2B
MX.#:2C-S4G9:6?-RR5M5!IZZD<&XZ-#"O$^[%5%##WE>44Z$F[<K5M5*T9-I
MW=]W<T_CYX]\4_!3X;^+?&?A#P+J'Q!US2]'C_LO0]+T2YUF2XU34=>T_3([
MZ:WLHCJ-S8:+;O<ZQJT,$]K*=*M+EQ>6`WW:>>^(=4N/B]^RCI'Q)\6Z3;:9
MX@O?A=IOQ2N].T^TN&BTS5X/"4FMW<>FP7<EY?6\5QYL[0V;/=7D=O)):B6X
MEC7S/8-*\??#OQ9J=Q;>#?BOX#\4:Q!:W&KMX>\,^*]+\0ZP=$2>"5M6:WT2
MZN/L%LMQ=6T3F>2.XAFD:WDMX6D1H;WBVY.H^!/&FEW(A:.#P=X@M<NODQ,T
MN@WD,B22)LF*A90QD8M,=[LP=@"?YNXH_P!GKTZ:H2INA44J<W=NK"5I<KOK
MJXQU5FK*VC:/Z$X95+%UJ^.I8MUH8BE&DJ4)7I4W%1;EO:]VE:\OB;T9^(4/
MCKP>T43+XAO$5HT958(S*I4$*S'36+$#`+%B21DD]:*P;CX96!N)S'KE_#&9
MI2D,3QM%"F]ML4;':6CC7"(Q525`)4'BBO/6)RUI-RQ=VDW[T]W:^O.O/HO3
MOZSP.8WTJ4+7T_=]+P\_+\&?+V@BXT#Q8FFW=L;5QJ=]9W,<R;[B"8"1YMRQ
M.J-Y<CE8D9Y$9W=HG8;99/[#/^"=7B33=4_8S\,Z3:;E/@R7Q[H^H(Z.L<=S
M<^,/%7B+$"^;,93+9:W:R1%HH0)G174!&EK\%/\`@I%\/=#^'?@S0/B;HME'
M#X\F\2Z?H6E^8`]KJT=Y'%+<V^LK;I`)3!96MTT<\4Z21Q/.N$C=K=_M/]BO
M7[K]DNV\1>'OVB/$FG^!++]JOP]X'\4_""PUBXEL9M$UCP3X::]\>:-XQDU&
MTL[?PE=PGQSX<MM(:]GDCO+Y1ILUY%JKQVMS_9_!.0XZEB\5:"G0Q5&<5.+;
MG&>&<*RIM)*]2,'7DTVK1BY.ZC8_CSC?'8:>7X>]3DG0QE*;BE%*U3DBY.VW
MOU*+;MHJB79O[W^/GB6WMKB[!\X)#L2:-4W1%O,9K61`765U42!'R492I.YQ
M(`GYE_&'P7H/QB\)-X<\06-I=P:;JD&MZ+=WMM]JATW7+*WU*UL[QH'RTD;6
M^LWMI>0*-TNF75]#!);SW,=S%]$^++OQ!XL343I5UI_B*UTLW;Z=<G6;)Q?Z
M9YHC06][/JL=E=6L%BD8@N(9ECE:)(H993+$DWS!<^-+F!I(=42.R8//!*CH
M\;LUO.8Q&JO<-($1RT+;$"QMY"R,B`!?$X[R_$JHJCHUO8RIU(1M%QYN96E%
MM--<K;:>[2TZL^I\/<RC@98:KAZM!8O"XC#XNBY*G6C"K3E&M2FZ56,J=1<T
M+3IU(N,D[23V<7[//P7^'WP&MKV'PMHVD/X@U"YE;5_$D&FQV=W.C65C:7&G
M6LZ^;?VFAFXL([U-/>]FS>S/<S2O+R/JCQ9JZV/PW\93-$Q>?0M9A,K.LJF2
M_M!:6T:,'PY,\^\1@JJ0IC=O`1OCV_\`C)X9\-SP7&L:U:6MNJ11E46X>=)'
M>4(C6MO%+=%,HZF;ROLP`<"0$K7#_M`_%/Q%\2O@AXC\0_`Y]+\56_PHL+CX
MG?$&Y-RUMINF:/X6T"[UJ&RU99;ZPO)TDA@N-2N])@EM[^YMM*:2*3[6UC;W
M7\Y\19/7J>S]E%O6,(SJ5793J.-.G&<Y)N"YFD]]TK:JW[_E6>0Q&*Q6+KRP
M\*M:=3%XCV%.E0A)M^TK>QP]&,*<7:,G&$%%:)*UCY]N]=,-U<PI=S(D5Q-&
MB;I/E5)&55YMF/R@`<DGCDGK17QEIG[3/@W4--TZ_P!:MWCUF]L;2[U:.Q:Z
MCLDU.YMXYK]+-':=TM5NGE%NCS3,L016ED(+DKY[_4C/EI[2EI964KK3E6_L
M]?7STZ7]3_6[(GJL1.SL]='9\NZYM'J].FGS_5O_`(*YDGX6^$@22(_B9`(P
M3D(!X;\1$!!T4`@$!<<@'L*]>_X.#)I8-+_8RNH)9(;HZ#\;<W,3M'.?^)A\
M!UYF0B0_*[KRWW68=&()17^@?!_\.A_V'9K_`.H-8_B[B7_>Z7^'"?\`N(_F
MYT[QQXUTF)AI7C#Q3I@4N5&G^(-6LPI?5)MY46UW'C=N;=C&[<V<Y.:VN?$W
MXD2P:W')\0?&\D?GR+L?Q7KSIM.GW(*[6OR-I$<8(Q@B-,_<7!17E\=?[G'_
M`*_5/_24>[PU_OL/^O$?_2F>5/XM\57&BVUK<>)O$$]K)(MQ);3:SJ,L$EPZ
M/OG>%[EHWF;)W2LI=LG+'-?K=^PW<7$'_!/?]N6ZAGFAN;S2_B[8W=Q%*\<]
MU96?P&MY[2SN9D823VMK->7<UM;RLT4$MU<R1(KSREBBOYKX@_@4_P#L*P7_
M`*DTC]2R3_>X_P#8%CO_`%'D?D7I=M;OIFG.]O"[O8VC.[11LS,UO&69F*DL
MS$DDDDDDDG-%%%>W+=^K_,X#_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]T<FEN
M+FIP9P``````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-#4R`#$P-3$U-#,Q
M,#8W`#`R,C8R,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/XQ++3!K>I7[6@*6D"7-\'9!&J6RS*L"2"-6AB:3S8U5!A"P*HP4<^__!6Q
MM?\`A(;55V^>LP`^<YW)%<@'Y3P=I)X'?D#%<%\-[>P%EXCGU`RQ:-?BUTMK
MUXHXG!-O>W4:Q!B\23F3['*!]H"13&U2171UGBZ#X:Z%X]U3QKX8T/X*^&_&
M7Q&\>:SK,&C:5X-\,^$-:\9:WK6LW\[V&E:3H>@:#9SZCKNIZG+++#::=8A[
MFXNPD=N)9`$K#C/!NOED,1&=/V^8T\5.I!64J4W5BH-P7PT)1DX4JMVI<DH]
M+O?PTQ&'RC-,/6K4IO"X&M0<ZC<)55&-10FJ2J.#JUJ<HN=6E&2DN9.*=[+^
MO/\`9`O;Q#HL@M42...WBE^20Q3-#"$E%H?,$A,+!4G\XEA!+#)&H<7#K^]?
MPGU*58K0P".9I(X$D9=DH<^3"9"K`+N$6YUP`&*+@AI`-W\G_P"PE^VQX5\5
M21>$-<M?^$3\>:4H5]*FC\F&YU7[%;V5T-,DN[\W<T[SWA9+.5(KYH7G::"*
M,J\W["_%#]M76?V6?#?]H1^"_$/B6\LK<ZC;K;:1%%H=FS+>7.G/X@U^]U*S
MT_0=-$FFA=4U#47C,,)FNX+>_!,3?Q?G%*M@,XC2KTZF'KNM#D@HVGK))2IW
MMS1DEHU;FC9VL?Z@5'@>*^%Z&-RS%87'X.IA&G.4G:')23G"LE>=*=.6DZ;7
M,K7LTS]H_&L4.H:)=K<0PLTL$J!I((93&C"-7V"XCE4$KR-\;H2$+HRJ%K^#
M[_@O+\,[;P-\<O!>L:=H3V6F>*_#VM7\LVGI!%:7_B&TU2&WOWM+98+1_/$=
MQIS79C86LB7<,*6SWEMJ6J:I^SO[/_\`P4-_:4_;"U;P]-K'[0'[,?P#\%R:
MS!I.J77A71->\4^)SJ>I":#2]%5/%!U/P#>W>K:U;:3HUM:7&JZ;J!A\2Q2:
M5INI:U_96E77D/\`P6I^!NM>+?V7_!?CF=[+QIJOPX^)6JWDGB"UTJ;3KC4O
M"^I:;<W%[JPM'N9Q8W$\>DVVHZG!I*VMJT]E%/:QP6EC;Z;;>OD2JY)QUE.-
MK8FBJ6)G.A64Y2C5Y:U"JE*I&<%%34K2>LDG%I/0_)\]R&KF'A;Q!D].$YXG
M$X)8G+J5*G6E2]KA\33:I8:4Z<56?+1E%N"4H\WO1:>O\[_@G_@E5^W/\1/!
MGA'X@>$/@-XRUCPGXZ\,:!XQ\+ZM;Z1JCV^J>'?$^E6FMZ)J,#II[(T-]IM]
M;7,3*S*R2J58@@DK^_7]F"VL_AQ^S5^SS\/#IMC*?`?P-^$O@PR7'AS49[B0
M^%_`/A_0R\\\5_9133.;'=++%9VD<CEG2UMU(B0KZ.?C1G$:DXTL-@G3C.4:
M;=--N":4+OV.K<>6[OU?R^!H_1_R-4J2Q*XE6(5.FJZCB,.HJLHP55132:7/
MSI)I.S5TNG^=C\3/A)J/PPU3Q[\/-9N#NT7Q5X9O8+LI:+)J.A>)]%U&73]9
M"V4L]FBW%K;:?=M;0%I;*:Y>QO+>VN;6>W3[O_9#_9ZUZRN--\3ZHWA6\\!V
M;66K"]UKX=?#;Q7::@%&J7,"ZSI/C?0_%:ZC!;:F_P!GCMKFSF@9"ZO%Y!01
M]_\`M?:9#?\`A#2YVT6QN5>74M);7)8K1K_2WU"#?IVFV\LN^[2"[O?-N<0Q
M)9_:-/A,]S:W$UFEQXIX:_:5T_PW^SU/X(O=2M[36].M;?3YH6FE^U3-:ZRY
MV-$MM(H,4:Q[MK'S/,:09V,U?VQ]+7P[Q?A9QS1R;AW$XROE<U0EE]14JU&O
MA,'7J5,5@<-"O!QYOJ.'FLOAC*4X*O+"57R0J>TI4OY*^@7XBY#XO\!5N+.+
MJ&68+-J%'&0S"CBJF%Q>!S+'8"&'I9M+%8.NZD(4LSQ%&>;?5*].4<.L7AJ:
M=2'LJE;G/@7K?_"WO^"DFD>(](7[:WQ'_:"UWQ#)Y+7(.M2:_K5_J&J:G(VH
M.EQ"NM7::CJ<MFK6_P!C2X:SL8+:-+6%?[-O^"B?[(K?';P(EWX,M&M/$'@_
M5=.O+34ECT6\@.APVDD<,&JZ;X@AN;:\TV:[N8&ODLS9ZC(8K8+J%E9VXFB_
MAF_86\3:AX7_`&K_`(#^)M,5GU.#XB:5%;A$/F8U&4:>\I8([/Y,-U<MM:,Y
M7S?FC+LZ_P"D->^+(/#DU]+JJ/<V$6GW$&MO/)<1"T\T1L+N\)6X=(S&ZRRW
M$P*6T<OF22K&0:_A;Q%=*EF^5/$1:5+!T).L]90]E*O&\I7YISYY0DW=M^S6
MG*G?^Z?"K'YH\MJ9MEE.A-UL\XA?]D*G"GA<5#&+):DZ/LX)48<N'K3P^'4N
M6GRXB4'&6O+^7G[*?_!-6RTS0M#D^*&B:)KL?@[Q%I'B'PY)%<>)I=3T$Z;K
MGBW7H;/P/JNM_$CQ</AEI$VM^)]8U3Q3I7PRM_!-A\1)[^[B^(ECXN\R.X@^
MJ?VJ?@WX=^+=MX0^&%[9VT/@CP]K]I\0/&-V?)^S:7X3^&=KJ&O7<UP;^YLP
MUIJ.HP:3X<OMUQ.ZV&N75W)87\=M-&GT[H'CC2-(TO4K;3;A8"\2^2MO<//&
MPD,[LVXK.[HRS.T2K*BQEE"':JJO\W__``6U\0_%;Q9X@^`'@/P[XDU_1?AO
MXIE^)%U\5+#2]=:PTO6[+P_J'P[U?PHOBC1EN(1X@MY=3L]1CTC3+VTN[2/4
M3=7K@FUE0Z<!\,X_Q:\0>$^&<OJYGFF8YGB(X?$5J%+V]7#8.DZDZLL-&DKT
MJ5#!*M7JUZLE0H4HN=2I3A"36'B%Q=1\'N"^.^/\WP>2Y#P]PU@L1C<IRZE2
MP^54<5C<<L/AJ<\32JTZ:Q&+Q>.JT,)0BE6KU^6A0HTI\M.D^<\?_P#!4+X_
M3>._&LW@/Q#X1N?`\OBWQ))X,N=9\$6J:Q<>%'UF];P[/JR?V/%MU*72#9R7
MR^5%MNFE'EIC:"OS<.K7P)"M8%0?E,EE,\A'8R.+Q0[D?>8*H9LG:,X!7^\&
M&^C;X%87#8?#+PPR.NL/0HT/;5JN/=:LJ5.G3]K5<<PC%U:G+*=1QC%.;;44
MK(_YW<7],'Z16*Q6)Q2\4\ZPRQ.(K5UA\.J,*&'5:HZBHT(/+).-&DI>SI1<
MI.,(15W:[]G^*'@J/QWX"\1Z$`KW\]J)M&4R6L3?VW:$WVF*LMUB.U2[N;5=
M+EOV>..R34?.FD6/<&_#;QCHMY;>(=7TC4+.YL9EN1!J45[$;-],N;$HFJ)>
MPW/DM!=QW,<J213K#,MR&1T:7<E?K+^V'\5M3^%?P*\1S:%<7&G^)/&.I:/X
M1T+6=.N)+75=`FO/M.L7FJ:==PW%M=V4L6EZ5>6JWEHXGM;JYM9$8@&.7\BK
M+7=6OK.+5KG5]2U#Q'J%O-J&L7^KW]Q>7E[-K+7%R]U'<SSO>WTRI>3"^+O-
M,LD4,S,R9=?QGZ?&8Y!C.(,@RC!1JOBC+<EAB,QK1J1^K/"XO$8N6786=*SJ
M+'4(PQ.,C43C!8>O333E*[_;?V;.$XDP?"O$F*S&=+_5+-<XFLGP\J4WB7C,
M-3PN&S;$1JR:I/`XSFPV#5-+G^LX&K)22E-2^\?^">/P3^%/CO\`:&\+7>K?
M&*]\#6?AV#5_$NB#^T?#VA^(-0U[0M.2]TW2]*;5I)X=1O;_`%&7RH-%M;&&
M^U6SM;]+2^M6BGN[3^YCX??&[X6>)O!,/B3Q1XS\*ZE>:CX=2T\2Z/?:IHLK
MV%Y]CMAJ-EJ.F7%]/<6SQK;`W<,YF=EO-[0LEQ:K'_#=^R+^RIKGC;7=-U[3
M+WPI?O?6%M>V.EIJDFF^9NE4V][::C9"UN]*FL[B7[:DXF1+BXTN*)4N)A9R
M1_UF_LD_LJ:?\,_#NCZWX[\!Z')XQM4UFW-Q>1Z#KUM;2WD]B9M2BU7S=4N-
M0U.^-G<,E\9[;^SH+NXL+:WB%Q?S7O\`C'XB8J5?,G'Z[*L\-!0IQE"G)PDT
MU4C>*4G%-N[G&U[V>R?_`$)^'G"G#>$\,</C\3C*F4YQC,3.O1RG!4:CJ8ER
MFE%K$5VX48551PK<Z3E)0HQBES'W%X<TZPFC>.QNH[NQG<0VEY(8F>1(II8F
M$LJR-`71D,/F)(L`*$C;'@#^;S_@I#\4M$^(_P"T5J.E^%M0NM0T3X:^'HOA
MW<&9E.F3>+=(U_Q'JGB>^TU(Y6_TFWEU:P\*:I--!!)_:'A6YA`DMX;>2OZ`
M/C#X9\;7WP%^,_AGX27MQH7CN^^&OC31?!6NZ%>OI5_X>\8>(=!UBU\-ZGI=
M]9RVD^GZI;ZU?6MW9WUE.DME<1)?221^6&/\/GP`^(_BSQL_CK2O&UYK.K>*
M-$UA=2O-1\37E_<^([Z3Q!J=^_B%]6DU%YKJ:]T_6EE>YN9I1<9U:*UN%>6V
MDFD_K']G%0X9CXOX['9Q6J_ZP0X?S#"\,THVAAZ=;%TJ]7&U*]GS.I4RO`XJ
MEA8)JF^>O3DI2G31_G3^T[S;BROX)T,LRGDK9%B>(\LQ'%52H^?%3P665L(L
M!0HRBE37_"QB<!B\<M)05.FXQ4.=P]YWN.R_F?\`"BK!M&))!'))_P!8W_Q%
M%?[AZ_T_^!Z_T]/^?Q3I:?#T_3S^_P"?='@'_!2N21?"OPLA5W6)_$>ORO$K
M,(WD6PTZ-9&0':SK')(@<@L$D=0=KL#^?/A-F&J^%R"02]NI()!*OM1U)[AD
M9E8=&4E3D$BBBO\`-#Z;'_)\,\_[`.&?_5#A#_53Z"?_`"9WAO\`[&>?_P#K
M0YB?O)_P25^;6(-WS8F11NYPJ76GLBC/0*0"H'"D9&#7]?'A]F_X0?PX=S9,
M%MDY.3E;ECDYYRW)]3SUHHK_`"?XV_Y'69?]>G_Z7(_W&R/_`)('@?\`[!J7
MYR-WP4`_PYT8N-Y>*\9RWS%F_M>YY;.=Q]SDU_`YK'[C_@HE^U7'!^Y1_B_^
MTA"Z1?NT>&/XXNR1,J;0T:-'&R(055D0@`JI!17[_P#07_Y2'X<_[",-^=<_
M@_Z=W_*//'O_`&&YG_Z9@>^+T'T'\J***_Z"#_G>73Y?^XS_V0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VMI9"YG:68`````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W-S<`,3`U,34T,S$P-C<`,#(R-#$T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y82\`,`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````A^00!``#8`"P`````+P`P```(_@"Q"1Q(L*!!@@`2
M'ES(L&'!A"4B0IE80J'#BPX!3-S(D2(`C"`?=ARY\6/(D!JA1`10!0^>*B54
MECP),F7%$G@`E-"C,Z5*FA=U>H2"IR)/H12!-D0ZD:4?`"\A;BRAE&%,CDY7
M^*FB\RH4DU4-^N1818\>E1*;ACTXEF/:D6#7"NP:L:[=NROE#EPALR[)MWGE
MCBUQX(#7B0A8L$#@5J_/$HL+7RV!H#""!XQG+DT8%^%4&H$2LFB1>`7G`RR\
M?M1#RN0*A)SC*K1YH(5I``=H@#XJVJM`/<FJ/"&5+,_`V&!GZWQ2904+S@A:
MT$"`G(7AB`*?)$L&O/AQY-@L_B;L3BIQX19ZJARH3HJ4:8%5M@-_#3O\Q]GA
MMQ/7XYQ\Y?4`C$:<>P*M0)Q^3\S%F7W*Y1?<=A"2HIU[BHUFUG:W):1?>PPF
MUR``R9#2'83<09A>=U40Q]5`(2ZXH%BS`1<?B3322$I\M\&G((,P@K4"=S/6
M*"2.]M57)&RRR3BBD!&699)L%L$HEHPI,@EA%9XD.-=#G2G897CQW1ADC66M
M>"1&43ZT4XA55$EBF4^F>=(*6BI8`I8BIE=F<W%^"1)Q3SQAFE9<Z52667P:
MJ10`$[IW@!^HH%(%"U`@8.EZ/?K9T(1`QA2II+KI!L%S;,F)D7;RK8`:I'Z0
MI)A>W@2QMEU:SH5J:PM?::J4=NJ-ANM&+?P*A74IPLIB,J:Q`(%NP>*J6`LL
MZ&&--689.]P*?$)AZP,5K;!"*:NL(JT>QH8G[1-"K?3$*M26R2ZYY3XQ[2J"
M8LONM-;06\JT[\'*$KX`!YROO#Q!0=]:`*P@\+SA`BP<3#$=O*A*]^8K[@H5
M)5S6*J64$@C&:I6*WY9S-=737=]!))7!:-Z7W&%DU?D81T_XT?*9V*Q0E%UM
MUAD>S'>BXC-#]X6'$!Y^)*UTE]AB3">KNAYG=&<)U8SN0DZAPNK5Y095KZ8!
M`0`[`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O;6%R9V4N9VEF````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C$U-P`Q,#4Q-30S,3`V-P`P,C(W,S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA(``@`/<`````````,P``9@``
MF0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9
M``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_
MF0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F
M`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,
MF3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S
M`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9
MF6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD`
M`)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEF
MF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_
M`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPS
MF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,
M`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`
MF?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9
M`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__
MF?__S/____B_)```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"'Y!`$``-@`
M+``````@`"````C^`+$)'`B@H,&#"!,"&,A0((D!$"-*G#A1P,*&`Q]2W$@Q
M`,:&`3B*A"B`Q$>'(T=:/(E-8\J-'EEB"[E10``!$&_:)&GR)`F<%`6L&*4"
M@(I11D?=!-#SY,V)29L1'345Z4J9,R4&H.IDU`JC0[T:Q`J`H@JI3UA=N\9J
MA0I6;?\T_>B2Y-$5:M>R7;&6E0JL,X$."/"GJ%Z]>*VP8@J8)L2C;ZWH;0N7
MU5R?$@7<S;L7[&6G0*..2LOVR:AF4C\['0#@-&JI;H>^)DKBKTR-1E^C=OU:
MQ='4MR&V'N5D]^_9IVEC?1K@>%'?T)F24/U1)XG>O*E2OUU0]VP5VP%-7_?>
MS#9@EN.]AQ=/@O?KZ>?I0JKMOAD)-NM]DH`T'_)1QO%A--U^D*C`7U'X!<B0
M;$3YIYR"`YU%WF[Y?714?;-5"%)!)#"ET$4G!00`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]P:6-A<F0N:G!G````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-S$W`#$P-3$U-#,Q,#8W`#`R,S$R
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#_
MV/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;
M`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?
M```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$
M!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6
M%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!
M`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#
M$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G
M*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/Z9?'_V^>PT
MW6I-.NM.GTO6+0R&[C*K';VW\?FQEP0_.?E^7U;K7A/[:O[0.K?!WX;>&[/X
M8Z?HOBGXZ_&KQ'%\-/@%X,OYH`;WQ_=1:KKEWX]\1QQQWH/@;X;^!O#/BGQA
MXEU"[2SMX5LM!T1I[;4?%>G&#ZL^+7BCP=X5\#^,?%?CO6Y-(\">%O!6M^)_
M$^I0178M]'TWP]HU_K^J7VI3V=KJOV06VFZ7>S,I1\^2!N!:OR*\4?$?XJ^.
M#XW^.OCSX7/X/U?PE^SM!X@^#?PUMG\?'X@Z-\,/BCXRU[5[SP_XPU=['R;+
MQ[\0M3^#/P[U'74TS39;KPI=:=X3TC7WL]/\3:Q#;?YYXO&T\ORUYC5IUJ\V
MIJ$H59KWW&U-NSY>15+<R2NX*5I)M-?V7DN&>;9C##\L*=)RC=.$;-*4>97=
MI7:=NR;U6J3^EOV6/!^@_!OPC>>#;/5)_'/C+QI/J&L_%_XC>*(I4U;XT^/9
M[Z[?4O$GBG[5Y$U_X;36=4U@^&O!FG:EIJ>&9--L?`W]NZEH]PL\&'K_`,/=
M,_9<UG4_CU\)=2US2O@C/J=YJ'QN_9ZTCPWJGB?PQH^F^*=0N(/%WQ2^"6EZ
M;J>B^*/!VJ^%])M;_P`3_$+1_!FH:KX=\7^'?#WBK4M'T;P_%H]C)K?Y4V7_
M``4,^(OP2^('AW2/VE?@QX1TKP)<Z7\-SXT\1?"#Q)>:MJ'PCU_XS^&/&_Q,
M\*^!?&.D^.8/#@TSX@V/A'X=^*=;\2:)X=U3Q/I6B:[X9M+^?Q$[>+;*VM>I
M^%__``4^^-'[6W[5VF_##]G"Z\'_`+/WPW;P]KGB[X>>*OBW\/?$7B>]^/\`
MJ'A^ZU+5SH>C:Q_:FB^&O!7A_P`11^#M6\7^&=+@OI]8BUWPY?ZA:Z1XOF\/
MZ;-X9^*R+)/%>68O'XA0AEKO6Y77HUHN-[KEG!SYD[:)3LDW)KENW]#Q1E>5
M8"?LLNA35648\W+*44[I)MIJ=FHMM-13NHIM*UOZ%?`/B31O%>G6>L>"=?T[
MQ=X:\7Z=IOBWPEK^CZUI>OZ+XIT/4;.RC2_T^\TN[N[CQ+I3_;1X=M9M2M9]
M8?P/IVI6-YHFGW=FNKSZ.H6NJO%+#K$J!C#=0VZ\'[/]F_B\_(\S?TQM3;ZM
M7YT_!GXC1?"S]N#XV?`Z_P###V?P^^-7C[X6?$;PW-H'B**]T/P[\<O'GP`\
M=>)?B-IS:3X@UK_A(/$MAXMT#X.^)[Z"UTWPRFAI%_;NL_V1HDHGM(OU0OK"
MQOHS#)YEQ%_I7&2C_P"D_P"V,GY.G^UWQ7Z=3GBJG)BYU)->J2LG9I623VMS
M.[;O=K9?$8:*H8F4:D(VER[P2E*T8[K5)IW=HV2U=KZF#&-):.-GD;<40M_I
M$7WBH+=_7-%4U\#:054F.8DJ"3^]&3CT\[CZ45Z2SBAI[DNG_+R?]WS\G]WW
MY7I7V>_\\O[O][R7W>MN=^*'@?2/B+\-OB1\/O%5C%=^'?B#X#\:^#/$EA=O
M>6]OJ>F^,]&OM!N3<PZ9=VYD%KINIWT/EAT-QYV1);E0:_F"_P"":O[0'[2W
MC'5?V;/AU^T)I_BC4OM?P+^,^IZ!XTUR'0]6T7QU\*K_`%'P!)X'\5S:SIM_
M?7-QJ7@/Q[\-[2/6I]9A&H:-J'[0>E>'?'.F$^(=+U*?^K.>:6*W$GE2Q1^3
MY3"`(F[_`&OWDDW;J.?J>WX9_`?P?XJ^&7QW_;7\">(/!6I:)%H7QO\`'7Q%
M\$:S<W-QIN@2_![XYWNC^)=-T?X5WMIKL1BLO#_Q#^'VK^%/BOH.F6-OI^F:
MYKWA/Q;JR^+5T?PQX=T_X'.,ZH8'@WB&E+!?7:N`2G0E=*5)RM27+?XUSU8R
ME'EE)J/.G#D<X_6\+47+'J<ZJHU-KV2=E**NHI[I/1I-WLEKRI^$W/B*;QO\
M&_&/[$%Q\']7O_VC_&_[57Q+U;QQ\4/BK\+;Q='^'O@;QI\6-9LYOVA4\0^*
M=+N[37?B7_PHZ_TKX:?#(>%K_P#X3`7$=CK5K=V^C:#XD+_6_P"R]H7QW^'F
MM>'?V==`\5?"RR^!'[)?C_Q38>&KCS=;U_XZ^-O`WQ-\-?$8?`S1_&%S-I=K
MHUQ9S^$/&DFI/XLMQI^K^+M6\':;HFL3K)J/B6_U;A?B%^T%X:^&/[27P9^"
MU_KD.AV7B#1K]_$M[-I.G67@R#QSXJU&?0_@'X)\6>)AJ6A'P#)>ZSX1^,WB
MGP-<6UY>^)=<\1>"XM>TF2\U;6=3U"]L_$CQ_!IO[<_P:\2_#+Q;?>)O"MIH
M_A#X,_M=>#O!FKZ?:^"_"<7Q6\9:M\/?@?)\2->N;M5F^(&E?$3XI:9J7@SP
M8IT[Q#I>F^$]5\.W,MG'+::DWBY9Q)Q7G.!RS!PIU,MPN*INK.+FU[6[?([J
M-X*]E3C%)*,HRNH2YE]'G>383"5'B6UB*R5WRSE-;)S2A*=DFN:*OIS2M)-J
MSH^$;34O!7_!4?PKK=[\1_#R7?Q?\:?&FQF^%^HR^#-2@\)?#GP;^RY\+-/T
M36(=9$_B3Q%X?\7^*-6L9)WOM)UG36.@:5XL\*Z?]G'B?Q;J^J?N_#<MG]V3
M&O9I8PF?_'B/\G/&:_*3Q'X1\*67_!1S]D'X@/IIN?&?CG]F[]ISPQKYMTU&
MQT4Z_P#!ZX^'1LO$UWX=L+!I3<Z5I/B[XI>"9]2N-6L5U>X\1^%Y@(#;Q6$O
MZE644"6VU'ENGYY:X\PC'7@JOTX/X8K]'P%#%4,GP"Q5>.(5;^):,(MVM%)N
M$8V=DFW%ZWNVY7/S?&VJXS]SH[)M)=^NO6][Z)^2TMT2W\FU?FAZ#^'VHK-"
MP``>4W``_P!8>W_`:*ZOJM#^3_R:7EY^7XON>=9?U\O\D<I%>13IF:!#'_SP
M*OV_V]_OU\OI]:_.O]N77M2^%WC;]E_X_P!_>7"?!O1/$GQ`^`?QUO(;.SU+
M5])\+_M%S^`[?X5^.%<16T5HWA7XP^"_A^\UQ-:S1V5GJ&O3W=XZW$ZR?H:/
M-^T[0&1/^FJ1QCCU'FMV[9KSGXG_``S\(?&CX6?$+X4?$#3YM2\'^.?!.H^%
M?$FGZ80=5@CU>&5K#5-/4C,VI0ZFMYJVCW"&&32;O3H#&\S;9$^`A4HX:CB<
M-B\/]9P^/LL53:UFI:/EEJX36KBU9)V=FK(^EJ2E1KQQ%)NG334KQ;WVL]4W
M?71-:OKU_)_P]X1T7QW^U)^UOX/\?^'/#/B;1KSP!^R+I=KX5ATZPU_1KW0M
M&\(_'B*/1=/L;Q;B/4K#1O'.EZQ<O#%KMI#91:Z\VJV&O#PKX5.E>M>-O@S\
M./AC\*?"OA#X9^%+#P-:W?[4'[(OB#5=,TBT2_U2?7I?VW?@MJ=SXAU.2_CU
M6ZUR9K:Q\0C6_$OBG4->>34='T?2?!VNZS'";S6/FSPQ\.?B=H'[0'Q5^$?Q
M&^)VO^'OB'I?P13PGX1^)B:EHVM>(?B9\$_#.N>';;X/?&70-7\9Z7)X0TKX
MK^"E^(GQ&\$_M&M(=230-;\7?#G4?#3>.!XUTJV3V+7_``1JGPR\&_L]?LU?
M!/X@3Z?XH\=_&GPQH<WB+QYXH\7_`!0\>ZCX1TSP=KFH?%GQGK%K-XD\-W_A
M7Q!X.UH>'OB5\)M>O9)O"'@OQ!;?"/3[GP]X:\2^(8M(NO/PN758<3Y/06,Q
M5/`?N'##>SE.#A"DDINHN:;A&24(PBY)+FA)4U#EE]SBJF$E@/K*J2DIQYN9
M/EBFN6/O2DKJ\4VU)RNHZ:N-_H/]FV\M_CC^TU^T/^T=INH&W\)?#8WG[&/P
M.O[-M9FMM9N_#OB'_A9'[3OCO4A)`(;FP\3^/[[PYX"TZZLC%'<WWPTO8(]0
ME6(PP_H9"8G3SIT$?_3&UE*?^/!6)]/N]Z\<^"7PL\*_`/X9>#?A%\.[==+\
M'>$?"ECX7\.7.H:A<W\^L:9H1U'4KGQ+J^M(X?6?$OBJ[UZ?QCJ]Q):V\\NL
MZW=O)/<[5<^PV5O%%T39S]QI=_Y$A>/PK]/Q-*GEE2CA'>KAZ5O8PN[K1;M7
M;;O=ZO6]VWJ?G6'IQ=6=1ZR<G9W:T:TTZ;??=JU[&K]OMO[_`/+_`!HK-+VI
M)(@'))^\?_B**Z%JD^YE["E_(OOE_GY?U=G+VRK(#YBK)P/O@-Z?WLU'XCDD
MMCX9FMI'MYGMM/#S0.T4K",:@8PTD95VV&20IDG;O?;C<V2BO@JNT?5?G$]#
M%?[FO7]$?C/^VCJ>I0_\%AO^"9_AV+4+Z+P_K'PL_:KL]7T*.[N$T;5;21=9
MU%[74M,6065];/J&F:=?/!=02Q->:?9714SVD#Q_)WBGQ=XKA_X+H_\`!/S1
M(O$_B&+19_@QX^TR?2(]:U)-+FTW_A;G[46F_P!GRZ>MR+22R_L[PWX=L/LC
MPF#[%H.BVOE^1I=C'`45]SA/^1UDO_8'_P"Y:AV5/^2:C_CE_P"EQ/Z9K"..
M/Q/J]K&B);6TFEBWMD55@@#Z1IT3"&%0(XMT<:1ML5=R(B'*J`([DD76`2!Q
MP"0._:BBJSC_`'U?XOT/*PFWW?\`I)HL!D\#J>P]:***<=EZ+\B3_]D`````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]F96UA;&4Q+FIP9P``````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-S4P
M`#$P-3$U-#,Q,#8W`#`R,S$V,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$"`@!.`$X``/_``!$(`+X`
ME@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'!P8("A$+"@D)"A4/$`P1&18:
M&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q-#`K-"@K+"L!!P<'"@D*%`L+
M%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*__$`:(```$%`0$!`0$!```````````!`@,$!08'"`D*"Q``
M`@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152
MT?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ`0`#
M`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1``(!`@0$`P0'!00$``$"=P`!
M`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:
M)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#
MA(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3
MU-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^J:`"@`H
M`*`"@`H`Q?$_BK0?"MJ+CQ%J]EIT;([H+B8*\H0`ML7[SD9'"@GD<<B@#B[3
MX\_#6ZNH;>+Q/&LDKA%,MI/&@).!N9D"J/4D@#N:`._T76M*UVU>ZT34[+4K
M9',;2V<ZRHK``E25)&<$''N*`+]`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4
M`?,?QJ_:/CM/.T;X<S;[V*;9-J[1H\0"X)$(.0^3D%B,8!V[MP8`'RE=W,]Y
M=375W-)/<S.9)997+/(Q.2S$\DDG))H`BH`*`/6/A_\`'OQKX3N@+O4)->T]
MWW2VVIR-(_)7.R4_.IPN!DE1N)VDT`?67PO^+OA?X@6MM'97L=GK;H#+I=P^
M)5;#$A"0!*`$8Y7.!@L%)Q0!Z)0`4`%`!0`4`%`!0`4`%`!0`4`%`'SE^U#\
M8-1\+72>%?"MS'#?3VQ:_NDYEM@Q&Q8V#?(Y4,3E<@.A4@\@`^/J`"@`H`*`
M"@"6TN9[.ZANK2:2"YA<212Q.5>-@<AE(Y!!&010!]6_`3]H*UDL(M`^(E_Y
M-W%MCM-5FR5G!(4+,W\+#/\`K#P0"6((RP!].4`%`!0`4`%`!0`4`%`!0`4`
M17=S!9VLUU=S1P6T*&2665PJ1J!DLQ/```R2:`/S+\5:]?>)_$>HZWJLF^]O
MIFFDP6*KGHJ[B2%484#)P`!VH`RJ`"@!#TH`0,#[&@!U`!0`4`?3G[-/QMCT
M^&R\'>+I]MHOF?9-5NKI$CMD5`5A?=C"_*^UBQ.650,8P`?65`!0`4`%`!0`
M4`%`!0`4`>)?M7>/'\*>`QHMI%)]N\0I+;K,-NR*%=HESD')97V@`?Q$Y!49
M`/AZ@`H`*`"@!I4&@`&<]3B@!U`"$@=:``<B@#[2_9$\=_V]X.E\,ZA/NU+1
M<>1O?+26K'Y<98D[#E>`%53$*`/?:`"@`H`*`"@`H`*`"@#X$_:*^(MK\0_&
M\<^D-<_V-I\/V:V\UB%E.XEI0A^YNRHYY(12<'Y0`>64`%`!0`A.!0`@!/)_
M*@`W#-`"@@]*`&/]Z@!R=*`.F^'?C#4?`WBVPUS2Y)`T+@3PH^T7,.07B;((
MPP'7!P<$<@4`?I!I.H6NK:59ZEI\OG65Y"D\$FTKO1U#*<$`C((X(S0!:H`*
M`"@`H`*`"@#Y#_:/^.7]L_:O"?@NZ_XE7,=_J$3?\?78QQD?\L^Q;^/H/ER7
M`/FV@`H`*`$)P,T`-7).30`K'`H`CH`5?O"@!7/.*`%CZ&@!]`'Z`?LSW,]U
M\#_#$EU-)-(J31AI'+$*L\BJN3V"@`#L`!0!Z=0`4`%`!0`4`?#W[17Q-\6:
MEX\UG03<7NC:38/+9"RAE>/[3&>#)+TWB1<$`_*%(QG)9@#Q*@`H`*`"@!K]
M/QH`4#`Q0`QCD_2@!!R:`'G"CCK0`SJ:`)`,#%`"T`?;?['.H75[\)9H+F7?
M%8ZG-!;KM`V(5CD(X'/SR.<G)YQT`H`]SH`*`"@`H`*`/G+]ICX*S^(Y+GQA
MX4CDFUE47[=8@EC=*JA0\8_OA0!L'W@./FX<`^/J`"@`H`*`$(R*`#F@"*@!
M0<&@`ZF@!ZC`]Z`'4`%`'VW^QSI]U9?"6:>YBV17VIS3V[;@=Z!8XR>#Q\\;
MC!P>,]"*`/<Z`"@`H`*`"@`H`_.KXYZ5/HWQ?\6VMT\;R2:A)=`QDD;9CYJC
MD#D+(`??/7K0!PU`!0`4`%`!0`TJ*`$V>]`#@`*`%H`*`"@#]!?V<=/NM,^"
MGA:"^B\J5X9)U7<#E))7D0\'NCJ<=1G!P:`/2:`"@`H`*`"@`H`^!/VH?^2Z
M>)O^W;_TFBH`\LH`*`"@`H`*`"@`H`*`"@`H`Z_X3^#)_'OCS3-#B$@MI'\R
M\E3/[J!>7;.U@I(^521C<R@]:`/T%UK6=!\&:`EQJMW9:1I-L@BB#$1H`JDB
M.-1U.U3A%!)QP*`/$?$O[5'AJR\R/P_HVI:I*DQ3?.RVT3H,_.K?,W.!@,BG
M!YP1B@#SN[_:J\8-=3-::-H$5L7)BCEBF=U7/`9A(H8@=2`,^@Z4`>_?L^>/
M]5^(W@R]U?6[>R@N8=0>U5;-&5"HCC8$AF8YRY[^E`'IU`!0`4`?G+\9O$]K
MXQ^)VOZYIZXLKB94@;)_>)&BQJ_(!&X(&P1D9QVH`XN@`H`*`"@`H`*`"@`H
M`*`"@#V/P!\6;+X5Z-JNG>$M(CU/5KMXS-K%W.XAEV=DM]JL$&YPI+!CNW,!
M_JU`/,?$OB'5_$^JR:EX@U&YU"]?(\R=\[06+;5'15!8X50`,\`4`95`!0!]
M)?L4:]8V7B/Q%HES)Y=[J4,,UMN*A7\K?N49.2V)-P`!X5CQB@#Z\H`*`/FW
M]J/XP_V1#?\`@;0%SJ%Q#Y>IW,B?+#%(F?+0'JS(PRW10>/F.4`/D.@`H`*`
M"@`H`*`"@`H`*`"@`H`*`"@`H`*`.I^%OBK_`(0GX@:+X@:+SHK.;]\@7<QB
M=2DFT9'S;&;&3C.,\4`?I+0`4`?(?[3/PG\5ZC\0-3\3Z#I=SJNFW<,#R?9E
M5I(G"B+8(PQ=^$5LA<`-_LDT`>!:[X<UOP_Y']O:-J6F>?N\K[;:O#YF,9V[
M@,XR,X]10!E4`%`!0`4`%`!0`4`%`'??&:V_LC7=&\.-I_V"?0M&M;6X3SO-
MWSNIN)6SR!^\N'&`2..."``#@:`"@#5T+PYK?B#S_P"P=&U+4_(V^;]BM7F\
MO.<;MH.,X.,^AH`U/^%<^-_^A.\2?^"N;_XF@"WI?PK\>:G?Q6EMX1UM)9,[
M6N;1X(Q@$\O(%4=.Y&3QU-`'M'PE_9JU--5L-8\=RVUM!;3+-_9*!9VFVL?E
ME;E`I(4X&_<K$'::`/K*@`H`*`"@#AO'GPH\'>.))+C7='C_`+0=&47ULQBF
M!*A0Q*\.5"KC>&`QTP2"`?.7QB_9S_X1+PYJ7B'PUJUS?V5GM=[&X@W3)%P'
M?S$X;!^8_(H"Y)/R\@'SO0`4`%`!0`4`>Q_LI>&M.\1_%:-M461UTJV.HP(C
M[09DDC"%L<D`ONQQD@9R,@@'%_%WQ*GB_P")7B'6X6C>VN+DK;O&C('A0".-
ML-R"412<XY)X'2@#D*`"@#J?AEXTOO`'C&RU[3T\[R<I/;&1D6XB889"1^!&
M00&53@XQ0!^C>DZA:ZMI5GJ6GR^=97D*3P2;2N]'4,IP0",@C@C-`%J@`H`*
M`"@`H`*`"@`H`_/_`/:$^'B?#WQY);Z=#(FA7R?:+`LS/L'1X]Q`R5;MDD*R
M9))H`\QH`*`"@`H`^@OV*V@_X61K*M'(;DZ2Y202`(J^;%N!7&222N#D8P>#
MD$`'S[0`4`%`!0!]>?L:^-_MVA7W@V\?]_IV;JRXZP,W[Q>%Q\LC`Y))/FX'
M"T`?25`!0`4`%`!0`4`%`!0!XO\`M9>%_P"WOA7-J$$.^]T:9;I2EOYDAB/R
M2*".54!A(QY&(AGID`'PS0`4`%`!0!['^R?K\&A_%^UANA&L>JVTEB)9)0@C
M8E9%Z_>+-&$`XR7'T(!R'Q:\"7W@#QC?Z9/!<_V;YS?8+N1&VW$6`PPY50S*
M'4-M&`V1Z4`9]SX%\46OA)?$]UH=[#H3.B"ZDCV@[@"K;3\VPY`#XVDD#.>*
M`.;H`*`.Y^!FJSZ-\7_"5U:I&\DFH1VI$@)&V8^4QX(Y"R$CWQUZ4`?HK0`4
M`%`!0`4`%`!0`4`4/$.E0:[H&IZ1=O(EM?VTEK*T1`=5=2I*D@C.#QD&@#\P
M*`"@`H`*`+6DZA=:3JMGJ6GR^3>V<R3P2;0VQT8,IP00<$#@C%`'Z2^!O%VD
M>-_#EOK6@7'G6DORNC<20N,;HW7^%AD>Q!!!(()`)?&?AK3O&'AC4-!UE9&L
M;U`KF)]KJ00RLI]0P!&<CCD$9%`'YP>*M!OO#'B/4=$U6/9>V,S0R8#!6QT9
M=P!*L,,#@9!![T`95`%K2=0NM)U6SU+3Y?)O;.9)X)-H;8Z,&4X((."!P1B@
M#]1*`"@`H`*`"@`H`*`"@`H`_+&@`H`*`"@`H`[3X4_$75_AQXC74M*;SK27
M"7EB[8CN4'8_W6&3M;&02>H+`@'Z`>$?%.B^,-&75?#>H1WUBSM&9$!4JPZJ
MRL`RGH<$#@@]"#0!YM^T9\)7^(FC6^H:*8T\1::C"%6"J+N,\^4S]0002I)V
M@LP.-VX`'Q'K^C:CX>UF[TK6K22SU"U?9-#(.5/7Z$$$$$9!!!!(-`%"@#]$
M/@GX^L?'W@BQNHKW[1J]K#'#J<;JJ2)/M^9BHXVN0S*1P1D<$$``[Z@`H`*`
M"@`H`*`"@`H`_+&@`H`*`"@`H`EM+:>\NH;6TADGN9G$<442%GD8G`50.223
M@`4`>O?#SX;?&+0KJ#Q!X2T:]TVY='C#32P1.RDX*O#,P.,C(#+V5AV-`'VC
MX/N->NM`M9?%>GV5AJS(IEAL[@S(#M!.<J-IW;AM!<#`^=J`#6O"?AW7;I+K
M6]`TG4KE$$:RWEG'*ZJ"2%!8$XR2<>YH`\QUW]FOX>ZEY'V.VU+2?+W;OL5X
M6\W.,;O.#],'&,=3G/&`"+1?V<?#NA73W6B>)_&.FW+H8VEL]0CB=E)!*DK$
M#C(!Q["@#TFT\.ZI!=0RR^,]?N8XW#-#+#8A)`#DJVVW#8/0X(/H10!TE`!0
M`4`%`!0`4`8'Q!U"ZTGP%XEU+3Y?)O;/3+F>"3:&V.D3,IP00<$#@C%`'YH4
M`%`!0!M>$?"VM>,-972O#>GR7U\R-(8T(4*HZLS,0JCH,DCD@=2!0!]1?#K]
MEW3+'9=>.[[^U)^?]!LG:.`?>'S2<._!5AC9@@@[A0![QX8\*Z#X5M3;^'=(
MLM.C9$1S;PA7E"`A=[?><C)Y8D\GGDT`;5`!0`4`%`!0`4`%`!0`4`%`!0`4
M`>!?MC>*O[)^']IX?CBW2Z[-\[LN52*%D=L'(PQ<QXX(QNZ'%`'Q=0`4`>^_
M!7]GW5]?U6'4O'-A<Z7H,7S_`&6;]W/=D,1L*_>C7CDD`D$;>NY0#Z]\->'M
M(\,:5'IOA_3K;3[),'RX$QN(4+N8]68A1EF))QR30!J4`%`!0`4`%`!0`4`%
M`!0`4`%`!0`4`%`'Q)^T/H_C/QC\5-5O+/PMXDN--M-ME9N-+DVE(_O%652&
M5I#(P;))##IT`!S_`(7^`?Q"\0?9I/[%_LRTGW?O]2E$/EXS]Z/F49(P/D[@
M].:`/JCP#\"O!?A'^R;O^S_[1URPP_\`:%P[_/+S\XBW;%P3\O!*X!R6&Z@#
MU.@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`/_]D````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9E;6%L
M93(N:G!G````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(Q-34`,3`U,34T,S$P
M-C<`,#(S,38S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/_8_^``$$I&248``0("`$X`3@``_\``$0@`O@"6`P$1``(1`0,1
M`?_;`(0`!@0%!@4$!@8%!@<'!@@*$0L*"0D*%0\0#!$9%AH:&!88%QL?*"$;
M'24>%Q@B+R,E*2HL+2P;(3$T,"LT*"LL*P$'!P<*"0H4"PL4*QP8'!PK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M_\0!H@```04!`0$!`0$```````````$"`P0%!@<("0H+$``"`0,#`@0#!04$
M!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6
M%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?H!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"Q$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#ZIH`*`"@`H`*`"@#,U3Q#
MHNDW"P:KJ^G64[+O6.YN4C8KDC.&(.,@\^U)M(I0E+5(OV\\5S;Q3VTJ2P2J
M'CDC8,KJ1D$$<$$=Z9+5M&24`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`
M%`'C/QB^$MUXFU:;7M`G@%Z\2B:TEROG,JD!E<D@,0$4+@#C)(K.<+ZH[*&)
M4%RR/!98->\$^(H7EBNM*U:U;?&S+@\$KD=G4X89Y5AGJ*RU3.V\:D>Z.[\-
M?'+Q/IUVS:SY&L6K=8W1877@_=9%P.2,Y#=.,=:I5'U,9X2#7NZ'I_@[XW>'
M]:W1:TO]B71E5(ED<RQR`]]X4!<'KNP`,'/7%JHGN<U3"SC\.IZ?87MKJ-I'
M=:?<P75K)G9-!('1L'!P1P>01^%:',TT[,GH$%`!0`4`%`!0`4`%`!0`4`%`
M'G?Q<^+6@_#2UA741)>:M<HSV]A;D;R`#AW)^XA8;=W)ZX5MIP`?-MW\3_C=
MXMM9KW1K/5H])O4*)_9&CLT0&-C>7+L9P<@\A\@YP1@8`.`MOAG\0]?UEE?P
MOK\E]=N\CSWUL\0=N69GEEPN3SRQY)[DT`6]2^$OQ)\,75E='PUJR7(?S()=
M.Q</$R$$-F$L4()!!..G'0T`3>#/C1XP\/:B6U#5+K7]*G(6\T[5)C.EQ'@@
MJ&?<4R&/(X)`W!@,4`G;5'M_PX\1_"3XDZBT.H^'X-`UV3:!:R7;10S$ML58
M2C*K-]S*[5)+'`;!-3R1-EB*B5KFAXW^`LEK:?:?!]W/>2+M#6=VR!VY.663
MY5XX^4@="<]!4.GV.FGB[NTSSOP3XJUKX;>(K@M8NKNJQW5C=AXR5R&!QQAL
M9PQ!P&/!S4)N+.BI3C5CN?47P^\::;XVT47NGGR[B/"W-JS9>!SV/JIP<-W]
MB"!M&2:/,JTG3=F=/5&84`%`!0`4`%`!0`4`%`!0!\*?M9Z5/I_QGU"ZF>-H
M]2MH+J$(22JA!%AN.#NB8\9X(^@`/N'2=0M=6TJSU+3Y?.LKR%)X)-I7>CJ&
M4X(!&01P1F@"U0`4`8'C'P;X>\96"VGB;2;;4(D_U;2`B2+)4G8ZX9,[5SM(
MR!@Y%`'R'\:O@!J?@WSM6\+"YU7PW%#YL[2,IGM<8#%P`-Z\[MRC@!MP`7<0
M"7X%?'K4?"EU9:)XMN9+SPPJ+!%(4W2V`!.""!N=!G!4Y(`&W[NU@#ZVUCPY
MX:\86,5QJ%A8:E#<0H8KM,%FCSN79*OS;3G/!P03V-)I/<N%24/A9\[>*?#V
MO?![Q;!JVB3O)ILC%8+AAE9%/)AF`P,X'MG&Y<$$+BTX.Z/0A.->/++<]N^%
M?Q#L_'&F%'"6VM6Z@W-J#P1T\Q,\E2?Q4G![$ZQE<XZU%TWY'=U1@%`!0`4`
M%`!0`4`>!?%;]I#2/#%^VF>$[>V\07?DDO>)<_Z-"Y'R`%0?-]6`*@<#=G.T
M`\[\*?$3XW_$G69)/"DD=I8LX1Y([&);2VQL#?O)59B?F#%0S-@D@8XH`^C=
M8^'6D>*?#FEZ;X]7_A)+NRR_VZ5?LTC.?O$>3MVJ>/E!QA5SN(S0!U6DZ?:Z
M3I5GINGQ>396<*001[BVQ$4*HR22<`#DG-`&=<>+O#=M<2P7/B#1XIXF*21R
M7L:LC`X(()R"#VI<R+5.;U29'_PFGA;_`*&71/\`P/B_^*HYEW'[*?9F_3,P
MH`\,^+W[/6D>,[^\UK0;K^Q]<GR\B%-UM</AN64<HS$KEQD<$[2Q)(!Y#\&O
MBCJ_PC\1S^#O'<%S'HT<Q22*0;I-.<\[TQG=&V=Q"Y!!WKDDAP#[(1K/5=-5
MD:WO=/NX<@@B2*:-A^(92#]"#0"=M4?+_P`5/"LOPQ\6Z=JOAJ^>""Y9Y;0`
MDR6[+C<A)X9<.`,YR"0P/5L)+E=T>G1J>VBU)'NWPK\;Q>./#INVC2WU"W81
M74"L"`V,AU&<A6YQGN&&3C)UC*Z.*M2]G*W0[.J,0H`*`"@`H`\"_:_\:7WA
M[P=8Z#IZ;/[?\U)[D2,K1Q1F,L@`QG?O`.3C;N&#NR`#@/V??@):^(]*M_$W
MC>.Y&GS;_LNF$&+[0A5=DQ=6#!3EL+A2<*V2IP0#ZWM+:"SM8;6TAC@MH4$<
M442!4C4#`50.``!@`4`>6?M+^-=:\"_#VWO_``W/';7USJ$=J9WB$AC4H[DJ
M&RN3Y8'(/!/?!`!-KC:AX]^&=C8ZD6TB_OK>WFO%6+(5\*[(4;YE`;MN!&!D
MGD'RZN/U<4NIZF'PG*U-OH>/WOP>UZ+SVMKK3[A$W&-=[*\@'08*X!/UQ[]Z
M2QD'NCKY6<[J'@'Q18PK+/HUPREMH$!69L_1"3CCKTK58BF]F+E8G@WQ;K?@
M369YM-(CD(,5S:7*'8Y&1AUR""IS@\$<CH2#O&5M495*4:BM(^HOA7XWB\<>
M'3=M&EOJ%NPBNH%8$!L9#J,Y"MSC/<,,G&3O&5T>96I>SE;H=G5&)\^_MB>#
M(-4\$P>*H1''?:.ZQS,<`RP2.%VYVDL5=E(!(`#2=S0!?_9(\:?\)%\/VT*=
M+DWN@;8FGEDWK+%(SF,`GD;0I3;T`5<'G``.T^.NC_VQ\-=4V0>=<66V[B^?
M;LV'YVZ@'$9DX/X#.*B:NC?#2Y:B/!?@7XFE\/>/+.`EVL]49;2:-<GYF.(V
MQD#(8CDYPK-@9-90=F=V)I\T&^Q]<UT'E!0`4`%`!0!\<_MK:A=2>/="TUY<
MV5OIGGQ1[1\KR2NKG.,G(B3@G'''4Y`/I?X0:K9:U\+_``O>Z:D<=L=/BB\J
M(.$B:-?+=%WDL0K*R@DG.,Y/4@&WXE\0Z1X8TJ34O$&HVVGV29'F3OC<0I;:
MHZLQ"G"J"3C@&@#X_P#'OB";X[?&/3]'TN20^%[%V$,BPF-UAPIFE)PQ!8J`
MNX`?ZL$`ELY5ZJI0<C6C3=2:B?3E?.GNA0`4`<QXV\%Z;XLA0W1>"]B4B*YB
M`W`<X5A_$N3G'!ZX(R:VI5I4]MA-7/GNRN-4\'>*8+@1O;:GITX8QN2`2.JG
M:1E6'!P<%3UP:]:$TTI1,9Q4DXL^R/!/B&+Q5X7L-:@@>W2Z4DQ.02C*Q5AD
M=1E3@\9&.!TKJ3NKGCU(<DG$X?\`:A_Y(7XF_P"W;_TIBID'@/[%O_)4M4_[
M`TO_`*.AH`^RM1LX-1T^YLKR/S+6YB:&5,D;D8$$9'(X)Z4#3:=T?$UN9?"/
MC:(W*)<3Z/J(,B1N0LC12<@,1D`E>N/PKFV9[#]^&G5'W!72>,%`!0`4`%`'
MS'^V5X%NKVVL?&MC\\5C"+._1I`-B&3]TZKCGYY&5N2>4P,!C0!S_P"R!\1;
M72+^Y\&:JUM;P:A,;FSN78JSW!")Y1[?,%!7IR"/F+*``>Y_%'X-^&OB1JMG
MJ6M3:E;7MM#Y`DLIE7S$W%@&#JPX+-@@`_,<YXP`9/A'X5^'?AO<W']ABZN+
MFY0;[J\=7E"Y^XI55`7(SP,D]2<#'DYA)\ZCTL>I@8KE<NMSIZ\X[@H`*`"@
M#QC]H.VA6ZT2Y6,"XD26-WR?F52I48SC@NWY_3'H8*6C1$EK<[']EK4?-T#7
M-,\K'V>Z2X\S=][S%VXQCC'E=<\[O;GTZ;T/-QD?>3-O]J'_`)(7XF_[=O\`
MTIBK0XCRO]AS_F=?^W+_`-KT`?4]`'R=^T+H\6E?$>XE@V!-0@2[*)&$",<H
MW3J24+$\<L?J<*BLSU,++FI^A]/>%M0EU;PQI&HW*HL]Y9Q3R+&"%#,@8@9)
M.,GUK9.Z/-FN632[FG3)"@`H`*`*&OZSIWA[1KO5=:NX[/3[5-\TTAX4=/J2
M20`!DDD``DT`?G?\6+[POJ/CS4[KP-926>B._P`BMPCM_$\:8!C0GD(<X_V0
M0B@%[P_\4_B#X0@%EI_B#4;>$PQ"."[43K'&%S'Y:RAMBE6!&W`(V]0!233V
M&TUN?>&MK.MK8+=R1RW(0B62*,HC-A<E5)8J">@)./4]:\W,OL_/]#T,O^U\
MOU,BO+/1"@`H`*`/-OCW_P`B?9_]?Z?^BY*Z\'\;]"9;#_V5/^9H_P"W;_VK
M7KTNIYN-^R>G_%WPT_B_X:^(=$A61[FXMBUND;JA>9")(URW`!=%!SC@GD=:
MU.$\<_8X\.:WX?\`^$O_`+>T;4M,\_[)Y7VVU>'S,>=G;N`SC(SCU%`'TE0!
M\O?M-3Q2_$&U2*5'>'3HTD56!*-OD;!]#AE./0CUK"IN>E@U[GS/H+X>_P#(
M@^&O^P9;?^BEK:.R.&K\;]3?IF84`%`!0!\F_MMZ]OU7PUX?BDN5\F&2^F3.
M(GWMLC.,\LOER]1P'X/)H`L_LU>`+?3="B\5:G:YU6\W&S,@.8(.@8*0,,_)
MW<Y0K@C<V?(QU=RE[-/1'J8.BE'G>[.&_:Q@F7QYI=PT4@@DTU420J=K,LLA
M8`]"0&4D=MP]:Z,O:]FUYF&.3YT_(^O[^]MM7T73-5T^42V-U$LT,FTKO1U#
M*<$`C(]<&HS&+Y8R+P$ES-&57E'I!0`4`%`'FWQ[_P"1/L_^O]/_`$7)77@_
MC?H3+8?^RI_S-'_;M_[5KUZ74\W&_9/?JU.$*`"@#XS^+NH_VI\2O$-QY7E;
M+HV^W=NSY0$>>@Z[,X[9QSUKGF[L]>A&U-(^M?!UG/IWA'0[*\C\NZMK&"&5
M,@[76-01D<'D'I6ZV/+J-.3:[FO3("@`H`*`/D/]MO2/)\4^&M9\_=]KLI+7
MR=GW/*?=NW9YSY^,8XV]\\`'L7PV_P"2=^%O^P5:_P#HI:^=K_Q)>K/>H_PX
M^B/%OVO?^93_`.WK_P!HUWY;]KY?J<68?9^?Z'O'PLU&'6_@CX2N[19$C@LH
MK=A*`"6A!A8C!/!9"1[8Z'BML?%NE?LS'!22JV[H\=\%^(-1^%?B:;PGX\N)
M)]*U"X>XT_6Y78HS,1N#EB=H+'+?W68DY5MXYJM..(C[2GNMT=-.<J$N2IL]
MF>ZUYQW%?4;ZTTRSDN]1NH+2TCQOFGD$:+D@#+'@<D#\:<8N3LD)M)79F^$_
M%&C^+=.DO_#]Y]KM(Y3"S^4Z8<`$C#`'HP_.KJ4I4W:2)IU(U%>+.0^/?_(G
MV?\`U_I_Z+DK?!_&_0<MA_[*G_,T?]NW_M6O7I=3S<;]D]^K4X0H`*`/,M=^
M#GA._P!=N]<OYK^)99C<W$(N%6$G.Y\DKN`)R3AAC)QCC&<HQ6K.F&(J64(H
M]%T^]M]1LH;NRF6:WE7<CKT(_H>V.U5"<9Q4HNZ9C4IRIR<)JS18JB`H`*`"
M@#PS]KOPC)K_`,.8M7LK?SKW0YC,Q&\L+=QB7"C(."(V)/148Y'((!Q/[,/C
M&TN_"W_",W<T$%_8RM]EC9@K7$;EI#M!;+,IWYP``NWWKR,?1:GSK9GJ8*JG
M'D>Z+/[5_P#R3O3O^PK'_P"BI:67_P`1^G^0\=_#7J>A_LXQ&;]GS0$7.[;<
MD8&<XN93C]*]'$P<Z4DC@P\U"HFS@-7^'NO>.OB'>2^/7C/A;3G9M+BLY%3S
M0Q3Y6X+XVIA\D'<?D.*\V.(A2IKV7Q/?^OZ\ST)4)U:C]I\*V/,?ASX"US6-
M:\7)X*\37>E:38W#P6]W%,X6^96;R@7CPI&WDL,XW@A3NKKK5X1C'VD;M_@<
MM&C*4I<DK)?B8'B71M7N?A]X9\9>(->O]8L+J[D@:SGN'\R'YF!\MVWCYA"<
MG`P=O#=M(3BJDJ<8V=B)PDZ<:DG=7/L#0-#TSP]IR6&B6,%E:+@[(4QN.`-S
M'JS8`RQR3CDUXLYRF[R=SUX0C!6BCA_CW_R)]G_U_I_Z+DKHP?QOT"6Q/^RK
M/*UOXE@:5S`C6[K&6.U682!B!T!(5<GV'I7KTNIYN-6S/>JU.$*`"@"EKEI)
M?Z+J%G"566XMY(D+'@%E(&?;FLZL'.G**ZHUH35.K&;V33/'/!WB>Z\$W]UI
M>L6LOV;>6DB51YD;X'(YPP(`[XQ@@^OAX;$RPLG3J+0^DQF#AC8*K2>MODU_
M7^3\O:-/O;?4;*&[LIEFMY5W(Z]"/Z'MCM7O0G&<5*+NF?,U*<J<G":LT6*H
M@*`"@`H`^4_C)^S?J-QK-]K7@!;)K:X?>=''[@Q$[0?+9CL()+M@E`HX4'@4
M`>5^,O"OQ4UBPN[WQ7I6LSVGAV+RI);E`%1`2"Z_\]ONY:1=W`!9L8-9PI0A
M?E5KESJ2G;F=['T1^QG<SS_"F]CFFDDCM]6ECA5W)$:^7$VU1V&YF.!W8GO6
MA!Z+<QB*YEC4DJCE1GV-?-U(J,W%=&?04Y.44WU1@>$_"^C^$M.DL/#]G]DM
M))3,R>:[Y<@`G+$GHH_*G4JRJ.\F*G3C35HH/"?A?1_"6G26'A^S^R6DDIF9
M/-=\N0`3EB3T4?E14JRJ.\F%.G&FK11M5F6>>?'2VFG\%1R1)N2WNTDE.0-J
MD,N??EE''K75A&E4^1,MBC^RSJ$4>KZ_IS*_GW$$4ZL`-H6-BK`\YSF5<<=C
M^/KTF>?C5HF?1-;'GA0`4`%`'.^.?#4?B;2!`'6*[A;?!*RY`..5)Z[3WQZ`
M\XQ7+B\,J\+=5L=N!Q;PU3FW3W/'/"'B.\\+:RHG-S]C5V6YM,XYZ$[3T8$#
MT/&,C->'AL1+#SUO;JCZ3&82&*IZ6O;1_P!=/^'/>-%U.WUC2[>_LBQ@G7*[
MEP00<$$>H((KZ*E5C5@IQV9\G6HRHS=.6Z+M:&04`%`!0!5U;3[75M*O--U"
M+SK*\A>">/<5WHZE6&001D$\@YH`^0_V/M<DT'XC:QX7U*/[++J4)7RIHG$H
MN("Q\L_W<(TQ.X=5`R#P0#ZA\01%+\OR5D4$<>G&/T_6O%Q\'&K?N>O@IIT[
M=C,KB.L*`"@"AX@LY-1T'4K*!D66YMI(4+G"@LI`SCMS50?+)-]P9X)\(-=/
MA/XC63Z@[VMO*S6=X'55V!N!NW8VA7"$G@@*?H?=A)7N<>(ASP:ZGV%70>2%
M`!0`4`%`')>//!]IK^GS3V\*QZJBEXY4`!E('",>,@X`!/3Z9!XL7A(UHMI>
M\>C@,?.A-1D_=_+S7]:GD_@OQ#/X3UR1IX93`W[JY@.588/7!_B4YZ^I'&<U
MXV%Q#P]35:=4?08W"QQ=*R>NZ?\`71GT'#)'-$DL+K)$ZAD=3D,#T(/<5]*F
MFKH^/::=GN.IB"@`H`*`/C/XGRI\)OVGK?Q'%!&]C<NNHM"A:1_+F#1W!PQ'
MSEO.91G:,KVX`!]>ZW;B:Q=@,O'\P^G?]/Y5R8VGSTF^J.K"5.2HET9RU>&>
MP%`!0`4`>+_&WPG#;;-?TZ#8)9-MZJ`XW'[LF`,#)R"<\DKQDDUWX2JW[C(D
MNIV7[//C[[?:1>%-3_X^K6)FLYVDSYL8.?+()SN4'C'&U>@V\^I3ET/-Q5&S
MYT>W5H<04`%`!0`4`>5?&/PY*[C7K81>4B+'<J`%;.<*^?XNH7U&!U'3QLSP
M[?[U?,]_)\6DO82WOI_E^H_X+ZXIBN=&N9U#!O-M48G)!SO`[8&`<#U8\\X>
M5U]'3;]/U%G6&U5:*\G^G]>AZE7L'@A0`4`%`'S[^V9X:?4O`>FZ]`LCR:/<
ME90'4(L,V%+$'DG>L0&/[QR.X`-K]E3QO_PE/PY32KI\ZEH.RU?C[T!!\EN%
M`'"E,9)_=Y/WJ`.YU&W-M>21XPN<K].U?/8BG[.HXGNT*GM(*1YKX[\?2Z%J
MAT[3;>"6>-5:62;<0N03MVC'."ISGOC%=N$P"JPYYO0^MR?A^.+H^WK2:3O9
M*WWWU\U:QRTOQ1UUU`6#3XSN!RL39.#DCECP>GX\8/-=BRRBNK_KY'LQX6P:
M>KD_FO\`([3PK\0[#6[Q+.Y@:QNI&Q%N<,C],#=@88\\8[=<G%<&(R^=*/,G
M='@9CP[6PM-U82YXK?2S7RUT^?RMJ=;J5A:ZG8365_"D]K,NUXVZ$?T/<$<@
M\UP1DXNZ/G3YW\?>#M3\!ZM93B8"WN6::PN(9?G4*P(R<`AP"AR!C)X/!Q[<
M;\JD^J.:,XS;CV/2_A?\:X(-/BTSQK+.9(OEBU$(9-R`'B4#YBW`&X`YSSC!
M8[1J=SDK85MW@>YZ1J=GK&F6^H:9<)<V=PN^.5.A'\P0<@@\@@@\UJG<XI1<
M79EN@04`%`$5W;Q7=I-;7"[X)D,<BY(RI&",CVJ914DXO9E0FX24H[IGS?JM
MG=>&O$DL`?%S93!HY,#G&&1L<CD8..?0U\M4A*A5:ZI_\,?:TJD,314NDE_P
MY]&Z==QW^GVUY"&6*XB65`PY`8`C/OS7U,)J<5)=4?%U(.G-P>Z=BQ5$!0`4
M`4-?T;3O$.C7>E:U:1WFGW2;)H9!PPZ_4$$`@C!!`(((H`^#K:77O@/\7V:2
M"25K-W4)(3$FHVC$@-\I(PP`8?>"NHR"5(H`^VM#UK2O'7ABUU70KJ&:*54?
M`D5F@8JK&.3:3M<!AE<\'%<^)H>UA9;G1AZWLI7>QYGX]^'W]M:A+>V4ZV]^
M0%E27)20C`!R,[2`.P(.!TY)X\-C707LYK1,^^R;B'ZK25*I&\.C6ZOK\]?2
MWGL<38>!-=LM6CDN]#BU*TBDP\7VM8UF7IPP8,/4'Z9!Y%>A_:%!KXK?)GT-
M;/L'5HM4ZSA)K1\K;3]+-/S_``?4]#O]'N?$D=C:WFD:?H&@PR&XETZS96DF
MFY4%F50`-OISC\-O+6S&,4U3U?<^6HXRG@7.I3JRJU6N53E>RCOHFVV[]]/Q
MOVMA;FZNDB&=I.6([#O7F4*3JS43YZM45.#D=3?V5KJ-I):ZA;075K)C?#/&
M'1L'(R#P>0#^%?0GAIM.Z/G'QQ\#=9M=0FN/"WD7UE+*2EKO$<D"DL0N7;#*
MHVC=NR2>G>L94WT/0IXN+5I'F'_$_P#">H?\Q31;V2+_`*:6\C1D_@2N5^F1
M[5&J.GW9KN?8O@&YUF\\'Z7<>)H/(U=XLSH4"'J=I*CHQ7:2.,$D8'0=$;VU
M/)JJ*FU'8WZ9F%`!0!Y5\<-/_P"09J21?WH)9-W_``)!C/\`O\@?7M7C9K3^
M&=O+_+]3W\DJ_%3;\_\`/]#K?AG>M>^"M.:29998E:%L8R@5B%4@=#MV_H>]
M=N`GS4(W>W]?D>?F=/DQ,K*R>OW_`/!.HKL.`*`"@`H`XOXK?#K2/B/X<;3=
M57R;N++V=\BYDMG/<?WE.!N7."`.A"D`'Q[X<USQ9^S[\0KZTO;&.5I$5+BW
MDD?R;N'>"LL3#`S@,%<@[=S@KG(H`]VT']HGP/XBTQI/$7VKP]J,0^XT3W*/
MDMPCQKD\`$[E7!;C.":YL3AXU5?JCHP]>5)^10UCX]^"+#R?LL]_J>_.[[):
ME?+QC&?-*=<]L]#G'&?-C@:KWT/0EC:2VU/-?$/[1VLW=L(M"T:TTUV1U>6:
M4W#`D?*R<*`1R?F#`\<<<]<,OBG[SN<L\?)KW58[']F+XN:]KWCJ;0/%6I17
M4=[;,]H3:JC^<GS%08U`P4\PG=_<&""<'LIT84U:"L<M2K.H[R9]45H9A0`4
M`%`!0`4`%`'G7QMN(ET"PMF;$\EUYBK@\JJL"<_5E_.O+S62]FH];GM9)!NK
M*71+]?\`@$OP4_Y%6Z_Z_6_]`2JRK^"_\7Z(G.OXZ_P_JST"O2/'"@`H`*`"
M@#Y]_;4MH&^&^C730QFYCU9(TE*#>JM%*64'J`2BDCOM'H*`/-?@;\%O#OQ*
M^'MYJEU>ZM8:M!<RV@>.6-X2P165_+*!L#S`"N_G:>1G``+/_#-'_4V?^4W_
M`.VUYG]I?W?Q_P"`>C_9_P#>_#_@GH.E?!3P5IVE7-HNGR7$\]O)`U[<N))5
M#?Q*"-BNO&&"@C'N<\LL95D[W.B.$I)6L?+VGWFN?"[XB"X@$<>LZ/<,N)(R
MT<@P5/#`$HZ,<'@X8$$'!KVX34XJ2ZGD3@X2<6?H)X!\3VOC+P=I/B"Q79%?
M0AVCR3Y3@E73)`SM<,N<`'&1P:HDWZ`"@`H`*`"@"KJ>HV>EVC7.H7,5O`/X
MG;&3@G`'<X!X'-14J1IKFD[(TI4IU9<L%=GSYX@U:]\7>(DE,2B:9E@MX5(`
M4$_*N3C)R>I]>PX'S-:K/$U;]]$?88>A#"4;7T6K9[KX0TF30_#EEITTJRRP
MJV]E&!EF+$#V&<9[X[5]%AJ3I4E!]#Y3%UU7K2J)63-BMSF"@`H`*`"@#P+]
MM+_DENE_]AF+_P!$S4`6OV.["YL/A'/<W<8C@O=2FN('+`[XPD<9;@\?-&XY
MQTST(-)M)78TFW9'=U\R?0A0!X[\??A'=^+--;Q-X8LXY-6LU(NK>-3YM[&`
M,%<'YG0#IC+`X!)55/KY>Y.+OL>7CU'F5MSQGX'_`!:U'X:ZR4D$EYX=NG!O
M+('E3T\V//`<`#C@,!@XPK+Z!PGVYX#\;:#XYT:/4?#M_'.I16FMRP$UL3D;
M9$SE3E6'H<9!(YH`Z2@`H`*`.:\7>,=.\-8BN!+->NF^.!%QD'(!+'@#*X[G
MVKDQ.,A0T>K['=A,!4Q.L=%?<\4U?5]8\6:E']H\VZG^80V\$>0@ZD*H]N_)
MP!D\5X-2K5Q$M=7V/IZ-"CA8/ET75L]8^'G@F/08EOM159-5=>!U%N#V'JWJ
M?P'&2?9P6"5%<\_B_(^?S',77?)#X?S_`*_KR[BO0/*"@`H`*`"@`H`^4_VB
M_#WC7XC?%FPT#2="O5T>P18K>^EA86I:15>65I=F```JE<MS'P-S;:`/H#2M
M$C\(^`]'T*R:/R[*".W>2*(1"4A?G?:,X+-ECR>2<DUQ8^3C2TZLZ\%%2J:]
M$4Z\4]<*`.KTBU>TM-DA&]FW$#MTX_2O>PE%TJ=I;GBXFJJD[K8\/^-7[/5K
MXQU6;7?"MU;:7J\_S7-O,A$%RY89D)7)1L;B<*P8XX!+,>DYSP'2_!GQ9^&W
MB.*]T;0M;M=2,)'FV-N+R-D;(*ML#H>5SM;D$*<=#0!]F?"OQ/JOBOPE#?>(
M-!O="U:-S#<VUU`T0=@`?,C#?-L.>,]"",G&2`=?0!YO\0_'S:;*VFZ%(IO4
M;]_<8#"(C^$`\%O7TZ=>GE8W'\CY*>_5GMY=EGM%[2LM.B[^?]?EOYUH>C:M
MXNU240NTTP7=-<W+DA1C`W-R<G&`.>GH#CRZ5&KB9Z:^;/9KXBCA(*^BZ)'M
MOA/PIIWAN`?94\R\9`LMR_WGYSP/X1GL/09SC-?08?"PH+W=^Y\OB\;4Q+][
M:^B.@KI.,*`"@`H`*`"@`H`*`!@&4JP!4C!![TFDU9C3:=T5)=-LY&!:!0<8
M^7*_RK"6%HR=W$VCB:L592)+:T@ML^3&%)ZGJ?SJZ=&G3^%$5*TZGQ,GK4S"
M@`H`*`(KNXBM+2:YN&V00H9)&P3A0,DX'M4RDHIR>R*A!SDHQW;/F35KS^T-
M5O;W9Y?VF9Y=F<[=S$XSWZU\G4GSS<N[/N:5/V=.,.R2/HCPEHL>@:!:V"A3
M*J[IG7^.0_>.<#([#/.`*^GPU%4::@?&XO$.O5<^G3T_K\38K<Y@H`*`"@`H
M`*`"@`H`*`"@`H`*`"@`H`*`"@"OJ-I'?Z?<V<Q98KB)HG*GD!@0<>_-3."G
M%Q?5%TYNG-36Z=SC].^&FCV&H6UY#<Z@TMO*LJ!I$P2I!&?EZ<5PPRVE"2DF
M]'_70]*IF]:I!P:5FK=?\SN*]`\H*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`/_]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]M86QE,2YJ<&<`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`W,C<S`#$P-3$U-#,Q,#8W`#`R,C8U,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#_V/_@`!!*1DE&``$"
M`0#(`,@``/_``!$(`+X`E@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'!P8(
M"A$+"@D)"A4/$`P1&18:&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q-#`K
M-"@K+"L!!P<'"@D*%`L+%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*__$`:(```$%`0$!`0$!````````
M```!`@,$!08'"`D*"Q```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A
M!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%
M1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9
MFJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?H
MZ>KQ\O/T]?;W^/GZ`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1``(!
M`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P
M%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#
M`0`"$0,1`#\`^J:`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`)`ZF@"K=:A:VJDSSQH!ZM2N-1;V.<U3Q]H=@"&NE=AV6DY
MI&T</-]#G+WXOZ/%@0HSMW&<8J?:(T6$EU,>[^-$8F9;>U4J!_$W-+VAHL'W
M9RNI?&C4VE/D2QQ@<;53-3[1FBPL%N9%U\7/$5V1Y<URJKWBC`S2YV6L/370
M@N_B#XIGMP%N;UU<<C<%/Z4N9E*C370S/^$N\2_W]2_\"6_QHNRO9Q[%:[U_
M6;P@W<%U.1T,LI;'YTKC44MD0?VE?_\`0/?\Z"@_M*__`.@>_P"=`%^'Q?K-
MLBI-+J,$(X&R=L#\`:=V1R1?0Z#1_'&KQ`-::M<,"<[9'W9_.CF9+HP>Z.Y\
M+_%"\BN2FM8FB;HR+@K5QJ=SGJ816]T]@TO4+?4K1+BU</&PR"*U3N<,HN+L
MRW3)"@".XFCMX7EF8)&@R6)X%`TKGAOCWXG"2_:VTR]B@A0X+%P"U8RGV/0H
MX9)7D>9ZIXLCOF:*35RTI/16))J+LZE!+9&796L>H1LYN;EUW?Q@K2*+8T6T
MWABI+>N:`+265NA)$:Y/6@!ZVL"MN$2`^N*`)515&`H`^E`"T`%`!0`4`%`"
M,JL,,`10!GWNEQ3A3&3$RG(*<4`,M+R2&X^S7H"DG]V_9A_C0!ZQ\*?%)TZ_
M73[N3_1YCA2>QK2$K:')B:7,N9'NBD$`CH:V/-"@#(\4Z''XATHV$UQ+!$S!
MG,?5A@\'VY_2DU=&E.?([V/-I_@/X>6-C:,!,3D-+&&YJ/9HZ%C)=4<3K7PA
M\46\\CZ?<6AA4X0+%R?>H=-F\<5![G,:MX0\6Z1&TEW*1&O4I;YJ>5FJJP>S
M,^WOFA_=W'GR29Y)B(I6-+H0ZS^]\L6MQG.`=E`RU8W4MP[B2W>(*>"W>@"Y
M0`4`%`!0`4`%`!0`4`5K^V6YMV1AR.0?0T`1Z->O*G.4FA;!^H[T"/I_X>:U
M_;?AFVG<@SH/+D'N*Z(NZ/)KPY)M'351B%`!0`4`-DBCD7$B*P]",T`4)]$T
MV8-YEE`=W7Y!2LBE.2ZF#KG@+1]0MV6.W6&7'RL@QBDX)FL,1.+/#?$NA76@
MZ@]M=(0N?D?'#"L&K'I4ZBFKHR*1H%`!0`4`%`!0`4`%``:`,6W<6^O2P[3^
M]7<#0![-\#]0DCUJYL<DQ31[\>A%:4WJ<>,C[J9[96QYP4`%`#9B1$Y'4`T`
M9GABZFO-)26X??(789^AI(J2LS5IDA0!R7Q(\/C6]`E\I,W,/SI@<GVJ9JZ-
MZ%3DD?.\L;Q2-'(I5U."#VKG/53N,H&%`%BWL[FX($$$CY_NJ318ER2W+<^A
M:I!$9);&=4'4E#3Y6)5(OJ9I!!P1@TBQ*`"@`H`P=1#1^(;*12,."I%`'I7P
MNN?LWC"R)<HKG:??/:JAN88A7IL^C*Z#R0H`*`(+Z40V4\K=$0D_E0-;F'\/
M;I;WPM;7,8(21F8`_6DMBJBM(Z.F0%``1D8-`'G_`(S^'EMK,C7-DP@N3UXX
M:HE"YU4L2X:,YNP^$MPQ!O;Q5&>0@J53-98Q=$=/H_PSTBRYN`UPV<C=5*",
M98J;V.PL]+L;*(+;VT4:CT6JL8.3>YQ&L>,;V_OKO3O"NDIJ1M_EEE=MJ*WI
M[TF^QI&"2O)V/-?&.G7RO+>7NC2:?(.7$?SHWOD=*SE$[*-5;7.6`.Q7P0K#
M(..M9G5<2@84`8FK?\AK3_J:`.W\#_\`(TZ=_P!=13CN95O@9].5TGCA0`4`
M4]:_Y!%[_P!<7_D:&-;G-_"3_D0M-^C?S-*.Q=7XF=A3,PH`*`"@"E/JEI!?
MPV4LRK<S`E(\\F@=G:Y=H$17:/):S)&<.R$*?0T`C#\$:!_PC^D""38UR[L\
MLBC[Q)I)6+G+F9N7-O%<PO%,BO&XP01U%,@\9FT&/4-.U_3;6)0VE7!\ACUV
MD9(K-JZ.VG4<9)OJ>9LI5BI&"#@UB=XE`S$U;_D-:?\`4T`=OX'_`.1IT[_K
MJ*<=S*M\#/IRND\<*`"@"GK7_((O?^N+_P`C0QK<YOX2?\B%IOT;^9I1V+J_
M$SL*9F%`!0!7U&\AL+&:ZN'"11*68DT#2N['(>"M.75KIO$]^C&YGR+=6_Y9
MQ]L?6I7<TF[>ZCMZHR"@`H`CN)D@@>61@J("Q)["@#C/`-HMT-9U49\G4IRR
M*1_".,U*-9NUEV/&O&=@--\1WEN/NAR1^-825F>G2ES03,.D:F)JW_(:T_ZF
M@#M_`_\`R-.G?]=13CN95O@9].5TGCA0`4`4]:_Y!%[_`-<7_D:&-;G-_"3_
M`)$+3?HW\S2CL75^)G84S,*`"@#A?'DHUW4+3PQ:R*6E82W>#RL0/3\34O70
MUA[JYCM;6!+:VC@B4+'&H50.P%49$M`!0`&@#BO$6JKKFJ?\(YI<FY^MY(O(
MC3T^IJ7KH:17*N9G6V%I%8V<5M;H$BC4*H%40W<\=^-&BBVOX=2B'RS?*_UK
M&HNIWX2=URGF-9G:8FK?\AK3_J:`.Y\"JS^*M."@D^:.E5'<RK?`SZ:KH/'"
M@`H`IZR"VDW@49)A8`?@:&-;G'?"W5;&U\'Z?:7-U%#<KN!C=MK`Y/8U,7H:
M58OF;.[CE2108W5@>X.:HR'4`(_W3]*`/-OA;IR3ZYXAUNXD>6]DNF@#,?NH
MIX`J8]S:J]%$]*JC$*`"@#+\2WD]EH\\MI"\UP1M14&3D\9I,J*NREX,\/Q:
M%IOS`/>SGS+B4CEF-"5ASES,Z&F097B31+;7=-DM+M<@CY6[J?6DU=%TYN#N
MCYR\3:)<:#JLMI<*<`_(V.&'K7/)69ZU.:G&Z.0UW*75C*H^828SZ"D:'HWP
MKY\9V'U/\JN&YSXG^&SZ+K<\H*`"@`(!&#TH`P-:\(:+K`S>649?LZ_*1^(I
M-(N,Y+8Y6WTY/!GC'1K.QN+F6UU+?&T4LA8)M&012V9;?/%M]#TFJ,1'^XWT
MH`X7X4?\>VN?]A"3^=3$UJ]/0[NJ,@H`*``T`%`!0`4`<C\1/#4.N:1))L_T
MJ%28V_I4RC=&]"JX2\CYD\26D\D*Q1J3(DHR/3!YKG/5/1_@W;"?Q=`6)!BC
M+#Z@5=/<Y\4[4SZ"K<\L*`"@`H`*`.#^)7^CZQX4OH_]<FH"(9Z;6!!J6:T]
MFO([P=*HR$?[C?2@#BOA?;36]MK'G1LF^_D9<CJ,]:F)K5>WH=M5&04`%`!0
M`4`%`!0`DBAT*L,@C!H`\$^)_A>32M4>[MHC]DE.20.AK"<;,]/#U>:-GN2?
M!4'_`(2XG''DM3I[AB_@/>*V/,"@`H`*`"@#F?'-I%<6^F22KEH;Z)T/H<X_
MK29<'OZ'3#I3("@!%55'R@#Z4`+0`4`%`!0`4`%`!0`4`5[ZRM[ZW:&ZB62-
MNH846&FT[HS]$\.:9HLCO86RQNW5N])12+G4E/=FQ3,PH`*`"@`H`P?&/_'E
M9_\`7W%_Z$*3+AN;PZ"F0%`$-Q=06ZEIYDC`[LV*`L96H>*=(L$#7%[$,C(`
M.2:5T4H-F9_PL+0/^?IO^^#1S(KV4C33Q3HY\K=>Q(9!E0QQFBZ)Y)&O#/%.
MH:*17![J<TR22@`H`*`"@`H`*`"@`H`*`"@`H`R_$FD+K>FFT::2'YU=7C."
MI!R*35RHRY7<P#:^+=-D"VES:7UN,`+,"K8^M+4J\&5=3M_&^IWOEP3V6FV6
M!EER[Y[XHU&N1+N$?P[AN9/-UG4KR]<XR&?"_E1RA[6VR.C@\+Z/"L06QB)C
M&%+#.*=D1SLN?V1IW_/E!_WP*+"YF4]4\+Z1J<82ZLHF"]"!@BBR&IR6POA_
MP]::%YHLVEVR')5W)`^E"5@E)RW-FF2%`!0`4`%`!0`4`%`!0`4`%`!0`4`%
M`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`
M4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4
M`%`!0`4`%`!0`4`%`!0`4`%`!0!__]D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M86QE,BYJ
M<&<``````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-#<V`#$P-3$U-#,Q,#8W
M`#`R,C8V,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#_V/_@`!!*1DE&``$"`@!.`$X``/_``!$(`+X`E@,!$0`"$0$#$0'_
MVP"$``8$!08%!`8&!08'!P8("A$+"@D)"A4/$`P1&18:&A@6&!<;'R@A&QTE
M'A<8(B\C)2DJ+"TL&R$Q-#`K-"@K+"L!!P<'"@D*%`L+%"L<&!P<*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*__$
M`:(```$%`0$!`0$!```````````!`@,$!08'"`D*"Q```@$#`P($`P4%!`0`
M``%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8
M&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ`0`#`0$!`0$!`0$!````
M`````0(#!`4&!P@)"@L1``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^J:`"@`H`*`"@`H`BN[F"SM9
MKJ[FC@MH4,DLLKA4C4#)9B>``!DDT`<!K7QJ^'6C726]WXJLI)&0.#9J]TF,
MD<M$K*#QT)STXY%`!HOQJ^'6LW3V]IXJLHY%0N3>*]JF,@<-*JJ3ST!SUXX-
M`'=:7J-CJUA%>Z5>6U[92Y\NXMI5DC?!(.&4D'!!'U%`%J@`H`*`"@`H`*`"
M@`H`*`"@`H`*`"@"*[N8+.UFNKN:."VA0R2RRN%2-0,EF)X``&230!\T?$;]
MJ*Q6PNK+P'8W,EZV^--2O$5(X\$!9(X^2^1N(W[<';E3RM`'S%XE\0ZOXGU6
M34O$&HW.H7KY'F3OG:"Q;:HZ*H+'"J`!G@"@#*H`*`"@#T[PC\=/'_AJ10FN
M2:I;!V=K?5<W`<E=O+D^8`,`@*P&1TY.0#Z(^%?[1V@^)Y(=.\4QQZ!J90DW
M$DH%I*54$_.Q!C).XA6R,`#>20*`/>*`"@`H`*`"@`H`*`"@`H`*`"@#X>_:
M$^-4_CNZDT/P]))!X5A?DX*O?L#P[#J$!&50^S-S@(`>)4`%`!0`QFP<"@!5
M;.!WH`=0`4`>L?![XUZ]X&UFW35+N]U;PZ42"6RFF+F"->%,&XX0J/X>%8<'
M'RLH!]SZ!K.G>(=&M-5T6[CO-/NDWPS1GAAT^H((((.""""`10!?H`*`"@`H
M`*`"@`H`*`/#/VPM>_LSX5IID<EMYNK7L<+QR']X8DS(S(,]G2,$X(`?'4@T
M`?$E`!0`4`)0!&QR:`$H`<&(H`<K`_6@!U`'K'[/?Q3G^'OB>.UU*[D'A6^?
M%[%L,GE-C"S*`<@@A0V,Y4'AB%P`?>-I<P7EK#=6DT<]M,@DBEB<,DBD9#*1
MP00<@B@"6@`H`*`"@`H`*`"@#X^_;9U6>;QGX>TADC%M:Z>UTC`'>6ED*L"<
MXQB%<<=SUXP`?.5`!0`C'`H`CSGZT`)0`4`%`#PO'H:`%4]CUH`=0!]6?L=_
M$-YHY_`VJ31A84:XTLE54D;BTL><Y8Y;>!@G'F9.```#ZBH`*`"@`H`*`"@`
MH`^*?VS+F"?XK64<,T<DEOI,4<RHX)C;S)6VL.QVLIP>S`]Z`/!Z`$/`S0!&
M22:`'H.,XH`8PP:``=>*`'JH'UH`"V3@=:`$VG'O0`N[@^M`'1?#7Q/)X.\>
M:'KRO*([*Z5IQ$BN[0GY954-QDH6`Z=>HZT`?I=0`4`%`!0`4`%`!0!\"?M0
M_P#)=/$W_;M_Z314`>64`%`#"G/%`#02.]``#SSS0!)D`9H`;RQ]!0`O"B@`
M&3["@!2H(H`;LYZ\4`?I1\*/^26^#O\`L#6?_HE*`.IH`*`"@`H`*`,OQ5KU
MCX8\.:CK>JR;+*QA::3!4,V.BKN(!9CA0,C)('>@#\VO%6O7WB?Q'J.MZK)O
MO;Z9II,%BJYZ*NXDA5&%`R<``=J`,J@`H`*`$(!ZT`,88-``N,\]:`'$X&:`
M!5YR>M`#J`"@`H`_27X4?\DM\'?]@:S_`/1*4`=30`4`%`!0`4`?+'[9WC2^
MAFT[P7;)Y5E/"FH7,RR,&F^=U6,J.-H*;CG.3MZ;>0#Y8H`*`"@`H`*`$-`"
M%3V-`##G\:`#)]:`)%.1F@!:`);2VGO+J&UM(9)[F9Q'%%$A9Y&)P%4#DDDX
M`%`'Z?Z3I]KI.E6>FZ?%Y-E9PI!!'N+;$10JC)))P`.2<T`6J`"@`H`*`*NJ
M:C8Z382WNJWEM9646/,N+F58XTR0!EF(`R2!]30!^:OC/Q+J/C#Q/J&O:RT;
M7UZX9Q$FU%``554>@4`#.3QR2<F@#%H`*`"@`H`*`"@`H`2@`VCTH`*`%H`]
M8_9E\&3^+/BAI]T1(FGZ*ZW]Q*N1\R,#$F=I&6<`X.,JKX.10!][4`%`!0`4
M`%`&7XJT&Q\3^'-1T358]]E?0M#)@*67/1EW`@,IPP.#@@'M0!\<>)?V9/'&
MF>9)I#Z;K47G%(T@G\J4ISAV63:HZ#(#L03QD9-`'C>OZ-J/A[6;O2M:M)+/
M4+5]DT,@Y4]?H00001D$$$$@T`4*`"@`H`*`"@`H`*`"@`H`M:3I]UJVJV>F
MZ?%YU[>3)!!'N"[W=@JC)(`R2.2<4`?HA\(?`MK\/?!%GHT'S7;8GOI1(762
MX95#E<@87Y0`,#A1GG)(!VE`!0`4`%`!0`4`%`'SE^V9X/?4/#&F^*;2./S-
M*<P79"*':&0@(2Q()"OP%`/^M)XP<@'Q]0`4`%`!0`4`%`!0`4`%`'UY^R3\
M-+&STBS\?7-U]JO;V&6&VMV@4+:8E9&8,226(3`(VX#,.<\`'TE0`4`%`!0`
M4`%`!0`4`<W\2]&?Q#\/?$>E0VD=Y<W6GS);PR!<--L)C^]P"'"D$XP0#D8H
M`_-6@`H`*`"@`H`*`"@`H`*`/T:^"NGVNF?"7PC!8Q>5$^F0SLNXG+R*)'/)
M[N[''09P,"@#M*`"@`H`*`"@`H`*`"@#EOBIX@_X1;X<^(M96Y^RSVUE)]GF
M\O?MG8;8OEP0?WC(.1CGGC-`'YM4`%`!0`4`%`!0`4`%`!0!^BOP,U6#6?A!
MX2NK5)$CCT^.U(D`!W0CRF/!/!:,D>V.G2@#N:`"@`H`*`"@`H`*`"@#YW_;
M2CU>7P1HRV=EYVC17IFO;E5RT#A=D6>>%;S)`3C&0HR"0"`?'-`!0`4`%`!0
M`4`%`!0`4`?7G[%.O6+^%M=\/^9MU*&]^W;&*C?$Z(F5&<G:8_FXP-Z<\T`?
M25`!0`4`%`!0`4`%`!0!E^*/#^F>*="N=&UZV^U:;<[?-A\QDW;6##YE((Y4
M'@]J`/D?X@?LQ>)-+NC+X-GCURQ=\+#*Z07$0)8C=N(1@`%!8$$D_<`%`'(?
M\,_?$W_H6?\`R?MO_CE`!_PS]\3?^A9_\G[;_P".4`<AXN\"^*/!\C+XDT.]
ML8U=8Q.\>Z%F*[@JRKE&.,\`GH?0T`<W0`4`%`!0`4`;_@;Q=J_@CQ';ZUH%
MQY-W%\KHW,<R'&Z-U_B4X'N"`000"`#]$/`WB[2/&_ARWUK0+CSK27Y71N)(
M7&-T;K_"PR/8@@@D$$@&_0`4`%`!0`4`%`!0`4`%`!0`4`%`'@_Q]^#?A>\\
M!ZOK6@:19:3K&F6QN$>U7R(I(X\LZM&HVDE2V#@'(4%MH(H`^*:`"@`H`*`"
M@#5\->(=7\,:K'J7A_4;G3[U,#S('QN`8-M8=&4E1E6!!QR#0!]C?!K]H#2/
M%EA/;>,;G3="UFWR^^27R;:X3/!1G;Y6&0"I))ZC(R%`/;K2Y@O+6&ZM)HY[
M:9!)%+$X9)%(R&4C@@@Y!%`$M`!0`4`%`!0`4`%`!0`4`%`'+?%?_DEOC'_L
M#7G_`*)>@#\VJ`"@`H`*`"@`H`EM+:>\NH;6TADGN9G$<442%GD8G`50.223
M@`4`>\?![X,_$JZ\RYBU74O!.FW&/-?S9(IYMN\#]RK*3@_WRO#Y7=0!]CZ7
M:S65A%;W-_<ZA*F=US<K&)'R2>1&JKQG'"C@=SS0!:H`*`"@`H`*`"@`H`*`
M"@#EOBO_`,DM\8_]@:\_]$O0!^;5`!0`4`%`!0!?T#1M1\0ZS::5HMI)>:A=
M/LAAC'+'K]```22<``$D@"@#[A^"OP0TCX>>3JMY)_:/B9H=DEPW,5N3G<(1
M@$9!"ECR0#C:&*T`>O4`%`!0`4`%`!0`4`%`!0`4`%`'+?%?_DEOC'_L#7G_
M`*)>@#\VJ`"@`H`*`-KP9X:U'QAXGT_0=&6-KZ]<JAE?:B@`LS,?0*"3C)XX
M!.!0!^@'PI^'6D?#CPXNFZ4OG7<N'O+YUQ)<N.Y_NJ,G:N<`$]26)`.TH`*`
M"@`H`*`"@`H`*`"@`H`*`"@#EOBO_P`DM\8_]@:\_P#1+T`?FU0`4`%`$MI;
M3WEU#:VD,D]S,XCBBB0L\C$X"J!R22<`"@#[<_9>^&3^"_##ZUK-O)%X@U9!
MOAGB57M(0250=6!;AF!(_A!4%#D`]MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`
MYOXF6T]Y\-_%=K:0R3W,VDW4<442%GD8Q,`J@<DDG``H`_-6@`H`VO"/A;6O
M&&LKI7AO3Y+Z^9&D,:$*%4=69F(51T&21R0.I`H`^UO@K\$-(^'GDZK>2?VC
MXF:'9)<-S%;DYW"$8!&00I8\D`XVABM`'KU`!0`4`%`!0`4`%`!0`4`%`!0`
M4`%`!0`4`?GKXX^'&JV_Q?UWPGX8TR2]DBN=]O!:;I!%!(5:/>S?="K(@9F.
M`>I[T`>G?#K]EW4[[9=>.[[^RX.?]!LG62<_>'S2<HG(5AC?D$@[30!]4>&O
M#VD>&-*CTWP_IUMI]DF#Y<"8W$*%W,>K,0HRS$DXY)H`U*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#__V0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]D;V<N9VEF````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,3`V`#$P-3$U-#,Q,#8W`#`R,C0P,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$=`!X`]P`````````S``!F
M``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_
M`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F
M`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_
M,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF
M,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_
M9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF
M9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__
MF0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69F
MF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_
MF?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-F
MS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_
MS,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F
M_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;_
M_YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F
M__^9___,____^+\D````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(?D$`0``
MV``L`````!T`'@``"/X`L0D<2+"@P8,(5RA$R)#A"E:L5C2<2/#AGT`2*1I4
MN,(*1E87,R9D:,5*1XL8':8\&"BBPD`P329D)?/@"I@M(:[<R`JF2((8@T*D
M^7/@S:,LC^;L653@R9W8.-Z\-G1HS8HF=P)0`O$AU:I,FW;4JD331[`Z]4`B
M`8"$6P`/M6Y5\A!M(+5LK)!`PI>$E8@%`0`HL52G%;QZ6.E906)%8JA1LPX-
M5)($)#:)T3(MJ-1PV\N9-1/%.K:D8"2815LM*E'J7B2A55]U^%?U:HT=J^+4
M/9LAW-HT*><>C=OD7XPEC6\NGM4*7,&_(:MLWCKY3>F<2[ZD^=SD]MX$B22"
M=:Y]?%.GPLV7KPH>?5:<VK7CI-S>*8"HT`5CT[\B_WV!`0$`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-Y;'9E<W1E<BYG
M:68`````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-C0`,3`U,34T,S$P-C<`,#(S
M-C<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y82``(`#W```````(```("``("`@0```0$!`8```8"`@8$!`8&!`8
M&!@A```A"`@A$!`A&!`A&!@A(2$I```I$!`I&!@I(2$I*2DQ$!`Q&!@Q*2DQ
M,3$Y*2DY,3$Y.3E""`A"$!!"&!A"*2E",3%"0CE"0D)*$!!**2E*.3E*0D)*
M2D)*2DI2&!A2.3E22DI24E):``!:$!!:*2E:0D):2DI:6EIC``!C*2EC.3EC
M6EIC8V-K``!K*2EK6EIK:V-K:VMS:VMS<VMS<W-[<W-[>W-[>WN$``"$"`B$
M>WN$A'N$A(2,``",C(R4``"4$!"4&!B4E(R4E)2<``"<G)RE$!"E&!BEG)RE
MI:6M*2FMK:VUK:VUM:VUM;6]M:V]O;6]O;W&O;7&O;W&QK7.O;7.QKW.SL;6
MSL;6UL[>SKW>SL;>UL[>WL[>WM;GWM;GY];GY][OSL;OWM;OY];OY][O[][O
M[^?W[^?W]^?W]^__]^___^____?_________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________]E65@A^00!``#_`"P`````(``@```(_@#_"1Q(L.`_
M`Q<,*ERX,`+#AQ`=0IQ(<`&-!2[^?6#P@>)#`P("`""PP.-$`A````A`P^3#
M"P)4`A@`PB5#`C)5#B!0T^:_%0X(B)0Y@"B!$!0M.)C@X$&"`CD+B"BJDP,#
MB!*VC$FS1LN5'@ETIO@R@^H`#B*NOM0PA@V=.5QZ%!V0H@T9!44%5(@R8@)3
MIA846F![AXU<E1G*K,F08H0")6)NA#%C1@T;,1H"&P0AIHH"HB/(L%D3)4&#
M"T6F3+'B9@V;,6`2%J0Q`4(!!;@50$B!1DT0#T2(0%DRO$F(##.`H#`H@<60
M*Y;7K!F#A,>-#S22#(=2W,R8#%@J_JP@>,')FCEU\-S!,Z<*FSAE8-"@L:3^
M$B(ZV)#A@(,%>2=QV*&>>G>@T0(9;=`1!@PJ9$>$"C6<4<:!8-P@@T`,*!''
M>AS:T<818O20PAA*H+$@A%Z<D<8199!14PP"35`%'0/>D4<<6K111QQB`)&&
M&B6N(<8//``AAA@]"22!$VUP>(>'7\QAQQUJ"#&"&$.,`<>*:(S!A083%#1!
M&33:2`<76LRQ7AQ'J%'&#SCPT(./9("IT`1D=#$'@770(2"52,01!Q!JQ-%&
M'&,D:5`#2LPXH!UYW$&E$FO4L<81<:B7Z$,$/*"$E$ZR4881:N#!IAI/N@B1
M11<\L:&'4V-H0,$-9=2A1J!WJ.H1!4^D$:ML*X0`!JEXL*&!2R4HX-=`-L38
M@QQWC"&;2244U.P_#I11V+$^+33!&GBH$6:W"FG`1F$/D&N0!6*HMT:Z$P4$
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O<VUI;&5Y+F=I9@``````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C$R,``Q,#4Q-30S,3`V-P`P,C,Q,C4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA(``@`/<`````````,P``
M9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F
M_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_
M9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S
M_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,
M9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`
M_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:9
M9F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;_
M_YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF
M9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,
M_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS
M9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9
M_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`
M9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F
M__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___
M9O__F?__S/____B_)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"'Y!`$`
M`-@`+``````@`"````C^`+$)'$BPH,&#"!,J7,@0VXH5*B"N:*CPH0H_J%!)
MDX9*(D6"#ZE@W$B29,>)%*N(+,FR9,>&*OVTG+F1"LJ$*E>V]*/B8DD5`&X:
M7$%%9TN@``#(W)@T*$*B?I:V;`I`A49I2`$<A&K4)54`5#;Z:2I4(%2I1ZFJ
MV(@JZU"1:%F.I4J22M."7..ZS`K`I-N!1.'2%-MT;=V[@$5VG<G39TD_=D$J
MUCNX)2JMB057WHS9;-&H,WMNYECVK%Z@5P>K,*CBL]ZQ5@>W?0N9LMW8EB,2
M#!3(2NO:C*NF9@MT(&_>OB?3;&PU8T^GV([W[OU[L4DJ/;/;-#[=2N_DFC<N
MO]S=_7MKN)1-5CDHW;L5W^?#LVU;UF#[]T#/U\;^\*/`X^Y9Y)%_!!9H($$!
M`0`[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D:6YO+F=I9@``
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3<Q`#$P-3$U-#,Q,#8W`#`R
M,C4V,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9
M`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P`
M`,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9
M,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`
M,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9
M,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`
M9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR9
M9LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`
MF3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9
MF9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```
MS``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9
MS&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`
MS/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9
M_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`
M_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(?D$`0``V``L`````"``(```"/X`L0D<2%`@
M"8$`#A9<R)`AB8</&TJ<"#'BQ(L%*UK$R)%$0B0<0V(C46*C2(<E2M"I\X1.
MB9,+2ZR@0^?)GIMT5L`D6*+.32AU]$#9\R20SIW85NSYM&<%E*)&`QG=28+.
MIZM0<EHQNF(JS!)+07W**=,H@!4EORYE^F1%6Z<SH:Q0<1(L4RND2#W)^D3/
MDR=Y5QS%:!?PL[Q_23TK5>K98KT<>S;-6R5O8\>8'4/&^*3."E)5/F<>K?D)
M8;F(%9,>K4>AQ*J`]:I>C7GSQ"0U`:W00SMS*5)T*<K5(WCV:E)Y@)_NJT+T
M:%*7\P:G6),X`,"7->=I3*HU1]Q0_%<B:0Y]<1Y`A_V*!.]71?.^>1&[[DAG
M3WA`Q-NZ=X]4*5&W+B%54$]7+=64@`0AL4(=5UU%QWQ(D>#4306^A&!2@0@B
M%U!0I'3A"H*T(H@@1LETQ6`,!00`.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+V)R970N:G!G````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3(P,#<`,3`U,34T,S$P-C<`,#(R-3<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/_8_^``$$I&248``0$```$``0``
M_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!
M`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-1
M80<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8
MF9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;G
MZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*
M"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"
MD:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6F
MIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V
M]_CY^O_:``P#`0`"$0,1`#\`_O@KXC_X*4^/?"OPJ_X)^_ME_%'QCX&^&GQ-
MTKX:_LW_`!:^(%C\/?C'X0M?'OPN\9^+?!G@[5/$G@'P[XX\'WJ/;:]H&J>.
MM-\.6MW9NUNP\Q)XK[3Y8DOK?[<K^:C_`(.:/B=^V'X3_9>^#GPB_9I\9:)X
M;^&W[6/C?XB?LX_M*:3H?@*Y^(?Q[\0_#C7OA=KGCS7Q\'_#\\UGHNIZ99?"
MCX??&BW\>>'H]1TSQUXON-5\%>%_A]?VVJ:I?2#*O6IX>C5KUI*%&C3E5JS>
MT*<$Y3G*VJC"*<I-:I)M)O0NE3G5J4Z5-<U2I.,*<5O*<FE"*OI>4FDKZ7:O
M9'\5?_!/.P\7:#\8_P!DGXJ_%O\`:1_8]_9K^"'[4?Q-\=_M`^,O$W@+7/AK
M\$_C'I'A3X+?&/5=.\9?LZ^)[?X2V_PQ\4_#/X=_'+Q[8^'Y_!?PTN-2C^&U
MIX3\,:!XD\`6.F6?@W5/!^J?II_P4J_X+-?L]P?MCZ9IW[/W[5'[=/@T?#&Q
MU7P)XQ^)'[.OBGX8>*/V;$\2>&]-\2ZEX;U[P]^S[\0))/"G[0_VSQSXFA\,
M_$W6O$'B;P!I,WA;P3:KX#O_`!KI]Y9ZA/\`97_!&O\`X(W?L;_#7P3=?M-P
M_$VQ_;1T/XU^`O%7PSMK7Q_\']/\.?"TZ/H_Q;B?79KCX4_$O2=9\2:9XMTG
MQ'\--+T"]MO%$R76@:KI'B("V*ZC%#I_Y1_M;_\`!N;^W%IG[4'Q:M_V3]`^
M#WC']G;X]>([^73?$6JM\./!4'P<\*^(O&^E?$`^&;CPUK-GJ'B#PC#X$\0Z
M%IOAC3?$WP(L=1US7_`L?]CC3]*T'Q?XO\!P_P`]5^(/#GB/CO'SS3,IX"&4
M99B<)0_M&E2RS+<5BZM1K,I5J.98.%=YAAW&G0>%QJ]GBI4%;#UG[:$_V".4
M<9Y-PI@Z.#P4<4\PS&CB9_4JT\?BZ5"E3@\$J57`XJ=%8*M>I46(PKO2C5;=
M:G'V,U_8M^S+\0[VW_9.\#_%#XR_M&_"GXVV^G^"];\5^(_VG?"NF:1\._AG
MXU\#Z1J>N7VE?$;4=*EUG5-&\)RKX&L=,O/'9MM5;1++Q):>()+*.STJ:VM;
M?\R?C!\!OVGOC1_P2?\`VE/"/CRZM_!?[27_``5Z_;J^"7BOX&>`/%&F7_@G
M4O`?@'QUXF_9B\._#SX5?&#3;+3+*W\)>(/`_P"RA^S=JE]\5]$O;_5I;XZ1
MK?A636_%?C?6X=(U7XK_`."@/_!.#]H;X0_L>?L3_L9?"+]LWQ=XX^'7C?\`
M:5_9H_9HB^"_QA\.^`](^#VK>)/$DWC76[K5O%'C/X;^`+3XX:A\-9_'UGIN
MJ6G@'6O%'BVRT/15BMK1M4U#PYX5NM&_;7_@G?JW[8O[=O[=?B_XR?MC_#?X
M._#7P5_P3#\2?$7X*?#G1_@-\9;[X@>#O&/[8?Q0\!Z;8?$3QG>R6[Q7E^OP
ML_9P^(B^!%\.>,[/2SX9\1_%[Q`3I=[XNL-3LOAW^><*\$_VUQ3D6*R3-\FQ
MV45N*9<2YHZ>&C@,SPF3<,9K1QV4T,)@*V'P[>'S3-WAL/FU+`X.."R[ZIA(
MT<3.E5BHZ<=YWBWA<+E>.P=?!5<NR["IJ>(>)5;'XO!JC4DZM.M7A-4:5.<L
M-5Q5;ZU4C/$3G!5)<K_I"MK:VLK:WL[.W@M+2T@BMK6UMHHX+:VMH(UB@M[>
M")4BA@AB18XHHU6..-51%"@`%345_9I^,!7X(_\`!5JQ\2^+OV]/^"5?@I8[
MW5/AYX<T3]NKX^^)M#258M+L?&?PV\)?L_\`PP^''CR_"WME/-=>&A^T!XM\
M-:9#C4K3S/'MS/=:1)+!::MHW[W5^*O[4GBS1_%/_!1ZQ\'SZ3>GQ!\`OV0/
M`7B30]8;4(KC3YM*_:K^.'Q$LO%6E0Z5%:75[I]['>?L<^";BYO()HFU6&XM
M(KG3[H:5I=PGPOB7C?[/X$XEKZWGE[PD>5M-2Q]:E@D[IJW+[?F;O:T7>^S^
MR\/<(L9QIP[2E;EIYA#&24H\ZDL!"IC?9N%FY^T>'5/DBG*7-RQU:9\S_L7_
M``_?1?BU^W;\3M-U#Q+#X,^*'[3=K;>!?"]YK37G@O3T^&?P3^%GP^^)WBOP
MWI$&M:UI]CJ'B?XU:)\3K7Q--"T=YJ,WAO3X=1@CFL7M6^]SY1).]\G><"%%
M&<_(,++A589+8&(SA55QR/POA\>_ML?\$S+B6?Q=\.O#?[9'[`DOB?XT_$+Q
M?\0_V>_`OB*W_;!^%_C3XW?%WQ5\:/$/B?QS\,]2\?:AX-\<?#G2O%?Q"\1:
M?=M\/=+T_6O#_A1H/%&NC34\'W-IXU_8SX1_&'X5_'OX>^'OBQ\%_'7ACXE_
M#CQ5;W=SX>\8^$]7L=4T;41IM[/IEY"LB1++!?:;J%K=Z;J^DWL-MJ5IJ5K<
MV>H6EM>6L\$?\0\28#%QK+-%6H9AEF(5#"83,\')U*,XX/#4\+AZ6-C)*M@L
MRJ87#PQ%?"XR%+$R<YUE&<&YG],Y+BZ"4\!*-?#9C2E6Q&*PF+C"E6YL3B*E
M>O5P[G*<,3@8XBM4I4JV%G4I1E#V5XM*,?!?VMOV=?"/QT/P/\4^-/COX_\`
M@5;?L_?%_1?C=X+UOP3J'P?TJR_X6OH6GWND>"M=U^Z^+?PU^(&B7H\,P:YK
MPTSPZ]O'X?U"77YG\1:5K-YINA2Z/\Y_L!:9\.OV;/VF_P!G?]G#_@G]^T]\
M5_C#\.]>^,WQ-UO]N;X;V.H>%_VDOA]?ZQ=_`GXVZEXA^.G[1/Q^MOA?XQ\4
M_`SXXZ]\6/#7PDL?["M/BO\`#S0O'NOV/AWPI-\-+*/QA=^)(_-/^"TW[+FO
M_MR_#']DC]BSP??^']`\;?M)?MB^%?#ND^-O$FB^*M<@\!:5X0^"'Q[^*'B[
MQI9Z;X:D2XU"YLO#?@R\TF>#41_8S:?J]_=WDNEQV7_"3Z-\&?LK?#C]H_\`
M8!_:I^('[)7P?\=:;_P3S_;8N_#.E?%WX>_LJS?%;6/CO_P3$_;&\()'?^$=
M4^+.E>$_B#96'Q:\'>)/$UW\.]9TCQ'J6B>,O#'Q*\(>"_!FE^)$L=>T_0?%
MVE6OZMX>XFEPID>6<;9UF_$6%X?P^*QM#&4\GRO#5<OP>%H8E_O\\K1G/,\=
MESJXC&8BO#`X#&RRRC0KXW%5<#AH*L?E?B%B\-BLRQ^2X;*LJK9A4PN#J/,,
M7B,0\6IRIIQI8*FK4<-4A1C2Y'6JTH5G-_NZM2HXO^].BOXI[W_@[[F^#M[=
M_"+]HO\`X)X_$N#]H/X675Q\./CM!X#^(NA6'@:'XR^!Y7\,_$^+P98WVF^+
M[VR\*1^-M+UQ/#MI>>+?%%U;Z0+.&X\1:W,CZG<E?U[2KT*]*E7H5Z-:C6IP
MJT:U*M3J4ZM*I%3IU*<XR<9PG"2E"<6XRBTTVFF?A3A--Q<)IIV:<9)III--
M6T:;29_:Q7YA?\%!O^"57[/_`.WI/X4^*-S_`,6:_;`^$2Z%>?`']K7P?I"Z
MAXX^'>I^%/$\?C+PYH_BSPX=4T71OB_\,(_$`O6U;X:>-+HV$FGZ_P"*%\+Z
MMX0UO7KK7U_,G_@OU_P6\^(?_!/6]\.?LQ?LJ:5X5N?VGO%OPYM?C+XO\:?$
M31-7U;PK\,/@YJGC&7X<Z->^&-)M9;"Q\5_$CQ+XKBU)],M]2U!M`\-:-X9U
M&ZUNQO[O7-#BB_STOVA?CY\<_P!KCXE:G\8_VI/BOXK^.GQ,U@)]K\0>,Y;)
M=,L%73M(TQK3PMX,T>TTWP9X.TQK;1-.4:=X:T+3H28`\QGE>25\<7+#NG.A
MB*<*U.K!QE1G%3C.$^:$E.,ER\KC=;MN[7*EJ]\,JT:D*U"I*E4I5(RC5BW&
M4)P<9QE%IWYD[-;)-)W[?Z$7[.7[1WBY?C=^T)^QG\<M9\`Q_M;_`+)&N^&M
M+^)<?@'4!!X/^*W@?QCX5T#QKX!^,/@WPOJ6H7/B+1M,UOPQXM\/Q>-_#%V^
MJ+\.O&FI-X='B'4([O2;NX9\6?V6M9TSX^V_[>7[+4,^F?M'Z/X+U7PY\2?@
M<OBNV\!?!S]L?P]#I=W9V/A_XG:O9Z)K,OAWXE:"D6CR>!/BQJ.FWTFF3Z)X
M+\*^,(-2\%P:?-I/\0O_``2E^.UI^R7^V[\+?BU>:5J.E?"CQ%J%K\!/C+XD
MT+2WN;73M.^-$.L+\.=+N=/@NK%+V>\^('@FP\7W,&FQ:KX@3PO\/?$^H:?H
MFK-IJ6U?Z'GPV^('@;7_`!EXY^'VC^(M-NO'_P`/;?PU?^-?#`%PFM:/H?C2
MRO+OPEJEQ;W%O`!H^NR:1K,.D:S83W>FZE?Z)XETAG.I^'+^'3_XS\1L@J<$
M\25\3DF'G1RG-<NG6^K\E6IA'@Z\UA,QRW$^_*3PKK3I./-4A.@L7A'0JT:\
M:%6/]6\(YWA>,N$Z7]LUJ=3/,IS&A@Y8EU:5/&5L0HK$9?CZ>E*^+CAJ=9)R
MIU_;+!8OVE.K"=:,?E;]I/\`:HO_`-F+Q;_P2M_:1^,>GV/PCT?4_P!L#P/\
M-_C]X:U?Q]HT?A3X::9^T)^R]\>O`NNMXS^).GZ;<>']0\.?"#QWKNB:]>ZY
M);:?X>\47GA:Q=M6\.6LZ:K9>]?\'%?@'P'#^P!J_P"U&WB#P+X!_:#_`&//
M'_PZ^-/[-7C_`,8Z[8^&I9/&VD>.O#<WB/X8:=?75Q:R:VWQ5\$6GB#PVG@U
M))8?$.H_V<EW`UC;W;#V'XO?"+X>?'?X9>-_@U\6O"UIXR^&GQ%T*]\->+O#
M.H7^I:;!K6@ZJHBG@34-)O=(UK3K@-'#<66LZ)?Z7JVE7<,.H6%]9WEO;7%O
M_#K\3?V^_'OPJ^&^J^.?$'QZ^+WQO_:PE\#>,_V/?^";_P"T/XBTC3?"7C3X
M8_\`!/[P;\5=;NO%7[7OB)M2\0:]<^(/BS^TUIFN77P$^&/Q`TSP_9^+K#PU
M\,M2\>-\1+C7='NH/$GZAX&YO@<YX4SGAO%Y;3J4,KQ?ML13K4HXK`8C#9Q4
MQ%6CAY4JWM9R5.KA:T)4\0JL94_9SE6G><:?Y/XKY76P6>9?FU+$*3S+#JE!
M1DJ>(IULNCAZ=2H[-4XJ5/$49Q=-P:GSQC17+"57^CKP3_P<B_L6:?X,\)6'
MQA^*^A?"#XMV/AC0;/XI?"7QA\,_VAM:\6_"[XC6VE6D/C?X=>*=9C^'NE)J
MWB/P3XF34_#6MZFFEZ:E_J>F75TMA9B46\97^>;_`&#I#_/=:?9ZA<M\US?Z
MA:6MU?WL[<S7=[=20F2YN[F0M-<W$A+S3.\C?,QHKX2K]$?PWG5J3I\2>(>'
MISJ3E3P]'-\@E1H0E)N%&E+$<,UZ\J=*-H0=>M6K.,4ZM6I-RG+Y-9_C$DGA
M,MD[*\G2Q"E)V5V^7$1C=ZM\L5&]K)+0_J__`.#I95;_`(*@>*2RJ2G_``2X
M^#+(2`2K']MW5D+*3RK%&9<C!VLR]"0?Y5Z**_JS&?QG_AC^1\]AOX2]9?F?
M0-Y+)IW_``3N^,GBG3Y'L/$VC_\`!0#]E.TTCQ%9NUKKNE6NG?LY_M4Z[I]M
MINKP%-0L;>QUN]O-8LX;6XBCM=5N[G4(%2[GEF?^]30M5U2T_P""T/BG0;74
MK^VT/7?^"97AW6M;T:WO+B'2M8UGPS^U]\1=/\-ZMJNG1R+9ZAJ?A^P\4^)[
M'1+^[AFNM)L_$>O6UA+;PZOJ"7!17X7XW_P,K_[)O/O_`%.X:/U7PJ_WG,?^
MQIE?_IO-#[L_:NU?5O#O[,'[1OB/P_J>HZ%XAT/]GCXL:[HNNZ->W.EZSH^M
MZ=X%UV]T_6=+U2RE@OM/U6PO(8KNRU&TGAN[6YBCG@FCE17'^>Q_P5-L+'1/
MVK;GPQHUE::1X:\&_#'X;^%/"'A[3+:&PT/PIX6L-*N=0L?#7AO2;5(K#0]`
ML[_5M5OK31M+M[73K>\U/4+F&V2:]N7D**\7Z//_`"+^+_\`K]D/_I.:';XN
M?[UPY_UXS/\`+`'YRT445_0A^2'_V0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=I;FYI92YG
M:68`````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3(`,3`U,34T,S$P-C<`
M,#(S,3(P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`
M,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`
MS```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S
M`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\S
MF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S
M_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F
M9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9F
MS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9
M,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9
MF9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,
M``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,
M9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,
M_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_
M,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__
MS`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````A^00!``#8`"P`````(``@```(_@"Q"1Q(
ML"````43*AQX$"%!`*1(.5Q($4"S9\T0-FPHD>)"BQB?';Q(4F1#CP9#7@2@
MLF7&@RBQ@20YTV7(DQ550FPY\N:SCAY9EBPIU"50F`9)#35:%.)&G`R7+CU(
MZN9!DT@%UI2*D:I4B5EEVOS*]2)0K57+CK4Y4:O:MSI3PB7JLJW;M5.5\DQ8
M=*[(O7S]TGSZ$>]8`&[<V&6XU?#@BHK[.NY:$9+EGG,7:VUH&5)#MB'/&NQ\
MT$UGSX<W*@1PVC-KTE?-1D1,>&!KV*V?OGY]V>'MT[Q_>S8-7*#PSJ:#X\Z-
M\+CSX;<A9G3-N37QYY=IZE3N.?KOHG6Y"%,_^%UOLX```#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O96QM;RYJ<&<`````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-C$T,0`Q,#4Q-30S,3`V-P`P,C(V,#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#XY_:+_P"#9DZ)X.U_Q'\"_B%>:]KUG;_:
M;;0_$?\`H?\`:G/MT_\`KYXK\-_@;^T7^UQ_P2P^.%UI?_%5>";K3=0-MX@\
M*ZJ3_8NO6.>^F=-6]NIZ^U?ZC/C.WT'P_IDNJ6\MY-::;H^N:EJ$,%S]LO;K
M^R].Y':O\NS]N;]M;XL_MP_&+Q1XQ\;_`-G:#X<&L7UMX'\#Z5H^G6=EX8T3
M^T?^)9IP_P")/_;>K:N/^9EUPD]#T!Q7XGPAF^-XAPLL+F2AF>7*-K3;NK6Z
M;W2OS75K7MKRW_8,]P$,%BGFF6.669E*3DG!M:R=[*UGJ_5W2L?T5>)/VG_A
M3_P5>_9RUG_A0_Q"U+]G#]MOPKX?OM;T?PWX<U@^&]%^+-]I>G?\3/P[Q_T'
MO^9:UW_D8_#GB//_`#*U?C#^Q)XP_;O^+OQKB^"/PKNM2^)%_KUQ_:7C_P`.
M?'#_`(G'@O0M#TLG3/$WB+QSJFK?\BII&@^I.>G_``BQ_P"$HQ7P-<?`7]H'
MX#>`OA'^T_X4M->TWPOXJGO]:\+^(]#N"/[*OO"_B,Z7V(YSIF1VSC/!Q7T%
M>?\`!43]K/5_"/B[P1X>F&G>)_B$!IOB'QCH7A\V?C2ZT/3`3IGAS^T]*`/]
MDKJ^IZGK)R",ZH<$\%N[#<,\.K!X_+\-E&1YGE^9.24Y.$:F46Y>:[3<KWUO
MS-)K1INQZ>'X[XUP5?`XZOQ1GV7X_+>6R_X5N65K6NG=23O;9K7SN?OM^U-X
M_P#^"37[%QET;Q1?:[^T%\;1I]F-8\'?"OQ1J7ASX9>&-<_YB6GZ9J@/]M`?
MVN#D<DC!)7YA7X+_`+:7_!1#PE^U5IOA:PTOX-#PKK/@.W_LWPO\0+CQ3J/B
M3QI=>%>3_P`(YXFU/5O^0MI&@X_XIG_H7>@YZ^#WG[+OBCP%X:\)?&/]JBP\
M8>&]!^)%_?'P?H?V?'C7QD-,'_$SU'_B;_\`()T@?\2W.MZ]US[&OZ9O^"*_
M[*O_``2*_;AL_&7PZD^#WCRS^-OPQ\/V/BS6-#^(WBC^V++Q1H9U+^R_^$B\
M-:GX3_L#^UO["_XEG_"2:(=`ZZKCG/&>%RCAK@W"RS/`8)S6`C[THN\)I6OJ
M[\R3=G>Z;^3-N)^/_$+C^<*'$^>/,,'"473RB5U4BURVDKV:>E]/-O6Y_*]8
M?M>?M)Z78V6F67C;Q!!9:=:6]A:0#4PHAM;.%+>WB"Y^41Q1H@7MMQ17^EM;
M_P#!*W]@^SMX+2+]G?P+-%:PQ6T<I\.B4RQP(L22&7'[W>JAO,_CSN[T5\S_
M`,1.X1>KR^%WJ].KM?[7F_N];=RSGCY)*.?YA&*225UHERV7R2M\O)7](L_C
MWX#\4V6EZSH7B33=8M?(^RV\\&H#_2B`?Q_/]*_G5_:?_P""/?[$GBSXOZS\
M6O"?BGQWX5M?%/B"^\27_P`'?#EQX=/A>ZOM4)U34QIFI_\`(:\*:1ZZ&0?^
MI6S7QMX3\;^,OA_IIB\%W^I32Z]<?9A!!_RZ_3U_SFOVI^&^AVNG>"-!B\21
M?VEK,UO]IU"^U6W_`./J^_L[/]G=>><=LCU/./YPXPX[S;@+*&LFQS689FG%
M)-JR:L^7LTGH[*S5]S_0.M]&/AK`YDL9B,:LRP"ES+)I7T=T[Z]GJUY,XF7X
M<>`Y?AYH'PUN?"VFGP)X5\/_`/"-^%_#A@^VZ+IFAZ7_`,P_3>>_KW/4]17D
MFG_LP?L_>&_$5KXMT?X<>%8==TTBYM]5@T<?Z*>/Q/<_2OM>XT_PY&D4L>E:
M;Y4W_/#C_(&<?Y-<'X@CT:WAOY8[6SAEA/\`S[_;.?KU(_,]J_F?"<7YZ\3*
M;S'/>:<G*7_"P^64FU*5U?5-MWO?2^A^D4/#G),96C&OEN2**22_X1XW27*D
MKZ7:4=UO;=GY>?\`!4#]GWXL_MXZ#\$+7X4:5H6I?%7X*>'O%>B6WA6?4--\
M.7WQ%\#^*/[*U0#PR-6(T3^UM".E\Y_X1\^(O#FK9YX!ZS_@B'^P+^T!^Q5\
M<?'O[4G[3&BQ?"PZ;\,-<\$_#_P1<>(/#MYK.O7OBC4-*_M/Q%J8TG5]?_LG
M2-`TG3#SGGQ$1P.<^Y>/_$AT.;_A(M'BTR'6=!_XG>GP06'/_$KY_P`YZU\P
M?$O_`(*"^-_%'AW[!X?TJ>:6\M_](_T?[&;7/X]C^?YY_L/P_P#$'/LVX*62
MXM*5DHN;7-/EYDU=N[TUN][:<UM#^>/%'Z-B7%F"S?A[!**S'=)6C>ZOHM$N
MB6R[;'[Q7G_!0GX?P7=U!)?VDLD-Q/%)*T^YI'CE9'D9L?,792Q;N3FBOX_[
MCQ%XSN9Y[F[9%NKB:2>Y"IYRBXE=I)@)<_O0)&8"3^,?-WHKZ99=P\[-QUT;
M]?=OT\OZL[_*KZ/N=:?O'T_]MMU]/N\]?H?P!JD5QXZ\-^%[>7SHK/6+"YU"
M?FS_`/!9D_\`4,]Z_<RY\?Z-/I444D,T\7V>Q_<6-Q]C]_ZGO7\Y_A#Q)+'K
M^@^*+?SA%/J_VFXG_P"7W[#^O^.?:OU9U#QI%)H%K+;RS?9=3^PW-Q//;_RY
M%?S[XNY/B,;C\DY=TUZ+:]TOOM_D?Z+8/+L/G3NKKSM9[IJ[];'T/K'BS2_L
MUK#I<MY#+_Q[7$$_^A\?]`[OT'_UN<5X9KGQ#EC26&2_FFBAM_\`1X/M'O\`
M\@[OZ_EFO&]<\>?O_P!W=0S1?\?/GV_^A_9/KU_M;M[`UY?JGQ#^S0^5)=>3
M%#<7US^_^O&1P>OH*^#RWAJM=7C=Z7TUZ>7Y=-#VZ6587`*^(<=%IJK>?7^N
MOEU'Q'\875Q87\L4LWF_9_\`1X/M!^VW7\_<<_\`UJ_,G2Y-4CL_-DM?.AAN
M/M/D07'_`!Z_S]/QZ^U?1GCOXIZ7)X=OY;BZ$U_#_HUM!!<?]!3_`#SS7S3I
M]OI<=_+);:_Y,LW_`!\6,]O_`)Y_/UYK^A.!,GKX'`8W2RTLGII>+T3[V?3[
MS\_SW,\/CL?@OJS7NOH[I6M?17MK^O4Z,^(;=25,:J5)!&1P0<$=>QXHJ==*
ML$54>2Q=T4*[_8#%N91AF\K_`)9[B"?+_@SM[45]O[%];_>CGYGY?<O\O)?<
M=#IZK#HDZPJ(E2Z\,;1&!&%QG&T+@#';&*^MEGG/@GP@YFE+IX1,R.9'++-_
MSU5LY67_`*:`AO>BBOS7C3>EZQ_.!]OPU_N__;B_]M/%-;OKV7=YMY=2[+@;
M/,N)7V]/N[G.W\,5QGC"[NO[,/\`I-QQ<\?OI./I\W%%%>'E/QP](?\`MI\W
MQ!_R*'ZU#YM\5R2/?^&D:1V26'[1*C.Q66XQ_KY%)(>;_IJP+_[5=)H1).K.
M22Q?ECRQY[GJ?Q-%%?MN#_A_]N_^W1/S#ASXX_XE^<"/<QZL?S-%%%4?='__
MV0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V=R965N:&5A9"YG:68`````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#0V,C(`,3`U,34T,S$P-C<`,#(S-34V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y84$`30#W````````
M`#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`
M9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``
M_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS
M,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``S
MS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF
M`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!F
MF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF
M_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"9
M9C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9
MS,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,
M,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,
MF<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_
M`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_
M9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#_
M_S/__V;__YG__\S____XOR0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!``#8`"P`````00!-```(_@"Q"1Q(L*#!@]A6`%@(`*'#AQ`C(E3(<.$*
MB1@QKKCXD.&*0*VN76-US8K"C"@/4N2(<&$@DB)9P0S4,*5-*Q4!4#2HD(7(
M:X%8K&!Q9>0**S8SKCPDDU4@FC4'`K`24\8#!"P>/)`AB!7+I!!=RK0B@^JU
MG5)G(N#*2I!5*ZRB@CW(PJ(@*P\NZ+7P(!#0C5)_RH#P<R2"M3GG%F3H-^\%
M"!;T/A!I,BUE"$T#8<O)<.!&BS89BHPL(T<7!!8LQ&0)P&])!!M7J%`!P$",
M+5MH+XRQN>)7B!3-(I(14C!FD9QU+@S#/,PB1HP,&=*]0CJC6-AC'5*(UN%"
M+C\#_LDH7-("(N0,#<"H#:.Y\^?2Q>2N8BB[_5C2#<70^5`AS&NGN2:2#!?`
MQ)`-/"3H'G.+/`===%M`=]^$L0#BD4H`%-;%!3+`Q$I>/[%`FPU@E+A@&(PX
M^"`CL,!"X82&<+$??P0I1-X%?+TD0V0_61&#>CR8Z%Z#*ZZ(GW0OWL=%9YX!
M\!]0#Z0FY7@B51$&#"0*V1R1AA3)(A>SJ<!%DMD]L5"-`%!96"`K(/``(L5=
M@U^06F[I)70NB@&(?ERLP,4JV-5G'R"Z$833"D^*A`A2Y,7"")UU.@==ERNZ
MB-TA.M$60Y\JK!!#?A3)A<VAB9+WTR&&A%$B&">BZ*6+_M(=$@,DD*P`"&!-
M,FF02Z::RDIT64:J(B-BX`F+*BKL1PLM2'"7DD6]DA<(L<&R.B1T8<2P@AC2
M>7()&R0`L"PD'B&ED5W1KJ3"JM8NV.E_3EF!$PDDL,$&+;1"@L29Y^I$7KSI
M(1AI&%MH*Z"T3LF&K[U(D!!:<ARE-[!HT9I*$;B_213JA0*%NJI[ZRU4L:DX
M`8`$&TB`%=M!)@%0IP&^E=IK70DAX8EB#QGP\97))7H7>?S*@+-#..V<'+HC
M"?(OC4,[I%"[81S-$`ORFKH9;TU[Y[*J/"=GR!8U;<P0UEFW!(![NG$F!FVY
M<I9QV;VY!W-.!H`M:JYZ/&'F_F=WX[Q<<W-7M(4A_!94LA[))&ZF;V4O9`/@
MG&TAQE0'+:1'*8DG4TJX%9G;-$X&,!?X$WKD#=IB`)2N0N:)DU"*)[HV_7?:
MF">N1^&>/:%YZ:RK@'GL0R]T0QBZ(<ZZ)V86='DR>G"7N?'`!Q_Z>L:SKGC8
M`"1>"G\;6;\XW`*=O9\GR:Q$ONT4Z5[*$P0!\$3MR9S^-E@`;,$#`*7<OA!M
MUB_?/`OAJ\@35I*0TPUM!>U)'4-44`7W62]Q'!%;1:1B0)S)AGB+6XC=JJ<]
M"FZD9:#9&`#GPK2SA6%CC-B"0ES'O)-LI%10,9F^^B81<Y5,*J*KB'0*Z#Z/
M`"`&_M&2`0#N10O<.4U4V(M*Z*)6$6XA182>DME(J@")985K?@4)5<<8\I@S
MU2\,@=N?(7!50)F,C!557!:SC&B00W'/"@=`@%X.P)`M$(\STNE4``$A+YFQ
MP@IJ'->^L!@^1+%I(7G)RPYT0,<(I9`S*C"$K%0@Q<+<BW-$)!<-FT02-J'F
M`F[:`2C/]J#D?"H&9NF5ARYQB8H@`5]LW-4*1!*(R%S@*CO8`0)"YZ"T<29.
MO0*)%50!"(?UIF&QE"4K"'2!7.K@,%\,0ZI2Z,N%`&)D(JE.\MH7/0PA0`?-
MS.4.Z+A$%1A`!=PB7$XJ&9,8&;%EY_JF#L09A!EXBGAT_@0``V.T,6R6)!;.
M`@M.$'``K03AH$$H@T*]D`,9S,`+,]A?#`ZQI`Q%ZQ!6B,4J3J(8A43T`%P@
M`T(5JM!$D"$1)J5()%?1IU+)A`OUL=`F,Z(3#XF4I"5%:2+XUA"%3!15@K+/
M=I+Y+-<$PB0RP*E.36J%H_+K.R^253=38I)6R&0%!Y`!"[Q0!I1VU:1"9!Q%
M`#6A4!%2(X)@"$F[\,*S=&%1B(B>6278M-BHM:M=.(!95B`#1(PEEE([*TWY
M8Y$N*#0'K@%`%TR"**<PK6U338I"S+60!,%`!HN5"0#R:1%X@N^(N4H0=31+
MHY)Q[+.&XR:)[A<^I]Y-BZCM=8@*@L3:S7C6(2.,;>7:$P8>J*"0C]4M2@#`
M6^8$<*;"[4AQ3]@;Y":W)>UI4-2:^]S0J$!2Q.I4<*L;D1]*<U)V$RQWFT2I
M%45VO*@K[X.Z@U[9%JE+[A0O=W=C+*$2M;TEJ\)U)K2*\XZ7(C'8[X3\"[>`
M```[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W1I9V=E<BYG:68`````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(S,30`,3`U,34T,S$P-C<`,#(S,3$Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`
M9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`
MS)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S
M,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68S
MF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F
M``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F
M9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F
M_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9
M,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9
MS`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,
M`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,
MF0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,
M_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___
M9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_
MS)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````A^00!``#8`"P`````(``@```(_@"Q"1Q(4"``$@43*EPX
MD`2).0@92EQ((M`*B!,S$B2APB&`CQ\C#NSH<&+'3L&"=2(!$@#$B$XZ=;JT
M0F3")RA3ZEP9\E*GDYU6K%BURN;`%9=VZE3)\N#.)T2M60.04`6`%2E7DLBI
M$F36)Q976"M:T.I0:\]6A,S)DT3*H4.)KDC(<I74L:O4N@WV<&M*%:L.EE1X
MU:Y0HDZ#'>1ZR>K$%1:EYLV;\Z/*F"PSAI1:$VVGF!]Y=OHXL:E8:T+1XAR]
MU>%*B1T/VI6\ZIE.URME&MT(J3<DJ%7RJN":U?7NAI!Z[?(]-/@*%4N#`3V.
MC02D7;1H^5;Q3*KMZ"I?JE/T3?ZT]^A:D4BT3A[J7=3/CF5U<@DDPX.]29R]
MFQ?M7Y0@48?-086]AQH`4AWS65=;B4>71;.]]Y%W*Z#D&H,+0;:?9!-*!5TP
M,3$5$D4%CJ7771\6=]`E`E;GT(MLG+9*BGPMIEB+V"!!`ALQSE;34GYU=1!#
M'JFPX7#@I<02"2PN!)B!)B:9TF(\91BAB<1%AV13#)V55V)+A;C48NNUE"53
M>RF)4D```#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O8F]Y86YD;6]W97(N9VEF````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(P
M,@`Q,#4Q-30S,3`V-P`P,C0Q-3,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA.@!&`/<`````````,P``9@``F0``
MS```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9
M,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_
MS`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F
M,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,
MS#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S
M,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9
MS&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`
M,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EF
MS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_
M,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PS
MS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,
M,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`
MS/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9
M,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__
MS/____B_)```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"'Y!`$``-@`+```
M```Z`$8```C^`+$)'$BPH,&#"!,J7,BPH<.'$"-*G$BQHL6+&"$"`+`"VT8`
M'K%9L9)QXL>/5E@%"K1BY<>2#ZV@'!F(8R"9)SO"7+CB9,Z-5E;B!+H384^?
M0'$&!7JRZ$&D*'U:.=K4*4&H3+%6M2I0:E*J4G%R'7CTFMFS9EE=JWGRYL:Q
M`S>R"HJV[K6/;D$Z9;2H[Z(M`-2B#6H%[<:\>F'R]=L71N%`=M>>'?IVYV*_
M9PP4OK;Y[(JZ;%_N9-RX,^3!=5D!>)PX(^F^`$YS[BRY;F!6(D>3C@$`=63#
M:@,5?0VX+NW(IV,,?[TZK<P5=']?8Q6C+Z.2KQ>=B6UVY0J5TCG^A\EN,7O?
M&%6^KPQO=H7Y1=<GON\+>/54Z5:JOX\?<?[YC3#8))AA9_C'WT/^O1:&`=P9
MEN`B$CU(7(-KP?!@A!*2=L9GW>GG7T2798C99E9L<2%$(F8'@UE6C)<@1"&F
MV-<-A5EQ@X0(RLC8%C>-5.*)##6BHU\\&N?BAPP-V5<8M`5GXHL+Q:+D(C&P
M8B5GW5D(I4)*AL$;;RIQ&(B62'*I(X\M+N(8=)`%<N.6",4HX1F!Q&#B&3'<
M--F1\RVDHY?Z;<>1@PD>>)"(`0)@@(O;P4`C6@8`&6>&,,1P0X`&`!+@C5O0
M1N9^?DH8!@`%TA=@J46>%6F9"<EI'@#^;V*VZB(TKN12J>8U$N2#,<SJUZ)^
M+7C2D^89BI"4_FV':V.?JCELGPXEZ"AI-Y!*[4E\DJ:K0\B:!X.OV@&0;;@;
M@4M:1$)F-^JRBQ@0*VD?$4L>NJ]MEVT,S3+V$;OG2I2N7S%XN*2XYM4'`*L0
M=;LN:>Z^ERC!T$XDI`'RTIHO8P^_.V]%`B^R<,'E;H2P0C2QM)I>B]D[7[4&
M\`9QL0S5))Q(2XTD$%^P^K?1C>6.;-!<+L5F,DD"P7`Q8Z-:6^W+&QMTF,PR
MC<21?2?SR[#('N\<<4&$K=822]"=S!%N5EBM;\ZP*;IU7"-9B=M--?DXE5NL
M<+'R1KBZ/&YB7P@%9:502]'\$E"`:!@#%UL(>G"P'V5G+$$]LB2U:D'9>E/=
MI(4!EMH>;V%PMA&E-%=!MMZLX<,`F-CI1PW[]7A)KI[A>8%A>+X%Z'"9+N+K
M<#7BJE^-;)O[\,07;_Q``0$`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VIE<FDN:G!G````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<T-30`,3`U
M,34T,S$P-C<`,#(R-C`V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R
M`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$
M`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"
ML<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=8
M65IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JR
ML[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY
M^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$
M`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)R
MT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H
M:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BY
MNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"
M$0,1`#\`_+/X7>(KRW71+266ZM"]QH,DC",21PQV\-M)<SF;R6?R8/[-!>``
M;VG4F13$!+_2+^SK^U!\)/#OA;3F\=^*M$LH[2&\2\NWTO5-85[*0:CJ&DB:
M,>'-1M=,4*50W\IACA-H$-W&;L0G\=?@7\"Y-2\-WOB^>\1#IO\`:MW#IT%O
M!=W4VG1//*D26XN_M)\T:=]E_P"/0[!>&4[C`(9_J_\`91^+O[<GBOQ?;^`_
MA'\*/`GC'P?XA\23>'KC3I_`[>+;CP_8V<"^2WB**T@TNX-DEE+<+.^K?9-'
M6:2WBN+@7,MFK?E<L-7SJJ\/@(4YUH2DI4YUJ5"W):]G6G3B[[V39_8N#IRX
M6R9XS'1<J6/6(G%.\^6C&RE4Y8\SC:]_>2EH[7N?U-_!7QOX(^(&AZ=>_#SQ
MSX+\3:%=6UB][J.G>)=+EEED32Y2(8]-M=<LS:79N[JTLY%(::*!YYC`VUHJ
M^HX[J[30]0%U<ZD]L+C[-:6&G_VD@CO=%>_TZ]L8;I[ZUM+Y')6XCLC=;;Y-
M]R(S]@+-^(NJ_";2_@MXK\4Z]XFT+PUX-\7>`K"U\:2^-O@];:EX,TJ^;5K:
MV74?#?B'PIHL\VCVRVEU'%IQM&UW49+NYN;;5A'"-+:TNOTZ^'GQ#_X2?X0^
M'_BIITDTLFOVFEZZ+.Q-M]LN&U".?7!I<IN-#N)[M=(1CIE[.;BR_M9[N/4G
M-@;065SUY;F<\'4>7-T^:C-QJ1]I!_O%92BI)N+M;=-Q?1]'^,\9\'U/J^%S
MS#Y@H83,*N'G12@Y1MBVG2OVYNS2<?M1CN>(_M<?M?Z3\"O!-O+X(\-:/\0O
MB1YOAI=%T./4H/#EI'%JJZK=ZG/XB^S>&9-7OI-(&D);1^&M.U'5WUZ^OK4D
M6IM?M4'\O/\`P4)_:&_:B^,7@KQ;\/?C/\0=).A>((-(U6P^'GPQTJ2V^'FD
M65IIFF:BT&HW>HVD.M+XNTX36EO>V=P8X;87=\I2>2!)5_33]J31;K]IK]L3
MPUI,/P/\6^,M:MO#D>G6]EXB\<W/PP\$2VUQKES9KJ&D/X?TCQ5<WU]X?U&&
MPOO[2@71;N*$W2F^MX1+#>?DQ_P4931]#\">"?`VD_#+XD?"SXA?#>?Q!X&\
M9+K7C9-=T._M_"<+^'9-7T#7+_2=,E\6Z7J6L:KY^J:]J$ZZG=7%EIEK';>4
MLT\?VF`J82KBU]:C!2Y8N+BN>^BM9Q35_6[T5]CDQV35<BP:Y)PJ8SD3K2A*
M*2346E?FY6[MZ)^=KL_G_P#[0NK?]P-.:00?N1(;@@N(_D#D>3U;;N_&BNEM
M?%&G0VUO#<6NFRW$4$,<\I:0F29(U660E;5U)=PS$J[*<\,PP25]FJ>&T_=Q
MZ?97]VWZ?>_E\2Z^)OUW_F7E_P`#^EI_59^Q+,3#H/A671YVL;5([5Q<W&IO
M917:Q:O(LULD>F7=F;F6TU&)UCM8+JX6*24+&\/G2I^Y.A_LJ?"S2;JT\3:1
MI7AG3=<U>\B&IW=]/:VUM<75R^DLTUZL6HV<9\J".:1H+NUL[V4!O]&2,2LG
M\\'[,OBFYT7QA%<W5I!;)J6JZK_9D]PJW!N7MKRTLHPC:3-9:I!)%9@*KKJI
M3;`ZNI:93'_4U\(_%YU;0[#5[B^U72-,2%+N273M670'N(DM;>VN5>73],EU
M*_@BVFX:SU&XNGN&B1FOXFA4R_@^$GA'F\HXZ-3"^PE.HZU.3:FYM.,6J=V^
MSNFM?1']1>(&(S&GP[E53"X:-:%;"8C"3INI1CR2FHQ@TI33NVTTTMU9NQ^>
M?[?_`(T\/^"?"_\`PI_PY)<M>^*YI9[_`%'P_=SPZ1J(TE-::WT^S6RL;NQM
MXKF/3K>Y2V:WGN)I9(D&H!862Z^S/V,K_4=<_9M\)::MAK\EOI<_AK1XHI+2
MZ626..ULK?5@\D5@)(UC@22YN%>,HDL4.GM('O4N(_RV_;=^#_Q4\5_'WQ=\
M7]3,FN^`[6#P_8^`/#.F)'>WLU];R:';37!DU.*$33B]T[4[N55C,TT9ELP`
MEQ)<Q?IU^Q2]]>?#U9;CPZ=*1#J>JVL6JZ#86&H6M_J6J:-=:FYTQ'N5:`7^
MAV;1W0DC,$;O:A2)_,7'"/!5\TG4>!JM5*E>5&47?VE*A*//43UMIJXRLWT6
MQYG%F7TL%X2Y/3=>C+'0J8+$582K4U6@Z5O;04')2M2LDG%-33?)<^@=7^&^
MI:?9ZK?Z5XB@\/V;IK4GVRV@T1-5TS1M3U*_!FTB86<FL:*'TV^OX+F&66ZB
MBO!;2EA.T2Q?Q]_\%G/CD]SKL/@WP;H/B'0/AS/#I_AOPYXKU2*ZBU#QG-X=
MNC=^(]1CE66UN9+/4]4$SZ@?/EM;FXN+2XD1GLX5D_MAUHZA_86^1-16U,31
MW:M="30HX;J*^?4+F6.2X%LRW>I2Z<T5@+:!M/MX[J1;R6/S(F_S^/\`@L)^
MT39?M!?M3^+;+P@1_P`*S^#$EY\._!7V=H4L+N[LY;(^*;^VC@&R!-5U?+6Z
M[;G$>FR-]KE$Q6/]-R2AAZN-A.%.5+#3P]*I24KMRYDO>:=Y)-K3FULGH?@+
MS7%XZC7G*<JBEB*RA4EHY0CR1AI*S2LK+1+71)7/Q\F\+&>:6=;O2HUFEDE6
M-M%BE:-9'+A&D:\#2,H(4NP#.06(!-%=#_9EV>0TV#R/]'0\=N?M2Y^N!GT'
M2BOMO9VT3T_X;_@_T]/&Y:U]G_X%'R\_)?=]_P#2#\"]6@D&G:O8V30V>GZF
M+NV5-<L+K^SK;4+FR,\ZQ#0[-[I%-T/E$\6[`!`)#)^PLWQIO/AS\)Y?BMXB
MEN-4\&Z3<MIMOIFA:2USJ_F&ZMK437,/]KZ?'_9]U9RWLDTRF0V\Z6T7D3"?
MSH?Y)/V7OVMM*M8(?#WBN_BTP3FTM]!2>VFDGN)DFT^U:"Z+O9I`D8$DYF,L
M^Z2-(?)_>>='_1)\%?'OACXF>%H[.\U2RUO1]4TB"RB\.C7&,=Q*9&\UI--M
M-%U62QE$EHDR7<R218S`SJTR$_A&?Y;6PM2=2A3G4DXI3DHR5GI[MW:]GYM/
M7Y?UMP]G61<183"X'%P>*6$:JSFHR2Y;Q=DFDG:W1-_>>U_#7]O#POXHOK36
M)=`\7ZBG]H)?::%T?4(X[$V]R]PMM,UAJ&JM;K?-!>W1NGMVBMO,$!BG;:S_
M`*$_#S]KWPEX@L)=)2]\2W4EY>V5QI:12:O/)"+K[4^H6LT-[HUG";'31,6F
MD2Z,DCQQ+Y4:&1D\)_9I_95T;0=*;4='UZ+1(=3L6"Z?J`M;FS>;3_M5X&68
M+I=W$+HL+%5^S2B/S1,8Y6`1?KFP\+>%?AGH=]XQ\<:MI>EZ)X&\.:]KES>W
M<>G66F6]C>ZC%I\]Z0=0N&N([*V?:DLOV>2:34$3R(MI=^3*,'CJE3!UZ>)]
MC3]ACJ,XN$FU5JN*@M$[\W=)K2[L9\?9]X9XC+GE]'!8BMF-"G&"J-8BG33B
MFHQ4:D8QNFFG):23:UCH_'_^"A?[0.E?LV?L:?%CQF^K"+7_`!'IFI^!O!-G
M-'+;KJ7B_6([?3Y/LMS]LE,4FG:7J5SJBNEH^^6U^SAH6;[1'_GC:_)&VHZE
M/<7*Q7ES<M]K6-I)FD!+M;K.TDI#2O,M]<7%U@/.UPD95!#NE_6/_@K/_P`%
M#!^V%\38O!O@Z^O$^"/PVU"X?PF\>J;=.UO7[=H[35O$@M4LHE#7@6!((3-<
M>3'&^VYE\SY/Q]F@2YDCOOMT#VDMI#;W&U3)<S7D<DT@N2?,78C1RNA7#[6"
M'>=P`_:>'LNJX?!826*FJE:&&ITY371Q^P];Z=]M3^6J]57J1I4E1ASRY*:E
M&W+?1MIVU6O77LB0.X`'E6S8`&XM)EO<X?'/7BBJW]GI_##*5['>!D=CC;QD
M<XHKZ#DEV_%?YG!>O_4X^7^?X/L=?XEAAMM>\-FVBBMR!`P,$:Q$,=>TL%@8
MPIW$$@GJ02,\U^P?[)6HZA;ZC,]O?7D#B]T!`\-S-$X1_P"T"ZAD=2%8@%ES
MAB!D'`HHKY;//]TJ>K_]*1^P^&_\6M_UX?Y,_L)_9L59/`6CW$BA[B/3+1XY
MW`:9'>]L%=TE;+JS*S!F#`L&8$D$Y_)+_@O]K.L:1^QAH$>DZMJ6EQZQ\2=)
ML=7CTZ^NK)-5LI/#?B":2SU);:6);ZUDFBBE>WN1+"TL<<C(612"BOD<H_W>
M'_7^K_[:?/<6_P#(VQG_`'#_`$/XT-1M[=-(MXT@A2-)U"HL2*BAH2S!5"A5
M#-RP``)Y/-9T,42RP!8XU!09"HH!Y3J`.:**_4L#_NU/T7_I,3\[Q/\`%_[=
M7ZDK,P9@&8`,0`"<`9Z=:***ZS-=/E_[C/_9````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+W1H;VUA<RYG:68`````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(R-#$`,3`U,34T,S$P-C<`,#(S,3(R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y82``(`#W````
M`````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`
M9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`
M_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S
M,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\S
MS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F
M`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]F
MF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F
M_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^9
M9@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9
MS)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,
M,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,
MF9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____
M``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_
M9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/__
M_P#__S/__V;__YG__\S____XOR0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```A^00!``#8`"P`````(``@```(_@"Q"1PHD!6K0(&L6`'`$,"UA@0C2A38
M$,")BX\>77MX[2*`B2`M7AR9\=$>5@Q7>`094:0TE1X+/&*!$L`*E1]9#K1X
M$^8)``4NT$R)4^?.$SU'`A5:4ZE1BB,][EDZ5.3/I]BL_MSSZ$+7H3YS&K78
MD"ND1\16*&08H6W;IP#<MN6ZY]J*BG$C$"#PEF5>O7SWW`1@L###O7MUYBW`
MN$!#5E8*JT6)6'';QH_5!C)H!2&`RGXO,V98N'!GPXE#1\!,F-5#SJ\I$["\
M>G3K@YQ+?YZMFK7!0"M8W41H<#=MUH17!+KV6_ENWB%%V\;MFGG"BI;Q/MX\
MN2;#L6VU?S-$2/XP:)"0VNX5CS<0XM03TP,FT#"0>(/O_:;?V[/US<X(6;&"
M7/I%P-U+D-UFVFV$Z0>)<#<E6%B``BJTD$(A00*)@/]9N,>'>V@HXH@.C@@)
M`"*B:*(;@;@!28DLNICB0R;:%\B+#MIHHGC*K0"73<!I]Y!X6+%GI%C8!`0`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F]B
M869E='0N9VEF````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(P,``Q,#4Q-30S
M,3`V-P`P,C,T,3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA)0`E`/<`````````,P``9@``F0``S```_P`S```S
M,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9
MS`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`
M,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-F
MS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_
M,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68S
MS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,
M,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`
MS)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9
M,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_
MS)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF
M,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,
MS,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S
M,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9
MS/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"'Y!`$``-@`+``````E`"4```C^
M`+$)'$@0@,$5!!,J7,APX,&&$",6!""Q(D2#%C,JQ*BQ(S:.V%88&$D2H<>$
M'%<PD,"2)8,#)D\*Q+BBI4T)!V#*G`G`P,J;+7/J/&D0`-";#$!V+'KTIE*-
M17\V34J1J$$D6+-JQ?HT8U$21<-^?>CQ*A*P8@V2R*K"*@PY;-@@"8LDKAP8
M#-J6!6`#D)ZX8>/J`71#0DRH`+@$"O0WL)[%@;@<]@H`<B`V@2T'FFQQQ0K+
MF(NRT<Q9X@HK@;K$N`$HM,'17&XHME(:X@HN71H<D-`:+0DVA%G*KMVP)LL&
M$KC(F0L`B1PN-XDS]&G31F,`;/38L,G`0$>1)'U>6F&.Q$KW\-(K&DCK?>?"
M%6G3N_?HV63]D/?O"\S/W[YGBO:%)*"`",5D8$*'(02`9_L1V-]`#.)W((0?
M#5B@A012V"!!"7ZTX'X?PA?B@"2*&*"&\Z6HXHHLNA<0```[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]M86XN:G!G````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`W,34T`#$P-3$U-#,Q,#8W`#`R,C0R-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#_V/_@`!!*1DE&``$!
M```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``
M`````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%
M$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U
M-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*
MDI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:
MX>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#
M!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q
M$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%
M1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8
MF9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?H
MZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/XU;O[;;7!F/EV\:.Z.ZO&KB*:"
M6(NYD(1H"QC#/TA&]R1D$?KY^RG_`,$Q/CS\:_&OP0^&W@WX+:3\1_B!\=/!
MUCX_MK[XBZOXI\$>`?AYX3C?2O$4FGW4VG6D<E]XCC\#:AX?UC7+_4'O;.`>
M(=$LK:Q^V:BOVO\`(R],,LLEL9'`O+-H6\S$@:7]]Y"0P#,AEFG:.VE<`K':
M7$]P<):R,O\`J/?\$6_VA/"W[4OP+\,?M5W]CH?@;^S/@W\*/V9_#%KJ;Z1H
MEKJGCKX2:!8Z-\:O$'AN&5+=+G3]?\;W'AO1([VU>0F#2K;3Y9-\$:4`?D+\
M-_A#^RM_P3"^*&B_`']K+]C+X1OK-K+J%KX3^.?C7P+HWQ%\">,/APPM-6U'
M6O`.K>*-&N;M?&6HZS-?:/XVO?$MOI.IVVA6=O8V=A;+IDES/]=?"[]FK_@W
M4_:-O!/X;_97^"G_``F/B#4]6N+[0M-U?Q1I<<=Y->S7=F\PTKQ&8[+3M36:
MX_LR\T:SALX7D^R+`C1[E_1W]O?PO^R-\>/ACK'P7_:?\1?"SP_J5PR^)?".
MG>+O%5AX3\7::RSO%$_ANX%Y%JME/KD`M[.;44W17,D(MC&SPY/\U/B3]A#X
M!_`OX>:O\:_@1\2]5MM6\*^)[1_#'B[PWXOTW6=#TC0H-8BL]?T[Q7J=E_:?
M]N/:W4]QIMYJEQ)#>Z1"RW,EO#=:+9"<`_.K_@NQ_P`$;[?_`()_>(=%_:!_
M9VM=5US]C#XO:[%HNFK=RW>K77P3\?7$,]Y%\/?$.IR37MWJW@GQ7;V=[JWA
MCQ#J$T%PVK6/]BJTC30B?^<:.XDB)\]OGX0NS>:Y=4"R%'C)#0&57,)!.8R"
M6))-?Z6/Q=N?%WQ]_P""0G[='PJ^/.CZ//JWA/\`9T^)?B=Y;,6TIT&_^'6F
M'Q5X0UZWBD@A,<)O['3-5MY+)/-L+N+7-)%PUO,B#_-IGLDN8FG\ITE9(9)$
M(+&/?:PRQ'S%RCF2W>&>0IQ%)*]NV)('``,G9*W(>`@\C(.<'GG/-%5"9`2`
M1@$@<GM].**`.POK.V$,I2<P)L9)BP+2&-D<3%XH\RW$:,;8+$P6.-I'</ND
M(K^W#]@K]EGXM?$K_@GW^S=^U3^S3X#\`?"/PYX8^$NE77Q(\4^)/$*^-?&*
M^)O@OXU\;-\3O&?P[3QMI]WIWPIL5M=&A\>>&&\&Z5JMQKGCB6>/6Y1IKV^/
MXE+^95#M!#%DC]Y.88L(\8DF@C#NPG`)21KA44HB+$Q/)Q_HH?\`!L'XT\1?
MM"?\$D/B)^S[XHU!-*TCP!X_^*7PD\+^*-.OWO=<T[0O&6E/XNEGO-$NEM_L
M5[HFK>*;W4M*DDG#:U;SA$C^S:3*[`'IG[7?PA^-O[0'B7]@S0_'WCK2+BY^
M)?[/#Z[K.JGPUX:T:;QM\2YYK3QEKWA47UOHKV7P]UW4_!5_:Z=X3\4W6CZW
MIEUK&ERP3:-IER\]Q<\5X1_8$\._`#X1_'/7_P!J;XH?#O7/A[\3OA9XE\&_
M%&)_"6G>'+Z;Q!K8U'0/`=U9:GX*1?#.K^++"[U+PUH::M9^&I-4\3ZP9-0:
M]GA^QV-EZA\7O$/Q;^%G[2]AX9U#Q!XE\??`SX,:)X)^&>C^"O$&@Q^!;R)]
M#\&V,<OCCPUKYU'5=7U6#3[6&VGDU[S8+;Q=XEO];33XGM$MGF^Q/'_PP\!_
MM+?$SP&_B-)=:\`P>!-#\6V6AZXQ&E:1<G[58:P=*MXGCAA\6W$173]>UZ[6
M74]*@MOL$-I#+'=RQ`'\MG_!/[]HWXL>,/V?OVV?V3?BQ+XF\,?&KPC^Q1^U
M-:Z5_P`)GI]Q8?\`"W?A?X8^'OB?3]"\2V(U"UT]_$-@EEHTEK'XCL[62VNF
ML3(92ZLU?R"Z8LDEOIR*K%9+"WN4\QC\Z?8[?S@"?]8L<S.-P+`*T8.!@5_6
M1^U'^W/I>F_M"_MC_MZ^*/@NOA_PMI?[,VL_\$\_V'M`U#7;N0_$#6/$'B/Q
M7\-M<^(E@]MHQTT:)X/^'\/B+6M8\/W$L]Q&L?AW2,%Y(9;GYK_X-VO^";GP
M$_X*-ZM^W!X0_:!\/W&I^%?`7P!\">$_!OC+1&BBUGX9?$+Q3KVJW-GXY\-7
M,$4$$OB/2]&\(0QI87L;K=:/>W]E(!.X,0!_-O*T:R2*6LD*NZE&NX592&(*
MLI<%64\$$`@C!YHJ+XFZK-X$^)/Q!\$65Y<:]9^#?''BSPK::Y`VBVL&M6WA
M[7K_`$B#5H;627S+:+48K-+R."3YX4F$;?,IHH`VC/%=9G#%)7MY(-Y^Z262
M5<1X_N)<1"3!RTZIG)Q7]=?_``:E?'#X7W'BC]L?]C3XN_$^[\!:7\6M&^&W
MQ4\#:(OBVZ\"W7B6Y\#W5WI?Q!@T7Q393Z;>VT][8PZ!_:FF6VIQ3:EH`OOL
MT:JMU-7\A$KJ;E8U(*,64;`.-JM(RX&<%45Y#Z(&<_*IK]R?^"%__!.SX4_M
M]_%/]HS5?C%\2/'7PIT/]F[P%X1\3>%_%7A;4O"^D6*^*_&VMZOX?NM-\37'
MBY9;2?2[CP_:79_LZR&G&YD=+C5=3BM;2SV`']:?B_1OV'KW1/C1\0?'/QD_
M9(^)WCGPYK^FZ/X4U#]G&\\;_#;Q[\/T@\3ZA)I4OCOQMJGQ;\777C./2=.L
MK6RO=*NM,M;.74)-7NFMXTG=F\N\9?\`!1W]G#X&?LR:%\$?@K\5=`^(/QPU
M+P5JUCYC>-++Q-I_PSM/$%SJ45S\0/'/C%9_[&N;K1X)]5U71]`6]%[-JMY#
M:NCR+'&/Y$/VLHU^`GQF^)'PL^(7QXT[Q6O@#Q7<Z%H6M^"-6BUC5/B3H3Q0
M1^#?%LLVASRZ;%HM[X.M]+NYS%)>::E_>7D=A?2HR$>M?L?>(_V<IM<T.6UB
M\.:G<ZB)GBN=7T%O,N6M;F/5+JUDU+5()9+-K2WAE807!%NTTLK1H3(]`%_]
MJ7XZ_"'XB>(/A)\.K;P]H7Q*T']G*P_:<_:&^)_A74[[7)_`&NZC%X535/!'
M@:[O=`U33+N;3;A8-`77+73M0M(M82_>U@U*.X>]CD_J9_X-PK?QAX9_87\5
M?M-?$?P_X+T'Q[^VCXL\26WPJ\*?#;P3X<^'GA+0?A1\!_!6M>'?#UIX5\*>
M'['3Q-HUEJ>G>)+HWEU;7>JWMQ<W%[J6I7\LK7MU_*E^T7^R+\:?&7[4?QKA
M^%O@;Q!XD\/_`+:_Q#^$'[-_P,\?:#X=FF\`3WGQ1U?P[>_$#1I_&-EIL/AG
M1-2\+:%X4.F:I`UWYD5EJ&I"8(=/NU@_KP_8J^(?PN^'G[75IX8\.ZU&/@%^
MR[\&-,_8N_9HT#3C9VMOXIE\+V6AZ/XQ\;V=M%,-/LF\>>+HY]0UKQC=;H?M
M%W8V+7+RZ_:QW(!_F9>,I-,U3Q?XKU/5M4-MJNH^)-=O]3M[RX@M;N#4+S5+
MJXO8;JVF9)K>YBN9)$G@E1)(95:-U5E(!7I/[1G@31M)_:$^.VE:/K?A:XTC
M3/C+\3]/TJ>"\M;^"?3;+QOKEM8S0W]M-);7L4EK'$\=W;R207*,)HG:-U8E
M`'-:N2GA?7KM"4NHK/26CN5)6XC9]4:-V288D0M&JHQ5@6154Y4`5][^";R[
MT+_@FI^TT-$NKC1QK'Q#^$$VK#2IY=/_`+4FLO`.K2V4NH_9&A^VR6DMQ/):
MO<^:UO)-,\11I'+%%`'YPV[,UWXA0DE+:'3TME))6W1F:1E@4\1*SR2.RQA0
M7=V()9B?NO\`9)M;:'PQX@O(;>"*[34(REU%#''<(7GT@.5G11*I8<,0P+#@
MYHHH`_MG_9GN+C3_`(0_L306$\UE`FG?MJ^,EAM)7MHE\7^'?V.O&\GA_P`5
MK'"R(OB30I+N[DT;7`!JFF/=7#65U`TTA;\IO@U/.W@CX9P&:4PZW^T]\(_#
M^LPF1S%J^@W?@[Q)K-UHFIQD[+_2+G5[B?5;C3;H2V4VI3S7TD+74CRL44`?
MRP?M0Z-I'A_]IC]HG0=!TK3=$T+1/CI\6](T71=(L;73=)TC2=-\?^(++3M+
MTO3K**&ST_3M/LX8;2RLK2&&VM;:&*""*.*-$!110!__V0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]H=6UP+FIP
M9P```````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q,C0Q`#$P-3$U-#,Q,#8W
M`#`R,C8Q,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#
M$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#
M`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S
M8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H
M:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#
M`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!
M`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q
M%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(
MR<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/R_
M\%_#_P`/>%/&B6G@OP#JMCKNMZ\=/\=:[J]I8)>7/AR\=9&F2)[^YT>WTVT\
M/7&FQ6'S:Q.GEK)>XG:6R@]T\5I<:)8V/AJT2[OH[[PIX>\VQ\/:)>_;=$MM
M>M[F]:;PYX@(\->%[:[T_1[JV\0:E>R6FOVH2[ETLVZ7]M/(?2+;P_IOA&QT
M#7=1\)VVAR:=J=QIOBF[.KZ'=^'H+J[NUU#4HK33OMEW):Q3WZR:9,8)$>/5
M$OO,<N=J^0_$^+7-6U;3;G3T":QI-_H*Z!*EWJ.I:;_8<%_OL/"\.H&:/0$S
M87:K=PPGSDNU>TDEB$,ENO\`(]?'8C,ZREBIUY8FC'FA*3DHQMRJRY;)VOL[
MKUL?VG0R6AEV"<<-R*$F^:G%73]I"TI.]WJI23UMKZL_1+_@CK_P3<^`G_!0
M'QIXF^+_`,>M"O\`Q'\+/@!;^%_!&G?"33=7DT+P[\2O'DHU2*V\6^.O%OAV
M.QU/7--T#PWI7A;QK-H6BZU:P_VOXZGM]065_"ESH?B+P7_@O9^PK^S+\,/V
MY/@CX8^#?AW1/AUX0\;?"7_A(_B'X3^'.JVWAK4-2AL=7FT/3[RRAETNZ\-6
M]]K4-@-15WT349M:NH]2U:[N+JZU%YSC?L:?&']I+X9_!3]H#PE\%$\9?#;X
M7?M,V]UX2^(OC&6TF;XB>$?%MW8RZ/<>*_@M'ITVB0BRLK6^\0^'I_&=AJ5_
M!X>>9[::T/B+PQHVJ:2WQ)\/9=7TSX<^%O'7C[QO\1$^!VCMX>^&/B/Q_KEG
MXJ\5>&O#<NL^*M7N;.7Q?K<VK:[XETK1KW5=4U?2UO\`4O$,'AC1+ZP\/0?8
M=/T>STRR^WP7$N%R_)<+@Z'LJ>9SQD.>M*+G.47"K[J;;>KY;62ZZ;-?`T^#
M<9FF?U\5F#E/*9X9X6G2CRPA:%.+IQDE&*M"2J**NY-6?-K8_%;XR?L">+?A
MM\&_V7_B1!XS\!:AI'[04'QLN-(\0Z9'X@NO%33_``Q^(%MX/O-/UKX>7FD6
M^CV3V^J:B]EHQT?7;I_%FD6!U3.EWT&H1R_.WC_X!ZG%\-?AUKGP_P##WBZ]
MU2>74Y/'M[H]KJFI6L$'BBULKKP5?:+?>'=.BTO4M+:RV7MR9--B,,M[-%)(
M)5DD?]MOB[^TC\+;_P""?[,_P9USXG?!G4A\`_C/\5OB?X:\<>'OBKKOB.#1
M/AU\:K26Y\8?#!O`ZZ))X5!7Q';1>*K;Q=8^/K!?"FH27&BZGX9AU&#5M:O_
M`)I^'/AOPA!KGPJ\(:/\;_#>AZ)XM\56W_"3^(];FO=(M?"OA'XA3VECH-]=
M^'K3^SM5UKPWI\*V^LV^L6-G+H=AIVN6,>B-K.AQZ?JM]]%_K7G6'4'7HT<3
M&$8U%5J4')Q=HWM)IM)<SMK;R3LUXV7^'^09C.G@O[1EA*\\5BL/%RK1J.G2
MBYN'*E=W;A"233<7[MW:Y\)0>!_VQXX88],\"?%(Z:D4::>8?#-BL)L50+:&
M)93YJQ&`1F,2_O`F`_S9HK]MK[X#^&K6^O+4?MP?L3(+:ZN+<(?$'Q&4H(9G
MCVE3X2?:5VX*[WQC&YNI*C_7=WUPF"O?K26_N^?I][^7ZE#P!R]Q@_\`6_&Z
MQC]F750_Z=_U?UMYEX8ET:7Q!J&K:KX0UW2?$GA:\L+#XFZKJ>M6>JV!UG5[
M*VUF,R6?BC3[?3K_`%^5]0CU"'1--O+Z6:YG:4SVB/\`V=;=/J"2V%YJ&J:?
MK?B^Y>Z\3>&K8>!]=T7PII317FMRQ'PQXJN_[..B2:,E[J5C<K>VD4ER\5I/
M:WS$";=)\WW>N:-\0M3\3^&?C3K<WBVZTC5[K7O"OBWS[R#3?A]?WU]J%W?6
M?B9@X\%^*)[WQ)=V]C87.DV5EJVB0RB&YU%FAQ%W>H>)=$TBR\5Z/XW8K;+H
M6L:!%!;0Z5J>NZOJ^K:;HFE/K]UXBGM]6CT!O"\>BIIWAK70DUC9VK3R7&G7
MEU,MQ'\)4RZ=.*C*4^>Z3C;W$M$[.U[]+7MIU5@I8VA4_=PQ;:M=KF3T3BNO
MGVUUT/I_6[CQ5-JEKI&K[;C5-%ATB3P]::+'XU_L_38;?3X1<P3:S!K.FV]Y
MKR:C+=#4='T62+2]9='U/[(LMU)G\]_VC?B3J/C/]H#0?V<KSXFZG\(+G2_!
M^FIH&JGQ1_PA?P]UOXB>+M7\.7FI:U\9O&.M>*M(U'P[\)=#\"SW0\16VB>'
M/%6K2ZS'?Z3;Z-J@7S+CVD_$N'QM<S^$[9M6T^PT7PY)=6WBOQE.ESIVKZ]K
MMO':Z-X6^'^EPVEQK&H:)X<T:&3^T-4DOK+6;O4;674;'5[+39K>RC_)']JG
MP?=VWB:U^(FE7NI:AX)UB*+PO>ZEJ5W/#->C08H8+"Y>Q'VJ74%\FS2_M+V]
MENM1BGN)('O18QP:=:^WPAD^$JY]A98O#4ZR6L>>/,E-NFDUK9.TFK[KI[UC
MY/CW-\7EW#=6>7XNJIQK1:5.23C^ZJ+F32OL^7M[W:QZ_P#$;P1\&OBM\5=;
MUCXB_MU?L1_#+3IO$'@;P\TG[//[-'[2_A3X*:?X3OWUGPCXRU?P]X>\"_LM
M?#O1+V32=$T?PQXB\2^)[^#4I_B5I'C""^M_$_B'QK)KNB)XIXO^/?[37B+P
M]X=^'_C+]J/XT_&+P)\)YM/TWX3:+K_Q.^*'BGX;>'=(\&M;:9X;O/A[X*^*
M5GI5UX4\-II.C:1#HOA:^\&^'(K#2;33K34_#-MJ,%TS^)2>+8V:,::=/T>(
MO]HLI+*S5IX_-_?0M%(2\EFD<TDMU]F0I:RW%Q*]W;3A8DBMV(UG7KNST'2U
M%_J5_),+5=,62:^D\V2(W$UTD$%S/-*]S=F>1[.PN-T1<W$BW'FL/Z+^K98J
M%=XVG".'@E#2G%MKDB^2]KV>_JEJC^2Z&<<0/,L+5RZK7IXJ+E6E4=1MV<DI
M27-HFW)7M;3:RV_3#P]_P6B\:>']`T/0=3_9E_9G\5:CHFCZ9I&H>)_$7@3Q
M_)X@\1WNFV4%E=:]KLFD?%31])DUG5YX9-0U-]+TC2M.:]N)VLM-L;8Q6L17
MY>ZK\.GTC5-2TG4M5O3J.EW]YIU^8-/'DF]LKB2VNC#YI67RC/%)Y?F*LFS&
M\!LBBOBGE/#EW:,;7T_=K;[OZOZ6_7X\;^(ZC'_A7Q&BC_R]711_N]+?^2^9
M]IS3^,(8=3T"]UGP]9^'-'EN;J2.YT^Y\.Z/'<ZC<:-JLUYHUQ(W]HZC/JB:
M7;-<+?W-X+62_P!1B14N/*N(F0_';Q)X@\5W6I:N?[`76-16:UU#RKN[T:X:
MTC33[2VBO+G^UTN]/M[>UBM;>TU)%A2.)$NS=W"2WDW[G_M*?\$8OBKX:U/4
M-)_9J^-,WQ*BFM[K5O!7PZ_:-\+6O@O5?%OAF*RMWL=&^%?[3/A^7Q=^S[XZ
M\6F9I[>T\(_$*+X*>.WM;=+5?#NIS6[ZWJ'Y9?"_P)-J>G>)_A[\2=*?X?>)
M/`&LMX1\3_#OQI:1^%_$FA^)-=GGO;&+Q#9VV]I=.U&66>33_$-K?R:2MM<6
M!,04-"?@<GXCX2XCPOM,HS;*\UH4XP=6491ISPZG%-59TG)5)**M%Z67.KV;
M3?Z'B,#FV'Q,L+3PE3!U*-1.=>K3FZ=6"O%TE*UGS2O:4;I^SDE)\LC-T&ZN
M=)U+3;L7VJRZSJ=SJVLZG%HNHZ//'!%_9QLHKBXNHM2GDT>>73UC;3[&&RBM
MELYHE2T4$`01>)-'L39K)<ZWI@M+`:5H-MXO;PSJ^F:HUX#=L9_`I\*:->Z=
M/"DYTZTO?^$L?^T[."WU5C&]ZT:>B^#?V-?&GB;3=8\`_#7Q;J]EXZL)]2\1
M_"SP[8^*+77?#7C1XY6U7Q)\,9+G3M-TJ)O'D-EJ$.HZ3X8"RWGB"SE6[LKR
M`744$'SU\4]>\5>#M2O9?BC\`I](;P5HW_"-ZKJ'@?Q]X^\.6=EXRME2R`\8
M:#XX3Q'9:?X@LXK>6[O?!FEZ7IMZT8&W5I'9KN?WL%DF(I3AFF5U*>+H<SC[
M;#R4/9.RFWRM\WN\N]FNVR.C'9%GF.P,ZE?`J6"Y+.<*;K0J3TM&5.]X)I2?
M/LK-=7;S7Q#X`_9WN[S4(->T[XO_``YUR[M9]4BU72[3PW?Z+K.HIJ4AU&UL
MO"<.G:I?Q:?):NHLY8_%CFW=))9@RC[)#V7P<U7]DGX7?$#1O$GQ!^&/CWQI
M\)?"*^)[WQ3X>\-^-K6R^)GBG5+W0=0TWPU?Z9\0-(M](3P3X<M[N73]3UW1
M8-(>ZDC4J-36Y\R[E_2+X+_\$MO#-M^SOX>_;@_;;\=^+O#_`,!M%T[Q'\2O
M$OP;LM-U+3O$'C'P9]FOM(^"\6BZP=^LVOB?XM>,O%>@P:+9K966@2Z#8//>
M737,PNU_*SX>I;Z]K.J:5JUKI]_8^'O!4/@;3;72=.TQC/J>JMIOA/P_I'F2
M:8QU;4CJ=]IFFZG+>C4I)C%<K:7LH,5^_;#/HYK0Q&'PN95L1B:&(5/$X2G9
M-*,5S3E*4;/EDXQ:6OO1LFDF?/4/#7,,+...K95EE'#O"SJ4ZDZK51>]3:C[
M+F7+>+YKW]WJE>R_M$_9=_X(/_L)_';]F?\`9V^-\?[+WC+9\9/@5\(_BJG]
MK?%(W>J[/B'X`\/^+E_M.[N)_M%SJ&-7'VVXG/G37/F22_.S45_4=X3@\.^!
M_"OAGP5X>TVU\/Z!X0\/Z-X7T/0=*LK.VTO1-'\/Z=;:3IFD:;;_`&9OL]AI
MME:065G#N;RK>&./<=N25?U;$:7>+3TNO:4]'[EU\'2S^X^9DL8I-1P&$<5)
M\K5.NTXIQLTU/6Z3=UY6Z'\]O_!,+Q+XC\?Z-XDT3QWK^M^-=&O_``=!<WVD
M>+=5OO$FF7MR5NW-Q=V&LSWMK<3EP',LT3R;@&W9`-?AK^WW:6MYK'P=UZ[M
MK>ZUS6_`OQ^TC6=:N(8Y]6U?2?#'[57Q0T/PUI>IZC*K7E_IWA[1-/L-'T.R
MNII;;2=*L;/3["*WM+:&%"BO\T_!G_D>/_L7P_\`3U$_M'C_`/Y*'BG_`+#L
M!_Z@S/C[XO:UK'AGP7?7GAO5M3\/7>B>%5\1:-=:'?W6DW.D>(+/Q/JMI::[
MID]A+;RV&L6MI;6UK;ZG:-%>P6]O!#%.L<4:KQ?Q"^(GQ`^(_@SX0:#\0_'7
MC'QYH>L_#[Q-K^L:-XS\3ZWXHTK5==NK?QA-<ZUJ6G:Y?7UG?:M<3$RSZE=0
MRWDTA+R3,QS117^B_#G^ZK_L&G^43XK+_P#D48__`*]2_P#3D3]V/VOB;?\`
MX)O_``7LK<F"SD^#_P#P38TJ2TA/E6SZ9_:7[/\`)_9KP)MB:P\R[NW^QLAM
M]]U<-Y>Z:0M_--^RS86/_#67P`TS[%:?V;-_P4,^`&C3:?\`9H?L4ND1_&SP
M7%'I4MIL\B338XHXXDL7C-JD<:(L05%`**^`\/O^1YQ)_P!AU?\`].4CCXT_
MY)C*O^Q=3_\`24?ZIETJFZN254DSS$D@9)\QN3Q1117ZZ]_FOS@?S4NGR_\`
M<9__V0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M<VUU<F9S+F=I9@``````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$P,0`Q,#4Q
M-30S,3`V-P`P,C,Q-#$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S
M```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9
MF0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,`
M`#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-F
MF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_
M`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8S
MF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,
M`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`
MF9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9
M`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_
MF9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF
M`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,
MF<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S
M`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9
MF?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_
M)```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"'Y!`$``-@`+``````@`"``
M``C^`+$)'$A0H!4`"!,BM%*PH4-L"UE=FTAQ(BL`#!\V1"BQHD>*%S-JQ-CQ
MHTF+`$:6/,GR6LJ-+6-2?#G0RDJ9+%<0!"#3BA69-&W*9'41P`J6-'G&E.C3
MYPJ$1ROJ%*@4)TBBK)Y"W=E3846B-`<"N/GQX(6S%P"D3>BPZDFS:,^N0(L1
M9E&$'A'257OAZ=FZ.R_&A7H-;MJ)>%W^+:@W[EJM?RM651L6XM_&C_FZE9R6
M,5H"C=7Z/8R8IT*%5.."=JRYM&G,B_E^=MPW\FG:9P_*'MQX;MH5<W>SUHU[
M-U3<M!GJQ@P;>?&=!`9#$NZ<[D;ITYV?!GR=+J3LU44?/C2\=CMKC6(35H\K
M_J%L]<@7HD]->SO;^?2K5YX?$``[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]R>74N9VEF````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`S,#<P`#$P-3$U-#,Q,#8W`#`R,C0T-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$@`"``
M]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S
M`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,
M`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S
M,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,
M,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S
M9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,
M9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S
M9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,
MF3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PS
MF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,
MS`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DS
MS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,
MS/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S
M_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,
M_\S___\`__\S__]F__^9___,____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+``````@`"````C^``$$"`"@H,&")`"0(+%B(8DG*A`^62AP8$&"
M!!.2,*#0P,(5I)X8<*("6142*E1L'"A`0$&7%!$"\+A"A9,\JAB2J))LX9,\
M"P.T#&"`5:`5"!-&5$@BSYQG#_,XL>9D19Y255D*9,7*2B`K*IE.5$'*R3.5
MI$B4`DH"SQ-D)598#'34VK5K=&LN5/'D25H5I9KJ`:`'**`G*^0"L)+8"JN[
MUTI9L7)2)402(1&3&'7Y#XG!BZT47/$8,N0G`5#^K*S0"<,G`!33U9BX"M>[
MT`(Y"03EB9YD?)^<;*B2((!`K!:NLI:GH(K'@%0$6KLJ3YXGJZHX(752,\$K
MU_C^.I.#K&%U@VJY5M%CZ)H30*L<JL@(?D5A3ZKR5+$&B''!*M<\0XI=SR1&
MD0$##01>4\B0THD3>MAU#30-`;#*7:Q8`QL)"2:84'U/,)<'*7E8\XP>7*A0
M`H=ZD#)*%;$UU*$`!+%P314J0)/',ZLX8XTUI4##QPJ"+`2(-4A`L<<5";8D
M0$(V)K?<,\<L=Y<U7SGQ1"?5:&A%*='(Q1*-!K2"%V$!CH+,E==80\H>`CX#
MS8!MEB"4DPEA"(`*>8SBS(`27OE,)\M!(Z%<3L*$(0DW=3(H*6U"!LTHI!S3
MIEVLV)GH0+-<LPJ?G8QBC3..0N9F,@+^^(PUT+320J+^!4'F1"<D6M.@CS]:
M@]^J;9(2$BNS8.$D4;AMYV`U`G;BC*'0.(,$%9Z0`D@RI$AW5RL(/$D"AML]
M0]XSR(RRJJJDR-$M<PQ!U@H+Q$ZX936T/J/F,]4\,8>OSSSCU#-]69$(9(EX
M=-<J<L@9:C6D(&.-*DC\P157>E3A;5I6W#7++#/=%4@5R"!K";CBNKD"(,@%
M\L2).^YFVD"LR/),*>(^,X<3JX2+#+W)Y)JO',[P6S%D'`$"32E4"C@*$CL>
MXPFE)STD(`DW5P&>Q0H%LLJJ"1]#"AY(X%%I@ZMF>$U9/T9LVDR!C&@BJ\Y(
MY<2Y0()=V(^=K'`V853("1D@*TZ8.X=-><@AAW7FTCOH<Y#-))#B!RUND'&.
M/]YX0```.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O86YG<GEB;WDN9VEF````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S(P-0`Q,#4Q-30S,3`V-P`P,C,T-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA00!!`/<`````
M````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!F
MF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_
M``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,S
MF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,
M`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`
MF68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9
M`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_
MF6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF
M`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,
MF9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS
M`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9
MF<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\`
M`/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]F
MF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____
M`/__,___9O__F?__S/____B_)```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"'Y!`$``-@`+`````!!`$$```C^`+$)'$BPH,&#"`566;ABQ<(J"2-*G"BQ
M2L.+#1E>A$BQHT>"&C%FM&)1Y,>3$C-6`2!R8\D5+!VN0$E3(,:'+44R!,`3
M8\V/.JU8R;F19,^>%W].?$FTH="'.)'RG#I3*4*+3"^R'+I"Z%.M6F/"K&JU
MX,BL*G,BK1*(:Z!5JQR6-=NT94^H5@*Q6K62Y=M5>><.%(FT;M>\>JWM'5HE
M+RM6@00KS#A6+$R6C5<%NHPYD+7/BEF!5BP96TF++"W?M:*9LT//H!^/9D43
M*U1LAF\V]HH8KNC1P*VA1!O3LD.23/6*_AT<>+7GU:Q%/@F6*&O`&?\VWSXZ
M^N?I'T/^4F9HY7';Q]ZYJP<.WF-6UFS96@.<>+U]X*N&)\6V-S/DQL_=)^!W
M95T$%TFK0!?<8\S%MHILG\'%WEQ#:<8:=-4\!EAO#UISS8?7P)489(&\-9ID
M;'6((5R:K0(B*T*YJ.%>\^D58A6K?$:;8`OEI>!H<($8"%8E%MD6CM^Q%J%@
MK#&(87HPYH7=6+R-Q990RT$VUUM/=JFCA20YE"-H))4)VWQ\;9E@EQA^V5:8
M2)+96&-GPL6158&PZ25P>XT)FF^*C5;D7%6PHN>>#C*GV79"M?>3CX?^B-^;
MCC47I607KH@A9'[R":&E<)6&(W2`/?<88P^R"&J)`9)6FD+^+"YT:HQ#[L86
M@WN]V19LFKTZ4(]%]DGJ@_WA5=]>N?J*T%OHM1K;KO6%IIFCR@[$5Z/$.C>;
MA=5*5")O"W$)79]M=3L1M$4RUA6+R)E+D6,E7MG88;;=Z6Y"\`YYY%!?/71O
M1"5J!A5>R.TVU+\&T3>D2N3U6&]#"!.TV9QX/>252+V5B'!<_`KE%$-S8N07
ML;W>&W!:#H$L'ELC:NDN8##>AA-E-\W(K;O7.3JS2P;".*V]ROIFA4$AI;C7
M?MB4:2ZQR1;T$I(,,A1QC-&%ZG17*_!:(M(O!^P;M65FG2MJ+"&\*[;4XC96
M0U/U9'9>:!_$=EA43;VKU09QUG9EW1%C@_=!>P=.5M\1!;[WX*9!3+A`5AB.
M%$$8+VZ:X!9!OK93DF]&%58IOU0<XO=6.;!Q=(-N+E=.P;UU4SP!C;-85LQG
M46N7K^WZO7JG7!GED@_F.%5R]9YW2ST*'U%.Q;\:$```.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+V)E<G0R+FIP9P``````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3`S-3``,3`U,34T,S$P-C<`,#(R-C8P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/_8_^``$$I&248``0$```$``0``
M_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!
M`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-1
M80<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8
MF9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;G
MZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*
M"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"
MD:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6F
MIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V
M]_CY^O_:``P#`0`"$0,1`#\`_AR\36@M-<U:W+%ECN<H3'L8*P,@79N;;@,1
MG<00,^PK:+HE_P")-=TGP]H]K<:AJ>KZE9Z3I]I!$K3W=]?3106]O`A;:9)6
MD`7<=H)PWRY-=EX_0-XHO;M[9X'U*&*YAM<(68RJ(!&K;EC+`_,&<HF2%8J/
MG'Z.?\$A?A;H>J_M)K^T%\2-+N;GX/\`[,G@W6?C%XKOCI\UQ;WE]H%F\.@Q
M::EU`++4+J'5UL;V:VE<@PI.@CF2%G;Z[BG/X\+<,9OG,W%3PM+VE.*M*O4K
M5%?"PHT8WJU95:SIPBH0E9M7LKW\'@C(JW$^<9)E4%*3QM6C2E&/O.-.,(SK
MU9*#DX4Z5&-2I*4K*R=M3^@7]D;_`(()?":P^%'@2R_:`\2>(M9\=-I\^N^+
M8_!^HP:;IEGXC\0"UU"[T:#4KFSD74)-)TF&TL&%M&H?4+C4[I!$]Z8(O=/C
MC_P;K?LT?$[P1J'AGX2^./&/PJ\;W&G>1X?U#Q%=PZSX9DU-+@7=K+K-M!%I
MLPL[JZ6&"_FBF:6"V>6:..9E$+?J9^R?^TO\)?VJ_AUIOQ+^#?BB/7;!;,#5
M="N8X(_%_AN[G658[?6?#$5Q=3:8=2N8HQ:72VR66HQ8MM-U.2Z=8U^E?&_Q
M,\#?"[PM/XK^(GC;0/`V@6T=W)/X@\4Z]8:;I0B@N$LU-J;B2.XN9Y;R>SL1
M!IZW(@U&ZCM+BXMP&G'^2V:>+OBG2XWEC<1B\\I8^EFGUVKD,F_:4\/4JQ<'
M4I1DU&$[J,^97A&3<^5)V_T.S3@[@MY`LHPF"R18/$Y31RV.:PIJ*C4I4^55
M(SE&ZK/W9.$6JG-:Z:]T_P`U;QQ\&/AW^S?XOU7X4?M!7_C+3OC3\-;G6/"/
MBOP1:Z+-+I^DZSI=_<3F6'5IIX8;W1[EK=%T_5$LHUU&"ZBO[2WGL$DN(_%4
M\5Z(+2^M=/FT^P1HK\V::I"DMU)#+%(($$B",12R`JJ%E8*Y!P0#7[\_\')'
MPAT.7]H7X$?M$>$[5-8MOVC_`(8V[ZCK6GB:ZTSQ#KO@^TT^.+58IK<V[7ET
M^A:OX8U*9S;62Q27,UI:0M8K<6US_,[K]DT5]<Q6UN,>;:0F.2,HT$RE0T;'
M]ZR>:WRX;9C/S,O6O]5_#[B__7?@SA?BKDC#^T:&(IUH137+B,))4<5&4;7O
M3J72E\,EK!M)2/\`-+C/A>EDW$N;Y)4KSBL%BE2HU&[N2GRU()6U2E%NZ:2O
MUN[1[>'Q=+##%%YEF?*BCCSYJC.Q0N<;#C.,XR<>IHKREK20$@PX()!&7."#
MR,YYQ17V=UW7WH^;_LRC_P!!-3ITE_<\_3^M_1=9TS/B#P:OB2UNM.L]4N],
MM-26ZL[FSN!I9U&./466WN,D&.V:8@^9@D#YAU']V?[-?[._[-_P!^$=WX?^
M$OA?[)X1/ASP.?BCK#W=_=:AXMTQ([=/$^K7(\R[6W^R:)JFKWUG8:9"LT=U
M%:M'=/-!&U?PZ_&+Q%XK\26'A>Z\6:[-K=U;0RVBW?V6"SN`#:P7I1Y(CAY)
MQ<&(/F/85\SG<%']1'_!(7]MO3]5^$OAKPU\5]3NM(U*^GDT#0_$NNJ5T?Q+
MJ&D3PVJV5OJ%U;I91ZI%!LFO-*NYBT%O&9(WO<B,_P`P_21R_.L5P[DV=9?6
MG&E@L93HYC@/K"H1Q%&E.,J,G[\9.4G%)<D93C=->\F?VO\`0SS'ARGQ+GV`
MS#`TY9]B\NQ4^'\YKTW.CE]27-3=*=*<;17L9R]Z=H634I*._P!2?$G_`()X
M^*="^-_Q-^,7_!/?6+K]A;3?#&J>!-*^'YU?X@7^L?#K]I71/$&AZI>^+_&F
M@Z?HS:M/X;N/#VK6UG!J/A>YT2ZT._;52T]K8R02&Y]8_9J_X)47'[0O[1/B
M:'_@H/\`$;]IK]HI_A[\"]"^*WAGQA=Z6FG_`+)FK^(-9@\,27O@S2_'!UZ.
M^UK5O#M]XBBT34?`.F:+H>CZ]K7A#Q5K<^HYTA=$O[OPO^.G@F?Q1XNM/"Z6
M%A!IGBSQ';QVR_VF(K.)KM9S+#'+YL%M;:RPC\Z&W1[6YB5XQ(B3$I^J/PC\
M3W&I^%&O7UGQ(^DW-PJIX9M]>O+CPS9)&ER9-;M-)NGC,5_J@O;J'4[@SRW5
MTLI$ERR-)%)_)6=^)F,R6>:8K&<-T*"QN5QPF&Q$*%%XCZQ.#II/,<5R8B?+
M*2UT;:48N[T_J/B;Z/KR7A?+,SR7B*>.Q-7/%FV*S.CBOKN7RAB*BFL%3PD9
MU*=&4>2<()J+DYR]I90IW_(;_@NI^RS\6/BY^SU\"O%O[/&F:9+X@_9[UWQ?
MJ%_X9A11-#\-SX1\-I!K/AG1PK'6E\)0Z.L]U!;BUN-EE'LM[MT6&3^+7XR_
M#_0_`.H6_AZ#XF^"==U*Z\&6_CE]?T'6YKJYLM5U42RZMX(\1:?)8K<7'B2*
M!)Y);5C8_P!F+CYIC\Q_MJ_X*Z_M]Z1^S9X<\-^!_"_AN[\5_%KQKX'\6:CH
M4+:K9V^AZ+IL\$^F:[?:K+;RB[%Y9Q+/%I.FV&]KMK99_,C)$-?Q4Z;\(VU.
MX\=R>-O`WQ&N?&NE^);NP\3^&Y9++PM-HGB*_>UN-#L;:ZN=%U*ZGU:XM-4N
M#?07$JB]LX4MGEMC=F:#^H?HMYEGU'P\5+.,'5PN782M5>65*EFJBQDU4KN,
M4Y32YY.\G%+K=H_B_P`>>&<AI\:Y;4RO$5,1G$\#/%Y]@(X>M_LN)<_9X93F
MZ2I3<J;4K0G-PO:HE*Z/C_\`M+71PLD+J.%?=+\P[-_J/XAS^-%?K)IW[`G@
M.]T^QO)Y_&=M/=V=K<S6Y\3VC&"6>!)9(2RV(5C$[E"0`#MR`!Q17](_VS@$
M[?6XZ:=/[OE]_P#V\?D_^JV-=FLMGT?\*7]W^\NWY]F?&GQ#L4N_"-_.SQ&3
M3M1TN>WB<*?M*7<%K:10_/+"L:SVT$ETS&10H_<LR_Z\?J[_`,$J?VAOAY#\
M&?C)\`/C+X%3XF_#9-;\/^+=3TY[>.ZU'0M+N8]5TZ_^(F@6=M"^N1W.BSQ:
M3+K<VFL]N++4&:9I?L6+O\KM3EMM374/"U^I36)K-?[(2:*.W&KWMQ;RMH36
M"S>;!-]FE'V%0Y:.5F\UP@#0U^M7_!`/X7?LX?%WXX_%_P`'?$CXL'X3?'.^
M\$65C\$+C5?*L?!7B*YOM1U%O$.FWVJSO%,@@BL_#;RZ`T9BU,W%Q;0^64/F
M?,^)F`P.9\)X^AB*52M.GB%.A6HVC*E5@^:G6@FM94Y*,M8R3:LUIKT>#O$F
M-X8XER[,Z-:G)1488B$XM0JQGR1E1J1Y6Y4ZB]UI1DK2ES7T1^J'P?\`^"=G
MPC\;D^.?AS^U'K%OIUU=Q26^CZ3J*?V[IMAY1)MKR>WE,EE)`D@\@3#[=:-$
MK*LDJA:^I?"7[+.FV/CB"PUG]K7XK>,+:TNHH=,^&'@7QWKUYJ4L$6UHXM;G
M?[%Y%D41I[Z:?3S9I"9$FN$CW3#]*_!W_!'CPWKFI0>+?B)9Z1X9UO3;Z07<
MOP]UN^TN/Q%#`\8LK^\MM)U'2M+U2RU48>Z5K>WO4A=XTN6D*R#Y+_X+<_%W
MX>?\$Y_V$/$?PT_9YTC0O#/Q)^,Z7'@VP_L*1K"[T[P5J=E>KX_\:#4=)A2>
MZOH],<>'=)OKZ]BN?[0UNSU-79K4V5Q_#^%X<XBXJSNEET<WECL-B,3]4JSQ
M^34X8B5/G5/$*&,4'[Z@Y\LY4(1YDFI+0_T(Q?CMP=D/#N/Q6'RJMAZTO:3G
ME%&KA7E=3%0A">&JT(O")TXJM/G4&X325W:ZD?R@?\%$/CYX"_;#_;-N_"?@
MW5X?!?@+X86&K?"OX8^-#=P7'AR#Q%X:-]I^FZ]=:O"M_JE[H_C*_M;^/[7/
M8V\MPFH6E_MACD)3[`\1_#G7O%7A'2_B)!XQ^'OB2]U[PK=-\<-+\1>*=-MO
M&M]\0?#VC>&(;_6O#VF*T5]XC&HWMR\^FZW'%IMPEI;&PATZ=W\Y?YM;77]6
MMM,\G3KB6SO-UQ=PZC8B&SNX;VXABBN99+B&W^TSM)!%]EM6-RAL;9]L),Z"
M=OK:Y^*OQ)CT_P`,Z"_B[7+N+0=,T:VAO=4NH;^:SN+ZV36]%G36$M+6]CNH
M;*:.'=>->Q226<=Q+&R'[,G]X9;P7D&6<,Y9DE)YG@*>5T%AZ;C7IN.)?(HQ
MJ35.;>C]Y\VKLU:[5O\`.K%>)6<OB[,^*<8J>,GG>,J+$TIKF^IT.:])1O>\
M6[02@G[OO65VS]U-%USP>FCZ2B>%("B:;8JA6QB=2JVL04AWU978$`$,ZJS#
ME@"2**_&[2OVK?B99:7IME+IGA"ZEL["SM9+J32KKS+F2WMXXGGDQJ0&^9D,
MC8`&YC@`45\P^!8WTS2LU?1WGJM+/\/P\V?>KQCLE_LV'T2_Y<]N7^[TM_Y+
MYGS%XY);P/\`#V]8EKR'3KHPW;$FYB,-YXI,1CG.98S$8XS'M<;"B;<;5Q8\
M.7EWIS>.-4T^ZN+#4[.RT&\M-1LIY;6^M;N*TUF6*ZMKN!H[B"YCEABDCGBD
M65'BC=6#(I!17U_$G_(GQ/\`U\_1'Y1P=_ON%_Z_4/\`T\C]OO`W[67[5'AS
MX/V5OX>_:7_:!T*W_L^Y_<:-\9?B-I</R1Q[/W5CXD@3Y,#;\ORX&,8K\KOV
MN/%GBKQ9\4_VF[[Q5XE\0>)KVV\<^!;.VO/$&LZCK-U;VEY;ZO<7=K!<:C<W
M,L5O=7%M;SW,$;K%/-!#+*K/$C*45^2^'G_(ZI_]AE?]3]/X^_Y$J_["U_Z7
M$^-[-$\E/D7F6W!^4<@N,@\<Y[^M?6VAP02_$7QG:20Q26J>%_!LJ6SQH]NL
MJ>`8-DBPL#&LB?PN%#+V(HHK]YQO\*E_C_5'\^3^&O\`]?(?G`^=K^65;Z]5
M99%5;NY555V"JHF<```X``X`'`'`HHHK@-WO\U^<#__9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O9&EG:6UO;BYG:68`````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#`P,``Q
M,#4Q-30S,3`V-P`P,C,R-3``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA00!!`/<`````````,P``9@``F0``S```
M_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"9
M9@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#_
M_S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F
M9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,
M_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S
M9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9
M_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`
M9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF
M_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_
M9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS
M_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,
M9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`
M__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^9
M9O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/__
M__B_)```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"'Y!`$``-@`+`````!!
M`$$```C^`+$)'$BPH,&#"!,J7,BP(4%9@?18"63-H<6+"0,%`K2QXD!HT`YA
M''DQ(B!2@*P8#&1E%<F7"ZU4^3.SBL$G5J[`W'F0BS5`50#IN6G%RAZ>2`6R
MLK8EZ$$H+/98`91TIS664P]:67&%Q96B55^"19@3BM&<*L..3'NPRIXK7U7F
M5(MMHL5`".'J1"MPJ%HK,BRR0BA5()2O=`G:;=@J;UHKA^D650F7K<+!"W$F
M+OKU[167"S''I(M78,[*#$LE;LA1H%ZXHA&67CW0<NVB4:Y$,:H'FD(HM&LG
ME/H62^56L0NR7'V:84ZI10-=LY9<.-TK;RU*A`(M6B!6UZ#^L4I.L2KGKY6W
MVC;(4=8U5H+`7POO$=NJ5O5WODZ_7J'[^:7(%QYHK(C'DPPLF,7"@ABYY%XT
MU+'RW2S1O*<4*Z`I9(TLT<A"X7R!F!)(@C)$L6""*[!@4VC6S#=?@='L$4B%
M2V&C!R*!0".+>(T1I.-_+HK8RI`);L6"#"L\81&0%8K'2BF!S`+B>`+.YR0V
MS\C7XG3("8((*\AMM0),_TE9("O*0"F=BU)NZ6(TX$4SBWAJ"C*D*:U\.=M+
M58)4H(AKNOGA-5):>0V@IB1J"IA##ED=2>"U""<T%%7HXGR68KHE1(DJDRB8
MX[4B2X8\07,I-")*N6B%4LY2Z*7^4NY12J*S-HH?A%5MZ"*J498"V!456I.I
MBZV$!V6:LX+IXJ-6N1CE1*5\9<JE+EZAD15<4+HH<O-1Z%MBT,SY'0M18D4A
MJ]?@B,A$5D#T'2N6SIF?6A%:PT(7,AP@@Q7A%@K-"ET((H,,K%R!XWCSS4L;
M*[-,A.\5!%\C9[HQ#,S"1'CJ@3`T"J\F,2)7=`$8(IB">&\7`5LQ9X`=TZ:1
M@(5:8\4!*ZP@<2!?Q8<<(L$AQ#`K#[()C17Q24QHH>,)TO-!!5YJ:8N'N&EI
MN#0N;1"559H2H$:S2"@QA%T'PK/5!;5:LC7((3<>NDW"1_9!XEW:HIW=0OCB
M=Z:\?=#^(55:$_.E&D6TI]X"';)HE802*^$JLG1%.$&A3B?((8($(DCEB"PJ
MBX31(/:X4M:TV,J<\(()Y\ZL(()(M)]C@_![AP@]"^II6SXXV=:@*DN$%;)J
M=RN!R(*ZTH^/&L@JJV"8::$[!G(((*NDU%_/T:MBO2I3P>HL(-8;HHHA5!&^
MRO6%J$(3M59"KTHJKV!C"!5ZZU%%%8;\D8HJV*14[*L=<K%**G\(X!;^$+[@
MS(][US-?'O*@BBJH+53(X1Y-_K`^Z]%D>CN)GOK6!T`MD((45*A"'O)DJP@"
MY7KW6Q]05I04":GB)(!(12I@48@4CF*!8S+(*O*`C#R,(H'AV$@A`5O#DT`\
M(26R`(KW"@$(]>4!#WXI2"E4T4-2?.^%5P0*(+@P-IA$:P55\-4*5%`^`E:!
M"JK`0QZ4M!)L+-!ZA?C#%FKXPE4\X0D2VDG-5G"(0*P`230!1,U4D(<J/"&*
M!-EA`%.!/%D<8@M-%!LKMJ*1E_B1!2L(Q,!J]@<N'&(%,5B!'MB(D`52T!#)
M8\41YV>%/"WH=@T1DTK^N,<J'.()+`@E"Q&RBC_D815<J-D5]DA+P.R1)\<4
MB!_G9Y$FSJ]F6S$`,7-8,YCDD""8U&,R!7+-UGGSF^"D2T```#LN+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUI
M8BYG:68`````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-38`,3`U,34T
M,S$P-C<`,#(R-#`R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``
M,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`
MF<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S
M`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS
M9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S
M_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF
M,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!F
MS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9
M`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9
MF3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9
M_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,
M9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,
MS,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_
M,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_
MF<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````A^00!``#8`"P`````(``@```(
M_@"Q"10(H*#!@P@3#EPX,*%#$A!)Y)F8!P!#A@X+(HD(D:)'BQ<).MP8T:/)
M@B&Q9>0HT>3'E"LYNGP9\B'+F11!7DS(LB/.BC`1]O0Y4R=&G@`"%%1:\.1!
MC!LS(KR6D:I.`"0A2MWZE&">H0:D2B3AL.'$@BS%?B6+T&Q%`#W#\IS(UN!"
M`&?1RGS;E&C7NSE[NFQ)<^=9P3]SIE2YE"42IW`5+V8<X.;'@@8D+SXHF*U6
MO$`GPTT:%\"<TZ<KAMY<=VC6QU\G$_P,-RU<V*M9UZT=$<G!L[+U[JZ-6_-F
MWCR)`A<-@&K4Y#Z-UFQ^C2KMARB/%ZQN??A)Y@>Y#&<LO-.A^(29EU\,"``[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O=F%M<&ER93(N:G!G````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S(V-P`Q,#4Q-30S,3`V-P`P,C,T,#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`
M``````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01
M!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"
M`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A
M<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;G
MZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^M?X4Z)X7^.?QA\(?M0?#&Y6^
M_9^^-'[$.D>$?!-U8:2=,M-,M]>\>S>+HQ'"MP++1;G6?#_B71Y6T(6?VF^U
MC14N`U@+*_@D_(7P;X-\>?\`!0/_`((]?ME_\$U/%G@Z/3_VIOV+=$U;]G3P
MS!=Z:EK;>*=:^#T8U3]G/QYX>?4Y;-K*X^).A>$])T5M4$[6EM=WMSJES']C
MO?)?H?\`@DWXE_;8^`7[*>F>`?@-^QG?_%/]F"?QM?7_`.SQ\6OB?^T/X:\"
M^(==\&^.?B)K<OB;QQJWPJU33=0\4>`OAWHU@+;6M'\*6T_B#7Q!<W][ICZO
M97;3-^]NG^,?@_X=^/.N_#N/Q9I3?'GQ]X!T7XB:_P""+6Y']I)X#\)W,7A)
M?&VHV)MY8]-TQ+^YBTFUO_$%[)J&IFTGLM'MWM]+NV0`P_V=!X3^$WP?^!7P
M'NKO3O#GB#X?_!OX9>$%T"ZOX[@6=[X>\'Z!I%UH*:LT[V=]KNFW5DKWFD+>
M#5;JQEM]8CAECD%P?H[4M1CTK3;C49X+N1+2V,\MM:PBYOE13AV^SPL_FB(`
MEC`S*V&*!EP1_/[_`,%2O$?B;3]#^+_BG]EWQ=\1?AC\=?A:=+\6>*_'T/CP
MW.G^"C?WFC6,&B^-?@)\0X/[)\5?!KXOZ1IMG#H_C7PC)K.CR^)%FT&6;0O$
M$=Q8GX7_`.",/_!PS=?&WXG6G[%_[=MSX:\$?%N\U`^'_A)\8;..3PYX-\9Z
M_90;;GX9^++;6+J63PSXKN9@I\)>?J/V?74$.C3WB:W]BDUP`_?_`/;>\9>%
M_&7['_[1EWX;\1Z>==^'_P`--7^+FG0MFWUBPOO@O<6?Q<M;@V.J"SN+*&UU
M7P?96.H:C:SE=/FDMKB*\L[V"",?5&L:)X$^.'PXTL>(=#T[Q5X2\8:/I'B6
MRM;I3,95U+18-2TRZTG4XOL=]I6KQP7<5QI6N6$UEJ%K*BO;RVY(47/B/\+?
M`/Q9\/:CX5^(7AJRU[2M7TS6-%O8I6GM;JXTOQ-HMWX<UB".^MI;>[AAN=.U
MJZLY+87CI@Q.`\\%M)'\'_\`!.?Q+\3O"'A[XG?LC?%_Q+9>(/&G['GBD>`=
M"UN&RM'O_%7[/.JO?3?LW^)=9NH=9>2Y\0V?PZ\/QZ7XPNWLO/O]3C99';55
MN9W`/H6#X)_M&V$$-CI7[7/BE-+LHH[334UWX;?#;7=;2PMD$-FNLZY>:(]Y
MK.JK;I&-0U6[=KG4;L37D[-+,Y)7UBD2*B*8TRJJIRD9.0`#DJB*3GJ550>R
M@<`H`^(_^"=&I:?<?L;_``(\*V]A!H.O?!_P+I/P"\?>&Q!##=>&OB1\#7F^
M&'C;1;^&`D6TL'BCPSJ%]IMM(8VO-(U2R\1D7%OKMI<2<KHL/PT^`7[=/Q2U
M3Q7JFHZ/XB_;2\-_"ZY\&:_XH6T'AG4?%?P5\-:EX4U+X3>%?%!\FWTK58?"
MKZ5\0K#P7J%U_:&LWNH^-?$'A:WOH;;7(8OP+_93_P""FGQ?_9T_;DTF#]JO
MP[X(T+X.?M?IX<\+>._BM\,-2O)/A5K'QKTVVT[PG\+_`(_:=H<T"S>%;GQY
MIMA9_"SXS6&@F;3=-U*W^&GC#4+:R:/5[KQ#_4-^T)^S_P#"?]J'X1^*O@O\
M7/#L/B'P7XLL;>22"&\N-,U?PWJ=E/)=Z!XS\&ZYI$]KJ?AGQIX5UQ+?6M!\
M2>'=2L=6TS4K6"XL]0!6)'`//_VH?V-_V9?VK-.T*\_:&^'6D>*)_`*ZI<>'
M_$5UK7B+PO>:%#J5M&VJZ??:QX:USPU<W_A6[2&&XU?1=:OIM"OYXO.DL5G*
MM7\('_!37_@E%\'?V7M6^)G[8OP&_;)_9P\76<7B@:YX/_9;N;:P\1>)]4L_
M%MU8:)?Z5H6G>,O%7BP>*;6RL)YM?GN=3T_4KC2[R4RQ/#)!`R?NS\"?VN/^
M"I?[`?[2OQD_9!_:?^%7CO\`;W_9O^"OP[L_B!\._P!IKPCIVFG]I#4_@YXH
MU/4M)\!W/B+3X;^SM_BCJ6EZIHMUX8^($]KI8\8Z3K(LM8(O-%OX9V_5/X=R
M_L/?\%5]+\)?M`^#-8A^(VE_#][OPM+H\OACPUINH>$M?N)1J6J:1K\GB#P=
M>^,M(UFW'FZ9=-X=\26.FW(M!-;&2.X%R0#^=;]@;QE^V'\&?^">S?M!?%G]
MO;]I[4/$?@SXI6'PMT;]GWR/#OQ0T>QU*\A\*ZG\%O"^L^*?'EG;^,]$?XKW
MNKVEKIGB<ZAK_@QO"VH:?)'Y6H2I=C^JC]D/]F#4?@+HGB/Q=\2?B%K/QB_:
M)^+T^B^(_CA\3M<FME74-;TC3Y+2Q\*^"-"LK>WTWPW\.O"\M[J-GX6T>VMT
MN!9M'?:W=:IKL]SJ3\!^V)\&?V&/#WP,\=^/_P!I[PAX+\*?#+P=X3TZ'6O&
MMO=:CX:\4V5CH%K9^'/"]IH6M>';C2_$&I>*[*Z30='\!6$,]YK-QXJ;1[33
M+226"RCN>Z_88^(_Q)^)_P`!;3Q3\19=:OHI/$VO:5\.M:\8Z3;Z%\1?$7PV
MTDZ9::7?_$O3-+V:*?'\>KG7="U>]\/VEAHNK1:38ZU9VZ-J,\TP!]H`8`&W
M9@`;1@!?]D!20,=."1QP<44!=H"]=H"YP!G''0<#Z#CTHH`_`;]K>Z^&_P`=
MO!^N>$OVD_\`@BY^T]XF^".I6<*1>-_`.C?`[6_B5ID)CGO8]1MOAY\*?BQ-
M\5_#20")H=2N;1OM\D'G6,NGR17$MDW5?\$B?V[?`7Q0B\5_L43_`!H3XL^-
MO@+I\E]\(_'7B&PU?PUX^^*'[/MEJ\6DZ!;_`!&\$>);'1/%7A/XU?!B5[?X
M7_&71M0T9)KC4-.T+X@I<W]GXOD$'[G%%`5`H54(VHGR(I5PZ[57"C#`=N1E
M3E20?S>_:_\`^"?G@3XP^*-)_:=^".A^%/A3^W;\)DG\0_!CX]VMA+IK:IK%
MGIUS9MX%^,"Z&UK)XW^%_C/39YO!OBZTU>UU36-+T:]M]5\-7>F:GI5M=Q`'
M1^,=3.C_`/!2;X/IJ\2:9IGBK]CGX[^'O"FMW:7,,/B;Q=I/Q<^#'B/7?#-K
M=K%%9W&LZ3X+TW4O$5IINY]031X-;U6TM;^QL+OR<WP!XI^"?P>^.OC_`.!W
M[,?@VW\7_%7XK_$S4/BU\>3X?ETK3O!'PQDN=)\.^']6UGQ+J-M'!%#.FGZ5
MI5OI7@C18K^]N?$EUJ<VIWUG=R7CR:7PI\9_!K_@HM^SY%<_$+P7<>'/&/@[
MQ7>>%OBI\-[O5;G0OBC^SC^T#X,ADT#Q1I-KXFT"ZT_6?#GB70HM1U;_`(1W
MQ9H%Y8/XI^'^N6MQ93SZ%XAU&TN?P.TK]G[]K;]BOXL_';1O^">OC/X:W'@7
MX73:C;?&?]H/]I'X=Z[X2T;3+6#PS?\`C#Q./%OQJ?4[_P`)^/[OX<37&@:-
MI'AKP9X5N##XNN]2U[QMH+II$"S@'[!?\%!_$'@#6_%/AKPC/XBTWXA?%;3-
M-T[PS\%/V?+OPW9^(O"</[2GQSU-/"?P?^,OCJ"\DU+2K[4OA?X1TCXA>./"
M^C:K979T30/"GCGXA65M_:6F^'IQ^F?PO^'^C?"GX<^!?AMX?EN)](\">$_#
MOA2PO;F1GO=2@\/Z/:Z1'J6I3&21[K4+^.U%U>W$TDTD]S(TKR.P5A^1?_!,
M?]D_QM<Z)\,_VR?VF[32E^+/C3X?6_BSPIX'$^MZUJWA/5_BCH$$OCSXN_%G
MQEXJ$.O^-OCMXX\*/I/@S5WU+2M#\+?"GP!I-I\,OAUIFG:;J'B"+4OVP&<#
M<,''(]#W'WF[_P"TW^\>M`"`````````#H`.`![`44M%`#8R2B$DDE%))Y))
M`R2>Y-5+KBWNG'#Q07LL3CAHY5MU19(VZI(%=U#J0P5V`.&()10!^2_P;1-"
M_P""T'[:&AZ(BZ/HOB#]CS]E#QKKVCZ4HT_2];\92>-?C%X=D\6ZOI]H(;34
MO$TGA_1])T)]>O89M5;1M+T[2VNS965M!%](?MQV5GJO@OX%:%J=I;:CHFO?
MM@?LRZ=KNC7\$5YI6M:>_P`6]+O'L-6TZX22TU&S>[MX+IK6\AF@:YABG*&6
M-&4HH`^URS%$RS']ZIY)/(TQY`>3U$@$@/9P''S`&KP54`1%5$0;550%557A
M551@!0``````,#BBB@`HHHH`_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O874N:G!G
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(S-0`Q,#4Q-30S,3`V
M-P`P,C(R-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!
M`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#
M`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D
M,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BY
MNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$`
M`P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0`
M`0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E
M\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#_
M`#_Z*_HO/[`7["?Q5^&BZ1X?\._M)?L^_&S2]-O7;7_$.B^)M=\*:C+;6-[<
MJ?&GP?\`$NDKXY\/W/GV4UO/K'PG^('QDT6PAAEU37]%T"T$EO;_`#MIG_!(
M?XA>$?`?CKQY\9]&\6:-X:T[X@_#/P7\/?'7A_4M-O/A[\0--\:^'?C+KFKZ
MSX<UY-$NS>WFF-\-='ACL[M=/N](_MBY@U_1?MC6]O!YN/S?`99E^-S''U_J
MM'+J*Q&,I5J=2.)HT755'VD:/+>O34[VJ8=U:<HQE*$Y1LW]?DW`W$7$&=93
MD.38:CF&-SS%?4\LJ4,12^J8C%.A]8C0EB9N,,-5E3Y?W6*5"I3E*,*T*<KI
M?BS17[]?M.?\$2?&'@7]H+Q)X'^`ME\1M:^"6KZ)\,_&OP;^*OQ6U?P7X9TW
MQOX0^)O@;PUXKT^&P\2:QIGP_P!#\;^(M*O]9U+0M6T_P#IVH7L%_HNH6D6D
MS7%L?/9\5/\`@@YXY^`'PBOOC'^T+^T7X0^"OAH&1M#N?''@#Q%X<M_$4L.)
M[C0?#VA^-]7\#_&#Q=XHCL2MQ!:^!_@WXHT*Y>YT]9?$5E%=RS6?0\=@6L)[
M/&X;$5<91P^(I87"U5B\9&EBHQE1E7PN'56OAU)35W5A"*M-M\L)M<-3A3B"
MBL5.OEE?#X?!XC&86KC<7*E@\#/$8!R6+HT,9BZE##XFK2LKTZ%2I4;G3C&#
MG5IQE^!%%>Z^&/@C>^*M2-GIFIW5Q;RW#VEA-'H[FZOIY',-FL-E'?3.\DDK
MPF2WCDD<LPM89'F=&KU7QQ^Q9\1OAYK5YX8\9#6?!WBJP$+WGAGQSX+USP=K
MMHD\8EB:\TK5F&H6OFH0]N9;41SQE9$DV,&KZ2AP[G&)BI4,&ZG,I.,57PT:
MDHQM>4*<JT9SBF[.4(R2:LVF?-.K!7NW9;M1DTMMVE;6ZMKK?2Y\:T5]+_\`
M#,GB;_H8]"_[]ZA_\CT5T?ZI\0_]"NO_`.!T/_EOG^?9D^WI?SK[I?Y>?Y]F
M?U'^&?A79^,+&SUWXJ^//VVO@+X)U;3&U;P]9_&_Q?H#_$7Q;8AO-_M#PK\*
MM+N[OQ3=:!&JVTMSXN\1V/A/PC;1Q3W]QKD-I;B0=/H^B_LV_$7X-_'31?@M
M^T=\>_B+X[^"WA7PY\7M1\!^-=>TCQ9X*U'P<?B1X/\`AC>ZK)J'AJ>]\(VG
MB+0[;XC:)J,<'A/Q+XXTNVT]=2M9M<@NHWAG_G[\5_&;XL?%:*\N_B+\0O$_
MB^36;R34M:;5[Y9&\1:D[V\AU'Q+-#%;W'B>_MKBV!L[KQ"U_-I[JXL60,;B
M?JO@I\2/C+X`\0Z]I'P2U#7X?$?Q9\*7?PEUO0?#>CIK^I^-O#/B/6="U>;P
MA%I`L-1N[U[_`%[P[X?O[6/3(%U,:CIED]G,CJ5?X7-_`W+<XR+-H*5'"8_%
M8#$++:,,7C7@*&*G23P]?%8BM*I7JPI349J,:5.FW=U*4X\L(_T1PA](OB7A
MCB7A_'U*]3&Y;@,TP%7-JM3+LJ_M+%Y72Q5.>883!TJ5*AAL-4Q>&]K0]HZL
MZT>9.EB:,N><_P"KKX):M_PC'[/OP)\2>,O^"N7Q%_9N\0_$GPW\25^%GP<\
M367BB\\)(OPC\02^#)?!7A3QKXC^*7AGX8>&-5N;.7PS_8&FZWJW@]1:>(X-
M/T^"2&:9G_G;_P""E7Q_^+WQ<^(2^&?'WQ9^(_Q1U-K2+1['5?B3X%\)Z%?:
M-HMC<ZA)JEK;ZUI'BKQ1J3*+A%2S6TNKKP]KVD:I+J6EZQ=P7,?G_,W[6_C[
M]IVR\.?##X(_M`:;XN\.:;X&TK5O%?PZ\+^+O!MKX8NM+T?XPV'A+QKJ6IVE
MY+I%EK.KVWBC3D\+ZH(M1O+^+2E9(K)-+N)M2MI_&O![Z]J&FZ,->UG6=3@T
M2P^QZ)9:GJ5]>6NAZ8\[7$.G:79W4OEZ;;O.6N9(;6,0LR(/NE0.GP]\)<%D
M4LBJ5<55Q&;87`T:>;3PN;9IB\IK5J<5%UL'3Q&)5%*2C2;_`-EA3BW5A&DH
M1BX^9XL>.69\<9AQ1A,+A\)1X:Q^;8K&9-'&<,\+Y?GV"P->O*K#`XO'Y;EJ
MQE7DC5G!RGF%>M*<:5:IBJM7VDI_9GP__9%UJ7]E;5OVH]"^*WP&72O!?C)_
M"OB#X/3_`!3L=(_:(T>V:Z\-6ND>,+/X<:G;6%WKOAG5=6\2(B:AX:U/4[^U
M>QO+J]T^"WM9Y+:S\?OVJ_V@/VE_^$%OOVA/BIXE^+&H?#/PI'X(\':YXQ>Q
MU#Q'8^&89C=IIVI>)_L<6O>(F%R9;N34O$^I:QJ;W,]W<R7CSW=R\WSS;F.*
M!9&P&=F&2!DG)`4-QA3LS\S!0<DD#IYUXV\3R65NMM9L'U"\?[-:0`%@TK/&
MA0$$`^6)`9<X#R&*$D*SHO\`1D:='*\/+$8J6'Q-2C.I4P$_JE*G7P="K3C3
MCAX5%*3G)Q;ASQ]E*I&IR3BU=O\`GQU%-1C34J;G""KI5)2C4E&5^=QLN5?#
MRP?,E))ILZ-_%]@CLAEARC,I^:)>5)!^5[E6'(Z,JL.A`.117C__``KQI_W\
MUU?/+-^]E=+=I$>23YW99)2\KJS,2KR.[L"&=F8DDKS_`.T\[>JPL;=+U(7M
M[MKKFWVNO-]U<4*?\SZ?:]/+U_'Y]=8D-9VI&?\`CWB'*LIRJ*IX8`XR#M;&
MUEPRDJ03Z'\,_B9X@^#/Q!\'?%;PHVE)XE^'_B+2O%>A2:SX>\,^*;"+5=&O
M(KVQF?0_&.C^(/#EY/#<11R63:EH]\EM>+;W<,0N8(77\R&UG6'SOU;4FRS.
M=U]=-EWQO<YE/S/M7<W5MHR3@5&^IZE(C1R:C?.CJR.CW=PR.C`JRLK2$,K`
MD,I!!!((P:^)EQ=2E1=&6`E-2I.E)2K1Y9)PY)*4?9OW9)M.-WII?6YV*C)2
M4E*S3335[IIW33[IJZ?<_3K]MO\`;C^('[=W[0MU\;?C=-X/T'5+N*#2M/TG
MP]9KI^F:1X<M[^[NX+2%M0GNM5NDGN;J\O+A[NZDLTU.^U*[L;'3HKN:T'`Z
M3XV\#16\<:^*_#<3R`L5?6-.A"*BGRTR\Z*@6-05C8A@[%``S;*_/6BO.R[B
M6IEB<</@</[/EC",92FG"$5913C962O]GK=W*K477<Y5:DI3G)SG/2\I/5M]
M-];*WJ?I/<>+?#HB62#6])N!(F;<PZC9RQLI7<DA9+EE$;E@YVN=V\F,$9(^
M:KWXI^'HO%?V^^2_U2TM(F2T;3EMI`K.21(S7%TD<LS*\C.ZLP1WB)/F0-"G
MS;16^8<7XW&^Q]G0I8?V515+<SJQDU;E3C*,5:+3:3YMU:S5WG3PL*=[R<K]
M;6_5Z'V6O[1'@D*H_LGQ.N%`VK9:257``VJ?[:7Y1T'RKP!\HZ45\:45'^N6
M=_SX;_PGCY>?]7]+'U.CVE_X$PHHHKY4Z@HHHH`****`"BBB@#__V0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VMI<FLN
M:G!G````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(S-C``,3`U,34T,S$P
M-C<`,#(R-C`U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1
M`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!
M`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P
M)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!
M``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$
M``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A
M)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`
M_H*\#_$SP/\`$KQ9X\\-^"]4TKQ!%\,?%NE_#WQAXL\.:II>H^'+7XH?;+BY
M\3?"[2;ZXUF#^W_'/A#P_P#V)>>+](^R:18^';GQ=X>TV37[WQ%;^+/#OA3\
ME_\`@K]=:]</\';.'Q!?>&=!U/\`9G_;<TK4/$VC6;ZK%J/C#4=3_9M\2_`7
MP1X9GLY+>X/CCQW\=?A[X4T/PYH\ZO>ZOJ=I=>#M%U26^O;A=)^\OV/OV>]'
M_9+_`&=OA9\)M/M;N/QA#X1T&^^,.JP3W]SJ7B?XT>(M*7Q?\0_%WB#6A>Q.
M^K75]K%AX<C\0Z]!J?B*PT+PUX2\/IJ2:;X/\.6NE_GO^W-\)?"/_!0#XXZU
M\/?'FM^,?AE\//V0-:M+:;4_!NI000_%[QK\2_"O@_Q'XV@\5:K=VMY!X;\*
M^`_`=WX0T3X;^)/['O;+6KW7?%USITOA^S\/7L=I_`."JY/PYFM7%8W%2IX7
M`4')KZK]85;VJ5&*G27,HM2<7!VDDW>2E%2B?W)@*.)S&MA94:M.,:]6UJO*
MX66CM>+Z25[--V2NKMO\]/V5_P!A/X??M'^`OC'\6O%7Q9E\._&GXT^++_7_
M`!1H/P1U_P`$WMM\-;W5?$MWXPO_`(:^)=,6[\5Z#X2TKQ%X@\*Z)\49_#6L
MR:5XCT23P[I'AJ\:W\>:%?7-?1?BC]E/X"_"'QIX;\*^,_VD/C=XS\1?$C5O
MB+XJ\"_`3PDO@7X;:CJ.K_$"2W\1Z[?MX@!\-Z/I7AOQ#,MA>:=X;\9>,_#V
ME^)$TOP\]G!K\NE:1-#V6F_LL?LW7'@/P=X&_9Z\1OX4\%?$KXV>%O$/C"Z\
M%?$3Q-XSN/%__"&?#WXN:_INCK?7_C+4="7Q/"US<76M6=IXJTM5T&R_X3OQ
M%?:GXZM=7NO$GNOQ4_X)_P#[,?[0WQ!\7>,/B;\-[G7_`(B?$6Z@U6+QKX;\
M;:II_C/PE!H]K*VG>(OA1%>WWARQOK"U.FJ]AK6FW=]ICZ+=VH.@:I>&#5#^
M?YCQM3J\3UZ&*SS,L-E6.A.="M'*$ZE&%N6$$W*,H0BDTE&JN1-R@N:I*1^L
MRRY8'!4HT*N!EBZ2YU12@E4;Y=)**:FMY--2>BV;2?#>"/#G[/\`X#TW2?V7
M_&?[,L^G_"2]U@0VFA?&/1M=D^)'ASXC:OX+FT/P=JOB;0_$>A^*?#UYHGC/
M1?"EEX!\+>/OAKXH\=6^D>);;2_!NEV6@:AXUTOP]X6\`\4_LOOX?_:O\7V.
MGG]H3]H)OA1X-^'WB'X%66@_'/X01CX*_#:?6/$]GXU\(&U^,5QK.OZI;Z0]
MOIMYX-\#^'K74O"7BSX/ZO/X<\37FI:U\--.U^#]'O@ROQB^`'PE^)L/Q=ET
MKXV:M\"?#GBQO@Y\7[;4[/3?B?\`%#X.Z=X<O_B%I/@[Q7)?+HEX\NB/8VF@
MVEG<^,M3_MD:I>>*]<35_$?AD:EJGPM9_!:QT/1?V6_VP+W7_C;HG[4OQC^-
M'P1^,.J2Z]J0?X3?$[7/$FB1MI6G:-J_P^OM<U+2?AOX5^$WB9_@MX-U;PW<
M:Q9Z1IFJ>'?ASXZ\.'1]:\5O9].09GAZ53&3PW$>.S>A4E[!2Q*K2:JU)>U5
M2/M*D)1BXI4V[/EM&$H>TE.</G,7BL95@HYC3PU*M6DX4:,(**C9<UU&*LG*
M*;=M=.9W22?H7B_]GSX#^.?%OBCQM(/VXKB3QAXBUOQ3)._@;]GFR>9_$&I7
M.K-*]GKOP,N-;M&D:[+M;:S/-JL!8Q:A+)=I,[%>2>)O^"PW[0'PR\2>(/AM
MJG[$$7C/4_A[K>J^!]1\8^&OB;XTO/#GBR_\)W]QH-YXE\/W<?@74([K1-=N
M+"35-*N$O[Y)["ZMY5O+E6$SE?:1H8V24N>&J3UQF&3U47LZZ:Z:-7Z,^:_L
M]]F_O_33KTT^X_HD6>SU#QD][;ZO9:_::MJ:7T%Y9R6>HK)IFM_9]6BFN;]4
M:*>>WT[31<Z9J%NR:%J7A^2/4!`\4D;#^3O]I'XD^`-2\)?%?XN^*=8^.6A?
M'[QK^U[XG^&$WQ.\6V7P:^*?[)NGZ5\*/C=\2]"\%:CH.@:]H?C74=7T3X*?
M`>.?0O`HTS2++5H_%&J^(H==?4-.T32H=._I1^,WAJ_/P&^.'ASX>2Z=X:\3
MS?!+QGX8\#7]A;W.GP:"8/!=SX>\.P^1I9A3RH-)CM;+1[?2(H1H.FV^L1(L
M0L+81?@Y\`O%'A_XR_"#]D?P)\.?@Q\$M2TGXB^"+KPUI=I\6O\`A';S0/"W
MQ:^&'@#Q-KGQ8UN:SM-,^*EK9?\`"X[K6+35=(\4:M'H7B;4+N2]AO-,TR?5
M=:TZ;BP.=2I8+$YC5P=/$K%.A1E[2,)2?(IUHQ:J74N9PYE+EG&#@KVYDI:9
M)E&!K\]/$8C%4U2I*>'EAIS@J=1N"DY..JCRZ:M<VO6S/JKXF_L[^%/V?_C=
M\!_CEIG[:7[5EM9>*O%\/[/WQ1\7WK^"/C7J$WPNU?X>_%SXR3R6Z1?`76](
MMK#4_&'@_P""&@7>M0:5JOAJ'1-=U"PFCGT_P_?7S^+^.V'Q+\=?!WPO\)/B
MWX=_X*"0>/;GQIXD\<G2O`7PM_9P^+OPH\<?#RST33/!WB_0OBIX8\+:+::/
MXEE\8^)-*LM2M-1T^WENM$\#^)[;4M8U*UFU)[GTKPM9_L]_#+Q#9^'OB]\`
M-&_8J\9S2I9^%O'>DC3/"WPZU6<6ZZ%+HOACXW>!#HGB;P]XF_L_Q"V@ZG#X
MIL]$GU/2;F]\.7$=K8^+[RQTWH['QYX2_97\;:KXFTB_^&VG_LG_`!?\2_#_
M`,-:RWA'Q!X-70?@9XZTR;5O!/AKQ#HWA[P_?>&/#M_;?$B.>;PY)!I&B_V;
MX<US3]$\2^/?$9U'7=274/,Q7$F,KTN9</4\=.C2G3PL?J=*7M-'>'[M35XQ
MJ0M%SM:+4KR<8/T9\,06)A7_`-:91<9+DIRQ53VL=(^Z[RYY+>RC=N6BLVDN
M+\0>/?VI]!_:A\)?%35?@A^UVOP]UR*UOM7^"(\0?"SX@?#G1O"7AZY\,6_C
M;Q)H%C\,OBSHOA_5?$"V_B'PE=:5;:W\.M=\0>)]0M[Q])F72=.L;2TZ+]G?
M]I33+_\`9G^'GPS^#G@I8?%XU/XP_&&#5_B;8:[X)^$'PO\`AEJ?QB\7I\/?
MCIKGBNWLX_'>B>'O%::YJNE_#W3O#OAF?6;W49_$^A6?BOX?^$(+;Q=J/Z8Z
ME:7%N]Y:FY:TGDNX9KNZTVWEAN7CM+IM6BO1<V*ZEI$FK0W8M;.WUB?4[+4(
M4L8[>"YM[=?(K\4/B[\!/@EX7^$>C?#?;XNU+X3:-JGQ-M_VJ_BAX6FOK&S\
M.>"O@_X<T3XV>)O!?CU?#%W:Z1JOB'5_`>G:!\*/V=O!?C^X\0_#[1/$/CZY
M\2Z!%I%Y<VFWY3A'BS+>(,4LKQ.3SP..PN,4ZF%HQG"%.G[U/FE2E)I2G>,$
MHN%W%QBG*=CW<TRJI@LJECJM>EBXT$YJNE[2IMS*7/;F=[:VYGS-.^FOT#J/
M_!.S1?B1J%]\1+?]J[X3ZC;^/;RZ\:0:A>?L<W6O7=]#XIG?7(KRZUQ;:)=:
MN;I+Y9Y]66*-=1E=KP1H)@H*]ZF\)_\`!1.TFEM+G_@HG^S]\'KFUEDM[CX2
M:!\)O#^M:%\+9X6,<OPYT36)?AY/+JVD>")%;PSINI2S327]GID-T\LC2ER5
M^RI96DE]2K::;3Z6\_+\7Y6_)'Q')MM8JO9NZLZ5K7C_`-.GIIW?7>VOZ4^&
MENAK-M'()KN2.ZM]"OHX(!>Q6MS<7%HE]/\`9A;SV]E';VDM]IMY<,\MA=-J
M7VJZ-S#:Z_)<_P`_OP'O_AQ\*?V1/`C?%WQ%H7ASP1\'?'?QZ^%M]K&NBU_L
M_P`+7/@;X_?$JV_M+P^M[`94\82Z3KGAG0+.]T?0[L6]E!:QZ3)':I`!^:+?
M\%#/V[_B`?#MYJG[1/B'P]=^%X?[#T&3P+X/\$>$]-&K6`EU6\U77$\-:5J%
MIKEQJ&E^)-/TV;P_K.@MX;M3;:A;V'AS38[_`%&VF@^!7[1?BB_\80?LY?&'
M^P/BQX5_:V_:?\!^(]5N]<ET[P;!X.U3XF?$O0]-^)?B&/P5HL?PSM=6UCQ+
MJ5]X9A26RGTKPUI/B.WO+RQT1;&PUZVN_&GPY0I8.MA:5>=?V<Z6)AAZ5249
M.%)2E4C23AI)QERIV;;348SND_Z*P?AIQ7PC&6:9AA\)/+N25*K*I2A4@XJ_
M+*47%\R5V[VTN[M;GR1\2_\`@IG^V?\`#/XL_'NW\!^/]:^(7P)M/B!XGT"3
MP7^T5X=3]HKX;:=I<=YJUMH%CK-K\5U\9R37]Q:WLT%A;ZDWAY8VO)X&T?2?
M-FT^";X-_&/XW?MY_'#X?_LRO\&?V-/AO<?%34DN?&'B'PI^Q+^S-\(->T/X
M=:%I1\8?$;5M-\8Z7X4F\8VGBF\\+^"M6U&#6]*\4^![Z^'AS5+#0;V_.L^'
M(X_Z>5_9-^`6NZIXA^)^O^$-`TG7M=T&![_7/M&G:%HTFF:-:PKI&MZY:>.+
MR;X<67BNQTDV5QJWC;4O#_B'PEK$ECXDN+.>UUM-+T[4/BW1?VS?^">WPR^.
M/QEUCP3:Z]\3?&UI\))=,OOBK_9NOZ_K/Q`OI]6(TCP1\)OAOJ&B^$]!T^PL
M6TCQM/XA^(D?A_X/:/=PQ:;!J/B/6O"&MP:KK/U7#/BQE&;9;C\IR/@:>&S#
M+L''#ULPKX*G&-:K*<:"E[?V<6Y\_-.3<FY\RYVTW(_%.*.!\/@\U_M;$\15
M,*ZF(>(CA<+"I5@X2Y9<GLH)Q4(IKELN5R4H-W34?T@_8QUF5?V,_P!GRV\>
M^+-:E_X1[POXT\.Z3XMUG3LZWJW@_P`"?&+Q[I/P^2XT1/"EKJ]EKNB_#3P[
MIJ7+/86>A:SIWA[68[O66U&%_%5YR'[#/P$\!_M":;\=OCAJ=CX^\0_"?Q_\
M?=?T+X7:)J'C;Q3'X/\`C'X5\+3P:EKGC+QK\._`>LZ_X0^*OA;QW\3GDT+1
M_#?C'0O$NCR^!O"N@S>+O#NC2V"0VGXU^+O'OQR^)'A?4+"\^$GA_P"'7P5\
M.?#/Q'\/OV?_`("^*?$OC2+5=.^$-UX3^&-OXAT'49M*CTJX\0?$#XL_!CQQ
MX0\<:#XUC^):P>(_A'X9\=:3\/;SPOKVK^(_%UAUUO\`\%)?V\=5\#>$?#7@
MGQ;\.?V;_!WA2#Q9:>%['P1X`^%7C3Q4FC:AX@\:^)O"/@Z35=0\(:E\-_!?
MA;PA\-KS2?#.@^(/#FAV_B*_'A2TOM2US4]6U34K^^^=P'`N5Y=CL=Q%C:]'
M#9MFKC3G2ART_803=9.E&G-KFDI<E1QYN645'VDDW)_;9+PQQ?QM@J.5\+.M
MCL+/7%3Q.$G1ITZ+LZ=3GE!\R]IM'I'X5&*BE_8%%=ZS/%'-!<Z%<02QI+#<
M->Z1>M/%(H>.9KV31=2DNVE0AS=/J-^]P6\UKVZ9S/(5_)+9_P#!2K]MW[):
M_P!D_M&ZU<:5]F@_LRX7P!\-HEGT_P`I?L4RQZ5\((=+C$MMY3A--ABL$#;;
M.-+<1J"N_P#L]?\`0SQ?_@Z7]W_IYYK^F[>W_P`2S<:]</@[^FO3_ISZ?AVU
M_)+PE!!]CU!/)BV'6&N"GEIM,\MP!).5Q@S2!$#R8WN%4,QVC'H?P]5;CPY\
M?]2N%6?4?#OPE_:CU?P_?S`2WNA:KX.^$W]L>$=3T>Z<-/IFH>%=6N;G5/#E
M[9207.AZC<3WNF2VMS+)*Q17H8#_`)&?_<*7_I2/ZS\3?^2"J?XW_P"FS['_
M`&O_`(D_$75?V%/V18=4\?>-=2B^)/Q0_9PN_B+%?^*M=O(_'UWJ7PS\?Z]J
M-SXU2XOY%\57%_KGAWP_K-[-KHOY+K5M#T?49VDO-,LIH/M?0_#7ASPG#/JG
MA;0-$\-:E<V?[<^G7&H^']*L=&OI]/T3_@IU^Q#I>BV,UWIT%M<2V>D:9KVN
MZ=I=L\C06%AK6K6EHD5OJ-Y',45IPO\`PZ?_`&'XG_TF1_%4?][Q'_7G#?\`
MJ6C^>CX5>(=?\2^+#=^(]<UCQ!=Z%H_PAFT2ZUO4[W5;C1IM+^&>B>%M,FTJ
M:_GGDT^73O#'AKP[X<L)+1H7L]!T#1=(MS'I^E6-O!]*?&Z62+PSX@\N1X]_
MPFU2Z?8[)ONH_C#H=BERVTC=<)93SV:3',BVLTMN&$,CH2BN7BS_`)&^']:1
M_>?@;_R3?_<*'Y1/'#I.E,2S:9I[,Q)9C96Q)).223'DDGDD\DT445Q+I\O_
M`'&?JDMWZO\`,__9````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+W)E9&-R96%T=7)E+F=I9@``````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,T,C4`,3`U,34T,S$P-C<`,#(T,30Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y84$`0@#W````
M`````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`
M9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`
M_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S
M,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\S
MS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F
M`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]F
MF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F
M_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^9
M9@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9
MS)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,
M,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,
MF9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____
M``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_
M9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/__
M_P#__S/__V;__YG__\S____XOR0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```A^00!``#8`"P`````00!"```(_@"Q"1Q(L*#!@P@3*ES(L*'#APJM0&'!
M8@7$BQ@3/MFX,:/'CY@NS>$(Y:/)AYTNB9R#[<G)EPMWI9PSAXY+F#@-[@HV
M$PJ=G$`'[MJE<@Z4)R6#`J5#A^8</4JQ,55*<T]0*)=^!J4)%:<5.KLP:07J
M=.$**U:N"+HR,&T@07N^7AI*-&K9A"N@Y`&4[!F4%2OTZ"GU[)FG2YB&7O(4
M%=M=@WE7<"P5:*,*R7F>J:2+V*I2%C016J&X0H6*)Z2>E`;\!!"R2\$4,VX,
MQ2A"BD](D%!A135@P'J0=0H6>]?LJ*!O8H/"',H5%JI)E.;X>\4>4IT.$QT;
M-/E&R16I_O^6_MW)$Z=%-Q\?N((%G:R>,R+E^)UU[_H<T:N\-',QP;RU;7:)
M27LX1=]&:/E&'TT"=C*<@X`0!,4>3<WA26S<8>34'))QA%9O'>I'5##")),,
M*35UM9PG>C`X%R8$CC229!TJF-\<^ZDD#"FE>-))370PUQ0@Y\V1W25)M95D
M0T>)IX(3+#!W7I$Y*J92'AR91Y--5`XHT(3,[1*?0U.J=II@+1;IHDHIB:0'
M1P``4..!`JT`ED@JT3'F0M"19,4G%-*D)H[[S9%':O?%*>=E'29I)U%S)&;<
M0Z/19T4@GS1YHXND\,C:$XK&22,+_Q6ZV2X9+B31>8+MH>F!_JAU*MBGH0)P
M6Z$X#J4B1-^E=<45$MT'V&6F!2`=8+4"$`!!`4A695$>^>8%7('$M8)N*AQ;
MG6^_*;JL0.$1FF-H&57$0A=K`5O:;M<R.AVWR"I+$'2Y[C=4J@\!9D47@8PV
M[&K3"9;EIRO8^M\3]LXUU'H72=:%NM7]]H0>G7IBY(^JP5G0"G/!IK!*#$/4
M'F`R!!+(%5WH8<6&.1:UD8'5!8"PPG0M_%%D)`/;6Y,;XBCHRXO]QBC"BG'F
MI4=22@SKTH)R^803$=?+&:HG-;<T=0L*.M)IDK%WGH`=X]LP?1'/^;*!]&W,
M8-$POC1RV9]NVK-M!'U-:"=BX?3V];:;JGE)'H_->U1-$P)54=E]%X4>2XWA
M!?>!(_WX,^.-.QZQW/D567E$ARM]WDP9;[BY0E`DF+6!#&XY>D3WJ>:$UD[E
MX0E'JR>$5A6XGZT[3>9943MDO^F!>Q68.[7D[W4"=GCNF3_M!(M[(O_71M,S
M[Y033U*._+P=U?F$]><1K_WV`FU$ZL9R5T%^0><=CPV-*Z2^/EI[U/]>R-BT
MKOKV5AP6TIV>P!]S).*^RJ%%2`G+T_H0(B6YM4QLVWO5Z00$P=_UZ6KH"0O^
MI'<UR.6I@J/3E-D@1Z@%'B0\'?2)"4^(0OHP9X4*T1=27@C#&MKP(P$!`#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]S;VYI8RYG:68`````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,38V`#$P-3$U-#,Q,#8W`#`R,C<U,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$?`"``]P`````````S
M``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,
M`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S
M`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,
M,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS
M,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,
M9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS
M9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,
M9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68S
MF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,
MF<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,S
MS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,
MS)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S
M_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,
M_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S
M__]F__^9___,____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+```
M```?`"````C^``$('$BPH,&#!"\`$%"P0`$!$",*<.@0HD!D&)$)O%!&8,2%
M$D-&?&@1`$:!93J2%"FQ`,&5)3>J'#A1I$L`.W8(A%E2(0"7.G_:Q'GM6E">
M&W\"U<GSYHZB1H5*3.KTVLZ61*$FVKF2:E:K,($6!5!T:\6>/P$D@NIQH5BK
M`J^9[0I`X<VU--.2'1MW[D<`*AGB'0@7*ERR?M$^5'O8L&'"B1G6W<G8JF/'
MB*_^O6!7\.7/<I5.K>OS)M^"CN<:5.A!:%R3&37N+4LPF.VDK0O&SA@WM$#;
MP4X*-+!7]V[9`X_+-D#\8'#ENP\:R&WP.73>&I&W]EG[NG+8`SE<<P0`W/MW
MX<0Y=B1O_OC%Y<U3_K9^G2!O`-,]M)8_OWW&VP!0QQEX\]&'$7#`%23>104.
MA""`!4FVX$F[)1@A><%-MI%"%$*'H$<,/:<AA]GY=YM%(B*DXHH%!00`.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)U;FYY+F=I
M9@``````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-C,`,3`U,34T,S$P-C<`
M,#(R-S8U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`
M,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`
MS```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S
M`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\S
MF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S
M_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F
M9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9F
MS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9
M,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9
MF9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,
M``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,
M9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,
M_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_
M,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__
MS`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````A^00!``#8`"P`````(``@```(_@"Q"1Q(
ML*#!@P@3%B3!L*'"AP(9KK`2J&(@*R0@(F1(\:*5CR`S:B1(`J1)DRN0:&S(
M\:3%ERM$'I38L>+'EZQRZF15<<7,FCLK[KQ&M"A15A@7"M5Y-*?1ISH#^22I
M)Q"K:ZQ6K&!E[>72H#T7>DIVE:=6*SRE`B"QPJM4A@8!?"([].A%`!%9RHS[
MJ92U:]:<VI4Z<B")/5>Q"N:9=J_&MG5S6DT;LS"VMI-U"DJ<UDI,QPG9>DT\
MV&9EB$@P"S8J^25H@R2$/C4:..C4C11)SP[\U6QHV;MW\A0$3?)K;+&M!E\M
MG/!/Y5!U%XV:]*#JI]!GM[Y=$,#UHMEG46.]>/P[T<WBI_<\GKLH;^GJ,W,?
MF+NKT,G3.6=GY;ACVK06.<7**G\Q-AU>]"EG8'KC_3?=7I#]EYEPK5VT54[S
M`:#AAAQVZ"$`2)"PED`!`0`[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O=V]M86XN:G!G````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-S,V-P`Q,#4Q-30S,3`V-P`P,C,P,#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#\2_\`@K/_`,%;OC?_`,%/_C2FN2W'B7X=
M_`WPD=0T'X1?!G0M9NE^Q:3JDC&[UKQO_9-[#IOB?XC^*6CAT_Q!=6D]WH=K
M#':Z?H'G:3>7ER/M+X+?LV_L1_L6_#+X,:M\7OA=X9_;9^/7Q-MM`^)?C*QU
M:U\06WPH^#'@*!=1\7>)_A3X<\,PSZ!%XA^(&G1^$O&.B>/-?U]8=.E\0)'8
M:)IUG/!+<C^:V:ZO+&2UNK%)K2:WEBN[:Z5IXO(N8'66&9989;>5&BE5'#17
M$$BE=T<T38=?Z2/^"4_[%'Q@_P""RGC7QB;OXY7WP5\/?`G0Y_%\_B'3K"#Q
MSJFI?$'Q-JT-E:Z%XBT'5M3TJVET?7+:PU>XU+47U*Z;6],AUB_\I=9<1D`^
M[_A-_P`%AO"WPHM;#P-^S1^SA^S[^S[\/K"Y\*:QK=A\/_AKI*^*-,\*_P#"
M,W>L>-K9=8NK0WEUXB\4ZZ-/O;53K-W_`&5&\$#J$N%#W-$_X*Q>,?VC/`U]
M;_&_X:_!/XPQ^(?$[:IJ'A3XB?#CP1XRLM$\$P-9W=EIFKZMXCT^*6"XN%TN
M.YU+69;ZWN-9U87D+^3HUG=W$?Z:?LL?\$(OV6?V<?AZVF?&V%?CE\:=0_X3
M?1O%VKQ:GJ6C?#./PSK.H7-E8>&_#_AR>'4M3$.DZ')!>V][+=PZGIFIQAM)
MD?RH:],_;)_X)>?!WXD?`;Q!%^SOX'\'_#C]H+PG-;>,_!FL:5X:MM0TKQ=J
M?A_1SX=31_%6@-*EOJ%C>^'PEI;CB[34+2&\>!IK]=X!^,/_``48_P""/7P!
M_:+_`&%]9_X*&?L._#;P1\'OBAX!L=9\9_%7]G7X0^)I_&OPY\5>$_"["X\8
MSZ#H<UA*?!WQ%\&:`[^(;S3?#\TUGJ4=BNG66)I(0_\`'I826ES#!/`J,DT*
M3"2-Q*I5D+JPV%@RLGS+MSO4<9YQ_?\`_P#!&K]H#QC9?'>T^`OQGL_#FG>%
M/%UIJVB^'[WPWJEOJOP]\0ZKHMK=Z?=^"]4\+:DWVCP_>S:8\^Q9(GM9(+:Z
MT>^+W15!_&#^WC^S)XM_9%_:O^)G@'7_``S_`,(SX%\>:WKGQ5^!TJL]S9ZK
M\%_&'C#Q/=^![FQO%46MQ/:"TDT+54M'ECTRZ$=C<&.8"(`'R(;JR!(,\&02
M#E&SQZ\45EO`2[GRWY9CQ&Q')/0[3QZ<FB@#`#;#_I#!X'PH#.KJH/=DD2:-
MEQU5XI48<-'(I*'^IG_@@E_P4*\+?\$Z?@W\2O%L'@&[^)=Q\8/CYX>\'?%6
M"/PEXWM]6\&>%=`\,M'X`CTKXHV=IJ'P^NM=U*UO_%&LP^`6-AKNMR6<L5G!
MYL;2Q?RS-A(&0/PB,3(I;S(P!]]?+#2!E'S*45F!`*@G%?W)?\&LVA?L^^/_
M`-C[]M/PO\3_`(?Z'\2/%?PL^,.D?&NX\*7FE)K'B&X\.S_#.31_#^H:'HEZ
MOEF]L;_PMK]GI>J6JR7::I"K6R/=7'E.`?JG_P`%'OVE?B=%^SE\%?B?^R+J
M?B/Q+X/^-$]WXA\0>)_`-M9:-XY_X0#1[:YN7TZ#Q)XO:VL_A1+'XFM-0TCQ
MMX@O7ANM$U'0K.VC:*_O(8)/$O\`@C1\?_VHOVF_$'[12>(Y_'5A\,?"7@WP
MO=_!_P`5_%OQ;=>.I=)^)/B&368=(TBUU^X\,Z+K/B(:!IEFEQXVMIKW4(=%
MNYK1$1VGMED_5GX%?M"_LJ_%IXOA/^S=IEQKGPQ^%_PVTF^L?$<?@C6-+\)>
M'G\2W][;O\/+VU\;:=9ZE=>,+IC%KWBBU>+R+BYO(]5U807K6J3_`%?X>CM]
M):WL=/M].2P:2(V>G:386UK9S'>L$$D6E:?:P6[3O;N\L4T+3-M5I4WJI8`'
M\`?A7Q_\<_AE\7?CIJWQ4TW6O`?C+1_CKXQT7672&707L/'>DZOJ]OXS\<_#
M^>&..\D\&C6A>7&ER+%]CN(M=M[596*(I^F?^"P'P]L/VN/^"5WP[_:RMD.L
M_%+]D'XL^&=&U?5K*UMIWLO@;\<+6/PUJ6C:A=[1<3Z5X=^*NB6.HZ3>/^YM
M+'6=1N(7&68\'_P6:_;Q\%_M$?\`!2D_L_\`PATE)E_9Q\*^(_@YXBUJ/^SE
MTSQO\3XO%5AXS\8:#9G325GT^UA^T:9IVI7327EOX@1X;QPT<J5]:?LC?#[6
M/C_^SU^U9^S#X4MKWQ7X'_:/_8\^*UGH4DEPJSZ)XCT?1I?%WP^U/4+)]Y&O
M0^*?#RZ'<:<B+J%F+NZD6)9@10!_$EBX7Y6$89>&!D((8<$$9&"#D$8X-%58
MM>T^UBCM=5MEM=4MHT@U*UGD6*>VU"%1'>031RE9(Y8;A9(Y$D571U97`8$4
M4`<^[7$BDQ*,*"4,8!8L.5W8SP3CDC'/:OZ%_P#@VW_:+\6_L_?\%%?#]C;Z
MP-$\&_'CP+K_`.SKJ5_K!DE\)6GQ3\7Z-_PD_P`"AK1CN;**<WOC7PV]E&JW
MMO>OIVOW[6;[G9J_G]A)@A8,/,E,KVD-LR2K)<WR`*-/1(5:X>[>0K#]GMT>
MZW.JQQF1D4_M1X]^`&O?"3X0?L]_`ZU:+X6?$GPWX63X\^+?B'HOVA?%FL?M
M#Z_?Z7XI\(:;+<Z?)$UG=^&O!EYX.T#1/#UK<10^&[ZSU35('74'F0`']:7[
M'7Q(_P""CW_#3,?PZ^,?B_P_XR\,:GJOBB3XG>'_`!=^SUXS^'47@2;PY=:K
M:R^)O!WCU/"GAKPY]D\1?:[FU\*:/<W.N:9KLEQ;1W>K>1;RS+[;_P`%*/\`
M@IYX3_8VTFV^"WPJO;#XE?MJ_&:UN-)^#GP:T"[AO;SP5>:RLFG1_%CXL;'E
M7PAX8\'&0:E:V=S';?VL+*:ULVDD)`_"7P]_P49_X+/_`+1/[.WQ=\!-\:_A
M7H>J?LX^(?A5\.O%GQ<\.S6?@GX\>/\`PS\79+'3_`/C30DM8M3AO]7U*WCN
M-1\0:YH$?A>[LA`@AN9]0E20_G;^Q?X$^'^@_&'Q#IWQ6^(OB?0?$?B6_N=3
MUCXC:3XF'A[QGXB\5F\+W,FL^*3HVM>)KZ::\M;V9$;5X5D,^Y8@&!H`_.OX
M1:+XCT7]H'Q_)J.J-K/B_P`+^+O&]CXF\8:K<J-8U#XA^']?BU:;Q)?I=-]I
M>#7=1_M2W$CC%Y'K,%K&SM$BU_1W_P`$V?VC/#?P=_:ET#QE9ZAJ6B_#S5_B
ME9O?Z;>W*WVF^'[?Q]/833P@0N%L=#U?48_%&HVGVHQVMM<00Z<C!Y/+K\O/
M^"B'[//@?]CC]KJ#Q-\$;*[UG]GW]I?PIX6\:?"3Q?8^([CQ9;WGC>SM],TW
MXW>$?$GBZ82"V\3Z#XYL]7\1>);>\>.\:_GTJX$$5DP+?=__``3N_8P^,/[3
M7C34K'P%=:)X.^&OA2V-A\</CAXB>XU7X>:'X<7R-;\-Z!X*MM,D1?&WQE\&
MZIIL]RGA:UU"/P]HL-M;W^J7MI!J,CT`?/7[3W_!MM^U]XD_:5_:&\1>!+.)
M?`^O?'+XM:UX-6VTV\-NOA35/'WB"^\.B#RH#&81I$]F(O+)39MV$KBBOZ[]
M.^/7[./A#3[#PEJ7_!87XL)J/A>RM?#M^EW\3_V1+6Z2]T2"/3;I;FUO?A'?
M7EM<+/;2":WN[V\N89`T<]U<2J\SE`'\CO\`P:^_#WP#\0?VIOVM[CQ[X'\'
M^-[CP/\``36=3\%3^+_#.B^)9O!^I6_AV.[@U#PO+K-E>OX?OH+N-+J&[TEK
M2>.X1)DD610P]X^.UK;7'[87P(CN+>"=+WXM_'"YO$FBCE2[N--\+,=.N+E7
M5A/-8&W@-E+*'DM3!"8&C\I-I10!Y?\`LZLR_$W_`(*:HK,J6-G^S#;6*J2%
ML[>P\11W-C;VJ@@6\-E<113VD4(2.VFC26%4=%8?`/QU9K#XM?$%[!C9/)X_
M\;^8]H3;._\`9NJ%=.WM#L+?8%9ELMQ/V4,P@\L$Y**`/Z&OAIX5\+^)_P!F
M+]E3P!XE\-Z#XA\":A^T_P#LMZ;?^"M<T?3]6\)7NG:SK'B>XUBPN_#=_;W&
MC7-EJMQ##/J5K-9/!?311RW4<KHK#]H?^"UCO\*OV&/CAHGPO=OAOHNE?!#Q
MI?:7I'@)CX/TO3;U'MHTO+#3_#QTZTL[I(Y98TN+>&.94DD0.%=@2B@#H?V3
M/V5/V7M7_96_9GU;5OV;O@)JFJZI^S]\&M1U+4]1^#WP\O=0U'4+WX<^&[F\
MOKZ\N?#LMS=WEW<RR7%U<W$DD\\\CRRN\CLQ***`/__9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9G)E9&9L:6YS=&]N
M92YG:68````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,T,``Q,#4Q-30S,3`V-P`P,C0T
M-S$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`S
MS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,
M,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`
MS#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9
M,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_
MS#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F
M,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,
MS&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS
M,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9
MS)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`
M,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QF
MS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_
M,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\S
MS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,
M,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"'Y!`$``-@`+``````@`"````C^`+$)'#B0!!(`
M``@B7+B0H,.'V`X"0(*-H<6)$"%>W'@QXT".("UZ#$FRH<:0*TB1`J""U"I2
M*@#D04CB)$=2SW*F7)5S9<R1$S?RS/F,U(J41P'5]%@Q*,.A.@.Q6B%U!5.!
M!A'JB;F"Z+-5)%9,%;OT:L45I8SB)+IJA96I;\M>);'6ZS,]1EE-+;6"A%^S
M+9_8+8KW**DGI5:]E/N0!*`G==DFALJ6L4,`.^T:/3KXJV6"+3GW-*QV,*G/
M6'&J[`G995'(BA7#9$J"\F&5HHV24*'B*$6/M;VFU%W7:!Y2:570AMKV=DJO
MMWLJSQ@\9UN>8%M"AYQ3Z<.%==N^$EV!<*=LP<]*,08``<*!YU^[]K3H%S[8
MRQ`L6'"/MOGXBZYYYA`2)1P`P0470#"<?$6IP`8;"XFFGD,D=-+)"@=>8,$!
M!P!07%]AX=9=``D59.$E&"*8X'N1*6976PE`4&*%G?`VQPH&JLA?9'8!8J",
M6-6HTA.77)@A@OR5,A@@*\08@(DJ\'28A0'DB*2"=97"Y``0/`GE4%.J<&.&
M'#[`(HX!<-DA015&291:*EQ2I04KROBC@0=<LE1````[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]P86EN=&EN9V)I<F0N9VEF````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,C,S`#$P-3$U-#,Q,#8W`#`R-#,P,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$E`"4`]P`````````S``!F
M``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_
M`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F
M`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_
M,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF
M,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_
M9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF
M9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__
MF0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69F
MF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_
MF?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-F
MS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_
MS,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F
M_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;_
M_YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F
M__^9___,____^+\D````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(?D$`0``
MV``L`````"4`)0``"/X`L0D<2+"@0``&$RI<>!"`PX<0&4IL""#0BA40,SJ4
MJ"HA1(P:0S+L:/!C2)$+\9`L>+*E1"<J5Q($0`V`LYLX;=:<B,T)3#PL:3JS
MZ<R8T:'.=D[$\S,HM9S`HAJ[J70BPI)";P*("HQHTHT+,SJ%ZA#GUZL*Q<[,
M.K2KU[,,:0(X=@PL-H=/M;ZE:M?C4+K4:B+$:[:PUL!H2_X]1E4PV\(ZY]:-
M*]ELW<<XZ_)56Y*N9<*&-3<&8,8,GL0#'S*^>3EO8=%)$9<^C3HU7;J@7Y?%
MB1B/[],>;[<V[.RRV=Z_:U.$N/KSWIJU:OE6'CPT@-/'`42?SO-N\\S7+WED
MW,Z]^US=>"ZHO_";]ESJG:VW=W\;?O#OQ3/6[\NSLG/5N/'7GV3"%7A9=V&U
M)&!"K#3(BD$..A2A@PY.1.&%%$K8(``8-LA0AQFRHJ&(('K(8(D;CL@ABB>B
M^-"$++:(848IKMBA1"7:R.&.-IJ(8(@7]EAA00$!`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)E<G0N:G!G````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<W,#(`,3`U,34T,S$P-C<`,#(R
M-C`U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$
M`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%
M!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()
M"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!
M`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!
M`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:
M)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#
MA(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3
MU-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_B:_9M^&
MM_\`%SXK>!_`5C$;FX\0:[:0%1OF:*SDFCBE9H[1C<Q-%Y"OY4B1LT,:/&LS
M&%7_`-"KX5?#/PQ\,_`'@CP;IEE8V7_"*>&K&S@DCC;RP\,"F[O$%S#;[C]M
MD>[E8P0RPS3AI%A-P1)_(]_P0M^&6E>+OVC[SQ-K5HMW!X.TB35K;[7`SV-O
M/,XM/MA-R9;2)TEBBBMITBBE^V21I'=?:H(%7^EW]JG]NSX3?LD:=I-_\0+3
M4Y;SQ%+<O8Z5ID4,U_.D%K`\=Q=;9`EOE2L4GFNYB2-.6,,\5O\`Q/\`28QN
M8\0\6Y-P3DV&Q./KX>C/'SP&$]ZI6Q5:$G!*FYWE&CAX3J3;O&$JDG!J]C^@
M/#_"/#995S&I4I48UG*+JUI*G&%.'N-U*LVHQC-KDC%NTN5*\G)-_:>ZS,K7
M'D!YHR^9TM3<29A-U"P66".;<ZK'<(8E=IH_,$,D:2SI$]22\B@-\)&M[<11
MAUQ>N$E7[1,K':(`MO*[RQI/(B&3SKE$ED5$MYV_`[Q?_P`%SOA#;&;_`(1K
MP7J^KS6DTB6TM\J6?EW7G.ZSNDDB".*1@+A;:4>:7@B>6(/#$L/S-XR_X+4?
M%KQO+)IOPO\`A1':WEVHV/J;W.K/:N[+$I2.V@M46:47*%;B5/DEBG)V[C':
M_B&"\&?$C')-<.5,OI.SG6S/&X7"4Z*NI7G&=?VJ@ES2D_9.3<;64DG+[=YI
MDM*:C4S?#5JE^2-/#*KBJTI1E!<L(8>G5O-MI1T]G;FU;2/UR_X*(?!GP;\8
M?V<_B%/%'IVGZ]::6^JV=[=P6]NTUUI5S(]J=D=O]IN[J6(>59M`K.KQPI.[
M/%*\'\1/BF%K2-H9AY<T<]Y&=KM%(K$Q*\[LZS!&A16B<JQ,<:1RP*X3[,O[
M=+X9_P""H/[=7AE];TOPSXL?X;75[/:/,A30M"W:7;BYN;:Z:Y>+S0AD:9(Y
M;=)IKJ:WAB5]UD@_'+XO>&=4\&>(M>\(:RES#JGA_5[W2]4!C:&2*^L93%<A
MP?.DCF1C.R>69=\L;($D+BXC_KCP5X5S3@G*9Y)F^:X'&XFOBUF%+!Y?4G6C
M@J4_9X>LG5DE?GJPC&2A34(^SE[-<W/*7YYQGF&%S51Q."AB'2PT/JDJ^+@J
M<IM-U(4E#F=11I\LN1UI<UW);*T?+(1+Y46%*#RTPGR1;!M&%\LQR&/:.-AD
M<IC:78C<2EC$CQH^5.Y%;(:/!W*#D8CF&#GC$TH])9/O$K]FE/#\SO"G>[O^
M[J/6^NOUR-]>MEZ+8^$C&K96E72LK6E%*UM+?N'IVU?JS^NC_@E/^PE\0/V/
M;7Q7XJ^)OB+P9JE]XRT727LM)\._8=2O='N98A/<6-Y?(9KL7EFDXCGDN5L$
M8^;;0-*R1S6?W'\>OV:/AG^T-IUA8?$'1H=5&F3--8R2Q1M+;EE?S$2<LDZ1
M2-Y;&-9-@>-"H3_61^2?"?\`:<^%7B=_A]I^B^,]"U+Q5XOT1M4N-!LK\7%V
M(Q%#*\L\<=P8[:>V\JXW1SV]K*\,ZQF)5\RXK[5MM026-)55"QWQSI*540D$
MP3,=Q9"8I&Q&5=MS`-&S%21_F-QSQ9QAFG%T^)<Z]ODV?-\E&KA,/7RR5&%"
M53"QEAO>=1PO3JQ=6,I>TG[9MN[2_IW*<BPF18"EA<NJPQV"E!1_>>SQ$)IK
MVCA5C/FA)3YE.*GHZ<J2M%62\Q^!O_!-#]B?X+_"WQ1\:O'7PBTGQ[?:%HFM
M>*[ZUFT_^TQING>'8;C59+7P_I2?9P]_-#;HZPRWMX'F6*%)8-\UM#\[>'?#
M_P"R9^U'\*/$OQW_`&?O@E-\#-;\-^++GP3K-CJVE)ID.J0"UFN)+^PMD@3R
M;AUM(H+N>"&&17NXGVWMY;"*OO71OB'X_P#!]MJ4/AN]T^_T&[@F2Y\/:[:2
M7VG.CI/'>2VH@GA*S7@.V0$3/.L8$C*)OF^:_B%\0]6U*YD\'Q:3X3\+>&;1
M[G5TTCPU!;:6PEN98[>XDNHK*9X8WM;=T6:^MK6.ZDG0"XU.VMKJ33;?]BQ_
MB_PYF/AK1R6H\?BN(WE2PM=UW5JU99C&U\PEC:TXWHRK*G7]A"<HN-Z#HRI<
MTEX7#G!.?+CAYSA\5A:6%AB_K;=&4:2A@VTZF"^HPIJ#;C-TH4W'V*Y7.4H+
ME3[2VU?X\^"=;_9;MOA#XH\-^$O@)X5\(K;?%[PS/?6-OK6J>)KM;B"0RQ1B
M1KUM2E,8L9+64^5=2/*ES+<"SND_C(_;_P!3;4?VF?C->3:>=(<^/-:+6L0<
M+$SO+=":8Q1/%"["0OLF@EE4NL0RZ2F3^LNW\8"*\L]/FNBT-I>1*;6YN+D1
M/<,S_)-I[2B2YAD5V82NBV;O<6YMA<2NCVG\FG[?31']I3XLRPRSR12^+;P[
MYS'`7>:0NTS"UMHXH[F0.1&R^0&F&Z""$3.D/W_@?Q_CN,N(*V&QF7X?!1RS
M(<+&/U=U5[>I/%X>A.K:2Y80J1@O<CS2BV^1S<7)^-XD<&1X5RE5E4G5EF.8
MUZSJUJ<5/DY:E>G"4W)NI*FJF\FFW*]1WE<^,DVA$#K!O"J&WR#?N``;?GSC
MNSG=F:4YSF1_O$IJW$6U<;F&T895C*D8ZJ02"#U!!(QT-%?TU*A2YGS5Y*5W
MS+V571WU7Q/9Z;OU9^**MHK*G:RM=TV[6Z^ZM3[G_P""97P_^*OB[]I_P/KG
M@Z#6%MO"/VO6K^^62Y@A2QBLY;D6XD;:L\-V8UB-LK,)A.=L;(\[K_4-HO[5
M?A+P]?KH'C.]B\*ZMI\D=C+9ZW/IUA&-UL]Q--$KR1%I9A"(DF3[4L+I);S.
M\LDCCY$_9>\`:Q^S1\&_`,7A"VT>W\<:O+I&LZ_<^?"FIR-?RQ1'3[F.4/)-
M;M!=M')!=W`@ME>&XE:_7[-(GW;\>/#7P^;56\'_`+0?PST_4+'5-.CU6#5=
M.@ACO=.75T>7$6H;8FA:PENAY\3B1HH4CEG=;R>`R?RAXZX7`\6YI2XB>68R
MIDN75*N04L3ED**Q5J-1XEXU1K1A2Q-*4J\VJ3<>6-IJHU)J?[YX95*>3X">
M1XU4<7CLPC#-5@YXGDKT74A"C[&BFG%U(PI1C5IVE*;E:*@^23UH_P!J#X4S
MV<DC>+O#QAN#@2#5+2WDCF(3S08WC"M):O+!([,7\V%1.T21S*B_`7CS]I'P
MSJ?CG59-"U?1M0,&U08I!+YCK;6URMQ-+/#BXBF,MN&M5(=-ADDDBD3;3?$7
M_!/#]GKQCYMS\+OC/9Z,RS&270O$-\TB@!I%4R2_:K>>S%OY-T5GNK98\21,
M([>U>:XMOFGQC_P3@\=>"[36]8TWXK^`[ZSTZU^V$QWUXEV+)XA=`RI`'D/E
MQ*%>0Q3K++]H5(DN;?RA^4\/<-^&<*E6=;BG&PJU(1HQPN9994P;C.I.FU";
MINO&H[V5J<HQN[\TH\T5^UY;F>'R7&T,11R6KC77?LZF`=3%PQ=)M*%^2KEV
M'I<U1M*$Z5:6LH\R3:3]+F^+OB7Q'K=II&C7$TMQ=-;64<%KY0L7CEGCCD$<
M4F^W$NQUF#N!$S*(%1+J>?[1^('[9L,EC\?OB5!'JAU2(^)+A9;P%P&95246
M[R-&KNT"S.BH9&$L\<I,<,B/<']TO@5\&O$G@SX5_%+7_AI!%XQ^)6B>#]5U
MB3Q+KLZV^F>$[NRM)5U`:9!<VJWL,D5M$[(TI%RL\ML+9!<>3.G\\-EX=\1_
M%#Q#K>LZYJC&ZDO+U]2OKQS<7-W=W%W<33E-R0L09Y=QE",A(D#,A,*+_1_@
MIP_1_MC.<?E&'A3RO"PHY70KSH2I5LQKQJTL56Q;A*'M882C*"HT).<95*LZ
M[J0:4#\S^D-QCA,QPN19$LMCEF+PGUC&8JA&I2G+#/$QITH8:I[%N#K4X4KS
MC-^T@G:*BDW/Q@;V`)"`D9(=H"PSSAB&(+#N03DY.317U_'\%_`MO'';F#69
MC`BPF9=:`64Q*$\Q0MF%"OMW`*`,'@`45_2CR;,K^[*LH_92@TE'HDE6M:VU
MM.Q_*2JTK*\&W;5\RU?5_P`,_<?XE:CJ%MXYOVMKZ\MS9^*O"\-H8+J>(VL)
MM[%S%;F-U,$9?YBD6U2WS8SS7[:_M)(FI?"#X.:OJ*K?ZK>>%;`7FIWJBZU"
MZ`T&VG`N;V<27,X$ZK,/-E;$H$GWP#117\QS_P"3<TO^O66_^FH'[5BO^3C5
M/5_^J[#'X,_%NYN-#\3Q1Z)<3:/&]AIRNFE2R:>CK#J&EPPJRVC0AEBAN[J*
M,$$)'<W"*`LT@;@EUG6!J#D:KJ0-K#-]E(OKH&V\Y[^2;R,2_N?-=W>7R]OF
M.S,V2Q)**_),T_WA_P"&?Y5#^H\A_P"1;C_^P.I_ZKIGZY_"?2],@_X)L?M)
M:C!IUC#J#_!N]O7OHK2WCO&O)HLS7;7*1K.US*68R3ES+(68LYR:_C4^$D\\
MFMN))I7!U.8$/([`CR;&;!#,<CS999?^NDDC_>=B2BOZE\&/^12_^PO%?^E5
MS^2/&K_DML^_["__`&^D?5E%%%?NDMWZO\S\>/_9````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+VEC97-K871E:VED+F=I9@``````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,P
M-S0`,3`U,34T,S$P-C<`,#(T,3$T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y82@`/`#W`````````#,``&8``)D`
M`,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``
MF3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`
M_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S
M9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DS
MS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F
M,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EF
MF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9
M`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF9
M9LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9
M_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,
M,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,
MS#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_
M`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_
MF3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG_
M_\S___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````L`````"@`/```
M"/X`$0D<2+"@P8,(";)*Q+"APX<0(TIDR&KAQ(L8(U;,R)'CQHX@)7X,2;+A
MR)(D-R+R<D6&RRM=O"!"*1+1E14`<NK4N4+&E98RO-!D966GT:,Y`UB9F?+H
MBJ=0D0)@(30D*Z-6<`)88855H$!>G^H\T,7J3I<Y5["ZQHKKVHI9TUX!V38G
MBZ);U[*U`O::7[A:YWH4Q&*%%Q8Y`_EE&VB%XL5LZZZXPO0B*T2"K@C"J39R
MX\>,^];=*GCB2,YKOS:V\A>L8[^!SE:&.!(Q@+>.`W4-O9NMUIRE:5M,U"4G
MZVM9P>JMJ-?WSA6S'8Y$A-JW6\B01^L4)')X(B\X=_YK=5LQ^^^<7:)3])[H
M2@``8&-OU<TW.U+HK1Z>9'C3;?B*?2V&%T]I!2*((%;(D!Y[B63V%%\/UK>8
M=O,9E]5D65WA'69/-?9@A]D-:!QG%RH65D'G;=5A>7^)F%9B>#W6F%0\Z<:5
M<C,:Q554!1+EXE$VIDBCBBJ2J-57]SDFY$XB*@>@4Q?N%.164BGY'(\Z)N=8
M7,]EZ>%-0\)XH5@\69&<:LK!]J!\-)+GXHY9-8<=8U#QE:-1,I8Y8YQS8C<:
M5U<XI=R8=_+9IU<Y3K;D%7R=>51RAT(EZ7D0SJ?:DI!FYV%7`([G(5<_(I75
M<7]Q]I699IH:GH<$2E74<?Y$0=4<8#ORQ%5>S*6HJ%H7=F6FG*@*"1U$"GF5
MUHTF_EJJ6+G]QB!$@NP$5VM\Q7JKE$4]^Q!U/09XS:>AZJ3M0UVLT(5N<+VU
MZ6_GX33NMHE0!V>J+)25D$"LM#)+G_E!2R),W&74EKZM%&RPOM?,`I$5!P1,
MEWH-M9*POQ!;IJW$"1]<,%$:%[PO=@?O%[&^LY1L\BRM:$CRR1V?+/+(&C?T
M5'`"SR00PGU"-DM=,A!<,$97R?JSQQ_WBPB7:GWL%\HB02?01/O:U*Y#'B_6
MKTD.3Z2O%0$$\%2]*V0]\KY7M_5N(OMNIN`*![!-\T,2*YQ(1?NB?'75*,O[
MM205Z67$]$8%]\ETO#X)4K%$?WL7,TW274/1O9!'CDA;A@L4$```.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]N96\N:G!G````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-S(V`#$P
M-3$U-#,Q,#8W`#`R,C0T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`
M,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_
MQ`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C
M0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X
M^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($
M!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B
M<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$`
M`A$#$0`_`/XE9=9<SQL?*B623#2LP578'.U6+`%F(V@`DG..O%8WC?5I-0L5
MMK<J(I=D$CDN8MWF*6#/%E@5'SL!G"@EP4#"O-Y=8O'&P."T+-)&'/#'^+'/
M)`R1M[CZ5H)<2R"S@7=<0S(]Q=(SK'M+(YDC61SA"R;AR<X)QZ5YT*>)HJG5
MIX>G5IT7*?OI<SE&,>?EC)IOE7(^JO+5J^OT"QCQDIPJ*U3%U(4<3/;GKU)Q
M7NR=E)RO%12U;T6NC_9?_@DM^S%^W/XVU?Q?XH_98\-W>D67B6P/A*_^*=U=
M>'/#,>F6HF%OJL.B>(M<@OYXH;N&Y?0]:U#2](UJZTC3]4N;Q-,NKF)+67]U
MY/\`@AQ^W1K<W@'0O$OC'X6WWAI=6O)[C7/"FC)I\_@S[0DFOV\TD^CV<]]X
MMTGP9J%C_97P^M]:NENO!EGKFNG1-6CT_6+SPV_U]_P3@OM>TW]E3X*>%_AA
MX8U.TTNU\'Z+J&HZ5;Z)-!]CUCQ1IT&MW%]?ZI!;`W*W:#36B:1\2#4M/=,B
M[MS)^I.G?$+XJPZ;!H^H:QIT$I5F&G075M+<LD"I.R/%-*@QL,1<.1\LBD<N
MF?\`.[Q"^D;Q/'BS-Z.5T,MP.$P>+GA4L9A95I5)4Y*]2%5Q<90=XQ7*[*49
MJVR7]PY/X%0I\*9*\NQ&6K'8G"4\7C*5?&UJ&)HQJJ[56C1FG3CR1YOWD%-K
M5M)*_P#,?JG[!W[9W["/QLT_XVP>/-,\3>`OAU;:A#?_`!,N-%O?B?;M\/?$
M4DOA_P`?V^L?"_6H;`Z]=+X?UK5[C_A'K`7.NWD:;M`BEUE;!6_+#_@M-^W;
MX;_;6LOV3W\-:N[ZO\*_AS\1-"\:Z9*8Y;RW\0ZO\2+W2+3Q!JFHVN=#FU#Q
M_P"#?AWX8\9OIVCR.=.T?5?#499H4F>3^S'XJ^-O&/A_PYK_`(I\8V4SZ!8V
M]\9U72]-72-/M-0L+F,W.NZE*TEEIEC-:/-<-<WS10M:QRRA]BLX_P`YW]L/
M3M"TK]H[XQZ)X0M+^V\/:7XUU;0M$@O#%<2S6UCJ4\%W-(805B*SVKK8[1A]
M-1VC)C1B/USZ-O&=?Q'XFS&MQ#3PW]H95E_M<+C,-06&PWL)*48T5S0BIU7.
M51R2DWRM625V_P`V\>^!Z'`W!V3U<IKX*;S3&K#8^C@\5/$\V)Y:;G.:E)U%
M>+IK;EM%6WT^4$9-B99"=JY.5Y.!D]>YHKKTT6S"J"T@(4`@$X!`YQ[45_7#
MQ4TW^\>C_P"?D.CC_P#(O\#^9(Y.[1_=O9?8T^QY>OW/OIQL+[V#N53;EB7!
M`PJDE2,9)8#:!P26'0\U]`?"'X2>)_B'%J=_I6GZM)HOAC5_!*^)M2M2)HM+
MM/'OB:Q\(Z29;<*3'<W-WJ!DTM)RD=S<6TC`.D$^WP.V*I?[)':&WFD>.27:
MP\NW?,=PHVI(=S1/)$!L;#.`0,U^D7[$OQ)^&^E>#OCU\)/'NC^!(M3^(G@2
M]\4>`_&GB+Q'_8\WAGXC^"O#^J#P98V\>LWEEH^KW,KZO<SZ38S74DB>)8;%
MK2.2]MX(!S9]7QU#*<1B,L][&8*6&JPIRNHU*=?'8.C5Y&E[[A2=2<XI2<8I
M2:L>EP7@LJQO$^5T,ZQ4J&"=:O5Y>;E4<1A\!BYX6<ND?]NG@FG)Z\K72Z_;
MOXD:5^T]X/\`$$_A?P;8^*M`\#>`;631_@S_`,(Q^T[XB^#MKIL&EC2=/.J6
ML7A-9/#VJ:_XBM1?_$"]E\47KZ5J&ARZOX3TZSU*^M8-*N/MCX,?#[]M,?L^
M_M5>*?&WQ&B\4>/_`(4>%7U+P/XHLM82Q@\5LVEO<W5C/H=MX,\*O;2:;H]C
M'K4EYJWAJPN)]/O=&TDW-]J.@ZC;MS'[$O[1GB;XKZ-IO_"4R:G;:QHF@:/9
MOJ6FKOU75'M=.MK"WM]8L+2TN[2?5+6YT^]\O3+/.J3RG[-##)<R)&WKOQK_
M`."E/P2_9+U#XK?!KXM_#;XX3^+]?T.?3M6FTKP=X>LO`%S/XNNM`U'38/!G
MBV1DO_&=^GPTU+3O$6M1>(E@&E:Q8WVB0E=2DBMC_G1FV=<3X_.,1P?@N!<#
MB\3E<J6)K5E0P=9SC4ITJLVI5Y^TC%U:CC-4HQBY2]]N2O'_`$[QV#R/!9?A
M.,<OSO%8:GQ74EA51IIMT\'&O*E1=1)>XHX:*UG:R7NZM(_(_P"(OQ#_`."@
MV@W\<?B/XH_&3XD_$6W\,B/PUK/A#XZMI_AG3;>_T:+4_$NEVWPSTFT\.Z+J
MFCZ#>7&GZ/\`%0^*/#7B&V\2:U<:/9:-=Z=O>]C_`!'_`&K?!-UX6^-?Q#B2
MWM[2WMM5\.7^J:?:Z:;73K#6_%'ARTUB]TH+I<UYHLM[I&H7>I:38:C:WCR>
M(M.L[W6(4DA,[Q_UA?M'?'_3?"7P6\/Z_I\[ZU)K'A?POJ_AVS\3::FD:_KV
MG3:7/#HEWXDL[6V6+0TU^&YTV^\8I?2V\>DZUJ-Q!>-'<Z&T<?\`-I\9OB/X
M?UGX%_%7QWXY-CXI^*/QT^)&GPZ1>:;JVFE?!NE_#O4--CBU34]&@D:\TZXE
ML/M_A31(+J.`ZKH]]<:U;FX@M'DK^E?!;B#,LQCCHU.#\+DOU*V55W'#T,/*
M=:FH59U*=*C[O):MS)JTN;11M=Q_!?'?ACAO`Y/2PG]N3Q5>AA(9U2G*<7-N
MM*=-4XJZ<G>EI;:[;>EG\'K-;A0#;0@@`$&UG!!`Y!!7((/7-%<!]N8\_:@<
M\YW=??[U%?N_U&7>?_@+\O+R?]/3^)?[6ATQF+Z?8GY?Y_CY,AU.-8]1O8L;
MA'<7")#NVLQ:X"(JC@D\A@`,D*34T&FZUI]OIVM'2M0@LKJZ:/3-6:WN!83W
M5L?,ECMKPI]FGD@"$S)'*SQ*K.ZJ%-7-558M>U"5LB'[3=PR$IE7CE,\%Q$&
M*E4,B.T/F@CR7<2!@5!$L^K7>JV^F6=S<H8])T^2TL('D`M[>$W0:SMECV@/
M-'<F.XN;H?-);(WGETC+5[D81EAZ$I6<)3=.HEJTN6#:=G==K25K73T%BZ<J
M&9YA[/25*M)T9_9FHS23B[6DFT_>75-7T/VZ_8A_::UC2+>:UTVYTW3_`!8-
M(T>[L[WQ)8>(-2\+Z3JA%IJUGX@\067AJ.36391&^FN[.6W14DNH87=C;I,1
M]X?$S]I'X[^*-4OY_'^N7VN:QJ;IJ^G7WA3]C8^//A_JKI;7>B6^I^'_`!.?
MB[8>(;P7&BBPLKR/Q;X?M_[,LHY=0L8A?V=J3^-=]\&?B1\!_"O[-_Q6TC4+
MJ&/XA?"[3?B)X.\4V.E7`TW4UUO5[IM9\&O-+-86&K:IX?U2+4=(O]+BOC?:
M?H%[87,UNJ2VZR_6NF_\%=/VE?#O@6X\(6NG>`0$GELY+Q;75K.\M+F5!:"W
M;1M1OKS3[Q(6<3`*C)!(HN8PLD*,O\T\5>'V(GG^+SWAC(<BS.4L0Z&-QF)Q
MGLL=0<6I2I1C"%7]Q%5.>[BKS=2,DK19_;/AOXJ8#!<,8+*>+,1F-&,,*JF&
M5'"4:M)QY(PBW.LXM3YHM-1]W9K=H=^UW^TUXZUGX5PZ1\2/$7A?7?%#:E8:
M/H=IX2T#4-'CT'1]/>"ZAM-4L-6N-4NK:>Z-LM@++2]1817-PD3[HMZM^$>M
M:A=7T^HO/%*IN;HW:6W^D1QV32R;BX@?:%,T>4&X<J=RGA<?HIHVE_%C]K+X
ML^&[2]MI?&OBSQ+KRV>E:!!;C3+.6\BN%DU2\NH8HP8=`TJU\VZ\2:VR+9>'
M=(AO-7U*XM;2RFFC^3_VE/AZGP>^-'Q5^%-G?ZKK6D^`O'GB#P_X=US6+?\`
ML^_USPY!JEV^G^));)XHI&3QC:_8/$MKMWK!:W*B-GA=GK]7X!RG*<DI2P5*
ME@XYCB_^%'&T<'6E64:U14Z,FXSM*%I4DG%)1TLK['\[>+_$F.XFS;^TL/6Q
MM;*L/26`P]3%T(T/=A5J553BZ=Z<HJ-:][N7O/HDU\Z[SZ#]?\:*G*Q9.67/
M?)7.?>BOTZS[/^O^'7WGXM[1=G_5O\_P];='K9/V_41DX-]>Y&3@_P"EL?YU
MDVH!NK52`0US`K`C(96E0,I!X(8$@@\$$@\&BBN+#_[I'_M__P!-H]G&_P"_
M_P#;DO\`U,JG^A!>>!/!&N_\$@OC'X?UOP;X5UG0?!/[+WP4\2>#-$U7P]I&
MH:1X1\17?PI&IW6O^&--N[.:ST#6KG4HX]0N-5TJ&TOIKZ-+N2=KA5D'\86K
M(AU'X=PE5,6J>"M`O]3B*@QZC?&VD0WM^F-MY=E/D-S<"28K\N_'%%%?D/`O
M_(SXR_[&6/\`_4?#G[/GW_(JR'_L5X;_`-/U#^F7_@COX;\.Q_L>?M-^,H]`
MT6/QA-\?&\"R^*TTNQ3Q)+X)@M],UR#P=)KJP#5'\*PZW96>L1>'FNCI$>J6
MEMJ"68NX(ID_GL_X+`6\%M^W+\78;:&*WB6+X=;8H(TBC7=\+O"+MM2-5499
MF8X'+,2>23117!X=_P#)Q\U_[%B_]/UC@XR_Y-]@O^QN_P#TQAS\R`B8'RKT
M'\(_PHHHK]Y/PY=/E_[C/__9````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]M875L+F=I9@``````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#(W`#$P-3$U-#,Q,#8W`#`R,C4V-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/0`L0D<2+"@P8,($V);`:#A"H40"3)L
M2!'`PX@))U:D>!%C08T;.7J46'&%29,E1PHL"8E$2T@@54XT">DE"5HP9XZD
M6!,))%I`(?F$1-'CS)M"@=+R28N$SH@.`?QDADHI*F8X+3:,.!.`2V9.E#IA
MUE*K18@<&[K\&;2L60!H'98E<1,H7:\PBV;D6),MSK8U-78T6%+M3[I(2435
M>["P6IPUFZ9E3'AR9)=(B;Z%BW#C1,PV%U,FZ?FDZ9,A!P\,R;IUQ<:N8V\T
M"%*V:Y,J<RN<712N[]R_@V,3KE)X[^'(BZ]&;ASX\N!;1^N>3KWZ](```#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=O
M;'9E<FEN92YJ<&<`````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$V-3<`,3`U,34T
M,S$P-C<`,#(S-C8W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B
M``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40
M``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$5
M4M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$
M`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`_3SXU>-M7\1?'7X[?`[6--M-*N?$EWXA\#>`_%NJ_9-.M/#/B-?%/A[Q
MA+<ZWK$L)&G>`O$[_#G1]9OM4CEO+O3;^&.9K.VAU752/QL_;+U3Q#\:[+X<
M?`^&RT?7['PUXE@^.>J:K9WJ2Z7!\*_!G@#QGIMQ?B\MA.]W=ZG?ZGX:T;39
M+>.;2]57Q`+^VU`V;B1?UJ_:J\'ZY\(M/^$_QE\/R0?$SX3^.9M82R^&^H7M
MO;^++6`C[;<^&M!\6WEE?ZK/?6FF23:1IGAOQ7J.I:;8PK-X?MUT&TLK":S_
M`!J^,'[05IX(T'X6?$_X:Z?:PZE-\3/!OP\MM+UZQT:XTOQ)^R]X_P##OQ(N
M=6^'7C2YO#J<?A[7[7Q'IOAWP_:Z[!=6]]H'B1;?0+K5A9"6R;_-_P`#O#M<
M)>-'A/G.?9=@\RR'"<885<.YSPYCYXO#16/EC886>(HX_"9;CL)BJM6K3CCX
M5Z#HUY5L9+`5,7]7Q.(/U[/.-LOXO\(/$3(LCEBL#F-/A/$5,RR_.L!'#U:>
M(A2I8>MBL-7PU7&4:^$E1I4ZE.-%U)8:4*2Q;I.HJ<NS^#/Q6^$%D?%'CCQE
MJ%GX<\!?`/\`9U\":7KNKW._S8?&$^L^+]>U721I=JMQ+);32^+O#^GZ+%:)
M->:A>W5S!';+Y-N;CW/]A_\`X*4?$+X6?$BUDN/#'CG6=-\2>*OA[J+_``W_
M`.$8U+4?$-SX?\0>%_BB8;V(>1:VXAUB[M=`O=$N+2\U'2;P:=K(GU:S5(;F
M3^:'XH^/K?2?VFO&?A29]93X)>*OB_\`\)U>_"C59WAO=0L_"-O-'X"\-^(8
MY)89[RUB_P"$EM]1U;3;^^ET59=+$!CN(]/D0_M)\/OVO/&WA>R\9?'#7]6M
MD_:,^))T'1_!>LZ#%+8W&DZ+X3FU6UT/3X-*>WA;Q!IF@:=J-LL.IZU920R3
MQ3:B]N[1>'$TK_91YEQ5GO$<^&\MR/`5.%\'A<5B,]X@S"NZ?+BZ^-<LOR;)
M\-&#EB\9C&ZF)Q6(J.E0RW"4J3Y,7B<32PK_`)$RK!93D7!.6YSFN>5/]8,=
M2I++LFP-*,Y_[)A,-'&YIFLIIRH9?3O/"82E2G*MF&-A."]GA,//&4OZDX_V
MF_#WQ8\!^*_'^C^$;VZMGAU`Z)I*3Z5J>HZ3]DM+I1<:R(;M$L$O)D+Q*T:R
ME(9L&3"/7\UW[4O[0>J^'_BYIOC.+0]3L+_PUK^@^);)G2`VT=]INM6][`DJ
MM/%$R32V9C\L)MV1M$K[/G;Z4^$?Q@C\)Z'IG@3P]<W.N:UXJ@@M=:N9!I6H
M1Z:]PTEO%Y^IV=O)&;N#[;)(]K%>W=KYJR11NT<;JWIG[4'[)1UOX`>,O$DF
MDQW7B!O"^HW]AJ$EM.KV&H6=C<30M%EC%?`2A711YJLS!0%"C;^M9!D^&R:C
MB:4^>$\3*-/!2E5O&3A!KX9II4XR?(Y<S<W[ZW1\MF^9XO,Z$71:=2BE4K:=
M4E)Q=DO?E%)J.JCI"]DV?#%Y:6_B2[NO$6F_$K5])T[7[F?6M/TJ;STETRRU
M65KZUT^5([^6-)+*">.V=(Y945HR$D=0&)7Y;VOQH\2Z=:VVGROJJ26$$-G(
MBR6^%>UC6!U'FPM+A6C('FLTF!\[%LDE>Y_:-9:.O45K)KV$7:W+=7YM;>]_
M5CE7$."LN:BKV5[5L0E?2]DEIJM.VG;7]L/^"W7[8WC+6?A/^SUKOAV'P?I-
MU\0-:\(?$[09?!'A/4;2;4+[6K1M<\,P:-JT7B'Q$_B!+J:73XDOM1L_#>N3
M3C%QX8TN>YDTVW_%+0/C+\6OA'^T7X9T+]L'PE-:_"CXR:KX1L_%_@KP5KL4
M&D)KGB.V@T_P/!XOTIH)K/4;3PWKNF6-_P#$G0M*U&SL;NW6[ENI-5O+'0-)
MGRO"OCZQ^(OAGPS\&?BIXP\1?\*KT#Q/>>*M!CL4GU77/AOXV%M?2:=XK\(6
MPU"RQ,^I21VM]HFJ2ZGX0GM=5O-8U#PSJFJ:;I-[9_4/[3OP8\.>+;(?MK^.
M-`NY?@QX#\&6.;RQL;W0O!/B/]H-K8>%/!GPBTW4[O5KZUU'Q!;ZEH?CCQK?
M67@?4(O"&E?#WPWX5UW3]+MM*\<Z<1_FI@'PWBN&Y\$9EA9Y3EN>TLRRK.,-
MD^2XW-LQQ6;YA6JUL@S?`9G&JJN3/"5Z=6MAL3["O/#YM]5I/'X*->A6Q7]<
M\8<"YMX6Y_5S&$99O*$L/FG#F?2QW]G8%Y;A9>PS#+<1A%14<;F4E*C1QV$I
MXNG"C@I_650QL9RAAOU\^`W[#'P7?Q9\4?$GQG^!/PS^)5GX>UG4+*RT3Q+X
M?LYO#_@>ZL-1\0"#P_X6O;KP[YI\'V]WJ`%O`+'2IK.RL-*L5L[V.!([?\*[
MO4+7]DG]I+6_AO\`M0?"J'X9:U:KIVM:=J$'AGPE:?#'6=(FV2)K'@6\TDM;
MZL+F.54&R&RNK2[M9;+7Y-(O4BB;^A[P+^TK%K_P>U!=7\1Z9X<\1_&CX;?!
MS]H;P!''I\EYIGCG1_'FD:!XT\4IH%]$KVMQ<^'M2OK_`$G4-)B%Q=6FHV%[
MH<_V74+62T?XPM]=\8_M/>'8=4_:S\(_!'6_&B76I6/@KX;?#EM.\4Z?X3\,
M'[.^K:?XFURR5GUWQ/#<6<!\3:T%%LEP@A:7S(6DK^0_`OZ2GTF?#['<5Y'Q
M]FN4XW@/(JN%X8X=A6RW+(\:8&&+A.AEV<Y+F,Z,I8C+L)1P.85LPH<1X3'8
MBE1C@Y1Q-##K"/'_`-#8GZ-OA]QS2ROC&AE&/PD<0ZF?XC`T:V9SRS/5'"Y1
MB<3A,7AZ<L#&@ZV89F\)AZN68RCS58XJ=&G.I@\75PWZ1?\`!/3_`(*3_L;>
M$/$UK8:??^&Y-0\2ZGHE@=:F/A>YUD7=Q-/%8%+BYU1+NUCAEF9((M&1/(#2
M,+0R!%D_3/\`X*`?$O0K3X0>+?'FFA+[P1XI\/0S7<^BR0W-S8^*(X;N*'5M
M2'GK;1:;J]K::=IT=Q!.[P:U!`[PO-KDDQ_CT^//[!?[.V@>`)O%7PMT"_/C
MC5=1L]&\+ZI\&=*\7^*?!V@>*?$FJ6>B^#]0\6>.=/N+KX?^%;4^(+ZTMBYU
M:]NED%THCAO(@L?WY_P3\^//Q4\=_L_?'/\`8B_;$\3ZF/BEX?74HO#;ZHEA
M9:WJ?PTU&ULHXKJWMXK*W36'\)>(M.OYEO(H9;JTN5TF[N9@TQD?]IX4\7,X
M\/L?A>.I<:9QQWPW#-\/C>)<-Q6OK/%M'"XBMAJ.+Q.78[#5<13S/+Z5.<,/
M44ZF%_LO'3P$73GAYXF.&UX]\$LHXRP%1<.<&_ZG9A2P3PV'P.6\ZR*%>E3J
M/!PJX7$T,+CLMKU9TIUHRE1QF'S'"4\95IXUUX1C7^/;S0_A_J%W=7XLK&47
MMQ/=B66V@$DHN96F$D@0,@=]^YPC%0Q(4D8-%<[?_LD?M76%]>6%GX&U?5[2
MRN[BTM=6TZ]T]]/U2VMIGA@U&Q?S!OL[V)%N;5L#=!*AP,XHK_5*CXT>$%>E
M2K4_$_@B5.M3IU8.7%&60DX5(PG%RA/%QG!N,KN,HQE%NSBFDC_/ZIX8<8PJ
M3A4X,S]5(3E":_L?&.TXR2DKK#M.TKJZ;3TU:;/QYLK"XTZ_M]1M5VJQ19X\
M;HKG*>4PD`7<KR,5E8AE"\,2N=E?MS\"O'X_;P_9;^$W_!/3Q+9Q^;\+/BWX
MC_:"ETR5;>RTKXK:!X/^%'B?PSX1\%1R6+)J2:_HEWJ>E0WMLT#)K?A;1D/]
MIM?*^GM^,5M`_P"\;<J0GRWCC+$,\@8@;2SGR]P&05*+C:CN5(6OJ+]F[X>?
M$C7?&5E?>`'UZPUJS,5_I^MZ3%?6T^FO%>VKI)9WELB&"YBE,;I<I+&8W3AB
M2BG_`#(XPS&.6Y1B\V_M:.2XO+\'BH8;-UB'A?JL:^&J49RG6NG^[57VM.?O
M2HUZ="O3_>T*?+_JQGF3\-\35,JRO,\%2QT<%F^#SO!8.M36,PRS+`U*<XK%
MX7VE%8O+L;&G[',,'*5..(P]2<7)349+[D_8BU3X6V'Q%\;?##]J^71KGX,?
M!^'XPZUX3\&>.[35M1TOX>>(="AN[C6K7P#8:1I]YKGAK5O%LVK>"]9?0O"D
M>CVOBA+*:341.VC1,G3_`+(O[&OBGQ/X2\.-X,/Q*T'X,>*@=:\1>(O%D^A:
M'XD\?Z+>V9UG0[7P_P"%O#NN7&JZ+X7D,=WJ>KR6.LM-K%CJNBS1QB`6^J5]
M'?&__@FM\?/CW\/H_C)X*M=.\2?'&[TVVG^)6GSVMUI7BCXJ6>DZ$NF>%[C0
M_L45EX8M/%GAR*2^M+J:YM-,G\?:7J]U!XFU74=6T[3;MO$OV>/@1#\,/@-\
M3_ACI'BGXQ?$[]F36--\*W9^#GQ3U+4OAOX\_90\0V*:[JGQ)\"?&;_A#+GP
MI\2O$GA7Q_J4^GW7@OPWHRWNBZAHWAWQ#;ZCX.O?#_B==9UO^9UQ]P_XC\'9
MWG7`_&N$S#%4\URO+,]R6E+ZU6PE3+9U\OQ]3+L/BJ^&P5+-Z=7$QSC(5F>+
MRO+LUPT,3F#Q\<YP^&P=#Z/"9K/!<:2J9=E5/&8JI#%X>I.GBZ=3`\/XNM+#
M5,!]8P^&H1KK"9E!XG"X['T\)CL9];A@Z>'RBG36+J2^I-1\<Q_M4>)O@=X6
M_9WO=;T/]EO2OC+X?U"XUK3;[PQJ7A7XWZ]\(==T3Q1XLT[X?Z:VHWOBSPS\
M+=`ET#PKX\TW7M>T?PSK/BS78IO#WAG3%\/V'B9]-N?%OX%S0_M2_`3XM>#X
MO.U?0OB+HW@_XERQ@+?7?@7XL7=WX4N3/"-PDLK#4;E=5\HRHP>T21#+,Z(?
M/?A%\:VTKQ/XE\9:7#ING:W?6%CH?AD7UAI<&MZ=H_V2];77LK#3;>TT&QU'
MQ'&ELTMIX>TN&ST#3[7[)I%W<WFL>*M5US]"/V<=,\+"U\8?$OQQK"2:AI>B
MR>*-0O[VZ0:8LGAG5=,U'0M/MU$MO:)+96[ZC=.D@WLLDD\SNT8,?S.!>-J9
MUE^`R_!X++,KRW#9M@L1EZ:KT,32SR%.GCWC<P6%P-3.,95P4JT*N8XG#X5N
MK&G0P>$P&`PF$PE#V\3*MPO#$0S;'5LRQ.98:%;&3DW*MC<;&KSX>.!P_P!9
MQCP6$RUK#V4:^(=;,%BL?BJ^+J8J=>KX1!\4[K3X8;"2%S)8Q1V<A5VVE[9!
M"Q7$>-I9"1CC&,<45\>Z=#%K6GV&L7?FI=:M96NI7**SHJ7%]`EU,JHL85%6
M25@%4`*````,45YE:CP]3K5::@K0JS@O=AM&:2^WV2_'NCNH\.\73I4I2H6E
M*G3D[QJ:-Q@W?1;-OML]K*W\^19A"^&8?O;1>"1\KQ_.O^ZV3N'1LG.<FOZ5
M_P#@G]I&E1>#_#DL>F:?'*WA_1MTB65LDC;O[,#;G6(,=P9@<DYW-GJ<E%?I
M/TP_^33XW_K[4_(_-^!_^2DQ?_8)5_-G]3W[+=M;FWN";>$F*UT%(B8HR8T:
MVN\K'E?D4[5RJX!P,C@5YO\`&_P/X+_X2_\`:)C_`.$0\+^7XA^&177X_P"P
M-)V:XNF7>NMIJZPOV3;J8T]KV]:Q%Z)Q:&[NC;^6;B7>45_&GT1?^3,8/_LL
MN(?_`%(J'XSE7_)S.-?^P;(__5]DI_(1\.XHH/A_\5=0ACCAOX)X[>&^B18[
MR&W^S/\`N(KE`)HX>3^Z1PG)^6OJ5M2U%/V;_BLRW]ZK'P5?Y9;J=2=]AK^[
M)$@)W;$W9^]M7.=HP45_66,^.7_89EG_`*BX,_?,^_Y.)EO_`%XK?^G*1^+.
MK:[K:ZKJ:KK.JJJZA>*JKJ%V%51<R@``38``X`'`'`HHHK]&H_PJ7_7N'_I*
M/W![_-?G`__9````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]A;&EE;BYJ<&<`````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,C(T
M`#$P-3$U-#,Q,#8W`#`R,C<S-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(
M`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)
M"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1
MH0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::G
MJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U
M]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/XAO'&EPV?CG7M&T:,W:G7+NRMH["R>...YFN3YFF6MF@+2
M+9W;R:=;FV7RKD0K+;HD4D2+^U7[*/PHUV;2XM'T<:O<7]]&MEI]KJYTZSAO
MM%TJP@N]+U`2G3[*21HH;F\M+:>"58+R`J\T-S<J+L?D_P#&OX4_M#?!SX^7
M/P\\8>&]0A^-*>$_`/Q3N_#?A:WO/$FHZ9H?Q*^$/ASXWZ7!):V2:A(\6C?#
M;Q787/B*R;[3:Z'96NIVE[-)I]A<3'W']F[_`(*.?$GX*ZYI$_BK0=,^(>AV
MODV<UL^S2M4729/M:W$=O>PVT\:WD45S"NG7"01M;6UBMB?-LKZ]CF_UWR3Q
M<X#RSB'B2A#&8S!5\3C*E+(:F886"R?#TX^T5"GBL9E]7$S=G5BIU88:I&:K
M0J5<33H05.G_`")XK\%<7<=\$\.T>&EEV=8>EEN"S#'8=9A3IX_-57PM*IA:
M^&>(I87"2P]2KAXU'4EBL%4JTY5I8:$:]*BC^E^'6+SP)J>G:3XCDBM=`ELT
MCMM1MM/A6ZN[[1=*T_19QJ=O;2W]Q%9W)MEU"U"&ZU&(7.E6D]^MM;7]A:_M
MC^Q+\+T\8>$U>33P@U!M4U.>YTBUF>^O;;0[F>WL8+V>\:ZM8KRWGMM7OK86
MEN(GM+5_*M?[0>\O*_G2_:7^+_PO^,O[&_P(_:X^!_BN338?#WQR\'?#KXX^
M$IGOXM>\-_\`":VO]G"5].O+>TU"ZFU&#4H=<3R[(6#:3:6=U9^5)K>C:C;_
M`-1G_!/'Q9I'P]_8.\>?&JXN=67Q&?!?C:Y\(QG5I4O!;Q>!;R&U2XOIIKJ)
M-2?Q+JEJ\=WING:>)-3OGN'LIY[E[B;S/$?$3ROAG^T<AQTJV9XW'4<FA0P4
M(QH9E7KX_P"JY;6J>RG.U.<9/'2J7JT:_P!5HXS"KV7U>O/^)<RREYG1R2GF
MU.OPEB,7CLSR3/\`'8_#1I5<FGD<W4S;$K"XGE<\R_LITZ&&J*MBL/F&/S3+
MZ%.=&<ZWL_J_X0>(O@O\)]>&A^.?&^GO?:[`+_2KBUL3YERDUC`\-LQBG=RM
MO$7G2X^WV]K;07\UW-(FG7"W%SN^)_B+X4UO6OMV@2M+HDMS]GGU2:SN[#3]
M.MC9W%Y:RWVJ7$;V+W+E]-L/LUS=VM]#)>P6L\"W%J\<O\T/Q'_X*.?LI_\`
M!.3Q!JOBS]KN/4?CE^U)KVDV7B;P;\!O!T6FWNI^%?#>HZ;IC>$)OB-<6^J6
MNC>`;K7-(N].U1M/\1ZK=>*[[PY;ZE>_\(A#IFOV&DWWP]\1O^#L[]I"^UW1
M-9TW]@WX0?#_`.'6LZ9<7FDZ7J_B#Q;)K?B&W#);6>IZ-XYM/"WA;3+JPM[B
MT=+V2W\*WZW,[7,1O[9V=3^`YWEV!H<6XZI''8O/*RPE&EC\<J\*.`PE7DE+
M3!8#`X[$49RC[*'^U+!TX8B,8M3C4J4Z=97X,^('B+X>4Z62\-K%Q6:8G,*&
M98N>5Y'B>*<PJT:=.=3+LQS+$8"&+R;+Z:G2P4L/AJU-5,+B95J]>G'#T9?V
MM?8[4\KJMFJGE5FAU%)0IY`E6*QGB60#AUCGFC#9"2R*`[%?@9\._P#@OQ^S
M;XQ^'_@7Q=XE\&:KX:\1^*O!WACQ'K_ARS\:?#^\L]`UO7-$L=3U71+6[N]8
MT2ZNK;2KZZGL8+BYT;2+B>*!99M,L)&:UB*\M8+%M)Q6+G%I.,X4%*$D[-2C
M+ZNKQDG=.RNG?3I^(5_!?Q,P]>M0GP!#GH5:E&5LRH-<U.;A*SCQ#*+5UO&4
MH]I-:G\0NE?MO_M7_L[?MN>#_P!JWPW\0=1C^.OP9T[P9\/_``_XQEM]-EO=
M?^&W@/X6Z5\$-#\/>)+FWLE&JMKWP6TVP\'Z[KLZ+XHE6:76(-2T_P`206U_
M9_/WQSF^"_Q(^*2:W^RM\-?B!X#T#QK'?ZY>?!+4Y+GQC;_"SQ5JGBSQ1/;_
M``T^&7B^77?$GC3XE^`_#G@]?"<.D>,O'=OHGCG5=6?7K;5]$:'3K/6=8^H/
MVL?"GB#P;\0]'^/?AVTMH?!?CV?&F,MI.S^'O%-G9_8_$G@WQ?!<VEG>V>J7
M=Q_:,^F->B"YNM):2VTY[6ZT"^LM'_5;]@35[**)/$.@Z%8ZU"=*U_6]<N[7
M3H[OQ));:?I4]UH[:-)J4%G?6VH7L>KZ?HT.E:9//:W5OK$CW427\ES)IO[-
ME_A+PCXH8NOQMP[QEB</PUF]>6=X+!U,#A88["99B,9B*%/+?K3Q>&@L5E6)
M>*P,Z<\!.D\7@L13I2G4YL0O]7>._$;'^$O#^1XJMPI#&8Z."P^35Z>#S2K@
MLNHYAA\-%5(8O"_V?7A/"4[PK8*O2J1KUXU53I3AA7[:?P;^VA^U-_P42_:+
M^)_PR^)G[:GP[UCX:67Q'\`_"[X8Z+81?"6]^"OA7X@>%_A3J.KZ7X:\5G08
M;?3'U7Q7HMQXDUBYL/%L1A:Q,%CIV@BQ\/Z%I6D6']WNDZK\4O@#_P`$:M+^
M+_P'^&A^)GQ=@^#6J_$'X'?#O3+:/Q!>^(O%T7BVQT_PM<Z_IZ6-L/%$?@*/
M5%\7>)/#<-Y!<:_I/AN_T&%5?4XI+7^2C]K$^-_VJ?&O@I_#OPZ\1>*-$\!V
MVMWMWK6F^&KSQ3=_#KP#8W'A^`>,?&U[`\]GX>\,Z#?74LT=^9+33O#]UX@E
MM9=3>VDEU)?Z[OV4O&/Q'U?]GKX,_`.=?"%MK%GX+\5>#?AIX>O=?M;'Q-\4
M?#_PYMK:W^+/B/X1^&VUJ#4?%VB>%)];TB7Q5XUT9I="T/6[IK.>"XO]0B@M
MO=\1^":?"O".2<+4.)I2RW+>*<%BZ\LUQ6`PN,P^54\NS?$5Z6"J0H4L-"%+
M%9A1Q454PTE1PM/$5E%^SK2A_&W'W'E#BW*."\W?!&7XG/J4L<J619)5Q\\M
MGF%+B;(\'A<;G,Z==YK/#U.%\!C<-BZL\93Q*QM;)JE6K]4CAZ-7_-Z_;_\`
M%/@_XK_M%>,?C]X1\!^._A;?_'O4M9^*7Q0^&7C#0X+?2OA_\:-=UW48_BMH
MO@3Q786FCZ5XQ\"ZQXT@U3QIX3;3?#'AZ#P7H'BS2_AS/'K-]X1O/$6J^G_M
M-_M\_M4_\%$/AO\`L2?LM>*/!OA35-,_9%^'%M\$?@'X0^"_P]UFU\6>+XKG
M2O">@V]UXFTNPU#7I/%7C2_TWP=X=LHAX?TS1['S8[Z[M=#BU'6-6NKW_3&_
M9?\`V$_@_P"!M9MM!^,?P^\$R:%=>%(I+_3/%VBV]_H6KO:6ZW.LP7&D:_::
MAI]C<ZKYT[7MMI-TMD\*ZE9W5Q<SI8V]ROCWP)^S;^SSXIU#Q9\.?A'\+?AO
MHUE>ZGJ&L>,-&^'VEZ5/H/@[P_ISV6I7MS?:+81ZM9RQV5Y%I%I'9P2:>\E[
M<+/;J+ZZN9_P>KA>$<+GN:Y5DN9YIF='ZC_:3S&OE6`C@ZL(1Q]/%3H9]4S6
MK7HUL3@JF,CB<52PU2K55;$3KX>7MEA</^R8OZ46)R[(,DS:?A_E^>9I3SW,
M^&,BR^EQE.CQ`\;2P.'QLI5^'*/#N*Q>&R^E0JX3"4GBZU?%8BO0H3I/$5*E
M+&5OYAO@1_P;[_M(:W\#_@WK7B'X-Z#I6OZO\*OAYJFN:9KOCC6M)US3=8U#
MPCH]WJ=AK.E!L:9JMG>S3V^HZ>.+.\CFMAQ'17ZSZQ_P<A>!_"6KZIX5\/?#
M_P`(:AH'AG4;[P_H=_K4ES!K-]H^C7,NG:9>:M!;:3=VT.IW-E;037\5O=7,
M$=T\J17$T861BODO^)F,VPO^S87(^%)8;#_N,.ZL>):E5T*-J=)U*D<QC&I4
M=.*<YQC&,Y-R48II1^_I>#7'V8TJ>88W.L\P>,Q].&-Q>$HY7P8J.%Q.*C&O
M7PU+ZQCWB%3H59SI0]NW644O:MS3/XH?V9O'WP[^,GPK^,7P3^,7B3Q%K/C#
MXBW-GJ'PXUBXETJ_T)?%4U])-K'B/Q/K^I/J&MKXBOIY%L[;6=.TW5;AWGN[
MC69H98[6:7Y<\#>-?&/[*WQ7U;PS>7;W?A]-2M;#Q1HEY'=VUM):ND,D>HK;
M"&>XT[6=-MIP9GC@GDWI-82K>QJKUX3X>^)7B+2]/T30(;R$:'I'B"Z\3Z1`
M]C9W4]OKNM6NBV%W=S:O=6KZ_?6E_I\7AVS^P7>H-8V86VO[+3K&[OM<33/T
M+O\`PYX<_:V^&'AO4[^[\.^%OC-97%[X2T'7;[6M"MQXXDT&TL+R31?&EG:3
MMK&CNZ:UIUCX6\9:KI5GH=]+<)X?^VBVTBZ_LF/H[^-^`X'4^$^*&J&65,P>
M:<,\2.5;FX9S2K1E1QN78]8?]]B.&<^M0EB:4O;T<HS&D\RH86,,QSFK4_H_
MC+@[`<287&T<9@XYA@<RP:P&<99)0<,51C)2P^84%*#E#,LN=W1JT9TJ\Z7(
MXSJU\%@*2_2;]GG]JOQ!X0TKXQ:+\-]7U'PO>_&/X/:E\+_'4NGW$&E^([;0
M-:OFE#:'KL44FH1S:/J%G'.;BUC2U>QUH6TIM[Z^=;#^L[]@_P#8C^&FK^$_
MV._VX(]?\<:I\4_V5OV2=._8OT?2]6\0R+X(\/:OX8\--X7\:_$'PCIK7%O-
MHWB'XG6=W-<>+]=M9;:;5H=4=;M+63[8B?YWW@>'QG>>*O"6GM<ZQX/\6>"M
M7TOPCXY\-WR6&H:M>ZSIM[<W.E:]';ZX\D,-[?W%Q;VUPWF:7IVK6-NBM?I<
M6`U2_P#[Y_V0?#W[3E_^S!\/-2E_:=T/PU\-O%.F>,?&EQX?^'7P>M+>Z@U+
M4'L+H:?I/B'Q[XS\11W^MP>'M/N+J>6'P]*N@>(HM2LKB]U"STVVC7^QO&K"
MTN(<ER?,\LQ64Y5+.<5&.,SBM@\1C<)GF7XO*\/35",,-A,=-XF&6QK82CBI
MQH8BE+!.CA,7*@X4\3_FCQSE^'\)ZV:Y?4S;%1CFV"Q&7X3+L-C*^"S/)\TI
M5*RPE;$8VG@,PQ,\I_=UJ\J>$52&+PV-P^7XF<*V86/N+XV?$#6O&YN/#<-U
M=IJYN[ZW272KEI;NQNY;;4?#Z0V=ZXU+[1/J>GS65Q)8M9SQ:7<&:QN8M2GN
M+RSLOYZO^"L?[8>D?LB?#B]^`>CZG+\0?C9XRD\+^*?VA-7\<+=:E;FWL18>
M,?#'PDT]%U6WLE\.6^NZB=9\56FDWJZAJ6K/#8PZRBZ3):Z=]%_\%-/^"CW@
M+]C_`$`>'_AL^G6?QWO8((=3TV\NK?4;/X7P_9+%]+E6VGL(8+KQ;J]C);70
M?5+J630I+RXN[JV.N+!/IG\*_P"T1\:?B#\6O&9UKQG?>(+_`%C48;6XL9O$
M#:B+DZ5=Q0)HUS:0:G&SKIDVF[)_#\XM7LSH4%UJEI'<6%O%IK?Q'XH^).'P
M&25/#CA.4\/A'*"XCQ%*%*FYUJ%6%6&64<12G5=;"TZL?:5X4JT\-4JPP\W4
MQ->DZL?V7Z+?@9CJ^-RSQ8XQPV(C3^K/&\-X3,:M.KF&9YCBJT*KXDQGLZF(
MY,OPT:2604YXJK]=]K_::I_5Z6`QN98U_P#$SQG>7U[>1ZW=V<=W=W%REI;&
M)+>U2>9Y5MK=%B54A@5Q%$H50L:*``!BBOFYYD+N3:V$I+,3*^J>$-\A))\Q
M_M-E?W.Y_O-]HOKV?)/FW=Q)NF<K^:#_`$%'/-,@LY4ED60V6IS&1797,R^$
M;*[64N"&,BW5]>W*N3N%Q>74P/F7$S/[-\.IIH-6LO(EDA\N]UN&/RG:/9#:
MW.H_9HDV$;8[?R(/(086+R8O+"^6FTHH`_0OXUR20^/OV)]>A=X==\3:K<:=
MXDUJ)FCU;Q!I^G^-/"<-A8ZWJ*$7FJV=C"[Q6=M?S7$%M$[1PHBL0?[F_#?B
M+Q!:_L]:0MMKNL6ZZ-\/;C4M'6#4[V%=*U&VT*=[>_TT1SJ+&]MW1'ANK7RI
MXF16CD4J""BO]$.#O^3#\`_]?N)?_5;3/\X/I7_\G.X7_P"P*A_ZL\,?P/\`
M[;&JZIJ'Q/\`%,FH:E?WTC^()D>2\O+BY=T\_4FVN\TCLR[H(&VDD9AB.,QI
MCX`UG5=3URZTZYUK4K_6+B)?[$BN-4O+C4)X]&T/7M)\/Z+I$<MW)-(FF:1H
M#-H>EV"L+73](9M-M(H;(F"BBO\`/&?QR_Q2_-G^C&%_W;#_`/7BC_Z;B>6?
MVQJW_04U'_P-N?\`X[1114FY_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S<&5E9'DN9VEF````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S0T`#$P-3$U-#,Q,#8W`#`R,S$R-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_
M`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF
M`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_
M,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF
M,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___
M9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F
M9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_
M9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-F
MF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_
MF<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!F
MS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_
MS)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]F
MS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/_
M_V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF
M_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(?D$`0``V``L`````"``(```"/X``0@<2+"@P8(DL"E4
M"("4LX>D(CZ<2+$B15()%P*@J**C0XL@.2[$MG$BJ5$J`)!0\3%D18P:G9%*
MN?(/098N*ZK0.)/$08$X<T+,2`+BJ)\`5`B=N)/DPQ4J?!XDT3(GS)(RC_X,
M*G1GR9D#2>3I1+;3G)5+9?I\^$2KBCEE.^59,8<K1)EX'PJD2&(%JQ5CR?JE
MNZ(E*:@=511VMG>BWVM_!;."3-CAS#R8,Z_0:E*@7Q5R/4?.$U4%9JEB23<^
M/)#5VY0"79,E?9I@:H$1Z9X-.Z>UZ;AO?<[I3:)W4MZH\T@52&)E7.7-B\.V
M.?!M9K/,YP2..SO/G,U`W\+.AEWP[&_@I#TR;CBS;)ZIVCL^M]OX?"<5@`I?
M)LU=[F**JP%&UDJY;<=='D]4I5=#$'5TFGS]S;892,SA=))I!AX877/TD0`)
M)!M&=UIQJ'E("R2TG-C71P!@0T**)WX(HDH?(@$)C2E"@@2,-RK%F(LHTM(<
MBC>^F*.))]H(8G,J.=0BD#+:."0M-M)"XY`SCJ3"40M%]^&1-8(HXX<^C:10
MF69B.66**FUHYIMOMHF$AQZ"".>=>'8Y9T9YCA00```[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V)A<F)A<FEA;BYJ<&<`````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$Q
M-#<`,3`U,34T,S$P-C<`,#(S-3<P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``
M$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'
M"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R
M@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S
M]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41
M``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC
M,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:
M``P#`0`"$0,1`#\`^Y?%_P"T;XG^%D/A_P`#_$K^SO#VK:1/JNC::MCKEGJM
MM>MI)MM.OY+2XFFM9;S2)OL\)T[4$MK6X"&$7-C9MN-?('[0W_!7#X8?!_P1
M?R37=MJ/B&+2]3GT_3M'O;>\UB_NX;=&FBOI]-DE%BMU/<)I5O'JDVRVE>33
M;,W"6:6[?0WQB_9V^'7[4?@GQGH?B6/7(-9-[K^JZ!K?AB6.'Q!H<VGN\$&N
MVFLW,#OIT%CBT-U!+-<O?PEXKF*^B^T2#^.C]N/]F/XZ_LG_`!L\"_"WQ38:
M=XJG\;^*=-U[X1>+K6]T*;3OB7IVEZU_9.E6&L6NGW<5AIUS#XAU&SL=;M=5
MCTF*/STOIK/3H)9)I/Q?)<EP6=XMX7$5XR4*>*E7PL94IRK8>BE*?/[27(H1
MTC-*2K24FHQE=L_KI2R7"97BLUQ%+%T\5@%AU3H2]W"U<17JQHTY\L'[:HJC
M;:TE3BO=ERMI/9_:9_:S^-?[2FI?%3QY\0M?E?PO\-SHFF:'X%T]R_@[3_&G
MCE+A;/1KG2FD&D^(;WPQHVF:]J.L?VA8ZM_:&NZ#:RW,-G:W4]G'\E6/PWU;
MQ!\-_&GQ'\8WMWHKZ#?:3!I\6N6\(O/%5QK$4WVZ.R::07-L\$4=I>WMY<O<
M:7+IS2SZ>9Y+.6V7Z=_:4\*)JOQ`^*EMH7B#PE>?#^?XQ>&M:\2ZMX?UJQTW
M1M<^+DOPZMYOB%X0\"#7IY+\Z183:?XUT[X4:CXATV#P?J<=AK6CZ5JLNJ:K
MH^@ZGYQ^UAJWA37/!7PP\)^"_$-KXM?X=Z6^@0ZW96?B/PEJ>M>&=^HSZ9:_
M%+X=^*E-YX?^)OAF=AI3ZAIVN^(/#.M^'H[*2UU>]*0,W[7D\,!EM3#9=@UA
M<!@5*554Z-.%"EA\/AJ5&5++T^12@\<JKA-IJI2E%SG*#Y;_`"N.P&*IT:N,
MK9?5Q.*6%<H1ITJ=.,9XJO.2J*,>2;K0H*ERT*$7*I&\X4I1NU\`SSPL61EN
MB-H6W0A9(D#"1)A)OC4M%,)'13A"Z,7G,ADF+?NW_P`$X?VL]3\>V.H_`SXD
M:MJ>M^*-!L9/$/@/Q7K5_P#;&U'PI9+:P:CX)\3:A<2FXFO=&U%=/NO">NWD
MTL\NEW&H:'?W:?8_#\!_":XTRXMW1;A#$)2`@9#N,0`\R8K"'!BB<B-W#;B<
ML!MQGV+X8R_$KX<7&G_'#P=<VVFS>%;R:YTYI+V"6[NK*20V&MFZ\/32L=:\
M)/:S3:/XG$ZMIM[IMYJ%A+&Z[YX/M,OSK_5_&83,*6(I4IRK0I26(G*5+&0E
MI+#5M9*49/WTJK5-.*?-L?G5'*,RS6IC,#2R['8M8?!XC&XE4,-7G/`8/!1I
M/$8O$QIQYZ=*G[6&E:RFY\L%-II?UP1:K;I%&@FB0)&BA#I]NQ4*H`4M(?,)
M7&,O\YQEOFS17Y(:=_P5!\(2:?82:E\*-?349+*U>_33O$V@OIZ7K01M=+8O
MJ>B7>I/9K.9!;/J%U<WS0!#=W$TYDD8K]A_XB!EG6HXO2\>3%Z-\EUI2MI=K
M33MT/%7"F8::TNG_`"]P/]W_`*>6Z?@O,_K!_9P_X*`_L)_L_P#@3Q%XH^.O
M[0W@#3M5F\"QV^FZ'H/B&T\4>)M6O-0MM8>\@M-&T)=02"ZEG>Y6-]1>;5+N
M\E6TBTIVMY;.U_DQ_P""J?[9/P9_;A^-G@>\^%%MXJ2]\):Y=>#?AO=ZG9V'
MA/P_I^E>)->MI[R;Q%K>M:UJ&KZFCZ]/'JNE79LO`L=A_:=]J6LO-(^FZ;H7
MY`W'C3Q'<J+>WU1+>.2Y%S!>^18RW\;K?FX$ZWPM+K4PZR%(XXK:2REN<O%=
M(T*&"#C9)FDG62.5KEI98C'*T#N[SR,JK)(9;E;EGD:1C([7B+++)YDCM.`\
MW\N\.<%Y5D&%7+4EC<RA+%SACYPC17-C5:?M.50E)1:CI)."2O&-V?H69YU#
M%YI6Q"I8AX:M6PDZN$J37L5#"R4J=*A!RTB_>NY.+E-QE)RLFOZOO@;_`,$X
M?^"?FF?!WPO\2OVB/V[=+\;?VK8+J$_PN^!FA:!#96>D^'9++6]6T;XE7>IZ
MWJ?Q=ATF[LM*GFO-8\,6/@(6NEBQ\1>&O'5QJ$[/8?!/QJ\!?L:_##XU?$'P
MG\'9/C'\=O#?@;6C9ZW\2=?U?X5^(/AG902Z-INM6=KX*\;:3H$7]JWFF">]
M6X\4>+=?T?0K&VT:[U)X_'6I2PO<_H%_P30^$W[.4_A/X2?MG^.OVLM.\)?M
M$>,?V<OV@S/\//B+)H^G^*=8^(]CX3^)7P?D^+6H?&GQ)J@\8:E\/E;5=`FT
M;0->TR\L-<^*T>G^&_"UUJO@[P/KCZ+K_L3?%#_@GYJ^M>&_@M9_L&?LJ:U\
M5?#?[/\`J>JQ^.-?M_%6NZUX-^(/@J[\.6FE^+O'OAKQ)>:%X2^+7C+7Y-8/
MC&]TGPI)<ZV^F:1+HNG^+=1-P+/2/QMXW&8?&YCAY8?-<7.E*>)Q^;2@Z^"P
M];FJ5,7CL?#+Y-86E%0H4<+35*$&I<DJ4JEN7]^PV88[%4Z&=RQV<YQ@)4:&
M6X+*H8VADU;!8>.$=;`8++\#C<'@\'5HTI16%Q684HRK1?-)8RM.O*K+^9KX
MU_"#Q3X&$6IZOX4\8^#]-\0:;I'C'P_H_C?PY<^'?$D_P\\5Z;;ZO\/_`!A)
M`+&Q2YM/%&EQ7%Y::QIB0:5J\@75M/MK:"_BM8X=)U9K3X<P210VPTN#X?7N
MEW<HD1[J'5YO$^JC2['26W>>DDMQ?WJ:O92Q2*M@]E/-(P:W1?L7]KWQ1\0=
M4_:5^(VB_%W0+KPUJE_HVEWUMHG]K#Q%HD5CXQT^V\=:%X@\%ZG%'I5I>>"_
MB+:Z]8^)M*U/3_#GA3[<NHO/XF\):3XVE\57^L?F[XFL+_0'U/PS!>37&BW5
MS9ZM%&R;5D>`&1$EB*@":W%P\4FQ9YHRGE@NXVK^P8?#SS'#X'+<5B</5>'C
MA<VI8FES2H5L/751*G!249.5&5-Q;J0C6D]9)NQ^?8[%QR&./XMRO"UX4LWP
M.8Y%F&$C%NOA,PPE3#UJ*Q<<3*I5>79G4HRI5:<'45.48<ZA#F:Y:..\6.-8
MS:M&J($8KIA+(%`5LS0K-RN#^]42?WP&R**!+(`!YVH'``RLDX4XXRH:16"^
M@95;'4`Y%%?;/V#>VC?\S>GN];>;_I'XRHS223E9))6K.VG*E_R\VV^]FK+?
MB?:+=;K,$=S"2T40"H8C%PD#RO%$54F]D$CR0M,80KMAV8UM*/*C(N%F9?M+
M6I!6+:NZ/!-Q(<)&AD9P\<093M)4;2/<_!/P1^*OQ(OHM/\`A]\,?$?B=[BX
MMK))K#1TEM?-U)XX=/MWO;QH$CFOYYH[9(ENK<HZ23B)R=S_`+*?`K_@AW\>
M[SP_8Z]\6]*N_ACXE\00F^\/+K>AZ-J,MC$[F.21-.C\9:/)I_B*VU+%FNL>
M(GDL;:XD4+X;OT\B\7Y_-.)<CR:E7GC,PPL)4)2A6I^T=2I"46H34J=%5*JE
M"3M*"@VF[VN['UE+AO,L5BJ=/$VH4ZG-#VE?#5\-SOEA).G"I2ISJTYPFI0K
MTXRH5.9<M1H;_P`$5_BIHVK6'[1W[&VI0?"^U^(7QR^'.IV/P5E^-/@?6_B1
M\,?$ES>-HVI?%WX-^-O">@7UCK&OZ1J/ACP-X8^)?@C2=&U/29;;Q+X"O9K.
M76+NYA\.:K]*_M7_`+,O[)?P4\):FG@#XI?LR_LM>/M572-9^(?PZ\+_`!XT
MK]H/X\>`/&=[:O</X9^%/BNQ\6Z`;'PS'?V6GW6L:OJ_P-T?QG9ZI8QLGC7P
MY;W4UJ_UQ^SK_P`$@/A!^S%>^&O'6M>)=0U_XE6&LZ?XLM=76]L[G4?"7BW2
M);J[\,Z[X?U2*'2M-NKGP=JMW:>)M.TBS\-I93Z[I^EIX@O-9TBUEM+G[JTG
MXI^(+M/&=IX4_P""7/[-?QI^)^C^(+H_%[XI-=_LPW%YKWBNRTBSU32?&]];
M?%:[N?B3H.G:IX4N-.U32=+T;2-9CTF=;BQ\.1:O!&84_`LQXAR?->(\R_LG
M%8O"X#$XJEFJ=6GAZ52.9NE"G4Q5*$L%5I.A5E2H^RI2E3=-*?)1BZU52_0\
ML57A["4,3B*5#%2A!X3$PIXK#X5+`NK"5."<Z?MH5*:YH*M@?95>64*=9U'&
M,I?RJ?M_:-I+_%WX:1Z-Y]NI_9>_9\ELKK4;F.[5]*N]8\>7^@:IJVIZ7:VD
M$@NO!EGI5_%J*0Z?INKI<0R65MIMI/ING1?G)\2_#T-]*EWHAE:RBGG>WDO8
MR9'MDD:Y<3YN=D+LKP.;8O-,&$\,%S=+:SRQ_?G[9.C_`+8G[1/[6&K>)/$W
M[-WC+PWXU_:`%KKWP^\.:/:G6-+\4?#+P&TW@_2%T'Q)I^SPQ>^#_#-[IM^?
M%&H+JUAH*:\;7^U;;3+:QL-/'ZP_LK_\$/+SQ6EEJ7Q_U&X\;:V86>Y\$>"Y
M;[1_AMX<9KE]T>O^-;,:?X@^(-[9F5=2O7T"X\,>&$OA/!$^OQE5E^ZJYSE_
M!V$RBC5Q4L=C:6%I1I8;!2>)Q3<G*<HSC!5*=.+E.24<3*$8.\8<JCIZ<JN%
MSG+\W690E@L)5J.I&I#VE"E:=1RCS>U]C4JU:::3DE*I-2O*4D^8_DY-GJF3
MNTJ[=LG+HTNQCGEEPQ&UCRN"1@C!(HK^_J'_`((M?LO6D,5JWP!T=VMHTMV?
M_A74EWO:%1&6^USZ_P"?=;BI/VB;][-GS)/G8T4O^(L4?^B:S-;:.OAK_9T?
MO>>OJ^RO\1_8&2],_J^7_":GVMK[37:/KIW/8/\`@G/\/_`<'@#]NCQ/!X)\
M(P^)-$_:#^-]KHWB&+PWHT>N:1;1?\([<16^F:LED+^P@BGO[Z>.&UN(HTFO
M;N15#W,S/]+^+0)_C!X*$P\X7$6I7%P)?W@GGD^-?CF)YY@^1+,\5M;Q/(^Y
MVCMX4+%8HPI17Y)XA?\`(^XO_P"RGSS_`-6,3W,+_'RG_L59%_ZJ,.=[\:K.
MS/@*XNS:VQN[?0[V2"Y,$7VB"22^MX9'AFV>9&[PJL3LC*S1*L;$H`*_'#]B
MK4]2E_X*IZ#I\FH7TEAJOP,GN=4L7N[A[34KBS_:*^&EO:3W]LTAAO)K6#7M
M<@MY;A)'@AUK5HHF5-1O%F**\Y?[W#_L'I_^G(GMY#_R)>(/^O=;_P!.Q.9_
M8"_XJ;XF>(KOQ'_Q4%W%XL^)>@QW.M_\36XCT/0-;U=]"T9)K_[1(FE:*]Y=
MOI.G*PL].:ZN6LX83/*6_J,^#EC91^$;,1V=J@GN[CS@EO"HFWF]1_-"H!)N
M2.-6WYW+&BG(50"BO6R'_DHLU_Z_2_)GS?'W^Z83_KW1_P#3:/`-4UW6XM3U
M&./6-5CCCO[M(XTU"[1$1+B151%68*JJH"JJ@!0```!11177+=^K_,\*.T?2
M/Y4S_]D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]M;VYK97DN:G!G````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#(P,S$W`#$P-3$U-#,Q,#8W`#`R,S$U,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#_V/_@`!!*1DE&``$"`0#(`,@`
M`/_``!$(`+X`E@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'!P8("A$+"@D)
M"A4/$`P1&18:&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q-#`K-"@K+"L!
M!P<'"@D*%`L+%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*__$`:(```$%`0$!`0$!```````````!`@,$
M!08'"`D*"Q```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!
MD:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I3
M5%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6F
MIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T
M]?;W^/GZ`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`^J:`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*``D`9)P*`*%_J]E
M8P>;-,"F<?)\QJE%LZ:.#JU9<L44QXHTP@'S7_[X-/V<CH_LO$=@_P"$HTS_
M`)ZO_P!\&CD8?V7B.P?\)1IG_/5_^^#1R,/[+Q'8/^$HTS_GJ_\`WP:.1A_9
M>([$UEK^GW<OEQ2D-_M+BIDG'<SJY?7I+FDC2BFCE)$<BN1UP<XI6.24)1W0
M^@D*`"@`H`*`"@`H`*`"@!KNJ(6<A5`R2>U`TFW9',:CXQM8@R6"&YE4X('2
MM53?4]BADU26M5\J.?GUK4YVE+3;8I?X/[H]*OEB>I#!8>"5EJB@H*C&XD>Y
MIG2W<6@`H`*`"@!.>Q(/M0!+:W-U9.7LIBKL<MD]:&D]R*E.G55JBT-^V\9.
M)8DN+8B,<2./YU#I'F5,E5FX2UZ(Z72M6M-4B9[.4-M.".XK-Q:W/(Q&$JX=
MVJ(OU)S!0`4`%`!0`4`!(`R>E`'">+-::_E-C8R%;=3^]D'\7L*VA&VK/I,M
MP2HKVU5:]$8,:)$`(E"^_<UH>G*3E\3'4A"4`%`!0`4`%`!0`M``3D8/(]*!
M!:O)97J7=BWENOWD'1J'JK,*BC5ING5U1W7AOQ!'JZNDB>3<)_RS8\D>HK&<
M.4^<Q^7RPUFG>+ZF[4'FA0`4`%``3@$GH*`.%\1>(GO9)++3F*PJ<2R]S["M
MHPMJSZ3`Y:J256KOT1@J`J[5Z59Z3=W=A0`4`!XZT-I;@`^8X4$GZ4)WVU#;
M<E2WN'&4@8BJ49/H0ZD%NQQM;H?\L#3=.:=A>UI_S$;1RK]Z)A4>]_*4I1>S
M&9'3G-*ZV*L+3`2@!:`!&DCF2:!RDR<AA0)J,HN,E=,[[PQK!U:T8R*$FC.U
MAZ^]8SCRL^:S#!_5IZ:IFS4'GA0`4`8WBO4/L&DRF-PL\@VH/6KA&[._+</[
M:LKK1;GGMNFR$9&)&Y?W-;L^IF[R\B5%+-M'6B,7*7*MR&[*XLD;(?F&1ZU4
MX2@[,2DF+!&9">P]3TK3#P4N;F0IR43D/&GQ&\.^#F,%U<+<ZAC/E1G./K4M
MPH-7UN<5?&Q@[29YCJG[1%U+"\>FZ2B-GASZ43Q48R_=H\R6.;3Y4<O>?$OX
M@ZNXNK-YH(/X5C7@UPU\TA=1E))H=..,K1O&-R$>./B2S*1<W65Y^[6']ITE
MKSE_5\=_*:5I\<_%=@Y34+=)'7@[UQ7J+,>>-XI&4L;5CHXGH'ACX[Z-JTL%
MOJ]M]CE?"EQ]W-/V\&DK:LZZ&/@VDW8]9C2*6-)+:XCD20;EPV213]@V[4W<
M]-5KZ-#""&VE3GTK%W3LT:IIJY)Y:@A6F0.?X2W-:NC)-)[LS]JK[#'1D;##
MCL?6LY1<9<K-$TUH$-S/8WD%U;2%=K8E'8K2:35F$J4*U-TYKT/4;6>.YMXY
MHF#(XR"*YVK'QM2G*G)QENB6D0!(`)/04`>>>++S^T-36(;6MXC\K+ZUO!61
M]3EM'V-+FZLRR23[]JH[$>5_'CX@R>%[&#0]#FVZU<?-.X&3$O;'N:UJ.-&-
MD_>[GD8W&.+Y8[O8Y'P9\0_%_A>XLO\`A,;>:70;@@/-(O*`]\UR4,TC*KR\
MUV80^LX>TZJ=OR(_BC\5[[Q%JG]A>!WD33WPOFQC#RG^@K?%XU0B[NR[BK8F
M=:2IT=6R'PY\*(Y`UQXIN9;BXE&=L;$E/J:^3KYO-R7LEIYGMX7A^'(W7=Y'
M:Z1X-T;2$"VUA%)C_GH`<UYM3$U:D^=S/9P^`P]&G[.,361(HD");1QH.BA<
M`5B_>=V=T*48+ECL.'E]1$GY4K+L7RON5+W3=-OX)8;FQMV\T89P@W5I&I.-
MN5VL<\\'2DVVKW.6MOA?X7@E9F6X<D'"LW`-=L\TQ$E:]CR8\/X>+O8Y+5O#
M/C'PQ</?Z-J=Q<00'*!)"2%],5ZV$SJ$9*/POOT/)Q.38JDN>E+F\NIVWA3X
M[BXT&ZMM9M0NOPQD6T@'RRMZ$=C7T#Q\5&\UH<-'&2;Y)+7MW9YG>6_Q!UB\
MN-6<7RR.2YVN5`'L*\R6:TD^=S']1S"I/F46F>J?`CXCW^O7Q\+^)G#31H3!
M.PPV1_"U>C2Q,9QY9ZWV8\-BJBJ.$U[R/8R"&97&>Q'K0XN+L]SVKWU1O>`;
ML6\\VG,S,3\Z\\*/2LZBOJ>9G-'GBJZ]#N*Q/G2"_ECALYGF8*@4Y)II:FM&
M$IS2CO<\N("RR;?ND\5T'V-[I7'(P5@3T!JZ<U"5V)JZ/G'X_P"F3Z5\3H=;
MN[?S]/OU7R&[!@,8_#K7-F6'DXOE=KG@6]AB5.2O_F8WC_Q!JUOH,.AWEU#>
MFZ`9=@Y0=A]:^;R_#TIU/:Q32B>MFV,JPA["23E+L=1\-?#MGX1\-RZSKRI#
M>N-X+]43T^M<V.Q;Q-51IZI;>9W99EJP5/VE2U[7;[>0D7B/Q/XZNIK7P-8_
M9-/C'[Z]FX'Y]JZ*>"P])_[3/WGT.&OF]>M/EPRTONR.W\)>+KF-VT7Q9:7]
MU`W[R%'Y4UBZN$A/EK4G%=S3ZSCVVHUDT.G\5^,O#SK'XBT!KN-1AIH1PU.&
M%PV)E^YJ6\B8YOB,/"U>G\T68OB;8O;M)/I=U#*O6+;4U,MJTY\C:.NEG]*=
M/F291'Q3N+V-TTGPW=/<=FVY`K9Y3%;U$<RXB2=Y0;1:MOB-+9A4\5:'<V+'
MI+L.#6,LONOW,U)G51SKWKU8N$7U.YL;N"]L8KRRE6>TE&1@YKSY1:;C)'NP
MG&HKQ?HSR[XP>#0\3>(=(B6/R\&>-!_X]7KY9C6I>QJ:I['S.>Y='E^L4_B6
M_GYE71?&&M:Y'ILT=RMK;Z:!]KR<"51_]:HQ&%HX><E-<W-MY&6$S'$8E047
M;E^)]QO@R5_%GQKBO-!@,40?>=HP`HZD_6OH<H@\/&,9J_Z'EXC%1JXYU::N
MOZU/J2Y8-.Q';BO2K:U&>W334=1L#M%?6\B.8P&&YAZ5D]ASBI4Y1:OH>HV\
MJ30H\;AU(X([US,^.G%QDTU8RO&"AO#]R#TX_G5P^([<K=L3$X$]:V/I@[@>
MO%`',^(M>\,SZA?>%O$<*7-Q:0&XB#+GRSCC'I72HZ<DG<\G%.G5DG'XMSYI
M\#V1U_XA&=P7@@E+@=>`>*^=S?$*G2:BK7(R?#RQ6*YYOX3T_P"*FCWWB4Z5
M8V6?(,P\X+V6O"P6(IX;FG+MH?1YE@ZM>$81?NWU-7XOWP\$_"RSTK0U%JL^
M(R8Q@GCGFN;*J;Q..=6>MM3P\>X4:<E'3HCS?]F_SO\`A,II%9]OE$.<\'ZU
MZW$6M%7[G)D\4Y2]#Z.>9B71PKIGHPS7R*T=XZ,^F=*+14&G:9//OEL(&?N=
MHJW6JMZRU9FZ$8K1'C7CSXGW.B>,$L/#UI;6]O`X$A"#+^U?28+)6Z#E7;NT
M>5BLR]A/V,+/NSV>]L['7M-ABUBTCFCNX`S`C[I([5\W3J3P]2]-ZIG?*DJU
M%Q>W8\6^'T,_A[XA:SX9WL]@FYX@Q^Z.U?2XQ1K8>&):M)[F645JE&K+"O6*
MU1Z!=6XO+*YM",K*I4@]Q7EJ36L=SZBK"$XVGLT?._AWPZ=7\<-X<%\+."6<
MHSLV%`!K[6@XRA&=17=C\UG2Y:\Z4':-SZT\)>#-(\`6!T[2(UENW`,M[U+_
M`(UZ<9QIQ]W<]?!X:'*II67XFN.!625CT1LW^J8'H::''XCT3PJH71H0O3%<
M\]SY;,7>NQOB[_D`7/X?SIP^(>6?[S$X`]:V/IQ\/^L'L<UMATG4LR9['B%S
M$MO)\2_%$R&XNQ^XA>0<(#QQ3J_NI2G$\-17[RMU6B.1^`ELHNKR]W$RE2,=
MJ^0SBJW)0/1X=I*3E)G?>--?N?"^C#5+*)99%?!5NF*\O#456J*DW:Y]'F5=
MT</*:5[&U?6%C\2OA[927K;6G7>C)_RR>N?"XF>58J:4;]'<\&5*&-I>J'?#
M?P-#X(T^Z59!-)/]^=N,#VJ<QS&6,DK;+H:X7!4<.DH:OJ;D>KZ,\-Q+'JUN
MZVV?-PXXQ7$Z-5-)QWV.A8J+O;H<GHGQ9\+:MJLNFYDM=^42XD.%;W%>A5R?
M%4X*I:_Z'%2Q].M-P4MOQ/)M9\!:I'\2HHK4-J5G-.)5NE&Y-N<G)]J^@AF<
M*N#;D[22L>5'+I?6U%+1NY]+-)%`B/-(L=O!&-[GHH`KXN,)U'RP5Y'TC:A!
MGBOA6<:W\5M:URQR^E(#$LV.&/M7T^(7LL)"C-6EV.++7/$XN=5?"E9'H,`)
ME;'<'%>6?4U/A/G2VMGN/'.IHBL7$CG*GE>>M?>9=.,8Q<GT/SB:_P!JGZL^
ME_A!J9U7P7*'E>9[5]A=^M>A)2]DW->AZF%F[I-G7CH*YST!LW^K--#AN>B^
M&/\`D#P_2N>6Y\KF'\=C/%W_`"`+G\/YTX?$5EG^\Q.`/6MCZ<%)#`@XYYII
MM.Z$UH<AXAT>XETOQ;"8(ET6XAWQ@#DOCDUT07M+W/-JTW#FOU1X?\![LIJM
M]8N5$>TD$]<U\AG-.*M/J:\.SDI2BEH>K:II]OJVGSV%ZFZ*4$8]*\.$I1DI
M1W1]?6IQJ0<9;-:F7'XAT7X6^%%LWF:ZNBQ,-OG+?CZ"NJO1JYK64TK)+5GR
MLZ5#+$X.3:>OF>9W_CCQIX]O&L])26*%SCRX!@`>YKTXX#!X*//4W/,AC<5B
M*G)1TO\`EZFWX/\`@MJK79D\1W36MDW+I&YS)]:Y<;GE*W+15WW['1A<K<6W
M4E?R74Z?4/@/H][')_95])#.!^[#'()KCH\05H/]ZKHUJ97AT[M-'G]IK/C/
MX1ZW]GO$:6TW8*2C='(/8]J]25#!YK3O!V:['G^TKX1\LM8MGM6D^(=!\>>&
MIO*N1$)5Q/;9PP/<5X,Z&(R[$J<5KT9[D)PQD>2F[HI:5IMEH]F;+28/)M`<
MX[L?4UO6K5*T_:57[S/H,+A88>FH05K#-<O5TW0KV]9PGDQD@GN:BG3=2:@M
MVPQ=;V-*4^R/(OA'8RZMJ^M:I-N$21,S-CJ3VK[S"T(J*4MD?G5*4IU'5>S/
MH#X5:>VF^"<R1B)KJ4L!W(]Z[JL[TN5[GLX2#3_$ZKIQ7,=XR;_5FFAPW/1?
M#'_('A^E<\MSY7,/X[&>+PQT"YV(SGC@#WIP^(K++?68W9P!ZUL?3"4#)(56
M8R6LPW03H4*]JUHM\_+TL8UHIPOU1\GZG:GP%\6FBD4Q6C3<^FTFO(S7#>UI
MRC;;8\;+\3/#8Q-:)NQZGX[\2P^&=%_M!<2/<C%NOJ<=:^5PV'EB)\JT[GVF
M,QU/#47.?3;S9Y9\/?!FI?$?Q!)J>KNZ::C;IIF_B_V5KV<9C*67453I[GR%
M/#5<=)XBN]'MY^GD==\4K+6?!4MM>^#X#:Z5$`&DB7)S_M>U<66U*&+3C7UD
M^C.W,*52G2C+#JUM['H'PV\8KXY\.27;J8[RR`%RG8G'4?6O)S'`+"5U3B])
M;&V7XV-6%[:['E'Q(^*6I:GJL6G^&4GM5MWVED'S2,#Z>E>]A,A6&O+%:W^X
MX<9F$W5]CA[O7[SV*WL1XL\!06/BVV`N9XQDD?,A['-?.NL\)BG.@]$SU*N&
M5:-I+IJCYQ\4Z!K/PT\3JT;N8<[H9A]V1?0U]A0J4LRH7MZ^1X$O:Y;74Z3T
M_K0]I\%:\GBK0([Z,!9T^66,=0:^=Q&'E0J.$C[;`8Z&)I*<>N_DSS;XT>+H
M+P)HFGL66)LSN#P3Z5ZN4X25_;37H?.Y_F%_]G@_7_(]:^`OA1]!\%FYU2)2
MVH`.J8_A/2OL*451I\\ON.#`8:\;OJ>C(JHBQH-L2_=7TK&I4=27,_D>S&*B
MK(6H*&S?ZLTT.&YZ+X8_Y`\/TKGGN?*YA_'9IS*7A=5QDJ0,U)R1=I)GE]Y;
MRVE[+#<X\TG/%=*=UH?8TJD:E-2AL0]\#D^E!9)(C0!'E8(XY5">35NC/EYU
MTZ&:JPD^5'CG[27A/^TM$C\06BL9[?B50/X:WK+VU)370\C,*#<>;L>#R:EJ
M7B[4=)TZYD+)'MAB4=`/6O`AAX8:,ZD=WJSBJ8JKBG"G-Z+0^M]'T^/1M"LM
M+@18UAC`8*,9-?`UJKK57-N^I]A1CHF^BL69$2:!X+A%E@<89&&0141DXOFC
MN:VUNMREH^D:;H<$D&BVJ6L,IW.J#[QJZM6=9WJ.[,J5"--:*VH0:+I$%T]S
M#I]N+E^6DV#)-:SQV*J4U2G-N*V!4DJGM;>]W+S$MU[=*YC5:&1XP\.6WB[P
M[<:7=`>=C=#+CE#79@,?5P53FIOW7NCDQ6%A6C:>S/FOP[XCU'X<:QJUB8!)
M(P,1#'`![-7UU?#T\?3C4B['S^'Q4\NJ2IM7_K<ZCX'_``^?QAK<VO:]"?[&
MA<NV[_EM)G./I7MX6@DE?9(PPT)5ZSJ25[L^F@4"+'"-L*#"(.BBM)U.>6Y]
M'&'*@I%"4@&S?ZH]SV'K30X[GHOA?=_8\&]"AQT-<\]SY7,+>W=G<U:DXCA/
M&EB]OJ,=U'ND,QQM_NUO3=]#Z3*JZG2=-Z6/*_&_C^32+X:'X2L6U?Q$_!11
ME8O<UU4Y*G%NUV&)Q$K<L-6<:;R]\`ZPOB?XAZZM]K$Z$)I$#[O+SZCH,5%&
M;@W4J:7."-J3]M4EJ^B*U_\`M$PWEG=6LF@(\$ZE2K'/!K+ZS)7Y29XZ-URH
MY'X":3#JWC6ZO6@VV\`+QY'"'/`KYW.<?/#T.2.\MS?*(Q=64W&_8^BW8LY)
MZ]*^)2LCZE*R$I@%`!0`4`"L4=6'4&A@U=6/!?VD]"BM=8L=6A3"W*[9,#C(
MKZSAZO*5.4'T/F\YIR:C5>RT.OT[XW^&=#\/:1I6GV#F*&$"8(N!NQS]:^NI
M5H2A[YC3Q=&GJNWW&QH/QO\`"FJ2F/4A)8#/#$<5K.I0E:,4;T\P@W9/[STF
M!XKFSBO+"9+FSE&4>,YXK.I2]GK'5'H4ZT:FP5F;$UC!-=:I;16T>]E;+^@%
M#:2(K3A3HRE-V/44&$48`P.U<Q\:]6+0(H:W9M>Z=-"C!)"/E8CI51;35CHP
MM94JJD]CX^^(7Q&T?PK=7]GX*B)UR4M%=W[KRI[[3ZUW5ZW(E"#._%8F,+QI
M[O\``XKP7X#U#Q5+)J_B&:987.X-*27E/X]J^7Q^:N+Y*3N^K['=EN1RJ-5<
M3I%].K.D\;>$-!\.^&+FYL(3]I*8W/S7!1QE>O6A"3TN>IB,KPM"A4J-6TT-
MO]G!`/#%XPC.YICE\5CQ"_WB]#BR>G%8;GZMGJY(%?/'L6)%AD8%FVQ(.=TA
MP*+ZV1G*I&/F<]JWC3PSI`;[5JT!D4X=%.2*ZZ.!Q%5V4695,1"FVJDDBQIG
MBCPWJHC_`+.UB"1GZ`M@@^E9U,)7INTH,="O[9.4+-(V)(WB(WCY3T8=#7.F
MC:,HRV!%#I*F?F9"%^N.*?5,FK?ET/`=?O=2U'0/$'AWQ$Z-J-C*9K?=U*>U
M?64:4?;4\106C5F>#6G*E1J4<0[MZHK?"_P9H>O>%9+S44=KD2E<@]!6N88V
MK1K<L=K&^4991Q-#FDKNYO:E\*-%NU9;"1K=B/E9CT-<<,TQ"DF]4>I4R#"^
MS:M9]SFM`U_Q'\'_`!&+2]+W&DS'YH\Y1U]5]#7T^6YG"HKK;JCYB=*KE]7E
MJ:Q9]*Z-K5AKFCV^K:2XDM[D?(G<-Z5Z52C9<]/6)[6'J*K'1Z=ST/P9I,VF
MV+O=8\^8[B.ZCTKCJ23>AXF:XN%>HE#9'15F>4%``>E`'@GQD^#OA^6_;QC;
MH+9[=O-O(%'R3>^.QKBQ[G&B^0]7)*=.>+C":O=Z'.W=]9VVDKJ%Q*D-@$W(
M`<#Z5\G"#DU"*U/T&K5C04G)[;LX?Q]JUEXA\"W%Q8.&5.PKKPJE2Q48S5F>
M=CE'$X&<Z;NK'"_#SXGW_@[2I=/CMTFM9'W\]0:]G'933Q555)/H?&8/'^P5
MFKJYZ1/\<],ATM)(K$RWK#E3T4UXD,@JRJM2=HGJ5LVI<MX7OV/.-7\2>-/'
MQ$2-<-9F3Y8X055?J:]NEAL'@MK7/-E+%8F/,EI<[/3/@4QMXY=3OR9G7+*O
M8UQ1XCITZVL+P1V4\H4HWJ2U*'BOX+W>G6INM#N6F=1DQYY_"G3S^E5J/FC:
M+>A<LGM!RI2LP^&_Q)U7P]J<>A>+FE?3R=H:8?-$?KW%+'931KP=7#[F>'QM
M2A/DQ&_1GL]OXI\.S7`6#4HB001EAS7S4\)7@KRB>U3Q*J^ZFKGEGQ]T2.UN
M#XFCE*-=H(DVGAZ^EX:Q%24)T4[)'DYGAZ4(>UO[VQ-\%(I$\$R;EQNE)7W%
M8YK).OIV/7X>36'3?<ZBVUS2+N^>Q@NT:[4X*9[UQ3H5(14Y+1GKT<;3JU'3
M@[M&;\2])CUCPA<QW!"O:CS(VQSD5K@ZSI5E)=3FS+"0Q%"4?FCH/V1?#>H2
M^'[J]U5)%T[S<VJ.",GN1[5]O#$3C3<%LSX6CC94J4J4=VSZ:'2L#A"@`H`*
M`(;RU@O+9[>ZB66%QAD89##WJ914E9EPG*$E*+LT?*?QD^!OB!_$*/X7FEN/
M#MR^Y[;?S:'O@=QZ5Q3IT\+#FA"[/4AB:V8U5#$5.6/]?B4[+P9I&E^'=0TJ
MPDEFN)8RL@EZAL=A7SD\9.=959KWET/LJ67>SPKP\=(RZGF?PJFT*U\1W6A^
M+;026]PQB24CF)\XKWL;AZU>E[:A/E:5[=SY#`R5&O+#RBF[V/;]/^&7A#2I
M6:.R^U;^0TG/%?*O-\9*/*V>W#!4N9R4$F=196UEI\8CTRRBM4'8+7#*<YN\
MG<Z845&/*WH2DDDDL234V-=!4=T.5/YT6$XI[F%XJ\(Z#XLLVM]5M1!+U6ZB
M'S*:ZL+CJV%ES0=_(Y<3AO:P<6K_`*'F$OP#N?M):SUQ1:@Y\QQ@@5[?^L2>
MGL[GC?V3RVM-W.8^*6OMJ+:9X-TVY^V6^G$1_:"<^8_2N[`4/9*6+J*UUL3C
M:L:KCA*"N[ZM]6>L>%=-DT3P_9V<Q5Y!'R5^E>'4G[2<I]&S[3#8>-.C&DNB
MU]3R?X@^!;SPV[^(M*N_W!EWE=V'C)/ZBO<P6-C77L*ZUM]Y\MF673PM1XC"
MMZ:OR_X!]`?!+P_/XX\-V.N^)[=H[=?EC@(P+C'\9]JBED]JS<W[JV+K<2WP
MWLZ*]]KWGV]#WNUMX;6W2"VB2*%!A408`'TKW4K*Q\H2TP"@`H`*`"@`H`XO
MQ-X"T_5+B6_M5\C4"IVE>%+>]>7B\KIUFYQTD?09?G]?#Q5&>L#Y<^-'P9\0
MZ+/;Z[IT1O'GDQ*EJA+1OV.*UP-&K3I>SK:F&;XVAB,2JV&7+_GW-SPE\28]
M+MTT+XAVMQI.JVZ#9++&0'7MFO`Q^158S<Z.J?3J=F$S:-1KG=GU[,]%TF^M
M-8L?MNEW$<]K_?SBO`J1E3ER35F>VJBT\^Q:B0S'$;1_\";%2VEU*G)05Y#G
M@=,[FBX]'!HNMR8U8RV&RI';PF:\N+>"`#)=Y!P*(RY_AU)=9:\JO8\5^)7Q
M=M4@O-(\.DRALHUR#P?7%?2X'(Y7C4JNWD>/B\W@HM4M9=SB_A'X;BOM6_M?
M63(EK`=\9VG]XU>AFN.C2C[&.[-<CR>O6:Q<EI?3S\SWS2[+4-=N472[.1[>
M0[!<8^5*\*E1J57RTUIW/K,17H82#=:2373JSN=-^$MK>P0_\)2XNFB?/E(?
MD<>XKW<)E7LWS5'J?*YAQ+SJ5/#QM&2ZGJ%M;Q6L$<%O&D4,:A41!@*!T`%>
MTW<^122T1+0,*`"@`H`*`"@`H`*`"@#GO$W@KPYXHGAFU_2+6]FAX1Y%Y`],
M^E.,G%W0I14E9G/ZO\+-'O-2L+FQ9].@MN#;6_RH_P!17%B\#1Q5^=:]ST,O
MS&M@F^356ZE/QM\(]/\`$FF_98-0N[!LY\R$\UR8'),+A9\]K^IMB,YQ-6DZ
M?<R?#_P-L]*A2.37-0N=HY+MUKHKY9AJM3FY;+L10S7$4J7L[W\S'U3]G#3]
M3OY);KQ#J9MW.3!N^6N_V6'C9TZ:1Q5,5B:CLYZ,6Q_9D\)6[[II[J;'0$UE
M6A*:M%V*PU6-*HIRCS6Z,]4\.>"-#T+18],M[**2!>ID7)-84L#2A%IJ[>[9
MVXK.,57J^TYN6VR6R-^RL[>Q@6"SA2&$=%08%=,*<::Y8JR//JUJE:7/4=V3
MU9F%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%
M`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`
M4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`%`!0!__V0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]E=FEL+FIP9P``````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,C`T
M`#$P-3$U-#,Q,#8W`#`R,C8P-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(
M`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)
M"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1
MH0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::G
MJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U
M]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/[&_&OQ-L]&U/6%M(FO;XW<I2VM@JDQI(T4<<\\\D;Q`NA;
M,*.V3@@`"OD7QT_Q!^+&IQ6%_.UMX?@N60Z#I#[!=('PCZK<1/YLL+E%(+KF
M'<YC+,Q:O-/B+\4/%6M:KJEGX<\.V.GV'G2&/6]6NYKF^O\`?(9)+F,H+>6S
MY,H5&9V*A>@KWW]GCQ#;W5KIMA=6\9UF%8$U"1Y'DEOMA/FRR2,Q=2OS[(R<
M,2"01G/\;\0^(F&XDSS$Y+6K8BOEM7%5<.Z6#J3I8:O%5ITJ;Q52[JUJ*G:K
M+!THJGBU%*K*KSR@_P!>PF08G*<!0S!48TJSC#WYI2KTG."?-!)2C3J.$O9J
M=1-QO[K7*K?*?QW^(OQ!_9P\-0^(/!'AY-=U3RUT^\=K2ZN;#PQIL)\Y8M)M
M[8+<NP9E-PRR1K.\DDGWW>OSFM_^"MW[16D>)K*VGO/"6JZ)=:BL-YH%SIU[
M]L\H$&2%KB1UNHIRCP*F%=(V^1HWD"H_]!7[07P^G\4>'=0BTBWMFU*ZTV[2
MWB>.0*\\D0^RQB6*(DS%_*41Y^0%CW7'\>/QU^%7PZ^'>M?$K1_%^@^/M!^(
MB>(KF;P]XMTG5HY])@O]WVC4M%\1Z5=W4=W:QAE<V]TJ(@TV9BS(QBDKP,UP
M..X>Q=HX[-JM&4USXBA251SQ%9Q;Q-2BJ_OP?+&'U2A"I45*A!/"RIJ7)[N6
M/`YIATI87!NJG3IN=;$>P<(64E-SYE%.FTH*4URWFY3?*F?T\^"_C'X9_:F^
M"<WB/39(++4[_2!9ZW8I&[K9W4R+NM)0JPM'-:RQ$>64!8_+O&,GXX\5_'CQ
M)X!\"S_"FVGGAU6'7&M[?4[:0^=_8D+":!$D\[]TXF5"TA+?*OS(0<5^4'[`
M?[2/B+X2ZSXB\*W]KJ.HVGBVP!B<-/<:3!+;-+:6]_=^0)3;_:%"3K<?<\QR
M'>1P8S^A?B;X@_`WQ!X9GDO_`!/HO_"?S+->*;[41:I:Q1J&B27YD+^:2514
M&YGVC!!(KY+-\TQF%QM2CA,;/"YJ\KQ6%KX^-:"I8_!UZ:<82<7&I7KRNZ5+
MV<'S5*,*U3X:D8>OE^6T84$L3AG6P7UZG*A";M.C-0IR4ZDERN5%4ZJ;5^6H
MIQ=M%;FKCXU^(9YYYIM:+32S2RRLR7A8RR.SR%BK[2Q8DD@8)R1Q17SA+X^T
M5)94%VL@21U$D6HKY3A6(#QY3/EMC<F>=I%%?.)<0-)^WS=WL[NK73=^5WLJ
MB6M[Z)+7;77T7*C&3BL'A+)V7^RX5Z)I+7V;[KJ]]^W]$4'P?AU.VDO1%##]
MLA,P81-`H61GQ!#D;>/-#DID[B6'!Q7SAXJUG4?@CXNLW6-2\CO)`R2;6N/L
MLP/$A^4HS2C*%5+*"-X&17UE!\0#_8]II_VAL11VT<1LQG8VQ`(VBFZR`CYG
M5MK<#->0>+/AS:?$'7K/4/$.^;3K3S&$"S^3(\)5@\<JEU(1I%1BJLP.`2<C
M%>]Q)A,JP.%AB\EEBJ.9QG[6-:I).$9N;5:]-1CS.]ITZS<H13J)JJO9PI^%
ME>.J<WL<UM4P3IQA*E!-SERNT5'FLMU&S=G=*^CN>5S_`+17Q$^(,DFA>";:
M\C\0WLYC6]O+J--/M3""7C>7RW:W>.2)?+8,QVMMR0>/F;Q?^PGI/Q=\0ZOX
MI^/6M75SXOU7]Q%_PCDB0QV8F<*][<RA%BN+MHT5$>4,X5WPRB1A7VCJOCCX
M>_`-%CTO1+2XEE>5I;"S"-?3NDCD^2#YTC2%68/@JI'.%YKYQ^'_`.U?K/QN
M\7^-SH]CX;\&Z+X/U"*VGCUO5[:#7[^2X.8TL=+G?RG>W5]PE#E6D,2;=Q*U
MQ?VCB?JN#QF*QN9X_&2J-TL+"C5I8:G3]V4Z\XU:O*W*ZJU*K=X<LIP3=CNI
M4W^^6!PU#`X2<H4_;59*6(E*5G&GSQISY(^[S-6E91_B6^+Y[^('[`WPC^#O
M[/\`\7_$'AK5?$K^*XM!U/['XHUJYD^VQK;QM-9Z/96EKF`B:1FBDFCC5I@T
M:G"*%'Y#_LC_`+-7B;XT?%'P_P"%K;1/$VFMH=Q<:UX\\47NI-'X=C\,P7"P
M10BSEMA.-1AA$GVF#[6RF[,(14C+1G^C7]I'4O'-K^SG?_:8C+/K>LV^)A;Q
MRM>6%]=6T5M%%`K!F:24K+"``22`<@D5YY^R'\*O$_PUT_QEX[\;6#:++XE\
M-&UTS3)%%M/'%`DD\MUJ.X,QE&-J@D</LQ@X'O<,8K,,[SBO@I95BZ.6^QP;
MQU:5.6$>'G3I1;IR<&HU825:-&C7F^>4(SK4DWRIY8_V>$RJC4>+IO%+%5?J
MM%5/;RE2J8F%&4U"W_+J-!MUG:R;2=E$X.;X(_`G39I=.C\-)>1V$CV27DB+
MYETEJQ@6YD^7[\ZQB5O]IS13KM[I[JY=40J]Q,REI2C$-(Q!90A"D@Y*@D*>
M,\45^E<_#L?=^J\/KE]VW)'2UE;7$O;7KWU[?.6Q#U^MXC6SUE6O]GRWV]=.
MY]M:->Z-K*6FI6MRLVG0R17"JEP61C&H6&,JW*AV)=@1@A@,?*!72>,OB3I_
MA;3;J2[6."TL8!([12M-(5A*S2*8D4RMOP`S*0I4D$$&OSQ_9U^+TMAX@M?"
M/B6]6YL[\G^RVN2%M_,4O*L,9,X>0F20H^0PC1$8@`U]]7O@6R\5VTDR6EI=
MQW=OYB6\S+<LTK,25BN%B+11,@*QR9,3+E`Y;@_E>$Q4.)J-/$X"C'V]-/ZQ
M3K8>$VI2IT6YK#S;C[*J_8U,/14[3F[5$XN2/8Q6!EE&+>'S&5Z<)6BZ<I*,
MX<RM'VJ]Y6TA/W79W5I+4\9\-?$[X6^(;UO%OB"Z\.Z+)--<VMK=^)-0B"LL
M,C1W)MK6^QY;ND>2>.&XZMC\\?V]/`WPN\.:KX'^*GPA71XT\2:O>P>)9_"&
MKI?Z?>206T-[9ZA>6]K(UO9RI=0.KI$W+1!SB0M7T)^TK>_$_P"!YT#5(O@Y
MHVO:4]W.);RYTJVU[1I+&'*30M':Q.]O((RL<BD++"Q=I`":^'M#TWPS\>?&
M,=I\/O!WBWX?:KXJUVQG\5>$M)=[WX=ZF\X8SS"PO,W.C7.))6U&.T\A)WC,
M;?O$<UXTIYU4G2P&*PM>6-AC:4?J]6C7A7Q-.I",W"=+!-U)5:ZJ1AA*$<-*
MC4J<KJXB4*<JT/?PE'!T55QRQ<:>$GAI\\HU(5(1E&G=756$7S1MNY)R5W=7
MT_17]G^+XK?&#P5X9U;X@:M'-X'T1M*O=.MY[.:\GU:[TN6.?3EMY&2-([>V
M>`1W89I"A4@,1@U]:_%#Q+%;>$;Q(D22>>*:R,:3,6,P7=*@M9-T@4J2.#SP
M!DX-:_A7PQ;_``Q^'7A_PKI&QHM&TBWM(_-55C-Q"(PS&0)(S`W#NGS,KEUV
MM/(_)\#^*6MO*^GZ=YCQL@EG-N\L3(UQ<E=L\C!O."$3!T+C85!.=I)K]XPV
M`PW"F0U(TJ518RLL++&QKXBKC/;YE4A"C:4JTZJC.A>%/#TZ4HTZ=.E2ES2C
M32?Y].O4S7,*?.DJ:YXT(QC%*CA8R4H4XJ,8_%*;E4DW>=2I*5HWLO#6N)"S
M'RW7))V^5=#;S]W&.,=,=J*OM'<AB#Y1.3DB>WP3GDCY^A/(HKX)1PZLI5Z%
MU9.\Z"=UR7O[SL[IWU?74^B4*6GN5^G_`+;_`'?/3Y=F</\`$[2M+TKP#\,]
M6TO3;#3=575[(KJ=A9V]GJ"EHH=Q%Y;QQW(+9.[$G.3G-?IY\$I'ET_09)7>
M21K.VW22,7=L1<99B6.,GJ>Y]:**PR7_`)*'`_\`8NR[_P!0L,+-O]Q?_87B
MO_3]0]R\26]O=Z/KD5U!#<QHE[MCN(DF1=PFW;4D5E7=@;L`9P,YQ7Y(_LP6
M=I'\;/BZ\=K;HUMK1-LR01*UN?M%V,P,J@Q''&8RO'%%%?3U/^3D<*_]AV9?
M^H%4\JA_R3F:_P#7[#_^G('W3XS=_P#A'O,W-Y@^R`/N.\!KF$L`V=PR22>>
M2<GFOC;QU+(=>U#,CG]W9I]]ON%-I7K]TJ`I7H1QC%%%?2<5_P#(LP__`&$4
M/SB<>5?[VO\`"O\`TY3.2).3R>I[GUHHHKYVG\$/\,/RIGUL=EZ+\C__V0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;WEA;F1P8RYG:68`````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,S4Q`#$P-3$U-#,Q,#8W`#`R,S0S,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6%``$``
MU2$`_]XY____````4E)2K:VM&!@8.3DY<W-S4DH0K90IY^?GQL;&C(R,.3$(
M&!@`QJTQ<V,8Y\8YC'LA_]Y2<V,QK9QK4DHI4E(YC(1*.3$AK9Q2QJU"K90Y
M>WM[C'LYK:5[C(1C````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(?D$`0``(0`L`````$``0`!`!O_`D'!(+!J/R*1R
MN00X'X*HH"`U&*31PP#+C3*_1:<XT>@J`FC%X(QNIP,$04-,%T_`Q'H=PG#[
MVPI4`P0'!P1M5`]Z=$F+CG10;G$0CXZ1:`L"AVY;1Q.58@B;`YD$`W-ZHFT5
M=*IH`P5_`GA#%VIN!@-_:(0$"0`1"1`8@P8`";J[DK1Y3@@0"0X&#*9H!V<#
MS-K,5%,#@P0,"FH"N;!1#MG;8&-8@UWE#`-]"_4*!`H,!]VSZXUZI`YMV87/
MC0(#FS`)D%"I":@ZFI1A*D"QP`$'$19)2!9@@`,(2AXN2A"1`0*1>D@N:".`
M(Z]^3#XE8+"RC0$V4PI<"5C``Z3_!(H>(3"GSE\!4P4:('"@[QO%H`C\26UV
M[&0P!V40:$5@H<#4KT@$A>@GQ8$$!%6*@OW"+\JW;U=RPJNRUH@8*%+:PF,P
MUUU=(1#=OBLGL8VI0EL:9-0S50^$*5AJMEF`\`]--%>".M+VZ&:`>H4GQ_+C
ML6%,D4Q#[])GMHY6:+^<)/F$4HP$`7^VF%W\,"*:EI_'&@A3NTZ#30=.%G?2
M@.,!W'Y@#EF>;EP4OKPA:9E'H17'.`E?J45"&\"#,N`,H6EZ;T!L`!30-%]5
MY\%9MZ_\`1@DF8"!S^$A<@$%(##`04H($:#@@@P2L`X$A+`1`#4!_->1&`DV
MJ.&&&NKG_XPS`OG'R5_;F"?``?U-DU`N)+;HXE_##3&>`1:\2(M>5>A$P`):
MQ,6%5S8:@>,4!E!$"!4523%>B[*%X*,!6A@91SG/]=62BW0X`,^0YU@98UUT
MW.;6E'/IM$440S()##127(.%?Y(5QI<<=8!5AY910,F72VKD$N!GB3QRQSJI
M=!$G)G\0,-H6E#Q":!T)%'#&E`2%MU)"!V'D*&=ZQ/<*=*H1XH<!#IB&AU"'
M2G3/`>(8)(!RFWU1GB,1C":G`@?D4L@9:CCP7JPAH22!K<J$H\`"%2&@F1BU
M#A`70PX5UX"%?E`610,29*#4LG0<UP8L5_RS'$FDO;H<J`$(T/\!)U<"MIP8
MZ!;0:'$24!N'A*]\.6MQK@B076TG?DMM&M*%\.X#I!A"Q:_U0?#,'L3ZU@8#
M0!(G4KT=F:*)`?/68<H@K(1R@&'HHE&QN)">Y<`HI7Q#1S`?K$R?&-/.X]]<
MIQXS\F0[9]P>-!)0H.`!#UA`#0,=NS;*.A-$,(@;A6#V31^8P+I!!0P'DP!)
M?6TSP2!4!Z!`R08-TL#6+_^"3*C;(!!`SQWAV`!%5BA5!A<(W&VE%]IH<`TU
M"D)9#66A$/76X8@G?K@_#VR-"@(#;$?-`J8X$.07H?RB"MC7Y'=Y$R1=1HYZ
MUG3TN4,)H-423;A2N4`@IZ,.*P(DT4$&4NRX;Q,$`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+WAE;F$N9VEF````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-S0`,3`U
M,34T,S$P-C<`,#(R-38W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`
M,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`
MF9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S
M```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S
M9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S
M_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F
M,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]F
MS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9
M`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9
MF0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9
M_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,
M9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,
MS)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__
M,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_
MF9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____X
MOR0`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````A^00!``#8`"P`````(``@
M```(_@"Q"1Q(4""`@P@/%ES(D&#"AP@;2C28<`6`%1@33F3X$*-'CQ$W.JSX
M\:-"D10M7C29,2,`E-@.JE0)4:-(F36='-3Y\.9%A"1VYG'BA-30H"<G/D1Z
M\)G39Z1Z;ORYDP11G7F>Y0%@%>G4GSJ[!B7ZC"O7K3X/;ATZU,E0K631?A6:
MA]134DZ>0I6K%*A;4G;WV@6,]^57BU;SU+7[UZG1I`T1(G:K&+#>O9`YKN1*
M0G'=/$]"9RUL6*),E8D7>W:LTV)?ER0Z+[Z\]>=KBRNZ5M9+VK7IS;FO-H;*
MT_;OEE8I"R].M71!R0=3?U8,?69FG#0I+WZ,'<`3`'6=6N.,#H"R9:B207X/
M3[$YB?7GG=9>B1A^RH3OR\=WRA-D_KHQU13;=_MIE5Y]`$35'$)7Z7?9,\5E
M1`TUZ25$E!]^4(/54UD9")T3&>:$X8@4%B68AZ<!$&)````[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O=F%M<&ER92YJ<&<`````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,#(P-P`Q,#4Q-30S,3`V-P`P,C,S,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````_]C_X``02D9)
M1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!
M`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#
M``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H
M*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0``````
M``$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#Z-^%7[%'AK]M?]I+]GM_V
M@/`5]XR^&'["/P9^%GQ6^,NJ^)=-'A:'XI_$W6_#>E>'/A9\(]<&L*-2AE\1
MZGX9U#XH?$'3?$B&XO/#BZ!H-O83Q^,;2WO?V#_;"\:>$/%GQ/\`V7O`_P`<
M?&WAGP'X\^*GC%O"W['UCHES=>(?$'A_X@>+?!>L76A^.-4\'Z?I4.D6<-E=
MZ'HS^';CQ-K5Y%J.K7$^DZ7H7@^>33XY/3_A#\!]7\8?"C7K[0(;W3V_:._:
M>_:A^,GQ.>T@O[2+6M7UWXHZ]X0\&V.H:Y]HCU#3M(T[X:>%;33=2-K(+YM-
MLI;+P[-9ZGJT#M^??_!3KQ7\"_V5/'?[#_@*PTFP\8_$/Q#^W5^Q[>>./BWK
MSVUIK7A^YTCXE>%K?P]H7AV]TF(:?X.\*C0H]1:P\$:(;71=%T":))H(UTFR
M6,`_/RUM_&'[3_Q\TOX0^(K;XX?\%-_VN[OPZ-0^)GAWQ%X]\0^#?V//V1]%
MO=2GMXM"^.MMHI\`^&F\4:9/;:_J<?POT^XT2[N8+FST_6;CQEJ-Q.9O9[#Q
M!^U+_P`$[O'/@;X+_%GX%?"WX/Z9)%JWQ<^"[_"N74?&GP4\8?$GP',GBV/0
MM'FDTRW\1>'_`!,_A$^.=/O8+W1[$7-A#:G4]5-AH6AWD_ZW?L[?'/\`9!_8
ML_;=\=?L(WQT3X=?'']K/XD?$W]H'0;V2W%O'XQ\1:GK$]KX5\"W>J7`5/[;
MO_AUX=T[Q%X!ADF;2=5L])\16#1Q:]'#%<?9_P`3_@W\*?'7Q`TGX%_'/P?!
MX\^'GC74_$'Q/^!DVJ?VA)=?#OX@Z1HFL6OCWP[IFLZ?-'?Z5;#0]9O?$?AF
MUNIS8FUU7Q/X9AM_[(\-Z7:``_`?X/?M@?#%?V@_VUOVU_AK^Q_\2OB7\"?@
M/J^K6/C;]H'4M7O[5[+4SJ\^M_$&/P5K6L^?XM\5^(=%@*:GK6GZ"^G?#CP/
M\/1;^'=/MA-,1K_[5_"K]H;X(?%+XD?%#0&\8^$/%?[/OQ@^'WB+Q)<Z3XH;
M3+SPQ#?:9H\.J?$VZU"76&&GP>"_B'\,_$6A^*-1TW4E&D+/X:\7:S<6^DPS
M36MS]J?#7X=_"7P7\,)OA!X.\/:"W@;POI%[X-\0Z*EGIKV6LNVCPVWB"/Q&
MUK:V^GZOK.L6=RLWC"=XIOM&HW%S;W+S2Q2K'_*S^P5_P3#N?%GA+QOX5^)_
MBBXU/]F#XI_'7XA^%?@;\*M-UR71Y/&O@+PG/XC\"0:]J7C.QU33O&LOPETG
MX4Z3:WDGA_2;J*Q\1^*K;PEH%_%/I2K`@!]8:/\`\$PO^"4'C;2-*\9_#SX\
M?&_2?`'B[3;'Q/X&TKP7X^U(^#M,\'Z]:Q:KX9T_PF;_`,)W=\?#-EHMW96V
M@F]NKF[_`++CM?M%Q--OD8K^@'PCX!^%GP^\*>&/`7A.R\->'?"O@CP]HOA#
MPSX?1KF-="\/^&M-MM&T;1UCFUE9HUTS3K*VLE251(H@"R`,"**`/#/V%?&)
M\4_`O7])OY;<ZW\*/CC^TG\&_$<OV9;=;>_^'OQM\<:;;3S0N6<+?:#%H>J2
MLY'VR*]M[A]V\.?Q]_:@_9!\)?M5_&[P=X;\1ZMK5MXK\6:YXF^(6G:^OE:A
M=>"X]9UBVL?#/B:PT>\\R.XUGPMI6I6]XVHJ(KJT98+6UF^W76GM!]E_LZ^(
M$_9]_P""C'[57[+'B24S?#+]M;2_^&XOV;/$<5V\N@:QX@GT+PK\._VG/AI8
M:M`Y@;5[6_T3PA\3M.B@F^U77ASQCJ&K60$=G<&+Z'\&?!W2KG]K[XA^-)I9
M9=-\*Z!H?A30[7RH_M$-YH"^$_&XL9Y&!,UM$/$ELUN<E6B,+OB8RD`'\U7[
M>/\`P3)_:G_X*QZ9\,OVS_A]XXL_A[^V)\*9+ZVA^$NNZI:^#-#USPIHWCSQ
M!XT^"GB3X9^+]!^RZGX?U+1]`MK6XGO=:&K^)M-\9^'=4TO4UGTY;LO]@_#G
MXX?\%2_'OA/]F'P=^W%\`O$/PT^+OP;UCQ'JOC?X@?`G6+35?%'B32=9^&NM
M>`_!&LZYJ2:GJ'PX\#?$+X@ZUJNJ6-EX.E\0ZM%K_B"#1=;FL_!NCZSH.G7/
MVCX*\11?"SXZ_`+Q79:*-5\/^`O%G[4_P(^/&LM=2R:C\.O#WA+XHZA9_"[Q
M7<Z?-+]@T_P)967C<2:UKBK9?V(/$HFDFDL[NX6+V;XS>$-7TZU\7_M-?$WX
M[>*/#D-K\8?`5UI?A'0/BVEO\)+3]F;P#X\L+VZ\-:OX"MKJ]\.^,/$GQ!\$
M?\)7XWUV>PT[5O$?B&>_TKP\+A-'T&VL``?ST?%S_@N+^VG^V-\9_AU^QU_P
M2N^!'Q.^!_@G4O&&G>$?&WQ/^,7PPGO/C;>Z?::]"/'][8^&+]=3\'^"--TZ
M:35M-\2:YKFHZSXCOO$MQ?3+)X=L3-<Z5]O?L(_M1V_[8_\`P4Q\:>&/@7X2
MU3PE^QE_P3F\/^'_`-G;X8:5?VD%K?>*OB'XNU[Q-HGQ)^(<UO(9Q;:5+=>&
M;C1M%-G=S/<Z=IK7["SDU.YT^V]=^.OQFUSXN?LY?$S2_P!ESP5\2?V2]"^-
M?Q1D\#:3XT2]OO`_Q&\<>+-=T&QUGXB^-/`^E0O;:OX'^$G@CPUJ?B#Q3XB\
M;S_V;>^)_&%Y9P:';0"^9I>C_P""*W[,_ASX&>&_C?9^#["1/#M[\5OAK86M
MU#)/J%UO\+^&_%'BG6KK7-5U>1[^\U>[U+Q*!JVHW5Q/.U^TMPEP$ND#`'H?
MQ<O/$`^*WQ.$-]?K"/B%XT$2QQZMY:Q#Q)J0C5-MT%V!<!=H"XQ@`8%%?CU\
M:OVH/CIXH^,GQ:\3>!8/&5_X(\1?$WQYKO@Z^L]*UQ[2]\*ZOXIU74/#UW:M
M#F%K:XTBXLYH&B)C,3J4.TBB@#]&?AO^S/\`')/V4_ACXVMOB'JWBB3X7?$'
MQ/\`%'X-:RGA_4]=^)?[&/QI^''B/Q'X(U3PYI%C`NH^)OBA^SAXWCLM8\$_
M&?X3R0GX@V?A/7-6/AFU\4ZC<);:1^IW[''[0?PY_:8M-<^('A34M`TCXC^'
MM=U;P]\<?A0FJP:IXB^'GQ#?2O!EE=VKW5IL;5/">IV>BVNM>#?%LEB]MXI\
M.:YI4T,/A_6X->TFT\4_X)N?M#_%CXJ?#WQEXD^-7PDO/A[HK:G-XF'Q4MY-
M+@^'7C3Q6-8U;PW\1KOPO!!J=OK6EB]\8Z3JNK75I-I0@M=0U/6XGG>"1%K[
M_NO@O\'M=\0V'Q$'@;PM_P`)C;V%]#;>./#EA;Z3XCFT_65!NP/$7AR.SU._
MAG,UQ-9+)>SPI)<7$\86:6<D`^*_A?\`!#X3_%3XL?M/Z%\1O"$6JGP/^TAK
M'C.S8ZYJEG%-+\1?AEHUA>P:NNE:O;VE[I#6=FVK1Z7J%H@CU,Z1?7$;7MI#
M/7R+?_L]6OAO4?"Q^"^L:UX3GOM-TJ'5-.77K?Q'?>*-3^,'B[Q)X9\#_#Z5
M=6GO9?#$-]X#L6^(?Q$\5I*?$NE^'?#3W/AF73]3O[VZN>[?Q-XM_9K_`&S?
MB9J/_"=E_A+K?Q%\'KXF\'3ZWHWC3X^?$'4E^#=E9^'?#WA+PAJ%]%XGU_P7
M/<:G'KCW/AJWU7Q9>ZQX%U?2W0V<#V\WN6F_&;P?K_QOL?BU?>'?%/PQ^`/P
MR\+>(-4U?5_%'P[\0:*VO_&3QKHGA33;#5/%T,6F/+X%D^'GPFLY-+,_CBXT
M.YL+?Q1:V]K9V.D1V+W(!O\`ACX;7W]J>%O!ECX9N4L+&TU'1/!4.IVYMHK;
MP/X<5]=\0?$'Q,N'?3M9^,/CZ[\/Q6NFR8N%\)RSV-]YLD5['7E7[0VH6'[,
M'P^\`_L1?LR7]P_[2?[9'B[5?#?@I8HQ=W'PM\"_V7I-I\<_VD?$45L`=-\(
M_"GP/:3:CX>CO7B;7OB#K/@_PKIRS)J&J+%ZW??MC:9XI\.ZKJO[&?@'Q-^V
M5XW\=W,:^'_%7AF(^"_V?K*RFA<:3>^*OCIXDCM?"/\`P@>D6[7=]>R?#Y/B
M#XMO9+K4[O0/"VIZCJDS5T_[*/[(GB'X4^-/B!^TM^T!XLTWXQ_MB_&?3M,T
MGXB^/M)TN\T;P1X"\!Z1>'4?"OP&^!.AZE-))X<^%/@S4IKF[OM6O_+\4?$G
MQ*M[\1/%EO;:EK-II6D@'U9X&^#/PP\!>"?!_@7P[X)\-P^'_!?A;P_X3T.*
MXTC3KZXBT?PYI-IH^F1SWMS:M<7DR65G`LMU.S37#AII6+NQHKO/*TD\R6UO
M-(?]9,;'S3*_\4AD$#"0NV6+@D.3NR<YHH`^)?V';&RD\`?'K0GL[5]$L/VI
M_P!H31K'1GMXFTJRT>X\1VLMQI5IIQ0VEOIL\M]>R36,,*6LLEY=.\3-<2E^
M3_8;U;5)3\1O#LNI:A)X?\,?$7Q]I/AO0I+RY?1O#VE:?X_U*TL-,T/3&D-E
MI.GV5J!;6EE806]M;6_[F&-(_EHHH`Z#4O"_AGQK\,OVGM3\9>'="\6ZEX>\
M7_'R/0-0\3:1I^O7VAIX:M]+N?#B:/=ZK;W=QIB:!<P07&BK920#2IX8I;$0
M21HR_,GQHOKWPC^Q[^T1J'A.\NO#%_:_\$Z?V@?%]M>^'KB71;NW\6%O%LY\
M407.FO;30^(C.B3'6XW74C*JR&YWJ&!10!]\?L::%HGAW]DK]F31?#^CZ5H>
MC:9\`/@];Z;I.CZ?::9IFGV\OPZ\,7,L%E864,%K:0R7#-/)%!%&CS,TK*7)
M8_2P1`00B@CH0H!'R[>"!Q\OR\?P\=***`'Y(Z$_G1110!__V0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]S=&%N+FIP9P``````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`W-30V`#$P-3$U-#,Q,#8W`#`R,C8R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#_V/_@`!!*1DE&``$!```!``$`
M`/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````````
M`0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q0083
M46$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7F
MY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)
M"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@4
M0I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I3
M5%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U
M]O?X^?K_V@`,`P$``A$#$0`_`/TA^%__``0\\0^'!#;:/XX\#Z=K$N)==UG0
M?"_B7Q-XKU^[DAC6ZU?Q;XKU,:%J.N:I>8(OM0U?6O\`2)762*&$2>4/HY/^
M"'WC&4R32?'.Q7A2(C\,K:5N%P5Q_P`+2A@4#&!MW97&]BVYC_1;H^D0Z7:0
M6L"*J+&!/\N3<3`)OGE9RSEB5(52655.!@``?&?[3O[5_C?]G[XX_LE_"KPI
M^R9^T1^T'HO[2OQ!U+P)XO\`BE\&O#>HZW\/OV9],TS5O`M@/''QQU5;:71O
M#OAJ]L_'>H:[;SZG>Z.]SH7@+Q?)IEUJFNVFC:)<?B.$\$N'<1"%;/Z^98['
M55[2I%8ZI[.@U92IIMR4G=WYJ:H05G^Y;LX_D^/\"/"3$8R=5\.9CCY1DXSQ
M.<<4<28S$5]4U.+IYI0H8:/>A0P\8.^O+:Q^/US_`,$:+S3+HVMS\?I[2X:,
M'[/+\'KV%6#-@O%-;?%>XMYX5*%1-$TD9)Y8';NKM_P1C^(%[;,?"'QAT/6%
M1G#MJ7@S4=!B:155CMGAU[58&R.#F0S!E`90AC)_HM^(MA:3^'Y+J>.2*6PE
MLWMWM8T:X1I+J*W,<8+Q(8W24B2-G$;!%)!*KCYW_;!_:;TS]B7X&77QAD^!
M_P`?OC]8:7XF\*^'O^%8?LQ?#6'XH?%*_'B/5X-*_M&U\+7/B+PO;'1K"XN(
MY]3U6XU:!+*XFL[()>2ZG;VTOFTO`G))9IB(U9XB.4PA"=+DKRG7DY-IT^:H
MMTHIO[.NEVV:8OP"\$:V#I1I<'U:./G-PE&GG_$B@H1Y;33_`+6>LF^VC6O1
M/^?3QK_P2%_:]\.QSS:#8>!O&,5NK2HNG^+H=+OG=78*JVVJV\(0J521IENH
MA&"SQW=NT8N8_@7Q_P#\$P/VU/A]J6O?$[X9?!:Y379+5?\`A*?`EAXG^'NJ
M^%/B%=E8K0SHGA+Q3JNI>%?&"P//-;^)[/0G74[A!8^)[/4K2222/^['P[J\
M?B?PSH'B&/2];T5-?T/2=9CT?Q'ILNB^)-(35+&WODTW7M'N6\[2-<T\3BUU
M/3IV\[3[^&>V<^9"37E_Q.\*7B6=WXD\,6FFCQ)%8W$*+?R7UCIU_=3O9VVG
MG5=5TR*ZN]+M(IBL6H:A;:=J5U;6-Q=W\5G?I8R:?>&:^#6!RG"UL7D.-QU1
M<C>+R[%2IU:&*IM).\6E'FHJU:/-)6E3C9W/(RSZ./AU'$RI87'\39+#$J=.
MI"EF6%Q^7XA5$XJ&.P.89=7CB()-*F^95H5%3J4Z]*K%5H?Q5Z7^S_\`M,ZE
MIFG:C<_LM?M':9<7]C:7L^FR_!_Q0\NGS75O'/+8R/`M[`TEH\C0.T-Y=Q,T
M9,=S.A$KE?U+^!OVC/@-X]\$^#_'.E^/=#TG3/&?A;P_XLT[2O$]W#HWB73+
M#Q%I-IK%II_B'1[^[GOM*URRM[R.VU;3;R::[L;^.XM;B62:)W)7X\^#Z',_
M]GJ+7;V.&:6L=-[O9?TT=K^AGP(VVN+<V2;NDLJRJR3L[+]P]MMWZO6_Z3AB
M`N#D=QU'X'K[_KWICA2[_O)-S!``K8"C';;R0PR?FW!224VDDGQ31O'^H6-J
MMO>VJ7R1!4BE6=;>78J!55Q]EE4E=I`8'<P()(Q@W+[XCWDR,EGI\5J[@AII
M9_M)7(P"(OL\2M@=074'VY)_JFGQYD#P\:ZJ5/:\CG4POO>TCHKQBVN3F3LK
M*235W>Z/WJIPSF].K*FJ4?9N7+&L^5QMTLN;FNTNL6]UMMT7CS6H+6SM[#9;
MW-Q<W$,K6TJ0RAK>!FE)"RB1=[2(GEML.%5\$'D=A:20ZE!:WUK<.(I0LJR0
MM$PF0;OW4Y,;@QY:0;5*D,?,1E<*R_,US+<W5Q)=3S&6>3+-+(<F1B<\H%VQ
M*<L<)NP<#!ZC>T'Q-=^'6*1J;BPD8>99O)RN!Q)%,49E8.Q)CP$D``+*>GRV
M7^(D)9OB:F-C.&78B,:6'497EA(QDOWE2*5W.2?O;WLK;._N8SA.<<NPRH7G
MC8-U*KY+*IS*/N)O9QL[:I:ZM+5?1BY50JA0J`*%`P%"@`!0.,`8],=!P!7,
M>,957P]J<<RN\5Q:S6DD:(K^;]H7RE1R\L*QH[NL;R>=$P60K"WGM#CET^)^
MC%5S9ZJ6*D.L=M;LBD(2062Z.Q6(V(2`P)7*KFN)\2^+;CQ"%BCM9(=-"NOV
M66;RY;I95$$RW;I'*1"L+S,D&'2:3RU=HP-Z_1YMQMD-/`UUAL7+&U*U+D5.
MESQG#GLM.:*6E[R=]KK8\;!</9G5Q5%5\/4PU.-12G4DX-6A[RVD]VK+JGJS
M^--O^"?'[>/QQ9OC5\-]+\2^!?AW\8"?BCX"\$ZY%XITK6O!W@OX@'_A+/"W
MA76-+6S`TW5/#VAZO8Z1J%@`!9W=G-;CB.BO[!V=I&,C#:SDNR[B^&8Y(WE4
M+X)QN**6ZE5S@%?BKS.FW?ZK7U?\Z[Q[_/\`'S/TA82=E^_I]/\`ETF].7KS
MZ[;];+NRKOD4E0,IU!^4$G^?<]J^2_VM?V[_`-E7]A+PGX=\;_M6?%K3?A9X
M>\:>(AX3\)O=Z%XR\3:AKFOK92:A+:Z9I/@+PMXLUA8+6TC:;5+^\THV%C&U
MN3<^==06\GT1X,\;>&/B'X:T;QCX)U[1_$OAGQ!9K?Z7JNE7L<\-Q;R)'(F(
MF,=W'*D<T?VN"[MK2YL9G6UN[>*<[!^<'_!4_P#X)<_"[_@II\(M)\->*/$&
MO>`/B]\+[/QQJOP`^(^DWK-I/ASQ;XRTS0;75=.\;^'I-'U%/%/@#Q-?>#_!
MB^*=-LGTWQ!!;>'HI?"6MKJMS?Z?6.5?V=B<5AECL0_J-2HHU:^%@ZCC=7NE
M:=DGNVI)K2UWH\1BO;8+V^65</BIU(J5&5*O&K&:\HP49-;7:DNF]U?P:?\`
MX..O^"2L%V]HOQ]\67+Q-,'\GX'_`!MPRP3/;2A&G^'EFH=)E(^8E64$J&!!
M'VK^R;_P4V_8=_;EU/6/#O[-?Q[\.^,_&.A6D%_JW@;5])\6^`?&5OITK3J=
M2L?#GQ%\-^$M0U_2[1+9I]8U;PPGB'1]"6>W_MG5-/>YAMH_YEOV9_\`@TXU
M&2/Q!??MB?M+V5E?237MOX/\._LK6.I>)].,<LMI=6OB+Q-X\^+/@WPP\-W=
M1MJ!7P-I_@.1?L_V"_A\>W"W,EK!Z?\`\$Z?^#=+]I']D+_@H5\+?VA?B5\;
M?@KXQ^!/P7USQ3XH\-2>#I_B+'\3?'.N7_@GQ'X>\$E_"&J>`E\*^%'TG4=;
M%[XZDTKQ]XH)TK3KK0]-N=5N+J^@TC[K'Y/P`\-B?J6<XF&,HX>O5P[J4J;>
M+J45%JA3Y8I2FF[RM=N+5K;OY_#X[B2E6HSK89*$VXSC*,W9I:N,>;:ST3OL
MUL?V$1.LD,1+LT3)&ZG<XX(!3'(8#IA>`!P1C(JR`JC(P-P')P<X^N2.OXYY
MJJ)5D!;<@.UII=KB2-(XU,UP\<T89)1'$LCQNH"2[5(9%;<OS5\=?VJ_@O\`
ML\"S'Q`\337.OZA;O/I/@3PK;1:WXQUB$+"[&"-[RQT+2(5BNK6[FN?$NL:1
M#]E$AL7O[I1:M^:8C%8;!T)8K%UJ=##4E&56K7J1HQA!R4;RG-.,9.]HIIN4
MVHI79[F,S'`X!8=XW$>RJXR=*CA</3I5,1B<1B:\HTZ&'P^'HJ5;$U\16G&C
MA\/AX5*]:I*%.E3J3FHGT]MN&^98+AE;E66VF964\@JRQD%2,$$$@CD'%%?@
M'J7_``5+^)KZCJ#V'PL^',%BU[=-90WY\57=]#:-/(;>*]NX-9LH+J[CA*)<
M7$-G:133!Y([:!&$2%?!/Q5X$3:_MS#Z.V\'U2_GMU_K6WZ9'PH\4IQC)>%?
MB8E)1DE+A*K&24E%VE&6-C)-<VJE%235FDW8_,JP\<>-?A_J6F:YX#\7^*/!
M.MW%U;P3ZQX1\0:MX;U6>">14FAFU#1KNRNY(ID1$EC>9DD5%5U(4`?UY?!^
M66_^%VCWE]))>W<VE6#S75V[7-S*\L<S2O)/,7E=I&)+LS$N22Q)HHKRO!__
M`))RI_U]I?\`IMGYGQQ_R?WQ`_Z]X;_U/K'=V$<<K[9$212DF5=5<'E.H8$5
MF>*28;B%(3Y2[5;;%^[7<O*G"8&5/(.,@\BBBOURE_O6"_QS_.!O4_WZMZT_
M_4O`'Y+?\%9/B%X^\!?"OX6W'@;QQXO\&7&N^+'TW6Y_"?B76O#LVL:==>&_
M$7VFPU671[VS?4+*XVKY]K=M-!-M7S(VP,?B7X:`OK'3KR]`O+N\N@;RZN@+
MBYNC+<A93<SR[Y9S(I*R&5FWKPV1117\^>-W_(OH?]Q/_2YGB_1D_P"4L*G_
M`&2G$'_IB1]5_P!G:>ORK8V84<`"VA``'```3``'``X`HHHK^+S@Q'^\5O\`
MK]4_]+B?_]D`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]U<RYJ<&<`````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-3(Q`#$P-3$U-#,Q,#8W`#`R,C(W
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#_
MV/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;
M`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?
M```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$
M!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6
M%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!
M`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#
M$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G
M*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/X]P/@MXQ\)
M+J'PU_9H\,:_X\M-"\9^,/BYX5M9OCKIOAKX2^'/!7C/0M:T/5O!/B2[_:-\
M2:AXJT'Q#X<:;PGX_B\5Z7_:^GZ%?:I#X3O-'\72Z'\1-)PQH/P'U7P1XOO$
M^!?Q!\4VOAJQ^&UW_P`+G^$'C#QC\/O`_P`//$'C_2=/F\0^%OC1HWQ$\$?M
M#Q>)M/TG6]/U?PY\.;WPIKOP<U'4M1LO%VL7TGQ!L+OPUHOA76O+WPQXP^&N
MF?#CXAZG\._AEH7P"\*_'&W^$WQ?\"?"7Q/K6K_M0>.YO&_A_68_A[XE\=Q7
M>GK?:;86VNSZCX5\0ZGIME;>#/#][#9ZII#7GB2U8\UXFU_QQK?A_7;#QYJV
MN_#KQ/JO@[X':;X/^$7A?X6#P9H/QF\+6EG%)X/\1>(K'PVGAG2]4:WT26P\
M2:!XFU30_$M[XLN-5M7TNZBMUM)8?["K^'_!N(PWL7DV7JAB*CQ#Q#E6P=?#
M_4\PC5IX>C7P-3#UJBK8:33DZGL,31I1^MT*N'6+MY4<PQD%-+V,93BDG+#X
M:<H_[/RNI"%>$XPYU)3BG!Q=67-02JJ%NFU#6_V<)H]/^%^F?`[X+:1I[?$]
M]/@_:NUGQ1^UMJ_VWX?Z=HN@Z6JZOX/T[QIIFGWFK^<TGC+QA>^'_A9HU]/K
M.O#3O#WA7PGX;33-.AW&^+_@_P`8>'O#7@GQGX0^"GPD\,?#?X>_$Q?!/Q$\
M!_LK?#O5?$OQO\4:1)J"?#[2/&'B#7-"_MJ\LMMII'A23Q;J]UK6NC[)>:WX
MXOM>\6ZOJFNKC>/$\4VOBQ&\9>"+?PG\1T^,FE7%Q^PU-\-_BAX1T".77_!_
MAV>P\6:3X26]B2S;QA(FGV,_AN"XT[6KL7>E2Z3:7_AF\CL+'RMKS3/"UG$?
M%.FZ%\6#>_#'Q9H.F>$;W5?B7I<G[/\`K6H^*M4M[&ZDACGT/9JWAS7+N^UB
MRT"\OM7\,7VI^()9M>L=2-[;SZCAA.$N$\IQ"JT,BPTZ2J.K0>-RVCCG5I^S
MC2G.%3,>7%4N>%256E6HSC3J04*\<#A?:4W%2S+&TW35/%NA3G.3DJ+=!MP<
M/84ZU3#/VT7*=.,:4)U9Q57GE.?M:M.M/]FO^".?[.'[,G[2_P"TU?>&?^"E
M,'P1^#'[/'Q5_9OUCXA:-XEU=?A%\%7\>ZMX&\?^%O!G@=_#EUI@\.>)?A[!
MYNE^*SJ5S\$)/A5J_P`1[C0;F^^(^I^.-#O_`!#;>(/V#^)W_!NI_P`$N_C/
MXWOC^RI^U-X>UG3+6WU-;#PU\"OC-IWB'2XK,7EY>Z0WBJ7QXOQW\5OXMC@N
M&L]<U#1M3TCPO_8%GX<DL/"R:VGB'5M;_'G_`((>?L*_`S]K?]MU/A!\:_VA
MKBQ^'EA^QWKGQI?Q/\,]:L;&[\&Z[_;G@:6]^&VKOX]\,ZEI\&IZ!+XDUHZ[
MI^CV%PD^HQ+<6%Y)YUPK_P!<6M?\$`?^"6&C6>E37_[=OQ&TAO$FOP^$/#=Q
MJ?Q)^!(@U'Q3?RWEKINFV]N?`UK+>R75Q97#6T<4\$=]!"9+:[$,L5P?Y!\<
M<'G.3<=4UD>197#)9Y)@*T5A>)*O#-6I5G/%T:CKX/"XG^S%BH)*E*N\%4JU
M%"C*LX8FE%4O[.\#LB\$\^\/G1XUX^XIR'CN&;8VCA\NPW@E@/%')L+E4/8U
MZ%2IBHY?0SJ?MJ];&UJV"PV?818645'E]ZM&M^&)_P"#7WX4,2UKX[^+E_:L
M2UM?6GQ?^%;6E[`>8;NU:7X(PRM;W$96:!I88I#$ZEXT8E05^B5Y_P`$`_#.
MF7=UIMA_P5/\#V%CI]Q/8V5C#X:\:>396EI*UO;6D7]E_%.+3/*MH8TAC_LZ
M**QVH/LD:6_EJ"OPISXR;;64YRDW=+_B(&$=ET5WGD6[=W%-ZW2NT?LCX$\`
MTVEXU^&ED[+G^B7XQ.=EHN=TL*Z3EI[SIMTV[N#<6F_X+6U6P3PYHMGKWB76
M/$_@:WF^+@\'_#2+Q-JO]J?#SQ)J6AZ=#I/BC5=-N-+MO#L$>O:JGA>\UB?P
M\QE\1V?A&[M-0^Q/I]E:UT%SXH\+P^#/&^BZ_HQ^-?BW5O`_PC/@;XKOXF^(
MVFW?P$@T26P?Q#X0'AZ^AM-$\06GDWL/P]+:A'=^'M*DM+._\'W[->JE?U3?
M&+_@U+^/GPIU&_E^"_[??PU^(OC3Q%INNZ=XLNO$/@+Q/X%T.]T#Q=I>HV>M
M6-UXC\/^*/BK?ZI>:Q]H,.JV-[H%JB6MY_:27T]W'#`_@&C_`/!LM^W[H'AG
MQCX,T?\`:?\`V<M-\*^/'\.KXMT2TUCXJK8^)(?#.MW6HZ*VJPGX8`N^C&4:
MI81*[*VHW%Q922QP1)?S_P"EKX]X3E.G/`\14)X>$J*I3Y\3@WR4Y.5&4L/B
M\/A\35<?:RE-5&\-5P]:OETY3P4JCE_F;#"5Y>T52A&DX3K4I1:I>TIU8NI3
ME2<*E6+456:A.M-3J45!5H2<J7*_P=3QEIOB33+"Y\97.N:U\0U^-?PKN]7_
M`&\8O%7QF\17G@+PA-X-MK&P\`2>&=5M=)-]K'A(>'IM8T+4T2W\1_9O!NKZ
M)X974=%MM+U*R\XDU#5?#5[XAB\(^-=1\+:=XH\%_$3PQXC^(^I7/C2WTGX]
M:9!XFU/5;R#2(CX7DU.RA\5V-KX;T=M%U<"V?5K-I?$NMZ9_:MQ;6_\`6_\`
M"K_@TC\?^-/`%OX6U_\`X*6>%/`S:E>VWB?Q3\.D^$/B/4O!*^*_#]@NFVVM
MVEU>?%GPY::Y-96GBO4M+T#7=3\-:+K4EG<:_!!I]K;"[$GLEU_P9A_$/6="
MT/3KS_@J!X6U3PUX>LM9G\-V5Q\#-9O=%T73FOOM7B";1H)/C?)96%D=2N/M
M&KR6:Q0"]G\V[83R[FVEXD\`2H3HUN):$<2HQJPY\)Q'BG&7M*,9TE4GE+GA
MZ<Z%"C#VV&F[OGBH3I5(R11P&-?+7H8/%^S]HZ;K0:Y:M:,%[2G2J*2IQY8*
MH^2$:CA-5%4<I*?)^"?_``1Y_8!D_;G^)/QEB\*^)K3X1?\`"K/`GPCNKY_%
M.E:EXJO]3D\9Z)J\.L:EI,5M>^'Q#9Z_KOAY?$%G;70GM[31=6M+>VN[@VD$
M]W_5G\%O^#:KX:^)8O[9^)7[;\::3+%<)%H?AKX>:'X7\46=U%<200MJ1\0^
M/?$MI';72QO<PF&V<O`L060O<2_8OR8TC_@W0_;;^&'B+QS$/VI?A)XXAM&T
M'P;X>O=,U;X@Z1?WGA7P`=1\/>&XC;-HC:/9V]OHTL$T%C;Z[?6ML#>?9]0U
M&:?[3>?7_P`//^""/Q?\56&G:#\6?VN?"WA^].J6%A8#2O"?B?QSX8AMW"6<
M.L:MJ?B7Q7X$FTIK59Y!=F'2+^.*U$UPMT!(ULG\(^,^7X'B+Q%SK-<OX%J\
M81E'*J.#S9\23R[+:V'PV4X.+C0PM6I3P]*C3JQKTJM*7-.IBU4Q,I3GB)*7
M^EWT;_%O'<'>$62\.5_IB97X$Y%[7/\`%8[@_`>"E+C+B7"8W&Y[BH.K6SC"
MX'$Y]5QF)H_4\=A\1=0PV7266R<8X%RI?IS_`,0R?[&/_1X/Q6_[_P#PI_\`
ME917R^G_``:_)(JNG_!0?X:NCJKHZ?"(,KHP!5E8?&0AE8$%6!((((.**_)?
M[`FG9^#>"36C3XRI)W]W1WK_`)]]>M_Z+7C!AY)./[2SB5II--?1HS%II\K3
M3_LIIIIII^?K>_X[_P""`O[?.F:+K^KWO[<WB#Q(FD65W>![O5O'9L;E-(M]
M0FL[BXFN/B->:G;:=&9[IOM$>C7NH6%M?7<\>DRR/<6[_`6K_P#!&_\`X*3S
MO'-8?M5>!(`&@A>VA^-GQXZ3WI-Q=EY/`$"[;>&=YC"`7,-L+>V!)AB'VU<_
M\$9O^"Z\DIDD_;*^UR/G=,?VP/CV['8S1)N:X\/1R-NCC1TX.(GC5MDBO%'X
M->_\$X/^"P$\2I9_M]?891(&:7_AI?\`:7N=T85P8_+E\$!1EBK;P<C9M'#&
MMZ>285U*52/A[QKAY*_.WGDZM-IM.TXUZE:;4;-*4(1FT[V3U/,Q'BCGM'"X
MO"XGZ8?T7\\PZ=*>'P\?"S#Y;B8NEI;#ULGPF2T8NNE2E5IU\7.E&5)0C444
MHG/_``X_X)&_\%*(]2T73]8_;$\)^%;/6KW3H-=U/0_C'\:!>Z?!.X0O-9R>
M&?#>B:A)ICW$P#W?B'2-/$7F2/?01^9._P"@=G_P;_\`_!0S48'>]_X*2>)]
M.;SB/LVIZ]\6IY9-NZ47(.F_$+4[?8TMU<A=\ZSB5KAVB591)+\"Z)_P3@_X
M+&*`^I?MX7"E$92ES^U+^TJ[N9[+1I$VK;>#[F(BSFCO[.2621)9;A)KB-98
M;H7$OT9X>_X(^?\`!<[5M(LM5TG]MUK;3=3@AO[(M^UY^T99FYMKJ&*6"[%N
MOA0.BSPLA3STCF*A2T8782ZN183#RDUX=\:8I*HVDL^Q%.E!N;7+3CA:\&HK
MEYHVCJK-RMJC#^*O$6;JG3G],CZ,/#<_8QIU(1\*LGS'%5X4:=.T\3B\^RW,
MHXF:C56'J3>.G\%ES2;D_-/VD_\`@A?_`,%$/`D.G3:%^V5;>+]9U:XU)VO?
M$_C_`.*7A`7T&BPV\*#3K[3+GQ_?:A+.MS;11VVN6_AJ&WCDLY#>.8;FVMOF
M+PS_`,$@_P#@IPM[<)JG[1G@^WM&AE,<NI_'#XN7"-)'-;BW""Q\':I<132Q
M27+21B-;=1$NZXE<Q*OV'\0_^"27_!;7PQHWVGQA^W"@TN_=](AN9_VL/VBM
M9M_M5_:W<AM9+$^$IY9$DM[.:299;?[)*B"&64LX0_*-G_P2]_X+!0:U:7$G
M[7ZR265_8PV^JO\`M.?'J6VBMK(K;6U^A70K?55@T^&"UDLK5+9)Q;Q)#Y$1
MB6V=1R+#5J,K\!\9X6$FFZ']LRJ.<I6NU4JTZU>+3C%W=2FE)MOEBDW%;Q7S
MO+,RPLH?2S^C1G^)HTU"GFG_`!#:A@*6%IT;1C3G@\OQ65956C[.K4IJ,,%B
MI5*%&E&'M*KE"G^@&@_\$)_^"C.M:'HVL_\`#='CY?[6TG3M3VV?BKQA<V:_
M;[.&ZQ:W-[\7=)O;BV'FX@GN]+TVZEBVR7&GV<K/;QE?-'_#N;_@KM_T?=_Y
ML_\`M-__`##T5JLIP:27_$->-'9+5\1XV[M;5VS)*[MT279*RMQ2\0>))2E)
M?3?^C)!.3:A'P6X6<8)NZC%SX(G/EBDDG*<I66LF]3\6YOVT_P!L>Y4)<?M9
M_M,3H&#A)OCQ\4Y5#@$!@K^*F`8!F`8#(#$9P35;_AL;]KO_`*.H_:/_`/#X
M?$W_`.:BBBO-P7^[Q]7^A]OQ+_R-)?\`7BA_Z0<-:?ME_M?V^NZ780?M6?M)
M06,<6I0QV4/QS^)\=I'#;7FLPVT26R>*%A2*WA@@B@C5`L44,4<858T`]`@_
M;1_;%MMWV;]K']I>WW[=_D?';XI1;]N=N[R_%2[MNYMN<XW'&,FBBNC,?]VA
M_P!>J/\`Z?/&X-_Y'>(_[&F+_P#5;2'3?MI_MCW*A+C]K/\`:8G0,'"3?'CX
MIRJ'`(#!7\5,`P#,`P&0&(S@FO#;_P#;&_:ZMM?U;4+?]JC]H^"_FN;FVEOH
M?CA\38KR6WCF5([>2Y3Q.LSPHEO;JD3.8U6"%54")`I11E/\.E_U]C_Z3,GQ
M!_WC%?\`8KE_Z7@SVG_AL;]KO_HZC]H__P`/A\3?_FHHHHJS,__9````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8V]C:WDN
M:G!G```````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S8V,0`Q,#4Q-30S,3`V
M-P`P,C(W-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!
M`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#
M`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D
M,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BY
MNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$`
M`P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0`
M`0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E
M\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^
M"^BBBO[(/GS]KO\`@@;^TO9_!'_@H!X&^#WCVXGU/X`_MKZ=?_LD?&CP%='5
M;[PYXP3XN0R^&OAL-1T+3Q+#/J*?$/4=%\,1:_-#'/H'A/QIXXA34=.TS6=9
M>;]VOV6/V%/&MW^V%_P0Q\"ZC;36_B;]DGX1?M?>+OC1J-[)'>^(-(\"_`O]
MJ;XF:-\,CJ(L[B71O[.\4?$+Q;I6@>'[73M6NFL;#5/$%W#'>V>A)%=^0_\`
M!`;_`(-K_'?[4ND?!W_@H%^U/\0/&?P+^#UIXKT'XE?`#X>>"+*QTWXP?%!O
M!7B"#6/#/Q)U76?%.DZOIGP_^&>H>(-&M+CPPO\`PC>L^*/B7X;6X\2:#<^#
M/#.H>"_&?BK^W;4O^"=EQHOCK7?B_P#"3]J/XV>%_BOK/A'P[X.O)_B9I/PP
M^,OPX\1:+X0UWQCXB\,:-XR\,7O@KPC\1E\.Z9JOQ`\6W<FE_"GXR_""_P!2
MEO[)=1UNXM]&TNWMO\;_`*;_`-'[Q2XX\2N,_$+Z.F:<#8;-N+_"S,N$>,\N
MXFS7.,JAG/%M/P^\7/"7+<WP+P?#^:Y77QU#@3Q@S*E+'X_$4*-7,>#N#,OK
M2CEU+%8S!_H7#6;X'#8+"X7-J>*Y<-F%/%86K1I4:O+AUCL#CJM&K&K7C.$/
MK>5P:IJB^>CC<15C-MTU+_'W_:.\+ZKXE^*'[2/QK\(>%=1M_@J/VF_&OA/3
MO$C&P?2=/UCQSK_Q%\7^"O"<=U9"WL]1U&;PCX2UW4)VT2V?3["VTZWDNA81
MZQHD=[\SU_6Y_P`%K?@#!^R1^Q]\%_\`@G58^%_A_P#LJ?#']DRZF^*GC5M<
M\?Z;\1_B3^W-^T9X]\->)/#'PW^*GP;T'2K#2O'OBCPG/IEGXWN_BM\6_BEX
M=^%?P\^'3:SJOP:^']IJ.I_!7PI\,/$G\D=?WY]%WQ&SWQ"X$S:/$/"N.X-Q
M7!O%.:\#Y=D.9/ZUF>&X?X7C0R7(\7GF;8.MC<AQO$&?8+`QXJQV#R#-<VPF
M28+/\JRO$XZOCJ&(JU/E,ZPE+"8JG[*O'$1Q%"GB9U8>[!U:UZE6-.G)1JQI
M4I2]A&56%.525*<XQ46DBBBBOZ4/("N\^'/@+5_B#XGTG1[+1?%.IZ.^M^'K
M'Q/?^%-&GUB^T+1]:U>WTV74"JH+*VN/+DN/[-.IW-G9W-[$L$ES$GF2)5^'
M/@C5/B9\0O`?PWT.6&#6OB%XT\+>!M'FN$DDMX=5\6Z[8:!ITMPD6)&@CO-0
MA>8(0WE*V&7J/]5#]FS]G/X;_LJ_`[P'\#/A#H`T;P'\.]'LM&AG$$?VW6=8
MN(Y;G5O$WB2]@BBCOO%'BW4X]1UW6+QUC-W?37;6\4-K!'!!_G)^T!^GSE?T
M+\KX)RK"<%3X]XQ\1(YU4PF7SS]<.8+),BRGZIAL7F^)QRR?.ZE?%XG&9A0P
MF58*.#A3J3I8W$U\0HX.&%QGZ[X5>%=;Q&K9G6J9K#*<NREX6%6M]6^MU\1B
M<7[9T:%*DZ^'A&$51<JU2=2]YTH4Z<W.4J7X6?#?X:_'#PO\%O"'[&G[$GQ$
M\?\`A/XQ^)OB]^V9I?P[D?2_`?P_L];^'>E>"?AQ)\`/V&Y?B)^TYK>K:5\:
MO`GA/QA=7O[1OQD^%/Q]\(^&OV@]%^#FA?M!?"CX6_#^:+P=KVC>./[-/V-+
M;6O"UU\2?A>NL67B/PY\/])^%4'BC4-#U3Q1KW@7PI^TKJGA_61^T1\*?A-K
M'BR<:@OPI\)3Z;\/_%N@^&8[.:#P/XF^(_C/P@NJV9T?_A7?PX_#K]HO0_@+
M\,/AOX$\'ZEIWP\\'R_%;]KSX16WPVT[Q`/"UCHWB7]I+XQ_M":;XP:_U&/Q
M:EQI.K1^(O$&J>+O%'Q.LKNUU5=9^&Z^/].NM$UK19KO0;O^H_P_X>\-^#-`
MTSPWX6T/1/"GA?P_816&CZ!X?TRPT+0-$TRT3;#9:9I6G06NG:;86T8Q%;6L
M$-O"@PB*HK\:^AO])'.?I/>&^=\;9UPG#ABOD_&.8\-8>O@J->AE.>8/"X'+
M\=A\=A*6)Q&.JT<71IX^&$S3#QS#,*5/%T?:T\9*.(>&PO5XF\$X3@//<)E.
M#S-YC#$Y52QU2GB)^TQF"JU<36I\DG25&C["7L*CP\EAJ+J0E-U**JPEB,1^
M,W_!??\`X)S^"_\`@H?_`,$\_B[H5X)-)^*WP&\/>*_VB?@SXATG2K.ZUK4?
M'?PN^''C^YTCX>7]XYBO!X1\>KK-]X?UFVCFFBL[B^LM?@T^[U/1[%1_CTJP
M=5=3E64,IP1D,,@X.",@]"`?6O\`>5^(L/VOX>^/K5O#K>*EG\'>*+;_`(1<
MP?:QXI6;0;Q3H2VL5Y9R7"ZP9#I9MS>6$DS3-&MQ`KI<5_@\ZGI5YH.I:EH6
MH/ILE_HFH7VCWTNC:QHOB+1Y;S2[J6QN9=(\0>&[_5/#VO:5+-`\FG:UH.IZ
MCHNJV;07^EWUW8W$$\G^B_A/BJBK9O@7.])TL/BHT]^2I&<Z,YZ3_=^UC.$?
M>@_;>Q]R:]A-/\IQT5:G*VMW&_=;V\[:]=+Z[HI4445^TGG'M?[-/Q0TOX'_
M`+1_[/GQJUS3-0UK1/@]\<OA)\5-9T;26MUU75M*^'GQ`\/>+]1TW2VO)[:S
M&IWUGH\UM8&\N(+3[7+#]JFB@\QQ^GO@W]L#XZ_MV?\`!4N']H*3]K[PY^PK
M:W&H>(+OPU\5/B3\0[/3?!'P&^!7@[3Y-2L_`&F:)XEU.WT3XA:MK^GZ3:QW
M_P`,K#3ET7XN?$[7=6U?5/#^FZ3K&L7&E_BO7U?^Q]\0?V7/`OQ+U6W_`&Q/
M@OXB^,WP0\8>%+SPWJD?@/Q!<^&OB9\.]>75M&UK1?B)X`O(-9\/6FK:M9+I
M-]X8U'PQKVM67A_5-"\4ZG?77GZEH^D0M^">+'AKP+6QF=^,6:>%E?Q6XRRG
MPYS'@&APYAL'D^<X_,^"LVS>EF7$F291D?$>,P&08[&YE3YJE>AC<3"MF.'P
M<<JPLG+%U,-B_KN&<ZQM&K@LCEFL,MR>OG6&S3$.MB,7@L+]=P]*5+#5<9B\
MOI5L;2H1;4'4ITJGU=R==17+*2_J%^)'CO\`X)'_`+>?[0G[-T]__P`%)?VO
M/VB?VF/A/\2/AE#\']"\:_"W3_#WPF\?ZI%\7_"UYJ_A*#P'X._9B^&GP]\/
M7'BWPYI=C;^+/'.FVVC:C)9:!IVJ:Q<_&*;2=*T6O])&0#&\Q>:\6Z2-0$W[
M]CK^Z,C(B2.CO&&+H,.RLZHS&O\`/`_X)D?$3_@@SI'[4O[._P`(OV5]1TCX
M4^*OB=\3?"'BSXA?%[X]77C70-8MM'^#VO)\9_!GP7T/QY\6;ZX\+:7K?Q6^
M*&@^`OAIJ/@_PS)I7AWXD>"K?Q!I>M:SX@\=P_#RQ\3?W[?#[XS?";XLWGBF
MR^%OQ'\&_$=_!-Y8Z9XMNO`OB#3O%>E>'M9U"&XNH/#VJ:WH4]]H]KXFBLH(
M]1U#PT]\->TG2]1T/5-4TZST_P`0Z%<ZC_,_A1G\>(.%93R[P"S?Z.G"V39G
MBLBX4X%SWA2/`695\JPL*.)K9TN!\-6Q.7\-99B\UQ>983*Z%"L\3F=+`5LZ
MQD*7]H4(+ZKCW$1Q.;8>K5S+A[-LPJ8&C5S'&\,U\9B\N=6;E['#SQN.Q&)Q
M&,Q>'H*G"M5E5J^SIRHX:5:=2A.-/XI_X*__`!A\*?`O_@F3^VOX^\8_$C6/
MA3I@^`/CSPC9^+_"\EI#XV37OB!I,O@?P_H?P_N+W4](AL?B!XHU;Q!:>'?!
MFL_;,^'?$.IV'B,VUY'I+VDW^*M&GEQQQYSL14SC&=JA<XR<9QG&3CUK_5+_
M`.#IKX3?\%'OC[^PTOPG_8V^%5I\1O@-+K.D>-?VK-,\'S2^(?CMXLT;P=KM
MCXA\">%_`OP[32[BZUKP5X?\6Z/IGCOQY+X4N+WXAWVJZ1X(@T/35\&Z;\1D
MU+_*V!!`((((!!!R"#R""."".01UK^N/"K"X>.%S+&>WISQ=2M"A]659.I0P
M\(J?M9T$TXK$U'RJI)-26&48--5$_P`VQTGS0C9J*3=[:-OHGY+IYZ]!:***
M_6S@"BBB@!"`000""""",@@\$$'@@C@@]:_WK_#?AOP[X-\.Z#X0\(:!HOA3
MPGX6T;3/#OACPOX;TJQT+P[X<\/Z+90Z;HVA:#HFEP6NFZ1HVDZ=;6]AIFEZ
M?;6]E865O#:VL$4$4<:E%?AWBW_R,>'O^P+-_P#T_E9Z6`^"K_BI_E,_@#^'
MO[6/[4\_PG\)>+I_VEOV@)O%FJ_MO>&/".I^)Y?C)\19/$.H^%#\5K+1#X8O
M]:?Q&=2O/#QT4G2#HMQ<R::=+)L#;?9"8J_GM_X.%_#OA_PQ_P`%@_VO++PU
MH6C>'K/5;?\`9Q\::I::'I=EI-MJ7C'XB_LE_`?X@?$'Q9?P6$%O%>>)O'7C
MSQ-XD\;>,M>N$DU3Q/XN\0ZYXDUNZOM9U:_O;@HKS?##_DI*G_8LQ7_I["EX
MW^"O\<?RD?B_1117]!GE'__9````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O8F%B>2YG:68`````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C,T-P`Q,#4Q-30S,3`V-P`P,C(U-3,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA'0`J`/<`````````,P``
M9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F
M_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_
M9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S
M_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,
M9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`
M_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:9
M9F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;_
M_YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF
M9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,
M_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS
M9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9
M_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`
M9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F
M__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___
M9O__F?__S/____B_)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"'Y!`$`
M`-@`+``````=`"H```C^`+$)'$A0X(J""!,2/#AP!<.&"A4^Q`8`P$(`$R,:
M=&C0(D2-#CDV9#@Q8T2,'[&5-)EP!4J5&Q=J+!CRH!6#(V>VQ`FSITZ$!TFJ
M9/G3(<8G*FJ*+.I0#Z!2SU:MBEJ*%"`]3XB.U#/UF=>O8)^5TG-38A528=.&
M'6MR!5=2:-6&)05UE9Z25J9BC2O7*RD]<>\.K#+5+J"N7O7H@3IW<=0J!N/^
M35ME!5^P@`#Y/5CE:^:T5R]_G1RUJ6?-?=5R]?H$@)[3J57'=?G:Z^?883^O
M<MC9;VW<7P$_(Z4"VY.N8X&/K@TH*.IGPH&/#3S0"F/2L?]*ACQPM>'4?P'%
M6R7%O6$5Q>%)285K]:KP4N>STEP!J`K4\(J=PD5L-WQ9@>CI<19B<OU%V%43
M6;$8*2NH\(1^I40(UU7R66?5?]@H^-=0%2EEU$M6`(*A0$]@Z)`55Z288A=7
MK%#B3RI5<5X@K212XXU=Y/=3%9GI06,B0`+92A=GC36398]U$620B,@05W,:
M$6:;%38&.:05HVF%36]B68'(DJU<\1N4$5GGU6Y7>"$((FPJZ)61,^4UG(<.
M'0?=3U:HIX=$B\&X97E^!@0`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W:7IA<F0N:G!G
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-#<T`#$P-3$U-#,Q,#8W`#`R
M,S$U,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/Y][NTM
M;^UN;&^MK>]LKVWFM+RSNX8[FUN[6YC:&XMKFWF5X9[>>%WBFAE1XY8W9'5E
M8@^5^"WN_@_9>(O!UA\8[_QYI?Q/U+3/'7CSX/:+X1UW2M6^&<7P1LO%WA3P
M9\1?BMJ]QI'A+X;ZQHFG?#+Q3XGUGP;?_#2_^)$OAKP4?BGJWCNV^#]UI>KZ
M+XF]<K:^#OPU^"OAKQ1X7_:6^+7P3\(?%,^'_P!JSP%%IOA7Q#\0-%O]$^(G
MA?X,P>!_B9\:?!?C+X0:KHFMR7]AXATSQ)\$/"VLWFOV=QX)U'X>^._$_A]K
M75]3\96=W\//[F^DPN),'C?"//.#88FKQ/@.-Y8?+L-A<!@L=_:3Q>!F_J./
MAC?8J65)T7B\93P./P&:N&'Y\#7E3CC,/6RX(>7S6?4,TPD<5@WE3Q-92Q-;
M"RI4J%:$*]2C6I8?%PI8J-&O.>%JXC#5\/\`6*=*C*"G6IU:?V%\1O\`@G'^
MVC\)+^STGXC_``1OO"FJW?A/2/&TFE:CXS^'#ZGI'AWQ+XHF\$^#YO$^GVGC
M&YN_".I>//&%IJ7ACX=>'O%,.C^(OB)KNC:_I?@C2M?O-`UJ*P]F\5?\$?\`
M]MKPIX+MO&5UX"T^]64W$%WHMAJ-Q+<Z9J-GI+^)KO3M5\0M8+X#T*XM_"0C
MU[9XF\7:%-=RL_A[3(+_`,3/8Z3?_+]A^VS\9O$WQ$\/>"_#'A"/7/'>H7_@
M;QGXE\->'8VUG2?&NIZ5XK>VT75=!\*W'C32/&?PQ\):1I?@OX#_``)N;#P;
MXU\-75O\./"L6O6GC#Q7\0M,T'1:_J8_X)C2?M8_M9?$+QY\*?C1\:?AQJ7P
ME\-:W\,?VUM!U?X*Z1\2-4\!:[<^,H?`^J_`;P5X+U'XP67A?QAJ/PV^'=U\
M/=.\5^'(O&/A[3?C#\._''P_T>Y\6ZJWBW7;T:%^)Y_])[QHR+/\JR?/LCX/
MR3'X.=7!<193E6"SS-XT\^HU\3"M@ZN.Q<J4:V0JCAE5PN<8"6$JXFE6HUZL
M</'&4J.%]7"\+\+XG)\ZQ-#'9A6Q&'Q$ZF4XW%5,+@\-B\NI3PT$IX&DL7BJ
M.9UUB82AA:E66'<G-0Q36`Q3K_QP^)/#/B'P=K=_X:\5Z)J?AW7]+DCBU#1]
M8LI]/U"T::"*ZMS-:W*1RK'<VD\%W:S!3%=6D\%U;O+;S12/AU_HW_M=?\$@
M/V6/VA?@QXE\+ZS9^,-`\7:?X7>T\`^/_"$OBO7?$/A3Q%I&JZG>^!]13P%;
M^)K3PEXUL[:'7=7T+Q7HFNZ9"-9L?$'B;7_#WB+X9>*==UOQE)_&#X,_8,\=
M>#/BYXR^'/Q*TV.7Q1\._&-_X;U`64=ZWA[4/[-O)(M/UC0[G5--T[4-2TGQ
M+;K9>(?#6IG3+?\`M#PW?V&IQVRI</%7]&\%_2$RGBG))N64XB/%]*K2PL.'
M,'.I4AF-2I23688;&5*/L\)EO/&J\3&NZ^)P"C"BECJU?"?6OAJ^45*52ZJ1
M6'T;K3<4X7;2@X<W-.6UG%*#;7,X7T_.I/#>N2(DB:=.5=5=23&I*L`P)5I`
MRG!&58!AT(!XHK^CZ#]CCPJT$+7'V99S%&9U5W"K,44R*H%O*`H?<`!+*`!C
MS'^\2OI7FOC7)N4,AX+C!MN$9RS64XQ;3C&<EF,$Y).TFH0NTWR1T3S5/+-+
MU,5?2]IT;7TO;]V]-7U?KO;^:6J>B>)[?3-;\?>&K;PYX.FU'Q'X4\"MJ7BJ
M^LM:U?QI9:-:>(_$][;Z+I!U74+KP;X3TVZU32H+L:]X9T&P^(>I*FO>'KSQ
M1'X+U/6-`URY7#>']/.G>,/'S/<:<\NNWNA>(!:V]W++J%O9?\([IOANTN+^
MTDMXTMA>WOAO5X[8PSS0R16`<.9WN8;7W_$+"X/&U>`</CZ*GAEXBY!BEB)4
MYUH8+&9=A,VS+*JTJ4-9/$YK@\#EE*I)J&%KX^EC)76'<7KD]>O0_M26'<>>
MIDV.H2@^53J4*_LJ6)5*3A-QE3P\JN(GR2I2G1HU:3FZ=2=*IM:AXEU+P#XE
M^'_Q&T"WOE\0^#_&.FS6>KZ9%.U[IFFZCNM=9MY+BRGAOK.QUB%8-.%_%#J$
M&@ZU)H7BVZT]E\-I?6'T_P#L??\`!07Q;_P2D^('AWX@VVDZEXQ\`"T\$_!O
MXI^%[)[37XUT?1/&GQ&U[0;?3-)U[Q+?PP:_X$\&Z=X@T^*"]NK/P_K?BBTT
MSQ-=6&M:-8^&-3MODWQ[X?F\1>&;^VL01K5G'-J.@3(D#3Q:M#:W$*102SW%
ME]E.IVEQ>:)<W5OJ&EWD-AJ=V;/5=,N3%?6_C'QG\5>.[G1KJY\1Z3I+W(O/
M!GBWQ+-_;-Y=.DF@WOAW2=)N=`U>XM+&_@\7SZD/$%O'>:1/*N@^')KJ^M[#
M2(M<71K'^2/I.<-9OA>,,9Q6L)B*.15L@RJH\UIPJRP<LSP^)EE_]G8BO&A[
M.CC:T7@ZE&A*.*J5<+3E7I5*5.EBOJOO<*488^M@LOC4BJ];&.A*G)THN5&L
MZ;C&$JN(PZ;JU;0I1=:A&6*^K0?M93C2G_2AH_\`P5-_;$_X*#>)OAU^US'X
M*^.GASQI\+_B)XT_:H_9W^%6C_#[XJ>.?V1_$W@+X`>%+[PEIGPCT#X?W\W@
M_P"'WQC\1>&_'WBW6O\`A>?[1^J:QI?Q*\'>(M0OK_X-^,-*\60_L\_LM:=^
MJ\?QK^'?[5'B[6/VF_AU;VT>C_%.QT37KDLT$FK6VNZAH>F7&J:1KL%KXA\3
M:=H_B#PPCP^&M6TG2-2EM+.>Q>VN)KG58M4O+S\)OV`[#]H;X%?L6_&WQ+\.
M?V>O&7@#X*:QX7\3Z])^T'J/@?QEX-T_7O#NG_"GXE:QI6K:1XQN-*BT#Q=;
MQZUH^FV?@"[\(:P+S6!\56N-0T?P_P"&_&_Q$\;>%/O3_@FGXATF?]G.7X>V
MC6T6K?";XC?$;PSJ]A#?V6I-:P>(/%NJ^/\`0_(O;6^EGU'3+32?%D'AVRU/
M4-(\-ZE+<^'=1TW5M)GUO2=5UC5/A/HI4\%3\4ZT:.88W%/$TL_Q&(HX_&8G
M$/"XZ>$R[&0RW"PQ$K4,-2P[AC:&$PL(8.G&+JTE*I[2<_0XNEB8X/"4J^#P
M^$='`8.A2E0PF'PTL30I8K&4WBL1/"^YB<95J*5'$U\0Y8E*A2HU7S0]I6_0
M>BBBO]-S\Y/\W_PC^TU\5/"EG<:=+?6?B:V2=H8)?%\.IZI=:<4O(C=&/4Q<
M:/J-U'-+J,@V>(M7NGL[>'3[2*;3XX!'J/M?A+]H;4-2M_'7Q,O/"T+7OA_P
MG\-]!OM%LM4DMK34KN[\1:LC:K'-+IUUJ=C:F7Q-(;33GLM9:)8/+M-1OOM=
MS=0_(_C?P'=>!-8@ABO=/U_PY?>?=>%_&>C2V]UH^OZ?;:U#;2M;ZE93R6JZ
MAI<N+76+=K[3[O3;Z5K8ZA-ILFE7.H:=EI=[9?!S4-9CNRB:U\1M"\-W>FH'
M*"?2=$UJ\A34[."9&DCEDN+:\6UDTVY,M[I%O<7#WSSI!8?Y29GQ_P")F1_5
M>'LSXDS:E/(<XR?&X/"YI.AF4\+C<JQ=+,<KK4*^,CBW7PWNTYX5T\17P&+P
M56C&,<3EU2$)?KN'P.78ASQ>&P5.3Q.#Q$*LL(I4*3H8A+#8F,XTH0A%Q5><
MI*=*E47L9QC*C7C#E^_/AG^TSX&\?W%AI%^DWA/Q)J$T%K::??3?;M*OKR[>
M_P#LUC8:[%;V\8O6CLXT^S:Q9:++=W]U#8Z*NK[HYY>R^/\`\%Y=?^'V@>,]
M(T[2-/U>Z\2:C<:U>OI#W.LZWX5TV/0=%BU.WOM,ENM0,6@7%WK>_2/[&FFU
MN.P,<NHV%QIGA73O$GY#H@`$C-&B-LB9KC[0TB0FT:XMQ+<"2VF$;VC/I\T<
M4<$5U;*'TVVU">,&'^AS]ASPEHOQ-E_9S^%WB1[KPYX.TGP\\'B;1+NXU.RT
MNU>R\,7?C?XGPPVFF:WX5N/!%WXUL_#\"^,/&#:M+XBU/5)--6VM[KPYX<\3
M^'V^NXH\:,]\0N"%P=Q)A\-5Q]',L+F+SS"8>5'$XS`87"XNGB<-4P6'P\L-
M2S&O/$*E3Q>"E@J$Z=58>673A*M'$>=A,'4X:S+#YMEM:5.?OTU3]I&2IR56
ME4NE4DY3H2@DG3Q%/$1A)-^UG4C3G#ZR_8C_`&B-*TOX8_#+X3:;XX^+P\*^
M$+_2/#WC7X;?&(:[;C3+75KVSC\3*GP\BAM?#>K1:;IU[JW@'3G3P]JDRZ6S
M1A+WQ%'I>OK^G/\`P2F\-07OC3]HKX`:YXSU&XU70I="\5>&-1F\*2;_`!#%
MX8M=&\&Z_P#$:\O_`.UKU(K+Q_X;U#X83Z1I$WB/7K+6+2PA\:>$M5M8KKQ=
MIVI?FG\=OAHOP/\`C9XC?2)KM_!_C#QII]G!,\7B233])UK4+#0;^QTAOM&K
M7L5RYLO%>H6%_+:,=)L[Z]^'LRZ%HEE;74E?1VF_%C6OV6/VB?@3^U1X?N3:
M:5\1O#5XGC?2?#A37M7U72[":S\#_$>QBL)_&>FQW^N>)]!\6>$])N)+SQ)J
MFK^/OB%!8/XJTKP#/HDEQ<?DW!^89AP;C</FV79QCZ.<X#$8[$X7%U)T:CPT
MZE"O*E0I2QE*KAOJ.(A1HX2IAZTZ$JD,5C,NA&O@\3&.)VSO&PS[%.H\#A,`
MITL-3Q.'P-&5+#UW2I04L745)3YIU>:6*KQI5*LXUJ<:N)BL32YC^B?5?V4?
MC=I>J:EI@T'PO?#3K^\L1>P_$[X7V$-X+2XDMQ=16.O>,='URSBN/+\V.TUG
M2-+U6W5Q#J.G6-XDUM$5^PO@JV^`_CKP;X2\;>#/"_CW7_!_C'PSH/BKPIKT
M.G?$^QAUOPUXATJTU?0M7BL;^;3;ZSCU+2[RUO$M;W3M/N[=9A#<65K,CP1E
M?LS^E7X@P;A.60\\7RRO5PL'S*R=X/*Y.#OO%RDXW:YG:YX=+(,!.G3FZ'$C
M<X0DW3X:Q]2FW**;=.I#$RC.#O>,XRE&4;.,FFF_\?OPCX?T%?VC/BAX+71-
M(7P=/X3M)I_"8TVR'AJ::PM/AE?V,LNA"'^RY)+*^U75+VT=[4M;W>I7]S"4
MFO+AY/=;?3--T3_@E5^W?JFBZ?8Z1J=S_P`%`/A?\-[G4=+M+>POKCX=KI/B
M7Q2O@*>[M(XKB7P6OB?P5X-\1CPM)(VAC7O"7AG5Q8_VAH.E7%H45^?^.'_)
M'<#_`/9R*_\`Z]',3ZSA[_?,Z_[)6/\`ZR;/QMO6:*6-(F:-!9V3!(R44-=:
M9:"Y;:I`W7`XG.,S#B0L*_M7_8M\/:!8>!OA5K=CH>CV6M)J6D3IJ]IIEE;:
MHL^N1?"#3M:F6_A@2[676-/N;FQU202A]0L[B>UNS-!+(C%%?%83^/\`]R&8
M_P#J/6.''?[SA?\`L;8'_P!.Y:+^W1J.H7?P3^(MS=WUY=7.F^)(].TZXN+F
M>:>PT_4_BI^T/I.I6-E+([26MGJ&E>'M`TR]MH&C@N]/T/1[.=)+;3+*.#@/
MVV+Z]TC]D'PB-)O+K2Q;_&OX/)`-.N);(0I+^SG!XME2(6SQ>6LGBJ]O/$TB
MIM#^(+NYUE@=2GEN7**JK\6-_P"P3#?^GZYY=?\`AY;_`-C#%?\`J"C\,9O"
M_AFXEEN+CP[H4\\\CS333:1I\LLTLK%Y)99'MV>221V9W=V+.Q+,2231117Q
M[W^:_.!^OX?^!0_Z]4O_`$BD?__9````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O86QY
M+FIP9P``````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#`T-0`Q,#4Q-30S
M,3`V-P`P,C(T,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(`
M`A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1``
M`@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152
MT?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`
M'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%
M!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D
M-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`
M/P#\6O`_Q$FTR&Q\/?&?0M2G\)6P47/B/3K:[OQ86,[*(;B2\A+M;6D9ACEB
MN'#7`,1V[=G/Z%_#K5-"T:W.K?!CXJ^#O'NF7`L[B;3-6UBVTV_O\,1Y6MZ-
MJJ6K7%Q;PRO!I^MZ=<_VK,'N4N]-UE5MUL_E'P!\'?!OPITM=0^,O[?O@[P(
MBLDMQI>O>$H;B*2VF3=+$EBUS--?N^^#SH88=Y/E!N2F/KGP_P#M&?\`!-JP
M\)VNE:3X]^#GQ;^)FF7<9NO$VB^!]5\$:EJ,$0=H$DLM1M(TN;B0EF1X+B8,
M8LNJ9BS_`!!QCE[QT:F*R#*LWS/#2KR]I_8^4YABLFK5)/6I6H9CD]&E3G.J
MW3=?"9D^65URMQ=-_P"DN2\7T<)]5RG/,SIX'&NHJ*RO-L3DE7,Z<*;O"-3$
MX+,:T*M.,HP]FZT8U*4%3@W[ECW;Q'I?P-^('PRGD\3>!KOPSX_MTNY[#2F^
MUZ%</?R72`ZAH&OPK9Z+>6,S11?:TGL+2YN8S:+?0,!":_//5?V/Y7\/ZS\4
M_B3XX\"_":SM;>^FM[[1O$>D2^+;FTBFD-L=9L#J6E>'Y8WC1!Y$-Y:WDZF<
M+!=LH$7]6_[)6H?L^?''X*IKOAK0]!F2QMX;:>V%E`ILI+:&.<-)9B:!7)F`
M1P$<S"5O,`S\W\I?_!4SP5XO@_;7C\,>(?V8_&_Q:^!>CZ$VEZ%X2\,^(T^&
M.@>)=1UU+JX;Q4-:LY;N'4M9L[R>#[.+RSG:./3$MY'"O&`N!<ASQ8[#4'G>
M&R3+\SI8NMB\9B/JF(JY:L!B,-+$9?3PV98C#X2%?%5G.#AB:E2DHPJ5Y4,0
M^2A4\3/_`!#C2PN<8/#Y#F&.S'+\?AXX;+J].OBUC*V+:C1Q4)83"XS%4J%*
MG*E7C4PM"ISTYTZ<ITJ;J5:?0_`?_@H#\(?@[;6'A^^U_P#9Q^(.G::@M6\0
M:;IM]X3UY84D,#2:O`-/U&ZGD3S5-Y=K#):)+Y313S>9N7]=+[P9X'_:S^%B
MZTOAW1=+BOM/,WA[6]'EFN9+R/RA);,]W>6=G<O"C.ICF$$0G1U#;O*0+^%_
M_!/O_@CU\8/C)J-POQJTNP^!W[.TWB?4M;U]K>'3KOXQ>--*A:UM;?P%J_C-
MX8-0C\*P'3EDNM*TY;32[ZXO9KN\MKF8PM'_`%'V7AKPEX1M-(\&?#32H-.\
M$>%;"S\-^'K:TW)"EAID4=HB22?(MQ*[0$S,JA2V,9[<WB/DG".58C!U^&,Z
MQ./S*.)E7QE6,L$Z#DX\\?92P,*6$Y_:.,JBPD(4H/GI\JM)'E<&\6\89G*M
MB.(^'J'#V)I4\)/"4H5,TGB/8N4Y3ECJ68XAN,,3"5.%&E4PR<L/"I.,:</9
M2G_.9JG["E]%J>HQ2:+#+)'?W<;RMIL#M*Z7$BM(SF(EB[`L6))8G).317]+
M9\.Z5(3)+H-FTKDO(QM[=BTC<NQ8IDDL223R3R:*^77'?&Z22Q:LDDKP5[+E
M2Z;[?AOI?])_MS('K+)LL<G9R?(U=ODN_FV_O/\`.2MOA[?^(]&\::+XH^&O
MQ=\5?&?5M8TR_P#"7CO1#+K_`(=?38Q*NHZ+J:7T23F.9;FU>"^MYO-L!`[J
M8RR$^V>'_P!FKQ=:Z9X5N/'5GI?A;3=#U35=?T;PKI5M-_:5K>ZK%IEE<C5_
M$-R7U2YB:72;*Y2TEN'M[6::Z:$!IY"?HKX.^/\`Q1X6LH=0T.^FUK1-5T])
MK:"V=9C;P74.U&6&3<\^X;X@L#+Y"PA'RKH![+)-J/C&V>>%T:>..`7=O</+
M9WB(3*\40@EMR61660A%D*(1G"Y!K^P\TXNS;"8I450RW!8*FW!XOZY4=55X
MP5%0I85\JH:+V<TG)5$Y5%;F=OY=X3\),@S3#QS6OB\TS;,ZJIN&!F_944ZE
M6.+C5KU:,'+,ZCYE54YSAR2Y92CS0E%_L-_P1+^)>HZ1XB\0?#VZU29[2ZL6
MU,*US*0\L,XMY/+WR;Y%5A%O9ASA*_H.^+WPJT3Q3HDVHR:9::EK>F032682
MSMYAY+2&=[;)B8A96PQ0$!FW,0237\H7_!-37F\#?M%Z+J%ZEY#;ZG9ZMHK;
MHC)$KR1M+&&5<B1!*GF;74!9`K@9Y']='AB\\>^(_#^EW.A6T.D07-Q9O/J6
MKP"1[NT@D@:<QQ2@L3<Q"1(W[*T@!PQK\,SZ.75\WS_`2I2K4\95HYC3IT:7
MMK5L?"-ZMX1<80A73<WN]T[JY^@9SA\=EL.&LVP]98+$++J.!J3Q%:6'<JF!
MJUZ#IR^U-O#J%-+5RY$GT9^:-]XG\6WFIOX>M+>XT>R3?!<Q.)(YBP8!U0`C
M:N5R0,`[@<'&:^N_@S\*%UFPB>_GE$4<<91V!4@J9G"Y/4*S,R@<*SN0,NQ/
M<_$'X):7KOBJ'5=$U"WTO7V<M=022!+&Z=I)9`ZP1J0#LW^>%"Y'D!\[$V]+
MX(U#6O!TMIX6\3V3Z9-<-<2Z7<3,D,.J6B$!KJWW/]IDAW.NTJ`JAQCJ*_-\
M%D^(P6;1_M:@I8*#]E2JP7/AN>3]V,I17+"2YE=.S4_=WN>KF7$5#,,CHQR&
M,<+CZM&-?%X:5)0K0CR4YU*E.[;E&KR>T6MG"496BDDH)/AQ;QR/&"Q".R`E
M020K%02<=\45[$7B8ELH=QW9$US@YYR,MT-%?5O*,NN_W,-_YI=X^?E^"OU/
MSU9[C4DG7E=63TCOI?\`7^DS_-*_X)\^*M,U;Q./@YXP:?3M6TR[FU#2;>\D
M:(WVDFX$=Y;6DTA!4::7-Q9V2$(8+D>4@5<U_69:>$/AYX0^!7B36(_!N@:S
M>Z?H4W]F37&@Z9J=U++]GWBZB+VLMQ%YD4*%C$58,78G+9K^/O5_!DO_``F,
M'CGP'J=SX>\7^&]2L-8T/4H(=_G!(X\I=`;0=,G5S87MLS8BC%NHC*)@?TT?
ML._M9^'?BQX$G\(>+T_L?QKIEFVE>(_#M^J1!+I;26-KBP?<L-SI5\NZ2U?#
MDKOC<`*`?N/'[@CB##5<#Q3A<+C*V44I2>:8>DZBHX6O&,92Q#5&]25*<;2E
M)WY:TG&Z@F>;]''QRX5XFR.EP8\]P-+/\)4HXS+J%3%4*&-QN%Q4L/-X.E[:
MI"-;%85^UA[*G).<*?+%.3L_F?\`9H^,V@?#WXI:5K/B3X;6K:3>ZA=?;=:T
M^&]DU2UDF:>6*:RT^8F-&M$D$<C1&+RTDC4Y4@#^AVZ_;TU76]1\,^%OA1X%
MM=<L$TJPMWUO7=4A26S,MJD/V?3O#.F*UY=:CER\:;P(I%4MS,:_DQ_:QT3X
MK_!WXI_\)G\.=<-UX?L?$J:MJG@[4(K2Z\*Z]HTQ;[5HFKQQ1O-96][9_:8[
M;4+11)9W*Q/E7\HK^EG['_\`P59_9[^!'PRO_P"T/V6/$5G\5;34FU[POJMA
MJMIK>G1.C1SM:+JUR1K$UI!&T,<2WLMP\Y,BJB_9B#\]4X>S3'X7"\1<.8B-
M+`YQA*4<;6R^=7$8FC'#QK5_JU3#SC*LYN"BU4I1C3C%-S:BG(_>\VQ7#F89
ME7RG,LASO.L\RF7-E&"J5<!@,EQU#,H15/%4\=4Q=%0^KXJT,50K0=:52<Z5
M*EBHM4:_]&J_$W6?A5\`/BC^T;\2O#M]HOA3X7^$M;\?>*;G5+6V3QGJNCZ(
M;6VOM)\)^%C/I$+^([MKM3H<.M:_;PZG.OV5K#49)<VOY3_\$ZM-_:@_:2>X
M_;B_:?\`'&OWOB'XJ:]J(^&7PNCNKVV\!_#?X;:3<&S6T\,^&7/V+2DDN70V
M]R1<:C>111WUQ?3BXBV_+7BS]J#]IO\`X+-?&WP9\')?"/\`PIS]F;PUJEGX
M@\5^%M'U&34[_7)X'AO9M:\0ZFD-N+82W-M;/I6FM)<;)?M,H6)[5"?Z4O!W
M@3PYX'T_P[X*\-V*:;X9\&>'=)\*Z-I\,<26UE8Z;;1J+9%B5(W$DQ>YF<*%
MDDER=S(37L9GA*.&RMY)AJD\2_:8=8S$UL11JU(RC6HXE451HRJ4Z$ZU:DZU
M;DJ2J4HT<-"LJ=2O5IK\ZS'"U>&?^%+-,/1RWB#.Z>-6$R6&'Q-.&3Y+5Y:<
MZDIXRE0Q.(Q.+E%X?+ZL\/AL-3P=#,YX6C4P]?+ZU/U"&<>5%BTB(\M,%HD+
M$;1@L>['N>YS15H07```VX`&.G3MWHK&.!IV7[N>R[?W?^#]_P!WY@ZE!M^Y
M'?\`FGWCY^OW>6G^9Q:*JJ-JJN<9V@#.XDG.`,Y/7/7O77>$KZ]TOQ1H][IE
MY=:=>?;+>'[78W$UI<^5+,@DB\^W>.7RY``'3?M<`!@0!117]X<6?\DYFG_8
M%5_])1_C;P#_`,G#X6_['V5?^K"B?I5XB_XF8A&H_P#$P$V@E)1>_P"EB5#'
M&Y203^8'4NB.5;(+(K$94$?&W@.PL1X[O[865H+>WGFD@@%M"(8)`9R)(8MF
MR-P68AD56&YN>3DHK^'N'O\`D0YM_P!AE7_TI'_2EP/_`,CO)_\`KVO_`$J@
M?U0_\$N]#T73O`MW>Z?I&EV-Y=W=C)=W=GI]I;75U(PU%6DN)X(4EF=@H#/(
M[,0`"<`5^K>AN[WMQO=G_P!+1/F8M\B/*43DGY4+,57HI9L`9-%%?(X'_>\1
M_P!AU?\`]U3\=\8/^2WSG_L!P_\`ZCX(]!9F#,`S`!B``3@#/3K1117TA^*G
M_]D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]C:&%R;&EE7V)R;W=N
M+F=I9@```````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3`Q`#$P-3$U-#,Q,#8W`#`R-#0T
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,
M`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS
M`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,
M,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS
M,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,
M,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S
M9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,
M9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,S
MF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,
MF9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``S
MS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,
MS&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\S
MS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,
M_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS
M_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(?D$`0``V``L`````"``(```"/X`L0D<2)`@@(,(
MG2A<J!!`08,((S*<Z"2APX?8`%#<R%!CPXL//7*D*/(CQI(C%Z*LB#'C1!(P
M8\I<";*@3)@I:6(DP?&FSY@L'_[\^:RH4:,D:F(#JO!F45(*CTI]!A*G$YE0
M2>79NI44J:E'03;EZ37K5[!HJ0Z$*1``6"=GGSE)J[:@6Z-GYQZ%FE9I1J-S
M->*]RW<J0KM%X5+5^XP48<9329$8>#!QWJ]QY=*5W-8QX+R*G])M/#FCY]&H
MGY4V?3<U6LX07:=U'%(V6K]M;1MNV1KPQXB[6_Z5J]!KY-ZTA0^7[1@WXM3-
MV2!Q'GOV03;2IRN'>+!L<P#8I1]CU[[=+L+PX\.3+]\6B?OIZM%+IV[W_7OP
M2.3/QQ80`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+V%P92YJ<&<`````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3`V,3``,3`U,34T,S$P-C<`,#(R-#`V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/_8_^``$$I&248``0$```$``0``_]L`
M0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$
M!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B
M<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ
M\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$
M`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&Q
MP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY
M^O_:``P#`0`"$0,1`#\`XCXD?M>>*_BSX_B^$7[-OAS3[YO%WBF;PEX*U>%X
M8_$WC37+ZYAM+#5K!]<-A%X1TZ\B@CO94O3;RZ9:E=:\47UAIT&L6<?S-9W_
M`,?_`!-XJN]+UW3?$\>O:.'L[W4/%EE9:)+H1N=-CU"*'4&UJU,4`EL+G3]=
M-I=Z:^M3Z)"QT>2SM[^[>Y^'OA5XYO9/&VK>-=-N[/4=<\%^';3QQX,\*Z5X
MQ2\E'B[P]XI\.?\`"+ZQ?W^C6MOJFBZ$KRV^IQW]Q_:&JS76J"VT?Q'86T?A
MJ/5?U<^%NI?$G4O@C8?$O7/"_BG7?B1XN\/>'-:C\/646LZWJSV.IZ-I%O;W
M?B+5+J'[=H]]=WUO+IZ:7#''KOB;5K3Q!JL6W4+C3S#\[2]FFW[*-Y2CRR<+
MRJ-13NW.*E>7)&247JU=I6;/JY3K5G>5:?NIMQC)*$(W2248724>:2;:?NZ)
MMM#=.DM].MUU#Q!XF\57.I6<5L+'2M*L[6'P_HUUXF\606RP'5[K3+F*\C@M
M[33='LGAT2+5[:ZUB\UVZUS2FO-.LK/M_A]^U&_PZE\/2^`_''C+X4>(I(8K
MW3WU74KW6M#&DOI,HTBZU2TU22?1M<M+B6.VGU;3]1U.^@U2*RL[)Q::[9.A
M\/\`",7QRFU"]\1>(O"/B'PYH?A?2;+4;Z2'3_\`A&[CQ#I=K=:)XBMM*TY]
M5TN[U'Q%?N;J[OI_"FGZMI4-YIES>VXN-!35-3N-6\)UOQ?X@^*%\R^*X;L7
M]C=S1:<FA^%I;G4#*_[F]TR2U@O;*)(X[32I-2MI]0-Q>3);7%NUY;PQ6]N=
MT[6YKK5?#9M:QBFU&[LW)/33DL[JZ3AR>BA=O6W/S1YK:NTI-6:46E?7G37*
MTKK^M;]CO_@I;X?^*]QI/PJ^,\6EZ)XCU263P]X>\;6$,FE^&O$]Y;PS64GA
M^_LTO=572?$YN(H+&`V^HI9ZMJ5Z-.M[+2-1CL;+5?T4N;?3AJ$B6%S>K#/`
M"TTR+B]A11+Y4TKQ*&:2027-K`0LSW"QF%/.BDMV_@[^'6LZ8_C+PW\/=2@!
MBL[S4=5EUQ]7M-<\+_\`"#%;S[?JFJZ9=W5C:IINBVU_XD)UBY#:?8+J?B2S
MB\"ZIXHU&XMKK]M_V./^"J.A_#'4=-_9[^+7Q,\/?&[P(D^E>`O!WQ>\.?V]
M<>)/`6I3:7X>T'4;7Q:_B?P]HYUKP]_:%_+JL6MZ==:Y'!:PZS:Q^(_$8TVU
MM7RE%5+*G5<9)M/D4;[1<DD^:,FHM2<4GS)W6D=8<6O>2=-.RDKZ-MKWDI15
MM4UMRZ):-I/^@@!"`7MKO>0"^+2W<;C][#21-(PSG#2,SMU=BQ))1;>)TU6W
M@U2RUS4;NSU*&*_M+K3M22?3[FVO$6X@N+&:WE-O-9S12));2P$PR0,CQ'85
MHKD]FWKRU===*5^W53:?75-IZ:ZZ/EDG\+6W1_W/\G]Q_EE?LS_'V/\`9\_:
M&TWQK;66EZKX=OY1X1\7/+-J<$5]HM]KVE:I=:_%>R:WJE\DVG:WI&F:VKVV
MJP'5K#3&LFN-,?4Y[NW_`%0_:?U?]HS7_'<'A/X/ZY?>$-"A2PO+"UT^_P!=
M_M:PTB&^?3FN;X6+VUI<ZOI]Q;Z?.L6IFPT=YH)_->,3S&7\-_A;)8W'Q7^'
M,WB&\>+3)_B%X0DUS4)G\R2.QE\2:>VIWDLDJ3EW2W:>=WDCFW,"SI)DJW];
MGA']F)=6U:Z\>_%+PWX+?1=6\'FT\._#+5=2NIK6YT2*,ZKX6UK6-(U"XCL]
M&L!+X6AN='\)-:Z;:_V5/<^)HM5&FVUI#J_=[-R481;YN5*[MK:UG-V<G%OI
M&+NWMRWM-&7-&=]%SJ22;32;5U%+1-I+66UFTW+?\BM-_:9_;$^#BZ=KEOXE
MUOQ3?:;X1B:#0=9.L:C::IHJWMWK-HVJ26NBB3Q#K7]HW^L7>F7<NF^&K&?3
M9ELXY-@O=)O>JTK]K6U^)-C?O\4OA4EKXWU5+XMXB>_U*RUM;'3M3&HROXBO
M9+>\_M34--C:Q-MX>\5W.MZ;X>T&VM](TW0U@T!9K']&OBA\+/$>JZ&B?%3X
M86?AW5+'0K:QUWXEZ-K)UF]UWQ';76G0VJV'A[2_AKI,OA%;C4?$$=Q</<:E
M9^$=$AM)-!U"VUQMPA_(S6="']K^(+1+'4;"VDDGM#IMWMBDL%FNVTYK2!);
M5+.&XN6N;F>:Z^Q6K?VG;W5\\$AOEMM(QDZD$N6;J14M5/F::4;I*+;Z<KYH
M16J7FEK+W+*2Y;QTLDI)\T(RYDUH]URRDTM4M4;_`.U)XAU[66_MCX3:WJ=A
MK?CR^?PU>ZA'XHU"TN_LM[<74^OZ_.J:7:QV&@2:>NG6T6DM/+)!9W=AJ&BM
M<WWA_5+30X_"S^)OA)X<\3V&KZM>:9>:QX7>76HHVT9KW6G6PU"'2K77]+6X
ML889WU*=8GGU&TBUO3SJMY?66GSS36NES?'?Q3^._B3PSX\FTWPU!I=P/!^G
M6=HUWXA@>XN'U200M?W,5H]Y86FHEY+BQ62VNM)F)DL'O/L45O#(R]IJWCS4
M_$$-[XBUBXOM--I8^)I;R:WN-)\02:]-I]A"=6T&UU'60MM8ZIIMEX<GU70F
M:RO[2XT^/6;'6/#>GZG!9PWL3;52,DD[J?LKRO*4G3IIS;?-[RM*4(JU_<4=
M79S%J2DVY*2<.=15H*/-*Z5K63;Y6[Z>\Y7T:^N;+]KSXL:!9VFA:9\6/$]K
MINBVT&DZ?;6FIZPMK;V.G1)9VD%LMG.]HMO#!#''"MJ[VPC51`S1;22OR_O_
M`!UXH@OKR'3#X/NM-AN[B+3[J_\`$.AO?7-C',Z6EQ>-;Z[IL#7<T`CDN&@T
MZPA:9G,5E:H5@C*PMB7JGA]=5=QOK:U^:TKZK=7TU5[&JJP22Y\5HK:.=M.U
MM+>FG8[+X:?!/PYJ4BW^NO+K6GOI\]T%E>>PLF\^VMS9P02Z+?SFYU&.XGCE
M$D.L/8/:F2;RKB*%7F_K<^-VI>(]$E^&_BSPKXPT3Q)X.B^!WPHO?#CZOK-C
MIL?BF/1_`_AE=/T#3KYM)U#P5J3+<Z-:Z=:V>M^,_"]A<W%GJ\%QX@B?0K6-
M?QV^'W_!*']L.%O'OB/Q_:>"OAIK?PW\'ZWXC7P!X[UCQEJ$TNIOIFNZ\CZ9
M>>&/`?CG3H+]O#,E_I%^MQJ_AV^AU;3I?#>FZ5J5Y8SZ;X<_2;X=ZQXZ/@K0
M?V</'RW6IZS\/+?Q?I/PZ^(?@JYC\5Z7XE\(3Z;<>,6\,WKWVH1:A->Z1:6J
M:SH_@S6_[)\4:/X7UWP_H&L_#\SZ]8QUHO:5*,Y.O&,KIJ;E!KWKQ<.6Z@O>
MLG&R<M;.\DUI0BJ=6*]A-QE%>[RRB].62ES6<M4VT]5%I-KW;/Q[Q+\5?%WQ
M`\36'AS6K:[T#5/$D\$6D:78WFG>-H;6SGAFLM/M;GQMH%]K'@ZPU%-71+W^
MSM5N,1W4\FZPOK&ZL-3A^&?VZ_$'A?X1_$ZVU'>\\]OX`\+RZG:26?\`9IF\
M0:@O_$NTY-/CMID&H3>%-,T'5KB2XN])O[Z]<ZMK6CV$\4TJ?>OAGXH+X7.A
MOX;\/>'&U.^T^ZUN/6=92.+POK?AG3KUKS4GM"FIZUJ7CJ9YKJ32;RQNM,TN
MSFFTO3[0>*]2MWL]0E^.?B[^P3/\<_B>_C.;QT(?A[\5X8=>O?''BO5;)_'_
M`(+.E7>K^'K+6[GP7I>C6:7VGV-Y;:^^J:'JDOA>P>]G7PPOB;2([CPYX@TF
M:4JBA&,ZT)1_=6=-WG%7YM5*=23M%)Q3O*"YDXO0TQ$(SO[*G/G<I.7/[L+)
M15U:,(^]*33DK1:<>6UVS\%+[7M:\1^(=5UZ[N5.K:I#J]Q>S);,Z-#)I=U'
M>0I##!<LBMIXEMEG=3Y((NKJ[A"37L?TKX;\11VWPSO!:ZM?1W\\?AS4;];:
M:R#Z=#8ZI%/JFM,]KI5A)#'9Z5816&@Z-97_`(BTB.R\-6^D7UE'?VU]X<LO
MU?\`A_\`\$6?"!O]6\*_$7]HR[TC5I/".IZW#83^")OAU?1/!\0O!WA$?9[K
M7[C6](\6+9W>IZ-+=:!=:YH\DC:W#J&@+/:V%WKD_P!E^!O^"+7[*^D:[HV@
M?%?XE?M(7FC:&OB:U^(MMX#N/AKJ$W@W3I/#%W9WF@>*]0T*R\8MH/B:WN?"
M5I?:EJ7B2Q;P9I6@R:=:Z=K#3W>@CP_M4G":2@U[K26BUC9V4=4WS6<+*]GN
MM4I<M/"5XWE.#ZM^\FXR7*VI).7*TFI:I.2T6NW\N/\`PC?Q+3Y=(NM6?2E^
M73'M?%EO+:OIZ\636TBWUDLD#6PB,+BSM`\95A;0`^4A7]?FJ?\`!$?]AUM3
MU%K:[^,-Y;M?WC6]W?\`Q&\+B_NH3<2&*YO1!^Q5>P"[GC*RW(AO+N(3,_EW
M,Z;97*P]O+JJ%^K]C.6ON]5/7??K9/JC?^SJW\M9>7M$K;=/9Z;[=-NU_P!E
M/BKH^D:=>_%+4=/TO3K'4%A\)R+?6=C;6MXKZUHFDZEK#K=01).'U;4=>UV_
MU-@^;^]UK5KJZ,L^HWDDWYD?'#P3X,T_PYK?Q'L/"/ABR^(<7Q1T6VB\>6F@
M:5;>,X[:#X9^.[R"W3Q1#:)KB00W=E9W442WPCCN;2VG11+!$R%%-?'2_P`<
MO_;CI?\``7_<M_Z33/SIMK.TO?A5^V-+>6MM=R^#_P!HQI_"4ES!%/)X6FU6
M^^),^J3>''E5VT274IH()K^33#:O>2PQ27!D>-"OT)\(K&R7XY?LUZ.MG:KI
M'C7X=_LH:CXRTM;>(:=XMU#Q%XH\6:9X@OO$UB$%MKUYKNFJNGZQ<ZK%=S:G
M8@6EZ\]N!'1144?X7_;R_P#3E04OXE/TC_Z1$_5'P196=GX8L;2SM+:UM)7^
M"&I2VMM!%!;RZCJWPUTSQ+JE_)!$B1/>ZEXBO;S7]0NF4SWFM7=SJMS))?3R
MSO%\0?#GAZPMO'WB*QT'1;/Q!X8U_4U\-:[::78V^L>'EOKOX)3WJZ'J<,"7
MNDK>3(DUT+">W%Q*BR3!W4$%%<D_@G_UZG_Z;Q!Z#VI?XZ/YX0^;IO$7B"YF
MFN+C7=9N+BXEDFGGFU.]EFFFE<R2S32R3L\DLCLSR2.S.[L68DDFBBBN5[_-
M?G`[H[+T7Y'_V0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M;65L;VXN:G!G````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3(Q,P`Q,#4Q
M-30S,3`V-P`P,C(W-3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#
M`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`
MM1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*Q
MP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ
M_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#
M!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1
M"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1
M`Q$`/P#X&_:T_;4\??M/?L__`+.OCWXTZ[:7.OZ-\3_"$WQ0\0Z"OA5?%6H6
M`UK6-,\1Z?X?\::79PZM+IT%DMCI^BV,-RD5Q*+J2YA%Y<W>ZCXJ^$'[4?[>
M?PO^(/[.#;/$GBSPA\6/A?XP_9U\7_'G6O!_PBM_"W@2XM;;P_J"VFJ^)=8L
M1JMO=^%KN'P5JMCX4TV\N]3T_P"'6A?VA;7,VEVL4/U'^Q?^S5\(_#OPK\'Z
MA=_`CXH_M(V\VMZK?Q>,/&6A_!SP-^SG!8:UJL/C+1=-^"?PX_:!\0IX]\6Z
M-I.HZS=Z9X9^+&H:+<:UK*6<FO\`@Y]*TRZ2W/Z+>/);70O!MG9_&?P#:^&_
M"_B?58O"WA;P)XC^)_C']H"_\8>()Y[J"VL+'PYI-UX-T:S-G<7=\6U7X87^
MIW%A<7%VTHT9'NM0D_S;Q/$V2<+YMA\OR2A@\1F.2YUF&/P>,G14ZF`@\1'$
MVC9O&4(.-"OA:^&JRC?#UN6I3=E*/YG2S##SJ4J4ZC515(RDN:5G96OT3WNI
M=S\'_P!DG_@@?^T-XQ\2_$+X?^./VG_AU\#O%?@^WU'7]<TS2OA;\9O&'B&_
M\,P>)9]$N?$O@R^UBQ^&4>J:=9>*/M&FH@F2#4;BT?68)K_P_=V&JW7V5HO_
M``29^*^D^/\`P[^S7=?''PQ^T#X;_9]U75AXUN;+2-6^%/@7PI8>))9[_P`.
M^&?BG\0Y_$/B+3-.\1>--4U*.\U7P#\*%^+OQ1C\-W]K>Q:%X?T.XMH[/]Q/
MB5\0Y?AA^SUXKD/Q2UWX>>*?A!X"'CKPO+\0(K_XN>,?!>B&TL/"^H)%HYTO
M7=1L/A3XSOKB_P#AK=0>/M:\16FF/;VFH::?&^N>%3+I/`_`7Q5X3^`OPHU;
MPI;;?B5X1U'X@>-O&UYKOAC5O'>C^'_$^M:I#I.EW.K>)=$TNVL-9U6&UT&?
M2M.^S>(WU#2E\*6VBZ=X=\J\O-0G;SLY\:.(<Z>(>)KY3AH8[%QP]#!1P5*%
M*MC,/'F^L1Q$J:K8V"I5FY495[PJ.C--.$;^].CE.-K4Z->JJ<:MFN5V<JB>
MEU'35\W,WJU\C^5?]M'X1_M]^#/BG^SE\-_VUO@/X+^&OP:\&_'GPQI_P_\`
M&OPB^`OP-T[X5VG@32_&$LFJ>&O#?[07P@\'6^I^+=$M-,>VU"?1/BRESJMS
MK^G7U_XPM8_%-IJSI<^%_P`;?$K_`+-WQMU.P^+FM^`/&GQDO?CMX[\>?$.W
MM(PK"[UR]T#^T8O[-%C;Z#JGBCPKX2TO1HM1TZ$7,T%SKOB*)FO38,W]<OPF
M^*O@CQ#JFL>!=,^$_P`/_'T'A4G3OBAX=^%2_#^/4_#]IJ-E)-I]KXO^`7Q0
MDL]8\)Z7=Z!J4#7%K:-JVBM%>33VL7D7J+7Y,?MS_P#!//\`9?\`B7IMO%^R
M];^#OV4OBO;^)M+OM%^!OQ>\._$/X3?`#XIPVM]/K=WX0\%:CXGT;6OA=X)\
M4>)8=-M+CP[<^'=4LO!_B?Q?)+I@BTR_67[-]7E'C%@L\JY7PSQ#DKR2MA\S
MP-2.882+EE^)PD:L<17C4I8CFK4*%:I'#5)*7UFC4E3A*=2RIV\[.\IP5:%.
MG0G[F'G%)IJ[DD^J24KM:IZNT5[SBCM/"_\`P5_^'EAX9\.V,/[3N@^#X;+0
MM(M(O"5S\2-'L+GPM';:?;PIX<N+&W\/""RGT14&F2VD`$-M):M#&`B+17\I
M/B[]JSXC>$?%?B?PIXD\7WFB^(?#'B'6O#VO:-X@^$HU+7M)UK1=2N=-U33-
M;U%=;F6_U>POK:>UU*]66475Y%-.)'$FXE?O<?#7`249*G4:DE)-0A9IJ+35
MJ#5FNS>^^NGSW^K]7I[1K3K+;W/^#^/F?T7^%/VVOA;\4/AEXI_::U>3_AGW
MX\?$/4+_`.%/PM^+>K:9JWQJ_9_^&#Z+J^H:#X5\)W'@B?0=9;P?#XRT_2[S
MQ5XF\9Z=H'B5M6U^X@TR[N[=--AT^R];TO7[;_@G_P#!OPC^TCXVT36O&'Q+
M^.^OZYIL'QG^(_Q$U7XHZ7+X(\#>#M1\6^'?%6J^-=`%MK5_X/\`B:^C:OJT
M7P-T2X\&>(9]7\3Z%X(\<^*M.T?0YSX$_%/X8ZE/HGP#_9-L=<72+>`_'._O
M=9L]0M[==(6QT7Q7\</%.B6@BE3[-90Z=XGNX_L-H$6.WU"S@N[=8YXTD'KG
MC+]LWXW?#?Q1\/[;P/9VOQ(\-^)O%'B32_BC\&_B)'_PDOP3^)U[XL/@J1+?
MQGX5UMKO3I_%]AJNF7VI^'_$=G8R7=I/;VM^)UOD>6OSO_4KAC.<7#*ZF%HX
M##U\TS7$X['T*DG4JY;E,,1A,+@\0U:O]7ISPTJU2,97<XT^=24IQ?E4L/[R
MI?%455U>=M\UDFM)-\S2<N]M-5W_`'NA^'6L:C^QG\6M`TSQ7\8_C_\`$']I
M?X4_\+.\26,6F:'X>\4:KX@^)^@V6F67@W0?!O-SX4L/`_@AVTRV\*^)9+Y]
M(MS?V^GB.QNO+;W7]@7X+?$_Q]^R]H>C^(T^-?B_4-"N_%G@5=8\;7'@&U31
M](TDK9Z-X>L]0O+"WUCQ)96.CS6>B:C+XPUO5+RVO[6]\-:2;+P7I^BZ=:_`
M^C?M;>%="U4?$?1?$=Y\*M!T_6[+Q5),E[=BV\)VVE:G%;ZUIUCXA2=#;VUW
M!$^A6$B")VL;@V,QD5I0WF'_``3[_:R\8_##Q1\:?`/[0_QPUR6W\</8_&'X
M*^%=4UO5KI+J[U+4;S_A*M.\&ZI;SB*[NM4\)ZSX6L]62^>.1M9TJ]T]A)'I
M\2K_`#KB>$\SQW"G'RK86KBZ679[A,]P>,]A"C2C0C*="5#*VJ25&A&@L/*N
MDJ?M.5-[*)[>45*4Z5:G7DVZ=9.,T_>BU%V2;NTKRV79+K<_4/Q-^S/\,-1T
M[4;?XFZ3<S^&O@W\1I?AO]A^$%Y-9_'_`/9'UW6I-(UW2=;\)^/-.UWPSK6G
M_"V[T3QAX*\3^(/"M[XL\9>&O`<?BR]NO".F:3\._"UQX8TXTW]H[X1?#?PG
M\;/V8_VD/'/P^\;>(O@_XBTSP3X@U#Q:UGXY\8?'?X,>+]$M/$'PO\7?$(0Z
M'9:+I]YKNFW>I^#_`!@VGV`GT[Q)I5U<F6]<-J-U^:'[5/[;7Q+\0?%?XZ>`
MO#=[J?PU\"^(?V-].UN"ZTZ,6\GQ)\2^$=;^(NBW?B:XAM98Q:Z]IVBZIIO@
MC^VI@U_+H/AS3+%;G^S;>SMX_P`L?%'Q"UFY_:0^+OCJ+5)KVU\5?L^?!'Q#
M?Z-(NE/<ZGKFK:9K\^CO%J=Q%+*MR8EEFDE,K3M-=W67._`RCP/G/%&55\'C
MJT\'@Z.64,YRS$8>4WCZ>,GC\EITJ7UN"YHT9T<7B%5H<W+&K3:JWE3N>G+V
M'+)TJDI2N[\S;;6U];K2UU+W=&[-WL?MY!J?PJTR"'3?!_[7OQ'\+^$M/BCL
MO"WAG_A76E^(/^$=\.6B"#1-"_MZ^62]UO\`LC3([73_`.U[QWNM2^S_`&RX
M=I9G)*_(G2?'<U_I6F7T]W?V4U[I]E=S60N-&Q:2W-M'-):C$&,6[N8ACCY*
M*^CAPMQM&,(_ZSYT^6,5_O.+=[**W536^NO6Z,.>?\TO_`G_`)GSYXITW0]=
M^$7P8\-))IVI:,OB&RTSQ;I\MY9W6GS^,HK_`,8Z9XMUFPUF*&+5[65/%K7^
MK:6MO*)+1-5*1.A=BWSU\<Y=?D-CXABOM3M8/`VM^$]5M]#T'3C=7]SK^O\`
MB>Y@TJYM3?S37XU?3(M-M--M;%HOLMY9WLUV^7U*X\S[/U[PY'8^"]*M]4T#
M28X_AO\`&?5H=2T9X;>_N)95^)B6=I':ZO+IFGR3_:;'Q!I<US.MLBWDA$S2
M78V74OSA^TKI@\+VUCXCM[S5=,\3^==7MA;P6<>H&_M_"$4WC.Y344D!B%AH
MCZ;=7SZS+NU.*8RV5HPAA11_1U"G&CFN7M4G.57$9PZ<(_:>(E1<T^52TDE-
MR?+*[;E9NU_)H)<V%=E=QLW;?WDM>Z\NQ[=XGT&?QS;>);#3KJ\-K:Z5?ZK8
M^%Y)0/"GB>_>;3TT/3/'.A1)#:ZMI6FSV(NYO#VI6MSIFFZLMS%80)%%$3M>
M'-1\5:9\:==\/_$#QGI7Q*TN/X3V/BJQNK+2;31K3P#XWT[7/#.O:IX;\.6K
M0IJ&B:/I&EZW:WES<H8[7Q"^I-I@\ZTL(8(MOX62Q7>FW?B&SFTZ9?$.EZ5J
MOVFPB\RPF6_D%ZGDQ7,>=-MI'G,JP7D9BA+G8BQ[17@.O^*M?F_:?\7P:W?"
M\NO$?A&X\-9DNFOX],L=(T/PMK^A:-IFK:4UMI[SWDFCZA?P6EC%$UI-/-#*
MKWD=S(_PN$GCL=A^*<BFX_5(9=F&*=%W3IU*%:BU%1NE:*YM/ANV[;6Z,/%*
M=9I)?O>RZ1?]?)=CLO%/Q#\5O\>FN/&.F:)+X2\:_"?5/A9X-&DZ[;7%_P"'
M])BU75?$&O07;/&;'Q!J#7*70GL3$MM%I%UI^GWF^2W;'R_8:OXUL[+PMI\C
M6$.N:]\$;>ZUR>"XNIK2UTCX1W6E6G@]8HKN1WMM9N;:_O+;6(XML4>LSZS'
M:A;:8JW;>(CJDWQ<^&"W0L1HR:/\1+#[5/->+=O9:A_8T6MW%]%(TDC:B;:2
M"S2>5FFECDNLN4G=3Y5=MX@UC2=.U?0;2SW6OPH\?P:M/?3W=M<630_$Q],C
MM[.1ML@CG,'VVQB1@B0W$9C"@C/WO#6!3R_+:$J5/]]E-*F[04+/"ULPPL;N
M+5VY48U))KWZD5*6I[U&C&HHI)7NNBNU[MU>VVWHCZ7M_$;B"$+>6X`BC`!L
M5R`$7`/R=A17KO\`8/A*#]Q/=:5%-#^ZFB-I,3'+'\DD9/E<E'4J3WQ175_J
MY4[SZ=_[GGY_U9'K_4H]H_\`@,?+R_JWI?T#XRR2?\(+\8'\Q]]KK'P1NK5]
MS;K:ZNO"W@2\N;F!LYAGN+NTM+J>:,K)+<6MO/(S2PQLOCG[7\447@.2ZBBC
MCN6\3^'(6N(T5)S%J>A);ZE$9E`D,>H6]U=07R%MMW#<SQ3B1)I%8HKIP_\`
MO^!_[&>9?^E2/SK#?[Y1_K[2/;?"*K:Z9K;6RK;MY?AR',`$)\I38QK%F,*?
M+6/]VJ?="?(!MXKX:^)$:77[4/CJ.Y1+E-/^(FGRV"3J)DL98/A*[02V:R!A
M;20LS&)X0C1EF*$$G)17Q.1_\C[C#_L39O\`^D1/5PO\2M_C7_I!V&IP0+XO
M^"+K#$KW=AX[DNG6-`UR[:)H5TSW#``S.UR3<%I"Q,Y,I/F'=50_Z1H6@I/^
M_2X\!?"-ITF_>+.VI?&#3;;43,K[A(=0M@+>]+AC=0`13^9&-M%%?9<+_%DO
M_8-6_P#5ECSV</\`Q(?XH_\`I,3]D!X0\)S`33>%_#LLLH$DLLFB::\DDCC<
M\DCM;%G=V)9W8EF8DDDDFBBBOUM=/E_[C/I8[+T7Y'__V0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+W=O;V1I92YJ<&<`````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`U
M,#``,3`U,34T,S$P-C<`,#(S,3(U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``
M$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'
M"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R
M@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S
M]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41
M``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC
M,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:
M``P#`0`"$0,1`#\`_M^_:._:(\&_LR_#B7XA^+_#WQ'\;SW>J1>&_!WPX^#W
M@36_B7\5/B5XRN]-U75].\%^`?!FA1-<:MK]_INAZO?*]]=:5HFGV&FWVI:W
MK.EZ9:7-Y%^2GQN_;]\*?$#0K#]K'X=_!CXU^#/B7_P3+^.>D7_[9GP"^-GP
MQD\)?'WP-^R)\:_`WBCPS\4?'>@^$['7=<TGQ;X<3PU!I?Q^\&ZYX"\2>(#X
MUM?@/K/AS19[JYEU30;[]WY;:WGDMI9[>&:6SF:YLY)8HY)+6X:WN+-KBV=U
M+03-:75U:M+$4D-O<W$!8Q32*W\U7Q6^,'PY_:E_X*:^(OB9^SIJFH:M\,_V
M<_V>/%G[.7QT^*7ANVO[/X;?&OXYZY\5_#NO^'OA[I6NM:1:'\3[O]E_1_!'
MCB/7?$.BSZM9^$?$'QI_X133M;@NT\7:2_XO](+Q=RWP*\)N+_%#-,/A<PI\
M-X"%7+\FQ68QRK^VL[KXBG0R;*J&,6'Q=6%7&X^I1IU%2P>+G##QJXCV4:5"
MO,^GX-X;K<6\19=D%"<J,L?4G&IB53=:.$P].E.KB<5.E[2BJBHT(3E"#K45
M.K[.'.W)0E]<?MC_`+9?[-&MZA_P3J_:)^'?[6OP)OOA%X&_;>\(WWC_`,9:
M3\</#EOX%'@7XN_LT?M%_"_3K[Q)XATWQ7%X3LK'^U_B#X<N[9?&D$]E.TR6
MMA)IFLW5C>)]??"S_@H!\%/VBOB;'X%_95M=>_:G\$Z4UJGQ"_:-^!^I^`/$
MW[-'P^O+RWMKB'P[-\8+SQMI?A_X@^-K6#4M*U#7?!?PD_X3[7/#&DW,\WB.
M#2]5AMM%O_R;\2_LR_LZ^,/AMK7P<\1_`WX4:G\*?$>KQ>(-=^';^`_#5OX/
MU77X+JSO8M=O-!L].M]/EUI+O3[&<:L8!J&^T@)N"(U`^E_@5X"_:$TCX:7/
M[-7[$7Q#^`_[)WA+P7H+^(_`\FK?L^WGQ6TK1[N34M0&M>&=+\$Z5\3?A9X9
M\.>']9UG5=(U_4M5@36=7O=2NO%=T]HNIZNNK)_$'T;?VE&2^./B9DWAAG'`
M>)X7S7BK-\YI9%F.&Q^'KY?'"8'*'F.78;'?6*DJU?.,PG@L5@*JHT:&%IQ6
M$J4JTI5)4J'ZGQOX(XWA3(L3GF'S6.8X?`4,++$T/93A5]K5K.EB\3!**A2P
MM*+HRC!RJU9.4^>=J<?:?ME17Q)^R5\:?VKO&>K?$#X3?M>?LV#X7?$SX7"P
MN#\:OA=K%AKW[+'QRT+7M2UBU\/:Q\)+O7_$/_"UM`\3K9:-/>^./AQXO\+W
M@\!+<Z,LGCWQ"VOV"+]MU_J)":FKJZ:=I1=N:$K)N,DFU>S333<91:E%RA*,
MG^"O0****L#^4SXC?M4?M-?\%2OC-^T%X%\%_$7QM^S%_P`$W_@G\4_B%^SR
M[_"K48/"?QZ_;/\`&OPV\0W7A'XE:M>?%C2K_4/$/PO_`&?;77='O-)T"T^&
M\_A3QOX_TC4=4L_$^NZ6$NM#TO=\>?LMC1O@9\+/A#^REXA7]FZ+X'>/OAGX
MR^'.F^%I=7L?!-[HW@SQ5%J/BOX>>/\`2=)O;;4_%W@SXC>&=0\5:9XHM+W4
MFO=3\0ZO:^*]2O+[5+*1[GZ!\9_\$OOVVO@?\4?BK<_L(?%C]F34_@)\:OBW
MXJ^-5W\.?VK=.^+"^*/@GXX^*OB34O%WQ=3X>^*_A<EZ/B!X(UWQ;J&H^+/#
MO@[QA;>&M6T+4?$.IZ9_PGD^DV%C%/QM_P#L+_\`!;K1]4N;S1OCE_P3"\>Z
M==VX5-'U[X7?M0?#&/2+H+)B:QOM)\<_%&[O;?<L7G6VH,9)_.=H;JR%LL=W
M_BS]*/Z-/TZ/&GQ?SOB?"XKA;'>'_"O$#Q?ACPSB.)LO>0_V52;P^$K8GAG&
M8:MA\9G.*PE:O#/J_$&'O6^L8[!86L\F>%PZ_IW@7CCPHX;X9P>`K4\QH9SF
M&#C2SK,:67*./IXA5*<Y.GC\+)5*>&H8B*KX!4)2K*&'I5Z]/ZTXJ?4R_%KX
M>0_%NR^!,OB2%/BOJ7PYU3XM6/A%K#5O/N?AYHOB;2/!VJ^)(]4^P?V&8;'Q
M)K^C:9/8'4QJP?4+>X6P:S+7"]5^S=X/\9?%KX\Z!^U1^QM\4OA/KGB'X,>/
MOB)^QW^UW\,?B3K'CO0[-_A_%!IGBV[ALM,TOPYKUWIGQ:\`>/D\+>*_`5Q>
M:%X?T/QW\/\`Q#XE@C\<3>'?%'A[5[+\BKWPA^W;^S!XA_:*^#7[0WAOPG\3
M?V\/$GP_\$?M!^%_BK^S;\29KK0OC1^S+HWQSAT'7_@;\*K'XM^#Y=3^`/C/
MPSH>H>+_``GX=AG^'>J?#ZQ\5>.[#XD:GXJO=;;6=;;[2\$?\%*OVG_BU^W_
M`/LO?L^_L_:#\)?A?\-/%'QID?\`:4F\(_`W4KC1O&.A>%?!?B%M7^`O@[]H
MKQ7K`T?XZ_$CX;^'M&D\5?$KQ;\*/ACX4\-?#W1_"[:)JGQ!L?$;V'PW\5_'
M?0T^CCPYX*?24G+Q1X@KY;Q[P;7H\*\.\(X+$8W-:F<\29YP_@,5BN-,8\FR
M:>7Y?X>UL%Q#0P/!\L\S.EF&:9_AJE3$X+#9GA89/AO1\3..,=Q3P3!9'@J>
M(R;,V\PQV85Z-##T\+@\+BZWL<GY\3CG4GGL)X-5\='!491^KSDL'4G2IU<1
M/]VOVFOV]_V/_P!C;4_"FB_M-?'?PA\(]6\;Z7KNM>%]/U^'7;VZU/2O#LEE
M!J=Z8M`TC5VL86N]0M-/TO\`M$6C:]JDCZ7H2ZEJ,%Q:Q>$_L#?\%"M-_:QC
M^*'A_P")OA^Q^!GQ2T#XE:WJ/PU^%/C35[+2?B%XW_9D\:W5KK7[/OQ<F\.7
M,R/%J'B?P]JB^%O&GA_29]7E\#_$OPUXC\%:Y<IK5D%N/S@_:R^-5CIO[?'[
M8GQ&6UUGQ]9_"'X.?LD?LN^`?"'@R-M?UCQ1\>-<U/XN_%74?@YX4TO2H;BX
MN/B7XPD^.?P0M+ZQO(I4TC3M3\+:MJ=SI.B1ZM=6_P!'?"K_`()(_$W6_CW\
M&_CM^V=^U)H7Q[\._!W4/#/Q>\$?LU^#O@/X6^'WP^^'W[3GAVZT[5-`\=Z'
M\6VUK4_BSXQ\#?#K4X+F]\$^#_$W]GR:MXCM?#_C'QG>ZI)H>F^'++_3#(O&
M'Q9XR\?^-?#_`(4\/.&*GA7X69KEO#_&GB!F_%.:83'9MFN?\-Y+Q##!<)99
MAL@Q6"KYIPI]=GA^(,OQN*=*O]:PBCF642G3^N?AN+X;X?RWA++<WS#.\9'B
M#/,-4QF69'ALOHU:>'PV'QV+PGM\RQ,\92G3HYC"E3JX.=*DYTE2K-T<4JB6
M'_<2BBBOZG/@PKS+XS^&OB1XR^%/C_PK\(/B4/@[\3O$'AC4]+\$?%+_`(1;
M0O&TG@37[N$QV7B2W\+>*+:^\-:Q>:<Q:6RM_$&F:SHL=WY%SJFA:[90SZ1>
M^FT4FKIIWLTT[-IZZ:---/LTTUNFF!_$_P#!?]E+]L[]C7]NS2OC5_P4+U#X
M?ZQK'[6OP8NOA+\/?BQX3UGPWXCOKKXQZ5XZU7QQJ'PM^+OC>W\(>"_%GB?X
MC>*?ASX4T7Q-X8U[7+36?`\*Z'??#7P#KVDQ6'AKP8_MW_!0GX<>'-(^$WQ(
M_:-\/?$CXC_`KX\>"?A9K7A+X8_'3X<?&#XC_"2_^&;Z@==U(:AJM]\-]5L]
M6U+X=-XDU#2O&OQ=\)KI^KZ1XYTSX>^%Y_&&FW&F>"['4=&_J8^-WP'^#O[2
M7PZUGX2_';X=>&/BA\.]>>UGU'POXJL%O;,7VGS"YTW5M.N$:&_T;7=*N0MU
MI&O:-=V&LZ3=*MSIU];3@2#^>G_@HQ^P3_P3*_X)S?\`!./]I/6?^%.>#]0N
MOB]XK\*Z+9_$C]I3Q=KWQM\5^'?B#XNNM)T"S\2>'OB?\</$/BGQ/X%U+PYH
M.E:IXCT"X\,:[I%XWBG3[&:&8W\EK/;_`.;7C%]!G%9OXX97](+@/Q;SKP[A
MD&69;B\[RG+<HQ689MB)<..KB<5#*,TP>=Y75A3S_!T84,PHXG#XZK7Q]?&8
MG$1S"&.K8=?M?#OBO]7X4Q?!V;<.83/7C98^EA,9B<71H4<+''4E&A[;#U<'
M6IM9?7M6I5WB*$:=&E14W&5!U9_B7^P];^)?`O\`P4V_X)X?$C0?C'H?QO\`
M"OB/]IW]JSP]\0O#^F_#WQWX8^`_PS\1ZYX8^%G@6T\:>&+'XF20_$;QI\:O
M&]_^T;:ZEJ7[5'Q/U#4?B+X\\4^)3X:O+O6](\0JLW]KG[5/C#]L+X9:I\/?
MB5^S=\,?"7[07P\\.0>*+;XW_L_C5]/\%?&;Q?IE_P#V+<:!XJ^"7CGQ1JVG
M^`)?%OA!=.UF-?A_XVN/#>B^-HM;>P;QCH=^NFZGI7\8?[$/BFY_:A_;;_8W
M\->!39^-;_XF>"1^UW\=/^$;N;WXJ:5X2^(7Q3_;K^"_Q+O9O%'BK2M$O/"U
MMI/@?]G_`/9*;P/X6T_QGI/@SPOIEU;>#+2TT;7]3OM(2_\`]`2OWSZ(^,XL
MQGA?C<'Q9@L5A,5EO%/$>%P^+QM##8?&YG[3.,;C*V.Q%?*\OR;!9@O:XB-"
MGF.&PE"KF5"A#&XZ53&XK$U)_(>(-+`4\ZH5,#4IR]MEN`=>C3]I^YJTL-2H
M2YX5Y3JT)5I4YUEA9I1PT)PIX=2PBP\I?F>__!4+X=0.T-Y^RW^WY8WD+-%=
M65Q^R'\1WGL[F,E)[6=[5;FU::WE#12-;7$\#.C&&:6,J[%?IA17]5?C_7D?
M"-W;:22;;25[*_17;=ELKMONV]0HHHH$%>,?M!_#?X=_%/X/^._"_P`3O`7@
MOXC^&1X9U_4QX=\>>%M#\7Z$-2LM"U-;/4!I'B"QU'3Q?6@GF%M=_9_/@$TH
MBD02/DHK'$?[O7_Z\U?_`$B0X[KU7YGRU_P3`^$_PL^'_P"Q9^S3J_@/X:?#
M_P`$ZMJ_P,\!Z;JNJ>$?!OASPWJ.IZ=86T]U8V&H7NC:;97-[965S>WEQ:6M
MS++!;3W=S+#&DD\K/^AE%%;""BBB@#__V0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V%C
M:V\N9VEF````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(P-0`Q,#4Q-30S
M,3`V-P`P,C(W,S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S
M,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9
MS`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`
M,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-F
MS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_
M,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68S
MS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,
M,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`
MS)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9
M,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_
MS)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF
M,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,
MS,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S
M,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9
MS/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"'Y!`$``-@`+``````@`"````C^
M`+$)!$"0H,"#)`B2.(BMH$.&#1T61`BI(B02&"4^'*C1(#82%D->[.A1(Q*/
M($6&3*CQ(,&3)PNF5"F2Y42(#DFPF4FS9DR<#GL*K4@""42,.PD.';J0HD6E
M%Y>JQ.B4J$RI(P'HO"B0)R2%0C%FS,GU8TVO%S&N8'7M&JL5!=_NK$J3Q-JV
M>/&^#>"V:5>F;/,*?MN7(5J+"04KOK86[M&55@$L;LO*"JNW@?Q2U*DQL.(5
M@=8&\&B8#<F[BN/*Q&E3(^J\J@FRTLQ9XN45=E/+UDF"%0"GK253OFPE+URM
M%9-V97,Q:=RV*Z)[=HN;^<CE&"V:)GB7[5O/EM]C9N3H-3B`N]RG4VX*8"I#
MAVL+OJ;NLB9$P[XEP@U0PNA`Q)K=UUMG`9AP@E]:476?@.U5=!XK)9QPPF\+
M5OC>3+VM8."$%%I8(4^]!2#A"05VZ.%CD0&PH0DFF'BB820]%!```#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]C;&]W;BYJ<&<`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(S-#$R`#$P-3$U-#,Q,#8W`#`R,C<V-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#_V/_@`!!*1DE&``$"
M`0#(`,@``/_``!$(`+X`E@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'!P8(
M"A$+"@D)"A4/$`P1&18:&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q-#`K
M-"@K+"L!!P<'"@D*%`L+%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*__$`:(```$%`0$!`0$!````````
M```!`@,$!08'"`D*"Q```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A
M!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%
M1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9
MFJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?H
MZ>KQ\O/T]?;W^/GZ`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1``(!
M`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P
M%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#
M`0`"$0,1`#\`^J:`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`$=U12SL%4#)).`*!I-NR/.O$_QA\+Z#
MJ"V;7#WD@R)#;#<(R.Q-<M3&4X.VY[V$X<QF(ASVY?4R?^%]^%_^>-]_W[K/
MZ_3.K_5+&=T'_"^O"_\`SQOO^_='U^F'^J6,[HUO#_QB\*:NMR9+LV)AQQ<C
M;O'J*N&,I2ZV.7$\-XVBU:/-?L=5HOBS0M:CF?3=3MIEB(5R'`P3T_E6\*T)
M;,\VOE^)H-*I!JYHMJ=@HR;RW`Z?ZP57/'N8+#U7M%_<<!\4M,U3Q0ME;^'O
M$EUH9MI#))-!_P`M>.![UP5,PC&5H*_F;PP4G'FD<GIMC\2_!\1FTG78?%T0
M$DDMC?C9(QP,;'ZYXZ?6G3S"+=I(FIA'%73.B^%'QFTCQS<2:7=POI/B"!29
M;2<X#$?>VD]<>AYKO335SEL[V/2?[2L?^?RW_P"_@I<T>YI["K_*_N#^TK'_
M`)_+?_OX*.:/</85?Y7]P?VE8_\`/Y;_`/?P4<T>X>PJ_P`K^X/[2L?^?RW_
M`._@HYH]P]A5_E?W!_:5C_S^6_\`W\%'-'N'L*G\K^XD@O+:X<I!<12.!DJC
M@D"FI)[$RI3BKR5B>F0%`!0!X)^TWX@U.S&G:3:7!AL;E&>8(<,Y!&`3Z5YN
M/J25HK8^VX2P=&IS5I*\D]#YXKRC[ZP4`%`"4`21RRQ`^5(Z9ZA6(S3NT3*$
M7NKG;?!_0KOQ/XZ@EN7G.AZ/^_N7))2:;^&/-=,$HTG*6[V]#XCB3,:D<1'"
M85VY5[S75OIZ(^DW<R.SMU8YQZ>U<IXJ22LA`2"""01R".HH&>+_`+0O@07-
ME_PF_AVW>+7;)P;Z.V7_`%\?_/7`[CO7H86KS+V4GHSA;EA:T:T.CNO\CR"+
M4);F&.XAN93'*N[ASP>]<,E*$G!]#]9I3HXFG'$4UI-7^?4=]JN/^?B;_OLT
MN9FGLH=@^U7'_/Q-_P!]FCF8>RAV#[5<?\_$W_?9HYF'LH=@^U7'_/Q-_P!]
MFCF8>RAV-+PYXCU/P_K$&I:?=2+<1'HS$AQW4^U73JRA+F3.;%X"CB:3I36C
M/L+X<^+8?&?AJ'5(87@<DI+&W\+CK@]Q7NT*JJPYC\HS3+Y8&NZ3=^QU%;'G
M!0!\X?M3_P#(9T7_`*XO_,5Y68_$C]`X._A5/5'AE>:?:A0`4`%`#HHI[B6.
M"S3?=2L$A7U8]#^'4^PJH14G9[=3EQF(>'H2J1^*VGKT^[?T1]4^`?#L7A/P
MA8Z/$060>;.P;(>5N68?C5UJG/*Y^84H--SENSH*R-A*`'QL%?YAE6!1Q_>4
M]133:9%2"G%H^0O&6BQ>$?'FJ^&XF1K??]JM2K9VJW\!]ZZL1%S@JWR9]%PG
MF"2>`GWYHO\`-?Y&>01U%<ES[1IK<*`"@`H`*`/JW]FP_P#%NE_Z^'_G7M8'
M^%\S\PXK_P!^_P"W4>JUVGS(4`?.'[4__(9T7_KD_P#,5Y68_$C[_@[^%4]4
M>&#GIS]*\T^U6NQ'(\P#?9;*ZO70A6$"%@I]"?7VJHQB_CDH^IY.89UA\%)T
MVG.:Z+IZOOY$-E>BZN9K5X)+:\A.&@EX:KJT73BIIWB^J*RK.*.8RE3@N6:^
MR^J[DNG1:GKNKOI_AFT2\DA0M/(_"K^-35=##4E5Q4N5-Z=SS,PXAG3Q'U?!
M14^7XF]K]D>@?`[PW?7GQ"NKG6K2$IHT0&8I.(IWZ`^^`WYUO&I2^KJ=%NTG
MU[+]#YG,,PKX^LEB$ER+9;7?ZGO_`(EUBV\/>&]4UJ_;%O9PEAQG=(1\HQ]<
M5C2@YR43CKU.2.AQ7P$\7:GXT\$WU_K;))>6U[Y:R*NW<C=`1[=JWQ=&-.24
M3GPM64I69Z(QPK'T&:Y#T%N>?>+_`(A'PO\`%O1O#-]';C1=0@0O<.=LD4C9
MP=W3;TXQ^-=D,.ITG);GFO$S50R_VBO!*:WX;;5;2W5M6TT[C+$I\R:+N!CK
MQTHPM7EER/9FE6-XJI#1[^9XM-H>FVV@Z=XCT.^OFT::0PWZW";VMF['CMGC
M->='%UIUYX2O%>T2O&VE_P"MSV\OS*>#E&M"3=.3M*^MO/Y%"[GBMH_,+&16
M_P!4L?S&7T"BMZ<)3=MN_EZGW>+QE'"TO;3=TUI;5R]"ZF@^*I[!;^VT-EM<
M%FCE;]Z0.N!6+QF`C/V4JOO>6Q\W/B/%2:G1H)0ZI[_(S=/O8;Z%I(R8V0D2
M1OUCQZUTU:,J3L]>WF>]EV9T,?2=6F[6W3^SZ^0EGJ-G>2-';S@NI^ZW!;Z>
MM%2A5IJ\EH&#S;!8R;A0J7:Z/2_IW/L']GS3KO3OAY;B\C$9FD:6,9R2I/&:
M]?!1:I:GYWQ-6A4QS4>BL_4]+KK/G@H`^3OCWXDN/&?Q&@\.>#K%;R\TY"D]
MR6!CR>2,]!CI7E9G4P]&'M<1*T5][/H\DS;$8*$H8>*<F^NR1C:-\--7N++?
MKNH6MG=,V##",M&GJ#T)-?)8C/L/"=L/!R7=]6?68?.,76HR]NK2?PN.ECTC
M1=-L]$TZ*QTR$0VT?KRSGNS'N37SF)Q%3$5'4JN[?]61Y^'PT:4.5ZOJ^[.>
M\<_#[3_%P-T2]EJRIMCNXA@.>V_U%>AEF=UL![GQ0OJGT]#EQ>!C-\]-VEW1
M!X?T"P^&/@G4;B>9FN#&6N[M?XV_A5!Z9K3%XVKG.,A&*TO[J[=VS##X>G@J
M+G-ZVN6_@2G_``B_A"]\1>,M3^PKX@O%>(W*G/`.UC_O9/\`WS7V]>FO=I4E
MI%'AT:CUG+5ME7XM?%OP9K7@'Q!H6EWMS<7T^U8F$1"2$$<@^E:X?"U(34FC
M.O74_N*G[-_BSPIX>\%7>FZGXABMM1N)OM,D<Z[4C5>-JGN33QE*<Y72)PTU
M!J5^A[K<75M#I\E[/<1162Q>:UP[80(1D-GT.1^=>=RMNRW/3]I%)2/E?]I7
M7]&UKXCZ5>Z/J4&H6D5K$))+=LA<-DCZXKV<+!QIM,\:H_>N>W:=\8O`.M-]
MA76);,BU53)<Q%5.%Y`]ZX)X6HGS6.RGB$H\NYA>$_"H\.:;/80WUMK/AN^)
MFL6,?,D3\L']>M?)<1R7UJ-2*<96W].WIU/:RJGS4)0GM<J>&O`FC^'=5EGC
MDCG(<O8VUPP+6V?8]?:N'&9QB,7246K:>\UU_KJ>K1E&EAXX5/1.]_7HNR.M
M9G#DL6#]\UY*2MH;)*VFQY9\0O`0U3Q+ILFA02VYU)F75&B`$:(,?/[$\_6O
MJ<ISGV.&FL0T^3X+[W[>AXV(I5J=9QH.RJ*TO-%_Q)\,-&D\%MI^B0,NHV*M
M+:W1.))FZD.?0USX3B#$K&>UKOW9:-=$O(5;+%"BO9Z26W>YZW^SSX_TKQ!X
M(TW3);F&WUJS0PS6DD@WMLX+@>AK])A&*BN78^7K5JE6HYU7>3W/71R*HR/-
MOC)\4K;X?6L%M%97%[K5]&QL843*,P./F/8<U,I1A%RD[)#C%R=EN>7?#_2K
MK2M"FDU.W@@U?49WN;PPCEBQR`?3&>E?EV>X^.-Q;J0=XK1=OD?:97A/84ES
M+4Z,`>E>.>F4-;U(Z99QR1P-<7$TR6\$8X!D8X7<>RYZFNW+\#+&UU23MI=O
MR6YRXS$JA3YK7*NE?"W6[N[%[XN\7W9>4%IK#3/E1&/0*YXP*^YIX?`48J,*
M2=N^[\SYIU,94=^>U_Z]3.U7X%WFK6QMM1\>WUQ:A]R126[$#TSZFMZ,L-0E
MSTJ23,JL,347+.5UZH]9T;2H=.T#3=*F$5\EC`L"R7$0?=MSAL'H>:SE5DYN
M2-8X:+ARR[GG/QT\$>&I?AMKNK0:';6VJ6K++'<6B;69B>=PZ;?:NK"UYN:B
MV<V)H1AMV&?!?P9X4U7X4:!>ZIX;TV]NY&DWS2J=S$$\DT\57G&;29.'H1J;
M]$>FZCI6GZIIG]F:E9QW.FD*#:L2$(7[HX[#TKBC4E&7,MSNG1C*/+L?/W[3
M/A/0=&TWPHN@Z-9Z6+J9UFDMT/L!GU]:]3!UI3OS/9'FUZ2A)Q7<]D\/_#SP
MKH>GZ3&F@Z;<WMK;QL+V2++.Q&=Q4]_K7%4Q-1O1G31PT)QYF+XZ\.:IXAT^
M*RT;6H-#@`^=DMBS=<C9C[H]:YW3P]5IXB/-9Z&\O;T]*&B.1U+X&:'?V9D7
M6M9'B,@-_:LTNY6<=]@Y`KIIUZ<(JG&"4>QA.A6;=1RN_P"OD<5X"\6ZM;^+
M;KP9XJCFFU"&1Q!=,N&8#GYQZ$#(-?.Y[DM*E2^MX?2/5?Y'IY=F,W4]E5U\
MSTW)P1DX/4>M?)'T09.<@\T`>??$SP397VEW6LZ-;&RUZU!G#VH(-SCDA@._
M':OHLCSJMAZT:525Z;TUZ'B9CED)P<X+4^EOAWJ=UK/@;0M1OPHN[FTCDE"J
M0-Q'/!Z5^E-69\BG<XSXN7NB6OB30DOKFU@U::.1+;S1ABO&X;NPKY'BJGB9
MTX^S3<%O;\-#WLDJTJ<I<^[V.<5D<9CDCD7^]&VY3]#7P+36ZL?4PG&:YH["
MF@HGT[4K'2]0MY]3N([>"1Q"LDAPN]N%!/;FO5R6_P!:5E?1['%F,E&@[]SM
M[EH[199+Z:.U@A4O+-,VU$4=\]*^RC!RERH\*56,8<Y@^"?$+^*M&FU8:=+8
M6+7+167G'Y[F(?\`+4CL#VJZU)4W:]V94*TIMIK0WJQ.D25$EAEAE4/%*A21
M&&0RGJ#[4T[:BE%2W(-)TZSTO38[+388++3X,E4&(XX\]?:G*3D[R9*C&&RU
M\B.76-(BNX+676M,6XG+")!<J=Q7&X$]L9%7[&I:]CGCC:4G:+V%U+3--U^P
M>TO(['5;2*02/$CK,(W'0D=C27/!W6A:J4JK_P`RYG(7T"A1[`=!69NHJ*L@
MVE@55E5R#L+?=W=L^V::M?44W)1;CN<1X-\?)JOB";PQXBLCH7BV!B!:NV8+
MD#H8F/.2/6NJKA[1YX:HXZ>*=[3/*?C?92VGQN\/-HL2QZE<*C3)`X$C<_-O
MQ_L@_A2K<GU"JJ^R77OT_$E7]O%T^YZ>^-[8Z9K\P6Q]JKV$7YF`!&3TI[#>
MAF>!I-0\:?$*>QT[=9^']%<?;IF3+7<G:-21\H'MS7V^2\.TIT%7Q&KEJDNB
M_4^8S#-JL:KIT]+'T2```!T%?:+0^>.5\?>`/#WCRTMH/$EC]H%N^^)T8HZ^
MHW#G!]*+@?,LVLCX2>-+[P;KS/-X?\SSK"Y4$O`C<@'U'8U\MG_#T\4_K-!6
MGVZ2_P"">UEV8NA:%3;HR/Q;\6[>&W:'P7`^I77EEY;F2([8!Z@=S7F97PCB
M,1)O$II+HMWZ^1W8K-[JU%7_`"+UCKN@>/OAK++XDO4M1"H-\8SAH9!]UU'?
M/I7%4PF+RO,4L+'FN_=\UU3]!JO3Q>$?M-T9OPR'B_XCFQ\.^(+JZE\"Z?,)
MY)Y8L&X1?N1ENX/I7W%24:4.9:2?3LSP(Q=25EK^I]+.P9AM4(B@*B*,!%'0
M"O*;N[GK0@H1Y4-I%%76=1BT;1+W5;B%KB*U4'R5."['I^%*4N5<QOA<-+%8
MB&'@[.77L>)Z_P"*=;\1VRP:Q=*;7=YBP0C:!Z*<=0*\RKB92TN?H.#RG!X*
M3E0C[UK7?YG%7GA31KL#S+5D8,6W(Y!R>M;4\SQ4-I7.3$\/X&NK2@EKTTW,
M75AJ7@&XM]=\&WUW9X8+.OF%@3VR#U!]Z];+L<\5)TJ^KZ'R/$.1PP,%6PZM
M'9K]3ZC^'7B1/%W@C3-:%PD]U*I2]95V@3CJ,=N*6(I^SFT>-A:G-&QT1Y&#
MT/%8'4<1\4/AO:>/&L;HZA+I6OV"[;6\0<..JJW<8/>NNAB73T>J.&OA[^_`
M\-\"_;_#'Q:OM.\?0RG7[M?+AOKA\@'LP8]0P&`?>N+B.C.O@E.@_=B[M=_^
M&W+RRI&G7]_6YZ'\1?%?_"'Z-#<10I<:E<R^7;6S@D2`?>/'I7R>2Y5+,\1[
M)7Y4M6M_)'OYACO817+JV<3:_$SQEJD<L6F^'+:VN-RQK.X(\IB<`X/6OLJ?
MA^^6523DXQW7<\ZGC,9B+PIPU\SZ>^$?@^?P;X7-MJ%\;_4[N5KJ[N,8#2-V
M'L*^@I0C3IQIP5HI:'SE24I3<I;L[:K)"@#YH^,\<<OQ$NA-##-MA7;YJ!L?
M2OT/(Z%.I@(N2OJSWL$[T%=7]3C84C@+&W@@A+C#>7&!O'H?45Z\<-2C>R.M
M2M\*2]$<7=^%+?Q'XRT_PSX;MX;:YN"9;J3S_EVCDY'MUQUK\_XDCA<+)*G'
M5:_?T/*Q4*?.J=-6[ZGU>7T[P9X,02RBUT72X@OS/\H/L>"2?3K7P?OU9:=3
M9<E):[GF&I_'G3%O3_8>C:CJNFJ!NNXXF4`]Q@CM6WU91TG-)]KE0E5J+GI4
MY22ZI.QWO@SQYX>\9R7*>'[[SY+<*7C="CX(ZA6P2`>,]*RJT)T_B04ZT9[,
MT?&>F/K'A+4+2"-I;M1YD"*VWD=?K]*YJL>:#1ZN5XI87&PJS=H[/^NGJ>!V
M\R3PAXW5@#L8J>C#J/K7CU(2A)QDK,_185:=1<U.2:[IW)*DLXSXCW+W45IH
M-E;S7%_=R*R)&I)//`'J37N9+0?.Z[>BT/BN+L=#V:PJ7O/4^I?`&@IX9\$:
M+I"VJ6L\4(>ZB5MW[X]23ZUO7J<\VSY/"PY8MGF_CKXP75MK]_X<\(Z>MQJ=
ML6CEN+@[$0XP<`\DAL^U:>SITJ:JUG9,WHTJV,JNCAU=KSL8GPY^+]]H]]#X
M<^(8=Y)I1Y6IL1A5/9\<$9[BM'2IUX>UH/3L95H5\%5]EB%9G<?'+P%8^,/#
M4NIFZ,&IZ;`9;:Z#;DDC`W;>.Q[$9J,+6=.7*UHS&M24USQ9X5X'NKG7XUUC
M6KB6]O+0"WMC+]V%0.H'=O>OT/A')L)0A*M3C9N1T82<JR]K4=VM%Y?\$ZVY
MEE:,N9':1/F0]P>Q]Z^ZA&*=K:,[7)RTD[GU/\/]0?4_"&F7,UTES.8@))%Q
M][OD#H:_+LTH*CBIPC&ROH?.8B')4:2L=#7GF(4`?-7QE!'Q$N\XYA4\&OTC
MA]_[!'U9[N"_@KU.(N9EMK::X=2ZPH7*COBO4KU/9TW/LCJ;44Y/H;?[+]A+
MJ$GB/Q7=.KM<2"VC1ERR?Q9#>F.*_%LZQ<L15<I=3R\,W4J.;ZE7X^QKJ/Q8
MTG3+AWELC8+(]N&.W/J17GSJRHX.52#L[G=E&'IXK,%3JJ\=2'3=*NY[>5=)
MTR>Y@MU_>?9UR(Q[UX$*-6O>2UL?I[GAL,HTYR4+[)]3FCI+:5>V^M>%2;;4
MH)O-)B8J95_B3VS7?ALQG&7L\0_=M;T\SYW..'(2IN>%BE.]_7R^9]$?#KQG
M:^-=".I6<1L[JWD\JYLV<L\##NQ/K7;6I<C36J?4^*I5&VZ53XENOT.7\=_"
ME=9U2ZU?POJ;:-JMS@SQ`9AE/=BO8T<].:4:T>9+[S>E5Q&%;E0FU<Y0_!KQ
ML`2OB^T)[9AI>SP7_/LV_M;,O^?OX'5^&/@UI&D>)K#7;[4+S5=2M\,$F.5:
M0="!Z#L*OZQRP]G3C9>1R583K5'5K2N^[)/CI\1[7P=I$^FVUR[>*;Y?W4<#
M_-:@_P`;D=_05>&P[G+FELC"M727)#Y?U_5SR#P?H#V,,(6"2ZUF]8;U4[GD
M<]L^GO7DXO$3QE;DA\*V/TC)<LI9?AO:5+*5KR;Z&Y\6/A]=:;!;VFJF"2[D
MB\ZTFCXPXZH1_7O6\8U,NK+71[G)76%X@PLY48OF@]+_`(/Y]CVSX=7][JG@
M+1I];T_['>"#R);9DP"J\!L>A%=5=14[Q=T?"X92M*$E9I_B?.OBWP_%\.OB
MM_9\=^\FF:K']H2,#E-Q.U6'L>]?9\+9@XUE&3LGIY7Z&="2I5^6^C-Q@02#
MU%?IR/4:L?0/P%_Y$./_`*[/_.O@.)_]^?HCQLP_C?(]&KYTX0H`^2?%!8^*
M]:+.[G[4W+G)^E?K&"M]5IV7V3Z2E_#CZ'.^(I3#X?U%Q%),?)*[(^O(Z_05
MGF$^3#S=KZ=`JNU*3M?0]D^`YB;X0>'/)\K(202>7C.=_P#%[U^&XO\`BLX<
M%\+,/]H'PU=7NGZ9XGT:T$EWH[$ZA)&<2M;]L#N!S544JM.5&75?B:0K/"8J
M%=:)/IVZECX">)88==>WCN(%TS5$\R-I#@M(.@'^%<F55)4:SHU-.C_0^OXE
MH0Q^`ABZ-Y./;^5]SJ_B7\,5NI)M7\-1K'=-EI[1>%E/]Y?1OYUUYCEBFN>F
MM>QY^0\4.FEAL8[QZ2ZKR?D>6>$-9F\):_/>06RF.Y(34;5A@R`?Q?[PKQ*6
M)G37LY/1?U8^HQV283&P<DDIO527Y/R.@O/C?IFG:U>0:CH5^NBJO^@7D2Y>
M=NZN.WM7L4J=.M'W):]5V/@,;A,=@JC5:/S6J^0T?'_PAD;M,UD+D9/E]!ZU
MI]3EW1Q^WK?RO[C%\1?%WQ'K4%SI_A#0WTB.9L1:O<MB18O4#LQK.57"T%>4
MN9KHCNHY1F&*DHN'*GU>W]>1QVB>&%^VR7$XGUK69G\Q[F0%VW5YM?'5\2^6
M'NQ[(^RR_(<+@(^TK-.7=_H?0OP\\(P^"K*X\2^*+B.&Z$)`0XVVZ=<>['_Z
MU>O@<)'"0=6KHSY_.\XEFM2.!P4;QO\`^!/_`"1XC\8?%TFHWEYXBLT,*%TC
MABG.=R`]0.Q-<$91QN,Y6M/R/<K*KD>5*$&G*+N_GT\SZ(TV<W6BZ3<,"&EL
MHGP>V1TK24>5\O8^+I5/:7G:UW?[SPW]I=M+_MSP<B"+^W?/)E(^_P"1GY,^
MW7%?0<.\WUJ';F..K_'C;O\`\.9,O^L>OV6.QZ\MSW_X",I\"HH92PF?*YY'
M/>O@N*$_KK?DCQ,P_B_(]'KYPX1&8*I9B`H&23VH2OH@/DGQ,RMXIUED964W
M+892"#]".M?K.#36&II_RGTE+^''T,NXA^T6T\&\IYJ%-PZC(JZ]/VE-Q[HN
MW,G'NC0_97U^&VDUKPG,<3B4W,!(.Z3'##';`YK\4S;#N%1^3L>1A9*,G%GO
M]Y:0:C87=A>[OLMY"T,NUMIP1Z]J\F,N5W.VM#GC9'RAIUC?^"_%5UX5UQ6C
M>.7S=/8_,KC.0588S_\`KIYE14XK$TOF>_POF?LY/!U7H]OU7_#H^GOA]\38
M-8E33M:2.SNP@$<N[Y)2!SDG[I]OKS79@<TA6]R>CL<6=\,3PT76P[YHWU75
M=O7^M#0\0_#31=82^NH-\>H70+I.&RH;L<>E:5\KHU4Y+=G-@>)L7AG"G+6$
M=+>1Y/J7PW\4V$T47V$7I9=QDMV#*I';YL<UX57*<1!Z*_H?:4>(\LKQ<G+E
ML]FM?PN5!X"\4DX_L2?'_`/\:R_LW%?RLU_MO*_^?J_'_(T]+^%WB;4K4RRQ
M161\S:8[E_FQW8`9%=%+)J\M6DCFQ'%.7T)\J;EIT6GIK8]?T/P_H7@/29KM
MF6+:@,]S*>6P.W^`KWZ&%HX.'-^)\+B\PQN<5E36NNB7]?B>)?$;QI/XLO3N
M)@T>`[HH&.`<?QO[^W:OGL?F$L1/EAMT/T')LHI951<I/WVM7V\EY'$_#;0D
M^)'C^.\N(/.\+:,<S[Y-HE?^'Y1R<G].]>CAJ/U.A[WQR_`^)SO,O[1Q"5+X
M(Z+S?<^FU4LRI&@`'RHB#`4=@!6&[,$E")\L?%_5[+Q?\9+"/1'\Q=-B6&>5
ME*J60G=COQTYQ7UW#>%J2KP2[W^1Y\5[3$+E[FNYRY(Z$U^L):'L-W9ZO^SS
M<6\5_K%N\H6ZEVNL9)^91W`Z5\KQ7";A3FEHCS<Q3:B^A[?7Q)Y(CJ'4JP!4
MC!![TTVG=`?(WB`1)XDUB.V"K#'=,H51@+[8K]9PKD\/3<MW%'TM._)&_8HU
MN48.L6-WI]_'XD\-W#6>MV7[S='_`,M@.HQW/\Z^8S_)J>)INK%>]^?_``3D
MQ.'YTZD-U^)ZW\*/C%9>-;]]'URVAT;Q!G]RF2(KGU7G[K^W>OR[%8&5%[')
M1Q33M/\`X8Z?XF>!X?'&F6UK)<G3=3LI/,M[O9ET/]T^U<M*IR7C)73W1U2B
M[JI3=FG=-'@6I7NL>'-0N=/\7:/<0&WP)+V",F%E/`?(['C\ZYJN4W7/AY7\
MGN?48#BVS4,7&WFMCK?"GQ6O-/T]QI>N0O;.W"79YC/H`>@J8U<=AO<L_P`S
MMJTLES)*M)I>CM]YV&A?&W4$A:"9+'4[DMN5HY`I`],"MX9KB*<?WD?FSBJ<
M-9;B:G^SU>73;<U/^%TZCC/]B0X]?,-/^W9=D-<%8=[5G]QFZS\9-8N(HC91
M6FGB,[I7=@P8>G/2LZF<5IV4%8Z*/"."PZE*O)R5O2QYEXA\?WNM7%TJR:CK
MLA=9)(;-"T49Z#GH*E87&8GWJCY4^_\`D*IG&5Y;:GAHWDETWMYLW]&^%'B/
MQ7IDA\63/X?M]^!:6R[VF4=2Q_E711HT,++FA[S[OIZ'SV.SG%9A#V<O=CU2
M>Y[%X1\(:9X,T8:;H5FT%M(P=RS;I)6QU;O2K5I3?--GGT53CI%ZHQ?B7XH7
M1-*GT[3VCFUVZ38D>[BW4\&0D="!T]Z]O(^'\5FG[Z'NTD_B?7R7^9HXRJKW
M=CP[1-(@TFV$<9$MP<^9<D?-*2<\U^M8#+Z>#IJ$5KW-:5&-*-E]YHUWFAW_
M`,"O^1]D_P"O5J\#B;_<5_B./'_P?F?1-?GIX@4`>8?%+X<1ZV'U?0U2#6$7
M,B`86Z'H?]KT-?39)GKPUJ%?6#_#_@'?A,8X>Y/;\CP5]T;O'/&\,J$J\<@P
M5(ZBONU9J\7='L;[`)%!!##(IV8]3.U/1]*U29I[V$B[(&+F%MKH1T8>]>7B
M\HP^)NYQUL9U*%.J[U%KW1V7A3X@>*-&9;77;NVU[28S\LQ&V[*]E-?)3X%C
M5G*U1K33U\_(YZ>#E3D_>TZ=_FCT2U^(OAO4XHK"YF79<C$EO<1@H.^UB?I7
MS]?A#-L/&4^524>JW?FBI8>^K1%?>`?A_P"*KE]5ET6SNI7&UI+.38AQ_LCO
M7BU)8K"R]E53B^S.:6#CS?YG/ZU\"/!FH:A%=Z?)?Z)L3:8K5MP8_P![)Z&I
M6-G:TE?U)^JS@TZ;L^Z=A-.^!^BV%Q"\'B/66A20.\#@%9<?PD]@>*SJ5:53
MXJ:N=E#$YA0LJ=1I7OW-OQGX4^'UCX:NK[Q)IHMM)B(WLLQ#,W95]3[5&&AR
MU$Z:U-LPS+&8BE[*O5NOZW//-,^--KIVG2:9\.O!GV2#=Y5I<,H"/_M2'N>_
M6O>H9+B\7*,DKI]3QZ5)RTA%N_W&3=^-_B=JNI/=MK5KH@0*$MXP"C$#!/?K
M7N8;@ZK*+Y]&CI6!K2^*R&>';C5]%N+Z]AU^\NM2U!2EY/*<J0>3L'8^]?28
M3A;`4E%UZ?.UJK_UL=5+"TZ>KU8J+M+$L\CM]Z21MS-]37TNB5DK)=%L=#8Z
M@0C,JJ68@`=S32OL!Z[\#/"VH1Z@_B*Z'V>TDB,<,3#YI!_>]A7R/$N8T73^
MJPUDG=OMY'FX^O%Q]FMSVROBSR@H`*`,+6O"6AZU=1W&I:?#-.@(#XP>?7'6
MN[#9EB</%PI3:3-J=>I!6BRA_P`*[\+?]`F'\S71_;>._P"?C+^MUOY@_P"%
M=^%O^@3#^9H_MO'?\_&'UNM_,'_"N_"W_0)A_,T?VYCO^?C#ZW6_F$;X=>%F
M4JVDPE3U!S0L\QRU]HP^MUOYCD?&_P`-[W39;+7OAF8['6;!=AL)&_T>]B)Y
M5AT#>]>;CZU3':XA\S77J2\34DTY.YI^%!XIU,R)K_AN+2&CB#;UO%F65^X`
M`^4?6O$J9?-?"[G73QT?M(Z%-'NRX#!54GDAN167U&MV-I8VDEH>-^(/AOXM
M^)7CR"/QK:G2O!UF&^S6]I=*Q)'0MQR6[GM7J8?#JDO,\RI5<V>NV_PX\*V]
MI%:P:1!'!$@147(&/\:]BCFF*I1483LD:1Q=:,5%2T0O_"NO"W_0)A_,UM_;
MF._Y^,/K=;N9>M?"?P]J,T#P)+8B,$,L!P'^N:ZL/Q'BZ2:E[U^YI#'58K74
MH?\`"F-#_P"?R]_[Z%;_`.M.)_E1?]HU.P?\*8T/_G\O?^^A1_K3B?Y4']HU
M.Q<TCX1^'["^%Q,9KQ0.(ISE0?6L:_$N+JPY(VCYHB>/J25EH>A1HL:*B*%1
M1@`#@"OGVVW=G$W<=2`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H
M`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`__9````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]D=6-K+F=I9@``````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,3,V`#$P-3$U-#,Q,#8W`#`R,C4V,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$@`"``]P``````
M```S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9
M`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\`
M`/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9
M,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`
M,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"9
M9@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`
M9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^9
M9O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`
MF68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9
MF<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`
MS#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9
MS)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``
M_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9
M_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`
M__\S__]F__^9___,____^+\D````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(?D$`0``V``L`````"``(```"/X`L0D<2+`@-@`(#2I<6!`A`"L0`3"<V!"B
MQ8@4*3Z\:%%B1H8;.5KQ^%'A0X<H1Y8T"6"%RQ6!6*U(N++ARQ565K`*-+.F
MS9LQ79*LB;)HT8Q&`RE=RG0I"Z,$C4J=2O4@581[LFK=<^+IU:]8L.X!D!6A
MUZ]3QSXBRW;MB:M6TP)8"R#L7+93!U(=>PTKPKYOI>H%<,W*M6L[_1YFNW@L
M@)B%^THD?+AR9;*.!]7%^M:R98>'9SI<T5<K`%(`3G`E++KEXK^>#[,Z[9"4
M,=0(40>*W3=NT;ZW@]L>;HRP8)`(A2MWZ%/@:>7#AQ)UN)RYS^?$L]^6KM'V
MU^T3BSR*GADL>["6"%L/37\SZ\P+4@E@OBGZ('V7>T03N$"@?W_^+>5W7TOW
M"546`!<DF*!?!39HX%9%0=A@0```.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5I;G-T
M96EN+FIP9P``````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$P-C4`,3`U,34T,S$P
M-C<`,#(S-#8T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1
M`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!
M`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P
M)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!
M``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$
M``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A
M)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`
M_&TL!G@\=21@#/OSGMG_`#E000".A&1]#2K_`*Z,$&7:?FB2-F7D$C<XP#P<
M\8()QC(S3;F:.UA>\O?+T^T^V20M/=3VEMLC\TJGD64MR+FY!^4*Z%05._8`
M"!R5ZL5>V(5)K3:+U3C?=/H]_N&Z6)<4Z-)UW)+1)Z-VT]UIO7T^9PGQ%TO1
M_$?AZ6'Q#>2VWA[3`VJZO;6\>H&QU.31/^)M):ZA%I5O>:E=Z;BS)U"WLK.Y
MN+FS6>"WB>5U6OT__P""97_!2WQ7^R7;/XK\#_'?1-3_`&7/A[XZ\->'/VD/
MA-K.F:+>^(?`/PO^).HZ]\-?#?Q5\/Z3!J?@'QAK$'AWXFOX8T;Q)HW@7Q;K
M>N>'Y]6L]6M/^$IT*WN_M7RA^R=\9_`_P,_:<^!?[0?Q:\/S^*/V5?#WC/Q)
MX(^+OB[3_"5OXJ\/>!_%?C'X>>,-&\*>(39GQ%Y5U=^&_&$%YJVK>!)[/6-2
ML]'\&Z]>27UZ(!;M[M^U_P#\$8],T[]OWX>^%/A:NH0_LU_MG:%\:]0^&'B.
MS_LQ/#/ACX@R_#KXA_$[X>^`+"_L--^PW/@76_$"Z2WPUT?5_P"U?$WAKPA%
M//K_`(GU[Q/8P>)H/`EF4ZDOWJNDTGJEHG'F?3HF[Z7=M]3Z+`Y)4J8"%=U'
M2Q:FG/#<J;E'1VM*\O>LUI9];K<_;[X(_M">"OVD/VE_VQOB]^S?X4^)WPQ^
M,$.L7'A7]N7]CCP'XN\.^))_VM?V3YEU;X=^#/V_/A!<:9X-TW3[+X]^`)&7
M7_#>B>#_`!EXMU3XG:!X9B\)V%YJ^F_%7X7?$;QE?_9'_P""<_\`P4@UC0OV
M?_V7/VA_%7PY^(O['W[(O[4WPA_:E_9U_:%UG5]9\+?M!>+O"?@!]:UJR^%_
MB[X:R6>L^)/`FM:BGBJTF\1Z%XPBTV;X;PZ78>$+:[\4-=1W-?-G_!!_]D?X
MV>'/CE\!?VQ_%OCIO#VG6/P*\3_L@_'/X1>(-(N=&\6V/C#X17GAGPSX8TK0
M;ZS?34M/`V@V?@KPA=7FHZE'K)O]0^'^L:=875O9/HNF:7^DWQ5_;M_X*'>`
M_P#@JW\#OV,/"OCC]ACQ5\._BTVO^,9O#FB^"_C9>>-_AQ\#M"\&^,/&MWXM
M^)WB>Z\=KX?U;QEXHTWPCJ6H^%K'PO;*^IR>'+71K30;'3+[6_$VE^M@,;A*
M_-3IU8J:M'D3NV[1TNVWM_*]DM>AY>89=CL).,ZV';A42<;Q:<5=:Z=.^_GH
M?O+>^'/$]S>7=RNB>!KE;BZN)UN)[/Q9!-.LLKR"::!--N$AEE#;Y(EN)UC=
MBBS2A0[%=?+XEU@2R"/X;>.IT$CA)H)OAMY$R!B%EA^T^.;>Y\J08>/[1!!/
ML*^;#%)N12O3LO/[W_F>7:76EVZO^Y?KYL_S*O\`@GA^P=\6/^"G7CO7=9U#
M6=<^&O[(_AG7+K1]=\8Z$\2_$_QQKZ6UP^G>&OA]:WT3Z);:1#=PQ#7-9U6V
MEN(8;343!=1DQA/ZC?@)_P`$H?V"/V9[+3/^$6^#7A+QSXQTNY^S2_$#XO:5
M9^.O$#B*%K.XOM1_MF35?#MQJ=^OFR7USI>G0V$EW/+-810P&%5^L?V>O@1X
M+_9D^#OPV^$7P\T[3]+T#P5X1\/Z/?W.EV%IIA\3ZE;:1#%JOB+5_L44`U2_
MUZ_EO=2NM0O!/<WKWLEQ<2R/.[-T?Q5^)_PS^"OPV\:?%WXAZ[;>!/A[X`T*
M[UJ]UJ6S34(;+2=$6.[DO8-&*,ERT7B,6?A?2O#J1;-?L[I=.CAE@E\H_B.;
M9CF6-QZHT9U(1C+D:C.2O:5N9Z^\WU;>NVBLC^DLHX8RW),'3Q^)]E+FI0JR
MC*$6DW&#MJFEKIHMM7>Q^3__``6MTWPEX#^`?PP_:'\2Z/H_B'X<?!K4/'?@
MKQ?\,I--;3?#^L^&OCA\.-=_9VTG6IB87LM!;P1XQUK0_&/AO5+>WB/A7Q#H
M[:[I/V34+O49[O\`F(^!O[4/A;]BWPQ^S9XD_9K_`&B]=^)FJW'CRU^,?[6G
M[).L>")/#OPQ\`7/P_\`$\7BK1I_AA\5];N]?\.:2FJZ9&^BWT>C:1H2:Y)=
MV_A5Q)IVO7.F2?TE?M5_%?\`;)^.?[.'Q*U[]J#_`()^?$/X?_\`!.+QOH&@
M:[XB\?\`A?XG_#OQI^U+X(^%V@^+M-\6:9^T;>_!7P]HZZYH-G\//$UMI_C_
M`,9>'/$$E]H%MX>T[7-2\2:%J>CIJ%M>?)O[,G_!%SX8_M"6</C[Q]^UKX+^
M.G[/GCWPYK5GX7\*?`WP?X;^$NH>*]*U:U:VL]7^)^O>$K'3;3QAXV\"!K7Q
M3)IME!#?KK_AZQN)08[9TKZC"UZ^`P<:F84U/VDHI\[4_=DH6NG?5)RZ]XMQ
M:U^"S*C1SO/8YGDV,I4IP<(O!T;PBW":=E&*2YI:+2+U:=V9WP^_X*8_M+?\
M%#?BK\/M+T'Q_P#![]@;]F&W^(\/C3Q;KVN_'CP=K/QY.BZ7K^G?$;1M*32_
M$^E7P_L>_P#$?A/1DDT93%HT]I?:G-?VEU;WNI6]]^F?_!8/3=-UW_@F1\1O
MVH/AYXI$T/[.WC;X"_%?X7?%/P9?Z;K.M:W\1+']H/P/X1T7Q3X3UO184T'Q
M.VC'XE^)=;T+0/$ECKEEI_B?^R=#T+3K+2KF:TKY6_8/_P""??P-^#7QVB_8
MB_;&_9C_`&;OCU!>7'_"U_V;_P!J.[^"?@O6+GQ_\'(=2'A;4/AW\6?$FH>&
M+G5=4^(&CZ+>7QT>\UJ^N+V+6X=,:"19EBD'Z7?\$^O@YK_[5'C#XB?M-_%[
MQ#X*\._L3^%?B?\`%CX4?L._L;_#A]*L/V<-*\)?!OXC:[\/+?XY?$OX8Z>8
M/AKXQ\;Z5KO@F^^(/@RZ\5>'KJ30;?4].\5Z7=6FJ:%H]Q'UY;A<)F&.AB\)
M-49X>:ER4ER*?+_-&.ZM)+7LM-%?#B/,<?E="&'QU%5:N)BO8NI[ZIN32?)S
M+W7=.\EKK?5NZ_+OQK_P<U?%WP)XR\6^"/'GP";PUXY\&^)M>\*^,_#EP/C-
M;SZ!XK\/:K=Z1XBT2:WLO$L-G!+I6L6=Y820VD,5M$\#)!&D2HH*_GR\5_`O
M]MWX[^*?$OQPMHM?N[;XRZ_K'Q6M[KQ#HGAG4]?N8/B)J-SXOBN-<U*Z,USJ
M&L31ZPLFIWUQ-+/=WK3SRR222,Q*^O\`]J_FE]_I_DON^_\`.?K6)Z02VT[?
M#IMY_P!:W_0WX?\`_!??]OWP;HFG>%OB;^S3\*/B>NBZ/8:#I_BCPG+X\\.Z
MOJ,6DVD5A87?BB>[U/Q!H$<BVMO;Q37%A9V[77EB:<"\EF<_K5_P36^*WQC_
M`."MSZ]X]_:A\%_!?P-^SC\%/VA_A+IMS^SGX3L?%'C+5_CE\1;2T\[PM!\6
M=<\6:WKGAG6?`?P_6*#XE)\+?#'A+PVGB3Q?X;T_4M9EFFB:(_S4L"H0L"HD
M.$+#`<@D$(3PQR",#/(([5]*?L;?M/\`QB_8O\5_$.;X>S>'-;\/_%'Q%X+\
M=:YX$\2?VGILD^O?#*_AUOPMJ6E>)M"@U22WFFO=?N+@V<VFF=%TV\@?<T<Y
MA\BAE&`PLZ>*G&,IQC&4].9J7N\SDG?=W;5M[VLKI>W4XKS_`!6&>"GC)R@U
MR1@DY-1M%*%XIVLM'>[T3\S_`$<]/^(/A75=/\<VDF((O!7BF#PQX@9$EYO-
M1N(+$7#K;/%<233&Y$<[12I<2QL\:R*S@C\"/C5\!]+_`."6_P`=9?C-\*(K
M+P1^P-^T1\4=7M?V@O"S65II?@[]F'XZ^.#$WPE^)OPL@M+/39O#'PW^*WCM
M-%^'/Q*TRU62Y\#?$OQ+X93P;?:#I>H:GI]U^7'P<_X+A_&KXF?'+QE^S]I_
M[-_PVOKO]JJRURY\'ZCX@^-]YH^D^+_'=KHU_?:+!8>([SX+ZQ%H6O:=J%M!
M?V?@KQ=HNI6/BJYMH_#NH10VNIRSQ?5?[2W[;WQ8_:._9`^)_P"Q)^U)_P`$
MMOVRO&GC;X@^%[KPMKEA\--;\#^,O!C:EHUS;:YX+\3Z/\;8[Q/#RWMEK&C:
M5J>F:Q:_"/2;'PS=65K'?+&=\RZ8]8#&8;ZO6ER3BGR/16D_@:6V^WGH8<.4
ML^R['PQ^#P3JT%6I^V=U-**G"4TTV[-QU6E[[:+7]H3(MO):ZCI\]K#<6'AY
MA9RV6H6]I]CDN&77=,U;2;O4UN;.TTOQ)K<%A!I/BRY@N-9/B*\TZ[GN;IXQ
M$W\I'[/OCKP;^R]\+OV[?^";GPJ_;LMO'G[&WB7X8>.=<TO]H/0?"_B+3/&O
M[,'C37]9N-`UOPAXAU&'1M$\+>)_"WQ(\'>'-8TFZU+038V6F^,(M6\76^D2
MZM<QW]A\P6__``4&_:/\$?LGZI_P3D^(?C5_#/C'X2^$=1@_:(_:M\-^)K;5
M/%'P,^'4/B)]4TCX2ZE!H<4O@KQ!\4;-?%5E\$->O]0\6Z!)X;OM2L?"UQHS
M>)O`&H:5>87[!'PH\3_&:'P1\0K;P[-\-_V2/`7B#4)_`_P>O[:ZUN;XO^+O
M#]O=7NG?%#Q_?>3IG_"01Q>)8['5I[71K"ZBTOQ+/H,T]\4@VS3P9P=C(8BM
MB,1C'+"UIWI>S5W%62O[JYHZ6Z+S5E9?6\8\08+.:%",<*Z>-PT/WDI)IQ>]
MTY:NS;2Y7HGU=V_"/A]J_P#P4Y\$^`O!'@SPQ^RM=^)?#7A'PAX:\,>'O$=I
MX)DNK7Q!H>@:-9:5I.MVUS+?M+<6^JV%I;W\,\K&2:.X61R68FBOW\NOAMJ#
M75RTGBKQ0TAGF+FRGA6S+F1BQM%+,5MBV3`NYL1;!DXS17Z?_JEAO^@ZK_X#
M/R\O-_AV9^=<R_F7W_UV7W'\Y\\LD$5Z\,CPN=-NR6B=HV)5'"DLA!)```).
M1CBL3P=(]WH;&[=[HF&$DW#&<DE$8DF4MDD\DGDGGK117YU+^)C/^O?_`+:C
M7`_[VO\`$_\`VT\J_:MN+C1_`L.M:1/-I6L:1XVDETG5M-E>QU+2Y=C)YFG7
MUJT5U92;69=]M+$VUB,X)%?W<?L`^)?$>M_L%_!76]9\0:WJ^LIX/F"ZOJ>J
MW]_J:A-`NG0+?W<\MVH1U5E`E&UE##!`-%%?-YA_O=#_`*^4?_3E,_5^$O\`
MD39C_P!A*_.D?P9V-W=ZG^P5^TYKNI75QJ&M^)OVA?@O:^(]9OII+O5?$%M>
M_P#"(:K>6^MZC.TEWJL%WJB)J5U#?S7$=Q?JMY*KW"B0?UJ_!+2],TKX3_#V
MPTO3K#3;&#PU9M!9V%G;V=K"T]EITD[16]O''#&9G57E*(#(ZAGW$`T45^U\
M%_[J_3](GYSG?_(SK>B_0]5V)_=7_OD?X4445]B>$?_9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]B871M86XN9VEF````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3$T`#$P
M-3$U-#,Q,#8W`#`R,S`W,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_
M`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF
M`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__
M,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F
M,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_
M,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F
M9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_
M9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!F
MF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_
MF9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]F
MF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_
MS&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QF
MS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#_
M_S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF
M_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____
M^+\D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(?D$`0``V``L`````"``
M(```"/X`L0D<2%!@@(,%$QI4J/`@0H8#'T*,Z'"BP146#3H,8/&@E8S8#@)`
M0+(D@H(./W8,8+)ER9`I,[)TZ5+`1I401]K<&$"``),[/4X$$)3GP9\DB^)L
M:-0H4J4YFS;]R7,I2JE3JT+$RC4FPX.!5G1M>O)K@$"!`(SE63:APT#7`DE=
M09=MVZL!K*#=B!8MJ[1VO^:QHI;OM</76)&]2S#`LV=6C,*-*Y4DQ8B/(:_=
M:%D@R8V9GWFT0GICE2J!/9MT'+IUYM.H.;=MR=IU:]AVRZ[.DSF/;]^W3^<^
MN;IU'L2\7U<A890F@MJ/?_]^#-M`<Y<';?>F+OPZ[>2A@2J'/BW6^_//X+5S
M+^S]($D`Z6V?9H[UL_OG`:IH%VZ=*_N9^.4W7GEK!00`.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-E>'DN9VEF````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(Q-C$`,3`U,34T,S$P-C<`,#(R-C(P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y824`
M)0#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````)0`E```(_@"Q"1Q(L*#!@P@3*ES(L*'#
MAQ`C*@2@@B"`BQ(1JE"1*M4*%1]3-4NU<47&@1R;31N9:I3(:2M'FLP((-5*
MDAMSOEP)DN;(C:*,"34F:J/-:20E4ASE)"BSIU").GGI$2)'DJ*@:H5:M)G7
MF0Y5>%5AC-G0IV>-`?#:#&S#JV2-Y10ZEZY(MPM5N%21E5FI/:6>_@ULMFC5
ML!T!E/5;(JZ*$H3-<L2K4.\HQ8(WTE416>[AMZ,N+S:[6*A6SY0G8D6[U2Q:
MPZD3PJ4[6O+0E+$UCJ7;]VG1H6N;57R8DB\S44V%(L_:=:Q5E:F2%\T9%/G.
MSPS%PL0IJKMWHS"W3^<VJ!WF3XHEL:TX^A-B3;;-+A^$.Q[AQ?L`$MX_R;^_
M_X/X8;.?@`3F1Z!2%B68GX$&1A0@1@,Q..!)"RJ8H%+[#5AA@/]UZ.&'('H8
M$```.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O;&]V96)I<F0N9VEF````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(W,``Q
M,#4Q-30S,3`V-P`P,C,T,S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA)0`E`/<`````````,P``9@``F0``S```
M_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"9
M9@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#_
M_S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F
M9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,
M_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S
M9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9
M_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`
M9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF
M_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_
M9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS
M_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,
M9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`
M__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^9
M9O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/__
M__B_)```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"'Y!`$``-@`+``````E
M`"4```C^`+%A`T"PH,&#`A,F/$A0H4``UR)*G$C1X$)J&#-2:_AP8D&/!"E>
M`S"0FK.3*%&2'"@1P*Z7$$>^W!4SXDH`)E/J)!D3@+"9$'T"]?@PITZ5+%WN
M$I8L4B2ENVKM>FJSJ#."*0$@#?HR6;):3E_6&DMU94FM5XT9TXKU6$BER821
M'4NW[$64QH`!0WO2+=>H<ND*MEORY)X]`/0"V(/2KTRQ@NL2QKES;TK'CZ-&
M=AKT[DZ^SC`_C@R6<.'/ET.VA$R6ZLBBH(_V5;TZJE/79G%2CIVZYNK;/1_J
M-NE6]FR6%9\&%TXY-._&-T76S(VQ>7'C;A?Z;GG7^G/H#AF64C^I]9CY[\X=
MJ@^?L_QYX^G7KV].OB#\^/(5TK]_-'O^A<?P)]MY_X5GGH"7^5>@=@?R=YY9
M"^H'@'D45D@A1Q&J1Y"%'/J587[B(?2A?*R4:"(`)K*"8HDC*I1BBBN6&*.)
M([X(XXTSLI*AC3>>F".+$?*H(D$^$IGBCCP65&2.']J(XI,K_JACDTY6>62+
M0F8Y94```#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;V\N:G!G````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$P-S0T`#$P-3$U-#,Q,#8W`#`R,C0S,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#_V/_@`!!*
M1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!
M`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!
M`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F
M)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````
M`````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/P#/QO.E?&"#P/X0D7P
MQX4LM1$FKWNG6<MK=^(-`T?4IK>ZL)KFUMK*2W\.ZY):37LFEQV4X$`MTD5F
M\V./]T?V)?VV?C#\-Y+W2]"^(WBW1-"MM9.O:796VM>(UCM-*O1;&TTP6EKJ
M?]EV]E<B>W0P);7-LD4$L#6*8#S?`WQR_P""2/Q[_84_;%^(6G_%IK3Q3\#O
M&.NZI:_`3XQVVK6&I0_$2PE\8KJ'@W1_$>F:)=/K7@;QA;6]K?W6J:!KEC;:
M?/J>EZ@NF:UK6AFS-SW7B?5-)^%_@7Q%NG73KZSBO'U_7':XCC\.Z19:=>7=
MWJ-VLD<GVM]+BTO[=#;QI)-?FR%K&^Z>59/Y)\:X8;%YKE>4X&I4GF_L<NE'
M&X6K.->ABI5H3>(AB*'+6I5J*;A*%.KLJ<:=.I.2<O['\!*&58GA_,\9F]'!
M5LOC4Q<?88RE"=!4Z=.$:TZRJJ5)TXQ4^>4HN[]VUHJ1_1KX>_X*3?M-^-KB
MP\1:?\3=+TZVTO3=-TS3[.^T"VBTC5HKV">_O]6U6&W<70UFUEB%M#?VZ*TL
M,WDW%O!&TD];7A__`(+`?M2:%+J5K=>&OAUXPN[L6.IQ3:AINO1QZ-#9OI5G
MJ,4,6G>*=*MIM*EMDD9(Y;F.>VU>;4)X9+J.<PQ?SL?LL?M&?![XL^&KC5]`
M\43^)(=)^U:$)+C2==T=8=:C_L5=T%E=0B>Y6W34+>4SNDD4]K/E"'CRGT_X
M<AEN_%>HRZS=33V&H6T4>EJ;>6V$D$L8\A3)&L$UM%:O=P3;)<RRPF&XE=GF
M;;^/XOC3Q&X-S/'8/,<YS^.-R^BU5I9A+'+$NHW%1YZ6(;CS0IRI2E&K2:DG
M=WE>_P!K3\).!.+\'#,LBP6`_LS$8A0P57+J$'0JTH37M+5**4Y0YHU-8R22
M]UZJR_JP^"7_``5I^`/C'2?"UO\`%5-6^$_C#5K:^&J07>CZGJGA"QN[,2JL
M4/B'34O52.6"QE2/[5"OF7@-O"[/)'O_`$@\(?%SX?>/M(TO7?!WBW0]?TS6
M;&+5-.FL[AUFFTR6**8:E)8W*07]K91QS1&XN+JVA2V9Q%<&*8&,?PJ_$OQ9
M/X7N[)+:X\RRL9(9H;-6$YM@ODR.4G>;4I1\S-*&-T-CEGP274_-/Q=^-6N:
MCI%Z7\37L7ALZ;:76JZ>?M#6EQJ-I9BXLF,<B>3<W$.FRV]A;)'$+.'S&O7C
MQ#<A_P!+X1^D%QEB:F7T<QR3+,=A,5"#>)C]9PV-DW"E%0O0]K1E6=TW'ZM)
MRE-+VJ5E'\_X@^C=EE/#XK%9-GN)H5:$7/ZMBH4,1AVE)7U2P>(I)4Y<W+*,
MW^[F]FD_]$ZX^)WP\L[B>TO?'G@ZRO+6:6VN[*\\2Z);W=I<P.T4]K=6\EZL
MD%Q;RJ\4\,BAXI49'`92**_R?M0_;-UK3+^^TVV,,5MI]Y<V-O'_`&II</EP
M6DSP1)Y/]CGR=D<:KY63Y>-F3BBOZ!AQ5Q=4A":X7I)3C&:3Q%6Z4E%I.T6K
MI2L[-ZVUU/QM^&V#3L^)\#>]G:DVNFS=2[79^:^?Z867Q=\=_'06OBCXK?$'
M5/%-S;:=#;Q7^L>*]9U1#A5F%WG7-4U&Z>X)N7NIG>2-S#&04+%P?BO]KWP_
M\5OBOX"US0?A+=:7]LU#4+/3O$TES=_91JG@_3A=3:E:07ICNK+^SM9F%C;Z
MC;7L;1WNFR7]K>Q/:W#0R?:^M_!K5?#GP(T/Q=I23V]SJOB:?1D@E.9)%_L:
MTU*V=I+,`12;9)T5YG,;"R>(KND4M\Y6?@[QAXAFMO#>EW5[::Q<WBS26B3R
M%+BURD5],DXO[2+]V,O+:3+F1%_=^8[>6O\`)619E3P.=1SNE6PS>78^->A2
MQZ6(HTE1=.O&I5IRJQE4@G&+3E)MR::5X*W]K9MP[EN;\.X[`X91P.$Q>"Q>
M659Y=3CAX4+.-"ORU*-*<:=^?6,E:*5G;FN5?^">7[.'C`Q>+M5UK1M$T#Q-
MXL\6>+?%<^B>&&TBS\%:1>ZK>SP+8^$-"\,:'I6@Z1HAT3[+':6-O8,^F+`\
M=B]OI$L5E;?KSXP^`WB+PMIUS=ZW:O;VVLVYDLM1MXY8].TF."Z:WDMXI#8>
M7!<G"O=?9GN/.\]%?R\`5UG[$&A^&?A1!:6^LPO?2OJEE=/>740NMS3>'[&&
M]-K;,DD]K!=7$>H8M<E]OE>:70.9/VJ^,DOP-^)WPTM/"[W4/A[4)GBN[*;[
M-+&\$]YJ5K>S):BWM#`MOY2QP3Y'R,L@8\9KX'CG,<\XUX@SKBB>)P\7*<:\
M*;4J:Q$:'L::IT*LXS48JE1<N2HWS22LVY-/QL@QU3@#!<,\,X++LSKY-A8S
MPSQ\:=2K&G&4ZM>6,J4J2DTI5JSFIVTB[VV/X'9OVB-4\-?MZ>(OASXRU_QI
M-96OAS3O#GAZSTO4M#T?P4OB34-&\,:K%XJ\?VFLPZGJOB"&'P]JOB-+5/#]
M]X-\3:5XKT?PW>WNK:WI5SXDTO4O9OVADO[/P)?7%I93'1(+2\FNU5!"(['$
MYN98Y#+:V$CPV,2VTOVE%@2..:.(M;0Q"OICXN_"WP;X&_:,\9OXY\">']4\
M1:3?1W7A;Q1=^'+.ZUJ6VU"TMY)6MM<^S;UTZ..2.".WN6,*10);VZ1L,G;\
M.:7I6J6FLV?B*PTF\TX:A-,++5DMYM'EB\E&<W4!+6LT<L1:"6!X9'>!I`ZD
M.K5^GYCQ=DUN"\QP.11P_P#8N097A\;&C[!4\WJTW)U<5AY8>.E6I.I)5)8E
M2J\TX1E*4:4$N#).%N),/3XWQ&)SAXREQ%GN.S7+<1.I5FL%A\9&HZ5*4:T:
M<(TZ+?)["C&--\TI63E)O^;J7P]K>IRR:E:Z5=+;:A(]];K#K)CA6"[8SPK$
M@G<)$(Y%$:!F"I@!CC)*_INN?VA_!^@W$^A6/@+P!:66BS2Z39VMOX&MT@MK
M73I&L[>WA2U\,2VJPPQ0I'&MM++`J*HAD>,*Q*_6X^.6=I15+P\QDZ:25.3X
MCP:<H)1Y9-/`)IRCK9I-.232Z?@T_#"NYR=3C#`*HY-U%'+YN*G>/,DUB+-<
MRT:T::MY_NK8_!R^\4?L_?#GP?JZV(M[:VT^)+"/3)H+VTU"32C%<.9[QXW?
M38(99;C3UT2*YLT6X=4NY;2*:5.Y_9M_X)J:3IVK_P#"?>(;6+4DNI-1BT>6
M\MIKU(%O'M3;7<<$NHJEO-!Y;.D\%I!>X.Q+Q0`B?H3X,\+6WA7PO:>%=2T?
M6+[1;;[-NN-/$.IZG%>I$8;S3OM5I%90W&A/I\6Y[:*R,T4TDUQ<2M!(B1^S
MZ?\`$GPOX7\$WFF^'+NV\1Z]I^F7USI?A*28VNIW$=C;3+::9:HR/,E^+X65
MA!"(95>21XT8L45/Q+@WA/!X[-L+B,UKQI4Z6&A4DG5C35;$T80C["=%UHU,
M52ERS:4%4<VXJ,)>];EXB\2,[PV69GE>33J4L+F>85Y5X4U.=+V&*K2J2O6B
MG0PK]HH.4Y^SDO?]I-15-'\^7Q]_9TU']F_XKOIMOK&K3^'/B#KFO:Q,^C6M
MS/=:5XBUCQ#'=C7)HM4OYKF:QTVPO-6\W3K74;>-DA?8LTC0036/`>@:[\9O
M%7A'P/\`#7Q:OC;4-/NY[CQ"!X4:TETBVU?2M-;2(3=Z[)IT4\WV2XNKSRM.
MU$00Q:;(-4^TW4VGV-?4W[9'[0OQ?\5^`=1N/"_[*5XOQ)&FR_\`"*ZGXVGU
M*XM+2UU.>VMWNI;32M$L-1N+F"TFNXY;>#4;+[)J+VJS7,EO<2&'[,_8B\2?
M"3P^FAS_`/"E/&GP]\8^)+6QTZ_,OAO3-?\`#EM?Z=8W$4M\OBW0;&QFBM'B
MBVRMK6E64]KYEO9"XNHXENY?NY<"Y'FN82R]XF>`R[&5(3DTJV&E.%?6=**K
M4I7J4Z\H.GSQBHPE:7,HJWZG#Q@S?)_##"U<5D]/&9O2IO+Z>+I8G)L70E6I
M0<88JOAZ,ZF82HQP\5>5*485:U->VC-4Z:C^7_\`P5=_80\.>%KGP+\3UN$U
M*XA\,1:/XA%];VZ-!=6QT^TLKJVU&">YN4DF@,OF0&R-DJ1;$G\R1&K\\V_9
M>T/X?_LK7?Q2UG1(Y-7\0^/8K70?#1U":VU3_A%(_!]Q?7'B6/2K._?6]8M[
MBX2'28Y[*R,;74L<$2?:66-_[,_B]\//AO\`&/21I?BRV\-:OI/GVHE;4XM,
MN+-XK>-I$@E>^BEMX8Y9`$(D3YW$2QE6`!_$W_@I7X:/Q1T;P!\./V>=/NO[
M%\&7,/AK6+7P/?S:?!HD+6^LZ7<7&JV?AO0Y';PC8P7<%CK;WGB.WT>![NVB
MOM*AN+C3;FZ^(XUX/_U5S+&2PV.4>&J$Z*R?!K$SJUIN5/#QG4I6<E5A1G*M
MBZCDKN<X*SBG$\+@+Q8QF>95EG#%>,WF<L=5JYOG6(E3IX3^S\/*K7HTJDH0
MC4ISK5%'"2DIQA.A&-.2DVW+^6E/@AIFJ(FIRZ='%+J*K?21G5]1A,<EV!<.
MABN=1CN(BC2%3'<1I.A&V5%D#*"OZ7O`O_!/^QC\$^#H]<A\+W&M1^%?#R:Q
M<%4C,^J)I%FNH3&-;I%0RW8F<HJ(%W;0J@8!7EKQ"XBBE&G4Q"IQ24$Y8BZ@
MN513UW45;S^;/4GF/#$9RC)Y=*2DTY.KB+R::3D_]I2U>O2]_-V_2K3+R[LO
M"-E%9W5Q:17.LW+W$=M/+`D[RM&LKS)$R+*TJQQK(SABX1`Q(5<?G)^T9XJ\
M3^'K+X=ZCH'B/7M#U"ZETJ2YOM'UC4-,O+AVGU"=GGNK*X@GF=IX()F:1V)E
MABD)WQH5**]O+_\`?<E_QTO_`$I'X//_`';-O\$O_2ZA^U7@#3=.\0>`OA_>
MZ]866MWEWX"CENKO5[6#4KFYEC33&22XGO8YI9I$:>=D>1V96FE((,CY\F_:
MNED\%_#71)/!TC^$Y)-0TF*23PR[:"[Q76LVT5S&[:6;5FCN(_W<Z,2LR?)(
M&7BBBOZ&SS_D6Q_[!,/_`.FJ)^98+^%AO^QIB/\`TFL>'^%?$?B&_L(X;[7M
M9O8I]+TZ6:*[U2^N8YI?[2UM?,E2:=UDDVPPKO<%ML40SB-`(?#NE:9;_$);
MZWTZP@O;OQS+I5U>0V=O%=7.EWTD1O=-N+A(UFFL+PRRFZLY':WN#)(9HWWM
MDHK^=N*?XN6?]?I?^VGZEPY_NV=_]@<O_4H^WSHNC@D#2=,`'``L+4``<``"
M+``'04445XU3^)/_`!O_`-*@>'+XY?XOU@?_V0``````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+VAO;65R+F=I9@``````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(Q,S``,3`U,34T,S$P-C<`,#(R-S,V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y82``(`#W````````
M`#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`
M9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``
M_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS
M,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``S
MS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF
M`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!F
MF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF
M_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"9
M9C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9
MS,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,
M,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,
MF<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_
M`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_
M9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#_
M_S/__V;__YG__\S____XOR0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!``#8`"P`````(``@```(_@"Q"1Q($(!!``03*ER8\"`2)"082F1(`L!#
M$A@S3MQ(`@D`$BI&-1O9;)2*B!L7=@Q)LF5)%2E5CG+BLN4HE#$'JJA9$V9.
M@21$\K2),R:)H2Y-@LRYD^>H%5!7J&!UC=4*HTZM4*VZ8BLKGQ./UNQZK2Q7
M5EJ+,F3I<H59LUU9L5*[=N0*H62ME/VJHB\2HZ-,LASU1&[5)T)OQOP8<N;(
MIWWODE2<TB(`MC8#2SWY-V5$@TTG;P9$BI0>NA*#)GVBI[1KTZAE.BZYHO5K
MU[%5LJU]^_7IGV*;J=`SO#?LGZ&'8SQYTB#&G]B"%W^=)W?8R2IN6Y\8NAGO
MTK^A-@N4*O0EZ?#BXT)-W%?%1_'1S5J5_'CJU9]0M^XE;Y=K3O7ZR7598%-5
MM1TV!R7HG((,$A00```[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F%R="YG
M:68````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$V,@`Q,#4Q-30S,3`V
M-P`P,C(U-C$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA)0`E`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"'Y!`$``-@`+``````E`"4```C^`+$)
M'$BPH,&#"!,6)(&-(<.&"B,B!*!B5$45)!Q*W"B0Q*AF()NE&D4"`$2."DFD
M"AD2(S:3*!.J9!G2XL.',0FJH$G3IL:<#3_RI#D2(Q*<'&<.'6H1)LJ=2Y>2
M1`G`8]2E*F("`+#R:D^D$DE`]<HR*TJ/H[J*3*66Y]2D*E;('35*KEVA-,UN
M7,&J;U^Y?OM6P0LR%5B9K*Y9N7:-%5_&D!U_39H8\F/%D5>TU1NV<N/+D#^K
M-7PVL&//F4<?3FD7<&C&DFNNEIF6[:@JJ%D-!FDSIT>VO''_72'4)U`5R*'6
MG<O22=JW'"L"9]F6MW/H80E[O3@;H5*RS2I0EHQI%7PSBT`;2F?+ONA8TND;
M9IR?G##\^`315@^/WZ!8IB[U-]!WDPG8T'Z\<89?16[)A<4*W6U$PA7$M5<7
M%E@(@F&$"FWEX8<@?EA00```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]N:6YJ82YJ<&<`````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,S$R`#$P-3$U-#,Q,#8W`#`R,C<T,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_V/_@`!!*1DE&``$!```!
M``$``/_;`$,`"P@("@@'"PH)"@T,"PT1'!(1#P\1(AD:%!PI)"LJ*"0G)RTR
M0#<M,#TP)R<X3#D]0T5(24@K-D]53D940$=(1?_;`$,!#`T-$0\1(1(2(44N
M)RY%145%145%145%145%145%145%145%145%145%145%145%145%145%145%
M145%145%1?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q
M008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+C
MY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&
M!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/7*R-:U:6TDAL[-5>]N,[-WW4'=C[5K
MUR:OYOB+49Y/O1LL"9[*!D_K0!:CT:USYMYNO9S]Z2<YY]AT`HN[0+8/#9XM
MSU'EC&#5O?E=O<=!4$DH=<YH`K^$+:U2&>018OD;RYG;DGTQ[5TU<QH+8\0Z
M@J#$?E(6';=S_2NGH`****`"N-NWEL/$=S!Y0?[8PDC)8*.F#U[UV5<MXPMM
MSV5TWF".)BK-&<%"<;3GTR*`,RXNM:N2WV2V$,:ML=M_3_:)]/I5FU>0>;,\
M[2PD`1N1C.!R?H34B0">$-=SW<P(_P!7,P(!]P.#1%.;V20IM,$?RYQPQ[@>
MU`&AX5@8V4M_*,27K^8!_=0<**W\UQUI)J6C6[PV4<=S;DYC65MIBS_,>U61
M;ZM.IDEU=T<_P1(`J^W-`'49HKF?[.O.^MW.?PHH`Z*XGCMH))I6VQQJ68^P
MKDWDU#Q!&TEQ.;+3W!VP(H+R+ZL3ZUK^*7QHSQ\_O9$C_,UF&Y-SJ(AAX@M\
M>85Z$XX6@#/FT:2U@$45U=R6S+@JA!9/\15A+IH;:TM;:%9+AH\JJ#"!1U8^
ME:7F9^9N"3CZ4U&`YQC`XH`6UM&1A)<S"67H,#")ZX%6II8X$,CLJ!1DDFJ]
MP9!;2E'V/M)5O]JJ6G`Z]?(EP@^S01K+(O\`?<]`?8=:`(O^$A!Y6VD93T8=
MQZT5V(10````.V**`,?Q/_QXV_\`U]1?SK&TO_CRF/<SO_Z%110!-*3QSWIU
MN25Z]Z**`)[GBRG(ZB)B#Z<4[PB`+:[(`SY^/PVBBB@#HJ***`/_V0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-U<&5R
M;6%N+F=I9@``````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C8`,3`U,34T,S$P
M-C<`,#(S-#8R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`
M,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`
MF?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S
M`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS
M9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S
M_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF
M,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-F
MS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9
M`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9
MF6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9
M___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,
M9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,
MS/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_
M,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_
MF?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````A^00!``#8`"P`````(``@```(\P"Q
M"1Q(L*#!@P@3*ES(L*'#AQ`C2IR($(#%BQ@S9EP(@!8M2"!#BAP)B0T;``D[
MTF+&C--'DC!-HC2HDIFQER'9(-DITMA-DR<+UKPID@TG8RR-N0SITJC,@36E
MX2R)5)I5:3:GLE'Z-.K2G%6O6F6&DPTS:9QD`C#)B2S)K6?%8J4%]&S:H&N-
M3AT95N[5NS.QY=T[TJ-A2VVM`A9JDC#,D+0X+:8)U.3CMT\KLN5:N7/.H`KS
M)O:+M65)T!S9MO1X-"FGTX$9YH7D&&CLAK,QHX8HNK*ES!-%LYQ,43!;XL6-
MVT[.>#=S@1:?2Y]./6%````[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O9&EL8F5R="YG:68`````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`P-0`Q,#4Q-30S,3`V-P`P,C,R-3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA(``@`/<`````
M````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!F
MF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_
M``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,S
MF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,
M`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`
MF68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9
M`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_
MF6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF
M`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,
MF9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS
M`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9
MF<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\`
M`/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]F
MF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____
M`/__,___9O__F?__S/____B_)```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"'Y!`$``-@`+``````@`"````CB`+$)'$A0(```V`XB5)B08<&'!0$\.SB1
MHD)DR!!"W-CPF<>/(#-JY+A1(LB0(TE"-'G28T:5'%FV?`ES9<N/-&M&O.DR
MI4Z#/)_E_)GPFDR41`T:-?J1HE"?-0$L56A2XE"=4K,VG?@T:5&M'B5:A0K3
M8LNQ29V>='JU;%"<9$D>O=FVK-J9<=WRK!LU*%^]=/.JG`NWI&#"/0WG1>PP
M(M623:E>,[KR(*2XDB=K/E@9$N6'`"YKGJSP<T3/URZ#AB3:J-3-9%^;'ECZ
MX.C-*STWIBW[-NG8"E73;NT;]\"````[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R96DR
M+FIP9P``````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-S$Q`#$P-3$U-#,Q
M,#8W`#`R,C4P-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/@CX@?$/3KS_@H;\`_$ND>+[NZ\&7GQU^.WP.T^WM]96Y\-66B_!7]GC]F?
MQ)ID\"V]VVEP7EOX]^)?Q5MI_)8):7=Y-$EO:ZC=:H;C]V/VZOB@NF?L?'XR
M:)J#V5W/X7^'0AN[2YV3+CXQ^!/!NII:3VUPLC3QZ'XPM&1([DLD3H9/W#HD
MO\?G@C0+RR_9YNOB1<?$OPG:?$#X*^./!7[1&A:=?>(-)N;A;WXX:EJ/@KXN
MSRZ;%=SWK66DIX?^%*Z@'L[AKJ;Q1I46EV?VFWOQ7]$WPK\8>`_VX/V#/B+\
M,?`M[J4\VA^&O%&EV%K?0ZK;2Z?-J-QX@N?`C-<ZO'80M=V/B/X;Z'X8NO)O
M+BW.J>![R6\N1%?V5_JWZ!P/QE1SG"9BN5PS.CC<3BOJ]72=:GB%23E051\L
MXP=.HIQ@Y./NN22E%OX+Q!X"K</9GDCY:>(P<LNP*E4IU*-6-.M2N_WRA*3I
MRG1J4:BG5C'GYFDW.$XQ^O?^"R'B?XF>&5_9_P#B?\/+&^UG1O#NBZEJ'BY-
M)75;C-LMK\(?C#:R6\>E,(8Y)=%^$/BJSLWN)D#WVI%(24N+J:'Z!_;=\->'
M?B-J/C#XY)<6^KZ;\1O^":/[:GPVT:]@$4EC=^)?"-UX`^.OA:QN[I4N/,O[
M_P`,:?X\;24-W-*UK%JES9P+;0ZC=)\^^/?CM_PN;_@G+\+/C=X=BMKL>*/A
MKX5U$2W$*2P7\GPU\?Z-X.\>Z%<PWL$8T^/4=!TSQ5X<NYRADLK7Q%=SVZWC
MVULS_-_P^^.&J_$/_@GKX,\$>*O$FGG7?V<OCWHG@/QOJJ36=LVL_"3X@^`_
M&_P9;5E;=;02IK^A?%KPU;W%G:7-YJ45U;3HIDFLYYH>3BMX>OE.8X6C*,J^
M%HU\3RZPG##8N4Z:JQ<E'W(."DU%OD:3E%;E<.4ZV$XERK'/#5:V#CG6&I*<
M:4JD)-4L)B9TVHQDX3G3J6]Y1<K22;E3DH_*GP]\8^+/C5^P%^T+^R]XNUSP
MY8^+OV6KC3/BQ\%-'UV_2UU3Q#X4^%-I%JWP=\:?9;VXFO\`58-0\&ZGXF^'
M'BFZTFPM[>]U#21I=K>16]M/$O(_L/?'#QA\.5TQ?#FL>(M,UO1K/2_$7AC0
M=:M==TBV\*>%#_9^I6>G:E?Z%<VPNH/AEXGTIO#/B^V81_\`"._#OQ%X4\'7
M)MM3O[F%_-M;L_BEH=EX+^-7PR_9X\1?$*^L_A)J?P9^,.L3ZQX<\+VK?#/6
M7^TZM:V^EZOKMIXTU*]\/ZS8>%_$?A[5;'P(T%]<VUYH]MJ(_MN_LYOF;P5<
M_&KQ%X7$/P_\#2ZEKOAK4-;^,WA'6?#OQ6\,R:%J7AD6<%C\3O!&O76I+H<U
MUIGCN;Q+K.NZUH:2Z[J.BZ=XT%WH\\Y\)Z;)IGXGDGB/B.;A[B2O5HRG##?V
M!Q7@76I5>:G@YRP\L55IQJ3BGB,+[.M:7[V%2A/GC%N"?]*\3^%5*&9<6<*X
M+#8JIALQ7]O<&8Q8+$T7*KBY1Q$,+AI5:%.55T:\IX=2IJ5.<:]*<9RH\\X_
MVB^'/^"V7PHT7P]H.C^,?!6O7/B[2=&TO3/%5Q97OPCN;.?Q)86,%KKDUI<W
M>O\`VNXMI=3BNG@GNO\`2)8F22;]ZS45_&]#^WO^SUIL46G>.9[WPUXVT^-+
M+QCX<E^$LOB:7P_XIM5$'B#1)/$=OIQ@\02:5JT=W8/K<!,.JM`;^,[)UHK]
MPAEW#%:,:T.(,J4*L8U()YAAE:,U"44TZB:LG9II;2VZ?SH\-Q/0DZ,^'\U4
MZ+]E/_A.Q'Q4W&$MZ5]X]==[];5O"L_Q]^)GC?X1?`/]F'X`?\+`\=3>%[V^
M\+7.IQZ_:^%]0\.VOA>Y?QHEY=C0]!-[#_8$^HZA<0:=-?I87<>@ZZ6M)=/@
MO(O-?@U\2OB%^Q7^U-/X(U[P,/!'Q#U;6=>\"^./AAX+U^U\8:#J>FZ5>W5E
MKFE>*M(U6[T_Q5\.M4AU/3]+UKP%<ZIX7N-1\4Z9)8[=0BT^[MDN?UU_87^'
M#?"K]J+X8?"/Q)KEWK^H_"[QH+GP7\4+>SO=`U'5/"T^B^*_$.@:EX>U<7D-
MS:R2:-87/AK5KK0M:D60Z1?Z=+-?1/9VMU^BG[0?_!)KP%\<OVUU_;L'Q/L?
M"NMQ^*/"OC#6_`.C?#/?-KOBKPOI.BV!UU?&R?$'29M)N==N?#^FZKX@MXO"
M&I"]:.XMY;B5;VYFK^0,NXORO@O'XNECL%C<ISK+<5B:D:OM,14>)JRF[5.:
M?NRIS2UIJ%H\R2>MU_;G$/!>.XZPN5XI9_0SOAGB'+\LG1P\L%R/+X*A2I0P
MZIT(1FZM&46YS51RT7/%)H_(WX$?&[P!^S#)\2/@3XE\5KXG_9A^(FO:CXW^
M"OB*=[6.?P^/&&BV]Y\4_!GB:[N&&@P^(H)?$^CI86%CBT35=)O1;P/.\\UR
MOPCN];\+>(;[Q-IMC93>#/B]X)N_`?C/5(;FU33/AY\04U^VEL?%@L8K)[8^
M&O#6L1IXN&I75Q#?67AE_$QN[.\72M,LY?T0\!?LI?`#XS_M#_$[]C>Z\/V.
MI6/B#P;#X]\,^*XM'MKO4/A!XP\.+ID.J6RRSP(/$/\`PF6CZ]H#2+='3[+=
MX+CGE^T7=S<IIOW;\*_V`OA?\)[;Q1X8BTV/Q'9>)WAOKO[8GV?2M,OFCN+'
M5X-'\.R7>H6^DZ=JL2VLMWI=KJ+:>\IN=ENGVAW;?B?QFQ6;95E.:+`SAF$5
MC<'5C*#CA<WRC&1A&>%Q%-J$HO#IRE0G%MU&U=QT,N$_!#*>',\S[(\RS-5<
MLJ1P&,IU,/-_7\KS7!SJ5,)CZ%&=U..(C-PQ5"K*$J4)<LKN*/SR^&7_``38
M_:3_`&H-;&J^%=;^'_A#X2ZKX;N(-:\5_$_2[+QUXL\(:OK\]MJ$T7PR^&4[
M3>"+*^3P;?:9J%C\6/',?BCQCJ%T-GAK0M"\/:C%J+?R>^*?A'\?_AQ^UGXU
M\$_">7XHZEX^^%7Q,^(7A[4-6U[1S!JFJ?$GPC\:/$?P[MX=`A\*P:"]M9^)
M9+/0+*ST/4I(-1OM;U6\L8],DTB:V!_T\_A+\*Y?ASX,TVS\&(/#&FVUC;VT
M,%G>:B5,<5N(+:'RC<Q+!!%"%CC2/SDMH(H;>'=%$H3X9\1_\$Z/V-_"OQ'\
M;?M$ZA\,XM<^)?B77O$GQ2\2>)-3\;>/M1TQ_%=YJ4OC/5O$5WH\OB(Z42=8
MTI/$3)>P/&-0$@:;S+@2GS<KXOPV59+3I5,DE1EB(N5*-3#TYT\32Q',I2C"
M*E4>(J3G&,DVW)-2NM3KQ_"&59MQ)C,7CLYK8O#X:#6%D\35HO#5\/[*2ISG
M&K:AA,/R.=-49PMR*,F[67\8OQ'\%_MC^%OB'X\\,:]^RCX<^(6N>'/&?BC0
M=9\?:9\(?BIJ>G>.-6TC7+[3]1\8:?J5EXTLK/4++Q->6\VM6E]:6=I;7<%[
M'<06T$4B1(5_1/XU^.]U#XR\6PZ'9Z:^BQ>)M>BTAW\1:G:.VEQZK=II[-:R
M:,\ELS6@A+6[LSPDF-F+*22MHX?Q'DE*EX=T72DDZ;<Y)NF^5P;71N+O;IMU
MUZ.7P?6E;QRS2-9:58JM&T:JM[1+?1232U>B6O5?B;\*/C7\5O@7XS\&^#]%
M^)-D_P`%=$UC7]1F\*>+](TS7O!GPR\57^F6>IZ5JM_>QW^A>(M+TCQ>^NZ?
M;H(?%-IHFA:W#X>U/4K.ZT[4+6QK^NSX1?$+2/C?\--%\5V,L-M-K6EW,$T=
MK>PW%YI6O1-+IE\MQ@1I#,)+1GCM;B)9)+:>&2((27?^*&VTSQ5\1_"E]XJT
M2#0/$7QE^$NDZA8?'3X6^'=+O!HOQ3\+:K;V[>'[C2M*N;%-7UG5M'T/4;[4
MK1M?CLH=/N=0\5Z-8W>K:9-#;K]W?L<?M\S?LO\`_"$:WXPO]5U?X)?$D:M9
M^%_$OB36[75=836_!J7;>)=*\92:7?3:!!KVE1^(M!NM-N4:SN]?\'WEIJUM
M;:G%HOB*_P!*_0OI%<`5^(*U/C7A"I#%8>IAXUL7@(/#TYRC.-*I3QN$JM>T
MQ"G#GIU\,],/*A&:7-B6W^:_1S\0,!E&"Q?`_$O/E^*IXNO/*,UKSG+#+%PJ
M1IU\HQLIOEPS]I[.5+$QU7M)03LC[^^`_@W]L']AS]M7XW^+M*\$:K\=_!O[
M18\#P77C>UL)=+G^&S?#[PYXL2TTU[."+5%O=+\3:IXRO8+R6-M+FTK44L7N
MVO+.YMX5_>7PAKFL:QIEMJ'B;PU_PC>KRNZ76ER78N9[6W$9F^TNZP6_RM*6
M&3$N"H&_:2M?,<7Q-\#_`!_\&#6M)U7Q7I5GJ:032'PEXEU3P/X@M)-*O71(
MK+7?"VI:;J]MY;6C&Y>WOIH)X6;R)7MIPS]9\.O"/A?2Y+VYN-5^*.N2%8?L
M47C;XR_%+Q/I\$D-Q:W-M<_V/K/BO4+)9S<P12O>PLEVZHT`E2WEGCF_CW&Y
MC/'SP]#,<7.C6P.$I8&C1A25*FHT:<:477C3Y:<*[5./.^5-S3;NVV_ZXQ65
MXBA1Q-3`\.X:+KUYX['YK]<]I5JU<=+V]2-*+UJT(3J3]DU)QY'[J5]?M6_\
M0:GIWARXNH+F34&M;$W-CI44MO#/J"V>GFYM["V:6+9')?SG[+'/(\FQW&R,
ME:_&;]N_XH?&.3X$:AXB\4:KH'P*T[2%NYQX>BNK?X@?V7J2Z-?6EOXR\5:K
M;PV;WEO:7VL6NEIX2T=FN-6U2.QM=`NY=>OM/L+S]/\`6=>EMM'*Q2*T]S*;
M9L/(PA6:&2XNKP%V!-NAR\CJHDWODP.Y>5_P'^/7QW\'?'K]MJW^!=A]O\3Z
M/^S7H[_$#Q[>.]@OP_\`#_C#PYJ>JWEO_P`)#/:W5Q<ZGXQ^'/V9_'>A6-_:
MWOAWPUXCTCP1XE.FZGXCL8KK2_T+PORW-.,.+<JR;"SE7C3K4L36Q55NJ\)A
M<*_:5)1E*[I1;2AHXIZ+4_(O$&67\)\#Y]GV:)0E##UZ6"P5&U-8W&XMJC"G
M.DE%5DG5=3EDI)<K:5S#\!_LV?MD>)_`_@SQ+IEU^R['IOB'PIX=US3X_B;8
M^-O!/Q)CL=6TBSO[1/B#X,M[UX/"7CA(+B-?%GAB!WAT'7A?Z5$S):*25^8/
MQ1_X*-?M(Q_$SXBQ^"/%.M'P8GCKQ<GA$W%W)-.?#"^(-070//FDGFDEF_LH
M6GF2/-*[ON9I')+$K_1>.4X.,8QYL2W%*-TYV=DE=:[.ZMZG^=CS##2DY/!0
MNW=WP\;W;B]?=\U?Y]D?#FF:KJFD?\%:?!.I:3J5_I>HR>--7MI-0TZ\N+*]
MDMY?A!H<4L#W5M)%.\,D<\T<D32%'2:5&4K(X/L/A+3=.3XV_P#!4;X;)I]D
MGPZN?AI\5-1N?`*VL"^"KC4/#VK>'_$V@7T_A41C0I;S0_$DDGB#1[F2P:?3
M-;=]6LG@OV:X)17Y)DW_`"2V5_\`8JH?^DQ/V//_`/DK^(O^RBQ?_IQ'Z"?\
M&]VLZQJ?[.^NQ:EJNI:A%9:I%#9Q7U]=7<=I$;CQ.ABMDGED6",HB*4B"*55
M5(PH`_J*LN;>U)Y)-H"3R2,OP2>H]CQ117\.^(7_`"4/%G_8SPO_`*7,_P!&
M>`O^3?<(?]@#_P#3%(\7_;/U"_T;]E']I;6='OKS2M8L?@?\06LM5TVYFL=2
MLV'AZ^<-:WUJ\5U;L'57!AE0AE5LY`(_EA_8%1(_@[^W3<1HL<[>/_$%JTZ*
M%F:VE^'/PA>6W,B@.8)7GF>2$MY;M-*S*3(Y)17[/]%#_DHL3_V"UO\`TL_E
MSZ5W_)+X?_L(RW\JASWA33=.G\+^&YIK"RFFFT#1Y999;6"226233K9Y)))'
MC+.[L2SNQ+,Q+$DDFBBBO[AEN_5_F?QK#X(_X8_DC__9````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O9W)E;6QI;BYJ<&<`````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#8S-``Q
M,#4Q-30S,3`V-P`P,C,S,#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R
M`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+
M_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$(
M(T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%56
M5UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W
M^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"
M!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`5
M8G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!
M``(1`Q$`/P#^=SXF?LIZMX)\*ZEXET;6%U^+2;V^N;VU%LT%W!X:15:TOF)E
M\B2YL<S2:XRB*VCL42\MUC%K=I<?)C6ES"Y6>UFAQ-<VKF>&>-8[BU5?M<;@
M*'$UDLL<MQ%AGA#1F:,JX5NNMOB)XLLT=+36=5M@U[J-ZGE:[XB58WU.U:UN
M8C#_`&P;>YC=/*,LE[#=75ZMM!:ZE<7M@KVC^[?#KX(^*_'+:9?2:-/9^&-0
M\3Z'JTOB_3;_`$6SCCL=.M;RV\06-CHDMU)%?O'J;PP:'JMMIKZ)9K:ZK-I=
MG<:=J$6GU_5&*H8?BO.L+A.#.&LPRZI7P[=;+'B,1G-*G*G4A1>-6,HT)U\+
MAG4Q&%I5I8G#_5J$I>WJ8BC1E4=+]?QV1<,>+7%>7X+P=X%X@X?KRP]*.8Y!
M[3%<28*$:<Z<'FBQ].BZF78>4ZD<)B)YFZ6`C7GA:]7'86&(KQP_;_#[]GG1
M_B/X*77?["E\#ZD\82PN7U63Q#H7BB/=YQNFT^=5U31;,3VULL%QI'B6YFEM
MKF]B-Y<J6B7Y;^(7PV\0?#753HWB%8EO$V_/%D6MY%(9#!?Z1-)L;4M+G6-T
M-R(H+JRO(IK/5+"PE-F;S]*K7QIIGA#1H])^'WA>0:+;B22[\:>/M2N_!?A9
MKV581)?ZAXA\0V<VL^(K]F\S[9]EL)I`MA+:1W$,=LB6_G?QDLH?B)\*]2\3
MZHWA%];T36+33?"^I^'&U/4&U<:I)9:?<>'&76-(L98KF\NK\/;21+J%M:7-
MO:ZGOLI;.XF@_1^(."^&J_#5"64XVE+B_*,HJ9CFM;!TYPR3/,+E]'VN/EA:
MJP6`P%6&'A6BL'F66T7]9=&&$Q];'8R7M8_TYXF^`OAWF'A__P`8M/#T/$?A
M3AUYKF>89=AE@L@XCH99@YXC-(1EALMRS),3*-##U88+,LIPM&G4QE.EA\TK
MU<;C959_FR00%)Q\PR,,I.-Q7Y@"2IRI^5@&VX;&UE)Z7POI8O\`48KB:[-C
M9:=(E]?W,<D]O=P6-NP:>XTZ=(9(O[12=K.STV%F\V?5]1TN%()8I)WA[C3_
M`(6:]K>NZ-X6T.'4_$$DVF+KDXL$(T__`$ZY%L);6]99=/L-/FB@LXYO$=_(
M+"?R)6L1J4D%A8W_`$/QDTC_`(5W/9^`+2:WEFL;.S?Q#=6MI')IU_JUW8S7
MITZW-X'N;.S\.Z=K-@^F6[&YGO+O5;GQ/?3P:Y<>8WXU#`8UX*KF=7!U:>6T
M<33P;Q5:G*&'Q./J^TJ4<MHRG!JMB)X:A7Q.*A3C+ZGA:525=PJ3HPJ?QGA^
M`L[RC+\SXKS_`"JO0X>X?QN!P$ZM5<V%S?/\73^L87(<)B(_N<7^[I5\1FM3
M#U72PF`P]9*O+%U\OHXSI+;]I?6M&MX-(LO`WPTCLM*ABTVTCF\-7.J2I:V*
M+:VZ2ZG;^*;>WU&18HD5[^"W@ANV!N(H8DD5%*^7**]ZGQMQ93A"G#.\1"%.
M,80A3P^"A"$8*,8QA!85J,(J*48IOE6ESVH>/?BM2A"G3XKQ=.G3C&%.$*5"
MG"$()1A"%.G3A3A&,8I1A",81248QC%))55F8*H+,Q"JJ@EF8G```Y))X`')
M/`K[A^`'PRU'2['6_'GQ!T"";PYK_P`/]>M/`MU_PLW4OA;KOAKQS?:3#<^"
M/B?HSZ5I6K:3KHT6[TZ$ZMX<\9VMG8^,=#OM7_TS3[N;2_%MC\F>`HO#UQXL
MT6#Q2MRVA27MN;\65I<WUZT,$T=TT%I:VV]I9[Y8&T\"2WNXECNW8PHZI<V_
MT`?B[X?\;_'KX=ZE\23K;_"/P]XITE-1\+>"S(FI6?A>.]5=2T_PX^GWD$>H
M>)K[38X[5+^*XMK";4W6RM;@Z#;VUW-\[7CP]2R+.L=GM#.LRK4,-4_LO)^&
MLSKY3G5>MAZ?UVMC:>8X*I3QV#5#V5&CE]/#U<//,\QJQP\J]/#4,4WEX>_Z
MBY)E>-XJXOQ>;8S,8YEA<JX;X;X>S:&58^==>RK9CGV:XU4JU3!9;EF&KTUE
M].,8U<US*I[*E4I8?!8ZM3^Z_"\7PBUKX-G3M>T*Z^*7QDTWXO\`AWQMIO[0
M6H_%>PO?!G@'X.6/@V>/Q3\.IO`6D7;>&KKQ3=^,;:[GN?$<^@S)J'AS4;:1
MO$ND3^%;?3[_`,EE&K>/&U^^\;>(+G0]!>:"]^&=Y<V\.C:'J-M<3:CH&FZE
M<Z?+]IU#3M0DU+Q+X4UBSGU&Y2]N_"/B/P9JUG;P1:VM_)]:?`GXP?\`!*;X
M<>,OAKK_`,?-)^.7Q(TK2]9TGQ?XQ\$>([&TUWX>^-M"D_90NM(U&V7P5X?U
M6+0=9\02?M-:!%J&C6GB"XMO#Z:3XPTBUD\6R>&/`FIW_BKX$^._[:&O?M*)
MX6\(S^`/"7A'P=\/OA1:^#-!BL%O+[Q%KA^'OPC^''@?2_%'C75;J?[!K&N:
MAX>^!'PWCO[.QTC2]#AN=#@DM+!=A,GQ'!GC)FV:\=XOA_AOPM\2*/!6>9CC
M>,^/>)_%/B/,E@LRS3/,MS+)>'>%^$,'5S3&XFGE&0U<@RK,,=EV%G5PV15<
MQI3P_.\=7IU?WNAX\9%@LTRW+\DP&95LMS7.LSS'B+#YWGV88VKQ%FN+R%9/
MDV%KPP]>OB,'D>7XR6"QF#CCLSSC%3K4G-8BAAZ/LZGTS\*T@O;KQUXATX1+
MH%[XD@\.>%TA(FMSH/@;2K/PR)K.\'%S83ZU::W):;3+&B[Y$N9_/8K\J_MA
M^!!:ZKIOCBUC6.VUJ-;"_<RRA/[?TVS=HY'^T7<%C;MJOAVR2WS%'<7EW-X9
MTZSMK=7GGED^[?#ITQ-&TJ#2[*QTFU&E:?=0:/IZ6\%OIMK>1&2"&&VMXH(X
MK<,L\<3);PQR-#+L0%'5?)OC1?\`AWQ-X'\=^$K6]M-3\1:1X>N?$S:;:Q-J
M$E@_A^1M3B%\T-G?VEC-=OIT]C%9:D(SJ*RS6+0RP3S*?[\XTX:R_&>&U;+*
MV+P<<;1C7SK*ZZ]CA*6(S]SQ>:5:&!H5?9JG''SQ&.P,,/!*K2PF*G!)2@VO
M[-\7>`,KXG\#LTX:Q^/P#S1X;&<29/BVO94JW%=.ICL_JT,HPU>?MZ5/&5,1
MF66X3!TE.OA,NQ3H1I25%TW^0=%6+N**"[NH()C<P0W$T4-PT+V[3Q1R,D<Q
MMY<R0&5%$AAD)>(ML?YE-%?QG%J45)7M))JZ<79JZO&24HONI)-/1I,_Q<::
M;35FFTT]TUHT_0KUUW@G1UUC7(T>Z6RCL8)]4>Y:8PB%=.C-VSCR+B#4)I%6
M)OLMGI6[4M3O_LFDV4MC<:A%J-INQ_"+Q_<^%T\767AK5;[1,WWG7MM;!T@7
M3IH+2^\RV,HU2)M.OC?6NI2W.F6UA;?V;=SP7UW;Q3R6_%6&IZMH-S%/937%
MA=13:?J5L^UHIH+JU:._TG4[4L`\%U;ETN;&]A*2>1/(BR/:7<\<VU?#5Z"P
MKQ6%KT:>+IX?%4XXFCB,-];R^K.$I5L.Y*C4J4:]!R]C7HSC";E&5.M&ZFOH
MJ>48K(L;D6+XJR'.,-E&8QPF9488C#8K+7F^4573JQQ.78BO2IK$X6O1G"I3
MKX:?+6HU(NCB*7M:=>/[&^'-!'A_X>^!_#%U\-_V;_&^C>$_%(\;_:_BW\#=
M+M?'=QIMQ\-+7P)+X.\6^//`WB'PWJVK^'=.6QLO%8T[57OIH/&EH-6DUB>S
MBDTZYX_XZ>*-,_:>7X'>#[+X=_L[^&-1^#?A9/AI?:Y^S)\(KWP!X?N?"LRV
M\FJ:O\3_`!2_BS7M,\7^-9$MKZXTVQL;C2;JSUKQ3X@U*726%W--)^8M[X\\
M2^([VU/BCQ!JVKVWFKYR:QJNJZI9[O/NIK>:YM;V74A]CLY+O+V-A;P"6U@\
MNW6&^<WM?HIX=^)7PP^,XTSX9VEMJNAQ?94U75-`LDMK/0]0CL/M8OO"::GH
MUX@N+47*KJ<QMH+>SU;3;;]W*5N)X(_J^'?#KP-XBXKHYGE_!&%X=S_+JCJ9
M%]=XIXBE+-LSSZ>,P&91R_"K'?V!E%;%1Q^(I8^I/`9K5EALQC/+\N>+PV'E
MA/[8\.J_@%XEYUC,#D7!>3\(YI1J97A\HRKB/B'-*^+XOQE:K44</E2EBJF6
MY#.G+"8:.(Q4L)G^(HPQLWE>5O'4Z&(AZ7\1_#UIXW\.33Z'I^A>)=0M7:(K
MY&@ZC/=VPMYVDTB"\U%HX(#)<3VES)`=4TE)8T:.:\2">6*?QN#PQXK\)>#O
M'.NZWI=EX?L+'P-XQ@N-*LYO#_AG1KR>32]1:SET[POX*%SI4ES/<F."/4/$
MVL:OJ$<%U%;Z?96EVUW+=>W0_#ZR\+:]8:Y\/]/TKPY#=7$%GXMT*PM6L])U
MG23B.&\M]-M;FTTJPUG1Y&:YBU"&R^T7=I)>6EQ]I9[>,?*W[1O[0-O/;Z[\
M--&TB[`34S9:MJUQ="*UU"WT;4(TO=.@@MA]HDL;G5;.\TW4)%O;69HM/NK(
MQ%+]Y+?^A>.:.2Y52S#B;B/ZUEF>.CB<OP.`RW&*OE?$F(>!J/!5%&I@H8A.
M$9^RQ<JLL)+`SI5U"K5HUJ>(QG]*^+.8\.<'93G''_'%:OP]Q/A\OQV49%@<
MLQ2S#).),U>"KXK*)X53RBGCZK59TH8Z..CA*&78FA7E^]P]2ACL=\(7UO+:
M7UY:3H(Y[6ZN+>:-61E26"9XI$#1*D;!74J&C14(&455P`55HK^28IJ,5)IR
M22;2<4VEJU%N32;U2<I-+2[W/\<92<I2D]'*3DTMKMW/VS^&-E9Z?X'T.SL+
M2VL;2'^T_*M;."*VMXO,UC4)9/+@A1(DWRN\C[5&Z1V=LLQ)_*'XSV\%I\1_
M&=G:PQ6UI9>+/$%I96MO&D-M:6JW,=PMM:P1JL5O;K/<7$PAB5(Q+/-(%WRN
MS%%?N_C#_P`DMX5?]BNK_P"J;*#_`$+^E;_R9'P-_P"Q5EG_`*S.3GE5?2_[
M)ZK_`,+>TAL#<+35U#8&X*VB:H6`/4!BJD@<$JI/0445^3\*?\E;PC_V5G#'
M_J]R\_DSP&_Y/-X9?]EEDG_J93/U9K\-O&LLLGBWQ*DDDCI!XAUV*%7=F6&(
MZQ?3&.)6)$<9FFEE*(`IEEDD(WNQ)17[U](?_=^$?^PS-_\`U%PA_:GT]_\`
MD1^''_8TXC_]1<H.8HHHK^9S_-$__]D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G;W!H97(N
M9VEF`````````````````````````````````````````````````````#`Q
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S0T`#$P-3$U-#,Q,#8W
M`#`R,S$Q-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F
M`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_
M`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F
M,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_
M,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F
M,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_
M9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF
M9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_
MF3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EF
MF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__
MS```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9F
MS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_
MS/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F
M_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG_
M_\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(?D$`0``V``L`````"``(```"/X`L0D<
M2+`@``!(2!1<R+"A0"0'D3B<V)`$B8,6*6K$1D)%'CV`0.I1H7#CPHYZ\CA1
M`6B%$T`A29H<2$)/RA(`JI"J`H#$RY`E*6+,DV?%"@`!G%2Y"$"%1U)Z@CH\
MB'1%(%:!K`0`8)45*RL>\U!E>)$$T8N!K%VS]A7`U6O7VE(%</(L(%)%6<&%
M9L7*BJ_0U@;JF1(C0;-55)#"^Q=NW$!_`\>U8G:QBBI1#U=>;%4MUJ-I!:_(
MLQ@OR\P/698N>M6J%:Y7(9,N3<JC'KH":]+>Z12`7ZI.G>R&>AGW9MHJG#B9
M>]")RN%X@Y(8_IS4<JK"K<^F#:CD\=6T5<(ZISU^M_>[X:$/MUA^L7?JZG>W
M7]P]-_KXT(E2][X=?_C^JTD'7W[SE58?3;.U=%=_@.1A$8`!%F162ZP\L:!R
M*UV4W7YD5?%7A7HL1EI*U>WFH$-HQ66AB!CNUF!&$\$6UPKW[:;'40=I5)5>
MD(5(VXTKO'84122L$``+5BU5ED6P>;4""P%,1`(+4%)9@A.C..%3%5I:X225
M+$AU&)A5!I!4EJ/DD24)`3Q)II@<D5DEE`:8B:6:3AQ)I9YA#A00```[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+VMR>71O;BYJ<&<`````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3`Q,S8`,3`U,34T,S$P-C<`,#(S,3<R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/_8_^``$$I&248``0$```$`
M`0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!````````
M```!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!
M!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/D
MY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'
M"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!
M"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)
M2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*C
MI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S
M]/7V]_CY^O_:``P#`0`"$0,1`#\`_A%N&B2]4SJSPK,S2*K["4#L6*O@KN4?
M,$R&D("*06!'[V?\$NO^"0_Q[_X*4Z+?>)O">N^'_AA\!?"6MCP[XX^,WB6R
MGU=I/$D-A::@OA'P?X,M;J/4-5U>6">-Y;J[F%OI[RF\F26TM9+23\+/#ZV\
MNNZ=]L@FO!)<M%;6=L-\TU[.'@M@8T(<+)=2VL29`625@B[R&6O]8W_@E_\`
MLG:%^Q3^Q3\$?@A:Z=!:^)H-$7QY\3]0BM4A?6?B/XZACUC6)=1R"9KS0[`:
M+I<$HVB!21"L;/*7_I#BWBZOPMD>.J8'$4UCLPJRH8>BW[R5&G1G.K)7349*
M:C!KF?-"3LE=/YS*LDHYYF.!PN+P\JF$PD?K-:HXITO>;A[-2LWSQ<$VO=5I
M+5VT^>/V5?\`@B#^P-^RUI6GVK^`=5^/7B^V%M=7WBWXSRQZQ;SZG%M:26S\
M$V;6?A?3+))-TEI%J6CW;[UBPWVA8Y$_1C7/@?\`!>\T:;P_%\'/AI_8DL1\
MS15^&>@0Z6?+4-&J16^F0V:*CHC(!&$W(I"[L&O8=8U5(4D<W;`B)V,CD32,
M\:EX59I?,=U,H0!6)4$C`K\]OVC/BQX[77K^RTKQ5JFD:;!#;V\6F6,T<*O(
M;<RS,SQQK/\`,%+X\PA<80*.!_,^=>(&<QJ3KYKCL9C*S4;*-:2IPA*,9JG'
MWE[L6V]D]6]+'[=P]PCA)UZ>`RS`Y=0@ES>VE2YIWD^[INSLEI?5[/J?)?[6
M7_!-?X:^.O!6O7_PC\83?LQ^,+?3[PV.JVC6M]\/8+R8^7]HUCP5-=/:C3WB
M>6&>6TM8X[`2C4+F&YM[66"3^#7_`(*5_LE:_P#`/XS:M?+'X7OK2]T[1+[5
MKGP?JHUWPU=7EQ:QVU[XCTV\Q#.NF:OJ4$DMPDRLNG37WE1O%!%$L7]L/C76
M]1O[=1KE_>:S%?.\<]OJ-Y<7,8C8GSA,)I"'0H6RKAEYX&17\[__``4MTC29
M_'7P%\7W-OIM[I!O_%_@SQ/H-^TBV&L>%+$VNOWVDWIADCD-O);1WBV@#J(W
MDC@5A:EH:Z.#N,:O$6:T<AJ8=.GC^94YU)RG)5.5)N=VW&+2C:R>MVD>CQYP
M?5RCA^MFSQ3J5,OJ4W*-&$8QY)N,5&*25^65VV[>ZT]7H?@_X?\`VQ_VK_#&
M@Z)X;\.?&?XB:5X>\/:1INAZ%I=E>R+9Z;HVDV4-AI=A:*MHRBVL[&W@MX`&
M8"*-`"1S17IVK_`OX1R:MJ<FF_$SQ#I^G2:C>O86$'V>2"QLFN96M;.&0EB\
M5M`8X8W+$LB!B3G-%?I,O#+$\S_<]7K>?=?W/ZLO(_*8\18RT;8J"5HV3J2O
M:T?\OZOI\\_"O4;?1/B7\-]:OX'GM-*^('@W5;Z!0C>?8Z5XDTR\N+-R=RHE
MX1&'EF'DP^4I_>2,L3_ZJOP6_;-U#XH>+[GX<>/_`(4^(_@S\0M-TG5-2T^#
MQ!>1R^%?'^E>'+;PVGC/7?A[JWVF2?7]'\)/J&BQZC(VFK<))=SJLYBMU"?Y
M8WPY^$WQ,\<>"_BO\3_"7A6_U3P7\"O#_AKQ=\1_%:6TYTGPOI_BCQ]X6^&W
MABTNK_9]@&HZ_P"-/&.@1Z?8F87[PZ9?7]O$+>RNI5_U2/A=:?"'XP^"O#G[
M0<6FV^I^-8?@MI'@_3-0GL;6\U/P_+XB\)^%[?Q2FBW4\<\]I::WJEE:7.L)
M:*D5Q]G+S+MWY\;QEGAG'*,90Q47B(8C,,-**FI4E[/"8:I&,K74:G-5E=/7
M:Z5D?1^'G)%YGAL;AZDJ#HX.M&4*3E-K$5YT^:%[+D_=.[O;1_$W8Y75?^"D
M/[%UWK%QX??]H/P%I>L:?J5MIE[IOB+^V?#T4MS)*^/L=WJ5L1<*3:RHKQD1
M2-A5P66OFOXK?$KP[XG\1ZMXD\+:MI_BO2KZ8R6=_I.IP75BQ,#Q121RB&.,
M1A'YWC#+G&7((O?%[_@E?^RY\8--U)5\.:/IGC/Q3I7A?3;J[U75YM.U6QMO
M#U_!KL%SX/G=+DVUU-=VSQZC<PP"YNM.GO+.>=H)"J^9S?LI?!W]E+2H_">E
M_$CQ9XMOI+)YM?\`A]!-9ZS8:9##$TD%Y=^(=2NFU"Q\^9(HUAM8U1F98HXH
M2XD7^:LTEC,3A5.M*#G*,9.<9-QLHQ5FVKW26NGE<_H3(J.5TLQ<L"JG)*$5
M&%2FXU+I*+?\B4G'2T^JVV/$]1_M;Q.MU:VT>Z4I/]KD3]U90(%=U+7[@0QD
MLH4^40\A/E(0[K7X<_\`!5?X<7.D>&M*U&Q\3Z=JDGPI\;>'O^$_L[6UN8/[
M+M_B)8VUCI:17-\7MYGEN&B2Z!!#6OGX'-?M-J7Q+C\9:AH6A1PVGA;PCIFM
M6B+H>FI<-/?6\-W&\YU*[Q+=W9\N-I!YLLJQ.JN@C*!E_"W_`(*F_$9K>+Q?
M\/\`6[Z.TUW]HGXL:7XUGTN\N8Y(M#^&WPAMGT3P]$L1M5=7\1ZK=6\T9\Q+
MA4#S)(1$H'M^$\L34XPRI81.M6AB*:?+&3A%*47)MV5EK;K=>5SS/$VJL+PI
MG4,=.G2HXB@O8PE).K*<7I)1NXV>B5I7OTVO^5L>O^$8(TA3PWHTJ0HL2R_;
MP/,6-0BO@2`#>`&P!@9XXHKB(M>L+2**T'AC3&%M&EN&%M&^X0J(P=[@L^0N
M=S$LV<L22317^D"Q.)LD\*KZ7TI[^[?KYO[_`+OX;YYNS3JVTMIZ6_3\.VOG
M7P@_:C^*WPK^#7[2_P"SIX?U*./X:_M6>'?`V@?$G0)@BA=1^&?Q/\*_%'PC
MK]LIC,D5[IVK^$9-*D!:/9I^M7K964P>9_:_^P]\:)OVD_V*_@)X8\&6OCG0
MM>NOA_%IOB;7O!GC_1/"WB&'Q'X*O?['US1K'2M9UNWN+ZS\1)IL5_)>6<<=
M_;6UR\5I/#:EH6_B^^/?PCN-.UCX@>./#FG0:=9_#WQL_A7QUI7VJ)KC2]5F
MU:]TC1-3TZTD/G7.F:R+.);J4Q&"WO6@C#M)-,D?WA_P3>_X*`^"OV?;6/X;
M?'E;*[^&UQJ%[J?A_P`077AJV\4WWAS4-0EMI;_3+V-85U6VL[ZYT^RV7MK>
M12:0SM?VS1QQ3I+_`"EQOD53,_#_`!D\%2J8C&X3.?[=C4FW[6IEN+PN"P\H
MT+MN<G/#596;4&MIO9?OWA_G='+N(JM/,\5'#4)X">7.*A3G26+HUZLZ7M')
MJW)*HT[)R22]WHOZVD\->*_!-SI\+>*/B]+XD"0V4/AWXAW.MW<VCK%*LEO+
MI^IW][JD-_YDJ(9)%NF1H2ZDM$Q1O+/BG\2OL7G3N]TNHZYIUK=:VE\L`ECN
M8H[BUGB$X037$+WZV]\D,SO%$81Y,:+E3Y5IG_!0/X/7/@^:]^%/Q/\`!U[:
M:PLT,L.N>/M8\<6ND6DD#")=#M-6DN+S3;\.46WL[BZG6&X*(@!&*^0M3^(]
MCXVOX[RW/C;7-(MOEOKQ],DM-0N((C))<K8+/MLP%@>=K5Y8TCE?8)YT7,L?
M\EU7BZ4G1?UQNE)PG0J0L[MJ25N9_8E&.^_-ZG]4Y>J59*O#V-2B\/&2KTE3
MC%I1CS/FNG>Z<MMFO0ZWQ#KVK^)=.U$:1K6IZ'#%!+;MK&F2/:7:WDQ\J-K.
M>#RWB8R.B/Y+(K1-(L@9"ZG^;;]IG5_'7A_Q58ZG\6=6O/$FG_$BUUKQ'X!U
M35M?DU[Q%HG@?P]X[\3^#-)MYK>:::2W-Y-X<N+Z&.X/F74=VMU.9S;Q/'^G
M7[9G[<?AOX8>&H?A=\##:>)O&&LQSK"\>-3B\(1W"[+E]5N+17_M+Q3%;?:?
MM.DP^?I^F)OU!;EVM`C?BO\`"SXB[_%=WX5\;^'K#QUIOC=_#?A[4YM9MSJ7
MB'0="TG67O;FV\'WMSYEUHL<TL][)J#6MQ:RS6DEU+(SW*I*O[OX-4,?EN/E
MF#HTL-+$/V&%A5@V_;6A+VLG9M1?,HWBV_==EV_G3QCS7+<RIPR[#XBI7CAY
M^VQ?LZEX*-VG23<N;VD7#GY6E&S2;U;6_!\0/AL8(2=0O@3%'D2VN)`=@R)`
MJA0^?OX&-V<<45R>K>'OV<]/U74["S\1^.[ZTLM0O;2UO3I\*&\MK:YEA@NB
MB*JH;B)%E*J`JE\```"BOZ6>-XFN[ULLWU_VC$+M?_F']?O^[\1CB<K2BEE^
M,>B2?L%KI&S^+KH_N\K_`&[^V8B6^H?MBB!%@$OQ+C640J(_-6#Q?X+F@638
M%WK#--+-$&R(Y99)$`=V)_)^^9ELG*LP+M#O()!?,&3N(Y;)))SG)))ZT45\
MGC/^1#3_`.R5RS_T]C#KK_\`(UQW_8WQO_IZ)ZY\$M<UJQ\6^'K>RU?5+.!=
M9L'6"UU"[MX5=KH;G$<4R(&/=@N3W-?M;\9_B!X\CTOPO81^-O%T=CJ&J>&M
M/O[)/$FLK:7UA>ZMIUI>V-Y;+>B&YL[NUEEMKJVF1X;BWEDAE1XW9245_->8
M_P#(PK?]?H_^D4S^E>&O^2?C_P!>Y?\`IN)\=_$_3--TSP=\=M5TW3['3]4T
M?4])TW2=2L;2"TO]+TZ;6M)BFL-.O+>..XL;*6.66.2UMI(H'221&C*NP/YX
MZ.[Q:?XIU&)VCU"#P_ITL-]&Q2\AEF\0:=%-)%=*1/')+$[Q2NCAI(W9')5B
M"45^K<(?[QEG_80__2*9_/V?_P`?,O\`'_[>CTC3(87TW3W>*)G>QM&9FC5F
M9F@C+,S$$EB22222223S1117[:]_FOS@?G+W^:_.!__9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R\`````````````````````````````````````````````````
M```````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,3`V-P`P,C$U,#,`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V%N9V5L=VEN:RYP;F<`````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-S8P`#$P-3$U-#,Q,#8W`#`R-#$W,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````#P```!4(`P```*Y%1(4```#`4$Q410```/____W_`/KZ^O7U
M]>OKZ^KJZN'AX=34U-#0T,S,S,?'Q\+"PL'!P;Z^OKJZNKBXN+"PL*RLK*.C
MHYN;FY24E)"0D(V-C8N+BX>'AW]_?VMK:U!04"0D)"`@(!L;&Q04%!,3$P@(
M"/___P``````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````&'A
MM_4````D=%).4_______________________________________________
M`%@L#0T````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````F4E$
M0508TV6/;1."(!"$=THZ["3#WHC0T_C__S'0)L?83SRSLWL+8I15,2+*;I5$
M)/S9Z5GX17ZKA46&;'Y9@K.M=4$6[KWA+./[^;X_<:VUKKGQN3^8T;^F(P%L
M0MKC^#*]GP<%U.P$8EF3JJI*D68K&-J9]S.W0^&G/#I22I%%SJ?^*\Y$U.&>
M^]/]YH&LVW+_?U^Q?_._#[[Q&BRYYWX.`````$E%3D2N0F""````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]W:6YK=&]N9W5E;W5T+G!N9P``````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#<W,``Q,#4Q-30S,3`V-P`P,C4Q,S0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@````\`
M```/"`,````,"&5X````P%!,5$4```#____.`%*U`$C]`V?\`V<A!!!(#R@N
M%"(0"PX\(S,2#1$/#`\5%AD]S+4PH(X&$Q$+(!T*$1"/XM4_U;L^T;<F@'`Z
MNJ0YN*(F>6L?8E<WK)<UI)!*VL`D:ETN@'$L=6E6W<5.R+('$A`(%!)KX,QK
MW\L^@78C13]_Y=(WKY@VK)4(&!4#"`<*%!(=)2,;&QO___\`````````````
M``````````````````````````````````````````"W'^)@````,G123E/_
M____________________________________________________________
M____``U0F.\````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MDTE$050(UV6/R1("(0Q$4^XKCHI&!05&41@7,O__<[)XL2:GO*2ZTX$V%5$@
MRATD<DI*J1P5)BTPE="4F/03&>><81,'T#I1[2_7V@"@<"V0PE7U?MPM`$-%
M0!*YL=Y[:SA*@E!X6SAT]E'/UK?/8KIY97WT1WY>#H;S7?:/]QMDLUY_?"CW
M<[[C9'3ZY>OD__OO"T.:'BN;U768`````$E%3D2N0F""```````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O9&5V:6PN<&YG````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T,3``,3`U
M,34T,S$P-C<`,#(S,S`U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````/````%0@#````KD5$
MA0```8!03%1%````____QB`CQ2`BFAD;E1@:E!@:>A05<!(4PR`BN1\@]BXP
MC1T>D!X?]SP]2QP=^6MM8Q`2&`0#\B$A[2`@Y1\?R!L;WQ\?S!P<?!$1Z",A
MW!\?#@("SQ\?S1\?R!X>%`,#UB$ARQ\?-`@(TR(APA\?P!\?:!(1'P4%M1\?
MKAX>@QX>8QT=4A@8]U14)QL;(!L;_/S\^_O[^OKZO;V]M;6UHJ*B=75U&QL;
M&!@8%Q<7$!`0#P\/"0D)"`@(!@8&!04%`@("____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````#^>L4````$-T4DY3
M____________________________________________________________
M____________________________`$%B!.\````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````TDE$0508TVV0ZU+",!"%SR(B#;:I2`'!N_$"
MT5:IRHHBI>__4&RWR(PSG,F/_<Z9S6Z"\K^PAY-MG=1\=;;E\WOE\5\/$N6+
M'=\J7WHP9\P83)4G_CDTQCP,IE[YU0=.='/@N6+VC;MN[S2Y?FJ(@=(&K@]$
MP-`%M@2';M0!4J`S<B&#S2.B-([C-,*+863FFU`K+TPF.8CDS!8T6TK.X>J3
M?HGR!7T4TE_:UGK^5>7OQ9'5^<TU<GK[*4YTOAB'2[EMU:[W$\-6^Q];WOV7
MOD^K#3Q^,].F5/;C`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O<F%S<&)E<G)Y+G!N9P``````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W
M-S,`,3`U,34T,S$P-C<`,#(T,C(V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#
M````#`AE>````,!03%1%````____S@!2M0!(_P%G)`$/5`0F/@4?5P@M&P0/
M%@4-`@`!)`<6%08.#P,*EB!EXS&9WS"6CA]?VC"2P2N!Q"V$:1A'QBZ&@1Y7
MHB9NE2-E*0H<(PD8?"98?BA:%0</ZV"Q%0D0ZHC`(`<6NBR!MRQ_KBMXZ#VC
MB"=AZDJHF3!NYEZN2"`X[W:^)APB"P,(&0<2#P0+&QL;____````````````
M````````````````````````````````````I0X<_````#1T4DY3________
M____________________________________________________________
M`$M7(F4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````E$E$
M050(UV6/V1:",`Q$YRANN*%5XX86I;5HJ1K^_]^TK2\>\I2;G,E,T/AB=LRA
M@R=KM-;&<F3.U6%/NZO*V3/G):W&\]F2RN\`C54$W)^G-TC9!FQ(`/(A`4&&
MP9JR2M9U+:N,-,-%OD1VK;W7'\]%FDY?0>_O9[=)DHP6X7[P%\-.M[^._CX?
M;0>]S2]?*__??Q\$UQ_#?3."\@````!)14Y$KD)@@@``````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V)L
M=7-H+G!N9P``````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S8U`#$P-3$U-#,Q
M,#8W`#`R,S,S,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`
M4$Q410```/____KZ`.[N`-;6`,C(`,3$`+BX`*>G`)^?`)N;`)B8`(J*`'Q\
M`#P\`!`0``0$`-75#<S,#,?'#/__'___.?__50L+!!(2!__X.]G.!^&V&/_3
M*>:@'^>?(_V7,_^5./!R(_]Q(?]T/?9B-?Y<,O\_*_]#+?PU)/\D&?\P*?\$
M!/\9&/___P``````````````````````````````````````````````````
M`````````````````````//X68P````N=%).4_______________________
M_____________________________________P""CW-5`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```)1)1$%4"-=E3TD2PC`,TS1NPI*F
MAL:!LN][__\]8GH"=+*LL22C4S#7S)\)RH)WSOG`/>?*DL)6K)RKDDQ1%(;*
MO$`7+`$Q1H!LZ,">#"`B@"'/8+?<KB3-DNS.:\>HW>EU;=,\R>-Y<W76-Y=C
MFU*2PWV?=?8+-#'?QRGT/OL/,,G^#4;JK_EC*(9]_F^_O_Y?_[T!7JP2"/5$
MA`L`````245.1*Y"8((``````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]E;6)A<G)A<W-E9"YP
M;F<````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`S-P`Q,#4Q-30S,3`V-P`P,C0T-S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4```#____^
M&!GV'B/Y+"_N+33O-3WM.$'<1UC43%[26&^^2&FR2VRT9HVM9(Z&8I:"8)8!
M`0(#`P5E:*IU?,-9<<,!`@0"`P43%!8\:[\,#Q0P==HK9KLN;,8A38T=1'P>
M1H`;/G(F27Q8@\4<("8Q>^,"!0D<1'@L:;HL9[<<0G4K8JX]AN@G4(A*C>I2
MA,I@FNL@,4AVJN\,#Q,&"@\``0(!`@,'"0H``0$='A[_!`0;&QL3$Q,0$!`+
M"PO___\6KVV*````0'123E/_____________________________________
M______________________________________________\`PGNQ1`````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"L241!5`C7;8_'$L(P
M#$1WZ+T30A$U!H)CXX2.@/S_7V'#B1ETTM/.KB2DKI@#YD\'1[&24JJ8O_QH
M>PLBFGKGIV,>;&8G(<1ZOKNRY3@$(JUU!(1Q"E8$:&.,!D@Q6'8;/9,DB:F7
M6I(1R'*FN+H\+_O</2\#JS<+E<,MN8VJV9K560W[$:P?T=CY;3X)V'P(<ODI
M+[?4\87?H>W2[;>#<')\'2>AQ7_W__SW!L,%)@UW+'T1`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]P=6YK;6]H
M87=K+G!N9P`````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,30W-P`Q,#4Q-30S,3`V-P`P
M,C0T,#,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````\````5"`,```"N142%```!@%!,5$4`
M``#___^$1%T(`@4#`0(%`P01#Q"O.7@7!0\,`P@8!1#C,9F&'5KB,IC:,))-
M$30)`@8U#"3&+H9.$C4O"R`B"!<R#"(9!A%,$S0C"1A<'$%\)EAV)%1U)%-?
M'4-+%S5W)55T+U?K8+'.5)MU,%A0(3SJB,`F"!K?,)=!#BRZ+(&W+'^=)FVN
M*WA%$3!P'4_H/:-M'4V()V%V(E1R(5%])UKJ2JCG2:;50YDY$BDI#1X<"Q7$
M4)1((#@O%B4_'S+O=K[H<[G=;;#<;:]%(C<F'"(1!`P%`@0!``$&!08`TPX`
MJ`L`J`P`I@L`I0P`H`L`G0L`FPL`F@L`F0L`F`L`EPL`E@H`E`L6,!@:(AI'
M@S@X.BX"`0&19F88%Q?GY.32S\^>GIX;&QL5%140$!`("`C___\`````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#G<\'#````9W123E/_____________
M____________________________________________________________
M____________________________________________________________
M__\`%!:Z>`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#E
M241!5"A35<Y7-\1@%(7A$T8-@Z,;O9OXE`]10Y28.+J,W@_V__\)+B)KQ;YY
MUW.W">GD+BVE.9-KR?M4KO*62TGD)N=S223YYZI4<[Z0A\?[S!K(;8VQSYI:
M2YX\-3![)04(7P-E?FUUW2*71[Y!J-1VM2WZOK\\UQ-70+K22]F:5I74\`S%
M>P='A;B9C5)D>'9K<G_Z<&K391.1&G8WQL,PG%CKZ#1*:KFXM+XSMOU2[_19
M)00>M_2?O-$[?>P&(.A0=^'GTR&'C@<5!.CP?&,=4?O"J&;_K3'&!G__`:A&
MJ@"`7X]J5.NB9+](`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]F
M<G5S=')A=&5D+G!N9P``````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4V,0`Q,#4Q-30S
M,3`V-P`P,C0S-S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````
M8%!,5$4```#____Z^@#N[@#6U@#2T@#(R`#$Q`"XN`"*B@!\?`!N;@!I:0`\
M/``K*P`6%@`0$``$!``#`P#__P^VMA;__Q^ZNA?__SG__U4+"P02$@?___\`
M``````````````#$]U=P````''123E/_____________________________
M______\`%[+BUP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``""241!5`C798_+%L(P"$3G)-@\;#2T4J+Y__^T-':ALN+"F1E`MV*NS$<'
MHY)BC*GP8,Z!K$)F8\X3>>><IVD?H)=`@(@`%$H')_*`J@*>$H,C.='V;"J.
M(J,.?@VNY[XUW>Z7?6_Z57;]MLRF-W^WBCR6Z^%_YM_F3_[O?7_W?_WW!@@=
M#19D*X]I`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]N9G5S960N<&YG
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-3<`,3`U,34T,S$P-C<`,#(T,#(S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````/````%0@#````KD5$A0```&!03%1%````____
M!!0$!R$',>,Q,-HQ+L8O+*XK,;8P`@<")GPF2^I*8.M@B.J)'"8<+KHL+K<L
M,+$N+ZXN)Y$F*(@G(4@@=^]V&QL;____````````````````````````````
MTH=;[@```!ET4DY3________________________________``$T"K<````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````@TE$0508TVU/`0X"
M(0QK%(8"<JA`]_^7>APQ%\0N6=)UZS:H0O5,..),T+D!2_^,_SJ9R*^NK,4Y
M5RH'I\_2D3T[I]_$&F.L;'L!6K,`(01`<E6PB`5BC("50M")";&U%H,11Z3!
M'X.G1>_SMSMV/(_Y[G]Y[_ZOZ^&_[/^];[E_^N\#C,D3GBUX?50`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAI<'!I971O;F=U92YP;F<`````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,#$U`#$P-3$U-#,Q,#8W`#`R-#<P,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````#P````\(`P````P(97@```#`4$Q410```/___U4,&R4##<X`4K4`
M2/\"9?\#90$!``\+`CTI``,"`(M=`?BD`O.A`NV>`M6/`M*-`L^+`K=Z`G9.
M`7%,`8A:`GI2`B<:`?JP'U$Y"OZS(..@'9!F$H9?$5Y"#!<1!1\7!_V[//;*
M;HA8`<:"`L)^`I9A`CHF`A4.`?VK$1P3`A<0`WA<*/[$5G19)_2\4R89`R`7
M"!<.`P(!`"82"1<*!QP*!UH;%#\0$`("`O___P```````````````")*6>0`
M```\=%).4___________________________________________________
M____________________________`+N(ZZ<````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````GDE$050(UV6/YP[",`R$+7:!$$,@98]"0UAA
ME0+.^[\720M"B/OE[VSISF"]B`*B;`)/6@HAI*:<*53HI4+R3&&,G#'&,78&
MV,:J4Z\-Q[.DB^N-!8*ODCX!"633R_%T6$P8"H+`\2`R2Q.-'`?9?A09D[.[
ME\C/^WF:7G<<)8'5"MGV5JG>6ZCT)_]1*A?:>7[6K_DL]M[]_OK__/<">=D?
M;&>7%E\`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V1A>F5D+G!N9P``````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,#0P`#$P-3$U-#,Q,#8W`#`R,S(W,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#P````\(`P````P(97@```#`4$Q410```/___\8@(\,@
M(KD?(*\='F(2$YH='D4-#I`>'[XN+WT>'_<\/?$[/.XZ.^,W.$L<'5(C)/EK
M;<A66)E"0Q<$!?(A(9L5%4(*">D@(*X8&)(4%&8.#D@*"N@C(<X?'6@0#TX+
M"T<*"DP+"T\-#,<@'\(?'K8='(T7%H,5%($5%-,B(<`?'K$='*0:&FL1$4`*
M"FH1$4D.#H,>'DH2$HXC(Q@&!@0!`4T:&O=45,%"0D88&/*`?R<;&QL;&___
M__]]#0$```!`=%).4___________________________________________
M_________________________________________P#">[%$`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```*U)1$%4"-=E3]<2PC`,\Y$P
M4D()`<(H>T/*+"LM=?__KT@H+QQZLJRS)$/F@)@B?B9P3#!**1.8<XS(^:B/
M9Q*AXQ@5-A"H`#8%NX!,$/T`CWOPT$1D@$R/VO?8Q/?V2#,$I*'RC932^$I3
MA+1XZG`C7]+P7DA3JR^&-=-LM`P?;*V.;-TMWY)G4B_-E_;>^N]FE6KM>IFN
MG+_+WX^5ZD\.>;[KIQV^_?[Z__SW!DQF(MK`D'YZ`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W-A9"YP;F<`````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S4U`#$P-3$U-#,Q,#8W`#`R,C<V
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`4$Q410```/__
M_P,&"R=BMB9>KB5;JC!UVA<W90XA/2YLQ@D4)0($!R9)?(BOZAP@)B9@L0<2
M(3%[XP(%"2QINB%.BR!,ARQGMR!+A08.&2%-B"MBKBYFL3V&Z#!IMBYDKB94
MD2=0B$J-ZF":ZR`Q2':J[P0+%!L;&____P``````````````````````````
M````````````````````````````````````````````````````````````
M`````````/SU"T$````H=%).4___________________________________
M_________________P"^JBX8`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```)))1$%4"-=EC\D2PC`,0S4L`4,IA$*`L&5#_?\_Q$E/##KY
MV6/)QEA%]F2K4"D'[WW(G)C=;24BZTO'RNQ.QZ6U=C$[:P-C=M?](\;XF&]<
M'L$@!D@I`48"02\6**4`5CS1*\=4=B5%Y;[-E<O$;/O/+53WMJ_^\GFK_^L@
MU5_S!S&:;V1H^=IP4N6F^_[N__GO"ZGI%LSB=6]G`````$E%3D2N0F""````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]F<F]W;BYP;F<`````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#4T,``Q,#4Q-30S,3`V-P`P,C,S-#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@````\````/"`,````,"&5X````8%!,5$4```#___\#!@<<(R4XHKLL
M:':.TN,]N]<[L\X)&Q\TDJ5IR^$UGK`UFJT&$1,XFZTVE*4WEJ<M>XDM=8%5
MR=\B0$5^UN8;&QO___\```````````````````````````"`-O9T````&712
M3E/_______________________________\``30*MP````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```!T241!5`C798]+$L,@#$,UP10"H4W+
M1]S_I,6P:M'*SQ[+,KJ*-.2LH%1S""%7+J9-HDJ6RK27>.><EVLTT&L2H)0"
M2*H=S.*!&"/@)1,,XDILK<7B)!!F\6.QV>:Z_SHP])[[ZO_\#/_[G/[;_?]\
M6_Z?_[X'"PSQ[U@5Y`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O8V]O;&=R:6XN<&YG````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$S,S4`,3`U,34T,S$P-C<`,#(T,#(T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````/````
M#P@#````#`AE>````8!03%1%````____``$!`0,#`@4%`@0$`0("'6)7/<RU
M'V=<)F9<"!43C^+5/]6[.KJD.;:A.+.>-[";,J"-,I^,,)F'-ZR7-:20+H!Q
M)VE>+'5I5MW%-8EZ(55,%38P:^#,:=S(&C8Q$2,@#!@6!@P+(T4_$B,@?^72
M/6YE-Z^8,9R'"AH7?>'.8[*C'24C`0,""PT+`P(!$Q`."@8%$0L*(`L*_P``
M^@``]0``(```%P```0``.`,")00$!@("&QL;%Q<7$Q,3____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````:Y/:
M^P```$)T4DY3________________________________________________
M______________________________________\`1!80``````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"H241!5`C798_9$H(P#$4SBKBV
MHM!6<->*N.!>W*/\_T_9BCXXWJ><23(Y@=0$,49\5V!("LZYD)@Q^HR:,!\-
M/RHS6B*$E&C4>FH>Y7-@53MS&\":I(#"+5I@#PJP*E.!@)R2[GBYF`[;A'*$
M6'/0#VMA+]`<F_X&LEP<W4=!#^>C2E1RVIK]5++Z^J:4NNX<)O4]]*/&74_O
MFY$6^OBYGO?U^_/_^>\%#5`A)V@E_S<`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O<'5N:RYP;F<`````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$P,3$`,3`U,34T,S$P-C<`,#(S,34T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```/````#P@#````#`AE>````,!03%1%````____"`(%`P$"#`,(&`40XS&9
MVC"231$TE")DD"%AQBZ&FR1IC2%?+PL@,@PB&0817!Q!?"982Q<UZV"Q=3!8
M4"$\ZHC`)@@:WS"700XLNBR!MRQ_KBMX<!U/PC.(NC&"M3!_;1U-B"=A=B)4
M<B%1ZDJHU4.9.1(I*0T>2"`X/Q\R[W:^Z'.YW6VPW&VO12(W)APB!0($`0`!
M&QL;%145$!`0____````````````````````````````````D)MTOP```#AT
M4DY3________________________________________________________
M_________________P`[7!'*`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```)Y)1$%4"-=EC\D.PC`,1"V6%#!K"6MBH`0"A+*T-?3__XRD
MB`/JG/PTTG@&RB#FC+FZ()`S1&0<?YECC4$ZYL"OB<)("!&AFKX]YXUA9V.M
MW:]'15X"'\;P4^O(P(1+**[W9[-H(S%DA*O+[+9XS,\"*0N^.,DT3:45P6>#
MD%@II=T!&H;2Z3YL?7X"/>W\/X[5H$KO*E^HWJ_6_V_?![()'4+,:B3Z````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O9W)I;BYP;F<`````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`W-#4`,3`U,34T,S$P-C<`,#(S,34S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````/````#P@#````#`AE>````,!03%1%````____*P$"&`$#)0,,
M!P$#%@,,!``"`@`!&P01HC#:CRR_C"N[E"[&D2W"?R>I>B:C?RBJRHCJIS'C
MB"RZARRW@2NN9B>(7R9\M$KJO&#K.B!(Q7;O(APF_P``&```$@``"````0``
M&QL;____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````3?Z*
M%````"5T4DY3________________________________________________
M`#_/0D\````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````C4E$
M050(UV6/R0[",`Q$1ZPEQ5!(LR=E<?[_&XD;<4#,R<\CVV-4$7-A7BL()6>M
M=8D[LS<D,IZ%V<^DM-:*YM9`38:`$`)`)E6P(P7$&`%%CL&6=(@YYQ@T64;I
M?.]<Q#^BZSTVO\WOGB_!QTGFV_[+L%V693.,LE_NG_?-/MSZ_37?=9J^^?[R
M__SW`;/"%(W+;N'K`````$E%3D2N0F""````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+VUA9"YP;F<`````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q,#(W`#$P-3$U-#,Q,#8W`#`R,C<T-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````#P``
M``\(`P````P(97@```!@4$Q410("`O[^_J,'!/Y(/M\)`K`:%=HJ([X(`^\3
M!Z8/#>TH'\H@&>X>%OPY+_YK9[`'`TX&`E8V+OY:41H:&MH;$_Y^>L(3#?XL
M(/P.!=(/![,2#<LG(KL?&OX=$<T)!````,G3,E8````@=%).4___________
M______________________________\`7%P;[0````%B2T=$'P4-$+T````)
M<$A9<P```$@```!(`$;):SX```"5241!5`C7-8^+$H0@"$49LS2-\-&F5K;_
M_Y=+NEV&&0[,P`6^+.AJY9/S/!XLZ`QBO.QYVIT>:.C]@MI[;G#,UV22KS[K
MPL1C.R&@3Y`VQ5O%84V-80VQ+C>TN<%A_:R8=.?3(`XAI/KRE*-S+DI);`KH
M*C'7FF54T.^KLBU:R[O=YP8=>RFWZOZ>=P01"?C[?Q]LU0]PI@W4X6')E@``
M`(-T15AT8V]M;65N=`!4:&ES(&%N:6UA=&5D($=)1B!F:6QE('=A<R!C;VYS
M=')U8W1E9"!U<VEN9R!5;&5A9"!'248@06YI;6%T;W(L('9I<VET('5S(&%T
M(&AT='`Z+R]W=W<N=6QE860N8V]M('1O(&9I;F0@;W5T(&UO<F4N`5534U!#
M350]`#H8`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+V1E=FEL=&]N9W5E+G!N9P``````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,#8P`#$P-3$U-#,Q,#8W`#`R-#4S,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````#P```!4(`P```*Y%1(4```#`4$Q410```/___\8@(\4@(L,@(KD?(/8N
M,)`>'_<\/4L<'?EK;18%!B4&"Q<%"!P#"!<$"%D%&3\$%%4#'20!#<X`4K4`
M2/\!9?\!9A@$`_(A(>T@(.4?'\@;&]\?'\P<''P1$>@C(=P?'PX"`L\?'\T?
M'\@>'G`2$10#`]8A(<L?'XD6%30("-,B(=$B(<(?'\`?'Q\%!;4?'ZX>'AL%
M!24'!X,>'F,='?=45!8("/*`?R<;&R`;&QL;&____P````````RL0.<````^
M=%).4_______________________________________________________
M__________________________\`NOMQ-@````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"_241!5!C3;=#9<L(P#`70.]3.6J"L;4B!E'T1
M72@F-%7^_[>(9<H,0_6D(X\LV2AO`_\XO>2I\WQ\\>1=_/;7@U0\O7HMGADP
M%\P8[L5?YNAKK3^&>R/^-8JJ6#T8MF93V[X,DG3Y6:L**$-%KT``C$B%)=BG
MS`-RP,O(9["F),BC*,J#A#2C</YQ+N[.;?\A/M6;\;?TV_L3[_&YWQC(_78^
M94_=7GOGYE<%19M69Z'<?E4AM/O[(5__2]XGV1F%`#+:/Q5/>@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W!U;FMT;VYG=64N<&YG````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,S0S`#$P-3$U-#,Q,#8W`#`R-#0P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````#P````\(`P````P(97@```&`4$Q410```/___\X`4K4`2/\!
M9R0!#U0$)CX%'U<(+1L$#Q8%#0@"!0,!`B0'%A4&#@P#"!@%$.,QF=\PEMHP
MDDT1-,0MA&D81\8NAH$>5R\+(#(,(AD&$2,)&%P<07PF6$L7-14'#^M@L74P
M6%`A/!4)$.J(P"8(&M\PET$.++HL@;<L?ZXK>'`=3^@]HVT=38@G878B5'(A
M4>I*J-5#F3D2*2D-'D@@.#\?,N]VONASN=UML-QMKT4B-R8<(AD'$@4"!`$`
M`1L;&Q45%1`0$/___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(;$=D8```!%=%).4_______________________________
M____________________________________________________________
M`++NL3@````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````JTE$
M050(UV6/R1;!0!!%ZQ!3C*U1QA!ST@A!Q!!)D?__)MW$PO%6=<];O%L0JQ`%
M1.\+%'F.$,+QZ,-DV*AB&Z3X,;"0,\8X6L.GY+#8::Q<U]TLNU$8`VU[\$UU
M1T`"YQ"=+K=25$-!$`A<',?GV75R8"@"U;.]Z?N^Z3+5DX.\/YKJ>N7.T2&(
M/1O9NJQIA3K:GMPC0^[G4^ELTY)"B5\[EVDE?G_^/_^]`$3\)J^Z7/5V````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V-O;VQT;VYG=64N<&YG
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S0P`#$P-3$U-#,Q,#8W`#`R-#,V,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````#P````\(`P````P(97@```&`4$Q410```/___\X`
M4K4`2/T#9_P#9R$$$$@/*"X4(A`+#CPC,Q(-$0\,#Q46&0`!`0$#`P(%!0($
M!`$"`AUB5SW,M1]G7`L@'29F7`@5$PH1$(_BU3_5NS[1MSJZI#FXHC*?C"9Y
M:Q]B5S>LES6DD$K:P"Z`<2=I7BQU:5;=Q36)>B%53!4V,`@4$FO@S&G<R!HV
M,1$C(`P8%@8,"R-%/Q(C('_ETCUN93>OF#&<AP@8%0H:%PH4$GWASF.RHQTE
M(P$#`AL;&Q<7%Q,3$____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````,'12ND```!$=%).4_______________________
M____________________________________________________________
M______\`<=*/$@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"I241!5`C798_7$H)`#$4S]B[B6M=86%>P8$/$BE'^_Y_<!5X<[U/.))F<
M0*1#%!+%%6CRI!!">I0PV1;J6#9I?O<NR#CG#(/%1_&AV0"CO[J9`,8I`I*3
MM@'FK@6O#DH"$LC7Q^?CO%]R%`2A8F?K#WW741S&?<?U_835O$36W=QKY<&5
MZ?W(LY#/Z[E\=826I^Z1'2"K9++%<:"$4K]IJ3!+_?[\?_[[`CV;)LT6LL92
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V)I9V=R:6XN
M<&YG`````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#$U`#$P-3$U-#,Q,#8W`#`R
M,S8R-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`4$Q410``
M`/___P$#!`$$!1PC)3BBNQQ072QH=@('""N%F2=YBSV[UR9UAR-L?#NSSC22
MI00)"A]"2FG+X2E[B29P?36:K2AU@R%@;!];91M/6"EVA!]99$C%W"U\BB]_
MCBUU@57)WR)`12QS?@`!`0$$!`$"`OS\_/O[^_KZ^KV]O;6UM:*BHG5U=1L;
M&Q@8&!<7%Q`0$`\/#PD)"0@("`8&!@4%!0("`O___P``````````````````
M`````````````)9BL>$````X=%).4_______________________________
M__________________________________________\`.UP1R@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"B241!5`C758_)%H(P#$43
M!7&DBM81+444'"**E/[_G]F6P\*WRLWX`MJ*R"-R$5B2@C$F)+5,`?>M>$"6
M*5CU^K/)*,NV)@%:\N'X>$GFI^F92PTD_#!.HBA*XM`7!,0&T&G!"#SV1@3$
MO,1",<_4P7%18EZ9.HGZ@5_'=V7FM5PWSY?MOZF-=/>7#11X_:B=NV\2^\HL
MKP^MO\Y_VOG_^^\'/J@;#>'Y-3$`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAU
M<G0N<&YG````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S8R`#$P-3$U-#,Q
M,#8W`#`R,S$W-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`
M4$Q410```/___P8"!P\$%!T()Y,KQWXEJJ(PVH,GL)0NQCD23!(&&`,!!'XT
MHR`)+'$AFA@'(:<QXW<CHA8''H@LNH0KM8<LMX$KKH0NL1<('X@PMH(NKFPF
MD3X64V8GB%\F?+1*ZI4]PI(\OHTZN+-*Z;Q@ZRL6-B,2+#H@2,5V[P@%"B(<
M)@X*$1L;&____P``````````````````````````````````````````````
M``````````````````````[Z[C\````O=%).4_______________________
M______________________________________\`6J4X]P````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"0241!5`C798_)$@(A#$13;AAW
M=`178%04Q/#_GR=ARH/:I[RD.IU`9A$EHEH!4S!::Q.H8[(*6<H2,]EF,AX,
M%Z/-MC0@!X7+Z=5=9FM4(0,9%/OVX>_SLT!#0!KES<=G]$ZB)DB%G8^OCE.=
M%XZ?.?L//2C:53_O[Y^<<\=5W<_Y**24`IN:_WO?W_U?_[T!GT,:S4!/FXT`
M````245.1*Y"8((``````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A;F=E;"YP;F<`````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4W-@`Q,#4Q-30S,3`V-P`P,C,S,#0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@````\````5"`,```"N142%````8%!,5$4```#____]
M_P#Z^OKU]?7KZ^OAX>'4U-30T-#'Q\?"PL+!P<&ZNKJXN+BPL+"LK*R;FYN4
ME)20D)"-C8V+BXM_?W]04%`D)"0@("`;&QO___\```````````````````"&
M+3L,````&W123E/__________________________________P`G-`LU````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)!)1$%4&--ECVT3
M@R`,@W.;%"H.]P)H^?\_=*UZ\QSYQ'.YI`&MR:G6T.1V2AH4?[8^.[_+7[6S
MR&KFP5)SFE*NLO-2(IMB6;;[9>3@O0\\%NNOD0$B`CA6W9,Y`,XY('`62&)/
M;A@&1YZ38)TVOF\\K9VO><RD>4JPO/8_\=#^&6_KM_L?F%[[_?]]W?[+_[Z6
M@!0%[?S'.P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]O;"YP;F<`````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P,#(`,3`U,34T,S$P-C<`,#(S,3,S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````/````#P@#````#`AE>````,!03%1%````____``$!`0,#`@4%`@0$
M`0("'6)7/<RU'V=<)F9<"!43C^+5/]6[.KJD+9&`*XMZ*H=W*81T,I^,-ZR7
M-:20.ZZ:/K:@.JJ6+H!Q)VE>+'5I5MW%-8EZ(55,%38P:^#,:=S(&C8Q$2,@
M#!@6!@P+(T4_$B,@?^72/6YE-Z^8,9R'"AH7?>'.8[*C'24C`0,"&QL;%Q<7
M$Q,3____````````````````````````````````````````````TA5U?P``
M`#5T4DY3____________________________________________________
M_________________P!\M=`*`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```)I)1$%4"-=EC]D2PB`,1>]HK74!-]!BH^*&6)<:[?]_F]`^
M.=ZGG$DR.4$=PUPQ-Q4B.:.U-HY;YD+)&%5PY/?P)C,A1";+]2?PJ=M!,MK>
M4R"YU&"SZ"=(#SV\!M(P6$NQ.S\?U^-&2,VH`M/>C[VEP%73)^M]RV'>2.1D
MK:4EXG[MU`0K(LHQ4R[<XZ*<(V9:!J%_OS__G_^^XQ\;I55VD%``````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;7)T+G!N9P``````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$U,3$`,3`U,34T,S$P-C<`,#(S,#`V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````/````%0@#````KD5$A0```8!03%1%````______P``0$`
M_^0`_>,`_.$`^=X`\]@`V+X`UKP`T[D`QJX`Q:T`OZD`LIP`JY@`IY$`GXL`
ME($`B7<`;V$`:5P`8E4`1#L`"`<`;E\`:%H`64T`0#<`/#0`-"T`%!$`&!0`
M&Q8`&A4`&Q4`&!,`(QL`#PT(0BX!#PL")1D`KW0!^*0"[9X"X)0"U8\"NGT"
MMWH"MWL"MGH"M7D"KG0":D8!IF\"B%H">E(">5$"7#X"L7@%LWH'_K,@_;L\
M!00"!@4#CEP!B5H!A5<!YY@"QH("PGX"JFX"@E8".B8"+Q\"_:L16#H&V)8:
M'14&&1,(_L16#0@`?DX!DU<!@D\!7CH%"P@$8SL)`@$`3R<%-A@`F"L`#`,`
M%A86"`@(`@("____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````O&*Y*0```&)T4DY3____________________________
M____________________________________________________________
M_________________________________________P`05I*J`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```/1)1$%4&--%D.=2Q#`,A'="
M+T<U<%0#H042S%$32DP]@SE*Z"6`_/XO@>/,S>T/K;X9:78D&"?X\,O&5;]@
MO\4+6)X'FDQZ;7'I\^;VM&0ZNMY>F=S=.C^D@BFY7/]YV;P"+A(R@%;/&W=?
M]Q]O^]^O``B(`"FE<RHX!+(L<TX(:@A3F9UE,@U1"T".W]L>'=OY6$2-U.ZG
MC4C$!*.5L(M6H5#:Y=?%;Y[GJZ)>Y/->2M3)P]/?L4JHFX./]I&.=P[V8DV=
M@QQF8F!XAB@@XKQ_MKBG6ND9YU8=E:GRWKDAQCS&1JK-?[`QS^MBTZW_&-;.
MR^8?RIE'_/_Q\M@`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<VUI;&4N<&YG````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-3,`,3`U,34T,S$P-C<`,#(S,S(R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````/````#P@#````#`AE>````&!03%1%````____
M^OH`[NX`UM8`R,@`Q,0`N+@`IZ<`GY\`FYL`F)@`BHH`?'P`/#P`$!``!`0`
MU=4-S,P,Q\<,__\?__\Y__]5"PL$$A('____````````````````````````
MLMYVB0```!IT4DY3_________________________________P`4(@#:````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```'Y)1$%4"-=EC]L2
M`B$,0S/0!2]<HEM0_O]'I3+[X)JGGG:2MA@FLI+?"D8EQ1A3X6+F(*:0:<R\
MB7?.>=EF`Z,$`505D%`&F,0#K37`2R(8Q6GKK][4223JXO?B>LS[,9]^[#K]
M^H3Y9_X%CYF_XV;YMO\.TW7M/]_W=__/?Q^PF`Q'Z0PYH0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O96UO=&EC;VYS+W-H;W5T+G!N9P``````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-S<W`#$P-3$U-#,Q,#8W`#`R,S,V,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````#P````\(`P````P(97@```#`4$Q410```/____]R"NAG"\I8"[A0
M"M9=#*Y-"LM:#*=*"O]U%#\=!281`YY*$(]&$A8+`]=I']-G'QH-!/^'-/J$
M,_&`,=MT+?^63/^M<B@?&=I=#%`M%O^B914&`1<'`@X#`!H&`1L(!`\#`0@"
M`0@!`"@"`"@#`?\``/H``/4``#H!`"```!<``#H"`1L;&____P``````````
M`````````````````````````````````````````````````````,6XVND`
M```P=%).4___________________________________________________
M____________`&*ET'@````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````G$E$050(UU6/Z1*",`R$=QJMI5H\$!&*]U&\PON_G4V9<<;\RI>=
M33;HI9AKYM1!R#MCC/,\,.>:I'3.PIPWI*RUBIHX0.\U35?KHIS/2/L>[$@M
M@0I8*'(,-F0+H`4*2X91"U?MMJV$ZZ27%P"G3=+%O[^'$#[GY)?][T?H0O=*
M^^7^[A;UYV&X'P>C:_0?QT.^E'^29;_\?_]]`4`J%O/K),F*`````$E%3D2N
M0F""`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]A;FYO>65D+G!N9P``````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3`R,P`Q,#4Q-30S,3`V-P`P,C,V,S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@````\````/
M"`,````,"&5X````8%!,5$4#`P-JDKXR0E8>*#2RRN)(9(`I.4F&JM)24E(0
M$!#F[O92<I(Z.CIWG\[*VNHN.DJ8N-K^_OY*2DI"675<?*,Z3F8F,D*BOMYR
MFLH*"@H6%A;2XNY&7GY"/D*ZSN8````P1),0````('123E/_____________
M____________________________`%Q<&^T````!8DM'1!\%#1"]````"7!(
M67,```!(````2`!&R6L^````D4E$0508&36."PX"(0Q$"_(1D95(61=QX?ZW
M=(JQ21O>E,R4IA1)_5Y"S3FW7Y:";KJ64JJ&(MRJC<P</]5!`%M6*27%MNY@
MX.%SSOY@J^%!48FYD8$/1)R(MKX1)2YN<1[]UD<&/X@"V&!OA+&?0?F7&>9Z
M?\<J>0'^Y_-<_L(0_OEMW3M#D/ML`RZ&@ARA.;]::@WWQ"**S@```(-T15AT
M8V]M;65N=`!4:&ES(&%N:6UA=&5D($=)1B!F:6QE('=A<R!C;VYS=')U8W1E
M9"!U<VEN9R!5;&5A9"!'248@06YI;6%T;W(L('9I<VET('5S(&%T(&AT='`Z
M+R]W=W<N=6QE860N8V]M('1O(&9I;F0@;W5T(&UO<F4N`5534U!#350]`#H8
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V5M;W1I8V]N<R]W:6YK=&]N9W5E+G!N9P``````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#<W,``Q,#4Q-30S,3`V-P`P,C0T,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M``\````/"`,````,"&5X````P%!,5$4```#___]/$!XC!`[.`%*U`$C^`V;^
M!&8&"`-DB!VGXS&DWS"@VC!]JR:0Q"U-:1B2QBY?@1X:(PE??"80%0>\ZV!L
MAS>[ZF#(ZHB-NBR*MBN*MRR#KBL/%`6QZ#U6<1X3&0=IB">UZDJDU$,1%0D[
M2"#([W8/$P8C)AP1$@<>%PT4#0D8#@D4#`E-)1PX%A4;&QO___\`````````
M```````````````````````````````````````````````Y12(\````,G12
M3E/_________________________________________________________
M________``U0F.\````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````DTE$050(UV6/R1("(0Q$4^XB:A111Q@=4$;<P___G"Q>K,DI+ZGN=""D
M(O)$N8-$SFBMC:/")!2F4H(2DS@@9XQQK.(`@E/U]'0]6P!4+@`9G->3[4X"
M<#0$I)%9V;:MM`PU@2^\+^P[^ZCGZ\WE\;HU61_]D1WOH_%SEOWC_0KY>S#L
M+<K]G&_UZ2]_^3KY__[[`B7_'#D,QX3[`````$E%3D2N0F""```````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O86YG<GDN<&YG````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-38`
M,3`U,34T,S$P-C<`,#(S,S,S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#````
M#`AE>````8!03%1%````____QB`CPR`BN1\@0@L,MR(DD!X?C1X?HB<HA2`A
M_$1%2QP=^6MM`@``_P0$_Q@8$`("GQ86EQ<5Z",ASA\=(@4%^R<GK1P;TR(A
MGQH9A!45+`<'_RHJ(P8&UB8E_#`P$`,#[R\OLB4D_3<WWS$QY30S@QX>C2$A
M@AX>=1L;Y3<V]CP\^3\_#`,#^D!`\E)2]U14+`\/]U55%P@(A#`P\H!_9$!`
M)QL;>%A8]/3TYN;FY>7EVMK:("`@'Q\?&QL;%A86%145$1$1"@H*"`@(`P,#
M`0$!____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````TT*(>````$ET
M4DY3________________________________________________________
M________________________________________``P(GU4````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````LDE$0508&07!!4+$,`!%P=]-
M($B*+A+<@T/18LO'W_U/Q(P`L'L;``'.*<:8L@&!:]A8*ZO+H1J$ZZ`LS2S,
M+Y9!-2*'(DU>3NVJA(R<RE#JKCMI6)+E>'AUT;5MVTT?'$6KC^=S.[?M0]MM
MSJ[$7HYG]T\WDNX>C_>BY;3]_JQ&S>?+J"2+'#Y>OQHUGV^CD!&N8S^_DOZ^
MMZH1N(Z?K)>R/W%J$."<8HPI&Q``=F\#\`_U-B,!DWIY%`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O=VEN:RYP;F<`````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`W,S8`,3`U,34T,S$P-C<`,#(S,38T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````/````
M#P@#````#`AE>````,!03%1%````____#A$*!@@#9(@=I^,QH-HP?:LF;90B
M:I`ADL8N<ILD:(TA7WPFO.M@;(<WN^I@C;HLBK8KBK<L@ZXK#Q0%E,(SCKHQ
MBK4P5G$>:8@GM>I*I-1#.T@@R.]V#Q,&(R8<"0H%&QL;____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````E5ES0@```"1T4DY3____
M__________________________________________\`6"P-#0````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"'241!5`C798_!$L(@#$1W
M5%"CH!6JE4C%\/__*)'I0=U37C*;35!5(D7D4T$IIQACRM)97"!5<*(L[D+6
M&&-I:`W4',;-_?E@@$*ND$3;<7TZ>\!2$D@DPWY^S9X-14'IO.I<EOF\S)L?
M$WOO^0;UM_T'7)EYPE[WM_SA"-6NY__>]W?_UW]O2JX3T`0@JC``````245.
M1*Y"8((`````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+W9A;7!I<F4N<&YG````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S4Q`#$P-3$U
M-#,Q,#8W`#`R,S8U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@`
M``#`4$Q410```/___P@,$3UWMSIQK3EOJCAMIS9IHBQ5A"Q5@QHS3CIQK#EO
MJ2Y8B"E/>@X;*4B"PC==B5"(Q10B,0P4'4!HDTQWIDYYJ6B8S6:5R6*0PEV)
MN"Y#6QHF,WBCTHRQV9:WW,/5Z1$A,@D/%`,#`P("`O___P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-97/=L````G=%).4___________________
M________________________________`(-6E]D````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````CTE$050(UV6/R1("(0Q$&S.(H$X0-]S`
M0>7_/U$BY<&R3WE))=U!%3$7YD\%(6>-,=9Q9QXUB?3(PCP.Y$,(GH;60'6:
MMH]3/,]VI%T%6_('(`%'3Y;!AD($,A`#&4813OF>DW#I\Y1S9Y9]?"7[[?[Z
MJ6Z7JWHMY'[S7VY4&ZI]]V^-^=3B3:N>[R__SW]O<^P/]DD,>$@`````245.
M1*Y"8((``````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H86YG;W9E<BYP
M;F<````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<U,``Q,#4Q-30S,3`V-P`P,C0P
M,C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4```#_
M___.7`C_<@K'60A9*`3H9PO670S+6@PL%`.V5`[_=13@9Q*M3PXQ%@2>2A`1
M"`*/1A);+0W_?24B$04:#00&`P'/;BJR7B3_AS3^AC33<"O(:BDP'`[_EDP[
M(Q+_K7(H'QG:70S46@PC#P)0+1;_HF4$`@$;&QO___\`````````````````
M````````````````````````````````````````````````````````````
M``````````#WY:>&````*G123E/_________________________________
M_____________________P`RJ/!<`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```(M)1$%4"-=EC]D6PC`(1#E&210UQKKA$MMJ(OG_'[2D
M+R[SQ(4S#$!1B70BM0*EY)US/LG($BRJ;!!E"?UL,E^NI\_'T("2+*[V5SZ^
M%FA3`?%H=I=;O)^V!KV`.*1SS#E')G0"W<`<<SMR5^?\,5?_!E2'ZM?]U#!S
M0W6_YJ,A(H-]S?^][^_^K__>76$5V_<$N#P`````245.1*Y"8((`````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8FEG9G)O=VXN<&YG````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`W-S4`,3`U,34T,S$P-C<`,#(T,#,T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````/````#P@#````#`AE>````,!03%1%````____A#L%_W(*62@$
M%P\)=#,%Z&<+XF0+WF,+:"X%NE$*UET,R%<+RUH,WV81_W44QEL0N54/GDH0
MB4,1CT82C$4272X-_WTE+A@)WW8MU'`K_X<T+!<)9CP>1RH5.B(1_Y9,9#L>
MQGY.*!\9VET,;"X&9BL&0B`*4"T6'1(+_Z)E[I=>HVA!!@0#&QL;____````
M````````````````````````````````````````````````````````OT5O
MS````#%T4DY3________________________________________________
M________________`!^:3B$````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````F4E$050(UVV/6Q,!,0R%,ULV+E6EEEIQ*;NH1?K_?YV&)\-Y
MRG?.G$D"2<3<,+\G$(K.&.,B?Y@KC2)=L3!7;0E@`<HV&Y"BQ@R4+=0Q`3M4
MGD((Y!4Z!C9H*71=%\BB86@RUX?;L[^O,S>23]?'Q_VTVTXES_WBNI'^JI!^
MBI/1W!.1G_7&4?8O+T-EK56#\X+_W/=S_]=_+]XY&9/:>/@B`````$E%3D2N
M0F""````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+W=I;FMG<FEN+G!N9P``````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P-S<U`#$P-3$U-#,Q,#8W`#`R-#`T-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````#P``
M``\(`P````P(97@```#`4$Q410```/___P8(`V2(':?C,:#:,'VK)HV_+(J[
M*Y+&+H_"+7VI)WBC)GVJ*%]\)KSK8&R'-[OJ8,CJB(VZ+(JV*XJW+(.N*P\4
M!59Q'FF()[7J2J340SM((,CO=@\3!B,F'!$-`QH1!`0"`!8,`PP&`0<#`24,
M`R<%`3D#`?\``/H``/4``"```!<```$``!L;&____P``````````````````
M`````````````````````````````````````````$S$PE@````Q=%).4___
M____________________________________________________________
M_P`?FDXA`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)E)
M1$%4"-=EC]D2@C`,13/:BE$$%5ML+19WBTOX_Z^SH>.#XWW*R7H#/8O($PT1
M,#FCM3:.$E.AD*4*8J9B@U(((;&*">B=JL?;_<X"H'(]D,%)/5JN2@")AH`T
M"ELV35-:@9K`)UXG]EP_0M([B_4X?WT]0A>ZYX'GX_Y9>PLAW,\9[X_WJ^DE
M=I\6Z?[@;Y[G7W]__G_^^P!X.1D.>_"Q=@````!)14Y$KD)@@@```"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]H:7!P:65G<FEN+G!N9P``````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`Q-@`Q,#4Q
M-30S,3`V-P`P,C0S-#(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X
M````P%!,5$4```#___\!`0`/"P(]*0`#`@#XI`+MG@+5CP+1C`+/BP+-B@+)
MAP*W>@*W>P*V>@*O=@)V3@&(6@)Z4@(G&@'ZL!]1.0K^LR#CH!V09A*&7Q%>
M0@P?%P?]NSSVRFZ(6`'&@@+"?@*680(Z)@(5#@%X7"C^Q%9T62?TO%,@%P@"
M`0`6"@`@#``:"0`/!0`(`@`I"0`%`0`H`P`Z`@#_``#Z``#U```@```7```!
M```"`@+___\```````````````"Y`='X````/'123E/_________________
M____________________________________________________________
M_P"[B.NG`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)])
M1$%4"-=EC^L2P3`0A7>4=*FXI.Z41BCJ3NJR>?_WDK2,,<ZO_?:<F3T+QHG(
M(\HG<*0$YUPH*IA"B4XR),<4QN@SQGR,[0),958KEWJ#<=K&^<(`P5=IAX`X
MLM%FM5Y.A@PY@6>Y&R73).I;]IQ_?L>?@?5)X.EQTYG.[CL4!$;)ZO:BM;X>
M`JF*^_6C3>\;Q?V\7[/5^O3[Z__SWPL^?1U`PQQ89`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]T;VYG=65O=70N<&YG````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<T
M,P`Q,#4Q-30S,3`V-P`P,C0R-#,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,`
M```,"&5X````P%!,5$4```#___]'$!XA!`[.`%*U`$C]`V;\!&8QXS$PWS`P
MVC$MQ"X8:1DNQB\>@1\LKBL)(PD'&0<F?"9+ZDH'%0=@ZV`)%0F(ZHD<)APN
MNBPNMRP_Z#THB"<A2"!W[W8)$@<4%PT/#0D1#@D/#`DY)1PM%A4;&QO___\`
M````````````````````````````````````````````````````````````
M```````````````````````````````````U\\"@````*'123E/_________
M__________________________________________\`OJHN&`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"(241!5`C798_)$@(A#$2[
M7",:41!E$'#<PO__H0)>K,DI+ZGN=%!JB7B1UJ%2BEKKF*2SF,"U@I'*8@96
M1*1X^`Y04F#`6@MP2`4260'..4!Q%(AFLB[G["RQ%OC.E\Y^LJ_ZP^E\?]Z.
M35_]Z3JNUH]-\^_W7XOE;-OOMWS[]WSWRS?)__??!R.B%>9GE'\=`````$E%
M3D2N0F""```````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8VQO
M=VXN<&YG````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U,3<`,3`U,34T,S$P
M-C<`,#(S,S,T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````/````%0@#````KD5$A0```8!0
M3%1%````____``!9`0'(`0&_`0&Y`0&O`0&3`0&%`@+F`@*V`@*@`@)9`P-;
M!P>E#0WB!@98$Q/6%172'Q^\'!Q6&!P8P<+!&,T`&,("')8,-X@L<8ENNL*Y
MP,>_?(%[AHZ$)BDES0``S0("S0,#S@4%S@8&S@<'S@H*T`\/SQ(2T!04T1T=
MTS$QTS,SU#8VU4!`UTU-V%55V6)BVF9FVVQLVYF9W*BHW;2TRJ6EX>'AU-34
MSL[.RLK*R<G)Q\?'Q<7%PL+"P<'!O;V]O+R\NKJZL[.SL+"PIZ>GGY^?FIJ:
MC8V-BXN+AH:&?W]_>7EY;FYN;&QL:&AH9&1D4%!03DY.)"0D("`@'AX>&QL;
M$A(2#`P,"0D)"`@(!@8&!04%`P,#____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````OU?0`````&%T4DY3________
M____________________________________________________________
M____________________________________________________________
M`*Z`;S$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````^TE$
M0508TT609U,",1"&=^QZV)5`J';%WDW42!1/-)PM<*Z5_/]?X>:.T>=#YGTF
MR<[N@DN8'LZD`9)S=C`(,O\^,Q`0XSV?[.LQ.I7XQ-!8?Y`P1\ZYM2.I6LLY
M<,:8;6.,;4N)`S"6XY6P$59XCC$@SQ>*):54J5C(>X=R=OY22GE1S9;)'-=O
MT!5"?,#WLW6`1IU_G1UL[IUTKY5!P%!+<51;6=X54H4(<0-NQ/;ZPN*:D#^W
M,=U_-L5A;75I2UR]-^F]N8/6Z?[&SO$#^/_.ZD>XI_HM>-%4WV%4?_5MP%,]
M0C]?)]+*HZ-.N@^TAOHW%O_VA30?)ND79+)%=B7F[S4`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O:6YD:69F97)E;G0N<&YG````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-S``,3`U
M,34T,S$P-C<`,#(T-3`S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````/````#P@$````D=]=
MP0````)B2T=$``"JC2,R````"7!(67,```!(````2`!&R6L^````G$E$050H
MD851L0W#,`P+T*TO>/$/?J2;C_`49.J>Q6NV'N`'.O4[EE3E&!D*@X!!BZ(D
MRPN6CH"`")TC=DH)&<60R7N*BP^L>)Y8>?\EN+@QN*,:=O+-$R@G<ZK,RR"F
M"DER8"\Y%6P&,57(]%,NI)6NAK>AD5?&BN1XD3\7.4[=O?=][`*WT;M/7G'X
MY(=Y??+INR=;F^[\_X]]`0"2(A?5)$N7`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V1I<V%P<&]I
M;G1E9"YP;F<``````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#$R`#$P-3$U-#,Q,#8W`#`R
M-#8V,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```!@4$Q410("
M`JZ$,O[$5FY*`LZF6J!L"/BD`OZS(%I20BX@`M6/`F96.K=Z`AX3`OVK$?V[
M//[^_IY^0L:"`NV>`HA:`GI2`@\+`AX>'L:.'FIB4JYR`FI2(O;*;CHF`L)^
M`@```#][W!D````@=%).4_______________________________________
M__\`7%P;[0````%B2T=$'P4-$+T````)<$A9<P```$@```!(`$;):SX```"(
M241!5`C798^+#L(P"$7OI@.'?<2U6[7:[O__<GT8$Y6$A`/A<L%>`]B`7M5,
M7BGE$SICS5(CKQ4*+N*(R,E2&MA3%C+,;$AR*DI>G&%K+1LG'D"4>+?C.%HF
MB865G)Z7\ZNQ:G/B:PB/(6";T/>'<+,\I5CV?_7_[C=_L]9Z[O[>_N/'_]=_
M!\-;#G37G<R8````@W1%6'1C;VUM96YT`%1H:7,@86YI;6%T960@1TE&(&9I
M;&4@=V%S(&-O;G-T<G5C=&5D('5S:6YG(%5L96%D($=)1B!!;FEM871O<BP@
M=FES:70@=7,@870@:'1T<#HO+W=W=RYU;&5A9"YC;VT@=&\@9FEN9"!O=70@
M;6]R92X!55-34$--5#T`.A@`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W=O
M<G)I960N<&YG````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S0T`#$P-3$U-#,Q
M,#8W`#`R,S8V-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`
M4$Q410```/___P<,$CUWMSIQK3EOJC9IHBQ5@Q\\71HS3BE/>A\\7`X;*4B"
MPE"(Q3!2=PP4'4AQGD5LET9NF6B8S623QE!UGGBCTEY_I(RQV9:WW`$"`Q$A
M,CE:?0D.$PH/%`,%!O___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````!*^L,L````B=%).4_______________________
M_____________________P`-T,-Q`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```(])1$%4"-=EC]L2@R`,1#--`<&%WJ)(M5K__R=+L"^=
M[DMR9B?)AG85L`"M(R7OK+7.XV`$TW?<]29`&>$<Z)(N5"LJ>\,SC3+2S,;O
M!,=QW:8\;6MD!X+E-.122AX26]!267)YEBR5E^9+\Z7Y.G][4]6CS>O^TTM$
M[M>V7^]S3"E%/NYK/E9]\_WE__GO`^GP#I,@,W:.`````$E%3D2N0F""````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A<VQE97`N<&YG````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V-P`Q,#4Q-30S,3`V-P`P,C,T-C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@````\````/"`0```"1WUW!`````F)+1T0``*J-(S(`
M```)<$A9<P```$@```!(`$;):SX```";241!5"B18_C/`(/2_Z7_*_P'D0@Q
MN)3Q__#_V6`8#F3#E$`E`_X7_J^$PT(@'Z(`*ED,%&SYWPF&+4!V,50!4-H8
MK+,3J'@F&#(#V2`3C$'2TD"[0#HG`:67@B$#D`TR(1RH'RB=#=8[\S_;_TU@
M"#(%I#\;)*T`EU[ZG^,_+XJT`K)N5FRZ"=B-Z7(N9)<3]#>!4",8YKAC#``"
MB"&YUV)%O0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O96YR86=E9"YP;F<`````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P,S0`,3`U,34T,S$P-C<`,#(S-C$Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````/````#P@#````#`AE>````,!03%1%````____IP$"_0(#M0(#^`8)
M!`H3'$>$,'7:#B(_#R1""!,C+FS&'$)Y%C1?)%.9)DE\#Q4>0$M;'"`F$"E,
M,7OC(U>@#R5$"18H%S=D+&FZ+&>W#!PR*V*N"QDL/8;H)U"()T^'2HWJ/'._
M/'*^*D9K8)KK(#%(+T=G=JKO5%]N&R<V"Q`6#A4=1@``10``,@``,```+```
M)```%P``]/3TYN;F("`@'Q\?&QL;%145"@H*"`@(`P,#`0$!____:(4#6P``
M`$!T4DY3____________________________________________________
M________________________________`,)[L40````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````J4E$050(UU5/61O!,!`<=Q&4JJ,1C:!1
M]\VZ^O__E:1]89]V=KXY%HD=(H\HW6"1ED((J2G#Y')FA[MD,;E@CN_[#H,Y
M(-$<O5`I%5;`=0*238RG413-QFA(`@D@?U['FU/Q`$'P1`VE+8!]83<2GN%;
M56`5MW'L#PU/DCFA,GH5.LSHC3_KOM[X/`?,^IO\X'Y![G&]!6F^.2R6=90[
M\ZR?[3_Y[?_WWQ?;VR!S^X0CJP````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;&]V92YP;F<`````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$P,S<`,3`U,34T,S$P-C<`,#(S,34T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````/````%0@#````KD5$A0```,!03%1%````____,>,Q,-HQ
M(I0C(9`B+L8O))LE(8TA+*XK,KHQ,;4P)GPF2^I*8.M@B.J)'"8<+KHL+K<L
M-<(S*(@G(4@@=^]V_0``^@``]@``]0``]```\@``\0``[```W0``VP``UP``
MTP``T@``R0``O0``O```NP``M@``L@``GP``E0``C@``@P``>@``<@``+P``
M&QL;____````````````````````````````````````````````````````
M400<E````#-T4DY3____________________________________________
M______________________\`<9Z]C@````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"Y241!5"B19<[;3@,Q$`-0*PM#0W?"-DV6>[D5RJ5E
M=OS_'\=#6H'HXY$MV2!)N@_N)$F0]%IBC*5ZL_=91$1R[R3H_4*Z$$(GB]X)
MUBR`J@*2*^%%.B"E!'12'!XE:!K',6F0Z!B:+YJ'H]R+8*XI)3V'%`=K/L-2
M5><XS;7MSP``)VW__[^C_R3=;6>T3]N;]G+Y8=O;5SOXX>K^\?EN/>U->[NY
M7GU-ASYIF]73Q%_S^WWB7]-(\@>9\24"'H.1@`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=&ER960N<&YG````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-C0`,3`U,34T,S$P-C<`,#(S,S(P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````/````#P@$````D=]=P0````)B2T=$``"JC2,R
M````"7!(67,```!(````2`!&R6L^````F$E$050HD861,0Z$(!!%339NL5>@
MX0Y<9#L.066L[&UL[3P`%[#R=G__S(*$PDQ^8CZ\^8P,`X8J!P</^;:]&P5$
M)%6DKR4%?C%AN35Q_2\H<.;FBDVUTL^E@#AH<L..0[73RPE!L&,O24J7$1EO
M=7)"9)XX:?8@.E697O))L._PU6%OIFOO3YL%7JVW\>?FO8VIF3-_?K$?8<HC
M#MU3ZMH`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAI<'!I92YP;F<`````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-S8Q`#$P-3$U-#,Q,#8W`#`R,S0W,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````#P````\(`P````P(97@```#`4$Q410```/___P$!``\+`CTI``,"
M`)]K`9MH`9=F`?BD`NV>`M6/`L^+`K=Z`G9.`:9P`HA:`GI2`B<:`?JP'U$Y
M"OZS(..@'9!F$H9?$5Y"#!\7!_V[//;*;HA8`<:"`L)^`I9A`CHF`A4.`=./
M#L6%#<J)#GA<*/[$5G19)_2\4R`7"`(!``("`O___P``````````````````
M`````````````````````````````````````````````````````(PS["T`
M```N=%).4___________________________________________________
M_________P""CW-5`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```)!)1$%4"-=EC]L6`3$,1;/4K1.E1=S*5!F*2?__]_3R8.$\92=9.2<0
MLY@%<ZD@D]=**>VY,AN'6<YP9C8M-E+*!MO4@#@ZS8:#]6;?S_%\B<#P4;]D
M8(5R]WH\[X>M1,4@$J]L.`9+B469DPVA<MK7"!U9:^D&J!FB=PNX$E$'$^>K
M_[1<'U?_WWQ_^;_^>P/3-1<Y$YJ-UP````!)14Y$KD)@@@``````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUO8FEL92\`````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,3`V-P`P,C`W-3(`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+V1I<W!L87DN:G!G````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-C$U`#$P-3$U-#,Q,#8W`#`R,S$R,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#_V/_@`!!*
M1DE&``$!`0$L`2P``/_;`$,`!@0%!@4$!@8%!@<'!@@*$`H*"0D*%`X/#!`7
M%!@8%Q06%AH=)1\:&R,<%A8@+"`C)B<I*BD9'RTP+2@P)2@I*/_;`$,!!P<'
M"@@*$PH*$R@:%AHH*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*/_"`!$(`'@`E@,!(@`"$0$#$0'_Q``8``$!`0$!
M```````````````"`0`#!O_$`!<!`0$!`0````````````````$"``7_V@`,
M`P$``A`#$````?1Z[C=3+)-EJF55#.DV,Z'89027!YQF4[8R1;LXKG7.B6UD
MU;8QS(BA@>@$2R*&6',I*LK*HJC+*B:U">A,#T!0'0Q1*,O/+35LM#152NG-
MW*1=%V522B8%B+)8E!1FCMI<P]D^:N6Q:GHA;ETYUF.TFDT0C"9I%';34Z<T
MB85RZ:[I@JA4QS,F:=)9,)=*(J;82^:VZ4*AKDZ'1D>.PI)M8<;&PHZ2*VFV
MEV&W;"6UEVR7;;:;;2;##L,FQMML_P#_Q``8$`$!``,````````````````!
M8#!`4/_:``@!`0`!!0*/.&9V"-,A_P#_Q``:$0`"`P$!```````````````!
M,``1(!!`_]H`"`$#`0$_`8=7@J/;@+S#@>"EE'__Q``:$0`#`0$!`0``````
M`````````1$@0!`P_]H`"`$"`0$_`1;>$3V#W"?)\E+F\?\`_\0`%!`!````
M````````````````@/_:``@!`0`&/P(._P#_Q``;$`$!`0$!`0$!````````
M```!`!`1(#%!,/_:``@!`0`!/R'"YIO+F<F_9N8:7(P-YCC)/DOOGESVDDS$
M$9R,YO,Y,S.,1'ISRS,XQ$1%R//)F9F9P1$1$1K,^#,1&$1$8S,XS.$1A$0Q
M=QF9F9PB,(B+N=F9F9F8CY&&!B[K.,S,Q$>!G==69F8B'SV[X[K._;L7?7=[
MG;]Q<+Y_`WMWQ\S_V@`,`P$``@`#````$,-O>=E3`._RH6&ZXBU;0/\`PDMW
MO78G-3Z@!Z^:$4&*Z-W*RSVX,&$9.5P2Q?%UHB`?&U"[R/\`@!#!`<!`_\0`
M&A$!`0$!`0$!`````````````0`1$"$Q4?_:``@!`P$!/Q!?V4LMM[#GV!%L
MREEMAMBVR66RRSP$>1;,^3,Q'"SHDR0B^P623)(ED$$%EM]-M226600<R3)X
MRRR"R.?_Q``:$0$!`0$!`0$````````````!`!$0(4%1_]H`"`$"`0$_$,^$
M(("R0D).@@A>+"R8).$00<,9DLB(X$)F>$0Q;,RRVPPP[;#,?U++P\<@1#;+
M++/#@PVRRRSS_\0`'A```P`#`0$!`0$```````````$1$"$Q84%1(*'_V@`(
M`0$``3\02HE2I"-=T)5PW()JD)N8*AJ84/7D0=$U#@6A*"3I`CJYLFX:(3PB
MMP2@A!#1@W!IHX+9M/3?1!*3;T)5T51&$(AJD(GT=8@0=+\8K9'IP\P:_"!"
M(5$)YA,$$2PH:J2_,$4HP@E$JJ)P2HE,(3&Q,$$0]%":@F&HGP5"(6Q5D9-P
M<&@@F3Z\PV&.H='61!$35'IW!,&J)![/KTU9JQ#I/]%IX-@F&I/X"#T/300>
MV-]P^#5F$9#8-T8;!CC(]8<#'VC#,8@4%]P@89"+].!AL&W!D&*,-<#%%*,0
M-W!L(E&(M.)@FF)R>C3HS%%A475&&Z7`S&0SF#-='_<"T)V>"C$YDK+J#=PH
M]C;@S.]&Z=>%/A&";0G"ZI11BHOHW"C4HX5&[X&TWX,?"'$+\?Z)P3I2HNH)
MT3@TZ4;IQ2I!NJ%U#Y"_!3__V0``````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M;V)I
M;&4O<FEG:'0N:G!G````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,P-#``
M,3`U,34T,S$P-C<`,#(R-38S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/_8_^``$$I&248``0$!`2P!+```_]L`0P`&!`4&
M!00&!@4&!P<&"`H0"@H)"0H4#@\,$!<4&!@7%!86&ATE'QH;(QP6%B`L(",F
M)RDJ*1D?+3`M*#`E*"DH_]L`0P$'!P<*"`H3"@H3*!H6&B@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H_\(`$0@`
M>``Y`P$B``(1`0,1`?_$`!L``0$!`0$!`0$```````````4`!@0'`P$"_\0`
M&0$!`0$!`0$``````````````P0``04"_]H`#`,!``(0`Q````'1$KER/$KD
M7Q>G=I2IK5;N-,4*BH_2E#/2B]`9$;)*K=QQ*X\5']&)F>E#O7`W"6JW<>,R
M+&_U,2-]&+=NAN$M5NY`1D:1_J6H7?%OVB%S6JW<>"[G9'1';#OC])2X>XTJ
MMW'9S19V5F\YI\M=+ZMT<?8?W5;N(.H$[LU5<WJW31I5;O\`_\0`)A```0$'
M!`,``P``````````!#,!`@,%(#(T`!`1$B$D,2)!0__:``@!`0`!!0+7[&2>
M6#;R+0_>-]B+2UO(E$6\92.M*\2B+>,N0K*<2B(H,N4I*,2B(H,N4I*,2B(H
M,N4I*,/=NG[Q5BE)3AT/J"7E*2K#W;I^\31*LLPZ(C?R$1(6ES/4H?N&\"1<
M@)GJT1+N.H[5Q\?=NF,[Q"-?U#;R+O%;Q#`=[%1_COEX9G4??__$`!X1``(!
M!`,!``````````````$0!``1,3("("%!_]H`"`$#`0$_`9@\OTF:!!3-$%,U
M04S""F8'29\HN3[SM1R__\0`'!$``@(#`0$``````````````000(!$Q,@(B
M_]H`"`$"`0$_`43]8HCV8,)=&#"6X,);HCNB&S1,8\9I_\0`(Q```0,$`@(#
M`0```````````0`"(`,0<7*!P1%A05%B4O_:``@!`0`&/P)<JL/WU:GB)5<8
M-FQ*K:BPS$JKH+<Q*?IW;F+D_3M!<Q=E/T[07,79531!#,795;`00S%V57.+
M-B[*J^W=69%V4/9)M3Q%RICZ;:GK$-_H^$4["I:P)7GX8/-GJF/S#__$`"00
M``(`!`<!`0$!```````````!$2`A,1!!47&1H;%A@<'A_]H`"`$!``$_(6J$
M(.A^7%RA0Y&$JD>:ZO\`"D[#BI-!CY?J\-X[R9VFOLRE2QODS.R<I19+._R3
M,[&,M;W^2,[#&4M;Y+#M"IVB>X1>3(['8%U\O<$O(E=P>3Z6A8?1N1X,6I\1
M4A`_=]RO:U"-G3.8%2$!<IH,T;97>0.K[(6$#1Y(T$,5W7R8^6V1=F@B/XDV
M:@03.7\7]'@Q65H1WR23_]H`#`,!``(``P```!#3]_SKC?R[U?SHW_QAG_QD
M!_PVQ_QX!WS_Q``<$0`"`P$``P```````````````1`1,2%18:'_V@`(`0,!
M`3\04E/@61]D8A^%[$8AN$+#$+R(Q#VHJN"R&I(<,60]+9`LC__$`!L1``(#
M`0$!``````````````$0`!$Q(6&A_]H`"`$"`0$_$*RDV>PZOB6D/9:0]RYI
M=FCJUAAU!</8=0B!L,*__\0`)Q`!``(``PD``P$!`````````0`1(3%1($%A
M<8&1H;'!$-'PX?'_V@`(`0$``3\0)1J9:QX?1TN6N;WO'NYBAK<H!NJ=E-@1
MQZ04C-8&_D^4(-0X;F*E_P"I?L,OS5=4H6C,]$;5JXX;F]E3X.PF'&XK(RL]
M$6(R1V+[#U$QMP/!L'Q#@Z0.Z.G^HJY\Q?T8-BO3W'W,5\IZS!#^1HV,#YB[
M)YF'EO3\;-_S1L>A^17J_1ET-P[M^$ZV5<?TFP\'7Y*T[OHPE2VN^?TF/GRK
MFOB&7YR='Y`K\+S"G,\+?<Q<^5G<CS#+\XB(4TJT[Q1I3F-`?MBKFOV="^1#
M+\TJ](J^@[-_N*Q;=.\MZ!%5XR[,%N]5=AS=(-#F/>I;#RI-%+?<8VU@L(N2
MWN'8!7<"O:"]A:M$OP,%1DX<@83ER>"_L9G-]>P36]"7A=H<4^BE;=,9;-P^
MN1'(4E\;'__9````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+VQE
M9G0N:G!G````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#,P`#$P-3$U
M-#,Q,#8W`#`R,C,W-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#_V/_@`!!*1DE&``$!`0$L`2P``/_;`$,`!@0%!@4$!@8%
M!@<'!@@*$`H*"0D*%`X/#!`7%!@8%Q06%AH=)1\:&R,<%A8@+"`C)B<I*BD9
M'RTP+2@P)2@I*/_;`$,!!P<'"@@*$PH*$R@:%AHH*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*/_"`!$(`'@`.`,!
M(@`"$0$#$0'_Q``;``$!``,!`0$`````````````!@($!0,!!__$`!@!`0$!
M`0$```````````````4#``(!_]H`#`,!``(0`Q````']4&VE#VD1266./MYN
MD`V;(,E\F-L8RDL-K3W./>D!&+$-%\:-L8VDO+>T=WCWIOH5BP#)<_)4DS26
M&[I[G.ZSX$8L`R9*3-/+4EEMZOISNX^A&*\,F2\C81=);F/MX\Z@?`;%B&C)
MN&O(&DNYH]C@[4H!8L@T9.P1W.RCSKFE`;'_Q``C$```!@(!!0$!````````
M```#!`40,S0"(0$1$B(Q1``@_]H`"`$!``$%`F-0>S!_9[C>3GH,;1K:B%(Z
MA"!;%O@R.HPE;>5T"1U*$G;^P&1U.$C;^L&1U/+1&W]8$KJ,I&W]8,KJ,Y&Y
MG=!E=1L$K@^CX$SJ-@KHZ<T?`F=2G"T=4N.AH&9U.7T=5>/$*1U7V+HV?Q[R
M(>77^%GCJ7-Z,X>0`7';^!R[@__$`!T1``$$`P$!``````````````$``A`Q
M`Q$R,R'_V@`(`0,!`3\!3TWZ\"7VL7H)=:Q^@DVL?8DVF=B76F=B76J=N76C
M2PG;!M?_Q``=$0`!!`,!`0`````````````!``(#$"$Q,A$S_]H`"`$"`0$_
M`4Q//C2;;I3<&VZ4O!L:4G!L:4GS-MTI.3;4<@VVIF@/PO_$`",0``(!!`$$
M`P$````````````!`@,0('%R$5%A@1(Q08+_V@`(`0$`!C\"M,1!=H"P8B>A
M8>Q%;%;M7WBMVK[Q5J_+'X_BM7Y"PFO"M7V+"7%6K[%@^-JWHCA_`B7F)'"/
M$6RE+NFB.%/0ME&?:1'>%%^6+9+I]].I&7O"#7Y-"%HE!_<7T(L__\0`)1``
M`@`#"`,!`0````````````$1(7$0(#%A@:&Q\$%1P='Q_]H`"`$!``$_(;'A
M2@8',?TG3@6$]W&AG-$]4:D5'T#M>435"?*AP<3N=3(F6I/V8(D2CN=K(GUG
M71&%1BMWOPFUG51#RZBM:Y$B+=BN[)'(N-E(W-G"'?@CD\7.LS&W$E,]AMW@
M5NUC0U$I]IANF0K>RHVJ%IGZ;_Y<6&<_(XD)/YA+7N8_VR$R)<\:>J8\+FDR
M!M9B#<"'I,D+"X>T0Q'J,B<9DC:DP[SS_!2R#/_:``P#`0`"``,````0\M,\
M\UTR\!Z\\8Q#\H$R\L\R\DZ_\BA__\0`'A$``@("`@,```````````````$0
M$2`A,6%!<9'_V@`(`0,!`3\0'MT*0FTJ4)@3C5G8XW#?<N-1K[\#E=V5""Z/
M`7&!/<'_Q``>$0$``00"`P`````````````!`!`1(3%AH2!1<?_:``@!`@$!
M/Q":7EO/406[6Z?@&_S@4QC-^(4SC1X8-3II-4TM`"CMJ(R(_\0`)A`!``(!
M`P,$`P$!`````````0`1(1`Q05%A@7&1L<&AT>$@\/_:``@!`0`!/Q#3*G?\
MC4;E.A":[M_I')Y4STP=-<6=E^;C37X3*MCO(OW#=/`^R8:TCV?%RI7(0[YT
MSP/W'8[P2]:D!^EA6^A/;0@&WMJJ)YA@5Q#E';'0P,5J0W-["V(.2!JNP@U)
MC-<RT0^&.^C-QX(*9>?I<,:J=E7_`'O%Y744+G*!B#>MZ.%H8O%C/]0_49,J
M!Q>M@PW3V4^Y1G6+[T&5Z)]3##NI[QMK4[NMO:/4594N6X[(?DF'<@-:V$X6
MB#:8+/>T?#-AVQ_%?X"?P%F*JKBJPI)QA?9+F])[M3FM1LYR=LX1*KJ'(+AW
M6@^)0IVH^&YF_3+KA0*[*+E+(8,Y2\%CW$JIE0TWM?T249E?*-Y__]D`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92]T;W`N:G!G
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#$V-0`Q,#4Q-30S,3`V
M-P`P,C(R-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_]C_X``02D9)1@`!`0$!+`$L``#_VP!#``8$!08%!`8&!08'!P8(
M"A`*"@D)"A0.#PP0%Q08&!<4%A8:'24?&ALC'!86("P@(R8G*2HI&1\M,"TH
M,"4H*2C_VP!#`0<'!PH("A,*"A,H&A8:*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"C_P@`1"`!U`0<#`2(``A$!
M`Q$!_\0`&P`!``(#`0$```````````````0%`@,&`0?_Q``9`0$!`0$!`0``
M`````````````@$#!`7_V@`,`P$``A`#$````?J@``````#'22$38;WGH```
M````````84.Y?5G/5^Y;::?14VFB)OW#/6R1NJ\6]#TGSOV:^J/FO7S5V,T`
M`````!!UTU3I@Z(5QA)G:ZG9Y0:\V\CZ9>5'SDPR9OYN$SKZW1;;-5LLZAMS
MW'S?*+^G(4V+`````0=\#9C<Q9T?2,YGBHTTNKZ/'2-9Z67ECA@9X:S&C/7K
MF:3O.=9-V\_?USKYFRO)'T+AMD=.^8Y18```T$+9HY^XHK'#+IRRC[XQ4]S\
MMZF.O4>4HN?*?TML*O`L]==@642/S1[UE%>5SR]PRW-."RF[^]^=_1.?0,T`
M!46_-[,KBNHY3KSFL=.S)\T:2#SW:P<VDMZFNF^K\YJ07GM'B7T&FE&$R9:;
M/FWS*IS]Q]9E[BRH/T?YYU\=.A$6``XOL.$N-];)T7S0YTSETH(O7Y>7T\[*
MN,YVFC]$UR$;N6.&V]J;R\N\\*3R[Q*CRW%/E:Z.O&%CE']OEW6T'R.GT(<^
M@`$;ACISQU&Q9;3X?V'I-Y9&SZ-WWTW/`/##$QB,W$9L6M/K_+G03OR^G#GU
M`__$`"L0``$$`0,!"`$%``````````$``@,$$@41$R`0%"$B(S`S0!4D,3(T
M4/_:``@!`0`!!0+_`#R0$98PN\0H2,/VB0!->AB3M3DD)[_(G0(LIA845PUR
MFP3A=XU"NH=:"AN0S?4)#18OM8B+-E/DIUR;]F1<,\J%%J%2(+NL2-.(HT0@
M+D"-S)-@AF4=^U4=4U"&P/H33MC#WRVGRS5Z2D=8N.BK,8@`$7`)T[&HW(@N
M^QH6XBA*TH'=$!REIM<A8FA'=PYM#4W1J*5LK/=L3XIL9F-V_NH*P;V2/#!-
M>\65-0LIF@N*&A5PCHM=/T*)2:18C6=NL:]T/37!R(#@^!]>1O'>;5L259*M
MAMAGMSR8ID61U*X9WP0B-JFE$3:\$VI25:,%5O240'*[IK7J&9['Q/$C58@.
M3'"[#7E=6E@E;-'[,CL&L9DM8M<3*T0C:B<6EIN7HFMBCW6ZR62W6Z)6Z)6K
M5P^.C+OV;J8&"69K9HM.L\,H\1[#_4FL2B"&(.EF[+#L6:,\,NYKD7(LUDLE
MDB]9+)3R`0T?B[/W%(\4UAN#]+GY(NN5V$=9:W-N]HQ;V6&<D#RYKZUT3,Y%
MR%<BY5RKD6:S6:MV'6I*S1EVV0<)MIH=-FXK'7=<H#X%W-=Z+E<Y!IRCN[%L
MH>,UFLENMU+<BB3GSVQ!$`V)@C;T4O@=Y)JK^2#JN.]4OXZ54;1*20,4;\QS
MLQ8_(6*C)E+%,Q<<.[1.M[H65XK]848PY11L"97<\M:&#IK^6Y;&S]'?E!U6
M7;OU!V.G-\&*QMLSE=!@<:X=CL5L4ZNUZ=IS7+\6OQA3=,3:0:A$6K%ZXW+!
MRQ/1_&>\%H;_`#=+SLR8^;5#Z::TN+8@L1]`@%.B!1&QG/I7AN-&=M9Z;'PO
M^74O["C;LSZ=@>$WC#/XPZ:=K/;_`/_$`"01``(`!`8#`0$````````````!
M`A`1,0,2%"`A400P03)`_]H`"`$#`0$_`?Y6Z&8S&8S&8417TN+XALN*$RF4
MREA/L3IO;'Q)+:T-4$Q.FZOV2$RI4J5E%)<HA==D3X'::=)TDXNIPW(;[([#
M,/!BCM87AOZS1KLTB[-(NS2KLTJ[-'#V/PUV1^(TJP\B5'R*^S$'=&'Q#ZO)
M_;/L_P#_Q``D$0`"`0$)`0`#`````````````1$"`P00%"`A,4%1,!(R0/_:
M``@!`@$!/P'^5*3\2"""!TD?%4]L2.!LDDG"!TZTA*<&]2&AJ=4;Q\5@QK12
MMQ<XM8S@EBRK11R(M;>BSYY'?ETC//PSC\,X_#./PSC\,[5X*^OM%%\3<5;$
MRI0^-%`NRTWJ^5T_1:/_Q``Y$``!`@,$"`0#!@<````````!``(#$2$2,4%1
M!!`@(C)A<9$3(S!20(&A%#-38K'A-$)#4'*2T?_:``@!`0`&/P+^WU*J]O=?
M>-[JCV]_BJT5\U*!#)Z!;Q$,?F*\[3&CHM[2GE?Q$3NMS3".J\C2F.^<EOM+
MAW4HS)%;CQT/PDW4"W5:<?#9[G+&/$4H+!#;R4XD5RWC-7*Y7+<<1T7EQ21S
M4M-T8._,V]3T*-)WL<K$<&7-7V7?`YE29WR7XT=3B.(;D%4*@52%57CNL.ZO
M'=4*H9JH4V&R5X>EM\:%]0O&T)]IN6(5B+4*TPS'K2;?FB7&3!>5X&A"3<7*
M;JE455*&+15!X;>=%YVD?ZA5?%/S4IQ.ZW(L0=:J<&,'?1>>PRS_`'4L<BJ*
M3@O%T4R.6:):+$<<3-4VWXCU++>(J;N$+[/H]&"\C622J;D$8KRV[V+C?MR(
MF$70-UV6!5B)1XQ*GCCJ$6";,1MQ1=*S&;Q-00<WTIJTZ\H0()WW7\ESU$IL
M!IW1Q']4UD,2:+AZ7BM&^WZA-.>Z=8TB#>.(9A-BP^%U5)W#BJ>C+`)SS<`G
M1HMY.MO^0_51+5Y$M=_H/)R4\WB7UV':.[@?O-ZJ:LF\>@2NJ9`;U*EK<U>,
MRC@=[D5SQ'I"!`J,2FM95C,<SB=@/9QL-H)L1MSA-"=UQ]!K?FB<E%B8`R&S
MXL(5Q&:G`):_V8J48$'-3:0>FU5UHY!?A0<258@@V3>[%W[*6S$A'^FZG0ZF
M'EMGDGOY(9G4*$DW`*XB6!3B)FR944Y$=5,4=FO,:(K>=_=4+X1YA>7I#'_-
M<#3\E]RWLMYS&=@O.THNY-JO)@S/N?\`\0,4SRY*FU+"(S]$"B,CMDYE2]U$
M-3;37$3O;>$\`F<]TNODH@>PAMH<"=1TI[MK)7%7%59]%<>RI/LOYE<>RX2J
M,*X2KBKBKCL0'?FEWU.&8VCTU:.SGJHJU5P^`J%NT4BI^T@HIO/:?T04`<M0
M^$!3^B:<VA,Z['__Q``I$`$``@$#`P,%`0$!`0`````!`!$A,4%187&!$)&Q
M(#"AP='P0%#A_]H`"`$!``$_(?\`S]$#NS1GX03^::O.P@CHC_TWI@ZP!N_I
M'#GN1C;+H_B)EZ(5FJ9T0_<5T#PE[-=%S+\*9H9P_<PCT=O)B%F0]!_Y'"`;
ML-3-V75[$L.JVO8CP:VMZ7VA%[:4_D56E[#7Q-;8ZYF`?0^)0N6>I)G`FRLE
M:I\%0X]?-,)4#A9!!1-EP^?^%T+T>.\RW0UV0Q1\H,MB6C404R,`Q$T&=-YJ
M1\X^9@/=,ZM?]XC%'@,.M#N?N"+`=&X=1/B/WAT1J"]CVF+HQY4;\TB0*.*=
M3M"PT^]57ZN$U8V3>(VI8(UFZ;E7*P`*%$6+,:VX.["RB8`L/`99GA?=_$S*
ME2]S]K*2\[#]1AA';_(P;7LBWK6S;FTIN/TBXGV#X=X>KTU'4E0"2Z4]=G0D
M83S^3J0;E"Z1T8!Q#P?<;(ZG!,L5D5CQ5=;SI!P!<+85`K5W['6)%J\[>QRP
ME2]047'HI%+C!#D2:B8@W^?/$O<MH^!Z=920@P'9@[,L"98?$IAP.MR=(\#@
M?<B!8=N'[1NM=CEB[A(]#!D;(+4RU83&ET8.7:-IL:.#5_ND'(6@)KUB8BX\
M9G&FL':-GT$>,6U!0K\E##[6>(ZPIM`DVQ\Q$AL*/#Q&LFV!^X@%6.1^RJR[
M7]E51A0%';.QL1X(<1D716P!X5E]X7WB#?T$LK-^8GF!M'KCUS21'-/;[(6E
MX)<P@Z,L=J6[;B*!QS,WWI]OL<Y5CO,!77#^QVF5\9*`>9<ME4:ICO!&D`/\
M4ZPJC1(-S7TKF_H>J.=W&^K++K&MJ^9<&CBF$P*/\`Q1VBP]%$8"]2;0&(UU
M2?!]BFCNA6*PCO-^`$9MZ71#H32G,'ABD894X=N2.1EBFDK#>JY9@E6775@Y
M:KT.6%('=6(*`-51Y?U*`&!R@X./R8(H7TFKZZE<XG42_D'[GN6;HK1[GUV\
M.$LIT;%8\BRX"%#0,K`5MJD*1ER0"Z7;TYG8&HTS%F\"8T!OA['[BEN_P]S^
M0)B-A*_G,/C7^)M`\X[3]6CWCN9WM^.(CIF[?X?MBYZ:'3L#!*(/,M6$'T(K
M=P/*OX64!+7Y/?Z\Y:DH>0]S#0Z>EU$-UHZXAL`(+7<_,#`!2RN`TQDAK+;H
M&_=G6X7X]B8Z6.TUCOFTTX_**-![*<HO#`&V6N;ZY(!1O$?_`)LW?Q0#^4HU
M+QZ#"*<"7V"2L7AG^*8^JP\)E@.6=X73L30.DH`\\0>I7M*]/:E<8A*E>@2I
M52L>FTJ5?H33![DRF3\1&"DC".H/A&7'G)*3U'U*N\COOSL@_P!1U@5-_4TG
M'IM#ZV;QC-IM`YUU,'U_$=]K\*8CQ^?H_]H`#`,!``(``P```!#SSSSSSS3S
M3SSSSSSSSSSS3*B31`#CSSSSSSSQ#!S!!!"RQS3SSSSRPSPBS`VDA0BS3SSS
MRQ2Q#`1"0R!3@#SSS;@0ASSSCP3B1!SSSS0@"PA#"`@0P@1SSSP"+_P$`"`!
MV+R`#SS_Q``;$0`"`04````````````````!$0`0(3!08/_:``@!`P$!/Q#D
M@`````````(:@``!4`0#`F`@`BQB%2%7_\0`&Q$``00#````````````````
M`0`1(4`@,&#_V@`(`0(!`3\0N``>````````/=`"@F);,8$""&9-1.]A_\0`
M(Q```0(%!0`#`````````````0`1$"`A0%`P,4%187&1H?_:``@!`0`!/Q#(
MT0B1"EV%(`#T%)8XA&!`@0"````"01`H`&(!T0%"@J('&@*5`("!0D!``4!`
M$$$!0`$4`@*#8H``L8``P(C>;$@H`$)`$!`*0H"$`$`%````H10``"@``4`Y
M``_"(6"AH@B`!$!$@`````1````D`(0`B`H@``!```@!``(`!``A(!01````
M2H:@`SV%L("`"$`H`(``"``!0D``%```1(4A```````@*(4'VAW-C3"$`WF0
MH(P``"$`4Q``32`````$`,`$```*)`%(8#T820#D0F`)```!"$(``````!2`
M!```#,@`A803]`L```!`"``8%`B`("``````!1`!8P``(F`R(```JL5T0!``
M``````(0````H0``````0%```A"`````!$`A468`>[D`P(`````````2``!`
M`%$()``$`*(`!`(!(`@``0`!10`%```&`(#BL#`00P0`H``$@``DD``!(``!
M(B%(*0```0)1!`@Q0H@`"@$!N'#J$("8`(`@!```!`%```@``"%0(6$&"*&_
M,H"`%'R1"`R9`3)H,F@"9`D#.BCZ4+AL4#[N(H8[A(/_V0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+V)O='1O;2YJ<&<`````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#,V,C8T`#$P-3$U-#,Q,#8W`#`R,C<W,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_V/_@
M`!!*1DE&``$!`0$L`2P``/_;`$,`!@0%!@4$!@8%!@<'!@@*$`H*"0D*%`X/
M#!`7%!@8%Q06%AH=)1\:&R,<%A8@+"`C)B<I*BD9'RTP+2@P)2@I*/_;`$,!
M!P<'"@@*$PH*$R@:%AHH*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*/_"`!$(`3D!!P,!(@`"$0$#$0'_Q``;```"
M`@,!````````````````!00&`0(#!__$`!D!`0$!`0$!```````````````!
M`@,$!?_:``P#`0`"$`,0```!]4`(OEGKGE6L6:NNC>5;FL;^7M9<H^OD]3C9
M.9KC*8IUE'E'0D*=ZILCG51F5KA5I#?1/&[<][,H>_0\=:8*',EZ`QU```#S
M+TWSRYYV;S_T/>:G!N]6N5^.FMQICI@0=<YF^&.G#(Z[XJ+WY2!OMS[ZQC.<
MV$G>Y9Z86M:_-UVSU&Z26T#'0```*/>*5<^?>E>;O=XO1Q@-1D-AA7*W#"*Q
MPQ)A6=,]^+6,:$;D;HSUSCHN'*+E-^G%*L&=YKLZO:Q#]`\Y]/SI\!G8```4
MF[5"YHJMTMWBQ*I?I<U3.<>OU99T"P(D7:]%B<^_1./!ANF.NFK5G6=(9IV5
MPTFKK]WFJS7I$>XU]:\F]BSJ8!G8```56U5M/.&JMSUY5#U&M5N:]?A5J9,I
M(-LWJIM5;AN/TD="/OWW-.G3>6DSYE@:KM_10\=;93>%5UYN["=!T7^T^.>S
MXUD":```"N6.OIYJX3.NO-JH;:35/<LD[$PC35KMUJK&5UF;LU"[3.Q'4/?-
M$8L8^MSM#TDYZ*+%T-8YKF*\X^Q>-^R8T`30```('Z!/,G:1YUYL]<J9IE@C
MQVB0&E<JU<,HLME:7EXA5/K"[J_Z+`E;K*9ZQLR2<(7=N5S)<D3V;QCV?&@"
M:```!`_0)YB^0V#ISG5^P*FNMH\]9Q;J5HX.$JLSZWZ625+48MSYB+N@96<;
M6C4188?3G)B)">ZNJYBN2)[-XU[+C0!-````A?(D\OL->L/3G-QG1J.NE;I#
MCV'*JU=EU$4Z+T327QXQ!L6DBVLS'.PIT90QACCV!:Q7I$]D\=]BQH`F@```
M2.TJ>66*N67ISEJ6M;:N$VEV.%/!S"7L*IUG;$5A'$Z+!AA:PK332T2JMR$)
MIT659(7L5R1O8O'O8<:`)H```$KI.GE%EK-FZ<YD:6-5"=8$Z;S%G(B36Z9;
M7'JKO,E2%.@M8)[3JHID/JC10,1:WR+JN8KDX^O^1>NXT`30```*FJQ/(;+6
MK'TYLHDE4U,X-+-+2Y4JLH\TWY5'@NHHO[2>YN:=#7GSF1!+!`5$QAXLE+F2
MU,>M^3^L8T`30```+F,)/&K%7+!TYMZQ9LM*NBWBEEY1^645BLVU7#=%TBQ(
M==Q*U1.*WEU9]DV@*EFIE_RD+JL9*TD>J^8>GXT`30```1Y&AX@Z3LNG*P[\
M]6N_./TE6[[L[,J6P5";88Z*XCV25]\959"?\")/Z0Y.F(<RWFI:IT=^CT*^
MXT`30````'C.9R?ISMZICQ7#VH6G)W0)["N?6KM:[;.9.;7.-JX"K-<:ZF+$
M@CRVA;(6R(7E?L&G!*W1LWRWH'_/H`*````!YW2_4/*-XNC%!8*7I;=M+685
MJRRH@6N);MVK'62S:UWE$.SQ6>K4'#*(B@LFJZ<^O!(B)KPCU>6&.@``````
M1_"O?/,[FMVZ@6#>;=F/(FL8SJ!J6!C!M@BDC*J$6(UR:Z[\C6+T7HOM5*]D
MS6`&=@``````0IH>"'JGDVN=B>5!K5CPHZ4RUA[$HBA+5RMUD].?&61PAXN9
M'';DG%'WF2O;]C;'0`````````#%9LXGAC'UJIW*B7'ZV=3.`,X,FN#;IPP2
MM(_`PAM5B*3Z9VSG8`H```````````&,@8R`````&,@`!C(````````!_\0`
M,1```00!`@0$!04``P$``````P`!`@0%$1(0$Q0@(2(Q-`85,#)"(R0S04,E
M-4!@_]H`"`$!``$%`N%@;$#D?`M1]U:W'EW`$Y;L_A_X92:+')N>,.57NOY<
M&/<;NRC>;%ONK9`'-"S[HQE*":U-EU:ZM=8NL76LNM76KK5UJZU=8NL76+K%
MU;I[!'3N\GH!YICJZZPK?N.[+-XX6>L75T')GVSLSZCGSZFM8*9Z]UYE#=F1
MJ]@A$.])Q3M2YT==.P0I%F,<0BL.K;ZRPC?K]V6C^IBB;#,G;5K55Z[]EJN0
M[M5=C5JY0J5%Y0Z5]P`%&Q*$I!L@(1!AL%Q`"1I5P1!";H\E/S&P3:MW91OW
M47Y=BJ7>+A8HK\M'[=KK:M.W1U3I2,A#B*,G1Y^%B?A!_-@&TI]V9\MJ[':3
M%6%&2G;U(2E;*OD?FGC3C7)L,N21T8D03B(DHRZ2*ETK)@L[D/RE">]M#IJV
M0(I8NVS"J7:Z'E+%9-8@499ZJU-?UAHZ4.[X@;S6?.&O/9)SF/*Q4MXBQ7R<
M;<9G(R8\W49NZNVND!7!T[%G(DA;6)/SIHZ*+L4=&R6F:9YQ1;DUU))*)9*]
MD-L0UKF-'*?D-+67Y8QM*/=\0_Q@=MW(<=S`F;K209VR.%UD.Z6O*L2N=#`R
M\+>9-)R3VK:MJVK:K@N=4I3ZNB8.CD)`,1=5D'QN*#1C=TY<'VA''51^^HVV
MKW9]OV_AJ:#V*;;AOCLA&P'=JK(!6(V,(-YO#*TFQ3/R'$[19EHM%HAC9U*&
MU5+1JJY.1.JM&@*=>8I0*5H-D;.JK,Y[!5#[Q^$.[.^U_*M+:]\&]H2D`M>Z
M^V5ARO$8X2++4>(?4.V6K16U:)HK1V3Q=H867ZIA,9=2.+1E`!+-K1F>=LD8
ML,156;6QWYSVOY`3*S4C-VYE>87@=/,@WYNJKRZ;(;5L6U-%1BHP66,P*^.?
MD57MJ$"$:Q:%60ZQ;3PA$<9(JH^[[\W[3\J_&<&FQ:3ZCMD$S0"=7JLMN+N,
M2.U:,RDT8O&*,2((6"/?M#K$*IFJ55-[EU`J"!QDBJG[OOS7L_RK\=6X/XHE
M8)%&%D2>N:!J>2>"&>!(#D.+VLG`*M637%CZMH(I57(AC$)G?5:MQ=%57W/?
MFO9_F#A)R6;/R<*)B"C4CV*LA%@6*U=%`,B>C%G>G.2'2#!1;:O%UZ(EIM\:
M%XZEAF9CBLT$.3$@_H55O<]^9]G^=9.JQ.GOR*-LESM&(XYPN4Y595S1.)_!
M2MQW1C>FI0R$$]R0T,L"Q31G=)0Z,,+%N?-YTB3OD;IZ$7C3=%57W/?F?9_G
M6]'5VMSV`1N86;S33+MKRT%BG_<%_<7#-&K6!:=ZLKP]TC"(^0&U*Q8F[5L<
M<8<=5.\K^[53E$,&:5Z:=%53W7?F/9?G6].%@`SLPK0%UFQ%LGLM3K=*.]N!
M:+OM+4G(V$VBC-I7IO<,\([6&6HH6J\6YUB:C3UGP=&]*?N^_+^R_P!*_HI2
M:+2N!90LBFHR=.[OP=M6>@T9,V0BMV0=2K6#H`1@APU=2)&*>X%D,L"-P-Z4
M?>=^7]E_I7^U`C&Y>YX1V#T:AV/CC5U7M,27T"3:$8@L'8=:D-ISJ[<G4B!5
MB<T*,J'O>_+^R_TK?:I2>I?<$2RG9>"A<=Y7ZT;0:!^<(Q8B@,5NRT<1*;2P
M[LBU;H%6ML5W?1@2A&#%YH9Q@I"BLL?:"L+D@1EC_?=^6]C_`*5_M5@,+`Y<
MVG+7G#''2+$V#Q6LBN\9Y6_/G@H7>96G>=B#L[FS>D2VM94X%YM6IO'#S*Q>
MC!ZM63$X&],;[_ORGL?]*WV\/Z)CPRER;T%.G:L(0H!'D*\Y2&0-F(Q2:+59
M*<AUFC&>1.I4B#)_R*>F0J``5>/!T;TQ?O\`OR?L7_DK_:C&B-;;LFF8P4(X
MR\?[-7"9?+QLN@9T.A6@[\92:+-.4WE&U%#M-S$Z-Z8K_L._(^R?^2K]JQY&
M^8&B,UW>SJ[C0F3&+5*WBGAYG\%(XF74A33:2E'=PE-WFU3DS>WHIVIO',Q8
ME6E-R571_3#^.0[[_LY_RUO17HO7LU3QWP(\V#/<\@L>IB2O*%@KQ=Z,8/4!
M4("=*M)K&*$H')7L&GL$&#PJXT[$#.44[15\SV20@PX.C^F$\<CWW/&J7^2I
MZ+1I,:B0+BM04/,K%AJ\,.*31YO)S60,YB5I3C0<TMU<\MF<GN>P-R5:I^H`
MS/")K@`MS+5Y5:PZHTZ/Z8!M<AWG\0&_DJ)N)!C*TL75=QXZK"2NU&LQ8I:Z
MA<JNGN5&4LA&2JTIN56*0+$FQ0$*E6"GXR5CT^'&_==[MX6O`M1U'T*1AQ@.
MR5=/;TZEQ2B[2;A_4@CDFK@9-X<73SUDU6S)$#8BJ]AB\)(Z^&H^;Z&4CLMU
M'4/2[+:>^0\WP[SZ>Q$18V@DQLQ$B6"G8@SM(TD\CQ36X,[.SLMW,>M8J#F6
M&X@Q<N5SRY525A?#D=*WT,_';=K.A/X7J[V`4K3LAV&T/8_5D7G`PLG1'D>T
M40ZHJI'YMJQ`,2P$<9M<;;N$V53:MAP\_KY$5JS$,*,)6+#J:L>N%CMQ_P!#
MXF'^H!_&N_@RMTX64[V*KPNU)-:OCTQE5ZP3E>GE26&.*N2(HS.TXN=Y/EB]
M38,)B`KV7JRZRFS3R6]Q4)DG_3HKJ?B2K#EU_H?$`M]&+Z2IS4?3A,(2(8QB
MX60#L#C5NU5UMB"^8%=3^9VFI41U.$X1FS5*S)O*W"2-)8T?/R'T3#8HK$'$
M>L31P3U;OU6O#5F6K/VNINK$U\,@^G\35-I8.JIM$.>K?0))W6QW4;`^J;73
M@[J3HLD[.4M(#5JWTK((6`6Z\ZM@;H!M$,NJW+5:]FJOU26:]2NXP-1"QR2\
M=5*2=U.6B.1?#U'ZN9Q[70Z/"8G4-R:4F7,7,6Y;EN6Y1+M36G4[#R6]>+IH
M.I^5'*L10>Z:,6BWU-%E<5"XQ1%JD#89E"T-TQ:SK2JZY5=UR`+IPKIPKIPK
MD`9<NLRUJQ4K((HMV",?<L=B269#%`4/KF",T3X`,GG@#,A8&>WY`OD,E\AD
MOD,U\A(OD)%\A*OD)5\A,OD5E#P"JXNM66G_`,7_`/_$`"41``(!`P0!!`,`
M```````````!`A`1(`,2%#$P!"$B41-`0O_:``@!`P$!/P$D=HT?4O3^#%ZJ
M#.1`_/IG(@<B!R(')T_LY&F3]9&WQ$V_=B[PD(:O7V+(=BRK%7&1[PET*C1M
M+,VFTLS:)49'!]"%18L58X/H5-34VD'+^L8J+?R)Q@E]%Z1P?0J2BG[NB=6R
MY*4I5C@^A>2.#Z%2];87HR.#Z%XV1P?0J*MJJK(X,5+5W&[%D<&+R1Q5+E\K
MUCBL;%LEUG?.]5BQ4M2Y?%9->-+-HN7PO2XO"XFTL6+&TVFW]?\`_\0`(Q$`
M`0,#`P4!`````````````0`1(`,0,`(4,00A(D!1$__:``@!`@$!/P%:;5^E
M_3R"/25`MM46WJ+;U%M]:VU3XMK4^+:U%3Z/43Y(`:>P1AIL(=[=[DM8\0T\
MW!3V>SIX&`YL<+V,!S<"10N8#G$US`<XGN8"3S,!E,!E,!E,!=\1]$^B8BS7
M=/(Q'$6D9`XS,'"3A=.G3ITZ=/Z__\0`0!```0,!`P@'!@0&`04``````0`"
M`Q$2(3$$$"`B,D%181,C,#-2<7(D0F*!D:$4-(*B!4!3DL'PT41@8[&R_]H`
M"`$!``8_`LSFN%1F:J[I!57X%5&'\E5RK]$QF\"_,''W1V-6[3;PJK5-%?0K
M9^ZV/NMC[K8^ZV/NMC[K8^ZV/NMC[KN_NMC[K8^ZV/NMC[K9'U6X*KC56G;#
M,[?2=-_)R(S&1O=NVN1TG1M+&4PM;TZ.Z@95"KHL<-Z<V2@&Y3&@U6U"J714
MI6@Q4A-`X7A6&V&W8O0KCHAK1>4&-W??,%)R8!IS#FJ9J%6F7Q?_`#HTZJSN
M.\(OM76+"`ZFG'>FBHK:^RGI9H\4"LGHJ4I7>HPTMM@4*LV8Z74=O36UK0:%
M&B]4%YWNT)W<].0<0,PSE^3T!.+=Q1;@\8M/;!Q-&<>*LL%!H.<B>+M-AY*J
MLG-T63MZ27AP76Y0UO)JM=/K<5J3AWFKV-=Y%=T4&2U:X[E:<1D\?%V)^2UC
M/+YFBOBF9^M5R>>_PR+VACF$*K(9W#T+5R27YA:L?1A:S_W+J9G-Y$JG\0BU
M?&W!6HW5&<!,YG3B/)!V:/)H#1[]_A'%=/!)TC#M'_E7$ME\*Q6.:WBXW-"_
M$Y5UF5OO`/N*KR24"\5"-J\YNBGO:4,DF=6,]T_-BL5>C!$.DE==1=+*.J.T
M`=E5SP^6G">:,;]EUR$<EP&/DG/DQE1!O"Z3([G>%='E;#=OHJM>,SB[NLGW
M<47'2/C;>$Q_OX.5ZK(X`*QDC"V/?(5:VYM[RC:4D7]-VKZ2K9^6:(?"-./U
M+!.L]\T4'D@<"$*G7&(S4F8'*N2SV7<"O$P?-3N=M.=>JF[EHWW*]2PQ1.DM
M&H`59+&3,^)6LHE=/)SP0Z$MLC<-V=YKU=-;_A<LS?+39ZLU0NDC'F."JTT\
ME>K(-D;RK0Q3AQ"D;S"QJ-&X53G/-ZREPWN3;;B`%01U:-Z+XSM;EK%4CV=[
MD(V"@&9HY]@WU:%J.YW#BK@?)=4ZR_@J/&8@[+M,H5VG:RN7A:-Y5F/6D5N?
M59P5E@H,\?J'8?JT:/%5:A=>K&4QVV\0NHD%KPG%8:[4(Y-K-K7(#><U7+_P
MLO<57!O-8]-)P:OZ,2J!;=Q.C'ZAV'ZM'%7+6%5P*ZN4D<'7J1[MYK<@R4_5
M;+J<A55UW'#9*I<T\\?HG!@=0\=Z-DM;4[Q5>TSODY;EU<8"OTH_4.P_5H?A
MX#9IMNX("3*)"\\U7)\H/D53*H[O$%5AJ,^LP?)5CE>Q:^4RD+9J?B6J`/(9
M[$+3*_@U5D>V!OW6ME4E5:M]+%OJ@X8'.SU#L/U:$[3[QJH'5%HUJJDK7I9Y
MKI\CV=[.*#VYK,372.^%:N36?45?`T^17M$#V<U5AJ,SFL=8@;MR*SDUDD8\
M4X@X6M51U=[_`/A/M8*('&F=GJ'8'ST`Z.Z5N'/DJ2,`E&XB]-NM4Q:=Z8WH
M@0'5LVKD0[><!N64,;LXJ+)JV6F]QY+V9[(6,'A4;YM5]*E#6%#S1::$\$R:
M"YCCK-4CF^&J8TTI2]3&UTFJ!;`I\E@*E6G4:T*TX%N3#]VA'ZAV!\]&D@O&
M#MZZLMG;P=<5UV1RCR5C),E<VN+BJ5M/=M%1Y2W9V3R3'-EH&WTI5%KG5=3$
MJE1O'U1-UGBF9/%?Q*L^[2B+71F7)]Q:M6*;R#%U&36/BD5O*G],_AN&C'ZA
MV#O,:%ZVE<X*XJ\YJ&\<%:R:5T)X8A7&"1=WD[?FO:<JNX1A686T!Q.\YKEB
MKW+;"U'`Z$?J'8.\QH/;+W4>[B5T;(F=&V@-&[RM:%GR"M9(\N;X'(L?J2#%
MI[&I0=W49W^\?DJNC?([X]Z'4-IOU1<OQ&3:CFX@)K_$,\7J'8/^6@ZMS9+P
M5:8]P)?:-Z`;>2KQJFE+^54V5ETU*ARUMMMQ5IQ5IH;#'Q?O5796X^E:N4RA
M58YLPX8%%KA8D&+2JH95E%"7&D3#_P"TTF1KKZU9@A>?]-5M'_356?>=<`HX
M]X%^>+U#L'Z%B3Y'@J3WQ[I`AT9!0!&"X,:%.\;)43)=AHM4YH-C<W:K?@KF
M-90TU<$WF2VB?7<ZBBF9<]/LXV%DQBLET6YV"=7%[K1INS='%ULO!JZ?*C:F
M]UNYNA#ZAV$FC0WA6HBZ%WPX+J\IC=ZE[5E#;'!J$<8HU-GAO>S$<59D(J/=
M>J,%PX(VAO59'M"#J$9,S?QS%^1R6*XL=@O^G'->TY27#@Q4A8&\]^C#ZNPE
MT.).Y5;DUW,KK\GD:..*U':'6Q@GBNKDG9Y.6ME&4'YJMBV>+S5<L]ZZMCGG
MD%7\.?J%T<C3')P=H0^KL)?+0G>_%NJ.28T"_;>:YK4?5R>)J$65[]E_'-6J
MO6VU;;5<5CF$<0M2'<JSTD?B!N4;6V0UW#<C0@.%WS5H[;<"HW'$C/%Y]A+Z
M=#IV]V^YW(HO&+MZDLAWO5^JP=9!=O3XY6GE5.C=>67)K(Q:D?LA,&5$RRO]
MT&@0D;"UHYKNF?15A)B=R7X?*OTNXISC@%%-9<ZV:RV<:)Y]RT0RO!8!.NK4
MU-4,E@O<<>2:QN#13/'V$OIT"'BK3N5K)-9G],[E9?6)W!RU'M->!1MO:7;@
M$^9UUO!`N\-RB)CZ6$`ZH-+TZ.3:OH.2LBT`3_A$R;1N4--JJ>SWBVB$#GEK
MFW%M:(`4:T<UK25/`*D+>BA\15([R=IQWZ`\CV$@^'2I*QKQS5P>WR*K9+S\
M1S"ALR-P*LY5"[U-7>EOF%WU?DJ9+$][N*Z?+-O<S-:>VCO$%?),0JMB!/%U
M^DX\&]@44,UIR;>R&ULVL2K43XI?(JSE,9B/$X*Z\:&M%&?TKN8_[5=0>0T+
M+`7.Y+!K/,HV'1R4W!$4LO&(.A,[D.QD'Q9\G#MFTF".0$N.HT"]-)D!93"F
M!5B2R:[BNDAJZ#>W@FN9@<U,3P"U<G>K\G>J/JP_$%=F<2;,3<2-_DA#"6UI
MC7%%Q>^AW!RVMU,,?-0EN+KCH2.XN[%_._/1G>-O:J/N>VXUW*Y'I(Y+9[LC
M<J2"A+;PIH]S3<F9,PTK>X\E&R`!I>ZS:WJ>(N+A&10E7\MRO`<T\0FAIKD[
M]WA3W#@FMA:UVK?7%6G1Q!M@5H/]OS%SJ!'*Y+FBYE=^A'SO[%C^(T+=;$WB
M"]HB+V>-BOF+>1:NCR6LCRB9.\?>>2$IV7BE59=Y@C<C0EQ<:N<=ZH<,<T4$
M5[JIT9WBBZ'*ZL(P=Q53E-?(*SD4+WGB4)<O=:X1A4W<,]%&S@WL;7@.C<M>
M&,GTKJHV,\AF+)14+V:1LS/"[%==_#B?):G\-=\U2RS)XU6MN4^_FI(T.'-5
M_#Q_14:`T<KM&)O.I[)S#@X43F'%IIVN*Q["2<^D=F,I;@ZYWGVE!F_#U/2*
M_2#&[1P3(AN%_9OB?LN3HGXC[]G9@=9-:J-LCK3AB5T]@=)Q5VE^)E'H'^>U
MJSOF[//DBUP(<-V:[L<%CI6W]PW'F@!<!VUIFI-QXJQ,PM.:]7K:5TB[Y=\%
MWX7?!=Z%>\+$*Y79@^>K(ON4&1BRT8`?R%F5@<.:K%(Z/EBM6=GSN763@'X0
MOS)_M7YD_P!J_,_M7YG]J_,_M7YG]J_,C^U?F&_1?F&_1=['1=;/_:%5K+3N
M+O\`LS__Q``J$``"`@$#`P0"`P$!`0```````1$A,4%181!Q@9&AL?`PT2#!
MX?%`4/_:``@!`0`!/R'HC,Q8$@9X";"1\E]DG5+XA#D)[C3K/2>LD_Q?69D#
M'>*'.J[GDL"9%>TN_P#**(I\D(M4,9\O\"U+AK`\3;#894[B$^JOL$H0W"(,
M#M_?8Y]/QZ9B$=PA.08'I*[C'/L(E@;DK;5<ZO8;)F&1)N$Y^J_GYP7N2*Q!
MRG=*+U.PU-K_`*-&>NEQX0U[XO,$8N8-V_:1&%-MV&P6O^V(U<#.?M%HJX-&
M-Z;.1I,5G1I<=5M9&YM;GA;F$.S>[HPKDF9_./67U1>G19"6(E-1'`R*;W:6
M?\%-2G*=IK'2.C:SLPL(]&W<F,D]25MT^0T$=FVGEB-KI%]A93<9%\Q0E*-&
M)X-BC)2#';O8]^D$%UF7"6[)6R^9D:9G8\:1S`J7\^_,-J<6+=R^CO*S1.V+
M1OJ+833?G[1N-#B"*Z,CP2:,3:/W)D1&YVZ9%<W26]"!(V_T$/?R<LA1A)D3
M'9>#ZL4OYW'#5?)[3(+"13A%E<S1UW/0LY'.)"LCGRDLNS!NG"T#Y$T8IED7
M,Z*TBY%WAE)3ERFP69]E[EE:Y*TQJ&AJF$RG?$81W-1MM3R(ZLQ*0V3NV[RV
M%!1^Q(,Z)CUIWD/W_P`_G!O&7H_]%H>'PQZ;P(0*2W]5_1/_`.<\"+I2MF,[
M<96QD\DRWJRSSRW2;P/V]#$A:7&XZF9O<IQ@?A1!F-$ZH8W_`.,):W1IFD3U
MAC(XPRRD(ENRC[D*:+AJ?!22)-(GDBW?ZO\`FOE5[#;6FVST9F`FVX2W[(:B
MDWT6B$8)BM-3*)1T5Q>.Q*/P>1>!,DDB-IIB=SK<-J7^CW9;<B""X"786T@O
M+ZD_8+S(OF2\FQ*IU&[5HQ]\D(7*ACL(BD33IHO"KGH?H?+'H98\9*]OYR-^
MZZ*QDN'+?0CJ0U+(@FF#(9_?5>1HU'C?JAB?,;H*WB4MRM<L-E_KH]HBRYAK
M8H;-+0PX,1T8_.DU^F?8YKLC"&T%2&2Q*-)V]"4A4NM1L6%)"XB0MD_FGT[,
M:#D,L2R@\7N)PF6'@T-HY]T*<=O<+X^0],W8B6<IWL0P<K5YZ""Z6).9,$G.
M$1HAJ;M)"E=V1;0)"78*QM;P,UT#GN!QAO'<D\U+_@+P>[>Y1,YJ0C^:SVOP
MQG%%4187HQ-X&6R+IY<34H7I"<EX]2#70NDX>E>=P;QK?S@Q)!>:<)K80NG>
M*<L2FSN>7[%5."#`Q$S_`&?X,/9\,9T+HRB!H]4>PA3*Z^M1%V[V7H&4:?06
MZ'4)(J;U$>"8)NMXE'1G'>BW']2VR!J]C!N:B@K^.B;-'^8[\BZ37I@8E/J7
M^#XGPS)T&@_`^()IY$%H30T38W$B2WI)?V*?2<!_IDC`\_ADN<_+@^J&C'PV
MA$Y:9/+>%C6`$3E^@IK(TQ#--SCT(1%S#&Y!S9)Z8F+&^QK^#XGPQB\#I#HE
M!+3*\:4PD3-HQG'CSH05^`QBBB)K811WB02A7![HY_L>3+F218[&(EEME)+U
MLVR2+'=BZ6-%8O"[QBE?39(M+1*Z6+/M-_P7\']C^0E(P@=28%Y0IZD7N\51
M"@+=L>5*V:0,3IRTD-93*V&A+@G,90A#.$^`22D%G'84HC'X#%FOI]OLA&WY
MLLB,6L>PA*H3;6K;B,Y4LK=A<=S`Q/K-_P`'LO\`8_F)7H:Q+QB\AK7#I";M
M5>6!,SRFQ76.2G:F>DFTD&`N'`]KI[V#HV);21MO22$IFU@12U(;E[!S6L8P
M14G!IM,@ZBQ)ZMB"*KH`@U:7K#W)Z^,%-@=:G^N1WA(P,3[C?\'M9_?IMSDR
M)VS"D\E(?EXVO"2@3PC%"VQ-2D66*2_(N0UR')/(?9#JF35=2&^=C<E8PRKG
M00Q.IP-QPTSU#2Y0FIM\$V]WX%*?T6KQ&>R4)+01CT/NM_Q8+TL#>$B@B^59
M3=N_T-9_!D1D;"6(3<M<C`*#UE71I.2'U"^Y(]9H9?<8E"%.J!Z_N%,Q+EP,
MK7Y&!]A8S3H?3;_@7^&)Y+UY@]PNI92&',U@?L362LOHQ03Z8P14,IE$*2.C
MM2/K+Z299,0,0ZN]G'R.0;!O(OR(\LG`?@0GJP9@S[+?\'NOET6Z65X.3L(*
M<DNHE1<R%.RD=IF^3)35`_EJW9]Q]:Z$8(20OO/#[[$>.+*#(9S!-IG4#.@0
MI[4DI$#2C:7(4TV'$.25*H&7RWR@2U;J&9)\QUW#,67^M?X/B_)_;KM*:RG+
M$(IXD*\[#9Z$=/,$D,HG/*4#+4]1Q`J.LCR6=7C4,1V$=3DEI0J2889(V$(I
M\\9<,R(8'CAM:DCE.20U7[A%L+7YBL>"):W6MD56RE<7*%_1L=L9F$^EK^#X
MOR/YD.GL99"9E/`V;UM\!8RK8,URULD8$]WN)EPMD+RIUU.1*V,@RD>Y9X'5
M%;F)MDQJ9+V#[<"7.9'+@NHE/86^W.%ZE@1G4\C->C,6[7\'L%\HIYCRI)"J
MVH26V*@6Q*9=["*'L+)0^-?0^YZ-[K/27(9[=9!K4NU.EM!JBDJI*J$MB([$
M@=5J=Y<_L%T&+8F>"A'349A?PS/GZD>;[=`_<L6V%A>105IL>)F@A;AHT10F
ML,GO93@9)+0(;1Y0G/6[F*7V*\,J:,)0QTO%33E\"E/BS<%K788Z.%=$DU[$
MZ@5>MZR5PR)T-1<LP,@GX%61?)UTY3T`%<%).6B&1WAGA[CIU$B6C$%BAEEC
M)+>W;@GNJ-WDL<\HN2T9#B73?P.R<;UZ"Y"V\.#H2)&^^#T2X&C3>J;XD**%
MI\$5&BTS4L_L-H@[N?(=.07L)^'^!8/(R]QJ"Q8U**0VPQG?=+R=FXNTV3BB
MQX;LHR/+"FI<B3;(EKR*-ZU_<9PDDAR+NH7Y:;"(U'H1%V46`^*%+8Z"P_V`
MW79%LCZBE!%0N^C1YUKC%YTN'1S,3'9GM^!.8;X,_<G")"/)VP(OUR.7:91:
M@O(AZ0DHQ&AQFC&\BESB>.U:*K?BF',]:D364+VNX[._&L-GHM2CU)%#/>MD
M/CJR$^^?G\$R]Q8VSZZ9Z$AC28G]@3W1TVFH+0YG6ED>1;;2#&MR7338R^<H
M8;WQ7"I[1Y$0]#9"H052T]IF*V=9.L=O:CG+I@/3/`#[Z?AXR;Y+46"\LV6\
M$JZ$&E6Y-G+L7J21ML\ILL,TLL2G&,@=O'!+,D?$%U%XL]&]!*;9P.K'*6AD
M-L$][*TB/L[BTR1"<2GL23M@5&DSW#=LAKTQ&R/:;7HO]_#XT]A>B9!@J8G[
MO8>1-B!+X#\(+A%<PV(+4-9D0WPT!;4G-L2QZ<$)6G?]A$44S+M8$C4VF6&R
M?`@KFOQ)S(=H86&TH)[ER.BV(&1X$DV,I1B-Q4+E)]PP&H:8#WN?N_#%HH_3
M_I"9U.%#9(T5:W<BR9RDL:[H;>#8E(S9T&S8D-IOZ$N6K6I%AB=G)%M!,%M&
MJ5:9#EZ+0\1OHQR>_)QUD$I!QPX/&<=,386<#R81$DE),+IH&B&CD2_#7<R>
M'70*$AYZ)>H>3O9H-I:;QOU%;LV`J]5V&?`/ZPLQ-YD2)_<+*LLRX%$6K-EC
ML=SBRR#^$G,A5QH*-1]AB),GBUZ!61^',^1DWK(@K@7.)3TTZ,R.Q,E39)ZL
MBY8U+3U$Y$!KHY&016S0,#K_`*_C8LXX-/\`1&R8DV+M$YZ2>1LDD6)'&BLF
MH3$8-!BIB8,#+HZ$+HPIB-9;";D!M4EJ]?Q0+3E,?Z(;OKANB%JQJ*6(3(E9
M%XH<B5R221(X]TA/B2.IHW&49BCI=@D(A8U)34;I@C\<$9DI9;`VQ!#;<D@4
M$EH6]$-Q*^F(T&-31#P*IT&=I,U(Z2S:="8EITMNV$$P(26B_+A`_1)\>X;T
MAZ/LR!DQU&DT+3EY-L^1,T+R;7J=`W/4'^P"R%Y-Y&@2%0:W<5WEPQ493C0?
M^!KVG09I5L@AC97!AOL3(AM]O]GV/[.?]]SZ?]'!^NX]KZOV/_8?L_ZT_P"C
M'+'=2_T/;GP_VL?>L9_^,TGD@C^,=(Z00-2O_F?_V@`,`P$``@`#````$/.F
M=KQ;CSGR0_&'?//*E/MNN#\.&BPF.///*C!-`XV,1Y^NE9///,>%G#)4.94)
M,H,///.H2)O=,##,.]\/////J(&'(7,.8;W:%///*M"%_420>N-\.////+M)
M/C/,+,)']%/////@)&:%$!1'*'`%///.B"!6*$PV$"%-////%H",2=(T^+$,
M&%///`(!#=N&`&#N&,-///%2#-+A$'$%D9`%///+*/*@&.07#+U((?///(.%
MU'-IJ&$R.!////`.)+8)]]#;%.-////$S(`6&/(#=((_////&(V'005`/??E
M//////"0A--'>LH]_////////'/+'+#+//////_$`"`1``,``@,!`0`#````
M```````!$1`A(#`Q87%`0;'_V@`(`0,!`3\0%&D&A*CT/\/J?8^I]SZGRGV$
M8W90=M\1-8/XK7S+"JLTZ`)?A>1^\5B5Z52#,3G#311<0HQ3(-/D&+!*IS;&
MEK,3$)%XBWC_`$.O!\@A!HD;17@A,%R(21B272$>(BLK(+1'A](*L018JZP(
MB8C-XA%U`9$Q1'DYS/'`WBBL;-\SQU)S/S*C\XJ*L5%9\<TY$(^BDRJQ&1XJ
MRIXXZO"+*R\0A1!<?[A<J7IGL@*/<*4J)+@C8M<Y2I199916"2_C?__$`!\1
M``("`@,!`0$````````````1`1`@,"$Q84!1D?_:``@!`@$!/Q`E4$W*3IHC
M^G@>1Y'B>T]9XC9Q@@(B40=,.Q,DH%%<C+D7ZIR0]".=0!Q1Q9,S/0JEA.SC
M-Q&A%8L&,,+2&(8QTZ+2'2$*1"T'8=*!TPZ8LW;!8H6;M:D=,<4Q3F[8*D*E
MK&'2%3'K*E(II:S%BAZPIR%H2HQT@HI"J2V"QEI%@I^00&_F_\0`*A`!``(!
M`P,#!`,!`0$``````0`1(3%!46%Q@9&AP2"QT?`0,.'Q0%#_V@`(`0$``3\0
M_A)+V_)D?6=$FXZ,WBQWT(/C?9/"&KU4<&`&3UFMFNUY_@HKK_"\7+0:ED;?
MPN7A.(M3>IA+BE6^^)7R3G?L3*HR;G,LLL'41?NE9\QHA@+"T+]'ZD+'<2=D
M(]&I737)#4+ZNRO;CQ'<U!3+S?%<187R8]'$IG6TO[SXA'Q'5:Q^]I_QWXB:
MBNF/X@M'?[XC1JCO(%&!W_1-W'];3]'^(-_7XA2VK?WM%?Q/Q!_A/Q"V_?Q&
ME]\'XAE?MVZSA:%M)JOJ?1LPN2TNLL`;M$(,%PZW1?U5BI6`9]"?Q4O<LT(*
M*&;OS&+M%;YJ\MX0$$<E.CI*-)3J7UE/+ZQ*V/24FS$8OS=@$I(MU6UO.EL>
MP:H$;U:!Z2FR[9NWB*=86;<XU<<5`O&H0"^72!C/:0;IWN6P`OL4'%=X)(0I
MIMX>(%-T>DSU]92Z(>\%=JB7PKGAN+@.=]H#F+"SR,&TK24#O%@Z`=U%^WUH
MTFSV1^(HHLU":]660\-I19T2Q&S.2,$QMP'??M#&/?:4B##`:[ZHVK<[QU40
M7506](S>66M7B",E<%JTTUVB>8A.PK.(V$5<(;^48`JTUK>M0<2((8`X.T%\
M(HU$#F4AI0RZ&\YS$..4;'OTC;"+N%H'0XTB9B!I,5C-<U-P"7"[H"_CZ[G[
M;W`/S*PE/;'ZE%,L=)0)92UF$ZPLL)]-R;O:'O0B"R]QV=I<C.J41U!\;RFU
M5;US!FRI:]>BW)+"TG%)45=2NHD^8@W0-KAO6+U'HOXTF3=?*VQ,-IC2I2@W
MW-(P!OG2@$TI<4?8=6X7,,H97R;O6!9B^>)0M1*U<416/DP4K&WO0?7DJE':
MQ'`#3Y6:PV86UP[]!FUC84L$#F2QMK*\"TWXJ-8*@4*AMEC*<V*)0NL4L2!5
MOA"N9=RAT2GVB$J45;IJ)B3N$GHEOO+E;J63RS?I+4N%L]CCVFYQJ/`9E@`+
MB<C68BOG<#!D5='WJ>T,GT!#?M*DXKI/QQTTE\TQJ[J(+HF%:/66"."8`==(
M4C5SU,%+9[&SX?6FV>9!/93?E5_#OYBA8M5S9S&3Y'9O!!K"A.HMCK-NYP4]
M.947BX;=(>%ARPBE<``L4M>WQ&.LV(0T2WZ10K=2ZZ$LR/0H76H]G0X6Z34+
M32L5'^+A?=@;5N^BN;$2Z`IO5@W`C22="(W8FK<(RTT$\IN](=4)J,T=@-XX
MUZ.WD:COF4=B'O,@NM[Q:+5>L?GZ\(V]</Q!T!$M$^Q*Y.QO0@YR9EJS04UO
M2/MM4428HB;(ZP&/+T%<+CO<6VEL%U_"Y4[&B[_?VA(4>S[W"2O^@$'R\1:U
M0Z=I9M#Q84-_P!:P@\.)7%F&Z*UBT%4#S9]ON1$=&S')SBI["K?`Q&?M%H.5
MV.Q%$"PM+]_W;8?;U1J.H\^9G/6N[MNR,4&2]$U.>T61RW<VC?KAKQCYOQ%%
M%+PN(&9`M!4KG"Q@%`681-"5$61U.O4C5^C$HSO*[8R0\^B7T).)I70$WR5'
M..[\*^[":IP'</E%=H7A>)9H0'?8)P@V4%+R01RJ"6+L::T/2#90T?/F`S&*
MWN_=\L,!"J0'%0P39UED[82D:G1$-EMZ<XYCK9"AH'$9YG!-F:'M7UE=P?>`
M<8EX._3CM!L[#U<(`:%JK@7^8>2O7('<VE&=4]1T@/'%&5'I'*EW.M]-)<?.
M?-/O!!6ES#NQ34G0G1ED!THH#+Z]0/8_[+(A%J\C[)"T!M6E\PO9C<$TBERK
MCK%6.P&9<$+>X<.T6:RK8C+_`&0,\QW9>*S-OZM0(`7M[?7<^&A39",'4#6U
M/'$0ES:SQUM`@@Z`\;QB0<W8>E;1@X'#>$[P<Q:V,?JJB]*5CXT\,+&K-;-X
MK:HD5BD<@CR3%`:3H[$U&H/2B@/0E38+ZP8FB%>WYB!AV;7H;18%(M;U0?9V
M`:]X<>FDU.LM/0P<?6"[B`X-\DUI<W+9ZZ]8V'_S!_,,%U;%T^-_,LPT3]IU
METI&MF[J?:%D9V*>/UM\QDI!F@:IX9?5:^SV8UE"MFM)9H:!PU_[$NJI[1J0
M0Y::;G)*'AZ`6RW,H'?!T@%5G\QZJT*;Y10LBT9P/WI$[+&'3J=_>-H5;"N/
M^>)B90<ND:Z])./KS'2!=H;0UE-G2.C*$U+@6J+O\04HIW,>\K@DW;">2,KD
M-V^1B8Z(`UY?E'&X4-5O0_9`^@2H?4]ZAAP*\JY2_,3::Q8G$0@\V`>RS/-2
MX5H2D=BKI$`=[U\7'J,K&&I';P$4'&:Q3S&1QU3M]HRC1XR0#I7DJ)4/\8QQ
M"1Q_0!@JW:CHHRS:4<Z+NCM7,#!_<MR@:E0\LTT9<B;1H.L113"KIZFI$-$[
M"HO8WDR>FD5>77VU\W/5ZC[5!ZHU4O\`=0=9]Z7D*'R,*DF^0]".<SWKVTE7
M$`4P:?$NWG*P+T"%V'C0-_VI>;;6:6PT[>$19]'N(8$,2X@X^O-O;[`BTP%T
M'6);/JSJZ-\0>P_9HLX':H42TT!KIJPT1<J`9S=TW3684X,1O<)48#![CAZP
M[08LS=G-[1Q9MK]/5T/6!V2U&AXG2?=K]H4-'*/=A9JR*]DV99J<OI`^/IU7
MN[6[#E;RC:[R]X=/24-X"+TS&E*-ED-2D:]8!7BHZ=)=@NQ(9!Z1W6:W6"SY
M*./K.;AOX!EN-8ET%]H4X/L"Y=9@Z='*2BEU.I!J3`@\DEV`0%G@3#&CYF*W
M95IVC4@H%`!N9C""C2[1PSD89;0-'<J8@Q@=3)VAMIY0,!.]LUHFSVM\3K"`
MGJ<,8IR[Q9,L:M+J+YN-%8CI:T`OO&K04I2*!/-1`Y%-"*5@,/I"%G0-@V"2
M*8`4'!L'V@US6Z06)O)Q]8MG;W;_`#',L&*YB<D<,`<]8MAS+\/X-DISTHK/
MX]XP"S+A#C)5\1V"2I;;"T'I%>":19L=(>2`Y0W=(`IZ*2\QOYBRM0@6Z5[3
M3U+BZ"B8UQ+$C@3+9>)I%'-'EX.L27ZS@JI?CT(]L)RYA/MBU+/08.P3;<2^
M!N]9H"@H10.`X@YQ*8D%)Y@LS]!^9Q]9OI)''E<)+G,JP33>'LPEVB6AZVCU
MJ*WRZ,7ZH(+AW>7QB$`(;*IZ0PK`N^\._-%!W2\EK:^B7?O*&K-P?O*U,<B[
MWQ$0MUU'EB#A9;V>?@*.D'!MITE#:]C5]^8S4*V,I55R5/>5SDM5^=O$*/&%
ML"*\@U'E#ETF77+V?B<?6'8^Y4<P4+3B9MT+B35-%!MFM3M47!WH5C$UMJ](
M*!=D+LTBH[U>B.,F8*?',53!2.3I&V[*4`'QF)K57(V2[T(G`7%,D>\U:3%5
MKVBY@"SKYV[0F;JVN'E<L/TS7)5&BZ/"'%N*&"9?P7*.MZ$V%S0'9AL_C"SY
MDX^O/I)%^ZIL%FI8Q7&GQG7OCY64BSE-[--7$:R``%V+/8@\(%2V0`D.L%Q=
M(PQ:44AS!^&NWCH;]I4%IKB='#[I``RMNGI5P=X0AAS>(/:,TV!UNO:<!RBG
M;F+W8)Z$)@&@-=/^^($CY@)P"UOS%,A8F3-4;<^T)T%JH%-@TP7Q4S3G5DM"
MMXCVT#JU\?PPD*>S)Q]8OH+](6JQAA-JS*Q*33%N=8QO&U->DS&\OX=R]$V8
M#J8!UHW-;2]DP%U055QWA58UXD(HXHI=+SI-)8T06,U$H_\`=]5*M:ANH`55
M@R\&95=8S.D!D:(#E6>8,^(`SDN%E-K,HJW7?.\T$X)J=JL$;&&%K5B;G[Y1
MZUI"`N1.K>\#(K?/\I<1)Q]9OH"]GYB@D+=91C&LH!IE;5B;%NK7<9>&EW&`
M]:#8'W(.&+K^U0!&89^7/(>8Q0%-IRZ=<S*6Y**5HZP1191*RVT#+*!ZTJZT
MSC2+-!45'I$E?+6O=T=^\Z!585BJJI8^F:]QFIF)S7<]HN=6>=+?B)*LH,]Q
M9])T>DRX2A?2.%N1;Z-SCZQ?1:#T(>!I5[3!]4:QP!]X(8ACIG9>(P[I_/43
MY?5&_)9)A*X+S&=V^\!&@._L0:SY@T>MD7V`:4!+]G&@L^(2%71:/L>T4%J0
M,!NH(CT.ERRI;M>,?:-`S4JH[\1_6M$-^6/>>:4+[Q=I45#V=Y;K5.M<0X_A
M+*.#Z3CZQ8]+Z(_$QJQ6IQ-KRRH%%AI1:USUC-1=TZ55T*Z;,&LR6N1H8T<Q
M=#71XN:P8=H!BK03IKLQ"\<@P/P,(,"-TS$PYM"H@<$GNPL$GF/^>\`&@163
M,JC@)VNH-['5*EZV(%4T<M"E7*2RY*35%@QG#37TBF<":FJTJT'M'N)Z0OHS
M1B"\S7Y8@A0W9/H+\3CZ^HQ,:+I#Q#>;:%0<2M2XRL].LL:6S@Z'R^8L^X+N
M@RPT:.D;.JC)Z6O>5V-[[F6P6[OBHV^3CEY/6.LK;K?V!O"OFT;A;:GM<OT$
M(J5KEU[RFL*H:V:U@KKRD:NI;LTA%IV^BA)D6P<T1U#OQK4:TW/M#?\`T0,#
M-S6#TB23J`!16?0Z1#.5`Y;W7&)A%8+U*NTHN,7@?,P+LE8=T'Z0V^HGA;\%
MS!H9)H[RS7V2JY)[#AFIMQUT%L@=,KIK;WY=I>)2L@OEFLRB84!<Y=H[@5"J
MG1$IZL6C.SJS418^"BVM1(5`,[D#>)`Q;S3U^^>\.IPM75;OE%.D:P<P:^DQ
MOO*\BXP3=`/%\/2HQ]0H!UUUB)+:/9\RQ'00E.AO"G1-;*\N)GO"JJCJ#[![
MX/NS;ZJCT&A]8-0)$MQ@S20VT>\;&Z'G2-VHU]7_`*1LN^"/49K)X?$!<X@P
M`H'!$"_JF#>STFCD9BIPU#B4W857XB-T&E-"ND0%X!X%%#1^=X5;U!=OLEK7
MJMWXJ/F;OE;;VB'N!^".`_IBO7'M%!;"591Z;>)C%R@7%#_KY1^8?7=NA3U*
MENW:CX:C@'>+DL5BIWOB/MBJR$+6FG:.ZLES`76&W10Y.S2!.W!I+2@JR0/-
M?("194VKD>A$!,FZ/NN4?I<5\E,KJTJ]?^RRU*"U(UE*U]&`$33).*&O>/Z=
M*/'&EX;V:G(B,GGJ?Q6,5&:F"SY7X0_HTANG?&1[0+UTBI>9N6=]$;IZ,#Y>
MP,T'0CJVH+.:N7+%1U`H;'`[Q#=VVNI.D,L2U%1:E&JRSJM+UX-(;8+HN0YS
M4`\LD9#K0<^LN+@[%[Q)4:982"^&>OM4W8VAC`UJC=O1*AM03F!JX%4(LX&1
M7EU8(O+7@BK8X[14NDK!#:T1V!^Z_IO=!8GN?FY05S3V)3@BCH%=E[P0@%$9
M*MN=YGSJMNZW>-XML$-0K!A%WN$[R^WHN)FHIG0[$PFJVUK7#WN4F!V*O7+1
M::C;4$P+;S7F<%"B+COI$>CK`GKF4@9/"#Q'7IP^=(E?A06.HZVA8U0PEVJK
M$"DVK?3V@,P45+`8XP925XS"DJ766@W:FZIN=Z'L3;^BMC47J_P(A!MS$-<P
MR+:KO?,/6\=Z#O`VE3']"51MM$3%<1W;D;556`59CL,/*7N9T(&`/5`1B]\Z
M(7%GS*;%U:`70:2M2(/0$<=IL!OL)4*K(SZ'^R]N=6OGO+*Y&L;<=B-W.EPI
MT$_V,'_]&WO*T!F+#U;1`?\`I*#@Z15*E6TUDM:KK=$`HR,X:S_2[C8W^C=/
M2-P9J"V+@U:LHNZS`[M!VV])S`_)=Z)T"+OD'AF$I4TN7`QL,+RN8I`KBA3N
M_,HP3JQOV9<7_=U^Q%!8JB_4MCT:6HI]GFXF8VC3GE<<SH5VB]6="4P>A43=
MK57^Z^9<U]T,%X@*LE"D?V+B4Z_T@=:"^IKW-8*]<0$?Q&I2`X9E2X%%D:`9
MMB6N'I%BS$Q:C7F&UFM5<?4N*:J5J?"PLKJ>9CJ=N$!!5X9S:2L5#L)GF/8O
MO`R7,2$S'<Q49-S+]P_JUUFRCDJ@H7U>G6*:5B6P5UA)1;Q*VF(MHT8EQ"[K
MB*53"&C`$X3>+46&[@V\Q6X!G)K#H]MSJ#FH0!;RPUB=3#+-)27B:PB`*FZI
MT)<$J`JW5_52`:M5FCL.I17:(;L"T-KH1U6)<@]X?"U\0JX,5E.8NI(LZT@7
M>57#+-'$&%=ZLO0A=+],-)AK6/II=;ZQK$8E`M26-*-H@)>T2E:B]9OND3)6
MN7.TKS_64T76X8!2P'(G[,I#JBDX?[*0(4I)6E3+H\,I7`/,+Z8`H5@<5YQ/
M%YFP^\T?+LO-/;2"J6PO"[(-J-KO%"F1#>!VC!5)+E+EA;TED%:TX_/7CK#S
M@&4!H']J'(U5=XF8E%<'`-?%1<A87(>@S<FN=X-3/$'H37N5LF5O5[F+M%W$
M-KRL!^*CULA]03%Q\E`,(3I*PJ.@NKEY\4*NT.AUE9]04?Z_7^^J-6-2)617
M9U)T;*^VT?>73]MFL#-ZU-7=2;7TDA?F1_T4=8^<.V'G"8SF?>!V?W.L_8/F
M8U^RXBY-O7Y9\0K3]%"\4'M*8UQIT_\`%H@>\I$KFW%5M*_BB5"F\)7]('64
ME(:#OYE'_P`O_]D`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T<R\`````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-P`P,C`W
M-S4`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE
M<G1S+W=A<FYI;F<N<&YG````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#$V
M`#$P-3$U-#,Q,#8W`#`R,S$T-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`$`P``
M`.W=XE(````P4$Q411$1$7=W=R8:`#P\/*:`&O_,,T`S#0````T-#7-9#?*_
M)C,F`"\O+____________Q'.T*4````0=%).4____________________P#@
M(UT9`````6)+1T0/&+H`V0````EP2%ES````2````$@`1LEK/@```%M)1$%4
M&%<MQK$)`S$`0U$M*12RATAC<)51,HM+C^/FX*>X>]43<"8@8(TGS9VKV2`X
M]@3!2@<(F@;$U30;<9QZ(I9?7P]$G3KHJM\_9^O8J3VU[@S5MNWH\_@#Y$-2
MT"TJF8<`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T<R]M97-S86=E
M+G!N9P`````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`P,0`Q,#4Q-30S,3`V
M-P`P,C,Q,30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````P%!,
M5$4````,$QH4&R,5&R,<(RLC.$TR1EPO2V<P2V<S3VPT3VPU4G`Y5G1$6&P]
M6GA`6WA*6FU"7GQ&8H!*9H1+9H-.:HA5;8=3;XU4;XQ7<Y%;=Y5E=HE?>))@
M>)%?>YEC?YUG?YIH@Z%LAZ5NAZ%WAI9]BIB!EJV`F+.'FZZ6J+V8JKV9K,"<
MK+VBLL.EM,:FM<BPO<[_________________________________________
M__________________^F=RM[````0'123E/_________________________
M__________________________________________________________\`
MPGNQ1`````%B2T=$/SYC,'4````)<$A9<P```$@```!(`$;):SX```".241!
M5!C3=8]7#L(P$$2'$II-Z(2$$GH)=4Z0^]^*W8TH0F(^++VW8WF-_"<H3LM'
M8)N=3_LV7J)Z/ZQ7Z2*95`J!AS"9Q-%0*<=4YV0<C08UJ,BLK]SOF+@)DQ3N
MA2:N.B>5O8F+]DGEEHG=1NZ3PBZ`/7M<"I/>-5`L5I[/M._JI??JW7'HFP'^
M?^X[3X8-)<-`E=/[`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T<R]S
M=6-C97-S+G!N9P``````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3<U-``Q,#4Q
M-30S,3`V-P`P,C,Q-3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M```#`%!,5$4$`@0\4B0<*A1,>BP,&@0T/B1L>EQ,6CPL*BP,#@1TDEP4%A1<
M>D1\FFP$"@0\9APL*B0\/CQ49DQ<>CPT,C0<(A2$FG0D,A04(@Q,7D0,#@R$
MGFP,"@Q,;C1$2CP$!@0\5B0D+A14?BP4'@P\1C1\BFQ,5D0L+BQ\EF0<&AQD
MADR$FFP,"@1$:B0L+B1$0D1<:E1<?CPT-C0<(AP,$@P``-<!`/0``'<`7FT`
M@&D5"O<`>'>H2][D`.<2`!(``````_D!`)L``/0``'?(F.#E`$D2FOL``'?P
M``Z([-GY_?1W?W>(&N(<`MCT`/1W`'?_.-#_YV?_$A7_```W`("0`&CT`!5W
M``#$E``>Y@#E$@!W````J@``FP`5]```=P``LP``FP``]```=P`XN`#'Z0`6
M$@`````$)-@!`.<%`A(!``#<@!CB:``2%1H```!^7MX`@.<`"A+`>````B<`
M``````````#_)`#_``#_`@#_``#_`&S_\%O__>7_?W<`=&@`YL``$A8`````
M1F@``,```!8`````,&@`Y\``$A8```!K\```B,``^18`=P!8^0`#FP``]```
M=P`&X`?V20#D^P!W=P`/(P`>HP#E]`!W=P``*P`!HP``]```=P!XY`!DY@`!
M$@``````R```*``5Y0``=P`4``#E```2`````````&P``%L``.4``'?@>#;X
M9``2%0````#P`/^(`?_Y`/]W`/^(!#8<*0#TY0!W=P#_!%3_Y_+_$A+_```W
M9`"0+P#TY@!W=P#@``P8`.CE`!)W````:/X`P%@5%DL`````;^P`$.<`Y1(`
M=P!X_UMD_V(5_TX`_P``""`!Z.@`$A(```!DF&\O$!#FY>5W=W<`;+X`;^@`
M3A(```"J*,B'EO\*3O]X`'^X`(@&`>@6`!(```#<!&CFY\`2$A8```!>`&^`
M`1`*`.5X`'<`P&@`W,``3Q8```````$`,```````7```50``3@``4P``3P``
M4FX`5/T`148`1`!\Y!I"`````7123E,`0.;89@````%B2T=$_Z4'\L4````)
M<$A9<P```$@```!(`$;):SX```!X241!5"@5!<$)#L%```#`H>XV95E1)=:9
MBL;M_V\S`P```-ME"0#J87'($P!I7:QB3`#,%X=/4P(P?W=CLP4>.U[7:1T3
ML&S;L\OQ%QJ`ZK8>3.YU!*"_N6;C,`*@ND^R,@!`572^`0#L3R$'`+W9$P`0
M<P!``O`'>`$'TG+0!TD`````245.1*Y"8((`````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L
M97)T<R]E<G)O<BYP;F<`````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4R
M,@`Q,#4Q-30S,3`V-P`P,C(V,S``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````8%!,5$5Q<7&```"W``#=``!J)AJF```W``#_S)E,,QI>&@UW
M,R9,``"`9DQ90"9S64"$``"_F7.=&@W9IG/FLH",9D"`63-J*BJ(&@WROXS,
MF6;,``!1*BIB*BK___________\<,>_Z````('123E/_________________
M________________________`%Q<&^T````!8DM'1!\%#1"]````"7!(67,`
M``!(````2`!&R6L^````7TE$0508TVV/P0K`(`Q#"X$V%[WMO/__RZ6MC"E+
M$<Q32F*WY$MYM_0`J`-O($\/LHFEE\TI8OG.%\#_P8BI86YN$"5]'!N88AN0
M<(!C1UPX0"6KI&QUTNZVY*NM?_H_&1<)`HUWHB,`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92\`````````
M````````````````````````````````````````````````````````````
M,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P
M-C<`,#(P-38U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VEM86=E+V%R<F]W+61O=VXN9VEF````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#(P-P`Q,#4Q-30S,3`V-P`P,C,S-#<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$``0`+,``.+BXLS,S+R\
MO*ZNKJ.CHWQ\?%=75T-#0P```/___P```````````````````````"'Y!`$'
M``D`+``````0`!````0T,,E)J[TXU\.[YQL0C"2!6`@AK&MAG-81L$,!HZI0
MO]FANC>,S*:1I'C%Q"&H03";R:@T`@`[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R
M871I;RYP;F<`````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-C4`,3`U
M,34T,S$P-C<`,#(R-#$S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```%U03%1%````?YBTA)RWA9VWB:"YBJ"ZBJ&ZCJ2\CJ2]CZ6]D*:^DZB_
MDZC`E*G`E:K!F*S"F:W#FJ[#GK'&G['&L<#1LL'1LL'2L\+2M,/3M\74M\75
MN\C7O,G7V>#G````D4G)`P````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$PDYSU?W.````%%)1$%4
M>-IC8$`'<E"`$)`5D9"4$4<2$&5D8F'G1A*08F;EX.%'$I!FX^05$))C@$,Q
M+CY!861#46U!DD!V"@:)2S7$%E1OH*F00U?!@*(7"@&[`0@F[URD"P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E+3$X,"YP
M;F<``````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3<P`#$P-3$U-#,Q,#8W`#`R
M,S`W-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!^4$Q410``
M`"<G)RHJ*C`P,#Q!1GJ'E(.1GXB1FXZBM(^DMI:CL)6MQ9>NQJBMLIJRR)VX
MTJNUOY^YT9^YTI^YTZ"ZTZ"[TZ&[TJ*[TZ*\U*.\U:2]U:K!V+''V\#.VL'2
MXL+2X\/3X\34Y,74Y,?6Y<C7Y<K9Y<S9YLS9Y\S:YP```)%:.G8````!=%).
M4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T
M24U%!]0,%!,*!E(<B<8```!S241!5'C:C8[=&D)0$$6G)"K:?I)4XJ#8[_^"
M'#Z.NFK=[?7-[!F1`8Z(@4W=Y/YF)120I0?K2]SCRW[9T@W'Y\TS-5L*2US-
MA!I$A6@6+$`&77+BDO%Z?QZ1/0FVT&2I.Y^ESN'9V9E.X/=UK-/TF?Q/#TYU
M"Y-\J!(]`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VEM86=E+W)O=&%T92TR-S`N<&YG````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#0S-@`Q,#4Q-30S,3`V-P`P,C,P-S<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````2%!,5$4````!`0%"0D)-34V(
MEJ.=N-*DO-2EO=6IP=>OQ=K!P\BSR-JTR-RVRMRWRMZZS=_(S-+'UN7(U^3-
MVN37X.G5X>S9X^T````)QS-D`````7123E,`0.;89@````%B2T=$`(@%'4@`
M```)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03"A76HL@8````3TE$
M051XVHV/-Q+`,`@$Y7#..>W_?VK-N!"X$MTNS`$A9!<40.)R."<IB>H:&UFQ
MS6UO!4>G&I/!:L?C`O8H3'^Y'[E(Y/DS^#M_'$W^DR]D.00M4QL`X`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]I;6%G92]F;&EP+G!N9P``````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`T,C<`,3`U,34T,S$P-C<`,#(R,C(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```#]03%1%,*:Z*BHJAY^UB*"VCJ.WCZB_DJF_EK#(
MG;C2GKC2H[S4P-+APM/CP]/CQ-3DQ];ER=?ER=CETM[JU.#K````E=-PQ0``
M``%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L2```+$@'2W7[\
M````!W1)344'U`P4$PD5_8^;VP```%%)1$%4>-J%CTL.@#`(1%L5G:KU._<_
MJZQLP32R('DO#(00&D7/.QU#:!FUB4>:@32^AN2&3GN5R1C,5B<^D7C=*V0Y
MRPPG>U:-6%;3\^>Y4@\PXP01T\R]P@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O
M;6ER<F]R+G!N9P``````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#$T`#$P
M-3$U-#,Q,#8W`#`R,C8P,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,````V4$Q410````8'"2HJ*G6*G7:+GWJ,FGJ/IGR2IHB@MH^HOY&HOIVX
MTKK&T\'2XL+2X\34Y,K9Y0```&]D$4<````!=%).4P!`YMAF`````6)+1T0`
MB`4=2`````EP2%ES```+$@``"Q(!TMU^_`````=T24U%!]0,%!,)+SN#0FD`
M``!/241!5'C:K8W;#H`@#$,GHC(J2O__9^4BTV?C2?;0DZP5^8BC"-V3>58!
M6C[``H8I&2GGA-MPA[%T$P"-40$_?H*VCGFRUJVNK'SMLM]/7#6R`^;5H<PA
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+V=R87ES8V%L92YP
M;F<````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$W,``Q,#4Q-30S,3`V-P`P
M,C,R-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$`
M`+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```
M%V^27\5&```#`%!,5$7>WM[=W=W<W-S;V]O1T='$Q,3#P\/`P,"]O;VYN;FR
MLK*PL+"KJZNJJJJIJ:FGIZ>CHZ.BHJ*?GY^>GIZ<G)R:FIJ9F9F8F)B6EI:5
ME963DY.0D)"/CX^,C(R+BXN*BHJ)B8F(B(B&AH9Y>7EX>'AS<W-R<G)Q<7%O
M;V]@8&!?7U]:6EI75U=65E924E)145%(2$A'1T<X.#@B(B(A(2$%!04$!`0#
M`P,```#___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#Y)V#)````.G123E/_____________________
M______________________________________________________\`-\#_
M"@````EP2%ES```+$P``"Q,!`)J<&````)Q)1$%4*,]=S^D.@C`0!."*J'A0
M10Y;J0IXH-8#3X;W?S$1E!+FSR9?-KL9DC5"RH$\=8!P^1(*(*:6S0(H\"9#
MRQ,UF-GYAE\!L&`NFT=_`/5>*U]$Y2.2P=2U\?V-YW$O44!/(^T.34,>[*[X
M0E]OZ8:9L@%?RP)LHVN,G$?(POB$XJA#J8-DNXD/"7YO\_NXR/,-53G5CS3K
M?P!B#RU+L1XI;@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O:6UA9V4O8W)O<"YP;F<`````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,C<P`#$P-3$U-#,Q,#8W`#`R,C(S,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(!````+7Z-^H````"8DM'1```JHTC,@````EP2%ES````2````$@`
M1LEK/@```%Q)1$%4*,]]T;D5P"`,!-&1NG,S%$,S%$,Q<@(^T*'TS]M$,LEN
M6*,CLV``K;G'P<OAPI<OT9K=PLE'X/D71/P)8GZ"C%<PK&$8.`;=#$)W##J,
M@D'6<L+DW]QW`SGO+\TU5-#"`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E
M+W)O=&%T92TY,"YP;F<`````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0V,P`Q
M,#4Q-30S,3`V-P`P,C,P,3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````5U!,5$4````H*"@J*BHQ,3&-G*J4H:V1I;B<M]&?M\Z=N-*?N=*?
MN=.BN].BO-2CO-6DO=6GOM2]P\BQQ]O!TN+"T^/#T^/$U.3'UN7(U^7)U^7*
MV.74X.L```#Z@2Z1`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9
M<P``"Q,```L3`0":G!@````'=$E-10?4#!03"A<XK*DT````54E$051XVHV.
M.1*`,`P#S8VX`@',Y?^_$T*#397MM..13!2!O&BQ;\<Y)4HP,'1E9H1KFUQT
M1^'[6DSQBE',#J-24RE?"^#G[T80,+^$;%M_^3$4RPUY&@7[ZR_,@@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R969R97-H+F=I
M9@``````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,S$`,3`U,34T,S$P-C<`
M,#(R-S`T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y81``$`#$``````!XE[%(9G\B,#O5U=6FNLMSDZ[5WN:/J+Z[
MR]@S2%J9F9GDY.2BM\E/;XK,S,R#H+A+:H22J\#___\`````````````````
M```````````````````````````````A^00!!P`3`"P`````$``0```%5N`D
MBL1HGB-0HB8!`(C*DL"1%`W`S`!D.`Z!CB=1``:`QVP""`"82M%BF(H\5RGJ
MA/$ZE6K/$7<Q>CP!CC#+?``HTC/N`>@PQIMU(Q;E<LJ6$RZ`7B@A`#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O87)R;W<M=7`N9VEF````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C$R`#$P-3$U-#,Q,#8W`#`R,S`R,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$0
M`!``LP``XN+BT]/3O+R\KJZNHZ.CGIZ>>WM[5U=72TM+````____````````
M````````````(?D$`0<`"@`L`````!``$```!#=0R4FKO3AKE?9,B">!8G(0
MW9880:B9AH!F\"`4\[7:@M#JAUBOEZ,D"(&D$N#Z()[0:$I$K40``#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VEM86=E+W)E9G)E<V@N<&YG````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#4S-``Q,#4Q-30S,3`V-P`P,C(W,S``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`8````?\_]A````!F)+1T0`_P#_`/^@O:>3```!$4E$051XVF-@
MP`ZT&"@$_\DQ1!VJ\7__BGW_B36$$<G)5Z_>>\;P[.TGAM?O/S/\^?N/(<[3
MG(&!@4&<@8'A%2X#6*#TU>8%.QCF;3W!<.?.'08&!@:&G]^_PM2P$N7G2:L/
M_#?VB/K/P,#P7\G`&N8%?:(#K6+Z1I@F!AR:4Z'B8LB"3##&Y<N7D<6U&1@8
M+J(9,!M*OT0WA`$J@.P"7.GB_]5[SW"J@QF2BB:NC^PU__PN%`.8D!2^@D;K
M;#3-%Z[>>\;`P,#PW]@C"F<ZP`:D&1@8GER]]XRA:N(2N."3FQ<8SNY8!M?+
M@L>`WPP,#`R+=YZ&:V1@8(!IUB8V>K70HO@_-,F3!+3PQ`Y)AF`%`"\`90%X
MO=1_`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E
M+P``````````````````````````````````````````````````````````
M````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S$P-C<`,#(P-#0R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O<F5V+6IO:6XN<&YG````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3`Q-``Q,#4Q-30S,3`V-P`P,C(V-S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!0````4"`,```"Z5^T_````"5!,5$4```#___\```!SQH-Q````
M`W123E/_``!$[O`S```!KTE$051X`0&D`5O^``$!`0$!`0$!`0$!``$!`0$!
M`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!
M``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!
M`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!
M`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!
M`0$!`0$!`0$!`0$!``$``0`!``$``0`!``$!`0$!`0$!``$!`0$!`0$!`0$!
M`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!
M``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!/4D!
M@IQ3N9,`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<RYP;F<`````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#,V-P`Q,#4Q-30S,3`V-P`P,C(Q,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````)4$Q419"0
MD````/___XD`3R$````#=%).4___`-?*#4$```!E241!5'C:8F!B9&*`8H``
M8F!B8@`")B:```(B1B";B8&1@0D@@(!L)A`;.PD00&"2$<9D@&@',QD9&<$8
M112F%B"`()KQ,Z&ZT!4P,A*O%@H``@R)2;8@`YH*N"`CT8+8:#*=!`!`E@+0
MYPH+]@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]T<F5E+V9O;&1E<F]P96XN<&YG````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$S-34`,3`U,34T,S$P-C<`,#(S,S`V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```8!03%1%_?/4_?;<^^BY<U@CHHI4QI5"Q+FC
MQ(P]]^W6QKRGNJ6*X,&'AV\]V*Q3\^_GZ-2A\M22^.&HJ9-ARL"MF'Q2G())
MX-.OV]/"I91OS*U>^N2PI8U8QI9!Z^35F8-4^^N_^-I[K)9F@6DSSL&FX,B%
MC6PT]>W9]^O+WK=M[N"^NJB"F859]-JBQ9$_AFTZVJU?].;`X=2PT,6MX\)_
MV:]AF70SKYIL]MR-__KMPI`[__+)__;<_.66^]Y^_>JP_?#+_.S">U0BH(9/
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____!$*$Q0```(!T4DY3________________________________________
M____________________________________________________________
M____________________________________________________________
M_________P`X!4MG`````6)+1T1_2+]QY0````EP2%ES````2````$@`1LEK
M/@```'I)1$%4&--CJ$<##)@"S""`),!LR,C(*,:,)*#.``3,<'4,S/9P8,`,
M%G!``(@`$Y.QC"4$.`*U,3!+Z;!R6$"`&I\X#P.SH`FW-11HRC(#M0CHREM!
M`;\R2$!?PPX&5)A!AK*;V\"`)$A`E=<6!A3`UM8[(@`S-M\"`+1-1M]V6*="
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]T<F5E+V)L86YK+G!N9P``````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`R-C(`,3`U,34T,S$P-C<`,#(R,C,T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````4````%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58
M=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\````!E!,5$7___\```!5
MPM-^`````7123E,`0.;89@```"5)1$%4>-IB8$``@`""(X``0D8``80?`000
MF0@@@.B+``)L^"$``;8``?2%K84`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=')E92]P;'5S8F]T=&]M+G!N9P``````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,S8T`#$P-3$U-#,Q,#8W`#`R,S,V,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%```
M`!0(`P```<U0W:D````$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!
M9&]B92!);6%G95)E861Y<<EE/`````E03%1%D)"0````____B0!/(0````-T
M4DY3__\`U\H-00```&))1$%4>-IB8&)D8@!C)B:```)B!B!@8@((("!B!+*9
M&!@9F``"""3!Q(2+!`@@,,D(8S)`M(.9C(R,8(PB"@,``40,$ZH+70$C(_%J
MH0`@P)"89`LRH*F`"S(2+8B-)M-)`$.(`M*C1$6+`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V
M+6UI;G5S;VYL>2YP;F<`````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R,``Q,#4Q
M-30S,3`V-P`P,C,W-C4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_
M````#%!,5$60D)````#___\```"Q+Z:&````!'123E/__P``TPY4A@```:])
M1$%4>`$!I`%;_@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`````````````@("`@`"`@("`@("``("`@("`@(``@("`@`"
M`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`0(!
M`@$"``(!`0$!`0(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("
M``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("````
M`````````@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`EHZ`MESO^NV`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R
M964O<F5V+6IO:6YB;W1T;VTM9&]W;BYP;F<`````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R
M-``Q,#4Q-30S,3`V-P`P,C4P-C4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,`
M``"Z5^T_````#U!,5$4```#___\```````````"":])6````!7123E/_````
M``@/P3T```&O241!5'@!`:0!6_X``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!
M`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!
M`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!
M`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!
M`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0`!``$``0`!``$``0$!
M`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!
M`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$`
M`0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!
M`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!
M`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0%"P@&&O@Q=LP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+W1R964O;&5A9BYP;F<`````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#,S,``Q,#4Q-30S,3`V-P`P,C(P-3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0!`,```#MW>)2````&%!,5$5N;763D9S/S-C___\```#___\```````#!
M8\IB`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3
M`0":G!@````'=$E-10?4#!03+3!'8ZXZ````.4E$051XVF-@8&!P<7%Q`%(,
M+(Y*BF"&DY.Q$8C!H@QEN+A`&8Y*2A"&D[$Q)0R@.1"[7%Q@MD,``#UG$EP(
MM:"#`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VIO
M:6YB;W1T;VTM9&]W;BYP;F<`````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-3<`,3`U
M,34T,S$P-C<`,#(T,S`Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````4````%`$#````MT>/
M3@````903%1%````____I=F?W0````)T4DY3_P#EMS!*````%DE$05085V/\
MS_"1D20<]AM"-Q1BHP$?P"<UNO&77P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<V]N;'DN
M<&YG`````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U-#,Q,#8W`#`R
M,S8Q-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7[3\````,4$Q419"0
MD````/___P```+$OIH8````$=%).4___``#3#E2&```!KTE$051X`0&D`5O^
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@(`
M```````````"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("
M`0("`@`"`@("``("`@("`@(``@("`0("`@`"`@("``(!`@$"`0(``@$!`0$!
M`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"
M`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(````````````"`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("5R("U8/XR/``````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]N=6QL;VYL
M>2YP;F<`````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S0T`#$P-3$U-#,Q
M,#8W`#`R,S`R,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D````$
M9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y
M<<EE/`````E03%1%````D)"0____\OT?)0````-T4DY3__\`U\H-00```%))
M1$%4>-IB8&)B8H!B@``"8@9&1B`)$$`@#DB($0@!`@C&QDX"!!"$A#$900#*
M!%*,#$"`(@H#``%$#!.JBXERM0`!AL0D6Y`1RF&DHB#Y3@(`<,$"^T4;)Q(`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O:F]I;F)O='1O;2YP;F<`````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,P,P`Q,#4Q-30S,3`V-P`P,C,S,C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*
MZ0```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````&4$Q4
M10```/___Z79G]T````"=%).4_\`Y;<P2@```#5)1$%4>-IB8&2`0D9&@``"
M8@@"""`X`@*``,)/`@00`QXF!##"`1(3((#HRP0(,"3F,!$$`#YQ`8:"29@S
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]T<F5E+W)E=BUL:6YE+G!N9P``````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#$P,30`,3`U,34T,S$P-C<`,#(R-C8R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````4````%`@#````NE?M/P````E03%1%````____````<\:#<0````-T
M4DY3_P``1.[P,P```:])1$%4>`$!I`%;_@`!`0$!`0$!`0$!`0`!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!
M`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`4%%`8?5
M\=B!`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU<V)O='1O;2YP;F<`````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$P,C``,3`U,34T,S$P-C<`,#(T,S$P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````4````%`@#````NE?M/P````Q03%1%D)"0````____````
ML2^FA@````1T4DY3__\``-,.5(8```&O241!5'@!`:0!6_X``@("`@("`@("
M`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!
M`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("
M`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@````````````("
M`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@`"`@("`@("``("`@(`
M`@("`@("`@`"`@("`@("``("`@(``@$"`0(!`@`"`0$!`0$"``("`@(``@("
M`@("`@`"`@("`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("
M`@`"`@("`@("``("`@(``@("`@("`@````````````("`@(``@("`@("`@("
M`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("
M`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("
M`@("`@)5\`+68I637@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP;'5S+G!N9P``````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C``,3`U,34T,S$P-C<`,#(R-S$S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````Q03%1%D)"0````
M____````L2^FA@````1T4DY3__\``-,.5(8```&O241!5'@!`:0!6_X``@("
M`@("`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("
M`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("
M`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@``````
M``````("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@`"`@(!`@("
M``("`@(``@("`@("`@`"`@(!`@("``("`@(``@$"`0(!`@`"`0$!`0$"``("
M`@(``@("`@("`@`"`@(!`@("``("`@(``@("`@("`@`"`@(!`@("``("`@(`
M`@("`@("`@`"`@("`@("``("`@(``@("`@("`@````````````("`@(``@("
M`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("`@("`@(``@("`@("
M`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("`@("`@(``@("`@("`@("
M`@("`@("`@("`@)2<@+0R0ZB'0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP;'5S8F]T
M=&]M+G!N9P``````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C``,3`U,34T,S$P-C<`
M,#(T,30P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````Q03%1%
MD)"0````____````L2^FA@````1T4DY3__\``-,.5(8```&O241!5'@!`:0!
M6_X``@("`@("`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(`
M`@("`@("`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("
M`@("`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("
M`@````````````("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@`"
M`@(!`@("``("`@(``@("`@("`@`"`@(!`@("``("`@(``@$"`0(!`@`"`0$!
M`0$"``("`@(``@("`@("`@`"`@(!`@("``("`@(``@("`@("`@`"`@(!`@("
M``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@````````````("
M`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(`
M`@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("
M`@("`@("`@("`@("`@("`@)2V`+2U]\]W@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VUI;G5S
M+G!N9P``````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-C$`,3`U,34T
M,S$P-C<`,#(R,S`P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````4````%`@#```!S5#=J0``
M``1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A
M9'EQR64\````"5!,5$60D)````#___^)`$\A`````W123E/__P#7R@U!````
M7TE$051XVF)@8F1B8&("8D8F@``"T@Q`P,0$$$!`Q`@2`D&```)),C'A(@$"
M"$PRPI@,$.U@)B,C(QBCB,+4`@001#-^)E07N@)&1N+50@%`@"$QR19D0%-!
M#4'RG00`1+,"U']6M%P`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M:6YU<W1O<"YP;F<`````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S4V`#$P-3$U-#,Q,#8W`#`R,S`R
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W
M!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E0
M3%1%D)"0````____B0!/(0````-T4DY3__\`U\H-00```%Q)1$%4>-IB8&)B
M8@!C1B:```+2#$#`Q`000"`!D!`(`@00C(V=!`@@"`EC,D"T@YF,C(Q@C"+*
M!+0%!``""%4;=B94%[H"1D;BU4(!0(`A,<D69$!300U!\IT$`$EW`M=00T&D
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O;6EN=7-O;FQY+G!N9P``````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#,T-@`Q,#4Q-30S,3`V-P`P,C,R,#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT
M4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````)4$Q419"0D````/__
M_XD`3R$````#=%).4___`-?*#4$```!4241!5'C:8F!B8F*`8H```F(&(&!B
M`@@@$`<D!((``01C8R<!`@A"PI@,$.U@)B,C(QBCB,(`0``1PX3J0E?`R$B\
M6B@`"#`D)MF"#&@JJ"%(OI,`3&D"V65>_-``````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]T<F5E+VIO:6XN<&YG````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`S,#4`,3`U,34T,S$P-C<`,#(R,3`R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````4````
M%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D
M;V)E($EM86=E4F5A9'EQR64\````!E!,5$4```#___^EV9_=`````G123E/_
M`.6W,$H````W241!5'C:8F!D@$.``&)@9(0@@`!"1@`!!$2,8`96$B"`&/`P
M(0"K`H``@I#T8@($&!)SF`@"`#B6`8+["E\K`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M:6YU
M<V)O='1O;2YP;F<`````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S4T`#$P-3$U
M-#,Q,#8W`#`R,S4R-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D`
M```$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E
M861Y<<EE/`````E03%1%D)"0````____B0!/(0````-T4DY3__\`U\H-00``
M`%I)1$%4>-IB8&)D8F!B`F.```)B!B!@8@((("!B!`F!($``@20@TMA(@``"
MDXPP)@-$.YC)R,@(QBBB,``00,0PH;K0%3`R$J\6"@`"#(E)MB`#F@IJ")+O
M)`!'I0+6O/JDQP````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6QE868N<&YG````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,R-P`Q,#4Q-30S,3`V-P`P,C(V
M-3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````&%!,5$5N;763
MD9S/S-C___\```#___\```````#!8\IB`````7123E,`0.;89@````%B2T=$
M`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03+@!*E\U5
M````.$E$051XVF-@8'%Q<6$``18A)1$',$/96$4%QC!R@#+`JH`,)241",/8
M6(5\AI`2U!P7%YC]8```H?D,RP0'1KT`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUJ;VEN8F]T=&]M+G!N9P``````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$P,30`,3`U,34T,S$P-C<`,#(T,3$W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````4````%`@#````NE?M/P````E03%1%````____````<\:#<0``
M``-T4DY3_P``1.[P,P```:])1$%4>`$!I`%;_@`!`0$!`0$!`0$!`0`!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0`!``$``0`!``$``0`!`0$!`0$!`0`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`3Z]
M`89`I&Z1`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+V9O;&1E<BYP;F<`````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$R-S``,3`U,34T,S$P-C<`,#(R-#(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`@#````*"T/4P```8!03%1%_?/4_?;<HHI4
M^N2POX0[PHTZ=ELDOX@Z]^O+[.;:K)9FQI0^Y=S+]]V?].;`^^BY_/;FKYIL
M\]"#\.3&W<)YOK&8Y<Z4X=2P_.S"^=MZR;N@T+Z;OX4[P(H[]N[>X\."KI]_
MI8U8GX=0U\FL]MF6X-.OSZU5PY`\W].]C&LT=U4B[>?=R+*(J9-AP8L[NJB"
MU[AA^=M[]=:,T,6M^.&HZMFL^]U]<U@C__OQPY$[_..0_O?D_.FJ_N_!__73
M>U0B_?#+H(9/____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````4KA/_@```$-T4DY3________________________
M____________________________________________________________
M____`$%B!.\````!8DM'1'](OW'E````"7!(67,```!(````2`!&R6L^````
M@DE$0508TV7/UQK!0!!`X=WH/4%T0407G>AKO/]#F2&#+SF7_]T1ST`B#&D`
M</]@6952#HP?])("`TK;$L#C6UY[0ZV3.?FIN(E0&.E'/VOF(41B%ZZ4(M@M
M[MP^2Y!KW[C*F,!)7+ERGV#3.G.K)H)=C-8/G];#.4(#)HJ;>MWP[0NON36/
M5AB#@0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUN=6QL;VYL>2YP
M;F<`````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C``,3`U,34T,S$P-C<`,#(S
M-C`T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````Q03%1%````
MD)"0____````SY'=U`````1T4DY3__\``-,.5(8```&O241!5'@!`:0!6_X`
M`@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("
M`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("
M`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@$!
M`0$!`0$!`0("`@(``@("`@("`@$"`@("`@("`0("`@(``@("`@("`@$"`@("
M`@("`0("`@(``@("`@("`@$"`@("`@("`0("`@(``@`"``(``@$"`@("`@("
M`0("`@(``@("`@("`@$"`@("`@("`0("`@(``@("`@("`@$"`@("`@("`0("
M`@(``@("`@("`@$"`@("`@("`0("`@(``@("`@("`@$!`0$!`0$!`0("`@(`
M`@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("
M`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("
M`@("`@("`@("`@("`@)T;@+[E!91J`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU
M<RYP;F<`````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C``,3`U,34T,S$P
M-C<`,#(S,#8S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````Q0
M3%1%D)"0````____````L2^FA@````1T4DY3__\``-,.5(8```&O241!5'@!
M`:0!6_X``@("`@("`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("
M`@(``@("`@("`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(`
M`@("`@("`@("`@(!`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("
M`@("`@````````````("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("
M`@`"`@("`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@$"`0(!`@`"
M`0$!`0$"``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@`"`@("
M`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@``````````
M``("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("`@("
M`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("`@("`@(`
M`@("`@("`@("`@("`@("`@("`@)5B@+4\<TYK0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W!L
M=7-O;FQY+G!N9P``````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-C(`,3`U
M,34T,S$P-C<`,#(S,#,S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````4````%`@#```!S5#=
MJ0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E
M4F5A9'EQR64\````"5!,5$60D)````#___^)`$\A`````W123E/__P#7R@U!
M````8$E$051XVF)@8F)B8&($8B8F@``"8@8@8&("""`0!R3,P,C`!!!`,#9V
M$B"`("2,R0#1#F8R,C*",8HH#``$$#%,J"YT!8R,Q*N%`H``0V*2+<B`I@(N
MR$BT(#::3"<!`$A,`M6!HY(``````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<W1O<"YP
M;F<``````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U-#,Q,#8W`#`R
M,S0S-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7[3\````,4$Q419"0
MD````/___P```+$OIH8````$=%).4___``#3#E2&```!KTE$051X`0&D`5O^
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@(`
M```````````"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("
M`0("`@`"`@("``("`@("`@(``@("`0("`@`"`@("``(!`@$"`0(``@$!`0$!
M`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"
M`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(````````````"`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("
M`@("`@("`@("`@("`@("5KP"TP&:N0,`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;6EN
M=7-T;W`N<&YG````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U-#,Q
M,#8W`#`R,S8P-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7[3\````,
M4$Q419"0D````/___P```+$OIH8````$=%).4___``#3#E2&```!KTE$051X
M`0&D`5O^``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@(````````````"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("
M`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``(!`@$"`0(`
M`@$!`0$!`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("
M`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(`````````
M```"`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("
M``("`@("`@("`@("`@("`@("`@("6=0"UP'^LJP`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]L
M:6YE+G!N9P``````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S`Q`#$P
M-3$U-#,Q,#8W`#`R,C`V-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P```<U0
MW:D````$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G
M95)E861Y<<EE/`````903%1%````____I=F?W0````)T4DY3_P#EMS!*````
M,TE$051XVF)@9(!#@`!B8&2$((``0D8``01$C&`&5A(@@!C(8P($$(2D%Q,@
MP)"8PT00`#]3`8?#_92-`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<W1O<"YP;F<`
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V-0`Q,#4Q-30S,3`V-P`P
M,C(V-3<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$`
M`*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M```)4$Q419"0D````/___XD`3R$````#=%).4___`-?*#4$```!C241!5'C:
M8F!B8F)@8@1C@`!B`#*!@(D)(("`""S,P,C`!!!`,#9V$B"`("2,R0#1#F8R
M,C*",8HH$]`6$``((%1MV)E07>@*&!F)5PL%``&&Q"1;D`%-!5R0D6A!;#29
M3@(`15H"TS4)<68`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]N878O````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C<`,#(P,C8W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]B;W1T;VTN
M<&YG````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0W-P`Q,#4Q-30S
M,3`V-P`P,C(S,#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
M5%!,5$4````(#1$J0ULS4FXW67@_98A%;Y9)=)Q,>:-0@*U;B+)?B[1GD;B1
ML,R5LLZ7L\Z:M<^;MM"<M]&>N-&@NM.DO=6OQ=JRQ]NUR=RVRMV^T.$````4
MM"1X`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3
M`0":G!@````'=$E-10?4#!01+@Q`I540````9$E$051XVFV-60Z`(`Q$ZU+W
M!0HNR/WO:=&()?J^.B^3#@#C;R#B=SW6E12K-5A*L9%*A?L(K5\1_CM%+)XA
MWYG%$B+FL=,2D<C!S%9F@*R?DLR=)LULQ"FYQ,$;-/`L%OZG<0+$^@G-P?I?
M#`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O9&]W;BUG<F5Y+G!N9P``````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-3``,3`U,34T,S$P-C<`,#(R-S`T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```$A03%1%````4U-3
M=W=WA86%C8V-E)24EY>7FIJ:GY^?I:6EIZ>GP\/#Q,3$QL;&Q\?'R,C(R<G)
MR\O+S<W-T]/3U=75UM;6U]?72TM+M7`.]0````%T4DY3`$#FV&8````!8DM'
M1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$3$!\TXG
M,P```%E)1$%4>-IC8"`*B$,`DH`H/S<;*[*`L*``"S.R@(@`'ZJ`&(8`/S]"
M`&2^&!_(#)A%XIP"0D!#65B8X&HX!`0$D/@@$5Y!9#X#`R,7#PH?J(9='-T[
M.#T*``^-!6T2HQVW`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;F%V+VQA<W0M9W)E>2YP;F<`````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-3`S`#$P-3$U-#,Q,#8W`#`R,C8W-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```!14$Q410``!%-34W=W=X&!@86%A8V-
MC924E)>7EYJ:FI^?GZ6EI:>GIZRLK,/#P\3$Q,;&QL?'Q\C(R,G)R<O+R\W-
MS=/3T]75U=;6UM?7U]O;VTM+2W.6.@0````!=%).4P!`YMAF`````6)+1T0`
MB`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$R+>J[&!,`
M``!K241!5'C:?8_;#H,@$$31BBU>86@5Y_\_5&"A#Z;V)&1W3O9A4.HW+(.L
M0A8>7S'DC6"Z2L"PBOVSA1#>,$T1S@/.>JPC1<RPU@'PRXN<HGCJ0AN#CJ_O
M$CF+$'+.HO1HI8>^-GWP[B]_.`&%:@F!_@#I/@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VYA=B]L969T+6=R97DN<&YG````````````````````````````````````
M```````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#0T,@`Q,#4Q-30S,3`V-P`P,C(V-S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````15!,5$4```!I:6EV=G9W=W=Z>GJ!@8&-C8V7EY>9F9FL
MK*S'Q\?(R,C)R<G*RLK+R\O,S,S-S<W.SL[0T-#1T='3T]/?W]]+2TL%;5=@
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":
MG!@````'=$E-10?4#!01,Q"KR&5#````5DE$051XVH6/21*`,`@$X[X$1$W"
M_Y\J43@82^W;=%$,./<"E[D0G+C(Q!>6MSW$$&EBS;`2>H_S<(HJX0(`*(PZ
MT?1*9SO$U)G6NL3<6K+YN_3YRP<''>L%39["PTD`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O9&]W;BYP
M;F<`````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-30`,3`U,34T
M,S$P-C<`,#(Q-S0T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M`$M03%1%!0`*"`T1*D-;-UEX/V6(16^6272<3'FC4("M6XBR7XNTD;#,E;+.
ME[/.FK7/F[;0G+?1GKC1H+K3I+W5K\7:LL?;M<G<MLK=````AE_J!P````%T
M4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````
M!W1)344'U`P4$3`3&>QG.@```%I)1$%4>-IC8"`*2$``DH`8/S<;*[*`B)`@
M"S.R@*@`'ZJ`.(8`/S]"`&2^.)\`4`!FD02GH+"0``L+"Q-<#8>`@``2'R3"
M*X3,9V!@Y.)!X0/5L$N@>P>G1P$JYP6<-1$@7P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V9I<G-T+6=R97DN<&YG````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#8U`#$P-3$U-#,Q,#8W`#`R,S`W
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!(4$Q410```&EI
M:79V=G=W=WIZ>H&!@8V-C9>7EYF9F:RLK,?'Q\C(R,G)R<K*RLO+R\S,S,W-
MS<[.SM#0T-'1T=/3T]O;V]_?WTM+2T*9<"4````!=%).4P!`YMAF`````6)+
M1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$R#*;2
M"$T```!F241!5'C:A8_9#L`@"`3MH3W$VI/]_S^MBIK4ETY"`L,#BU(M`')3
MQ(.\*()2!_X*L(<@`GR<UWW=?A$!IMT[:]TZA6%!QVXC(A>8@S"A!I/1(I+I
M(V,6T=0K1G(,-8=ND[:__/("[HX(9%"V6-X`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VYA=B]R:6=H="UG<F5Y+G!N9P``````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#0T-P`Q,#4Q-30S,3`V-P`P,C,P-C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````2%!,5$4```!34U-W=W>%A86-C8V4
ME)27EY>:FIJ?GY^EI:6GIZ?#P\/$Q,3&QL;'Q\?(R,C)R<G+R\O-S<W3T]/5
MU=76UM;7U]=+2TNU<`[U`````7123E,`0.;89@````%B2T=$`(@%'4@````)
M<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01,RIMQ+SQ````6$E$051X
MVHV.60Z`(`Q$ZXY;&5S:^]_4B(`):N+[F]=)ID1?Z$/D1GN];QZ8:'1?-Q%9
M8(H@K`,L.\S#U=$1S!:`FSIOM*T#96@TU4G*<27EN)7EET_I+P<O+05M)ZK3
MU0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]N878O<FEG:'0N<&YG````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`T-3,`,3`U,34T,S$P-C<`,#(R,3$Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P```$M03%1%!0`*"`T1*D-;-UEX/V6(16^6272<3'FC4("M
M6XBR7XNTD;#,E;+.E[/.FK7/F[;0G+?1GKC1H+K3I+W5K\7:LL?;M<G<MLK=
M````AE_J!P````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3
M```+$P$`FIP8````!W1)344'U`P4$3,:2QV,70```%E)1$%4>-J-CED.@"`,
M1'''C0ZXM/<_J1$!$]3$]S>ODTR5^D(>(C?2RWWS6!V-[.O&S`MT$00Y@(S#
M/%P=&:TQ!,!-G3?2UH$R-)KJ).6XDG+<RO++I^HO!TKW!9R9EHVB`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+VQE9G0N
M<&YG````````````````````````````````````````````````````````
M`````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#4T`#$P-3$U
M-#,Q,#8W`#`R,3<R-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M``!.4$Q410```!PM/2E"6BI#6RU'8#13;S]EB$EUGDMXHFB2N9JUSYNVT)RW
MT9ZXT9^YTJ"ZTZ.\U*2]U::^U:K!UZO"V*[$V:_%VL34X\75Y````"BH+NH`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0,%!$R-F#>T?\```!7241!5'C:8V#``231^6@"DN*2:'P!
M20B`\86$1<1$1`4X):%\'D$!/FYN/BYVL`"C!!\_+R\/'Q!P0%4PLT$!*\P,
MH`@3"+#`[`**H-@"$B'D4DR_X`$`;?T%U@-5])4`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]B;W1T;VTM9W)E>2YP;F<`
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0W,P`Q,#4Q-30S,3`V-P`P,C,R
M-#8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````45!,5$4```53
M4U-W=W>!@8&%A86-C8V4E)27EY>:FIJ?GY^EI:6GIZ>LK*S#P\/$Q,3&QL;'
MQ\?(R,C)R<G+R\O-S<W3T]/5U=76UM;7U]?;V]M+2TLX;TU5`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?4#!01+SAX"I#D````8TE$051XVFV-5PZ`,`Q#PPA[M"FCY/X')0514H&_
M["?+!A#Q+8CBW8YUI<'J"$L--C(I\!]@[0O"OC=AXSGBCA891<QCIR4BE0.9
MG<X`63\E63I-FH4HJW6!0SYHD%LL^*=Q`J!K"8',5N`=`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]N878O=&]P+G!N9P``````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`T-S0`,3`U,34T,S$P-C<`,#(Q-C`Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```%=03%1%````'"T]*4):*D-;+4=@
M,U)N-%-O/V6(276>2WBB9Y&X:)*YFK7/F[;0G+?1GKC1G[G2H+K3H[S4I+W5
MIK[5JL'7J\+8KL39K\7:OM#AQ-3CQ=7D````EC(2%@````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$3,S":\4,0```%Y)1$%4>-I=STD.@#`(0%$<<:Q8Y\K]SRFF,5+^CA=24@#6
M@<27DSJ4J@AV(Y9!&M^<SH$*3F8WHQ(.ZS+A+QS\Y@4^>:_MY#!79_D<24`]
MNELXR(`?#/1-6Y<:U,\>_>P*'&SO8AX`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;F%V+W5P+G!N9P``````````````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P-#4T`#$P-3$U-#,Q,#8W`#`R,30R,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```!.4$Q410```!PM/2E"6BI#6RU'8#13;S]EB$EUGDMX
MHFB2N9JUSYNVT)RWT9ZXT9^YTJ"ZTZ.\U*2]U::^U:K!UZO"V*[$V:_%VL34
MX\75Y````"BH+NH````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,%!$T$9..PQ(```!7241!5'C:8V#`
M`1C1^)(2DJA\<3YF210^#S\;DHBDN)`@+QM"1%)<0%@`*``3D00"$3X>-B80
M`Z9&C)L/*(!DJ`BZ@"@?FH``%YH`)SL'*PNR``0P$`<`#LT%UGZM[G(`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]U<"UG
M<F5Y+G!N9P``````````````````````````````````````````````````
M```````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0T,0`Q,#4Q
M-30S,3`V-P`P,C(S-C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M````15!,5$4```!I:6EV=G9W=W=Z>GJ!@8&-C8V7EY>9F9FLK*S'Q\?(R,C)
MR<G*RLK+R\O,S,S-S<W.SL[0T-#1T='3T]/?W]]+2TL%;5=@`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?4#!01-"(L7J($````54E$051XVHW,V0Z`(`Q$T;K5C5H5F/__5#&&B$U(
MO$_,20-1I<9L1)@M'3[;;5P(XK$[?@513TV0!2DOCMO[D6_"*@F*3[V%(`9T
M,3"/T]"7\$3_N@#'?`5-^S$3(P````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O=&]P+6=R97DN<&YG````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-3,`,3`U,34T,S$P-C<`,#(R
M-30R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```$A03%1%````
M:6EI=G9V=W=W>GIZ@8&!C8V-EY>7F9F9K*RLQ\?'R,C(R<G)RLK*R\O+S,S,
MS<W-SL[.T-#0T='1T]/3V]O;W]_?2TM+0IEP)0````%T4DY3`$#FV&8````!
M8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$30)
M@.);1````%Q)1$%4>-I=S^L.@"`(0&&Z2%F0E2;O_Z;16@LY__C&9`*(#32Y
M2(NHA1?\QEL';5+%S3Q(,].&1J0>.^$O4M.9%#YYKF4F[,U9*2LKF$>SA\(.
MTN(@3G,8+9B?W?@^"&2AQ5*R`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;F%V+VQA<W0N<&YG````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-3`U`#$P-3$U-#,Q,#8W`#`R,3<S-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,```!44$Q410````@-$2I#6S-2;C=9
M>#]EB$5OEDETG$QYHU"`K5N(LE^+M&>1N)&PS)6RSI>SSIJUSYNVT)RWT9ZX
MT:"ZTZ2]U:_%VK+'V[7)W+;*W;[0X0```!2T)'@````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$R
M%+6^D!L```!J241!5'C:?8_)#H`@#$1QP7V!@@O.__^G0-&#45]"VGGI81#B
M':0!7((7'+?HX@9"N`J8%I?8U\TYMU";):$MD5:6YAXL1J.4)B([-<#@12T3
MN0_2OZH,Q,R"B3F*U"/G'O+9M,#77WXX`;&)"<U4"YJ_`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VYA=B]F:7)S="YP;F<`````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#4P-@`Q,#4Q-30S,3`V-P`P,C(Q,C(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3````5U!,5$4````<+3TI0EHJ0ULM1V`S4FXT4V\_98A)
M=9Y+>*)GD;AHDKF:M<^;MM"<M]&>N-&?N=*@NM.CO-2DO=6FOM6JP=>KPMBN
MQ-FOQ=J^T.'$U./%U>0```"6,A(6`````7123E,`0.;89@````%B2T=$`(@%
M'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01,19PG:+T````
M:$E$051XVH6/R0Z`(`Q$W7&%BHJ*\__?*5(DD8LO:=*^'CK-LA0`H7G%B;!X
MA?0=[%?`:C`L8-?-'&;7`PM8N6B:)AI;-_3(+YJ5DN3HG!"N2A%H6'A3/%1!
M/"9>$9RCC#GJ-&GZRR\W\4P*''MOINL`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C86QE;F1A
M<BYP;F<`````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q,#0`,3`U
M,34T,S$P-C<`,#(Q-S4T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P
M``#J8```.I@``!=ODE_%1@```P!03%1%````_______X___[R\K`J:B@E92-
MP+^WDY*,FYJ4JJBAM[6NMK2M_?KPE)*,F):1_/COOKNTN[BQTL[&R<6^TL['
M_[A&F9:1JTU!]UI,PU!(^/CX\?'Q[.SLX.#@U-34P\/#H:&AB(B(>7EY8V-C
M3DY.-S<W,C(R&1D9____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````?5K91P```"IT4DY3________
M______________________________________________\`,JCP7`````EP
M2%ES```+$P``"Q,!`)J<&````'A)1$%4*,^-C]D.@E`,1#LR[EL5B]>Z(,IU
M^?\?5#`\0$QT'N;AY&32RK,3^0-(*V_P.!?%Y5J6,<;;O0("X`B<@!Q:@P.Y
M(,=53SY&DJR!H>I468.]V=9LY^[6;S9FO;EG66@9'D)HC.Z&INF`7)*CS4J^
M7?KKN1<(>A;FO_S1]@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1A8E]B;W1T;VTN9VEF````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`T-0`Q,#4Q-30S,3`V-P`P,C(S,C``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#=A%``!
M`(`!`````/___RP`````%``!```"!(2/F04`.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]P<F5F<RYP;F<`````````````````````````````````````````
M````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`V,38`,3`U,34T,S$P-C<`,#(Q,S,P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```(I03%1%``4`'1T='R<O*2DI,#`P,3$Q-C8V24=&
M4%!/4E)235]S;&EG:VII<G!M9GF/<(*5=(JBBH>$>(VD?8R<?)&G?9&G?YFS
MC9FEA)ZYA)ZZI*&<L;&QR,?&RLC!TM#,TM'0T]+/U=33S];=UM75V-C8V]K7
MWMO6W][<X^+AZ^OH[.OJ]_?W^?CX````W9?-&0````%T4DY3`$#FV&8````!
M8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P($AT'
M.Y6_U@```'U)1$%4>-IMCED2@C`0!8/@%O<%<4>C@*!]_^M)-D'+^<CT5+U*
M/R'^#3_`R</!0VF`.R[&2U,7>Y_AF6LD<OG+H\CV!&'CJ"<=$'R+Z=.^Z'$<
M-6UF:HW@MO`E5FJYZ=2[FEAMHN9;:;37L5DJWDD;)AWJ-YY*/K\[1[O`&R75
M#F;W^[4?`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6%P+G!N
M9P``````````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C$Q`#$P
M-3$U-#,Q,#8W`#`R,#<V,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,```!@4$Q4161D6__\S:BFB-K8M,/!HLW+K/_ZO?STJ)R8=*^KBK:RD7AV
M8_ONCMG0BI"+9_;C?,_'F?/>=/?GG?_3-_;/2?K85^2N&N2V.\B6'M2C*=VN
M-:M]%KZ-'%P_)4]/3P```(J'Y#`````@=%).4_______________________
M__________________\`7%P;[0````%B2T=$'P4-$+T````)<$A9<P```$@`
M``!(`$;):SX```"6241!5"C/3<_9$H,@#`70J[((1:D4ZX(-__^797-:'AC.
M369($,OA?N/UA7)/:R=/_@N>:]<)=_`[*!;"[KP&R<,,@.S%<E#JPTA$9@DL
MHO8S$,@8'QA\M@/4!&N75\`FA9",'L9,R>\/].F$5#0;4ZP1]>'DF(+J_*W>
M;4]S<QE,78LM5O?H*OBUN2VG0G+_MVU*FN,7&=\3QXR&$]\`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V]R9V%N:7II;F<N<&YG````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$V-P`Q,#4Q-30S,3`V-P`P
M,C(S-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3```!+%!,5$4`
M```)"0D,"PH.#@X3$A$3$Q,7%Q<8&!@;&QL>'AXB(B)$1$15555?7U]T:TQM
M;6UN;FYU=75V=G:"=U5Y>7E_?W^#@7B&A'N)AGZ(B(B-C8V4DHN3DY.6E(RA
ME7";FYN<G)RCGY>NH'2PHGBVIW6JJ)^HJ*BZJ72KJ:&KJZNLK*RQK:2^KWVT
ML*BTLJJWM[?<O'3`P,#$P+C$P;G)Q;W&QL;+Q[_JR'O+R\O=S9C2S\C4T<S4
MTLS5TLS8UM#6UM;8U]'<W-SSWIKTWYWUXJ3AX>'VXZ?WY*SDY.3FYN+FYN;I
MZ>;IZ>GJZ>?KZNGKZNKM[.CO[NWQ\>[R\>[Q\?'R\O+T\_+T]/+T]//T]/3U
M]//U]?7W]_3W]_?X^/C\_/S]_?W^_O[___\```!3;<,5`````7123E,`0.;8
M9@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4
M#!01-C#MT;'.````Q$E$051XVDV/UU;"4!1$`T&J-*4J2$?I12!*D1)Z$>D=
M#//__\"]`1;,XU[[G#7#,-<`S'V`:>H.`0=!V%6#9P16#F1G_\+Q6'XAY.&S
MHDE;D-H?NE_40*ZS8/\R5C02@/L1#/+KI6K2B[%`T$0-96F[4ZN>/D`3,A+C
M9[&:#P<>N-HPB#]>"[^C<=&*-XX<F2FQ1>(!ITP7Y:"]]`"D>/8VB>'00P1A
MW[O_N\[!?BF/38OG:P1<MZ#/T205MVD2L84HG`"_;3.Y4*=/<0````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQO9VEN+G!N9P``
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<V,@`Q,#4Q-30S
M,3`V-P`P,C$S,C,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
MP%!,5$4A(2'JU,OCQ;K;M*3NWM?Z]_7RY>'2K)D```"-GGS-V<+>YM?:XM&;
MK8FWDX)P?6.TQJ*LP)AC;E>KBGKDZ=UE<5C$GXW#T;6`CW!,5$)88T[FZ^#4
MW<G*U[Z0H7]?:E-37$GI[>1A;5:HO)5\BVY,5$.VPJI>:5/_____________
M____________________________________________________________
M______________________\7Y'27````0'123E/_____________________
M____________________________________________________________
M__\`PGNQ1`````%B2T=$/SYC,'4````)<$A9<P```$@```!(`$;):SX```!_
M241!5"C/;8])$L(P#`0G$:#!`8-,V/?]&?K_KS@X5)D4?9KJ4P^\!XH)E`*H
M:@$*,1B.:NT$,Y6H(HMQ:"93BDC,PCF;6Z*(+@!W)]M@RT31%1Q.MF%MF^V.
M,0(.[@]'L].9%W8=O)K9C4Y^2]G<'T^6Z7PE_G[ANR><?]]F/N/K*`TPEY7S
M`````$E%3D2N0F""```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L:&%N9"YP;F<`````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T,30`,3`U,34T,S$P-C<`,#(Q,C<S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````A````#@0#````4S!HOP```!A03%1%____P,#`
MO[^_@("```#_``"`````````6NUX4P````)T4DY3_P#EMS!*`````6)+1T0&
M86:X?0````EP2%ES````2````$@`1LEK/@```'])1$%4*%-=ST$*Q2`,!-#@
M"73CNJ20"Q0\@=Y`]];"W/\(C4W;_^EL(H^!&`J?>+()S;\`1.3V5R*XJY#H
M"U!!=^)D:`G(.7N*Y-;!0Y;9,F'1KI5,`O8026:)D\FUK#LPKZF4<LN$@[=4
M:[TE8I%C`UIKC]"$$'_R7&$__,2?("HD[6LFQX8`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O<W%L+G!N9P``````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#$R`#$P-3$U-#,Q,#8W`#`R,3`P,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT`
M`'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q41?SI
M._OG._SK/?G?.?;2-F59,$]!%6Q?-%M0+5Q/*V%4+O*V3>^T3?>U1/>U1?2R
M1->N=````/___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'I#\!L````3=%).4________________________P"R?=P(````"7!(67,`
M``L3```+$P$`FIP8````54E$050HSW6/6PK`,`@$[?O==/;^A^U')#&%BN`Z
MZ(JF3UA1T`*Z@PCHKST"[%[B"D-:"::,YT:Y`N*9P.\8B!F4TP$1R(<KJ-T/
M<$GK(;(3Q&]S>0'V#!$%YH6,:P````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C;VYF:6<N<&YG
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W-C$`,3`U,34T
M,S$P-C<`,#(Q-#8P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M``1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J
M8```.I@``!=ODE_%1@```P!03%1%````____[^_OW]_?P\/#OKZ^&QL;____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````2M?+&@````AT4DY3_________P#>
M@[U9````"7!(67,```L2```+$@'2W7[\````1TE$050HSVV/`0K`,`@#K\ZN
M___Q+&U!TP44/()&AHC5674`;0(C@U`!%G+2CG;F#8(XHP)3((Y7''3SO)1'
MSOX$D^C7<UD?NUX%)VP->?0`````245.1*Y"8((````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P97)M
M<RYP;F<`````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S,`
M,3`U,34T,S$P-C<`,#(Q,S,R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D`
M`'4P``#J8```.I@``!=ODE_%1@```P!03%1%BWU*;V0[7E4R[M:`\O+R[>WM
MW]_?VMK:SL[.R,C(PL+"O[^_M+2TJZNKDY.3:VMK45%12$A(0$!`(2$A!P<'
M`0$!````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````^)IS*P```!AT4DY3____
M__________________________\`S1,NZ@````EP2%ES```+$P``"Q,!`)J<
M&````&%)1$%4*,^5SL$2@C`,1=%H?8BV2A&][___U`4,UNZXRS.9).&N,&L[
M<$[IE#6S0XI(:*C;9`!7GEK+$+!<))5MPF%N4\GEM\.,C\_[17-VNFN8&S!5
ME>8Q&^&CD'N@@[^^`Z03U,.I)L\`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%Z+G!N9P``````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#(V-P`Q,#4Q-30S,3`V-P`P,C`V,C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````D````)`@,```"=_^Z#````"5!,5$6Z`!9F9F8```",
MM<Q"`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3
M`0":G!@````'=$E-10?4#!01-AFO8RFB````)TE$051XVF-@`($&!@;&"0P,
M3`L8&-B6,#!PK6!@D%K)P*"U"BP+`$YG!*?ZOMDG`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]U;FQO8VME9"YP;F<`````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$R,34`,3`U,34T,S$P-C<`,#(R,#$Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```.=03%1%````!`,"!00#"`@("PL'&A,+%A86
M%Q<7+RDA+BXN34U-@5HK<G)RJF\KI'$VK'$NK7,RH'=$HWM+A(2$I'Y.J(%,
MM'X^IX)2IX)3N(`^JH15JX=8K(=8NH1"JXA8NH9'O(=&O(A)NHE+KXU>K8UD
MO(I,L(U?O8Q.I9%VOHU0QI9=QYMDJ*.>RI]HJJJJRZ1QSJ1PS:9NS:9VT*9T
MS*=[T*ATSZM\L;&QSZQ[S:R#SJV#U*QYU:Y^TK*)U;*$V+6,O+R\UKJ4P<#`
MVKZ:X,*>X<*<X,2@W\2CX<2@XL6AX\:BV]O;````A$]HZ@````%T4DY3`$#F
MV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'
MU`P4$BXBGC7FA@```(QT15AT0V]M;65N=`!-96YU+7-I>F5D(&EC;VX*/3T]
M/3T]/3T]/0H**&,I(#(P,#,@2F%K=6(@)VII;6UA8R<@4W1E:6YE<BP@"FAT
M='`Z+R]J:6UM86,N;75S:6-H86QL+F-Z"@IC<F5A=&5D('=I=&@@=&AE($=)
M35`L"FAT='`Z+R]W=W<N9VEM<"YO<F=GBL='````ATE$051XVF-@P`%\?'S0
M!+P=>)A1!-BYS(71=''JH>EB<_)!&,C"R,C$H<,*Y6NXN;L[.SL[&G%#E/AX
MVNO*B(M+""GR0P6\;-3LS,PL]!5XH0(>QMI2(B(B@K(P%:X&*K:6EE8FD@)0
M`1=K0V5I:3E1!3&H@*F6IJ:2DKJJ/)\/W!U0@,W;`.H0%TQJ<R;C`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]H:61E7W!A;F5L+G!N9P``````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`W-#4`,3`U,34T,S$P-C<`,#(R,S`T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```,!03%1%````4E)24U-355555E96
M5U=76%A865E96EI:6UM;7%Q<75U=>'*0>721>G21>G63@'UTB'^CK*F]Q<'2
MRL;6S\_/T-#0TM+2T]/3U-34U=75UM;6U]?7V-C8V=G9VMK:V]O;W-S<W=W=
MWM[>X.#@X>'AXN+BX^/CY.3DY>7EYN;FY^?GZ.CHZ>GIZNKJZ^OK[.SL[>WM
M[N[N[^_O\._S\/#P\?'Q\O+R\_/S]//V]/3T]O;V]_;X]_?W____````9%3[
MK@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`
MFIP8````!W1)344'U`P($APLCC)WUP```)Y)1$%4>-I%SML6@4`4@.%(!Y64
M0:$B10H5413M]W\KTV3-_)??6OO`<22#QOUA]H_!1-<U79M2:!=+R[;L50\`
M1CL8XC8.`?@`P-IQ/=?;=@!OA!#P/#_:^0$&>*`Y!G\?A$%XZ,#L`D$0)3$Z
MD1$"QRA.XN3<+S7Q4DF6Q_(U96<O:99G^8T]IBBJ>B]*!L6SK,JJ9E"]ZJ9N
MOA1H/V`'%AOR[AYZ`````$E%3D2N0F""````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9&5L971E+7-M86QL+G!N9P``````````````````````````````````
M`````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q-C0S`#$P-3$U-#,Q,#8W`#`R,C4V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````"```
M``@(`P```//13KD```,`4$Q419D``)EF9LP``,PS,_\``/]F`/^9,\S,S```
M``````````````````````````````````#_____108```````#,^!(`,\K6
M=WQ:V7>B#]AWE`_8=QAOCP`8:X\``0````$````!````H/@2`)SY$@`0^Q(`
M,-78=_CX$@```!0`4#KY=R0```!(#10````4`.@!%0#0^!(``````.CZ$@!`
M??IW(#CU=_____]0.OEW]WSU=_6(]7<```````!``#B&2``1````!`````,`
M```8:X\`:-MA`$#Y$@#K0-1W:-MA`.S___\`````&&N/`!AKCP`@FO5W*9KU
M=QA@&``D``(`4#P5`"SZ$@`P^A(``````',Z^7<@8!@`?HKU=]@'%`#!CO5W
M/&`8`"A@&```````P8[U=P4````H`````````&)>&``````````!````%`#\
M^!(`>`$4`.3Y$@!`??IW.!SU=______!CO5W9I'V=X&1]G?@-?QW=)'V=X!@
M&`!@8!@`/&`8``#@_7_,^1(`!````"CZ$@!`??IWV!7U=_____]TD?9WE)KV
M=P<````X````*&`8``````"P51@`N#@!````%`!T^1(``````'3Z$@!`??IW
M.!SU=______!CO5W+H_G=P``%```````.H_G=Z"\U'<``$```0```!!>&```
MX/U_``!`````````````"`$``"A@&`!$^A(``````+#_$@"&N^EW`(WH=___
M__\ZC^=W7%=#`"A@&`"@O-1W``!``"`````P.D*6<,O#`3`Z0I9PR\,!@*>1
MY'$7PP$`````B0```"0````@`0``9&5L971E+F=I9@```````!C[$@#H`14`
M```4``3Y$@`$^Q(`-/L2`$!]^G<H'/5W______6(]7?3F.=W```4``@`%`#D
MF.=WH+S4=P````````````````````!$VD0`&`(5`-S;%@`<`A4`;(9(`/__
M___H`14`GMI$`!@"%0!ST$0`Z`$5`,F+PK,````(=%).4_________\`WH.]
M60````%B2T=$_Z4'\L4````)<$A9<P```$@```!(`$;):SX````H241!5!C3
M8V"'`@9V1D80S<3`SL["`.(S@'E@)H+!!)5B9H'J@@`6`##)`5S3D!GI````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O<')O8FQE;2YP;F<`````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,S`U`#$P-3$U-#,Q,#8W`#`R,38T-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`$`P```.W=XE(````84$Q41?S3RP```-^!9-YU5?*@C=^!9-^!
M9-^!9&0/M50````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]0+!1,E!VV";=<````F241!5'C:8V!@8&`4
M8(``(44(S:BD)$`T`ZX+"P-N,AQ@V(6F&``$*P,@!$2]U@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V-O
M;&]R<V-A;&4N<&YG````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0R
M,@`Q,#4Q-30S,3`V-P`P,C(S,S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```&0```#`"`(`
M``!]#5'[````!&=!34$``+&/"_QA!0````=T24U%!]((#P<D'X*>ML4````)
M<$A9<P``"Q(```L2`=+=?OP````L=$58=$-R96%T:6]N(%1I;64`5&AU(#$U
M($%U9R`R,#`R(#$Y.C,T.C4U("LQ,C`PNJ0O=```!FE)1$%4>-KMG>&)'$<4
MA(6PX002[/W3#R<@<`("1R!P`@)'(!R!4`;"$0AG(&<@AR!G((=P"S)(8(.%
MQ/3\>;=U5:][NGMV:ZA?N[-SL]/?O5=3,]MS_UY9KHH>%STI>EKTK.AYT8NB
MET6OB]X4O2UZ5_2^Z$/13='_40^O%OWP>-&/3Q;]]'31S\\6_?)\T:\O%KUZ
MN>BWUXM^?[/HC[>+_GRWZ*_WB_[^L.CFYJN^+??O>:$7[F!]1^B*T$-"!T6/
MBL`&'Q2!'?N^Z-2W$PZ6EY,':UJ.UD\!H-:_#H!BOF#^W]#+W0=K-L2NBY@-
M,CLF(F:R<F1-PM%U$-/R<J4J-L$&UL'+2)_UZ+2VZX\UQ<MD3>FS(CZ5/@L`
MQ>S8G7[=/FMNG[4VIN8^2^J/H%':9^W!9ZWCQ@S[=CZKG5]WS3J//*O29X$-
M,GF6?=9\/@N,&S/L:V&JY$C*19UG3>RS5A.<L_+-(].<E;?/VGF>)9T2`I_5
MER/7K)X^"YRO,^=B/7V6\ZP+R+.`FONL+8N7R1J;9S&EJGEDZNN&^^R&0\J9
M)/NLG9-U>OG<2,>@5EN>Z&"9K`PUGXKB*RLLZQVD\96H(Z$^])FL1F2!XPTX
M`F4HKLS@$UG[%+2^5<D11LQDU9$5CR[#$:`F(K9=S0+T2:S=BIC)VLPZ@!&0
M^F.L8DS-JJQ0Z\?)"N6:M1E9D0CP%L,14\68FA4KE,0:0,S=<'3-RO5'0(3D
MLX!QEWI?1,PU:P.RI'8&UI'0R-4L:1UIY['_,EE#\ZS*D8R,-$'#>=;<>5:N
MUP!J;@A);3'7G9UG39-G28B!QL0D"@Q'.<3`]S)9??,L,$J`&NE,D*E9H&-*
MB#G/VE6>Q424`#I0LT`&FVMY/C<<W0US`2G(&&+F*=4L<'%(\GW.LR;.LUK=
MT"#YK(@8N`S>\#8(DS7T1/IS:S&(@5<8Z.Y\Q62-).NJD0[$KR^D5^)-KHE7
M3-8V9'6@YG#ZQSL`'PD6('?#OF2!`R\!M8+P(`C@`Z"+6U[7828(B-^+8LUD
MU9+%''@P;I&:5C4K`L7@`ZA95W;-&NVSP.!45C&I9L6WUNW$XI5KB[<4+Y/5
MOAM6`@6J3\YG16HDH$"I0E7,9&U8LR2@P,J`(ZE1YH!*6GF3E20KQTA<!S#"
M<!37D?YZ[0F@R=I3GB6AD7/Y8)TF8)JL[GF6U'T8-*X)@8PAUZ]=L_J2Q3A=
M"2B&-:9F,><&$E#.L_:09P&@#LH%&V"X)(X8H%RSICDWK&R43)HNB<G[G6?M
M(<^2?,U!N3S#^"PF[\]=+G0W')W!2Z4JOL+<HY"K695R-YPO=9#H&R+G6=.1
M]1\AYB:^?P@=@YA/,7^=^18F:TNR*CE:;\<$('PL.J8TB#63U:IF=2A5$F*C
MBY?)RI'%'&_F=PN1&J;EY2;0ZL::R9K29S']$4#W\;3LL\[.9TG%"U2Q2I_5
MES63U=-G52+6W&<Q^V.?-9_/VJ[E-?=9*[--6#-9$_@L,)*5/LMYUF7G6:L8
M(HZIW^'G6(O(VV?M/,\"/EM"C#DE8/;GWR+[K#WX+*GEY2;08DX2G6==4I[5
MTV<!EQ?W.18O^ZP]^*P<1XS/\G5#^ZRFB$F]3RI>]EF#NN$0UACHF$;)Y%EW
M>GJ3M3%9IY?SGSW+9+4GR[-GF:RF9'GV+)/5E"S/GN6:U=UG7?3L62:K?3?T
M[%DF:^.:==&S9YFL)%F>/<L^:V]YUIG,GF6RNN99%S1[ELEJ1I9GSS)9,^59
M9SM[ELGJ<6Y8V2AW.7N6R>J19UWB[%DFJT<&?XFS9YFLP1'-V<Z>9;)&':SM
M'MC::LLF:SZRI`$$3S@]$D]3E7Z\TY4^D]6,+'"\I0<V'T\_>I?!!SSB/#[K
MO)(CA)C)JB4+/!P><`2HD9X)75FS`'T2:[<@9K(VM`Y@!*3^&*L84[,J*]3Z
M<:I"N69M2%8D`KS%<,14,:9FQ0HEL080<S<<7;-R_1$0(?DL8-REWA<1<\W:
M@"RIG8%U)#1R-4M:1]IYY+],UN`\JW(D(R--T'">-7>>E>LU@!II,AJF+>:Z
ML_.L:?(L"3'0F([*3"&`HQQBX'N9K+YY%A@E0(UT)LC4+-`Q)<2<9^TJSV(B
M2@`=J%D@@\VU/)\;CNZ&N8`49`PQ\Y1J%K@X)/D^YUD3YUFM;FB0?%9$#%P&
M;W8;A,D2EB]EY,&3)^6A!@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M>6%C8V]U
M;G0N<&YG````````````````````````````````````````````````````
M````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-#(`,3`U
M,34T,S$P-C<`,#(R,C$Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P
M``#J8```.I@``!=ODE_%1@```P!03%1%(B(C"@P0Q<;(#!`6YNCK)2@L#!`5
M*"PQ-T96&!XE;W^1?(J9EJ&MH*NWN\;216%^36J'4FZ+3FB#77F5"@T09H*>
M15AK:(2@56R#/4U>67"(;8FE6&Z$<XZJ"0L-8'*%?I6L'2(G9&]ZC9FEB9"7
MU=OAY^KM\O/T3F9]9X.>7'2+;XNF159F=9&L4&-U?)6MB9VPBIZPFJR]I[C'
M;WJ$&1T@D9F?D)B>R=/;"0T/$A05$Q46#1$2$1$0&!@72TA$$PH`&P\!020%
M-A\%FU@/RW49S'8:R'0:T7H=T'H=T7L>Q74<PG,<TWT?Q70=P7,=#@<`"@4`
M"`0`-1P"%0L!)A0",AL#938'1R8%6S$'-1T$-!P$DT\-+!@$I5P0?$4,*1<$
MK&`1BDP.>4,,M603)A4$'1`#OFH5MF84J5\3+1D%@TD/RG(8S'49S78:S'4:
M&`X$+A@#0B,%-!L$,1H$+QD$.A\%638512\:3#HI&A(,)!X:*28FS,S,1$1$
M)24E'1T=!@8&````____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````KX]Z*P```(1T4DY3________
M____________________________________________________________
M____________________________________________________________
M______________________________________________\`E](VO@````EP
M2%ES```+$@``"Q(!TMU^_````+Q)1$%4*,]C:`:!)A``LYH90(1MD[U](%0$
M)-#0:%]7#U1B"Q.P<Z@,"4A+=6Z$"3@Z>?OY^[C'!\$$8B,]O'P]\Y*S8`(E
MF;EN^:XY&:4P@3*7].S0PJ24(KBU$3%AB7$1X<$P`9N:\N*HZ(0*3CF(`*N9
M@4EU016#DHZD)4B`G5=65T^EEDF92T)&3*29P<I<7UI;BUM=S5A!55B#@Y'!
MFD=44UQ*GL7"2)5/55"(C<'44``)\#,S**(!`&EU5,O<[92W`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W-H861O=RYG:68`````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-C<T-0`Q,#4Q-30S,3`V-P`P,C$T-S``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA(`,@
M`\0``/___^?GY_/S\];6UL+"POO[^[*RLO7U]=O;V_S\_/'Q\>#@X-'1T?KZ
M^O;V]NKJZMC8V.WM[<7%Q>CHZ,G)R?W]_?CX^._O[_[^_K6UM;N[N\3$Q/GY
M^0```````````"'Y!```````+``````@`R`#``7_("".9&F>:*JN;.N^<"S/
M=&W?>*[O?.__P*!P2"P:CR_%@9/`()_0J'1*K5JOV*QVR^T.`Y=#H^(MF\_H
MM'K-;KO?941`82'#[_B\?L_O^_]W#`L1#@F`AXB)BHN,C8YE%`@/!X:/EI>8
MF9J;G'@2$!,"!9VDI::GJ*FJ)P0#`:*KL;*SM+6V6ZVOH[>\O;Z_P,$CN;#"
MQL?(R<I_Q+O+S]#1TM-(S=37V-G:VR;6W-_@X>*VWN/FY^CIB^7J[>[O\&7L
M\?3U]O<_\_C[_/W^)?K^"1Q($%W`@@@3*HQV<*'#AQ#)N2H6L:+%BZ<:8MS(
ML:,?C1Y#BAQY!B3)DRA3_T(QJ;*ERY<Y6,*<2;,F"IDV<^ITB7.GSY\>>P(=
M2O2AT*)(D_X[JK2ITWA,GTJ=.BXJU:M8KUG-RK4KLJU>PXJ]!7:LV;.HRJ)=
MRQ:3VK9PXR)Z*[>N73QT[^K=BR8OW[^`L?@-3+APM8G.#"M>+`\QX\>0LPR.
M3+DRB\F6,VL6@7FSY\B=/XM6''JT:<"E3ZN^FWJU:[BM7\L^&WNV;:^U;^N^
MFGNW;Z>]?PLO&GRX<9_%CRNOF7RY<YZ.GTMOVWRZ]9#5KVO'F'V[=XC=OXM/
M&'Z\>8'ESZO?EWZ]>WKMW\MO%W^^?7/U[^O_EG^_?VS]_2<@0]$-:"!W!1ZH
M(/]X"2[H('D-/B@A>A%.:"%[%5ZH(7P9;N@A?1U^*")^(8YH(G\EGJ@B@"FN
MZ"*!NKPHXS8!SFCC'C7>J",<.>[HXQH]_BBD&4$.:20N+1ZI9"E%+NFD%$T^
M*>4144YII1!57JEE#UENZ24.77XIY@QACFFF"V6>J68*::[I)@EMOOEFG'*N
M26>=9]Z)YYAZ[OEEGWYN"6B@5PY*Z)2&'OIDHHHNR6BC1SX*Z9"23OICI9;N
MB&FF-V[*Z8R>?OIBJ**N2&JI)YZ*ZHBJKOIAJZYN"&NL%\Y*ZX2VWOI@KKHN
MR&NO!_X*[(#"#OM?L<;NAVRR]RW+['S./OM>M-*N1VW_M>==B^UXVF[[7;?>
M;@=NN->-2^YTYI[[7+KJ+L=NN\>]"^]P\L[[6[WV[H9OOK?MR^]L_O[[6L`"
MKT9PP:<=C/!H"B_\6<,.;P9QQ)E-3'%E%E\,6I(:S\EQQW9^#'*>(H_,9\DF
M_XERRH*NS'*A+K^,:,PR+TISS8[>C'.D.N],:<\^7PITT)H.372G1A\-:M)*
MC\ITTZ8^#76J4D_-:M56OXIUUK)NS76M7G^-:]AB[TIVV;Z>C7:P:J]-;-MN
M'PMWW,K.37>S=M\-;=YZ3\MWW];^#7BV@@_.;>&&?XMXXN(NSGBYCC^.;N22
MKTMYY>Y>CGF\FF].;^>>WPMZ_^CZCDYZOZ:?#G#JJ@_,>NL&OPY[PK+/SG#M
MMC^,>^X2[\Y[Q;[_CG'PPF\<8_%@'X_\V,HO;W;SSJ<-??1L3T_]V]9?+W?V
MVM?-??=X?P_^WN*/[W?YY@>.?OJ$K\_^X>Z_KWC\\C=.?_V0WX__Y/KO;WG_
M_LL<``/(N0$2\',&/*#H$JC`TC&P@:A[(`17)\$)NJZ"%HP=!C-(NPUR\'8>
M_*#N0BC"WI&PA,`[(0J'I\(5&H\B+G1.QF*(CQG2T!XVO"&'6JA#P^2PA^_X
M(1!!Q,,AHH9X1B0.$I,X%"$RD41%?")KEBC%G3BQBN"X(A:YH<4M:J.+7F11
M%,/(%O\PDG$:9CPCC&"H1A"RL8TC?",<32C'.::PCG9D(1[S^,+$\/&.?ORC
M'@,IR#X64C-I/.0O$JG(7C"RD62A(B0W\LA)TJ*2EI0%)C.YBDUR,A6>_&1&
M)"E*HY"RE`L))2H[H<I5;J*5KLP$+&-YB5G2\A&VO&4C<JG+=9RRE_[@)3#G
M\LMA8FB,QIR),)/YD6(RLQ[+?":.G"E->$2SFGBA)C:)N,=M8N6:WG0#.,/)
MAG&24PWF/&=?M*E.<:2SG8U!)CPY\LYY<J&>]M0"/O,I&';R,QO[_&<5`BK0
M*1"TH%$X*$*?H-"%4LF?#H5&0R-*A(E2%$L0O6@R+*K1?&3_M*/&X"A(>2#2
MD>J@I"8%TT=3Z@N4LK0&+GTIF58J4XG(LZ;WB"E.7Z#3G;:@ISY=`5"#RB::
M$E450SUJ-XRJU%'>M*GJ2"I4.</4J;*RJE9])5:S*LNM<K667OTJ+L,JUEV2
MM:R^?"I:N7C6M1)3K6X%:%OCRHRYTK4/4IUJ7J&ZUZ;V5:E_/6I@B3K8H!;6
MIX?=:6)QNMB:-E:FCWUI9%DZV916UJ27'6EF0;K9CG96HY^]:&@I.MJ(EM:A
MIUUH:A&ZVH*V5J"O_6=L^3G;?-;6GK>=9V[AN=MV]E:=OSUG<,DYW'`6UYO'
MW69RL;G<:C97FL]]9G29.=UD5M>8_]<=9G:!N=U>=E>7W[UE>&DYWEB6UY7G
M765Z4;G>4K97E._]9'PY.=],UM>2]YUD?B&YWT;V5Y'_/62`"SE@01;XCP?F
M8X+SN&`[-GB.#X9CA-LX8356^(P7)F.&P[AA+W9XBQ_&8HBK.&(IEOB))V9B
MBI.X8B.V>(@O!F*,>SAC'=;XAC>F88YCN&,7]GB%/T9AD$LX9!$6^8-'YF"2
M,[AD"S9Y@D^&8)0;.&4%5OF`5R9@E@.X9?]U>7]?QE^8ZS=F^97Y?6=F7YK3
MMV;SM7E\;P9?G+LW9^W5^7IWIEZ>H[=GY_5Y>7]&7J"+-VCA%?IWA^9=HG.W
M:-LU>G:/AO]=I%LW:=55^G27)EVF0[=ISW5Z<Y_&7*@K-VK)E?IQIV9<JA.W
M:L.U>G"O!ERL^S9KO=7Z;K>F6Z[CMFNW]7IMOT9;L,LV;+$5^VO'YEJRL[9L
MJS5[:L^&6K2;-FVE5?MHUR9:MH.V;9]U>V??QEFX:S9NF97[9>=F6;I3MFZ3
MM7MD[P99O#LV;XW5^V+WIEB^([9OA_5[8?]&6,`+-G"!%?Q?!^=7PO.U<'LU
M?%X/AU?$VS5Q=57\7!<G5\;#M7%O=7Q;'\=6R*LU<FF5_%DG9U;*D[5R8[5\
M6"\'5LQ[-7-=U?Q6-Z=5SF.U<U?U?%4_1U702S5T417]4T?G5-+_,[5T2S5]
M4D^'5-0;-75%5?U05R=4U@.U=3]U?4]?QU/8ZS1V.97=8W"]*QKMJG8]G-U-
M;P]9VMLN4;;3_0YQ5U/>23;WNRMC[V8"_,GZ[O>OV+WP;1"\F!2O,L(C7AB,
M]U+D6^;XQP-C\EK"/,PJ;_F6'K[SZ^0\Z",I^M'70O-60OW,2F_Z6:A>2J^W
M&>M;'XO8.\GV.9L][9'Z^=TC2?>^=VHW@Q_5WA/_"KA74O)Y!OSC7[7YSM<J
M]*/?U>E3'ZS6O_Y8LZ]]LW*_^VD=/OC9^OWQOU7\YI=K^=-?U_6S'Z_&?_\0
MEF\D^O_,_?)W>_SS#P3["\G_0H-__(=W__LW@%Q2@`:X`P#H(PM8-`*8@(F'
M@!"H4@\X@>@D@18(4QB8@3-5@1Q()!OX@3#0@#I"@DCC@2+8!29H(RNX-"B8
M@K^'?C#H>2\X@_U4@S9H!2TH(SOH-#B8@U30@RXBA%'S@T`()2%XA*R0A$H(
M$$S8A,/PA%`(`$2H(E5(-48XA49PA2;"A5>3A5I845((A5XH(F6H-6`8AAB5
MAFK8?V/8A&?H(7'8-6S8ACXPAQJ"A\DC@W9H"GIH(7_(/'S8AZ00B!)BB,\S
MB(3("8CH((TH/8JXB)KPB`I"B=43B9+H%F^HA)9H()V(/9B8B9;PB0)"BML3
MBJ+H"*;H'ZOH/?^HF(J,T(KZ(8OA\XJPJ`BT:!^Y2#ZV>(OG1TB^6(B;>(2[
M*!_%>#Z]&(SMEXS*"']UV(P\-8Q`>(SN08WJPXS0J'_/F(V7(8TY:(WJ`8[M
M@XW<2(#;6(Y%=8[HN(3JN(Y.V([N&(7P&(]4Z(TV*([F@8_P0X[T>('S&(_Z
M*!X!.3_\V(^A5Y`&"8+_Z(X#Z1T-:3\(F9!>\)#:09'Y$Y$2>4_V.(,6:1T=
MR3\8F9'ZM)$P^)'289+_$Y(B>8,JN9(Z2)(IB)(R!),B*),"U)(N&80T^8&?
M$`K`F)-\$`F3D``+P``;H`$98`!*N91,V91.^910&952.9546956>97_6)F5
M6KF57-F57OF58!F68CF69%F69GF6:)F6:KF6;-F6;OF63YD!&K`!@D`("1``
M",``%"`!!-"7?OF7@!F8@CF8A%F8AGF8B)F8BKF8C-F8COF8D!F9DCF9E%F9
MEGF9F)F9FKF9G-F9GOF9H!F:HBF8$D`!#"`'=%`!%Q``"X``$#``L!F;LCF;
MM%F;MGF;N)F;NKF;O-F;OOF;P!F<PCF<Q%F<QGF<R)F<RKF<S-F<SOF<T!F=
MTCF=U%F=M0D!"+``8"`&%7``"A`!#S`!`3">Y%F>YGF>Z)F>ZKF>[-F>[OF>
M\!F?\CF?]%F?]GF?^)F?^KF?_-F?_OF?`!J@8@(ZH`1:H`9ZH`B*GA/P`!&@
M!$R``0U@`0YP``)0H19ZH1B:H1JZH1S:H1[ZH2`:HB(ZHB1:HB9ZHBB:HBJZ
MHBS:HB[ZHC`:HS(ZHS1:HS9ZHSB:HSK*H0?@`!;0`$T``"$``#L`````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]S:&%D;W<N<&YG````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8U,3,`,3`U,34T,S$P-C<`,#(Q-3`P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(```,\```#10@$````%-(Q;````"MT15AT0W)E871I;VX@5&EM
M90!4:'4@-2!&96(@,C`P-"`Q,3HR,3HR,B`M,#8P,')J/&8````'=$E-10?4
M`@41%1^O/'5M````"7!(67,```L2```+$@'2W7[\````!&=!34$``+&/"_QA
M!0``#*-)1$%4>-KMVE%JVT`40-'GV(1""'3_.PU.[(YD0S<0W4![SJ!!]I?^
M+F^8\P#`T<YS6NOY"@!'^S4O:\V*SUUX`#C>[[GLX;G->@&`H[W/YWS,%IZ[
M\`!PO+>YKOVZ[<(#P/%>9RO.?L7@Y:>_!8#_P':UX'FO37@`.-[I[W5JX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`.-Y]7[O+G.=UWN9]/:\K0Z>?_C8`_CGWN:WU3,]E?_F:S[G.
M"`\`!]C"<UVE^=J:<UE_W-:/C]DB=!(>`+[=-N)LI?E<Q=DGGJ]]VKG.>>W"
M`\!WVX[8'F=K:^;90K,=L)W7XZ(!`$>Y[8/.?6Z/">=QQ&;:`>`H]WD<N<T?
M^<4^K/A0+:T`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8V]L;W)P:6-K97(N<&YG````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,S<U`#$P-3$U-#,Q,#8W`#`R,C4S,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,```&`4$Q410```)\X4S43'%^@
MAR`U+3*5EA$R,@L2#Y:.<RHG'A(&";NSFS`M(P81$<=H24(C&+36N#Q'/4)K
M;&:JJWS1TRE&1JO/L#-`-;>OE$5!,R(M*@X7%TM=2PT,";"GB:*7=I.*;"TJ
M(1<5$18,"+JPDGIR6["D@7AP6(A_9)V2<^[6@$]'*SPX++ZTE<*YG+RRDK>L
MBK2HA)Z4="8D'#0P)H1[8;^UE[VSE)F/<"$?&&A;35I30;BMB\&XF[ZUEG!H
M4A43#QH8#B,>&AH8$ZB>?Z29>%--/6MD3K*FA,"WFI:+;2XJ(AT;%8J!9WYV
M7/__________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________WE:-^,```"`=%).4___________________________
M____________________________________________________________
M____________________________________________________________
M______________________\`.`5+9P````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"*241!5"@5!<'!20-1`$#!>;L_NT%S#(H$M`ZK"VG%
M'NS!2@2]ZD%74&<Z`P`&%P"<#9<HBI@`FH$)T)B`B6K?/,_5RN!`2YM#Q0"6
MUL^UGX4!+&5YOWU[:A#'7_-=]W\/?0U.E*IT-8!]V]_:9FD`2VO:K`WBIOK&
ML<?A#+Q<OYX^=ID`=KL]X]D_:U$54//2I44`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<F5L;V%D+G!N9P``````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3,S`#$P-3$U-#,Q,#8W`#`R,30U
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q41?____S\
M_?+Y_>_R^./K]='A]%:F[G+&<@*:`Z+:KL_H_L/5][*R_A*>$NKV_J+6SL3A
M^KK>]J[7_2FG-Z+2_EZZ@@```/__________________________________
M_P#>&7X````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``
M"Q,!`)J<&`````=T24U%!]0,%@XE)"N7".<```!T241!5'C:9<_1$@(A"$#1
M3:1E*5%9\_\_-2P<M^F^<5!GW+:_^LKA9H4`$5T^,`S[O5\@`/JE`3O10?QX
M3K#98N0)Z9!L4!P@B,1Q@JL#@(B44NJ$L28;U2$:I%R2JBZP3FT.S)3W\Z7:
MVA<0N=J+"_K/?]\LX`F)*\1V;`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VAO<F1E+7!O=V5R,2YP;F<`````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-3<T-@`Q,#4Q-30S,3`V-P`P,C(U,S8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```%0````?"`(```#VEGTY````"7!(67,``"XC```N(P%XI3]V```+
MF$E$051XVN59:U135Q8^]Y7'S>,2$AY)55X*R&.6%(JA:*:.5A'EH2A4$0@J
M%3L6+)6NL6BU,=):!%3*H!"=U<>X.G6$:D6-'4&75)'J6$>P6&V%01`4)!@@
M(:\[/XYSB2$^9KEFUK3NE1\W^WQGG_.=O<\^^]P+P',L"`"`INGGD3F"H$\$
M[=FSQ]O;V\7%12J5&HW&7Q/_)Y.O/;&?+>I^^V,7D]FT9LT:A]:&AH:*BHK_
M-U;EY>7,\V.F]V3RAA&=UV1,%C`\;<X+6JW6ONFSSSY;L#`N/W_=S)DS>WIZ
MGG'&5ZY<N7+E"A-<C8V-4`D`@,:O7;MF-!J-1B-4MK6U=71TM+6UP::!@0'8
M\>+%BR=.G&#,'C]^_.+%BXRI@8$!V`4`@#]Q3B:SD<0!`"!N%7WJR/V2DI*\
MO#P`@$JE*MFQ[=54(FR:6+W\[(8-&ZJJJIZ%_(8-&V0R67M[>W5U=49&!D51
MI:6E'AX>H:&AAP\?+B@H4*O5>_?N7;5J%451%$4!`#HZ.N+CX]O;VV_<N*'3
MZ3[XX(-MV[:1)#D\/,R8U>ETT/DD28:&AK:TM(2'AWM[>SOQ?&YN;D-#@[W&
M8C7C!```H&1OT!2I2J6:.G5J3$Q,Z<X/%ZYAQ:2S.#S`Y7`6+U[\[.%:45$A
M%`J___[[H:&ARLK*H:&AC(R,FIH:'H^G4JDF3YY<5U=G,IDHBF*SV0"`Y.3D
MS,S,2Y<N413EZ>G9W]^OT^DJ*RM)DF1LNKBX:#2:GIZ>K*PLK5;;T=&1EI;F
M).P3DE_>NZ\R(2$A)"1$K58;C<:U:]=>N](MEF(``)JVIK]OC%LAP(2W?FP[
MJWR/'1U'``".[@42B?OLV;.?G7QJ:BH`0"Z7RV2R18L6R62R\/!PDB3S\_/9
M;'9Z>GIL;"R+Q;ISYTYT=#332RZ7=W5U$02A4"C$8G%*2HJ]Y_5Z?4I*2G!P
M<&AH*``@.#C8R5&W6_-1P8:"M\J$F-6U=I_YAXOW"1:&$(/SEK,CY["P1^P/
MRPA1L'`X^_7?J]7J9V2>D)!PZ-"A_UX6;&QL+"TMW;9M&XSYAXXZJ:<?R<=;
M+YC<_08RMPYOK>8O6(/D[B2CYHTRMY@=+5ZNX]@LB%/F/!Z/Q6*1).FPCQXE
MJU>O?L9\"4?D\_DPMXV=CTJE@LP=$U["_*2[=[O6%[S-$Z*1L]D$:8R8#0#`
M``#&0>*H!ES_AW'$8"6%M'\XF/D:BR=$``#>H5::MJY=NW;'CAT.@XV,C%BM
M5JO5.C@X^#2SCXF)>1;R)I,)CFBSV4PFTU@`#'M[>2B:5V:^V7[K^IZ*W7P7
M)"B2!96W?W#=GMOE*I(H%*].G#CQIY]^.GOF=-.)KM>WDA,"</&XX:35DJJ=
M5?7U]6PVF\OEBD2BN7/GKEJU"D$0&%T$0?P/SG8,P^"(*(H^91<GY>W\1>$W
MVIK?+J=0%%@'W=]9<"LR,M+^Y`0`Q,Z+O=1<]P<-G^^"(@A6MQ^]TV$QC0"3
MD>YN-UN-PO;V=H(@+!8+CN/-S<U>7EY#0T-BL?A1\S`:C4\$P),<QW$'6%]?
M'X_'&QD9D4@D%HN%((ASY\Z%AX?;`]AL-I_/=RAOG>0Q&WI__"0,10&"8)]O
M140BD0-S`,#1VJ.!P1-.?MF?\#J7IJTSEEA'1^KBJM/ZF;\T3<?%Q?7U]5FM
M5HJBHJ*BOOCB"WM3NW;MJJJJZNKJLE@L%$5-G3KUP($#]H"RLC*-1G/KUBV+
MQ0(`8+/99\Z<"0@(```L6;+D[-FS`P,#&(9)))*QEY1ERY8U-#3H=#H41:52
M:6IJZKOOOOL0@K:3DI(2J1<W<Z-`T^3VZ85`3T_/%2M6T,[DC3?>"'B1K&QT
MTS0]^)75N:7FN4_PHSP\/&B:QG'G)X2?GU]W=S<TLG3ITK&;PL?'I[.S$P*4
M2J4#`,.PEI86O5X_<>)$I_8)@FAI:3$8#'"!'MKD.)Z8F`@MCY(WF\U965D3
M`Z0R+^[\Y8(=WX@U36Z?-X5)))+BXF*GY'?OWNWE3U8T2#1-;F4G/6)>\Y2X
M"\>/'[]LV;+>WMZQY.&&A!(1$4'3=%%1D3W&'C!ERA2:IG?MVN4`0!"$P^'H
M]7JY7.ZT(R2OT^D4"H53`(JB&S=NA.0?F`X(];0A0Y$Q1%0L*1"A_XY_`X[C
MK:VM3A?XZM6K'![`<`0`\/<3W+-'[^7FYJI4JK%(@4`0%Q<GE4IK:FI^_OEG
M`,#ERY?KZ^LK*RMA)/-XO/GSYX\?/_[0H4/7KU\'`#0W-Y\\>7+/GCT00))D
M;&PLK$^$0N'ITZ=AN0X`\/7U7;!@P>W;M[_^^FN]7@^I5E=7-S4U,7&4G)S<
MT]-34U,S,#!@L]D^^>23T7G2-.TQ`2\\Z,H$,/SM^T[Z\BO!OKZ^3CT?%.H=
MJ^1#9/2K+T1&1CH`H-,0!,G+RV.4(I$(#IJ4E`3K<P1!LK.S&8"KJRL$Q,?'
M0S""(%E96?:6T]/3(8:B*+/9#)7Y^?DPSW,XG.3D9&;=+URX`#$Y.3D,`'K^
M@9-=7:E/U99/M]!_V4Y_]4>Z\9@)`&"C+6D%2&]O;UQ<G(,SDY*2^OIOSTQA
M`P!H&FG_T<#C\9Q?&U$T(2&!^<MPNW?O'O0JBJ+,7`$`[N[N3(IF``L7+G1(
M[_!!(I$P^T*I5$)N"((P-[SAX>'ITZ<+A4*2)*NJJB!G:'8T[+,SWSMRY(C^
MKOZ^T6@RF;ZMO8&SZ(B9;(+JR=TNV[GN5$!`P*Q9LX*"@EI;6T_6:7MU_\Q2
M<RDQ'(Q>G,.MVG1^\^;-FS=O=GI*V2?7L0"SV?SX`]GA)8K#)F>*G+$`J]5J
M,!@<D,Q)^8!\3DY.3D[.Z-UN76:U9K_W9%PBP[RF]*D."`_O'CCVM_U?U5IY
M0N#W(K)R*9^2C-82P=--BW.H[<7;?7Q\,C(R_M/ZQ#Z?.R7F($Y7D,5B,<]6
MJY6).P1!&#R"("*1:,N6+8^[S^_<_J>O#G]Y\ZI%(L,``'R1>>EZ0-L(LQDG
MB-$+P?V[K+;6D<"7`(N#1"=:]/<$>7EON;JZCMTF3@LR#,,``#:;K;Z^?L:,
M&5#?W_^@1N!RN8_JRVPQ)KP!`%JMUF:S0<("@8!!%A<7LU@LF\UFL]DX'$Y2
M4A*'PWG<FYR/=JY#<4M(%.NA8$,!B_V`.6U#OZOEJ],'_UQH5:>-5.^RW>VT
M1<9@!J/AVK5K3^-MH5#HYN8&W5A>7EY86'C\^/&HJ"CXT@;#L.G3IS,.=)#X
M^'BX<'U]?1$1$;6UM45%186%A9"\2"1*2TN#N6!P<+"RLM+'QV?.G#ESY\Y-
M24EAF#LI<J!$S9+%I)&:)C=-D_L[I;^9%.(R<Y$XZWW)QZ<D,+VGY0;Q>#RE
M4MG;V[M^_?K`P$`W3XHOY"H4"H=LCV&85JMEE+Z^OG#0Y.3D39LV,4&.HJC]
MD>[GY]?;VPN=CV%834V-PPS]_?WM@\B^GE^Y<B5-TT%!0?8`@B`(@@@+"V,L
M."?_[?D3WH'LK7]UW?>=='E>&(_'FS9M6EA8F-A-L"#[P=GV2JQ?2$B(?2^M
M5JM4*@T&`Z.!SD%1]-BQ8XS2Q\<'#CIOWCR:IA4*Q=A-+I%(SIPYT]W=#;<Q
MBJ('#QYTF.3Y\^<]/#S&OHV6R^40<.G2)4]/3P>`O[__$\B_^9:2$F,?5GLF
M+@WG\7BYN;E07UQ<+/-FE]5)-$UN+__.UWX5G0J7R\5QG,OEGCY]FE$&!@;B
M.([C>%)2$M1D9V?+9#(.AT,0!$51<KF\I:6%ING6UE:!0(#C.(?#L5\^1F[>
MO!D='2T2B0B"X'`X,IG,H1+O[.Q4*!00``>%A>/CR'=V=LZ8)><+2(JB2DI*
M[)M\_,6I[_`U36XO3?-EUO@7*LZSO4PFJ_OF7%%1T:1)DQ(3$^V;?AL=>^KP
M@5`YT=6N#YCD_6OX</'TJV4P&*12*451X\:-*RHJ^J5[_KG^5O<\?Z0%_P*G
M[^$/F_*2T@````!)14Y$KD)@@@``````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&]R
M9&4M<&]W97(R+G!N9P``````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,C4U
M`#$P-3$U-#,Q,#8W`#`R,C4S,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````5````!\(`@``
M`/:6?3D````)<$A9<P``+B,``"XC`7BE/W8```A?241!5'C:[5A[3%39&?_N
M8X;APLQUAD&0"@PB&,>W$&0V&8UD6P7EH1A`09?6FL":V$IJ2KK2&*W82!!E
M=1MQS&H,29,FXF---!41'RTE,V$%41Y=(5V-PS(,X`SSNG//](^#M^.=`<6D
M&QKZY?YQ[[F_[SOW=[['_<X!F,-"`(#/YYN+S`F"G,N>)P%@Q8H5<Y=\7U_?
MM6O7YBAYC\=36UL[1\D#0&=GY^#@X(>K/7CPH+>W=ZJW86%A4JF489A'CQ[]
M"!RZNKKPC.'AX5U=73,C'Z:0O'GSIK*R\@-UZNKJLK*R=#K=X<.'@P+<;C?'
M<6ZWVVZW_PCD/1X/GM'E<GD\GIDI?UHP#P#4:K7-9O.]3RHJ*F0RV>3*D61*
M2LK`P(`(0],T`%`4=??N7=]_7SHZ.O",$HG$:#1^H-8D^:-_5M(T"0"EI:73
M*VS9LH6B*`"(3PY+V:#`ZDJELK:V-I`\3=,]/3U.I]-BL4QC\T,`9K/9;#8'
MPBP6B]/I'!L;FXJ\Q6*9RJ.3Y`WMD:L^40#`PH4+I_D(G4Z'\4M3Y/7-:D-[
MY"]^KV3")0`@D\D,!D.@YY.2DE0J%<NR<7%QA86%(H-GSIQ9OGRY2J52*!2Q
ML;$[=NP0`>KKZU>N7(D!"H4B,C*RIZ<'ORHJ*HJ+BV-95J52)2<G8Y?XDR\N
M+HZ/CV=95JE4:K7:X\>/3TG^X!D5#N.3)T\&TK;9;%JM%H-UF]D_/5(;VB/Q
ME;-7`0"AH:&MK:TB\H&2F)AH-ILQ9M>N71*)1`1(2$AX]>H5!I26EHH`%$5U
M=W?;;+;%BQ<'M2^12+J[NYU.YY(E2T2O:)K.R\L+3K[A[Y$+%X4!@%:K%3'O
MZ>F)CX_'_>".SU4";4-[9$-;9&Q2*`"L7KTZ,.S]&TGA/C4UU>?SU=34^&/\
M`=A4?7V]"$`0A$PFL]ELZ>GI014Q^;&QL?7KUP<%D"19557E3WYR`I*"GY9(
MOCX*SY\_5R@4+,O&Q,1LV+!AS9HU!P\>'!H:HFERS^_83[92_I/U?\M_W^\D
M2;*PL#"H*^1R>79V]H(%"YJ:FEZ\>`$`3YX\:6EI:6AH\'J]^*>X=>O6V-C8
MZ]>O]_?W`\#3IT^;FYO/GS^/`0S#9&5E+5NV#``4"D5K:ZO)9,+&%RU:M&W;
MMM>O7]^\>=-FLV&J5Z]>;6]O%^*HH*!@:&BHJ:EI?'P<(73Y\N6C1X^^\XG8
MC5\]5/\D(53D,9Q+(:'TKT\K_7V.+]VF>0`0'1T=M-H3!%%142$,*I5*;#8_
M/Y]E60PH*RL3`"J5"@-R<G(PF""(??OV^5O>LV</QK`LRW$<'CQTZ!!)DKCT
M%!04".MN-!HQYL"!`P(@B.<!0!I"_-80-C8<.OJ#[V4_]!E1?Y?#8><42NFO
MZL+CM93(J^,6].W#"0#(R,@(WD*09&YNKO"H4JE&1T<!P&JU8J^2)"E\*P#,
MGS_?:K4"P,C(B`#8OGV[O\V1D1%\HU:KA;PH+2VMJZM#"!$$,3X^C@<=#H=>
MKQ<4,5ML]C^%P/^!D1.,G(I9!,O28=-N<-@DS__!QRPF%VB";/Z,?T5.!\>R
M[*E3IZ;J(%PNEVAZD7`<-WT/XF\A,,F%)B<0P/.\T^D4(2,B(J8D+Q)&3J1\
M&AR`$#R\X<$[PJBHJ(]NSOSK>5!B(@FZ@E*I5+CG>5Z(.X(@!#Q!$$JE\MBQ
M8Q]*?AKYYQ/^Y7<3-$V7E97-5)>B*%Q*$$(M+2T;-V[$XS@I\(]SFEW#9-*]
M#6\`N'/G#D(($Y;+Y0*RMK96*I4BA!!",IDL/S]?Z$W?V=C,5!Y=1P`0&QM;
M7%P\4UW<KF`WGCMWKKJZ^O;MVSJ=;FAH""^-7J\7'"B2G)P<O'`C(R.IJ:FW
M;MVJJ:FIKJ[&Y)5*Y>[=NW$ML-OM#0T-"0D)FS9MRLS,+"PL%#'_2/)CP\C4
M8@>`M+2TCU"G:;JDI`0'N=5JK:JJRL[.;FMKPR&JT6CV[]\_U<E:<7%Q8F(B
M7CB3R92;FUM966FQ6/#;S9LWY^7E)2<G8X#1:,S(R-!H-!J-)NBGD@`P_(KO
M,WF?_LW;:_(.?<][/>\YTB,I")/3`/#X\6-10?+/3)_/AQTB2M>)B8DC1X[H
M]7K,'R$D%&&U6GWITB6OUXL]+[*`Y<J5*T*5X7D>`PB"2$]/OW#A`@`T-C9&
M1T<+`([C.(Z;F)@(X@8`^")_%"'?VSI!R.=)M&F,/H],6D,%K4$*%5GV1Z:F
MC'OY\F565M:]>_<"*Q#'<1*)A&$883`D)`0')`Z_UM;6\O+R&S=N6*U6GN<9
MAEFZ=.G%BQ>U6FUO;V](2`A"B*9I?PM8TM+2VMK:2DI*GCU[9K?;*8I2J529
MF9D&@T'H$4TFT\Z=.[NZNNQV.U[T0#N3I[<41<ED,IJF$4(.AT/(M\7+PPLK
M)`G+@Q?%.U>\?_ER5"J5GCY]NKR\_'_Q]);`U7+5JE4RF<SK]79V=C8V-MZ_
M?W]P<)#G>8HF\S]7_*Q$$JC,>^'X9XY_]4_$Q,3LW;N789BHJ"B-1J-6J^5R
M>6AH*,NR@35FUI$/6EWJZ^M/G#AA-IL!8.O/Y^65!^'_Y`'WY6_&WCD))TF2
M)&F:IFE:\E8B(B*:FYM%#<:L)H]EW;IU>)_PV1=*?2X=Z/ROC[B^Z^2]7M[M
M0AXWCY#/A\0&29(\>_;L;$N-]Y,'@+5KUW9T=,@8R>'+\NAX*DBWQP//^Q`/
MO!?<+G#:D-L);J?/[0"'W=?TE<OZ@RLW-W>VG8X3!/'^#J^EI24I*6EX>/B;
M"^B7?Z""_OE(BGC;$8,R\AU,GY%X^(UK8&!@]AY=3R,LRQ85%0&`Z;YM^!4_
MTPEBETPV,_!_F57R;W)KNXW"M.S=`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O<VAO=U]P86YE;"YP;F<`````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-C(T`#$P-3$U-#,Q,#8W`#`R,C,T-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`@```)"1:#8```%;241!5'C:E5(]2P-!%'QO=R,Q&%"K]()5
M.$AM(=C9!()@C"'_PH-`D)@+`>$@G('TBM<H6IR-G8WE8;C`-0GW!U($A4BT
MVK5X\>Z,'YA7S<[.O%F&Q9/C(UAD!`!DL[O_5/O^O2#TY/KXBTA*Q1A*J1CG
M2TD0`+"WO[.QN8Z(C#%$O+V^J!NFYWDAHY1"1$2\N3J?)7#.-4T#@&ZW2TRS
MV201'0W#("P`(&3?IN_+J62I6"`#K8\GS`PD!8">.WR=3%?2J8/#.]NVPUVM
M5HN>%QE(G4B(?B]X>9ZLKJ6#(*"MC#$I):5%AIX[?'SH$R90J]5(04\R3?.+
M(3[51L5QG%PN][VER+"UK0'`:?VRVJB4BH5\/E\NE^-]M-OMR*"4&HU&F4RF
MVJC8MAT,/%+\U9(08CP>$WLV\`!`UW6Z0D3+LN9;XISCYQ#3Z71"AA)^-A`[
MQ\1KQ46_]P>."8$-*F#M80````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAO
M<F1E+7!O=V5R,RYP;F<`````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C0T
M-0`Q,#4Q-30S,3`V-P`P,C(U,S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```%0````?"`(`
M``#VEGTY````"7!(67,``"XC```N(P%XI3]V```,UTE$051XVN59:W1459;>
MY]QS'_6N/$@(":0(>9@4(71"8"T8!.Q>+;A:`FTW]`RN'O[H4G%TK6$<$,?I
MI:ZA>T2AP<A#A08%%C,@/L(`&:`U@@^03B9(`GF8%R0AKZI4U:VZM^YS?IQ0
ME#%`1>E??7YDU3W9YYS[[7WVWM_>%^!O>"``>/SQQQUNZYR?%;F2;3]^QW!0
M"OHCX9`LA:.&;@``RQ&K7;"[+>X4.V&91#;I[_9?.',E*JL8X]+2TL<>>^S>
M(T>(T%^AX4CM9\WEB^ZSNRP_;"]=,_I[_#WM@[Z!D"1&544;=9)@Y>PN2WI6
M<L:49.?=M)R6F518FEW_9:MA&)<O7SY__OR<.7/N.7X&`!8N7*@HBA2.AD-R
M>J8[0>/$C][.H;IS+6V-O;[^8%12J<$I9H00_:VI>B0D]W?[>SN'(N&H*]G&
M<N0.>[I2[)*H!GUA7=?[^OK*R\LYCKN'R%]ZZ24$`#4U->^__[XLRP"0G9\^
M<U[>F/@10@AAC#!]-$W3,'594AHO=G0VW]`U@\KP/)^4E)2<G.QRN2P6BZ[K
MHB@.#P\/#0T%@T%=U^ERA]OJ+9^:.37U#N\7&I:^/GU5BB@8XXJ*BH4+%][;
M:X\HC`\^^.#,F3.JJ@)`7G'6]#DY&*-1H@QF.<(3AD4(F::I&6IP./AUS97>
MKD'3-!%"=KL]+R]O^?+E:6EI8YY74U/SV6>?]?7UT8,(RWAG>7*\F:/.NN63
MF.UM'^ZXVH\`.1P.A\,AR[*F:3S/"X(@"`++LAS'"8+`<1PAA&590HC=;L_)
MR1D'>``X<.#`YY]_3BTS?79.P<S)\:(8,P)K=5B3+)P-8VP81C`8.'?F8EM+
MEZ(HA)#\_/S5JU<[G<Z[GOK))Y^</GUZ<'"0/DZ?/;5@YI0Q'!(3@;,*C/U&
M>TA3#%55?3Y?=W>WS^=3596^,W4KAF$00AAC^I?G^25+EMQ___V)!CP`6+5J
M52`0:&AHT#3M2FT'RY.<PHQ;X!$F#&OA;#^?ORP0"-KMMC?>W*I(!B&$$+)@
MP8**BHH$[]NB18O*RLJV;]_>U=5E&$93W36K79B<F_9]%R,,AQ'[Y!-K@H&@
MR^7Z_1]^;[5:`X&`IMV*IJ9ITD>J#@`(A\.7+U^^*W@`^$[(>>JIIUYYY97K
MUZ_KFN'K"\2#!P"$,(-)?]^`)$E21))$11`$M]N]>/'BV;-GC\O?G$[G^O7K
MMVW;UM;69IIF4]WUU/0DN\MBFC1P8(0080AA"&.2P8%!29)T79N:/RDE2YCL
M2Y:CLJ[JFJIKBJYJFJIH2E355%V*1`-#(@#X?+Y$7F-TO*5:Q!AEYT\<DQ:P
M+)$D((0(@I"2DK)@P8*2DI(?%G*>?/+)@P</=G=W`\"--G'ZG!3=T!$`Q@S&
M#&%8GK5BG8R<R+(VAX5W)3M2>#`!88P``8!NZ*JF:JJBJFHH&#YWXINHI(BB
M.&[P7WWUU?#P,`"X4^W):6-YKWGK6J:DI!06%GH\GCLE?UU75540A#'_R[+L
M\N7+SYX]&PZ'3=,`67"Z.80P85B"6<,P>4[@&`%C?#,*,(2U$H9E,"&8U74=
M(8RPJ6I*5)5D)<);.+O3HLBJ+,L-#0U>KW<<X)N;FQ5%`8#4##=#\)@+S)L7
MI+*RLJ6E19(DC\>S;-FR)YYX8I0>=^W:55=7)TE2=G9V147%FC5KX@7.GS__
MUEMOU=;6BJ*($'*Y7)NW;G+94C'"_WOBS\>/57_;VF81!._T(D51*14E#"<(
M'"`X4_WIL8]/MC9_R_%<:5G)+U=43,OW$"8@2I"2[O;U!S5-:VMK&Q_X_OY^
MPS``P)EDO>T*$P!`EN7#AP_3B::FINKJZE.G3NW?O]]BL0#`[MV[UZY=&P@$
M8CH]=>I4=77UH4.'K%8K`+SWWGO///,,O65T"(+`$0MC<B^L_]W^?0=C\Q?.
M7XS]YCF>(\*_K?_=GG?VQ2;_\G7M?QT\LG'3RP_^8I%N:$ZG'6.LZWHB;O\=
M\U*>`P`VA^4VU]BX=?5'4N#(#D>/'MVP80,UZ;///AM#'A.HJJIZ[KGG`*"V
MMG;-FC4QY#1?.)U.J\6RH_*=&/+8PMBP6*Q[WMX70QX3"`9#__+L\Y?^TN3O
MD8;[PQACTS3]?O\XP'_ZZ:?TA5B.$:S<;0B\?C.AP+1IT_;LV5-55?7((X_0
MF3U[]O3V]F[;MBT<#@.`Q^/9O7OWL6/'5JY<207>???=GIZ>'3MVA$(A`)@R
M9<K.G3M/GCQYY,B1+5NV]/</[-KY%I7\^U4K/SAV>._^=^XK+!C1$<MV=_=L
MK]Q)'W_S#RO^I_JC0X?WE\R<0<VVJW)W8%".2CI-^#S/)Q3P#ATZU-C8Z/?[
M;Q(O<CN'IQR6FFO+EBT//_PP`#STT$,E)267+ET*!H/'CQ^OKZ\'`(9A7GOM
M-:J7)4N6M+2T4/?^\,,/+UZ\2.VV:=.F%2M64'>[<.%"75V=W^<'@)^4SMST
MQ_]0=04CG)R:_*NE*Q5%Y3BVONZ;WIX;`%#D+=SXGZ]8K59%UM:M6_>/OUVM
MJFI]?3TAQ&JU9F5E96=G)YKG:VIJJ*L#`&]ALZ9-X'AV3&E-&V'F',>5E97%
MYG-S<R]=N@0`?7U]U.P\S\?7845%1;6UM0#0V]M+S<[S?(P=$$)$41P:&J*/
MA44%BB9'HB*#F;R"'$$0%$7%"`<"`<ID.CNZ%LS[F:'KI@D((<I*15'T>#PS
M9LR8-&E2(F8?`6\8!D)@M0N9.1.FWI=QAZK6-&XY/,T+\>Q@=!D7Q\-B]4R\
M0&P'A-!HTJ9KJA8U,,'Z6"V#<)BJ.'[,F#%CO(R#`,"$2>Z,*2F3/*DVIW`7
M/AQ7@<3HY&@%W9PGY%8J81CF#JLT3=-U/7;[,,8,9@C#8LQ@1*BR#-.4PM$8
M0:`;TMTPQEZOM[*R<KPLBP#`O,7%MW/RT<4&86*V&A,&(81F.T51FIJ:LK*R
MZ'QG9^=()>MP?'\AK57H0@#H:._D60NE]UUMW9(LTSS'<R.V\7@\>_?NM=OM
M+,L:AD$(R<W-C>DW\8$!($'D`$#(K6(^=I/CA]OM+BXNIL9<NW;MN7/GNKJZ
MUJU;]\477P"`Q6*9-V\>#:OQH[.S4U&4W-Q<B]4"`%]^<7[KZ]M#`;FC]?J&
M?_UW):H`0'Y!7EE9F</A`("VMK:C1X^FIZ=[/)Z<G)S\_/P?@'QTGK\[>):A
M#HL0BO?Y>,L__?33-`/7U]<_\,`#145%K[[Z*M74TJ5+R\O+OP^^O;T]$HDX
MG8[EOUQ&8]"F/VR>-VOA@S_]Q>?GOJ0RO_[UKQP.!ZT==5U__?77<W)R)DZ<
M.''BQ%'D\J\%'F-,(Y.JJK'@'!_/`H'`_/GS7WCA!6H*555CD6G6K%E;MVXU
M#(-J+>;DHBAV='2$0B$Q$OKG=?^T<-%(BA)%D=H<8[SAQ76%186#@X.K5Z^>
M/W\^%8A$(L%@,!@,)EC#W;VJN\,P34,WM-345+]_V&:S#0P,1"(12E=M-IO-
M9HL%N9=??MGK]>[:M:NAH4&6Y<S,S,6+%[_XXHM)24G#P\-NMUN69:O52H4_
M^N@C410YCI-4T>)@=OSICP?V_O?QJI/M[9T"SY?,+%ZU^C=EY3^I__IJ*"!F
M9&0</WY\X\:-5555UZY=HY:@OO`#6]?5%P\D8/.13@['6&YT^GT#`;_?GY:6
MMG3ITA_32//Y?)LW;QX:&F(8YN\>+/'D3K;P=HX(A"$(80#3,`Q55[J[;EP\
M>UF2Y(*"@D<???0>MZX3,;NB14,1/V%$!8>_;6L50^'6UE:WVYT(E[I=P;MO
MWSZ?SV>:9DJZ,SG#+D5%58LR#(L1CK78=$-KOM+:U]=/NR#WL(=)`*#UF^N4
MTA*6(2S#$,P0AA?8>(9OFJ9NJ+*J8PVS=A!<<*W+K^OZQQ]_/(K,)3[>?OOM
MUM96PS`XGDR?XP%D:H:J&QK2HC$B9)IFT!]N;[T>C489AKGWX.N__!9CA##"
M&&,&8XPP@ZPV8?9/"T?A-TW=`!T`IGHG]O?Z!GL#HB@>.7)$U_6Y<^>.Z^`W
MWGCCRI4KAF&8IGE?:;8KQ3YR!)A@&M^YGPP(%E8,1'1=/W'B1&9F9EY>WCW[
M:%%65F::8!JFH1NZIFNJKD:UB"C;',+8_1P`0IBD"<Z!'G]44J/1Z-6K5WMZ
M>KQ>;SRKN]UH;&Q\\\TWV]O;:;0OF#FYH&1*S-1C-'PXDC3!,=`S')5569:;
MFYM+2TMCC.C'?K38L6.'HBBJJFJ:IBA*-!H=&AHR#,.99)VW9(;5?MLB(>B/
M_-^YEH'>81H_7"Y7<7'QW+ESQVR;!X/!AH:&LV?/=G=WT\8!0JBH+#M_YI0Q
M^_:C0V-_\*O3C9(8!8",C(SGGW\^P>KE#@'O;_DC+?P_CT4\9+HONJ\`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H
M96QP7VEN9&5X+G!N9P``````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q
M,3$`,3`U,34T,S$P-C<`,#(R,S(P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P````1G04U!``#8Z_4<%*H```,`4$Q41?___P```.;FZ"XO-%97
M67!Q<YZEK[N]P"(G+D5(3%A;7V)E:4%&3$5)3F5I;D1@?D)<>$AD@DUIAT]K
MB5)NC%-OC5-MBEATDF![F&5_FV:`G&N%H5UO@X*8L4507(V@MF-O?)JJO%A@
M:9ZKN:2QOZ^[R3%.:S-0;C)/;#).:SI7=3Q8=#]:=45A?4IB>DE@>%IVDQ8=
M)`T1%5UXE$YE?%-G?$Y?<5EL@#U*5UYQA#I$3FY_D'2%EGJ*FYNMOQT@(V%J
M<ZNZR5MB:4)'3$9+4*JRNDM.48^4F5M>86=J;:ZPLO#Q\N[O\.?HZ<O,S311
M;352;CU9=$U@<7Z/GR\]23,[0BXU.TY672(L-#Y,5T)'2V)F:=WAY$E,3N3G
MZ5UQ>^OM[F!S>^_P\&QY<G%^=X*(=*"A@>[6@$Y.3CP\/"4E)0X.#O___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"ZX=T@````!=%).
M4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T
M24U%!]4*'`8=`5*^]X(```"R241!5"B18V#`!C@880`JD*UH+*8;J*TC8`81
M8724%$Y/3T_5U(^$*,BR,TA+5%=+#S`+!ZM@5)$2X4])3T_6LXAE!0EDRHL+
MQ:>KJ?F;AK&`5#"J2HL*:FFHJ9F$>()U9,A*"/,#%:@%A4:!%;`%V]I86\K(
MF,MQ08Q48N9U<^/D<7;AXX8(.$1[^3(E^23XN4-<9<_(:*6@'!/GS>X!<S@#
MR!,13JYP/A@8,3(:,F`%`$PY&T@J'L"]`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAO<F1E+G!N9P``````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$U,@`Q,#4Q-30S,3`V-P`P,C$S,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`8````?\_]A````!F)+1T0`_P#_`/^@
MO:>3````"7!(67,``"XC```N(P%XI3]V````!W1)344'U`P5#S<ZNAN`C@``
M`?=)1$%4&-.EDTUH$T$8AI_=;OY(5]&#%1KJ0?,CP4,"0BR:1+"]^'OP4`(V
M5EK:BN!-*!)O@MI#$0F(-Z&@AX`MA!:A8$MR,!04;858J!"U\5`5*X9DD\V.
MAT!#9%.0OK>9;^;AXWMF)$"PBR@`)R)N1H=N$PJ%_NNRS^=#!AB\^XMGJ2>F
MAXK%(IJFM87(``=<,K:#[R@4"BW%7"Y'8O(2-Q-]+"XMM@=4*]![SL:CY,/M
M0CJ=9GK^.F,/[%P8KS,W-]M^!C5-T-73P3Y_AAL39Z#23>>A5:Y,.+'88'E!
M(SXXO`.@VA#1'W.@US1*O]=Q[G%B&(*M32BN].`?\;<'V!S2]H;5+B'+$GI-
M8+5+K.8T(J'+.VM<>E'AZYJ,$.!R&P1/6W'NE:G7!?N[9-YF7A,C9@J0`)%,
M)@F'PP!DLUF>ST[1/_(=UQ$%Q0+S3\M(Q?-X/$=1515550D&@P0"@08@G\^W
MMJ4H7!L_RT#B!XY.B9H&&^LZY9*@6A&4M@PVW_<RDWK9T/AO=%TG/G"+Y04-
MBTVB0X'#QRP$(E9.7;1SO,_.EV\?FN_`+-%HE(V/"L)HK(VZX/.:SO3]/\S<
M<S-Z]4YSB*;#D22$:)IYE2KS<^4D0_$QO%YOJP6S9#(9NCUU.A0+U8K@TQLG
MCR>GS"WLYCO_!0N%JOX,%C3<`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-E87)C:"YP;F<`````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,U-P`Q,#4Q-30S,3`V-P`P
M,C$T-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$`
M`+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```
M%V^27\5&```#`%!,5$7V]O?Y^OSU]O@X0U'I[O1I@9Q=<HI$4V1/8'.`F[A\
MEK*#GKN%H+V$G;F(HKZ$G+B)HKY#3UUO@YF%G;>,I+Z-I+V'F[&7K<6$EJJB
MM<K3W>C7X.K7WN;EZ_)!46)"4F,Y1U5OB:1SC:AJ@IMK@IIF?)-=<89@=(EK
M@9B&H;V(H[]SBJ%J?Y5A=(A!3EMPAIQJ?Y2+IL%I?9*-J,-><(*4K,65K,24
MJ\.+G[28K<.7J;N.G["?L<21HK.QP]:KO,VVQ]FOP-&UQM>YR->YQ,_,U^*Y
MPLOG[?/CYNGU]_D]2UAQAYRBMLG4W^G6W.'3V=[R]OG5W.&YN;FQL;&0D)!Z
M>GIW=W=U=75S<W-P<'!O;V]N;FYF9F9>7EY<7%Q;6UM86%A75U=65E924E)0
M4%!/3T])24E#0T,^/CX]/3TZ.CHQ,3$O+R\K*RLI*2DF)B8E)24C(R,:&AH6
M%A8-#0T*"@H)"0D("`@'!P<&!@8%!04$!`0!`0$```"`@(``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!#$+6;````?W123E/_____________________
M____________________________________________________________
M____________________________________________________________
M__________________________\`_^$\"0````EP2%ES```+$P``"Q,!`)J<
M&````,Y)1$%4*,]CJ`.#J/3LVIJ\Y-"Z.@8P/ZE4T,A;6\.K+!XB$%EF8NWF
M)^/#I586"A;(T+/U9_!DD3;E9$\!"^0;N#`%L$C9:8HHY8(%:O4]&-U]'0QY
MS/AK(`(Z@;)2#L9:W)+"M6"!(G4K5R=#+3YS1\5LL$`6LXH8+[>`N+.H?!Q(
M(#RVFD-5PL+&WI*M*@PDD)!36ZJ@*Z3,*E>9"'189&U515%:9F%-;4%2!-#I
M,?E!(<6I=7#`4!(<75M;AR10#N3'(PO$U]8F(?'K`$Z:6T[T>_#+`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9W)O=7`N<&YG````````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,S(U`#$P-3$U-#,Q,#8W`#`R,3,T-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`
M@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410@("104%A86
M&!L;'!05%Q46&,O2W,/'S0X3&@X4&Q$8(!`6'41=>4ED@5-MB6A^EHJ>M("0
MH@T3&0X4&EUYEE1MAUIRBUQTC%-H?5IPAVN!EUEJ?!\E*R,H+8*3I,S4W,W3
MV4YD>6J&H4I=;W*.J8"6JVQ\BUUK>(F;JPX5&XF<K(&1GW)Y?]SBY]WAY"4H
M*LC+S35*31$7%`4+!VBG:2E_*2E^*B=U*"V%+2V!+2Z`+C&',36*-CF2.42-
M1#AN.$]^3R=9)C!B($]R0ADK$!\J#00$`CX\-G-P9ZVIG*FEF"@G).;AT-O6
MQ_#JV8!]=I9I&J!S'M2:/M&-)]:0*=J6+]V8,=*7.TI!-AH.`1(*`:I?"JQ@
M#,1P$[]M$[YM$[YN$[UL$\]Y',YY''$_"HQ.#2L8!&DZ"H1*#;IF$\UV&KQM
M&TA&1"06"1P3"R,8#E-,1@,!``0!`&UK:WIY>6=G9UI:6@4%!0("`@```/__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#,2Q'8`
M``![=%).4___________________________________________________
M____________________________________________________________
M____________________________________________________`)/#J.H`
M```)<$A9<P``"Q(```L2`=+=?OP```"X241!5"C/8ZB"@<I*,,4`XWOZ^'E5
MP@48F1A\_?S\8`+,Y66E%?Y!X7`!M^*2PB+OL%"X0&1V0GRB>TBPGP=4("HI
M.2LV(C``;`A(("TS-2/.U<G9SLJ^$BR0%Y.2'NWB:&)C90D68-$IR,W/,31V
ML+4P!0FPJJFH&[`+BBD:69N9@P3T!92D]72U^$6Y*RO!ALJJBD@HL&G(BW-!
M_2(CQ:>L+2?)RZ,)\YRP,"<GIS"'4!6J;V$``"(2655!M*L:`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C;&]S92YP;F<`````````
M````````````````````````````````````````````````````````,#$P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-#,`,3`U,34T,S$P-C<`
M,#(Q,S$T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```#-03%1%
M!0`''!P<'1T=.3DY5%145555<G)RB(B(CHZ.IJ:FJJJJN[N[Q\?'X^/C_O[^
M____````$)I!C0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,`
M``L3```+$P$`FIP8````!W1)344'U00:$`@+!R[&]P```&E)1$%4>-I=CUD2
M@"`,0UE4L%";^Y_60F49\Y<WZ1+G'#8Y%<I20O<RU`G,/T8,G$`5\0@\$A&>
ME?)("(=V@>:("*D_9`,M0CN(;807N(`<$";0#5D8."<@TL<JT6V@S,=+^LJ,
M:MW_Z[^;TPQ1(OVC1P````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O>F$N<&YG````````````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,C<P`#$P-3$U-#,Q,#8W`#`R,#8Q-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````"0````D"`P```)W_[H,````)4$Q41;H`%F9F9@```(RU
MS$(````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!
M`)J<&`````=T24U%!]0,%!$V"US:6.H````H241!5'C:8V```JU5#`Q2*QD8
MN%8P,+`M86!@6L#`P#@!*-$`DF4``%GG!*=[7+#T`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VQO8VME9"YP;F<`````````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,3,P-@`Q,#4Q-30S,3`V-P`P,C$T-#<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3```!#E!,5$4````$`P(%!`,("`@)"0D+"P<3$0X:
M$PL6%A8<'!P@'1P>'AXO*2$K*RLM+2TN+BXX.#A-34V!6BMR<G*J;RND<39Z
M>GJL<2ZM<S*@=T2C>TN$A(2D?DZH@4RT?CZG@E*G@E.X@#ZJA%6KAUBLAUBZ
MA$*KB%BZAD>\AT:\B$FZB4NOC5ZMC62\BDRPC5^]C$ZED7:^C5";EY3&EEW'
MFV2HHY[*GVBJJJK+I''.I'#-IF[-IG;0IG3,IWO0J'3/JWRQL;'/K'O-K(/.
MK8/4K'G5KG[2LHG5LH38M8R\O+R^OK[6NI3`P,#!P,#"PL+:OIK@PI[APIS@
MQ*#?Q*/AQ*#BQ:'CQJ+2TM+;V]L```![0$@>`````7123E,`0.;89@````%B
M2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!02+`1^
M#@'Y````C'1%6'1#;VUM96YT`$UE;G4M<VEZ960@:6-O;@H]/3T]/3T]/3T]
M"@HH8RD@,C`P,R!*86MU8B`G:FEM;6%C)R!3=&5I;F5R+"`*:'1T<#HO+VII
M;6UA8RYM=7-I8VAA;&PN8WH*"F-R96%T960@=VET:"!T:&4@1TE-4"P*:'1T
M<#HO+W=W=RYG:6UP+F]R9V>*QT<```"9241!5'C:8V#`#B*!`(G++18>$>$I
MS`P7D/82X.04=)"&\?G\6$`4OSE,%Z\/F,7A"Q-@,^)B961DXC%EA]I@$!0<
M[._O[VTM!%$2&>IAIB(OKR"E*0X5"'/5<[>W=[30$($*A-B8*,G(R$BJPE0$
M6NJX.3DYVRI*0`4"7*RTE9759#7DH`)VQH:&6EKZNNJBD0B?00`V?P,``.(=
M%XJG_UT`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V1E;&5T92YP;F<`````````````````````````````
M```````````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,30V-@`Q,#4Q-30S,3`V-P`P,C$T-3<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3```!@%!,5$4````("`@0$`@0$!`8&!`8
M&!@A(1@A(2$I*2$I*2DQ,2DY.2DQ,3$Y.3$Y.3E"0C%"0CE*2CE"0D)*0D)*
M2D)*2DI24D):4DI:6E)C8U)C8UIK8UIK:UIK8V-K:V-S:V-S<V-[<V-[>V-[
M>VM[>W-[>WL`_P"$A'.,C'.,C'N,C(24E(2<G(2<G(R<G)2EG(REI8REI92E
MI9RMK92MK9RUM9R]M9REK:6MK:6UM:V]M:6UM;6]QKW&O:7&QJ7&QJW&QKW6
MUKW&QL;6UL[>WL;>WL[>WM;>WM[GY\[OY\[GY];OY];O[][W[];W[][O[^?W
M]^?W]^__]^__________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________^%HO<^````@'123E/_________________________________
M____________________________________________________________
M____________________________________________________________
M________________`#@%2V<````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````PTE$0508TSW/_0^!8!`'\$OH*2*D%T)D(^\AP^:EH840_Y!_
M73U/N=MNWWU^N-O!-RJJ7"VP@&,T`7K/]^LH`1"@][M.A>%ZT]D,(F"=L[>M
M\;PZLNU0PKZ_`__F[!>[PZJ-H?_XA!7XE[$J1_"5](EW]4ZF7A<07IK)BXU6
M4Y-Y.IW!@"PQCUB*2A6X+('Y1K?THI;3>(;`VC5/ICPL&1)*8.`N%4O\0S>!
M^`HC#)00AJ*"LLES@FD(&L?&SV&B`$C\`53`.ZYX:)DM`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W5S97(N<&YG````````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C,T,@`Q,#4Q-30S,3`V-P`P,C$Q-C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP``
M`"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#
M`%!,5$4B(B,*#!#%QL@,$!;FZ.LE*"P,$!4H+#$W1E88'B5O?Y%\BIF6H:V@
MJ[>[QM)%87Y-:H=2;HM.:(-=>94*#1!F@IY%6&MHA*!5;(,]35Y9<(AMB:58
M;H1SCJH)"PU@<H5^E:P=(B=D;WJ-F:6)D)?5V^'GZNWR\_1.9GUG@YY<=(MO
MBZ9%5F9UD:Q08W5\E:V)G;"*GK":K+VGN,=O>H09'2"1F9^0F)[)T]L)#0\2
M%!43%18-$1(1$1`8&!=+2$03"@`;#P%!)`4V'P6;6`_+=1G,=AK(=!K1>AW0
M>AW1>Q[%=1S"<QS3?1_%=!W!<QT.!P`*!0`(!``U'`(5"P$F%`(R&P-E-@='
M)@5;,0<U'00T'`233PTL&`2E7!!\10PI%P2L8!&*3`YY0PRU9!,F%00=$`.^
M:A6V9A2I7Q,M&06#20_*<AC,=1G-=AK,=1H8#@0N&`-"(P4T&P0Q&@0O&00Z
M'P59-A5%+QI,.BD:$@PD'AHI)B;,S,Q$1$0E)24='1T&!@8```#___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"OCWHK````A'123E/_________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________P"7TC:^````"7!(67,```L2```+$@'2W7[\````
MO$E$050HSV-H!H$F$`"SFAE`A&V3O7T@5`0DT-!H7U</5&(+$[!SJ`P)2$MU
M;H0).#IY^_G[N,<'P01B(SV\?#WSDK-@`B69N6[YKCD9I3"!,I?T[-#"I)0B
MN+41,6&)<1'AP3`!FYKRXJCHA`I..8@`JYF!275!%8.2CJ0E2("=5U973Z66
M29E+0D9,I)G!REQ?6EN+6UW-6$%56(.#D<&:1U137$J>Q<)(E4]54(B-P=10
M``GP,S,HH@$`:754R]SME+<`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6YF
M;RYP;F<`````````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4S
M`#$P-3$U-#,Q,#8W`#`R,3$T,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,````$9T%-00``V.OU'!2J````(&-(4DT``&V8``!SC@``U,\``'L/
M``!X]@``R_(``#*,```C34@19+(```,`4$Q410```/___^CGZ.#?X-C7V):5
MEM_?X-?7V.?HZ-?8V)66EM?8U]C8U]#0SY:6E>CGY]#/SY:5E?#P\.CHZ.#@
MX-C8V-?7U["PL*"@H):6EGY^?FUM;6QL;/___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````,NY=+,````>=%).4___
M____________________________________`.P8'%X````)<$A9<P``"Q(`
M``L2`=+=?OP```!K241!5"C/?8_)#H`P"$11JZV[MBZ@[?__IN"AJ9KXPNG-
M0`+`ARS%BK`IMP!`'FL1HQ`2\5GQ#,<8&Q[1/QLB_ANO&\;ESN1N=(*(A08J
M:29JAJ)B4>MMTYU:E5)KJP'",>V1_F01TM=#N``.&`S4"P>29P````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]L87EO=70N<&YG````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`T-S(`,3`U,34T,S$P-C<`,#(Q-3(V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`@#````*"T/4P```$Y03%1%````H)Z7M[6P
MN+:QY,!!Y<%$Q<3`Z<MBZ]!R[-%U[M>'U];4[MB+V-?5V=C6VMG7V]K8W-O9
MWMW;\^.J].6Q].6S[.SK[>WL\O+Q````<9PG$P````%T4DY3`$#FV&8````!
M8DM'1`"(!1U(````"7!(67,```L2```+$@'2W7[\````!W1)344'U`P($ATZ
M8_WSQP```&5)1$%4>-IUS>$*@"`,1E'32LV:E:;M_5\TE<&PZ/NWR^`(["<$
MCL88N^*=<LYG#2;&&#0FYS:0%*X2<KE!]1_>MV!#F<8#P.\M+'43SE(I-=3P
M8<ECECQFR6.6/&;)8Y:\?_:]!]0]#R=FNP,R`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O<FAA;F0N<&YG````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-#(W`#$P-3$U-#,Q,#8W`#`R,3,P-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````(0````X$`P```%,P:+\````84$Q41?___\#`P+^_OX"`@```_P``@```
M`````%KM>%,````"=%).4_\`Y;<P2@````%B2T=$!F%FN'T````)<$A9<P``
M`$@```!(`$;):SX```"*241!5"B1;<]!"H,P%`300<%U/FC6Y1?^NB20$Z@G
M4->)@;G_$;J(15HZFX&W&0;R$X?6GF3YD@S`6$3$P9,4#P!=-8HXC/.\,@,]
MU0)8FKP`&$ZM"FL2@)X82.I''C!0DPB+P[0L:U1-N6OS#N.V'3%H'L[G)=.^
M'ZR!,,HMXFNDIDL\6?Z]N./>AT0E2TXNFA``````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V]F
M9FEC92YP;F<`````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q
M,0`Q,#4Q-30S,3`V-P`P,C$T,S8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`
MZ0``=3```.I@```ZF```%V^27\5&```#`%!,5$5W=G>6E9:3DI.2D9*"@8*!
M@(%]?7YY>7IX>'ES<W3'Q\C`P,&HJ*FAH:*+BXR*BHM^?W]]?GY\?7US='1K
M;&QA8F*9FIJ3E)2,C8V"@X-]?GUY>GEQ<G%P<7#)RLF6EY:4E92+C(N'B(>&
MAX:`@'][>WJ9F9B.CHV"@H&`?W]]?'Q\>WM[>GJ?GIZ=G)R5E)24DY.3DI*2
MD9&*B8F)B(B(AX>&A87;V]O9V=G/S\_.SL[+R\O*RLK(R,C'Q\?"PL+!P<&\
MO+RTM+2HJ*B@H*"?GY^=G9V;FYN9F9F8F)B7EY>6EI:1D9&0D)"/CX^.CHZ+
MBXN*BHJ'AX>&AH:%A86$A(2#@X.!@8%^?GY]?7U\?'Q[>WMZ>GIY>7EX>'AW
M=W=V=G9U=75S<W-R<G)P<'!N;FYI:6EH:&AF9F9E965@8&````#___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"!!K02````;7123E/_
M____________________________________________________________
M____________________________________________________________
M______________________\`+;;42P````EP2%ES```+$P``"Q,!`)J<&```
M`+I)1$%4*,]CR$$##!`J&PA@`MDH((<AV]P1"++!R-'1.9LAV\(J/<L)#+*`
M-$B`F]O!WH[+5L[&VLK2%2C`+<L9KR,8'JH4H&ZD+PP22$Z(U=*4##:6\#7P
M2@`)),9I"["8F2CZ,7E[Q($$&%2EPD.#`OR9%3S=I4$"[%$J8<J!$K[B\F)N
M,2"!Z`B-$!,^/T-&-3T7(9!`)&NH*;^_#U"#+F\$4(!'-#,C3215)BF!0X<M
M)1O3+^C>!P`B(4Q>NK[7G`````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9&%T871R964N<&YG````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-38V`#$P-3$U-#,Q,#8W`#`R,C`P-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(!@```!_S_V$````&8DM'1````````/E#
MNW\```$K241!5#A/I9([:L-`%$6U&O>ILHB09`.!-")@2&\"(4U:@Y1"@J`_
M$>I490<JO!#WUO__>\D;&,_8D@NC@5.)<^^=08(@"+`0`=[E'WC:2%=Q__+!
M`I[?)+A;?U[%[:/(`O#T?7^1KNN@;5MHFH90516XKCL-\'W_1/S^__;[M3[*
M=5T3N2Q+L&U[/H!"`Y!S.<]S<!QG/F!N,B\710%9EEU>P,N\>//P2L#V-$U!
M5=7Y@#FP%=\"`[`]21*0)(D%C.,XF8PBG8RM*&(SRE$4@2S++&`8ALEDVDSE
MU69%B.,8PC"$[7;+`G#^^4/Q5\!F&H#MA\/A-`!E?B:=BFTH8"-*/(JBL(#]
M?@]!$,!NMR-XG@>F:1(,PP!=UPF:IH%E64061>Y77LBR\P>+KY)@9/";Z0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5D:70M<VUA;&PN<&YG````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#0T,``Q,#4Q-30S,3`V-P`P,C(R,S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````D````)"`,```#73_8B````8%!,5$7FYN;XV3A/015E7#Y<3ROQM4WV
MM$37KG3\Z3Q+2TM(2$A%145#0T-`0$`Y.3DT-#0Q,3$N+BXM+2TL+"PI*2G_
M__\```````````````````````````````````````#^$])"`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?5!PX('RPM2;_:````.4E$050(UV-@``-.3DXH@X.5'\S@XF!C!K.X80P>
M1C9F`1"#EY&511"LB(^=61BBC4E(!&82A&8``#M4`5)1:\F]`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]R
M97%U:7)E9"YP;F<`````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R
M,S``,3`U,34T,S$P-C<`,#(R,#(Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````*````"@$#
M````M_Q=_@````903%1%M0``````[V`["0````)T4DY3_P#EMS!*`````6)+
M1T0!_P(MW@````EP2%ES````2````$@`1LEK/@```!U)1$%4"-=C^'^`X3,8
M37)@:'!@>'@`A,Z`T?\#`-S_#M'`<*PM`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6YF;U]I8V]N+G!N
M9P``````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#`Q`#$P-3$U-#,Q
M,#8W`#`R,C$T,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```#`
M4$Q410````P3&A0;(Q4;(QPC*R,X33)&7"]+9S!+9S-/;#1/;#52<#E6=$18
M;#U:>$!;>$I:;4)>?$9B@$IFA$MF@TYJB%5MAU-OC51OC%=SD5MWE65VB5]X
MDF!XD5][F6-_G6=_FFB#H6R'I6Z'H7>&EGV*F(&6K8"8LX>;KI:HO9BJO9FL
MP)RLO:*RPZ6TQJ:UR+"]SO______________________________________
M_____________________Z9W*WL```!`=%).4_______________________
M____________________________________________________________
M_P#">[%$`````6)+1T0_/F,P=0````EP2%ES````2````$@`1LEK/@```(Y)
M1$%4&--UCU<.PC`01(<2FDWHA(02>@EU3I#[WXK=C2A"8CXLO;=C>8W\)RA.
MRT=@FYU/^S9>HGH_K%?I(IE4"H&',)G$T5`IQU3G9!R-!C6HR*ROW.^8N`F3
M%.Z%)JXZ)Y6]B8OV2>66B=U&[I/"+H`]>UP*D]XU4"Q6GL^T[^JE]^K=<>B;
M`?Y_[CM/A@TEPT"5T_L`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9&]W;FQO
M860N<&YG````````````````````````````````````````````````````
M`````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S<S`#$P
M-3$U-#,Q,#8W`#`R,C`R,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=
MXE(````P4$Q418```````/\``']_?\#`P/___P"```#_`/______________
M_________________]88PML````)=%).4___________`%-/>!(````!8DM'
M1`\8N@#9````"7!(67,```!(````2`!&R6L^````3TE$050(UV/HZ.AH8`02
M#""&(BY&`X.B($2$24D"1<K8V%C8V-B"H=D%#`P93$-!(-B0P03$=RN&,ER<
M@0QC$``QP&J`#&,(D&!H%`2##@#CYRHZJ'QM40````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQO9V]U="YP;F<`````````
M```````````````````````````````````````````````````````P,3`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<T-P`Q,#4Q-30S,3`V-P`P
M,C$U,C<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````P%!,5$4`
M```.$0P7'14=)1L@*1HJ-28Q/2PT02\Y1S-"5#U)7$)15$];6UI/9$A3:4Q<
M8%EL;&IY>7=@@4B(``"9``"9.2FB$@RP%@JQ&Q"J/RRQ33:S4S[(/BO?0A[D
M8D7G=5N-C8N9F9BHJ*:XN+;`P+W)R<?0T,W5U=+@X-[BXN``````````````
M````````````````````````````````````````````````````````````
M``````````````":P#W"````*W123E/_____________________________
M__________________________\`(\FGT`````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```")241!5!C3=<_1$H(@$(7AHT:9E2:4I96":%CO
M_X#MDFG33/\%#-\%"WC^A/<Z]8&'ZUH]`>T$ULQ0P[F>(&#@F@ON'@*&FKI5
ML*U!&'HX4><C\BVBA8<#I2KL#81@N!:%4B5XBEB.E]+9CQ4Q@902)08"/0,P
M]&:#U3H9'Q;!9HB379KBW^>^>@'.J1531Y@N@`````!)14Y$KD)@@@``````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:RYP;F<`````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(Q-C``,3`U,34T,S$P-C<`,#(Q,C<W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@
M8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!0
M3%1%%Q\6%1P4'24<5V]3H[:@7798<8]K<(YJ;HMH;8IG7WA:7G=98'E;A9Z`
M@IA^9(!>8WY=46=,;HMG87M;6'!36G)5:H9D7'17;8-HAIZ!H;.=#1$,8WY<
M98!>4FA,:85B:(1A9'Y=87I::X=D:H9C:(-A9X)@6W-5;8EF;(AE:81B9X%@
M:8-B<HIL>(YR?(]WAIJ!A9F`C:&(DZ:.G*R8G*N8&B$86G%3'",:@)1ZB9Z#
MAYJ!C:"'CZ")GZV:H*Z;FZF5!PD&$A80````____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````-TUW-@```$5T4DY3____________________________________
M______________________________________________________\`LNZQ
M.`````EP2%ES```+$P``"Q,!`)J<&````(E)1$%4*,]C<$$##,0)2(.`L[,S
M7(#1SMK&R%@"*@"4,#,0T%%5$'$&L1F<31V<F0SYU;3$1)V=I5B<&9SM]6SY
M9/@5M#0UA'@EN8$")DIRYHJR6BH:PJP\;#Q``4M!9PM=;2UE#G%G9U:@"K!!
M5EKRG.Q<$$-!5CGIJW-S<3,CW.$(`L@.(\US`**0-\]!9$BP`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1E=F5L
M+G!N9P``````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$P-@`Q
M,#4Q-30S,3`V-P`P,C$S,#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``
M=3```.I@```ZF```%V^27\5&```#`%!,5$46%A1)24,8&!;FYN2RLK#N[NU=
M7%6(AX&1D(JPKZFVM:]"03R)B(-V=&MM:V.0CH996%2=G)A@7E=E8UR7E8Z?
MG98H)R2`?71#0C^3D8NKJ:/5U-%(1D$V-#`A(!Z,BXG?WMS=W-H*"0CN[NX`
M``#___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````";5_"U````)G123E/_____
M____________________________________________`*=Z@;P````)<$A9
M<P``"Q,```L3`0":G!@```!^241!5"C/;8_)#L(P$$,#92T-E(0A+%/6-___
MBUR2*@)\L639LNWL"RXS4`E@/#'(`N\9*LH2LK!?B<CND)02$>E#EWR.@$HX
M'0?9*I@S8]Y*?WM-FQ0#Q=$-[OZ(V6'&.K7-]1S'VO8B*7F_*"W0HUZ90+5T
M4RW]_?+O[8@/LHL?J"2](@``````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O=V5B<VET92YP;F<`````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-#`T`#$P-3$U-#,Q,#8W`#`R,38U,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````
M(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`
M4$Q410```0<-%`H?-081'!`J1!@X6!8S41H]7PT>+Q@V508-%!T^8"!"9"5&
M9A@J/"]1<ATE+3]%2SL^06EL;R-$8RA,;1PU3"E):"]5=PT7(#)6=C-5<SYC
MACY=>4QPD4ELBT1B?TYOCAXG+WV7KC-8>"U,9SYDA#YC@TIPD%B!HEMZE5Y]
MEWV<M1TC*)"JOXZGO$!+5,;2W`,,$P4*#DUUE6&(IV*"FWN?NW^COXBJQ'F7
MKX&AN82DO(&@MX">MGV:L8VMQ8"<LHFGO8NGO3E#2YFTR)NVRIFRQIVWRIVV
MR9^WRJ>_T:&XRJ_$U*N_SRXR-<C8Y,?6XLW<Z`<*#!$8'2DV/X&CNY>XT)2U
MS)>XSWV8JY*PQ%UP?8VHNZ&]T9NVR4-/5ZS*WC0]0ZW%UJW%U:K"TJG!T;S5
MYZ2YR*_%U;S2X<+7YKO0WCI`1,#1W<O<Z,;7X\76XDI05-CE[MGE[=CD[*^X
MOK:_Q=;@YU!356F&F:O(V[+/XJ*\S:6^SK_9Z:[%T[O2X+[3X,?<Z<38Y,C;
MY\;8X\C9Y,[?ZMSI\;O1WM+>Y7Z%B3<]0)NHK]7D[$-%1E=>808)"@```/__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````&69\U$```"5=%).4___________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________________\`-F0;.`````EP2%ES
M```+$P``"Q,!`)J<&````,U)1$%4*,]CF((&&$"$R\3*"4*"2G"!7.&RDL[\
MP'+_$(A`;T]%?W-V2VFQ8<(DD$!H47=[4WUZ5F%`4(8N2,"@+R^NNB:QL<#7
M+R5F,E`@2=G.(2(\LJ,MIR$^B@$H(.#L%&9N8=G:E5FGIP@2D)3S3+8QU=2Q
M]_9RY`=ID91W3TNU-=&0\7'5Y@0)&(N9>=1JJ:E+Q$;+,H,$IC"*N^E+JTB)
M6EDS,8`=-IFK2H&'5X1;E6_R9(C3)P=SL+&SLAB!^!#/39D,!@C?(@,`OA9G
M/:GA:TH`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P<FEN
M="YP;F<`````````````````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,38`
M,3`U,34T,S$P-C<`,#(Q,S0Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```1U03%1%````&QL;34M'3TU)4$U)44]+44],4E!,5%%.5%).85Y9
M86!>:VIG;6UL;VYK<&]L=75U?WY[?WY\@'Y\@']\@8!^B8>%B8B%B(B(C8V-
MCHZ.D)"0DI*2DY*1E)*0E).0EI:6FYJ8GIV<GYZ;GIZ>IJ:DIZ>GJ*BHJZJG
MJZNJK*RIKJVJKZZLL*ZLLK"ML;&NL[&OL[*PM+2TN;BUO+N[O+R\OKZ]P+^\
MPL+"Q<7%Q\;&Q\?'R\K)S\W-SL[.S\_/T='1T]/3UM32V-?4U]?7V=C6V=G8
MVMG7VMK9V]O9V]O;W=O:W-S:W-S;W=S;WMW<WMW=W][=XN+BY>7DZ>GIZ^OK
M[.SL[N[N]/3S]_?W^/CX^OKZ^_O[____````)[,>1@````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L1```+$0%_9%^1````!W1)344'U`P(
M$BD($`!1L````*I)1$%4>-IC8,`&XF``QH^%@K`XF("THZ.4@K6U"UP@-`0(
M0D.]X`(24E*A`D9&"(%0"$`(2(>&JJBKJ=E#!.),-.U,0<"25P8D$F<1$QL=
M&QT3$QT58:8,%(F+C@R6#'<(\O#W<3;48P0*6#EY^P8$^KEYNKN*RH-4V"IQ
M<7"RLK,P,;/)@@5LS(T-]'5TM50UM'4400)RPF+B(B)"@D+\?#S<<<A^!?L7
M`*0(,2F/S@[2`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]H96QP+G!N9P``````````````````````````````````````````````
M````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(S,38`,3`U,34T,S$P-C<`,#(Q,30P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y
M_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````____'1T</#P[
M?GUWM+.MW=S6\O'KX>#:U-//T,_+R\K&R,?#\_+N\O'M[.OGY./?V-?3?GQU
MP+ZW=7-NAH-]L:ZH\_#JY^3>45!.9&-AW=O8A(%]MK.OV-71]?+N[>KFZ.7A
MXM_;96%<6552Y^+>\N[KZN;C=G-QU-'/RL?%NK>U\.WK].GC"`8%R;NT+BPK
M.SDXIHZ%\-+']./=9$Y'W+RQZ,F_RE4UZ6Q*Z714XX%FXXQTDUU.[I=_K7AH
M[JB5\*J7X;.FX[JNV;FPJ#09WTDFS$@IY%$OWU$PS$LMZ&%!UV-(Q&)+T&M3
MTVY6ZGMAR'5AFUM,UI.#TY."Z**1\:F8WJ&19%51YN+AD2T6J#4;;R,2E#`9
MU$DIND0ID#\MUGUI[9%\Z+&E`0``"PH*14)"'QX>#`P,____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````&&B<[````&IT
M4DY3________________________________________________________
M____________________________________________________________
M________________________`+SDW.,````)<$A9<P``"X8```N&`4$'9;<`
M``#"241!5"C/8\AD8``B$,@`,2%80XZ/74);*A7(!,N'&BL**/(KV+@R9()A
MLF.B/JLPA[F'6TP*4`V39)A/;$0Z@V1"@+>7J0%02V1XO"'0H$P&WR0G99`9
M?%Q&AID@8*BK)`H2$-<48P`+,/`*BH`$5*6YH2ITM,`"VNK.06`S0EQDF8$"
MJ9+65G:!0(<&^[O;IF6`W!'M:>F@)F_B%Q<5Q0!Q:8R%&1LGCSV(#Q;08Y"4
M$6+14`%S(;Z!>!?JTTPT``!&\3>*6Y.B]@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H96QL+G!N9P``````````````
M```````````````````````````````````````````````````P,3`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<S-``Q,#4Q-30S,3`V-P`P,C$S
M,C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````P%!,5$7\_OQ<
MLOQ,KOR4CJ04BNQ$=J04=MPT;KP\:K0T:KPL:K0\7J1$7FP\7G0T7G0T6G0L
M4H0T3GQ$2F1,2DP\2EPD2IP<2IP<2I0\1EP<2H0,1HP</G0D.EPD-E0$.F0,
M+E04*E0,*E0$*DP,)DP,)E0,)D0$(D0```#___\`````````````````````
M````````````````````````````````````````````````````````````
M``````````!V=%24````*7123E/_________________________________
M____________________`%+T((<````!8DM'1#\^8S!U````"7!(67,```!(
M````2`!&R6L^````@$E$0508TUV/BQ*"(!!%KY;2P^RQEJ6DU/KZ_R\,U[#D
MP#++G3/+@,$#57Z;US7O!A2[[1>EU.;1(EX[@C!8[3M$1\<A39,3(^O_X1KW
MG@"R/<;`O&P`(MBKI&)@L@F3D3E#%#:_&:*(X;UR6036.#^UUF/)63+>IN%F
MWMS"__X'6+$;U2?4JQL`````245.1*Y"8((`````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E9&ET+G!N9P``````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$S-C4`,3`U,34T,S$P-C<`,#(Q,30P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```8!03%1%1D9%_.D\^-DX3T$595P^
M7$\K\;5-]K1$UZYT_O[^_?W]^_O[\?'Q[N[N[.SLZNKJZ.CHYN;FY>7EXN+B
MS,S,RLK*Q,3$P<'!O;V]N[N[IZ>GA86%@("`?GY^?7U]?'Q\>GIZ>7EY=G9V
M=75U<W-S<'!P;6UM:VMK965E8V-C7EY>65E96%A845%134U-2TM+2DI*24E)
M2$A(145%0T-#0$!`/3T]/#P\.3DY-C8V-#0T,3$Q+R\O+BXN+2TM+"PL*RLK
M*BHJ*2DI)24E(R,C(2$A'1T=&1D9%Q<7%145$A(2$1$1#P\/#`P,"PL+"0D)
M!@8&____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````]I&F_P```%)T4DY3________________________________
M____________________________________________________________
M________________`*TM#'$````!8DM'1'](OW'E````"7!(67,```!(````
M2`!&R6L^````L$E$0508&07!O2X$`1@`P/E^K+U"H7$EE0B%1$$0#^&U"4(B
MD2L5.H50[&V<F(E;]R(S,N($VOTGB$6_'2&EJJK*^OE:H24CDUZ^?U0=M&*"
M=?R>OFQMM62!*>>SIV%3+<4$T^'CL#E?M@BC:;3_.&PN]K1D+>;#A_Z[;%+*
M<1RCAK^K5=&"-<=WU_VTG;02V_-0-\]"TEK,YM<(%*T("")IM1,0B.]=;3E&
M1F1D1@3_[NPI6*[)+;L`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]K97EB;V%R9"YP;F<`````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`T,#$`,3`U,34T,S$P-C<`,#(R,#`Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`0#````[=WB4@```!Y03%1%``````#__P``
M@("`H*"@_\#`W-S<P/______````:ZQ_]0````%T4DY3`$#FV&8````!8DM'
M1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$Q(KE=A-
MZ@```%Q)1$%4>-IC8&#@G`D"#$"&NH2&4"6((52AH2[)`!:?6M'),%&PHTEI
MDI(FA#$]`BHRHPBJ!J1]1AH8>#),:P$#(,,%!#R`C`X/(.B`B;B`U'0``5!J
M"D3$$FX.`.IO,6]W<W?K`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9F%V:6-O;BYI8V\`````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,3<V`#$P-3$U-#,Q,#8W`#`R,38R-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````$``0`0$````0`@`&@$
M```6````*````!`````@`````0`@````````````(RX``",N````````````
M`````/\```#_````_P```/\```#_````_P```/\```#_````_P```/\```#_
M````_P```/\```#_````_P```/\```#_V-C8_]C8V/_8V-C_V-C8_]C8V/^A
MH:'_#GQ@_Q;7IO\5SZ#_&$U`_]C8V/_8V-C_V-C8_]C8V/\```#_````_]C8
MV/_8V-C_V-C8_]C8V/_8V-C_WM[>_Q%61?\6TZ/_%M.C_PU_8O])4E#_L;&Q
M_]C8V/_8V-C_````_P```/_8V-C_V-C8_]C8V/_8V-C_V-C8_]W=W?\15T;_
M%M.C_Q7+G?\5SJ#_$K*)_PMI4?\Z3TK_FIN:_P```/\```#_V-C8_]C8V/_8
MV-C_V-C8_]C8V/^=G9W_#7YA_Q;5I/\5RYW_%M&B_Q;8I_\7X*W_%<>:_QP[
M,_\```#_````_]C8V/_8V-C_V-C8_]C8V/_<W-S_)T4^_Q3"EO\5SI__%<>:
M_Q&D?_\0F7;_#Y%P_PV"9?]'5%#_````_P```/^5E97_T]/3_]/3T_^7EY?_
M)D@__Q*MA?\6T:'_%M:E_PUW7/]:75W_@X.#_Y"0D/^=G9W_S\_/_P```/\`
M``#_#H-E_Q!=2?\07$C_#H%D_Q3"EO\6T:'_%="@_Q&E?_]&44[_V-C8_]C8
MV/_8V-C_V-C8_]C8V/\```#_````_Q;4I/\6U*3_%M2D_Q;6I?\6T*'_%<N=
M_Q;3H_\/CFW_?GY^_]C8V/_8V-C_V-C8_]C8V/_8V-C_````_P```/\5RYW_
M%<N=_Q;3H_\5SI__%,"4_Q;.G_\5SZ#_%<69_RI&/__8V-C_V-C8_]C8V/_8
MV-C_V-C8_P```/\```#_%M&B_Q7.G_\->5W_'%%$_S=)1/\+:%#_%M&B_Q;:
MJ/\,<UG_K:VM_]C8V/_8V-C_V-C8_]C8V/\```#_````_Q?8I_\2L(C_2DY,
M_]C8V/_8V-C_C(R,_PM81?\6TZ/_$[>._TE/3O_8V-C_V-C8_]C8V/_8V-C_
M````_P```/\7X*W_"V1._[FYN?_8V-C_V-C8_]C8V/^AH:'_#DD[_Q9.0/^8
MF9C_V-C8_]C8V/_8V-C_V-C8_P```/\```#_%<27_SI,1__8V-C_V-C8_]C8
MV/_8V-C_V-C8_[Z^OO_1T='_V-C8_]C8V/_8V-C_V-C8_]C8V/\```#_````
M_R4_.?^@H*#_V-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_
MV-C8_]C8V/_8V-C_````_P```/\```#_````_P```/\```#_````_P```/\`
M``#_````_P```/\```#_````_P```/\```#_````_P```/\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&%N:RYG:68`````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P-3(`,3`U,34T,S$P
M-C<`,#(Q,C4S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y80$``0"```````#___\A^00!```!`"P``````0`!`$`"
M`4P`.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9&%T82YP;F<`````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C`W`#$P-3$U-#,Q,#8W`#`R,3$Q-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,```$L4$Q410````$!`0(#
M`P,$!`,$!04%!08'"`<'!PH)"`D*"@H*"@L+"Q86%!@8%B$@'B@G)"$V2#8T
M,$-"/TA&03I,6TE)0UE85$E@<DQ@;5U<56!>5T]D=5EC;65C7%1I?&UK8W)R
M<'9T:VMX@F=[BX!]=(B'@8F(@XR+B<=T9L=T9XR,C,=U:,AV:)".AI"0D).1
MBW^:KK>'?H&:KI>5CH.>LH2@M<V&>LB*@)^=EIV=G8:DN8FFO*&AH=&/A(RH
MO=&0A(VIOM.1AJNIH["OJ:BQO;:UK[:VMKJYMJZ_S<#`P,7%Q<C'PK_+ULW-
MS<?/VK_5Z,K6W]74T=;6UM?7U\O=Z\_@[=_>W-OG\>;FY.;FYNOKZ^[N[O'Q
M\?+R\O3T]/?X^OGY^?S\_/[^_@```')J$C`````!=%).4P!`YMAF`````6)+
M1T0`B`4=2`````EP2%ES```+$@``"Q(!TMU^_`````=T24U%!]0,"!(G!?`R
M`(,```#4241!5'C:8V!(1@$,#,GQ(>:V8&!OZ^COG\R0'.Y@J*T)!!J:.F8.
M<D"!4(?@)"A(,)6&"$!!4(R1.$)%8EP4(R.C.%R%&Q>7):L[LPA8(#HI*99;
M2X%;V$*8114DX!'@Y\/I[6IA8:%KK`(2<+`V,%)FL[`0DU)3400)V+EX,3(*
M6T@)\0M:R(,$3+V\DM5=+<3X.'@C0%JLC+Q\DYF$+=0$>=3#9!F2E4R,?",%
M)+B<55PC`O5E@;Z3D;;QU&-W=;)045%4E&1@@/E?+%E843A9%`"Q]3V#,(]Z
MVP````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O861M:6YI<W1R871I;VXN<&YG
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-38S`#$P-3$U-#,Q,#8W`#`R
M,S(S-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q410``
M`*VME,Z<,?_.8\;&QH2$A._O[S$Q`)QC`&-C`/__G/__`(0``/\```"<_P``
M_\[.,3$``,Z<````A%-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;
M[U-;[YN4(2\````@=%).4_______________________________________
M__\`7%P;[0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"`
M241!5!C338Y9%L0@"`3;)>."XY(<@/O?,H(^9_JOZ@$-F!D[+,'!;0X8^R^<
MAW5[9;&#P1%>&-;8:XO)'V>"^[5,8^8$8D*<@N&M["#F3(@0OO2'E!-(2[Q%
M*5^.1%%$;6H+*'1"`EIMDI#'/9#T:*W/@SSZ2%J[@GXK'\%8S"]NN`PJ:B0_
M<P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUA<%]E=2YP;F<`````````````````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,30T,0`Q,#4Q-30S,3`V-P`P,C$T-30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3```!@%!,5$4``,<!`<<"`L<"`L@#
M`\<#`\@%!<@&!L@&!LD(",D)"<@,#,H-#<H/#\H0$,@7%\`6%LP8&,T<',,=
M'<X?'\TB(L,F)K`E)<0J*K$G)\XG)\\I*<4L+,8R,K0O+]$Q,=(V-K4W-[$W
M-\8\/+$]/;$Z.M0\/,D[.])`0+-!0;<^/M5&1K-"0M5)2;9*2K9-3:=,3+5-
M3;124J-55;A24ME96:=96:I:6KE=7:=86-IB8KI>7MQG9ZEF9K9G9[EL;*EM
M;:YN;JQU=:UX>+!Z>K-\?+!V=N%W=^)\?-J#@[^'A[&'A[*(B+:5E>>AH>NK
MJ^NQL>BVMN[#P_+7U_3CX_CCX_GDY/?Q\?SR\OS^_O__________________
M____________________________________________________________
M____________________________________________________________
M______________]EOP2D````@'123E/_____________________________
M____________________________________________________________
M____________________________________________________________
M____________________`#@%2V<````!8DM'1'](OW'E````"7!(67,```!(
M````2`!&R6L^````KDE$050H%07!AR)6`0`&T'.1O4)&9LOX94OV=LVDN,9]
MF>_5G2-)LK\X,SG_*TDBR>E(`0:VDT@..Z%KNE_+6B(G;>##??59\WID'+1^
M'/SW/*8OC@K8>ZKKNGYLM6(5-M_^_/SQ\-K@B^_P_R]7+PV,6H#J4N_.%`S;
M@*H$^.:B0%4";,E75"7@4^2VAZH$VH\CN>XV-P0Z#A));F:;H)@X2R))<K>[
MO/3[/$GR#E6O*XP$OAO-`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V=O;V=L92YP;F<`````````````````
M```````````````````````````````````````````````P,3`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(R-P`Q,#4Q-30S,3`V-P`P,C$T-C8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```$L````@"`8```!:?85S````!W1)344'TPD:"`(C
M](A3XP````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M!B1)1$%4:-[M6'],5648?N`"*GB]>N4W>C&T0`.*P!\HA@*9.KUN*A:1DN4H
M'8GI$-9F\D>I25I-U)!F.I<!M6P(&4F[M=Q<6UI3BO[H#[=,^Z%M;5&;*[Z^
MYXMS._=P#DYN;,S.NWT[]Y[SP?GN\SWO\S[O!]AAAQUVV&$'&D0X9A6/0G&+
M8UBO,Q\C48G[PW:B,J0>1T*VXF=XD3KT+R8X^4U/([^C'>FO^]3(:NY&7N=Y
MY)VNQ_RFQ4*(X0565W$$#B`6U7A&`345AX;^I?,/%2"KZ2H\%0>1O#Q-`V7:
M-$1@2OE23&FX@HPO!)(/]&+RX[G#CF%[\`0JT(M)V#K$0#4M1EJSP/AE2P><
MYUYQ40T7QOT_P9(LPLR/>N$NW';3N7$/SE-,&X9!S5)@)>*QH7O+0M^;B*YA
MU@4%0GDV(MOBL.I\$FHX]L5C!>]9S7]A(^*^?1>5VMB^!MX!-V+)]FCDO)>%
MJ=/OQ@A7BKK.J%^I[FE@E4.8@=7D1I&V+G[V/XB(7A0P1L8GJZMI>/)24'"A
M!VZO+QB@BIW(;7'AZUUCL&W]""S@]1,W>B_$X=IJ64^-\T^\A*T=N^$C0!Q'
MJO'RE9/H^:4=U_A=/[>L3%:[>6T[D-[0B.2J%]5ZO9=_5?K*[SF')ZK?O1?/
M*K`FA)=H?^L=#V=[#-JJ(W%PBP,K>>V*@N!:%?@:8$;@3(,[PQ0<6_C&8($J
M<.&^$V,A>`UX('?_;`1$9PC$=,E?/5`?[,`?*!8!+%HT"QF7CT-PC`S#;-Y3
M18;,3ZY\6_]_D=;Q3Z'A9XTD1K"$<&A`Z=_S6A0VO26?+@I%>S^P]-=^L>K[
M.O7BP8+E]3J_3,29#1$X9_:8#.MR0&P(P0_\GC`-'C)HID?^+),@PVZT0E2M
MP"5_A>9F1D;>&S`Q>^\V))T5^HP(>16U,@']8#'="`HR'XC5YCR2@Q0"6.+`
M=T6A6']K/Y;TSN1+984;1+2G8=W%&-Q8Z,!1L^=%3MQ)VE=QT0G%'FK3^?T0
M&9.PS&P^V46P]I3*^:RXW$S7,3_3`N0C]8Q`?,5O`6"169X(E?;G/#A0%RH%
M'QA/X$[&XG!=)%KT++^UH'_*ZA84>`KN@.(ZZ^`,53FY4/F9*<(%,=7\E#8$
MYU"WRD/Q)Q?YXVDT,@73[\"C5EU#3R=^)UAQ44A'T5?U"I31>77]="RIV9Q9
M?6!=2L*'^R2K%X2B='\DUG+C@JN$;HQ11E.]V,(Z4$#IWE-W'E?.G@([>6<W
M'W&WF&:DM=4KF*8$2XI+.L$BL]8NM';9USO0O=F+O^:F(4&97U>'VDRU5BUX
MWU$A])HE?58`6$RW5KE?5BD_N&"58?Y+P4Q--.FI]+TAM2+A??].TQY(U(2B
M.TNY2?C&X9N'F89]XAZ@229QZ1U<)UC_^D!9\0A,<NU/RCRK3D.V8-+S&4QI
MK5[@*>1<6W6XU,O_JK]E>56M#$&8VGJ-VF+=M,J^D4Y?EQ8-HW&*.U@2C@[C
M]-P4Q!)(OYC.KG*265:I2`$^6HG>PBP\I+\?!=G[Q3^YTL]LDRQ0U9"FM(]9
M9"(K,0>URDHF;CTF9B4JJDLQ51I!2V%5$+C+^NHI*R(!X>!NZJ?3SQA!I(\B
M(!P$1[]P@CA0BF)N:XW2V`E;/C<^XHF#2D-=NT.]HFYQ,\GP7?=@!N^WN9#-
MM4H$!VG$F?]Q:TYAU&;)G$:AJ)Y[LE$M<$YG);*/[U9:Q3G&%)!_2U!8];B+
MM`QDG/(X/!4P!)E3NQI7"1CM@F92^=ER?9*5:BW,`.H83T1X2J(U^V7X&#FX
M*MW>9YB.C=I[R6IJ9E6?7!"\YT;@4P(6=%HR=>":N5Q1G2<0$S?5P//4:HKJ
M36DKRST=/,?V4IT@6P291::I'7?WG^_S(4RE/H%A@>%:N"Y:!NJLW#PUQYA:
M/.,*O.E@@6&G$7Q5'(:1F2FEBNZ=;#;HJ-(PZBPS8.R<"OND=O:Q=2PF3B?N
M,D=3.G-J;!"MVNT3K'R2.:9VQF\K9']H,ZO/_U'(65"L#@&D]PKV:.FV"-72
M*(OPO%#>CET$4Y.#59JB+_L^FU6&TUG$+'E%,8Q'-73T[&GML,,..^SPQ]]4
M4XI>\"A>M0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]S879E+G!N9P``````````````````````````
M````````````````````````````````````````,#$P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$P-3(`,3`U,34T,S$P-C<`,#(Q,30R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P```/E03%1%```%$2@U$2PZ$RT\
M&#!"&C%`(39(+3E)+D-3+T96,TE:/D]<26!R3V1U66-M5&E\6&V`6G"";FYN
M7WF):WB">GIZ@(:,@(>/AH:&QW1FQW1GQW5HR'9HD)"0?9>L?IFM?YJNMX=^
M@9JN@YZRA*"US89ZR(J`G)V=AJ2YB::\H:&AT8^$C*B]EZ6PT9"$C:F^TY&&
MG:FPGZFPJ+&]H;;$LK*RN;FYKK_-O[^_P,#`PL+"Q<7%O\O6S<W-Q\_:SL[.
MO]7HRM;?U-34UM;6U]?7R]WKS^#MV^?QYN;FZ^OK[N[N\?'Q\O+R]/3T]_CZ
M^?GY_/S\_O[^````86H!I@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$BLY:2?;+P```*I)1$%4
M>-I5S]46@D`4A>&Q"P-;%&/$#NPZHBC6V/#^#^.`HR[_RV_MFXV0\1="QGU?
M;5EU6SU5-9!QE$M9@981<A4Y3.$@[W360PJ^@:5=,/=;/&^$?(&V!=H'SKI^
M)69G!M/-:FDU8B`WBIA6R&,&[2'`FNQJOB0#"<#IUV#BB'0LJ&-0O#S`S,;W
M38B7L7)RQV`QMO,#SGP7"C;GHIB.)CR!E(O"_W_T`NK@-G<JJ?0U`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]P<FEN="\`````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C<`,#$W,#,W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!R:6YT+W-C<F5E;BYC
M<W,`````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,S,0`Q
M,#4Q-30S,3`V-P`P,C$P,C,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+W!R
M:6YT+W-C<F5E;BYC<W,L=B`Q+C$N,3`N-"`R,#`V+S`S+S$T(#(R.C0S.C4P
M(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*
M("`@(&-O;&]R.B`C,#`P.PI]"F$@>PH@("`@8V]L;W(Z(",P,#`["GT*"B-M
M96YU('L*("`@(&1I<W!L87DZ(&YO;F4["GT*"BYH96%D97)B;W@@>PH@("`@
M8F]R9&5R.B!N;VYE.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C
M9&1D.PI]"BYW:61G970@>PH@("`@8V]L;W(Z(",P,#`["GT*+FAE861E<B![
M"B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*+G-M
M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@
M(V9F9CL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@
M8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["GT*+FET96TP+"`N:71E
M;3$@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C8V-C.PI]"BYS:6=N871U<F4L("YS:6=N871U<F4M9FEX
M960@>PH@("`@8V]L;W(Z(",P,#`["GT*+G1O9V=L97%U;W1E('L*("`@(&1I
M<W!L87DZ(&YO;F4["GT*+G%U;W1E9#$L("YQ=6]T960R+"`N<75O=&5D,RP@
M+G%U;W1E9#0L("YQ=6]T960U('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F]R
M9&5R+6QE9G0M8V]L;W(Z(",P,#`["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VAI+6-O;G1R
M87-T+P``````````````````````````````````````````````````````
M```````````````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,3`V-P`P,C`Q,S8`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O:&DM8V]N=')A<W0O:6YF;RYP:'``````````````````````
M`````````````````````````````````````````#`Q,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#0W`#$P-3$U-#,Q,#8W`#`R,38P,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M)'1H96UE7VYA;64@/2!?*")(:2U#;VYT<F%S="(I.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VAI
M+6-O;G1R87-T+W-C<F5E;BYC<W,`````````````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,S(Q-0`Q,#4Q-30S,3`V-P`P,C(Q,C4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````8F]D>2!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C9F9F9F9F.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z
M(",U,#4P-3`["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z("-C9F-F8F([
M"GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S4P-3`U,#L*
M("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V-F8V9B8CL*?0IA('L*("`@
M(&-O;&]R.B`C,#`P,#`P.PI]"F$Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`P
M,#`["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`P,#`["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F9F9F.PI]"BYH96%D97(@>PH@("`@
M8V]L;W(Z(",P,#`P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F9F9F
M.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(S`P,#`P,#L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-F9F9F9F8["GT*+F-O;G1R;VP@>PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V9F9F9F9CL*?0HN:71E;2!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C9F9F9F9F.PI]"BYB=71T;VX@>PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(S`P,#`P,#L*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L
M:60@(S(R-#L*("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C,C(T.PH@
M("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C8V9C9F)B.PH@("`@8F]R9&5R
M+6QE9G0Z('1H:6X@<V]L:60@(V1E9&5B8CL*?0HN<V5L96-T960@>PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(V4V939D93L*?0HN:71E;3$@>PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V4V939D93L*?0H*+RH@365N=2!S='EL97,N("HO
M"B-M96YU('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(V9F9F9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M,#`P.PI]"B-M96YU(&$@>PH@("`@9&ES<&QA>3H@8FQO8VL["B`@("!W:&ET
M92US<&%C93H@<')E.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T
M:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["B`@("!T97AT
M+61E8V]R871I;VXZ(&YO;F4["B`@("!C;VQO<CH@(S`P,#`P,#L*("`@('!A
M9&1I;F<Z(#-P>#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@,W!X.PI]"B-M
M96YU(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(S8V83L*("`@(&)O<F1E<BUR:6=H=#H@,7!X
M('-O;&ED(",V-F$["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S(R-#L*
M("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S(R-#L*("`@('!A9&1I;F<Z
M(#)P>#L*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8V]L;W(Z(",P,#`P,#`[
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C865A96%E.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED("-E964["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S
M;VQI9"`C965E.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#`P.PH@
M("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`["GT*"B\J(%-I9&5B87(@
M<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F9F9F8["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E=VAI
M=&4O````````````````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S$P-C<`,#$W-C<S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V)L=65W:&ET92]I;F9O+G!H<```````````````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#(P-0`Q,#4Q-30S,3`V-P`P,C$S,S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)L=65W:&ET92]I;F9O+G!H
M<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,T(&UD:G5K:6,@17AP("0*("HO
M"@HD=&AE;65?;F%M92`](%\H(D)L=64@86YD(%=H:71E(BD["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B
M;'5E=VAI=&4O<V-R965N+F-S<P``````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#4U,C<`,3`U,34T,S$P-C<`,#(Q-C<R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1H96UE<R]B;'5E=VAI=&4O<V-R965N+F-S<RQV(#$N,3@N-BXY(#(P
M,#4O,3$O,#(@,3DZ,S(Z,S@@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!F
M;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A
M+"!S86YS+7-E<FEF.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*?0IA('L*("`@
M(&-O;&]R.B`C,S,Y.PI]"BYH96%D97)B;W@@>PH@("`@8F]R9&5R+6-O;&]R
M.B`C-C9A.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C0S9$,T9&
M.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD
M.B`C-C9A.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["GT*
M+FAE861E<B!A('L*("`@(&-O;&]R.B`C9F9F.PI]"BYH96%D97(@83IH;W9E
M<BP@82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z('EE;&QO=SL*("`@('1E
M>'0M9&5C;W)A=&EO;CH@;F]N93L*?0IA+FAE861E<B!["B`@("!B;W)D97(M
M8F]T=&]M.B`P.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E;G0["GT*82YF
M:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0HN;&EG:'0@>PH@("`@8V]L;W(Z
M(",S,S,["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S8V83L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE
M;'9E=&EC82QS86YS+7-E<FEF.PI]"F$N<VUA;&QH96%D97(Z:&]V97(@>PH@
M("`@8V]L;W(Z("-C8V4["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*
M+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(V1D9#L*?0HN=VED9V5T('L*
M("`@(&-O;&]R.B`C,C(T.PI]"@HO*B!&;W)M('-T>6QE<RX@*B\*:6YP=70L
M('-E;&5C="P@=&5X=&%R96$@>PH@("`@9F]N="UF86UI;'DZ($=E;F5V82P@
M07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@
M,3)P>#L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V8S9C-F
M.3L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-CD["GT*:6YP=70Z9F]C=7,L
M('1E>'1A<F5A.F9O8W5S('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!B
M;W)D97(Z(#%P>"!S;VQI9"`C.3EF.PI]"BYB=71T;VXL("YB=71T;VXZ9F]C
M=7,@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,S,Y.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",S,S,["B`@("!B;W)D97(M
M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S
M;VQI9"`C0S1#-$(X.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED("-#-$,T
M0C@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P>#L*?0HN8G5T=&]N.FAO
M=F5R('L*("`@(&)A8VMG<F]U;F0Z(",V-F$["GT*"B\J($%L=&5R;F%T:6YG
M('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN<F]W
M179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0Z("-E964["GT*+G)O=T]D
M9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*"B\J(%9A<FEO
M=7,@<&]P=7`@86YD('-T871U<R!L87EE<G,N("HO"BYT;V]L=&EP+"!D:78N
M;FEC971I=&QE('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@
M(S8V83L*("`@(&)O<F1E<CH@,G!X(&1O=6)L92`C9F9F.PI]"@HO*B!-96YU
M('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K
M9W)O=6YD.B`C-C9A.PH@("`@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED(",P
M,#`["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U
M<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(S,S.3L*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L
M:60@(V%A8SL*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@
M(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X
M.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*8F]D>2YS:61E8F%R('L*("`@
M(&)A8VMG<F]U;F0Z("-F9F8["GT*(W-I9&5B87)086YE;"!["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`V.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED(",P,#8["B`@("!B86-K9W)O=6YD.B`C93EE.69F.PI]"B-S
M:61E8F%R4&%N96P@<W!A;BYT;V=G;&4L("-S:61E8F%R4&%N96P@82!["B`@
M("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I;F<M8F]T=&]M.B`R<'@[
M"GT*(W-I9&5B87)086YE;"!S<&%N+G1O9V=L92!["B`@("!B;W)D97(Z(#%P
M>"!N;VYE('1R86YS<&%R96YT.PI]"B-S:61E8F%R4&%N96P@82!["B`@("!C
M;VQO<CH@(S`P-CL*("`@(&)O<F1E<CH@,7!X('-O;&ED("-E.64Y9F8["GT*
M(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O;&]R.B`C,#`V.PH@("`@
M8F%C:V=R;W5N9#H@(V-C8SL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`[
M"B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*(V5X<&%N9$)U='1O;B![
M"B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*?0H*+RH@5&%B('-T>6QE<RX@*B\*
M+G1A8G-E="!["B`@("!B86-K9W)O=6YD.B!N;VYE.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED(",V-F$["GT*+G1A8G-E="!L:2!A('L*("`@(&)O
M<F1E<CH@,7!X('-O;&ED(",V-F$["B`@("!B;W)D97(M8F]T=&]M+6-O;&]R
M.B`C93EE.64Y.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$@>PH@("`@8F%C
M:V=R;W5N9#H@(S8V83L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED(",V-F$["GT*+G1A8G-E="!L:2YA8W1I=F5486(@
M83IH;W9E<B!["B`@("!B86-K9W)O=6YD.B`C-C9A.PH@("`@8V]L;W(Z("-F
M9F8["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W-I;7!L97@O````````````
M````````````````````````````````````````````````````````````
M```````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,3`V-P`P,3<S-C0`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M<VEM<&QE>"]G<F%P:&EC<R\`````````````````````````````````````
M`````````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`R,3$V-``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X+V=R87!H:6-S+V)A8VMG<F]U;F0N
M<&YG````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-#,`,3`U,34T,S$P-C<`,#(T
M,#`T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````"````!`@`````@82QY0````EP2%ES````
M2````$@`1LEK/@```!5)1$%4"-=C>/:,X>E3AC=O&-Z]`P`K:P=+BZH.C0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O<VEM<&QE>"]I;F9O+G!H<```````````````````````````````
M`````````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,3<U`#$P-3$U-#,Q,#8W`#`R,3`S,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<VEM<&QE>"]I;F9O+G!H<"QV(#$N
M,2`R,#`T+S$P+S$W(#$Y.C,S.C,W(&UD:G5K:6,@17AP("0*("HO"@HD=&AE
M;65?;F%M92`](%\H(E-I;7!L97@B*3L*"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W-I;7!L
M97@O<V-R965N+F-S<P``````````````````````````````````````````
M```````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C$U-0`Q,#4Q-30S,3`V-P`P,C$S-34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=&AE;65S+W-I;7!L97@O<V-R965N+F-S<RQV(#$N."XV+C0@,C`P-2\Q,"\Q
M."`Q,3HS-#HR,2!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U
M;F0Z("-E964@=7)L*&=R87!H:6-S+V)A8VMG<F]U;F0N<&YG*3L*("`@('-C
M<F]L;&)A<BUB87-E+6-O;&]R.B`C-S,Y,&(Y.PI]"FAT;6P@>PH@("`@<V-R
M;VQL8F%R+6)A<V4M8V]L;W(Z(",W,SDP8CD["GT*82!["B`@("!C;VQO<CH@
M(S-C-V%E.3L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C,6(U-V,R.PI]"F$N
M=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"BYH96%D97(@>PH@("`@8V]L
M;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-S,Y,&(Y.PI]"BYH96%D97(@
M82!["B`@("!C;VQO<CH@(V9F9CL*?0HN;&EG:'0@>PH@("`@8V]L;W(Z(",T
M935D-S(["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S<S.3!B.3L*?0HN:71E;2!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C96-E9F8T.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z(",S8S=A
M93D["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9&1D.PH@("`@8F]R9&5R.B`Q
M<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#`@,G!X.PI]"BYB=71T;VXZ
M:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C.3DY.PI]"G-E;&5C="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-SA!
M-$8Q.PH@("`@8V]L;W(Z("-E964["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC
M;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",W,SDP
M8CD["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U
M<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(S4X83)D8SL*?0HC;65N=2!A.FAO
M=F5R('L*("`@(&)A8VMG<F]U;F0Z(",U.&$R9&,["GT*"B\J(%-I9&5B87(@
M<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-E964["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C.3DY.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",Y.3D["GT*(V5X<&%N9$)U
M='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O8V%M;W5F;&%G92\`````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`R
M,#`P-@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C86UO=69L86=E
M+V=R87!H:6-S+P``````````````````````````````````````````````
M````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S$P-C<`,#(Q-C`V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V-A;6]U9FQA9V4O9W)A<&AI8W,O;65N=2YP;F<`````````````
M```````````````````````````````````````P,3`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,#`U,``Q,#4Q-30S,3`V-P`P,C,R-3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```QX````T!`,```#VR_/`````&%!,5$4?+AL21"(I/2)G;$`*
M*1+___________]OCHOX````"7!(67,```!(````2`!&R6L^```/MDE$051X
MVJ6<;8*RO`Z&B[H`.KJ`$5T`"@M`Z?[7=.A'DCMI<7S>TU\CEC;)E8]2ZK@0
MIM1&?PG!;\TY=YRF81AN4VG/H;1[H/:.'[>>U&6[;[L0;^^WJR?N%]:'RRT.
M'\)KZW$)\/4T/7RZ+7U,8^6^O:-VTOVW#H=MKO/$;=PZ'4C&3>P\8FJEUXAC
M;-/,68.L3YY%!J`VC0<9DPRQ]>S,U"#D4G1-,\\TFS4CM*O/EN,Y'75WI$*>
ML<EC2*/G>88T>^[P\,(C`FGR*!>\5Y9)*(E'LO;4;1\W<+L\LNW\U`1R(W%2
MRU_/H6YO]J]BPQK'-FP9E.<:?J-U/`!A*1T`Z<KTXD([/*[DG<*#%2(=HF/Z
M\[O)(U\2K1:2:)/@I_#P1;32BI]WOF$4P9'%6B>P9I-'2+):'ED#^:!PV`EG
M4?_^(3PFGFFSVG97DNV0>32!!`DVXI&TXIYU!`Z0+/*%J(5S:I#$PV\\6F`K
M?UM9GFVZWRX/@!;(OK?#0Q*+1/8#Y`!%8<*D&-K$MD\XMBMOS+^N'1Y1S>CL
M/Q%'RCV2GCCP%!+,6*)7O[#'M'"`58A';WBDA*5XO#_PH'#///(@)_-]_,:W
M>+PX#$X2V7L\UCPOZ_*!QT-*A\Y5.>D,P&-IA\<MD=R^W,*^U(*53>^]F1S#
MV/#P'+8UCZNJI='*6_A-OL%C,T*QO58@R:D32%`\G*G72:=D/GTU-S+YB2R>
M)[L2CP%XK-FX1./'^(@%0@:+>MXYMK0R^SQN>;*E&"5'&9O>VP`9+8\.@#"T
M5GB@538@=^<>%8_>\)AU'(\F@W#"*CR,S0N/:X/'R^0CL-;UA_(I?:]2S54M
M2EI$2/9$$'@H@]QWTA4GNIH'5]HJ0$Z0+Y!'\0Q9K`$.;:S"H_^#1]"BND\\
M3L&VI?A>@\=BRK6Q%@&1V&'7T(O$O,R8VSS>BL?S+QXW($D\RM)U)=.CF?\K
MCRN43>"Q[/%P[UN;QVAY+,"CD9,^\!@UC[6U(J39ID\\AF*_]0\>%OB=A:<K
MLAQ*")::Q^@X:/9YN)H'I$3HH.SQ'D+DX5OUPQW$4S[S@/BX_U\\I@\\:)4B
MSO7S)8_A`X]@>=QE#.`Q(8^)+'7^D@=W.0B-SSQZ-41O>2@E(@^=E+[C<:W7
M5ZM:EP3_,$Y/TL<.M$K).B6#F(0UMW"4X&[SN(/T>=Q;:/$X:Q[\Y'S6//`!
M!!+6F;N<HL&I@\]>I;UT"+%^E(C0X>&>4XO'K>+!Z6K3"2'!GSG#[/$H/?/D
M+1XNCH%).,MJ`F1F>ZEL,@./5:FBO2E>.4\88\3C3'#8'G;E5'AD:);'!#PP
M@(9J?24\>AC!U3R>FH<.C['!8\%ET[3'@QZO`(<V\I!6;)LBCGFX?*VS7;<`
MR89\6#LH'J+)'44M+CNU>)SY@QCD80,DW7^<Q<>8QQFZX(P_0VN!M92PZ`%'
MON,X[?`H.%ALX1$&I2-A2TY]]=4#R$HWQP\OWP;R2X.34N52%4LW38,-\6SS
M(!S`(VX35CS<F3^H;)BSO.$A?TJV03.U>"BK#+KR,*U]'KX_:5>1#1Q,5LF"
M'`;/G/&K\)BD$(H(/TT>1YKK,$"],H4-5YG$`XTOFH`P1"/=@&9/BI+)9ZWS
ME'<UC`W0/4F6699E%8^K!0(\%*<%-^<,#Q4<(@$DL9?E,>6-+?HHX9%O/D%X
M6+]WBH?$8KSTUD"N.N]Z$?TV&QZH[U+NJ<+@@CPFNU@8P4M2W+9Y7`(\1P*/
MCGF`FRX'XF%<]P./2\6C>D#LBP79"I1(7M$'GT5O\"P,CRA+@X<.Q2:/P2S<
M1?!;62RY<D'[9>Y/4<"Z/30/VPR/0Q3UB"XC"2>-J+,/\O!B]:DLWBY?\[B$
MFL=H=F#[8D'D43)[C)6;A:EYA!#>EL<1(Y%YA,$"4;80N6]4#,JRUB0$R6XS
MY.*'KS7=YY%D/:++=&+K!@\//$B2/%(C/#;)CSCWX3./Z:1N?A&/"7DD(.=D
MHTJOTTOAP`!!K36.3SS*CA^7EFSIA5]GZ)SP\NK%E>)AJH9Q)/;:;"&G0EA,
MO19W9'_M//*@Z\S#AH?A@3LOF/NYZ9NI?!@>$Z>0VL_LBH(#Y!>4AAWX'1Y7
M^':KST_@X;)?(@\,D/,NCUT@#1XQ$%$"LO1:'EF`?X/'^C4/6<E<FS+N\9B_
MY`'KHDO-HX@R>GAEF-<+EH<LO4Y;+!P'X9$>FEQ9DOF:QU3S,'FDP6.H>`RW
M4;L$C?!0,_(RLDAR,CPLCEQ9_BN/+$S<;FGQ&`9=0$8='D7D!H^HD@J0:7Y_
MQ^-6'H[_*P^3#5H\:@E2:_-XM7E,^SS<+H_+GSR6PN-(/%;&$=-"@X=Z;`@J
M0(!'TDGSV(^/J`)GV2GS6/9YG#_R:`=(*U_)XRN%L.(A1VPT#S1J*U^9Y15L
M%?MFD6N$AY,%[\K6W/1^:A[/'1X4(5@_XB!8/K[E<9ORGMNW/-A_^/M6@(PM
M'@;'D7EXU7JJ9*CTNLMC<88'!\C5MYX_@$?<3>M8'N!1)K8\AILS.P07$..@
ME[M@!T=GQ-H\4G*B<EYNBH[2-7F\9//QO_(8&\E*5OSK0ZF8\X?EL1QW>"S.
M\J`5UI74T`+.('8TKP.SE&BBB9_%0,SCU_+P2@Q1S6:*>*D8_/[^Q.-6[H@\
M/&N!6CO-@QY@+PT>=ML.#5318,LL-8Z:A\_UM7X>K`V@GSKW>*S%5I+E*1UP
M^QDLC\&DJQC-IPI'%:\I/(K![[K<E(EY>TND[[SB(>"/6I,U\P"30"9H\Y@,
MC*.RC%*Q;_"X\(X1#732X2$3!3-?NGF-QK`\J)^X`><#I($\GGQ$*-^!`JO6
MV71QG(C'#?:ED,=!PF,D5VKQ6%!9T>1Q:?"8X:74!QZ&;Y`WBK(D&5`4+T[K
M@@&B1\1]/];*)X^\R:S1/U?#P^OG'R_[A#)@M!GQZ$G!42E6'/L\U>T)=)%'
M%TVYR&19*1;!2(?E">RO4O@*W[=YC,C#>&HQ6U*!O8W61R5`7L(CJ.2R*!YS
M@&,5P",E")*R/`?<]G@$'1Z#C!=YY#.-64[K:S)@BP=&VY-X=&5>65S-D,+K
M<JX>?<-.0Q[*/^76_?!8BMET/UX@F>8X54-X*!Y!C=.)I]^+F*#[V.3Q4N&1
M.(XV:%UCGRI>&"G4=WC<](<N6_H-[#%&ZW*N%F]_\(!R7_&``$';+6RVL^IW
M&G:`"`\LHT<E(,[7@:,7V=Z*1X<\WG<)$.81&"_(U/*U^/?#_\WC#,'RT!OV
MG,,I1(VSJ)V(QQZ/P!;>5@\)CK<\)LM#X7#.ZWYO$5$S^8:'.'0T-^,HLLV@
MO.'Q+AN0+^01[WH@C_PF"50;08C2H<'C*03.6$QFP'%CG_<J7T.Z^@<>^4AG
M2%[2-WF<./]E-Y"HZ50_Q4/))3R<I"NS7@O`'WGD`)&ADR6!=1CX72E$U3WN
M'R@>FS@]6AIX/`NQ#SPZ+^\ZDM5`SVVLHL*/\42JYIBNNC]Y)*77B==)5NC`
MSW6A\!CHP43U.PVFM7B<A`>FP'T>]_3-4_'`V'MG9B5"\"ZO>5P;QY,5#_PU
ME.%1WG4\.1[`]6X3KU/>)C$4L81'+#Y?\R@*'*W0L2_P6.D\#'3-/,S>]+7%
M`_[\Q`,*01+M1[3'\QT5#^JW\5C5*KQR_P:/VQX/7GX5EYC-RRS@H?)T$:L7
M'L/D]W`LP.,N%?VHY*')N',\_',@.6IN?^:KC9I9(@2I'[C@_9%"$%?4GWG<
MN8((CR![*H>&M5W-HP4DVSS5J[YU%/L7>02-XT)I%'C<=GDX\OEW^<E>JVUS
M72"8\K5#$430C52J0PN'XF&7"#L\+@$<91M!TI79QP0>(1;`G.ON4*=*C'S!
MHP$D72[+AP:/7Z=XJ#,3A8<7'G&BJZ9059D0\A&SM<EC=/)Z5O,8,))&EHD3
MZ_5+'IBNX`$$LVI<&1V*_FT>)6'U);9H"2R3^J'U"K?B4?_*`UWKN+O9R]*^
M;+I2"^DG^`[P(UF5/79X=!1UH,FA$GV$D*W#H\DCW\@[:JOF<3$XJ`K\>H/#
M#\"#BD_@4XPTWMF:^K'#PT1(WG1F'D_+HS<\,$`N3(=X2"[5O2_9EZ(L>!*_
MQ:-^PZM^]<L\>)AW'1Z1QPI9XL@CR>.U4SSDYWPI64E5[KQO\K@K'K,Y5=KY
MZI4Z[;E9'B9`U!9I7_&X>LL#`D3@J&`;Y"@\H$L^I\Z1-WG`&\77T?``T?%T
MU$<>4]XUU4&U99=7]J%1\T##'?*HEZS$P_`8(!HBCS>$C"]+5:.7Y_V389='
MGO;*/*:*AR^+E#I`^HJ'T+S7Q4;6.Q\3%O#(<3?*PX$$"`KTIL0JF1YY//FN
M\O\,8O]0A!Z54!`=O)>?Y""#1ENCSU'QF8L0]WC)TZ,UIJ('&>%H?IIE>_U\
MY.'+'B6HSU8^53STO;K6U#S:`0*O3-+(41'B(;Z$AP>)1\YVE@?8!<.)DJP2
M:E+GH0;Z*771+VO0H<L1#WY>*S]VR<9`2Y.%TPMX;2?3"V.]*B">@-09JP^6
M1YWL/O-@%YX)SJWBD1KS8`W!/UXIT__F(M%9'D_1N"HW8(@B#\K9_=";]=>9
MTIW4E0%_-RD\[FD/_/R11S`\I-OC*QZEO-D`.54\!ML01U_SH`"9"4YZ/?=O
M/#;GR"\<G$H+S$-N4]4FJWPV/!#'YO57KWA,AL>PRX-FKM+5-GS\?<L_\-!&
M+0ZR)#%T@)R"Y6'#PSP2-'BL@J-L&GW)8^0^$_$XYB_^B8<`$;V`A_^:QUEX
MO%H\'OXK'M[R<,:HPN,PZ`#I0\6CPH$\X$$@&"#R]S/*]@6/1\^NL:F:7Y`>
M,2]\RT.?P5!AO/&@GUXI'K")"3SH5&&*CS-Y)UNZE]^5'F?<&RS2Y?_K,I&R
M?H]'%BB>[3[@8\76\82EY$\>O6OS2%:3Y)7CXV(*5<7CH;LX)_E*>(0='F\E
MVA$"9#%^\\/U7/%@:T+]\(J'+5SX`J4_5B=T(X\`PN.^Z%%W%7-J'J[%8S=?
M,8VL\`F!*!Y3WBVJ>.A#`QZ.\N3AA<?8Y/$K.2F\?E`SWJ&<T[]948Z3NUWH
M4:7PN#1YT-5[<*4W^,_H@$=MIQL?L"C>!UGET/;O+!P;L2<G5SPBDCN<<RY:
MBX(T6E!`9JPEY=7D#H\;"=WBX0R/%7C$+\4J/Q"X)/GHJB8JG"GK;"-(]I<]
M&4^[6MM%^D=KXD`C*M_8LYT,#VCT"_+96"2I+`'B[*DP2,,JP\2OLCC9_1I`
MUIJ'.<(A/+@R-GG$W..$!_]C'3G!U%4*]_LXV#691W0MC__V"WC\"`^5+'CH
M,N&YXO$[\2_=:A[%"]E)U1?X2^PV#UE)Y+G.I&N@_]+0B!!)5^3A%\OCAT8K
MGZG#"WEL0.A-WO\``G/6?,NMS^T`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V%M
M;W5F;&%G92]I;F9O+G!H<```````````````````````````````````````
M`````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,C`R`#$P-3$U-#,Q,#8W`#`R,30T,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O8V%M;W5F;&%G92]I;F9O+G!H<"QV(#$N,2`R,#`T
M+S$P+S$W(#$Y.C,S.C,U(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M
M92`](%\H(D-A;6]U9FQA9V4B*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O<V-R
M965N+F-S<P``````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(P-``Q
M,#4Q-30S,3`V-P`P,C$W-S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V-A
M;6]U9FQA9V4O<V-R965N+F-S<RQV(#$N-RXV+C,@,C`P-2\Q,"\Q."`Q,3HS
M-#HQ,R!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z(",Q
M9C)E,6(["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S5D-60V,#L*("`@
M('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S5D-60V,#L*?0IH=&UL('L*("`@
M('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-60U9#8P.PH@("`@<V-R;VQL8F%R
M+6%R<F]W+6-O;&]R.B`C-60U9#8P.PI]"F$@>PH@("`@8V]L;W(Z(",S,S8[
M"GT*82YW:61G970@>PH@("`@8V]L;W(Z(",P83(Y,3(["GT*82YW:61G970Z
M:&]V97(@>PH@("`@8F%C:V=R;W5N9#H@(SDY-CL*?0HN:&5A9&5R('L*("`@
M(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S,V,SL*?0HN:&5A9&5R
M(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",Y.38["GT*+FAE861E<B!A('L*("`@
M(&-O;&]R.B`C.3DV.PI]"F$N:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C
M.3DV.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A
M8VMG<F]U;F0Z(",S-C,["GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@
M(V-C83L*?0IA+F-O;G1R;VP@>PH@("`@8V]L;W(Z(",P9C`["GT*+FET96T@
M>PH@("`@8F%C:V=R;W5N9#H@(V-C83L*?0HN8G5T=&]N('L*("`@(&9O;G0M
M=V5I9VAT.B!B;VQD.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C
M.3DV.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD.B`C,68R93%B('5R;"@B9W)A<&AI8W,O
M;65N=2YP;F<B*3L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M
M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C,S8S.PI]"@HO*B!3
M:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O
M=6YD.B`C,S8S.PI]"B-S:61E8F%R4&%N96P@<W!A;BP@(W-I9&5B87)086YE
M;"!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-S:61E8F%R4&%N96P@83IH;W9E
M<B!["B`@("!C;VQO<CH@(V9F9CL*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I
M97<N("HO"BYP<F5F<T]V97)V:65W(&@R('L*("`@(&-O;&]R.B`C9F9F.PI]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O;'5C+P``````````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`Q-C0V-@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O````````
M````````````````````````````````````````````````````````````
M````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S$P-C<`,#(P,C8V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU
M8R]G<F%P:&EC<R]T86)?8F]T=&]M+F=I9@``````````````````````````
M```````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#(P,0`Q,#4Q-30S,3`V-P`P,C,P-S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA%``!`(0@`-WCU=OA
MT_[^_O+T[N;IX-K@TOS\_/7W\OGY]^KMY.#DUN7HWN[QZNWPZ>_RZ^+EVOCX
M]O?W]?/U\.GLX_KZ^/O[^^ONYW=F5>/FV^3GW?W]_>SOZ.'DV?'S[N#CV.CK
MXBP`````%``!```%!N`ECF19A@`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O
M=&%B7W)I9VAT+F=I9@``````````````````````````````````````````
M````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V-#8`
M,3`U,34T,S$P-C<`,#(R-S(U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y89`!E@#$``#5T+JWKHC2S+79U,'BWM#I
MYMO]_?S>VLG6T;O7TKWS\NSKZ-[LZN#W]O/P[N?N[./GY-CZ^OC)PJ;4S[C-
MQZW0RK++Q*G`N)?EXM3<V,;8T[_/R;#.R*[*PZ?\_/OO[>4A^00``````"P`
M````D`&6```%_V`@CF1IGFBJKFSKOG`LSW1MWWBN[[`D0(:@<$@L&H_(I'+)
M;#J?T*AT2JU:K]BL]NF)*`B""R`8*9O/Z+1ZS6Z[W_"X?$ZOV^_XO'[/[_OC
M#0H."P<2"`8-B8J+C(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*5"@H,$`0#%QBE
MK:ZOL+&RL[2UMK>XN;J[O+V^O\#!PL/$Q;D.#PL8!QD=%`[0T=+3U-76U]C9
MVMO<W=[?X.'BX^3EYN?HZ=L?R:C,80_Q\O/T]?;W^/GZ^_S]_O\``PH<2+"@
MP8,($RKLMZ#`L@P#$`1@0+&BQ8L8,VK<R+&CQX\@0XH<2;*DR9,H4_^J7,FR
MY<<%"R`\'*`A`,R;.'/JW,FSI\^?0(,*'4JTJ-&C2),J7<JTJ=.G0PNXRZ`A
M08`"6+-JW<JUJ]>O8,.*'4NVK-FS:-.J7<NVK=NW<..2E4D`8@*)$/+JW<NW
MK]^_@`,+'DRXL.'#B!,K7LRXL>/'D"-++HR!`+.[$P(0V,RYL^?/H$.+'DVZ
MM.G3J%.K7LVZM>O7L&/+GDT;-3,-``0("'"@M^_?P(,+'TZ\N/'CR),K7\Z\
MN?/GT*-+GTZ]NG7D&2!JF%"APH8``\*+'T^^O/GSZ-.K7\^^O?OW\./+GT^_
MOOW[^//K;Z\!`7<.%%`00`($%FC@@0@FJ.#_@@PVZ."#$$8HX8045FCAA1AF
MJ.&&'';X(`+^";`!!19T$`"(**:HXHHLMNCBBS#&*..,--9HXXTXYJCCCCSV
MZ../0,X(P`0"5`!@!R8"H.223#;IY)-01BGEE%16:>656&:IY99<=NGEEV"&
M*>:854Y`9`4D=B!!`&2VZ>:;<,8IYYQTUFDGF686F>::=_;IYY^`!BKHH(0R
MF2>:)?)9Z**,-NKHHY#&>>B>;$9JZ:689JJIH),F6NFFH(8JZJBD0MFIFI^6
MJNJJK+8*Z*F*NBKKK+36NB6LJ=JJZZZ\RHIKK\`&*^RFOPYK[+'(!EILLLPV
MZ^R8RSXK[;342AEM_[789OOLM=IVZVVPW'XK[KB^GDDIN>BFRVJXZK;K+J3L
MOBOOO,J:ZRF]^.;[JKVHZNOOOW+&"_#`!&,I<,$()^SDP0HWC####D?\+\02
M5TPOQ19GW"[&&G<\+L<>AZPMR"*7/"W))J?,+,HJMSPLRR['S"O,,M=,*\TV
MY[PNO['J[//+/.?Z\]"[XDSTT9<:C?32CBK-]-.$.@WUU']*3?75=5J-]=9P
M:LWUU]`&#?;838M-]ME1FXWVVE6KS?;;6;L-]]Q=RTWWW6'K>2_>?.>-:+]]
M!_ZEUX*_37CA:Q^.^-F*+SYVXXY_#7GD6T].^=667SYUYIH_S7GG2W\.^O_1
MHH\^=.FF^XQZZCFOSGK-KK\><^RRMTQ[[2G?CGO)NN\><N^^=PQ\\!D/3WS%
MQA\?<?+*-\Q\\PD_#WW!TD\_</763VQW]F1CSWV^WG]_\?;B<QU^^>^>C_[&
MY*]/M?KNHPM__!^W3S_3\]_O;?[ZCVQ__T3C'P"K)<`!GNQ_!M19`1/HK`4R
M<&4(?*#,'"C!8U&P@D#3&^`P>+H(<C!W'OP@[T(HPM^1L(3".R$*BZ?"%2*O
MA2Y<'@QCZ+P9TC!Z-KPA]7*HP^OQL(?:TV#/@"BR"Q)Q548\8JF2J,11,;&)
MH7HB%(GUPRFFKXI69)\0A99%ATFQBY;Z(ACAA<4C,=9OBV:4F!C3R*@ULK%0
M;GSCH.(HQWJAL8X/*R,>"1BT$```.P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]T86)?;&5F="YG:68`````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#4V-``Q,#4Q-30S,3`V-P`P,C(U,S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M"0"6`,0``+>NB._MY>#<S.SJX/'OZ>?DV-?2O-70NMO6Q/W]_?3S[>CEV_;U
M\OCW]/'OZ.OHWMS8QNWKXMG5P?#NY^[LX_KY]^/?T-C3O\6^G\?`H]_;R[RT
MD.[LY.7BU.SIX-/.MR'Y!```````+``````)`)8```7Q8"(^1K8!@`AAB->(
M"?0Y<%4]&&TW#'-(.X9BF%E4>`J"8[)1()4<"H`G)`0HD6E/,:$,/("M-?)X
MA*ODQ2*<##P*'0M@.!D4+`+-W,%Y=#00$@`$$Q$+%H$7@P$#"P(0%P:+=@((
M!I)6E):8C`65EY.>FZ&?G)J@F:*HG:6DHZFML*^LLZ>FJK>QM*NVKKRXOKFU
MP+*_NKW%PL;#Q\2[RM#!TLG3S]7(UM3:V=S8WL[?S>+,Y,OFT=OAY>C=X.[C
MY]?OZ_+P[.KQZ?/Y[?;U]/K\!038CR"^>_L0"BS([^"_A@D?*C08<2#$A0XM
M3KP4`@`[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L
M=6,O9W)A<&AI8W,O8W5R<F5N=%1A8E]R:6=H="YG:68`````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(T,3,`,3`U,34T,S$P-C<`,#(T,C8P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y89`!E@#$``#____^
M_O[]_?ST\NWY^??R\>IW9E7R\>OZ^OCW]O+V]?'X]_78TLBOI)>1@W3EX=7H
MYMKO[>;Y^/;JZ-[MZN+U]._GX]CV]?#]_?WQ\.G\_/KP[N?KZ=_`N*Z`<%_+
MP[8A^00``````"P`````D`&6```%_Z`ACF1IGFBJKFSKOG`LSW1MWWBN[Z_G
M-`^`<$@L&H_(I'+);#J?T*AT2JU:K]BL=OL,""041L/1"7#/Z+1ZS6Z[WW"N
M5U*)0,2=N'[/[_O_@(%$<W4<$!\.#(*+C(V.CY!KA!&&$`T-D9F:FYR=?Y.&
M%HB>I*6FIZA)H!!W'JFOL+&RGU^%$!86!@&[O+V^O\#!PL/$Q<;'R,G*R\S-
MSL_0T=+3U,48&A(#E!`/#P8"X.'BX^3EYN?HZ>KK[.WN[_#Q\O/T]?;W^/GJ
M&@0)VA/<O!$82+"@P8,($RI<R+"APX<0(TJ<2+&BQ8L8,VK<R-'A@@L%*-SJ
M9B"!R9,H4_^J7,FRI<N7,&/*G$FSILV;.'/JW,FSI\^?,!5<.+#!4#=O`Y(J
M7<JTJ=.G4*-*G4JUJM6K6+-JW<JUJ]>O8,.*G7J`*`6`1PT46,NVK=NW<./*
MG4NWKMV[>//JW<NWK]^_@`,+'DS8;H8(9P-Z*\RXL>/'D"-+GDRY,N$,&Q"'
MPF6@K.?/H$.+'DVZM.G3J%.K7LVZM>O7L&/+GDV[MNW4!0Y3J`3!P-C?P(,+
M'TZ\N/'CR'\?T$UAMP$%T*-+GTZ]NO7KV+-KW\Z]N_?OX,.+'T^^O/GSZ--K
MOW"APH#<F2,86$"_OOW[^//KW\^_O___``8HX(`$%FC@@0@FJ.#_@@PV^)])
M[0W@F0$=56CAA1AFJ.&&'';H8842+)``=.P9@,")**:HXHHLMNCBBS#&*..,
M--9HXXTXYJCCCCSVZ../0-(XD`1$2O"-/D@FJ>223#;IY)-01HFD!E2BJ$LU
M6&:IY99<=NGEEV"&B24&9)9IP"QHIJGFFF><R>:;<,8IYQ!NSFGGG7B64F>>
M?/;I)R![_BGHH(2V6>BAB"8:1:"*-NIHHHP^*NFD?$9*Z:68LFEIIIQVFLJF
MGH8JJB:@CFKJJ8&4BNJJK+ZA:JNPQKK%J[+6:NNBM^:J:Q6T[NKKKKW^*FRM
MP0YK+*O%'JOLJ,DNZRRGS3XK[:313FNM_Z+57JLMH=ENZVV?W7XKKIWACFON
MF^6>JRZ:Z:[K[BOMOBNOGO/6FV>\]N8+";[Z]KL(O_X&[`?``A<<!\$&)\P&
MP@HW;*C#$),:\<3[4FPQ(PQ?K#$3&6_L\1$=?RRR$"&/_''))F^,<LH7K\PR
MQ2Z_''',,CM,<\T*WXRSP3KO+'#//OL+=-#Z#DVTO48?/6_22K_+=-/K/@WU
MN5)//6[55G^+==;;;LWUM5Y_/6W88C]+=MG+GHWVL6JO/6S;;O\*=]S`TKWS
MW';?BG?>Q/(M\]Y^PPIXX,@2GO+@AI^*>.+,,B[RXHY["GGDT%*NLN4:3XXY
MI9IO+FGGGCL*>HCHV)(^L^D0CXYZH:JO/FCKKO\)>^S@TLZS[07/CON=NN\^
M9^^^QPE\\.@27[3Q^0Z/?)K*+S]+\\['`GWT\%+OM/7N3H^]*=IO3TKWWG<"
M?OB;C$]^)N:?7['ZWJ;/?B/NO_^O_-K&3S^@]UMK?_Y][,__'O[[W\$$Z*P`
M$M`-!CS@PA3(MA```#L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]C=7)R96YT5&%B
M7VQE9G0N9VEF```````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4S-P`Q,#4Q-30S,3`V
M-P`P,C0Q,#(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA"0"6`,0``/___W=F5?[^_OW]_/KZ^/GY]_W]_?S\^OGX
M]OCW]?7T[_;U\?3R[?+QZ_;U\/?V\KNSJMW9U>GFX_7T\X%Q89B+?^'=V9B+
M?KJQIY.%>.'>V<?`N/+QZJZDFI.%=\:_N"'Y!```````+``````)`)8```7<
M("!J6$4%@?AE4#2)P-9)L&AY=`U@D"Y>$1^`\O*EA$>`8+D,,`V&@300'1P(
MA$(A(+TB$HE'`%M`/!P*QKB<0#<:ZZ^#T>",LXE%6GTM/_0*`0=]7PL+7%99
M"%]445=96U!5@P=.2Y)3(DQ,23J=-9\PH2*C`*6G0J:IJ$BKKJVP1J^RL9ZS
MMK6@M[JYHKN^O:2_PL&JQ:RTR;C*O,S`SL30QM+(R];-U\_9T=O3W=78X=KB
MW.3>YN#CZN7KY^WI[/'N\O#S]O7XP_?Z^<?\__X"4@,X4.`W@MU"```[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]L=6,O:6YF;RYP:'``````````````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-C<`,3`U,34T,S$P-C<`,#(P,3,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]L=6,O:6YF;RYP:'`L=B`Q
M+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-B!M9&IU:VEC($5X<"`D"B`J+PH*)'1H
M96UE7VYA;64@/2!?*"),;WEO;&$B*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M;'5C+W-C<F5E;BYC<W,`````````````````````````````````````````
M`````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`W-C8R`#$P-3$U-#,Q,#8W`#`R,#0V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*BH*("H@)$AO<F1E.B!H
M;W)D92]T:&5M97,O;'5C+W-C<F5E;BYC<W,L=B`Q+C$P+C8N."`R,#`U+S$Q
M+S`R(#$Y.C,R.C0X(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R
M;W5N9#H@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+"!'96YE=F$L
M($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68["B`@("!S8W)O;&QB87(M
M8F%S92UC;VQO<CH@(V,T8S1B.#L*("`@('-C<F]L;&)A<BUH:6=H;&EG:'0M
M8V]L;W(Z("-E-F4V9&,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",P
M,#`["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(V,T8S1B
M.#L*("`@('-C<F]L;&)A<BUH:6=H;&EG:'0M8V]L;W(Z("-E-F4V9&,["B`@
M("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",P,#`["GT*+G-E;&5C=&5D('L*
M("`@(&)A8VMG<F]U;F0Z("-C-F0S9F8["GT*82P@82YF:7AE9"!["B`@("!C
M;VQO<CH@(S,S.3L*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0HN
M:&5A9&5R('L*("`@(&-O;&]R.B`C9CDP.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED("-F.3`["GT*+FAE861E<F)O>"!["B`@("!B;W)D97(M8V]L
M;W(Z("-F.3`["GT*+FAE861E<F)O>"`N:&5A9&5R('L*("`@(&UA<F=I;BUL
M969T.B`M,7!X.PH@("`@;6%R9VEN+7)I9VAT.B`M,7!X.PH@("`@8F]R9&5R
M+6QE9G0Z(&YO;F4["B`@("!B;W)D97(M<FEG:'0Z(&YO;F4["GT*82YH96%D
M97(Z:&]V97(@>PH@("`@8V]L;W(Z("-F8S`["GT*82YH96%D97(@>PH@("`@
M8F]R9&5R+6)O='1O;3H@;F]N93L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R
M96YT.PI]"BYL:6=H="!["B`@("!C;VQO<CH@(S,S,SL*?0HN<VUA;&QH96%D
M97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B!T<F%N<W!A
M<F5N=#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS
M+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@9F]N="UW96EG:'0Z
M(&YO<FUA;#L*?0IA+G-M86QL:&5A9&5R+"`N<VUA;&QH96%D97(@82!["B`@
M("!C;VQO<CH@(V8Y,#L*?0IA+G-M86QL:&5A9&5R.FAO=F5R+"`N<VUA;&QH
M96%D97(@83IH;W9E<B!["B`@("!C;VQO<CH@(V9C,#L*?0HN8V]N=')O;"![
M"B`@("!B86-K9W)O=6YD.B`C9#AD.&,Q.PI]"BYI=&5M('L*("`@(&)A8VMG
M<F]U;F0Z("-E965E938["GT*"B\J($9O<FT@<W1Y;&5S+B`J+PII;G!U="![
M"B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA;"P@2&5L
M=F5T:6-A+"!S86YS+7-E<FEF.PH@("`@8F%C:V=R;W5N9#H@(V8W9C=E93L*
M("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-C8["GT*=&5X=&%R96$@>PH@("`@
M8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD.B`C9C=F-V5E.PH@("`@8F]R
M9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0II;G!U=#IF;V-U<RP@=&5X=&%R96$Z
M9F]C=7,@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<CH@,7!X
M('-O;&ED("-F.3`["GT*<V5L96-T+&]P=&EO;B!["B`@("!C;VQO<CH@(S,S
M,SL*("`@(&)A8VMG<F]U;F0Z("-F-V8W964["GT*+F)U='1O;B!["B`@("!C
M;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F.68Y9C@["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED("-C
M-&,T8C@["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(V,T8S1B.#L*("`@
M("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]"BYB=71T;VXZ:&]V97(@>PH@
M("`@8V]L;W(Z("-F.3`["GT*"B\J($%L=&5R;F%T:6YG('-T>6QE<RX@:71E
M;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN<F]W179E;BP@+FET96TP
M('L*("`@(&)A8VMG<F]U;F0Z("-E964["GT*+G)O=T]D9"P@+FET96TQ('L*
M("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC
M;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-E-F4V
M9&,["B`@("!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(S@P.#`W03L*?0HC
M;65N=2!H,2!["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A('L*("`@(&-O
M;&]R.B`C,#`P.PH@("`@8F]R9&5R.B!N;VYE.PI]"B-M96YU(&$Z:&]V97(@
M>PH@("`@8V]L;W(Z(",P,#`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(V9F9CL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F9F8["B`@
M("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",W-C4["B`@("!B;W)D97(M=&]P
M.B`Q<'@@<V]L:60@(S<V-3L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A
M+F-U<G)E;G0@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C
M8S!C,&(X.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-F9F8["B`@
M("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C9F9F.PH@("`@8F]R9&5R+6QE
M9G0Z(#%P>"!S;VQI9"`C-S8U.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED
M(",W-C4["B`@("!P861D:6YG.B`R<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S
M+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O
M;&ED("-E.64Y93D["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V4Y
M93EE.3L*("`@(&)A8VMG<F]U;F0Z("-F-F8V9C8["GT*(W-I9&5B87)086YE
M;"!S<&%N+G1O9V=L92P@(W-I9&5B87)086YE;"!A('L*("`@('!A9&1I;F<M
M;&5F=#H@,7!X.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#)P>#L*?0HC<VED96)A
M<E!A;F5L('-P86XN=&]G9VQE('L*("`@(&)O<F1E<CH@,7!X(&YO;F4@=')A
M;G-P87)E;G0["GT*(W-I9&5B87)086YE;"!A('L*("`@(&)O<F1E<CH@,7!X
M('-O;&ED("-F-F8V9C8["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@
M(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*("`@(&)O
M<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!T97AT+61E8V]R871I;VXZ(&YO
M;F4["GT*(V5X<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*
M?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!["B`@("!B86-K9W)O=6YD
M.B`C9F9F('5R;"@B9W)A<&AI8W,O=&%B7V)O='1O;2YG:68B*2!R97!E870M
M>"!B;W1T;VT["B`@("!F;VYT+7-I>F4Z(#$Q<'@["GT*+G1A8G-E="!L:2![
M"B`@("!M87)G:6XZ(#`["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S
M+W1A8E]R:6=H="YG:68B*2!N;RUR97!E870@<FEG:'0@=&]P.PI]"BYT86)S
M970@;&D@82P@+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&)A8VMG<F]U;F0Z
M('5R;"@B9W)A<&AI8W,O=&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T(&QE9G0@
M=&]P.PH@("`@;6%R9VEN.B`P.PH@("`@<&%D9&EN9SH@,W!X(#$U<'@["B`@
M("!C;VQO<CH@(S<V-3L*("`@(&)O<F1E<CH@;F]N93L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C-S8U.PI]"BYT86)S970@;&D@83IH;W9E<B![
M"B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI
M8W,O=&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T(&QE9G0@=&]P.PI]"BYT86)S
M970@;&DN86-T:79E5&%B('L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI
M8W,O8W5R<F5N=%1A8E]R:6=H="YG:68B*2!N;RUR97!E870@<FEG:'0@=&]P
M.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$@>PH@("`@8V]L;W(Z(",S,S,[
M"B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+V-U<G)E;G1486)?;&5F
M="YG:68B*2!N;RUR97!E870@;&5F="!T;W`["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(V9F9CL*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A.FAO
M=F5R('L*("`@(&-O;&]R.B`C.3DY.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G
M<F%P:&EC<R]C=7)R96YT5&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T(&QE9G0@
M=&]P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-F9F8["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O;'5C8FQU92\`````````````````````````
M`````````````````````````````````````````````````````#`P-#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`Q
M-S,S-@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6-B;'5E+VEN
M9F\N<&AP````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R
M,#``,3`U,34T,S$P-C<`,#(P-S8W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]L=6-B;'5E+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ
M,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B3&]Y
M;VQA($)L=64B*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C8FQU92]S8W)E96XN8W-S````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,S$S`#$P-3$U-#,Q
M,#8W`#`R,3,R-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;'5C8FQU92]S
M8W)E96XN8W-S+'8@,2XQ,"XV+C0@,C`P-2\Q,"\Q."`Q,3HS-#HR,"!J86X@
M17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!F
M;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A
M+"!S86YS+7-E<FEF.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-#-$,T
M0C@["B`@("!S8W)O;&QB87(M:&EG:&QI9VAT+6-O;&]R.B`C939E-D1#.PH@
M("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C,#`P.PI]"FAT;6P@>PH@("`@
M<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-#-$,T0C@["B`@("!S8W)O;&QB87(M
M:&EG:&QI9VAT+6-O;&]R.B`C939E-D1#.PH@("`@<V-R;VQL8F%R+6%R<F]W
M+6-O;&]R.B`C,#`P.PI]"F$@>PH@("`@8V]L;W(Z(",P,T,["GT*82P@82YF
M:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0IA+G=I9&=E="!["B`@("!C;VQO
M<CH@(S`P,#L*?0II;G!U="!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82P@
M1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.PH@("`@8F%C
M:V=R;W5N9#H@(V8W9C=E93L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-C8[
M"GT*=&5X=&%R96$@>PH@("`@8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD
M.B`C9C=F-V5E.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0IS96QE
M8W0L;W!T:6]N('L*("`@(&-O;&]R.B`C,S,S,S,S.PH@("`@8F%C:V=R;W5N
M9#H@(V8W9C=E93L*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C,#-C.PH@("`@
M8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,V,["GT*+FAE861E<F)O>"![
M"B`@("!B;W)D97(M8V]L;W(Z(",P,V,["GT*+FAE861E<F)O>"`N:&5A9&5R
M('L*("`@(&UA<F=I;BUL969T.B`M,7!X.PH@("`@;6%R9VEN+7)I9VAT.B`M
M,7!X.PH@("`@8F]R9&5R+6QE9G0Z(&YO;F4["B`@("!B;W)D97(M<FEG:'0Z
M(&YO;F4["GT*82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z(",P-F8["GT*
M82YS;6%L;&AE861E<CIH;W9E<B!["B`@("!C;VQO<CH@(S`V9CL*?0IA+FAE
M861E<B!["B`@("!B;W)D97(M8F]T=&]M.B!N;VYE.PH@("`@8F%C:V=R;W5N
M9#H@=')A;G-P87)E;G0["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C,S,S.PI]
M"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U
M;F0Z('1R86YS<&%R96YT.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@
M(S`P,#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS
M+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@9F]N="UW96EG:'0Z
M(&YO<FUA;#L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C1#A$.$,Q
M.PI]"BYI=&5M('L*("`@(&)A8VMG<F]U;F0Z("-E965E938["GT*+RH@06QT
M97)N871I;F<@<W1Y;&5S+B!I=&5M,"P@:71E;3$@87)E(&1E<')E8V%T960N
M("HO"BYR;W=%=F5N+"`N:71E;3`@>PH@("`@8F%C:V=R;W5N9#H@(V8Y9CEF
M.3L*?0HN<F]W3V1D+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE
M.3L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N
M9#H@(V8Y9CEF.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P
M.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E
M<BUL969T.B`Q<'@@<V]L:60@(T,T0S1".#L*("`@(&)O<F1E<BUT;W`Z(#%P
M>"!S;VQI9"`C0S1#-$(X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@[
M"GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z("-#-D0S9F8["GT*+FEN
M4')O9W)E<W,@>PH@("`@8F%C:V=R;W5N9#H@(S`P,S-C8SL*?0H*+RH@365N
M=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C
M:V=R;W5N9#H@(V4V939D8SL*("`@(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI
M9"`C.#`X,#=!.PI]"B-M96YU(&@Q('L*("`@(&-O;&]R.B`C,#`P.PI]"B-M
M96YU(&$@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B;W)D97(Z(&YO;F4["GT*
M(VUE;G4@82YC=7)R96YT('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9#H@(V,P8S!B.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O
M<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X.PH@("`@+6UO>BUB;W)D
M97(M<F%D:75S.B`U<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PIB;V1Y
M+G-I9&5B87(@>PH@("`@8F%C:V=R;W5N9#H@(V8Y9CEF,SL*?0HC<VED96)A
M<E!A;F5L('L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",X,#@P-V$[
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S@P.#`W83L*("`@(&)A
M8VMG<F]U;F0Z("-E-F4V9&,["GT*(W-I9&5B87)086YE;"!A('L*("`@(&)O
M<F1E<CH@,7!X('-O;&ED("-E-F4V9&,["B`@("!P861D:6YG+6QE9G0Z(#%P
M>#L*("`@('!A9&1I;F<M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!A
M.FAO=F5R('L*("`@(&)A8VMG<F]U;F0Z("-E-F4V9&,["B`@("!B;W)D97(Z
M(#%P>"!S;VQI9"`C,#-C.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PH@
M("`@+6UO>BUB;W)D97(M<F%D:75S.B`S<'@["GT*(V5X<&%N9$)U='1O;B![
M"B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]P;W-T;G5K92\`````````````````````````````````````
M````````````````````````````````````````,#`T,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C<`,#$W-34S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!O<W1N=6ME+VEN9F\N<&AP````
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$W-@`Q,#4Q-30S
M,3`V-P`P,C$R,C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+W!O
M<W1N=6ME+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S<@;61J
M=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B4&]S=&YU:V4B*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]P;W-T;G5K92]S8W)E96XN8W-S````````````````
M````````````````````````````````````````````````,#$P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,U,3<`,3`U,34T,S$P-C<`,#(Q-30W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]P;W-T;G5K92]S8W)E96XN8W-S
M+'8@,2XX+C8N,B`R,#`U+S$P+S$X(#$Q.C,T.C(P(&IA;B!%>'`@)`H@*B\*
M"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V(Q8C<X8CL*("`@('-C<F]L;&)A
M<BUB87-E+6-O;&]R.B`C-C8V-CDY.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O
M;&]R.B`C9&1D9&9F.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L
M;W(Z(",V-C8V.3D["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z("-D9&8[
M"GT*82!["B`@("!C;VQO<CH@(S,S.3L*("`@(&9O;G0M9F%M:6QY.B!'96YE
M=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z
M(#$R<'@["GT*83IH;W9E<B!["B`@("!C;VQO<CH@8FQU93L*?0IA+G=I9&=E
M="!["B`@("!C;VQO<CH@(S`P,#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA
M+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]
M"F$N=VED9V5T.FAO=F5R('L*("`@(&-O;&]R.B!B;'5E.PH@("`@8F%C:V=R
M;W5N9#H@(V(Q8C<X8CL*?0HN:&5A9&5R('L*("`@(&)A8VMG<F]U;F0Z("-B
M,6(W.&(["B`@("!F;VYT+7-I>F4Z(#$W<'@["GT*+FQI9VAT('L*("`@(&-O
M;&]R.B!W:&ET93L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L
M=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@["GT*+G-M
M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@
M(V(Q8C<X8CL*?0HN8V]N=')O;"!["B`@("!C;VQO<CH@8FQA8VL["B`@("!B
M86-K9W)O=6YD.B`C9#ED8V,R.PI]"BYI=&5M('L*("`@(&-O;&]R.B!B;&%C
M:SL*("`@(&)A8VMG<F]U;F0Z("-E.64Y93D["GT*+F)U='1O;B!["B`@("!C
M;VQO<CH@=VAI=&4["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,#`P,#`P.PH@
M("`@8F]R9&5R+6)O='1O;3H@=&AI;B!S;VQI9"`C0C%"-SA".PH@("`@8F]R
M9&5R+7)I9VAT.B!T:&EN('-O;&ED("-",4(W.$(["B`@("!B;W)D97(M=&]P
M.B!T:&EN('-O;&ED(",Y.3DY8V,["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S
M;VQI9"`C.3DY.6-C.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@9F]N="UF
M86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*+G-E;&5C
M=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-B8F-B9F8["GT*+G1E>'0@
M>PH@("`@8V]L;W(Z(&)L86-K.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=VAI
M=&4["GT*+RH@06QT97)N871I;F<@<W1Y;&5S+B!I=&5M,"P@:71E;3$@87)E
M(&1E<')E8V%T960N("HO"BYR;W=%=F5N+"`N:71E;3`@>PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@(V8Y9CEF.3L*?0HN<F]W3V1D+"`N:71E;3$@>PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(V4Y93EE.3L*?0HN9FEX960@>PH@("`@9F]N
M="US:7IE.B`Q,W!X.PH@("`@9F]N="UF86UI;'DZ(&UO;F]S<&%C92P@9FEX
M960["GT*=&0@>PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N="UF86UI
M;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*?0IT:"![
M"B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!F;VYT+69A;6EL>3H@1V5N979A
M+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"@HO*B!-96YU('-T>6QE
M<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD
M.B`C8C%B-SAB.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE
M;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z("-B9F(W.&(["GT*"B\J
M(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-",4(W.$(["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O8F%R8FEE+P``````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`Q-S$R-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B87)B:64O:6YF;RYP:'``````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-S4`,3`U,34T
M,S$P-C<`,#(P-3<S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]B
M87)B:64O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS,R!M9&IU
M:VEC($5X<"`D(#\^"B`J+PH*)'1H96UE7VYA;64@/2!?*")"87)B:64B*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O8F%R8FEE+W-C<F5E;BYC<W,`````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S<Q`#$P-3$U-#,Q,#8W`#`R,3$R
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````O
M*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8F%R8FEE+W-C<F5E;BYC<W,L
M=B`Q+C4N-BXR(#(P,#4O,3`O,3@@,3$Z,S0Z,3$@:F%N($5X<"`D"B`J+PH*
M8F]D>2!["B`@("!B86-K9W)O=6YD.B`C9F5B-F,R.PI]"F$@>PH@("`@8V]L
M;W(Z(",T-#AF.3D["GT*"BYH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@
M("!B86-K9W)O=6YD.B`C9F8X96$U.PI]"BYS;6%L;&AE861E<B!["B`@("!C
M;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-F9CAE834["GT*+F-O;G1R
M;VP@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9C8S)D,#L*?0HN8G5T=&]N
M('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V8T
M-C$W9CL*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@(V8T-C$W9CL*
M("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C9C0V,3=F.PH@("`@8F]R
M9&5R+71O<#H@=&AI;B!S;VQI9"`C9F8X.6$Q.PH@("`@8F]R9&5R+6QE9G0Z
M('1H:6X@<V]L:60@(V9F.#EA,3L*?0HN=&5X="!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C9F9E-65C.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C9F8Y,6$W.PI]
M"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C9C0V,3=F.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-A86,["B`@("!B;W)D97(M
M<FEG:'0Z(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S
M;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`["B`@
M("!P861D:6YG.B`R<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED
M96)A<E!A;F5L('L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F96(V
M8S(["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V9E8C9C,CL*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-F9CAE834["GT*(V5X<&%N9$)U='1O;B![
M"B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*?0H`````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL82\`````````````````````
M`````````````````````````````````````````````````````````#`P
M-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W
M`#`Q-S,U,@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA
M+V=R87!H:6-S+P``````````````````````````````````````````````
M````````````````````,#`T,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S$P-C<`,#(Q,34R`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O;65N=2YP;F<`````````````
M```````````````````````````````````````````P,3`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#,P-P`Q,#4Q-30S,3`V-P`P,C(V,C$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````$````S"`(```#9Q?5X````!W1)344'T@<0"A8!%Q.<
MG`````EP2%ES```*\```"O`!0JPTF`````1G04U!``"QCPO\804```!6241!
M5'C:58RQ"H`P$$./_O_'.780='-0$,0Y:>^N03N$)B^YVOFR//=5S&P2Y<GT
M_0T^,I$91#!`/<([S^S;SJA];KY[AJ@>\W_JG/^S]JYU/VRI6P._3EW)`Y_2
MO0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M
M;WII;&QA+V=R87!H:6-S+VUE;G4M86-T:79E+G!N9P``````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`S,C<`,3`U,34T,S$P-C<`,#(T,#<T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```!````,`@&````T#,0@0````1S0DE4"`@("'P(9(@````)<$A9<P``"O``
M``KP`4*L-)@````A=$58=%-O9G1W87)E`$UA8W)O;65D:6$@1FER97=O<FMS
M(#0N,.HF)W4```!,241!5'B<;8^Q$8`P$,,L[;\-`]"S%!2??,A!XT+G6/D<
MYW6;)!7`"&$P]8=U3]]OW7M4SRC3(41J=#%[U*^C6>VUK3[.9%G>OFB/!V8>
M!`G95F?7`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL82]G<F%P
M:&EC<R]H96%D97(N<&YG````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#`P
M`#$P-3$U-#,Q,#8W`#`R,S`W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````!P```!D(`@``
M`'+LHV\````L=$58=$-R96%T:6]N(%1I;64`5'5E(#$V($IU;"`R,#`R(#(S
M.C0U.C$X("LQ,C`PQ8$840````=T24U%!]('$`LN"0^5PF(````)<$A9<P``
M#L,```[#`<=OJ&0````$9T%-00``L8\+_&$%````5TE$051XVF.<LF@M`P9@
M/'?]'J8HR_/G'S!%F1BP`18&5@9BU>(P@0.[N2Q811FPJ,;E,JPF<)+@,JPF
MX%*+S66DF$"Y*,NY\^<Q11F]?*.PB!Z[C"7F`1[0#7.]U&#P`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O:6YF;RYP:'``````````
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$W-``Q,#4Q-30S,3`V
M-P`P,C$P,34`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VUO>FEL
M;&$O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-R!M9&IU:VEC
M($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")-;WII;&QA(BD["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]M;WII;&QA+W-C<F5E;BYC<W,`````````````````````
M````````````````````````````````````````````,#$P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,Q-38`,3`U,34T,S$P-C<`,#(Q,S0U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]M;WII;&QA+W-C<F5E;BYC<W,L=B`Q
M+C<N-BXU(#(P,#4O,3`O,3@@,3$Z,S0Z,C`@:F%N($5X<"`D"B`J+PH*8F]D
M>2!["B`@("!B86-K9W)O=6YD.B`C8S=D,&0Y.PH@("`@<V-R;VQL8F%R+6)A
M<V4M8V]L;W(Z(",Y-&$R8C4["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(SDT83)B-3L*?0IA+"!A+F9I>&5D('L*("`@(&-O;&]R.B`C
M,S,Y.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"BYH96%D97(@
M>PH@("`@8F%C:V=R;W5N9#H@(V,W9#!D.2!U<FPH(F=R87!H:6-S+VAE861E
M<BYP;F<B*2!R97!E870M>#L*("`@('=H:71E+7-P86-E.B!N;W=R87`["GT*
M82YH96%D97(@>PH@("`@8F%C:V=R;W5N9"UI;6%G93H@;F]N93L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"BYL:6=H="!["B`@("!C
M;VQO<CH@(S1%-40W,CL*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(&)L
M86-K.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@;F]N93L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"BYS;6%L;&AE861E<B!A('L*("`@
M(&-O;&]R.B!B;&%C:SL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C
M865B86-A.PI]"BYI=&5M('L*("`@(&)A8VMG<F]U;F0Z("-E8V5F9C0["GT*
M+F)U='1O;B!["B`@("!C;VQO<CH@8FQA8VL["B`@("!B86-K9W)O=6YD.B`C
M861B-F,V.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@("UM;WHM
M8F]R9&5R+7)A9&EU<SH@-7!X.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O
M=6YD.B`C8S9D,V9F.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@
M("`@8F%C:V=R;W5N9#H@(V,W9#!D.2!U<FPH(F=R87!H:6-S+VUE;G4N<&YG
M(BD@<F5P96%T+7@["GT*(VUE;G4@:#$@>PH@("`@8V]L;W(Z(&)L86-K.PI]
M"B-M96YU(&$@>PH@("`@8V]L;W(Z(&)L86-K.PH@("`@8F]R9&5R.B!N;VYE
M.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`P.PI]"B-M96YU(&$Z:&]V97(@
M>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V%E8F%C83L*("`@('!A9&1I;F<Z
M(#)P>#L*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@=7)L
M*")G<F%P:&EC<R]M96YU+6%C=&EV92YP;F<B*2!R97!E870M>#L*("`@(&)O
M<F1E<CH@,7!X('-O;&ED("-A96)A8V$["B`@("!P861D:6YG.B`R<'@["GT*
M(VUE;G4@82YC=7)R96YT.FAO=F5R('L*("`@('!A9&1I;F<Z(#)P>#L*?0H*
M+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C
M:V=R;W5N9#H@(V,W9#!D.3L*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E
M="!["B`@("!B86-K9W)O=6YD.B!N;VYE.PI]"BYT86)S970@;&D@82!["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C86)A8F%B.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED("-E.64Y93D["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*
M("`@(&-O;&]R.B`C,#`P.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$L("YT
M86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B86-K9W)O=6YD.B`C865B86-A.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED("-A96)A8V$["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O8FQU96UO;VXO````````````````````````````````````````
M`````````````````````````````````````#`P-#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`Q-S4R,P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E;6]O;B]I;F9O+G!H<```````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-S<`,3`U,34T,S$P
M-C<`,#(Q,3<Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]B;'5E
M;6]O;B]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,T(&UD:G5K
M:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D)L=64@36]O;B(I.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O8FQU96UO;VXO<V-R965N+F-S<P``````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-#$R`#$P-3$U-#,Q,#8W`#`R,34Q-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8FQU96UO;VXO<V-R965N+F-S<RQV
M(#$N,3,N-BXS(#(P,#4O,3`O,3@@,3$Z,S0Z,3$@:F%N($5X<"`D"B`J+PH*
M8F]D>2!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["B`@
M("!B86-K9W)O=6YD.B`C,#`S.#DS.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L
M;W(Z(",P,#,X.3,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",P,38X
M9&(["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S`P,S@Y
M,SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`Q-CAD8CL*?0II;G!U
M="!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["GT*<V5L
M96-T('L*("`@(&9O;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@
M(&9O;G0M=V5I9VAT.B!N;W)M86P["GT*=&0@>PH@("`@9F]N="UF86UI;'DZ
M($QU>&D@4V%N<RQ697)D86YA.PI]"G1H('L*("`@(&9O;G0M9F%M:6QY.B!,
M=7AI(%-A;G,L5F5R9&%N83L*?0II;6<@>PH@("`@8F]R9&5R.B!N;VYE.PI]
M"F$@>PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ697)D86YA.PH@("`@
M8V]L;W(Z(",P,#-#9F8["GT*83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,S@Y
M,SL*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,T-F9CL*("`@(&9O;G0M
M<VEZ93H@,"XY96T["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z(",P
M,#,X.3,["B`@("!B86-K9W)O=6YD.B`C,#$V.&1B.PI]"BYH96%D97(@>PH@
M("`@8V]L;W(Z(",R-S`P-#(["B`@("!B86-K9W)O=6YD.B`C,#$V.&1B.PH@
M("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ697)D86YA.PH@("`@9F]N="US
M:7IE.B`Q-G!X.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(S(W,#`T,CL*
M?0IT9"YH96%D97(@>PH@("`@<&%D9&EN9RUL969T.B`S<'@["B`@("!P861D
M:6YG+7)I9VAT.B`S<'@["GT*82YH96%D97(@>PH@("`@8V]L;W(Z(",P,&$X
M9F8["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C9F9F.PH@("`@9F]N="UF86UI
M;'DZ($QU>&D@4V%N<RQ697)D86YA.PI]"F$N;&EG:'0Z:&]V97(@>PH@("`@
M8V]L;W(Z("-&1D,X,#`["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C
M,C<P,#0R.PH@("`@8F%C:V=R;W5N9#H@(S`Q-CAD8CL*("`@(&9O;G0M9F%M
M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@(&9O;G0M<VEZ93H@,31P>#L*
M?0IA+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C,#!A.&9F.PI]"BYS;6%L
M;"!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["B`@("!F
M;VYT+7-I>F4Z(#`N.&5M.PI]"BYC;VYT<F]L('L*("`@(&-O;&]R.B`C,#`P
M.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V0Q9#%D,3L*?0HN:71E;2!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E.64Y93D[
M"GT*+F)U='1O;B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z(",R8C<S9#4["B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED
M(",Y.6,["B`@("!B;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@(SDY8SL*("`@
M(&)O<F1E<BUT;W`Z('1H:6X@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUL969T
M.B!T:&EN('-O;&ED(",P,#`["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!F
M;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["B`@("`M;6]Z+6)O<F1E
M<BUR861I=7,Z(#5P>#L*?0HN8G5T=&]N.FAO=F5R('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z(",Q,38U9F8["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-B8F-B9F8["GT*+F9I>&5D('L*("`@(&9O;G0M<VEZ93H@
M,3-P>#L*("`@(&9O;G0M9F%M:6QY.B!-;VYA8V\L0V]U<FEE<BQM;VYO<W!A
M8V5D+&9I>&5D.PI]"BYS96QE8W1E9"UO=F5R('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-C8V5E9F8["GT*+G1O;VQT:7`@>PH@("`@9F]N="US:7IE.B`Q
M,'!X.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F8SL*("`@(&)O<F1E<CH@
M,7!X('-O;&ED(",P,#`["B`@("!P861D:6YG.B`R<'@["GT*+F%C8V5S<TME
M>2!["B`@("!T97AT+61E8V]R871I;VXZ('5N9&5R;&EN93L*?0IA+FAE861E
M<CIH;W9E<B!["B`@("!C;VQO<CH@.PI]"F$N8W5R<F5N=%1A8CIH;W9E<B![
M"B`@("!C;VQO<CH@.PI]"BYN;W1I8V4@>PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V9F8SL*?0HN<VEG;F%T=7)E('L*("`@(&-O;&]R.B`C-C`V,#8P.PI]
M"BYS:6=N871U<F4M9FEX960@>PH@("`@8V]L;W(Z(",V,#8P-C`["B`@("!F
M;VYT+7-I>F4Z(#$P<'@["B`@("!F;VYT+69A;6EL>3H@36]N86-O+$-O=7)I
M97(L;6]N;W-P86-E9"QF:7AE9#L*?0H*+RH@5&%B;&4@<W1Y;&5S+B`J+PHN
M;&EN9612;W<@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B`C9F9F.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-D9&0[
M"GT*+FQI;F5D4F]W4V5L96-T961#;VP@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C9C-F,V8S.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED("-D9&0["GT*+RH@06QT97)N871I;F<@<W1Y;&5S+B!I
M=&5M,"P@:71E;3$@87)E(&1E<')E8V%T960N("HO"BYR;W=%=F5N+"`N:71E
M;3`@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V8S9C-F,SL*?0HN<F]W3V1D
M+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V4Y93EE.3L*?0H*
M+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(S`Q-CAD8CL*("`@(&9O;G0M9F%M:6QY
M.B!,=7AI(%-A;G,L5F5R9&%N83L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C
M9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!C;VQO<CH@(V9F9CL*("`@
M(&)A8VMG<F]U;F0Z(",P,38X8F(["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@
M<V]L:60@(SDY8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",Y.6,[
M"B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`R,S`V-#L*("`@(&)O<F1E
M<BUL969T.B`Q<'@@<V]L:60@(S`R,S`V-#L*("`@('!A9&1I;F<Z(#)P>#L*
M("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]"@HO*B!3:61E8F%R('-T
M>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C,#$V.&1B.PI]"B-S:61E8F%R4&%N96P@<W!A;BP@(W-I9&5B87)086YE
M;"!A('L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@8V]L;W(Z("-F9F8[
M"GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O;&]R.B`C9F9C.#`P
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+VQI9VAT8FQU92\`````````````````````````````
M```````````````````````````````````````````````P,#0P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-P`P,3<V-C(`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&EG:'1B;'5E+V=R87!H
M:6-S+P``````````````````````````````````````````````````````
M`````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,Q,#8W`#`R,30V,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]L:6=H=&)L=64O9W)A<&AI8W,O;65N=2YP;F<`````````````````````
M````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`Q-C0`,3`U,34T,S$P-C<`,#(S,3,R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(```!#````%`$#````[(\2?P````903%1%:Z7><ZWOQ+-S7@````EP2%ES
M````2````$@`1LEK/@```!1)1$%4"-=C8,`"_D/!`R36(%<'`![16'&N3H:)
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&EG:'1B;'5E
M+VEN9F\N<&AP````````````````````````````````````````````````
M`````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,C`Q`#$P-3$U-#,Q,#8W`#`R,3,Q-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]T:&5M97,O;&EG:'1B;'5E+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@
M,3DZ,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B
M3&EG:'0@0FQU92(I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU92]S8W)E96XN8W-S
M````````````````````````````````````````````````````````````
M```P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$T,``Q,#4Q-30S
M,3`V-P`P,C$V-#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VQI9VAT8FQU
M92]S8W)E96XN8W-S+'8@,2XX+C8N,2`R,#`U+S$P+S$X(#$Q.C,T.C$Y(&IA
M;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V(P9#!F,3L*
M?0IA('L*("`@(&-O;&]R.B`C,S,Y.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD.B`C-F)A-61E.PI]"BYS;6%L;&AE861E
M<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",V8F$U9&4[
M"GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI
M8W,O;65N=2YP;F<I.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@
M("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-F)A-61E
M.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+VUE;G4N<&YG
M*3L*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(V(P9#!F
M,3L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V(P9#!F,3L*?0HC<VED96)A<E!A;F5L
M(&$Z:&]V97(@>PH@("`@8V]L;W(Z('EE;&QO=SL*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO8FEL92\`````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,3`V-P`P,3<Q-3(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O;6]B:6QE+W-C<F5E;BYC<W,`````````````````````````````````
M`````````````````````````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,S8S`#$P-3$U-#,Q,#8W`#`R,3$T,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O;6]B:6QE+W-C<F5E;BYC<W,L=B`Q+C$N,3`N,2`R
M,#`U+S$P+S$X(#$Q.C,T.C(P(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@
M8F%C:V=R;W5N9#H@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!#;W5R:65R.PH@
M("`@9F]N="US:7IE.B`Q,'!X.PI]"G1D('L*("`@(&9O;G0M9F%M:6QY.B!#
M;W5R:65R.PH@("`@9F]N="US:7IE.B`Q,'!X.PI]"F1I=BYS:6UD978@>PH@
M("`@=VED=&@Z(#$U,#L*("`@(&AE:6=H=#H@,3(P.PH@("`@;W9E<F9L;W<Z
M(&%U=&\["GT*=&0N=&]P('L*("`@('=I9'1H.B`R-C,["B`@("!H96EG:'0Z
M(#$Q-SL*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]T;W`N
M:G!G*3L*?0IT9"YL969T('L*("`@('=I9'1H.B`U-CL*("`@(&AE:6=H=#H@
M,3(P.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+VQE9G0N
M:G!G*3L*?0IT9"YD:7-P;&%Y('L*("`@('=I9'1H.B`Q-3`["B`@("!H96EG
M:'0Z(#$R,#L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]D
M:7-P;&%Y+FIP9RD["GT*=&0N<FEG:'0@>PH@("`@=VED=&@Z(#4W.PH@("`@
M:&5I9VAT.B`Q,C`["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI
M8W,O<FEG:'0N:G!G*3L*?0IT9"YB;W1T;VT@>PH@("`@=VED=&@Z(#(V,SL*
M("`@(&AE:6=H=#H@,S$S.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R
M87!H:6-S+V)O='1O;2YJ<&<I.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O<'5R<&QE+P``````````````````````````````````````
M`````````````````````````````````````````#`P-#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`Q-S(Q,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]P=7)P;&4O:6YF;RYP:'``````
M````````````````````````````````````````````````````````````
M````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-S8`,3`U,34T
M,S$P-C<`,#(P-C4W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]P
M=7)P;&4O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,2\R-2`P,CHP-#HU-"!C:'5C
M:R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B4'5R<&QE($AO<F1E(BD[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O<'5R<&QE+W-C<F5E;BYC<W,`````````````````
M`````````````````````````````````````````````````#`Q,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,#`R`#$P-3$U-#,Q,#8W`#`R,3$W
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````O
M*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<'5R<&QE+W-C<F5E;BYC<W,L
M=B`Q+C$N-"XV(#(P,#8O,#0O,C@@,C`Z-#<Z,C@@:F%N($5X<"`D"B`J+PH*
M8F]D>2!["B`@("!B86-K9W)O=6YD.B`C,C(T.PI]"@HN:&5A9&5R8F]X('L*
M("`@(&)O<F1E<BUC;VQO<CH@(S8V.3L*("`@(&)A8VMG<F]U;F0Z("-F9F8[
M"GT*+FAE861E<B!["B`@("!C;VQO<CH@(V-C93L*("`@(&)A8VMG<F]U;F0Z
M(",T-#8["B`@("!C;&5A<CH@8F]T:#L*?0HN:&5A9&5R(&$Z:&]V97(L(&$N
M:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PI]"BYH96%D97(@82![
M"B`@("!C;VQO<CH@(V-C93L*?0IA+FAE861E<CIH;W9E<B!["B`@("!C;VQO
M<CH@(V9F9CL*?0IA('L*("`@(&-O;&]R.B`C,S,Y.PI]"F$Z:&]V97(@>PH@
M("`@8V]L;W(Z(&)L=64["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-B8F-B9F8["GT*+G-E;&5C=&5D+6]V97(@>PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@(V-E9CL*?0H*+G=I9&=E="!["B`@("!C;VQO<CH@(S(R
M-#L*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@8FQU93L*("`@(&)A
M8VMG<F]U;F0Z("-B8F-B9F8["GT*"BYN;W1I8V4@>PH@("`@9F]N="UW96EG
M:'0Z(&)O;&0["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9C.PH@("`@8F]R
M9&5R.B`Q<'@@<V]L:60@(V%A83L*("`@('!A9&1I;F<Z(#%P>#L*("`@('!A
M9&1I;F<M;&5F=#H@-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`X<'@[
M"GT*"BYL:6=H="!["B`@("!C;VQO<CH@(V9F9CL*("`@(&9O;G0M9F%M:6QY
M.B!'96YE=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT
M+7-I>F4Z(#$R<'@["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C8V-E
M.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S0T-CL*?0HN<VUA;&QH96%D97(@
M83IH;W9E<BP@82YS;6%L;&AE861E<CIH;W9E<B!["B`@("!C;VQO<CH@(V9F
M9CL*?0HN<VUA;&QH96%D97(@82!["B`@("!C;VQO<CH@(V-C93L*?0HN8V]N
M=')O;"!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-C8V,["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(SDY.3L*?0HN
M:71E;2!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-E964["GT*+F%C8V5S<TME>2!["B`@("!T97AT+61E8V]R871I;VXZ('5N
M9&5R;&EN93L*?0HN=&5X="!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-F9F8["GT*"B\J($9O<FT@<W1Y;&5S+B`J+PHN8G5T
M=&]N('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(S8V.3L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,C(T.PH@("`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUT;W`Z
M(#%P>"!S;VQI9"`C.3EC.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C
M.3EC.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@9F]N="UF86UI;'DZ(%9E
M<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*83IH;W9E<BYB=71T;VX@
M>PH@("`@8V]L;W(Z("-F9F8["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N
M=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",T
M-#8["GT*(VUE;G4@=6P@>PH@("`@<&%D9&EN9SH@-7!X.PI]"B-M96YU(&QI
M('L*("`@(&QI<W0M<W1Y;&4M='EP93H@;F]N93L*("`@('1E>'0M86QI9VXZ
M(&-E;G1E<CL*("`@(&UA<F=I;CH@,G!X.PH@("`@9FQO870Z(&QE9G0["GT*
M(VUE;G4@82!["B`@("!C;VQO<CH@(V5E9CL*?0HC;65N=2!A.FAO=F5R('L*
M("`@(&-O;&]R.B!Y96QL;W<["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(S8V83L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",V-F$["B`@
M("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUL969T
M.B`Q<'@@<V]L:60@(S(R-#L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A
M+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S8V.#L*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C.3EC.PH@("`@8F]R9&5R+7)I9VAT
M.B`Q<'@@<V]L:60@(SDY8SL*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C
M,C(T.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,C(T.PH@("`@<&%D
M9&EN9SH@,G!X.PI]"B-M96YU(&@Q('L*("`@(&9O;G0M9F%M:6QY.B!697)D
M86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="UW96EG:'0Z(&)O
M;&0["B`@("!F;VYT+7-I>F4Z(#$X<'@["B`@("!L:6YE+6AE:6=H=#H@-3!P
M>#L*("`@('9E<G1I8V%L+6%L:6=N.B!B;W1T;VT["GT*"B\J(%-I9&5B87(@
M<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@("UM;WHM8F]R9&5R+7)A
M9&EU<RUB;W1T;VUR:6=H=#H@,35P>#L*("`@('!A9&1I;F<M=&]P.B`U<'@[
M"B`@("!P861D:6YG+6)O='1O;3H@,3!P>#L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-E964["GT*(W-I9&5B87)086YE;"!S<&%N('L*("`@('!A9&1I;F<Z
M(#)P>#L*?0HC<VED96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82![
M"B`@("!C;VQO<CH@(S`P,#L*("`@('=H:71E+7-P86-E.B!P<F4["B`@("!F
M;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@
M(&9O;G0M<VEZ93H@,3%P>#L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*
M?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@+6UO>BUB;W)D97(M<F%D
M:75S.B`S<'@["B`@("!C;VQO<CH@(S`P,#L*?0H*+RH@5&%B('-T>6QE<RX@
M*B\*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-F9F8["GT*+G1A8G-E="!L:2YA8W1I=F5486(@82P@+G1A8G-E="!L:2YA
M8W1I=F5486(@83IH;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-#0V
M.PH@("`@8F]R9&5R+6)O='1O;2UC;VQO<CH@(S0T-CL*?0H*+RH@4')E9F5R
M96YC97,@;W9E<G9I97<N("HO"BYP<F5F<T]V97)V:65W(&@R('L*("`@(&-O
M;&]R.B`C9F9F.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+P``````````````````````
M```````````````````````````````````````````````````P,#0P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,3`V-P`P,C`R
M,S$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8G5R;G1O<F%N9V4O
M:6YF;RYP:'``````````````````````````````````````````````````
M`````````````#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#$P
M`#$P-3$U-#,Q,#8W`#`R,38V-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE;64@8GDZ($5R:6,@
M2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N
M961U/@H@*B!0;&5A<V4@8V]N=&%C="!T:&4@=&AE;64G<R!A=71H;W(@9F]R
M(&%N>2!M:7-S:6YG('-T>6QE+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE
M<R]B=7)N=&]R86YG92]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S
M.C,U(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D)U<FYT
M($]R86YG92(I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+W-C<F5E;BYC<W,`
M```````````````````````````````````````````````````````````P
M,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0Q-P`Q,#4Q-30S,3`V
M-P`P,C(R,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RHJ"B`J(%1H96UE(&)Y.B!%<FEC($IO;B!2;W-T971T97(@/&5R
M:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@4&QE87-E(&-O
M;G1A8W0@=&AE('1H96UE)W,@875T:&]R(&9O<B!A;GD@;6ES<VEN9R!S='EL
M92X*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8G5R;G1O<F%N9V4O<V-R
M965N+F-S<RQV(#$N-BXV+C,@,C`P-2\Q,"\Q."`Q,3HS-#HQ,B!J86X@17AP
M("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F,&(P-C`["GT*82![
M"B`@("!C;VQO<CH@(V,V,#L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C8S8P
M.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD
M.B`C8S8P.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0H*+G-M
M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@
M(V,V,#L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9CEC93AA.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-C-C`["GT*+F)U='1O;B![
M"B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C-C`["B`@("!B
M;W)D97(M8F]T=&]M+6-O;&]R.B`C,S`P.PH@("`@8F]R9&5R+7)I9VAT+6-O
M;&]R.B`C,S`P.PH@("`@8F]R9&5R+71O<"UC;VQO<CH@(V8P8C`V,#L*("`@
M(&)O<F1E<BUL969T+6-O;&]R.B`C9C!B,#8P.PI]"BYS96QE8W1E9"!["B`@
M("!B86-K9W)O=6YD.B`C9&8Y9C-F.PI]"F$N<VUA;&QH96%D97(Z:&]V97(@
M>PH@("`@8V]L;W(Z("-F9F8["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N
M=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C-C`["GT*
M(VUE;G4@83IH;W9E<B!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(V8P8C`V,#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F,&(P-C`[
M"B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S,P,#L*("`@(&)O<F1E<BUL
M969T.B`Q<'@@<V]L:60@(S,P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N
M=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-D9CEF,V8["B`@("!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@(&)O<F1E<BUR
M:6=H=#H@,7!X('-O;&ED("-F,&(P-C`["B`@("!B;W)D97(M=&]P.B`Q<'@@
M<V]L:60@(S,P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S,P,#L*
M("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"F)O
M9'DN<VED96)A<B!["B`@("!B86-K9W)O=6YD.B`C9C!B,#8P.PI]"B-S:61E
M8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V8P8C`V
M,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9C!B,#8P.PH@("`@
M8F%C:V=R;W5N9#H@(V8P8C`V,#L*?0HC<VED96)A<E!A;F5L(&$@>PH@("`@
M8F]R9&5R.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@('!A9&1I;F<M;&5F=#H@
M,7!X.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#)P>#L*?0HC<VED96)A<E!A;F5L
M(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",Y,#`["B`@("!B86-K9W)O=6YD.B!Y
M96QL;W<["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@=&5X="UD
M96-O<F%T:6]N.B!N;VYE.PI]"@HO*B!486(@<W1Y;&5S+B`J+PHN=&%B<V5T
M(&QI+F%C=&EV951A8B!A+"`N=&%B<V5T(&QI+F%C=&EV951A8B!A.FAO=F5R
M('L*("`@(&)A8VMG<F]U;F0Z("-C-C`["B`@("!B;W)D97(M8F]T=&]M+6-O
M;&]R.B`C8S8P.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]R=&PN8W-S````````````````````````````
M````````````````````````````````````````````````````,#$P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S,#``,3`U,34T,S$P-C<`,#$W
M,C`U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]R=&PN8W-S+'8@,2XR+C(N
M,2`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@
M("`@9&ER96-T:6]N.B!R=&P["B`@("!F;VYT+69A;6EL>3H@5&%H;VUA+$MO
M;V1A:RQ(;VUA+$YA>FQI+%9E<F1A;F$L1V5N979A+$%R:6%L+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PI]"@HN;&5F=$%L:6=N('L*("`@("`@("!T97AT+6%L
M:6=N.B!R:6=H=#L*("`@("`@("!F;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A
M:RQ(;VUA+$YA>FQI+%9E<F1A;F$L1V5N979A+$%R:6%L+$AE;'9E=&EC82QS
M86YS+7-E<FEF.PI]"BYR:6=H=$%L:6=N('L*("`@("`@("!T97AT+6%L:6=N
M.B!L969T.PH@("`@("`@(&9O;G0M9F%M:6QY.B!486AO;6$L2V]O9&%K+$AO
M;6$L3F%Z;&DL5F5R9&%N82Q'96YE=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M
M<V5R:68["GT*"BYL969T1FQO870@>PH@("`@("`@(&9L;V%T.B!R:6=H=#L*
M?0HN<FEG:'1&;&]A="!["B`@("`@("`@9FQO870Z(&QE9G0["GT*"BYH96%D
M97(@=6P@>PH@("`@9FQO870Z(&QE9G0["B`@("!T97AT+6%L:6=N.B!L969T
M.PI]"@HO*B!486(@<W1Y;&5S+B`J+PHN=&%B<V5T('L*("`@(&9L;V%T.B!R
M:6=H=#L*?0HN=&%B<V5T(&QI('L*("`@(&9L;V%T.B!R:6=H=#L*?0HN=&%B
M<V5T(&EM9R!["B`@("!F;&]A=#H@<FEG:'0["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I935M86,N8W-S````````````````
M````````````````````````````````````````````````````````````
M,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,S0`,3`U,34T,S$P
M-C<`,#$W-34W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]I935M86,N8W-S
M+'8@,2XR+C0N,R`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@
M*B!#4U,@8V]R<F5C=&EO;G,@9F]R($E%-2]-86,N"B`J+PH*(VUE;G4@;&D@
M>PH@("`@=VED=&@Z(#0P<'@["GT*+G1A8G-E="!["B`@("!W:&ET92US<&%C
M93H@;F]W<F%P.PI]"BYT86)S970@;&D@82!["B`@("!F;&]A=#H@;&5F=#L*
M?0HC<VED96)A<E!A;F5L('L*("`@('!A9&1I;F<M8F]T=&]M.B`S,'!X.PI]
M"BYH96%D97(@>PH@("`@8VQE87(Z(&YO;F4["GT*+FAE861E<B!U;"!["B`@
M("!W:61T:#H@,24["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O;6]Z,30N8W-S````````````````````````````````
M`````````````````````````````````````````````#`Q,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C8P`#$P-3$U-#,Q,#8W`#`Q-S,V,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;6]Z,30N8W-S+'8@,2XQ+C(N,B`R
M,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#4U,@8V]R<F5C
M=&EO;G,@9F]R($UO>FEL;&$@/#T@,2XT+@H@*B\*"B-M96YU('L*("`@(&]V
M97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT.B`U,'!X.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V]P97)A+F-S<P``````````````````````````````````````````````
M```````````````````````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#,S-@`Q,#4Q-30S,3`V-P`P,3<U,C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J("1(;W)D93H@
M:&]R9&4O=&AE;65S+V]P97)A+F-S<RQV(#$N,2XR+C0@,C`P-2\Q,"\Q."`Q
M,3HS-#HQ,"!J86X@17AP("0*("H*("H@0U-3(&-O<G)E8W1I;VYS(&9O<B!/
M<&5R82X*("HO"@HN=')E95)O=R!["B`@("!O=F5R9FQO=SH@=FES:6)L93L*
M("`@(&AE:6=H=#H@,C!P>#L*?0H*(VUE;G4@>PH@("`@;W9E<F9L;W<Z('9I
M<VEB;&4["B`@("!H96EG:'0Z(#4P<'@["GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]S869A<FDN8W-S
M````````````````````````````````````````````````````````````
M````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T
M-C4`,3`U,34T,S$P-C<`,#$W-C8T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE
M<R]S869A<FDN8W-S+'8@,2XQ+C(N-B`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA
M;B!%>'`@)`H@*@H@*B!#4U,@8V]R<F5C=&EO;G,@9F]R(%-A9F%R:2X*("HO
M"@II;6<@>PH@("`@=F5R=&EC86PM86QI9VXZ(&)A<V5L:6YE.PI]"@HN=')E
M95)O=R!["B`@("!O=F5R9FQO=SH@=FES:6)L93L*("`@(&AE:6=H=#H@,C!P
M>#L*?0H*+G1R9652;W<@:6UG('L*("`@('9E<G1I8V%L+6%L:6=N.B!M:61D
M;&4["GT*"B-M96YU('L*("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I
M9VAT.B`U,'!X.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O<V-R965N+F-S<P``````````````
M````````````````````````````````````````````````````````````
M`#`Q,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(W-S0Q`#$P-3$U-#,Q
M,#8W`#`Q-S<P-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<V-R965N+F-S
M<RQV(#$N-RXT+C4W(#(P,#8O,#8O,3$@,C$Z,S0Z,C<@8VAU8VL@17AP("0*
M("HO"@HO*B!';&]B86P@9&5F875L="!S='EL97,N("HO"BH@>PH@("`@+RH@
M6F5R;R!O=70@86QL('!A9&1I;F<@86YD(&UA<F=I;G,@=&\@<W1A<G0@=VET
M:"!F;W(@8F5T=&5R"B`@("`@*B!C<F]S<RUB<F]W<V5R(&-O;G1R;VPN("HO
M"B`@("!P861D:6YG.B`P.PH@("`@;6%R9VEN.B`P.PI]"@IB;V1Y('L*("`@
M(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R
M:68["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!B86-K9W)O=6YD.B`C9F9F
M.PH@("`@8V]L;W(Z(",P,#`["GT*"F)O9'DN<V-R;VQL8F%R+7%U:7)K('L*
M("`@(&UA<F=I;BUR:6=H=#H@,35P>#L*?0H*<"!["B`@("!M87)G:6XM8F]T
M=&]M.B`Q,'!X.PI]"@II;6<L("YI;6<L("YI;6<Z86-T:79E+"`N:6UG.FAO
M=F5R+"`N:6UG.G9I<VET960@>PH@("`@8F]R9&5R.B!N;VYE.PH@("`@=F5R
M=&EC86PM86QI9VXZ(&UI9&1L93L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R
M96YT.PI]"@II;G,@>PH@("`@8F%C:V=R;W5N9#H@(V-F8SL*?0ID96P@>PH@
M("`@8F%C:V=R;W5N9#H@(V9C8SL*?0H*8G(N<W!A8V5R('L*("`@(&9O;G0M
M<VEZ93H@.'!X.PI]"@HN;&5F=$%L:6=N('L*("`@('1E>'0M86QI9VXZ(&QE
M9G0["GT*+G)I9VAT06QI9VX@>PH@("`@=&5X="UA;&EG;CH@<FEG:'0["GT*
M+FQE9G1&;&]A="!["B`@("!F;&]A=#H@;&5F=#L*?0HN<FEG:'1&;&]A="![
M"B`@("!F;&]A=#H@<FEG:'0["GT*"BYB;W@@>PH@("`@<&%D9&EN9SH@,W!X
M.PH@("`@8F]R9&5R.B`Q<'@@9&%S:&5D(",Y.3D["B`@("!B86-K9W)O=6YD
M.B`C9F9F.PI]"BYS;VQI9&)O>"!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M,#`P.PI]"BYG<F5Y8F]X('L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`[
M"B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYH96%D97)B;W@@>PH@("`@
M8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+7)I9VAT
M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*?0HN<F]U;F1E9$)O>"![
M"B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#$U<'@["GT*+G)O=6YD9614;W`@
M>PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O<')I9VAT.B`Q-7!X.PH@("`@
M+6UO>BUB;W)D97(M<F%D:75S+71O<&QE9G0Z(#$U<'@["GT*+G)O=6YD961"
M;W1T;VT@>PH@("`@+6UO>BUB;W)D97(M<F%D:75S+6)O='1O;7)I9VAT.B`Q
M-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+6)O='1O;6QE9G0Z(#$U<'@[
M"GT*+FAE861E<B!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I
M8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@9F]N
M="US:7IE.B`Q-7!X.PH@("`@<&%D9&EN9SH@,W!X.PI]"BYH96%D97(@83IH
M;W9E<BP@82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z(",S,S,["GT*+FAE
M861E<B!I;6<@>PH@("`@=F5R=&EC86PM86QI9VXZ(&)O='1O;3L*?0HN:&5A
M9&5R('5L('L*("`@(&9L;V%T.B!R:6=H=#L*("`@('1E>'0M86QI9VXZ(')I
M9VAT.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"BYH96%D97(@;&D@>PH@("`@
M;&ES="US='EL93H@;F]N93L*("`@(&1I<W!L87DZ(&EN;&EN93L*?0HN;F]W
M<F%P('L*("`@('=H:71E+7-P86-E.B!N;W=R87`["GT*+F-L96%R('L*("`@
M(&-L96%R.B!B;W1H.PH@("`@;&EN92UH96EG:'0Z(#`["B`@("!H96EG:'0Z
M(#`["GT*"F$@>PH@("`@8V]L;W(Z(&)L=64["B`@("!T97AT+61E8V]R871I
M;VXZ(&YO;F4["GT*83IH;W9E<B!["B`@("!T97AT+61E8V]R871I;VXZ('5N
M9&5R;&EN93L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(V)B8V)F
M9CL*?0HN<V5L96-T960M;W9E<B!["B`@("!B86-K9W)O=6YD.B`C8V5F.PI]
M"@HO*B!486)L92!S='EL97,N("HO"G1A8FQE('L*("`@(&)O<F1E<CH@;F]N
M93L*?0IT9"P@=&@@>PH@("`@<&%D9&EN9SH@,7!X.PI]"G1H('L*("`@(&-O
M;&]R.B`C,S,S.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A
M+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["GT*=&0@>PH@("`@
M9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N="UF86UI;'DZ($=E;F5V82Q!<FEA
M;"Q(96QV971I8V$L<V%N<RUS97)I9CL*?0IU;"YL:6YE9%)O=R!["B`@("!L
M:7-T+7-T>6QE+71Y<&4Z(&YO;F4["GT*+FQI;F5D4F]W+"!T<BYL:6YE9%)O
M=R!T9"P@=&%B;&4N;&EN9612;W<@=&0L('5L+FQI;F5D4F]W(&QI('L*("`@
M(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D.PI]"G1A8FQE+FQI;F5D4F]W+"!U
M;"YL:6YE9%)O=R!["B`@("!B;W)D97(M8F]T=&]M.B!N;VYE.PI]"BYL:6YE
M9%)O=U-E;&5C=&5D0V]L+"!T9"YL:6YE9%)O=U-E;&5C=&5D0V]L+"!T86)L
M92YL:6YE9%)O=R!T9"YL:6YE9%)O=U-E;&5C=&5D0V]L('L*("`@(&-O;&]R
M.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V8S9C-F,SL*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C9&1D.PI]"BYS96QE8W1E9%)O=RP@='(N<V5L
M96-T9612;W<@=&0@>PH@("`@8F%C:V=R;W5N9#H@(V9F8SL*?0HN<V5L96-T
M9612;W<Z:&]V97(L('1R+G-E;&5C=&5D4F]W('1D.FAO=F5R+"`N<V5L96-T
M9612;W<M;W9E<BP@='(N<V5L96-T9612;W<M;W9E<B!T9"!["B`@("!B86-K
M9W)O=6YD.B`C9F9D.PI]"G1A8FQE+FYO<&%D9&EN9R!T9"P@=&%B;&4N;F]P
M861D:6YG('1H('L*("`@('!A9&1I;F<Z(#`["GT*+G-O<G1U<"!["B`@("!B
M86-K9W)O=6YD.B`C8F)C8F9F('5R;"@B9W)A<&AI8W,O>F$N<&YG(BD@8V5N
M=&5R(&QE9G0@;F\M<F5P96%T.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PI]
M"BYS;W)T9&]W;B!["B`@("!B86-K9W)O=6YD.B`C8F)C8F9F('5R;"@B9W)A
M<&AI8W,O87HN<&YG(BD@8V5N=&5R(&QE9G0@;F\M<F5P96%T.PH@("`@<&%D
M9&EN9RUL969T.B`Q,'!X.PI]"B\J($%L=&5R;F%T:6YG('-T>6QE<RX@:71E
M;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN<W1R:7!E9"P@+G)O=T5V
M96XL("YI=&5M,"!["B`@("!B86-K9W)O=6YD.B`C965E.PI]"BYR;W=/9&0L
M("YI=&5M,2!["B`@("!B86-K9W)O=6YD.B`C9&1D.PI]"@HN=VED9V5T('L*
M("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF
M.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]"@HN;6EM95-T871U<TUE<W-A9V4@
M>PH@("`@<&%D9&EN9SH@,7!X.PH@("`@;6%R9VEN+6)O='1O;3H@-'!X.PH@
M("`@8F]R9&5R.B`Q<'@@9&%S:&5D(",P,&,["B`@("!B86-K9W)O=6YD.B`C
M965F.PH@("`@8V]L;W(Z(",P,#8["GT*+FUI;653=&%T=7-787)N:6YG('L*
M("`@('!A9&1I;F<Z(#%P>#L*("`@(&UA<F=I;BUB;W1T;VTZ(#1P>#L*("`@
M(&)O<F1E<CH@,7!X(&1A<VAE9"`C9C`P.PH@("`@8F%C:V=R;W5N9#H@(V9F
M9#!A9CL*("`@(&-O;&]R.B`C9C`P.PI]"@HN;&EG:'0@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"BYS;6%L;&AE
M861E<B!["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N="UW
M96EG:'0Z(&)O;&0["GT*<VUA;&PL("YS;6%L;"!["B`@("!F;VYT+7-I>F4Z
M(#$P<'@["GT*+F-O;G1R;VP@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K
M9W)O=6YD.B`C8V-C.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",Y
M.3D["GT*+FET96T@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD
M.B`C965E.PI]"BYA8V-E<W-+97D@>PH@("`@=&5X="UD96-O<F%T:6]N.B!U
M;F1E<FQI;F4["GT*+G1E>'0@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K
M9W)O=6YD.B`C9F9F.PI]"@HO*B!&;W)M('-T>6QE<RX@*B\*+F9O<FT@=&%B
M;&4@>PH@("`@=VED=&@Z(#$P,"4["B`@("!P861D:6YG.B`R<'@["B`@("!B
M;W)D97(M8V]L;&%P<V4Z(&-O;&QA<'-E.PI]"BYH=&UL87)E82`N<W1A='5S
M0F%R("YS=&%T=7-"87)4<F5E(&$@>PH@("`@9F]N=#H@:6YH97)I=#L*?0HN
M:'1M;&%R96$@=&%B;&4@>PH@("`@=VED=&@Z(&%U=&\["GT*+F9O<FTM97)R
M;W(@>PH@("`@8V]L;W(Z("-F,#`["GT*:6YP=70L('-E;&5C="!["B`@("!F
M;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF
M.PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N="UW96EG:'0Z(&YO<FUA
M;#L*?0II;G!U="!["B`@("!P861D:6YG.B`Q<'@["GT*;W!T:6]N('L*("`@
M('!A9&1I;F<Z(#!P>"`U<'@@,'!X(#-P>#L*?0HN8VAE8VMB;W@@>PH@("`@
M8F]R9&5R.B`P.PH@("`@:&5I9VAT.B`Q-'!X.PH@("`@=VED=&@Z(#$T<'@[
M"B`@("!B86-K9W)O=6YD.B!T<F%N<W!A<F5N=#L*?0HN8G5T=&]N('L*("`@
M(&9O;G0M<VEZ93H@,3%P>#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE
M;'9E=&EC82QS86YS+7-E<FEF.PI]"F$N8G5T=&]N('L*("`@('!A9&1I;F<Z
M(#)P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P["B`@("!T97AT+61E8V]R
M871I;VXZ(&YO;F4["GT*"BYF:7AE9"!["B`@("!F;VYT+7-I>F4Z(#$S<'@[
M"B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E+&9I>&5D.PI]"@HO*B!3='EL
M97,@9F]R(&5M86EL+6QI:V4@;65S<V%G97,N("HO"BYS:6=N871U<F4@>PH@
M("`@8V]L;W(Z("-C8V,["GT*+G-I9VYA='5R92UF:7AE9"!["B`@("!C;VQO
M<CH@(V-C8SL*("`@(&9O;G0M<VEZ93H@,3-P>#L*("`@(&9O;G0M9F%M:6QY
M.B!M;VYO<W!A8V4L9FEX960["GT*+F-I=&%T:6]N('L*("`@(&UA<F=I;CH@
M,65M(#`["B`@("!P861D:6YG+6QE9G0Z(#%E;3L*("`@(&)O<F1E<BUL969T
M+7=I9'1H.B`Q<'@["B`@("!B;W)D97(M;&5F="US='EL93H@<V]L:60["GT*
M+G%U;W1E9#$@>PH@("`@8V]L;W(Z(",V,#8["B`@("!B;W)D97(M;&5F="UC
M;VQO<CH@(S8P-CL*?0HN<75O=&5D,B!["B`@("!C;VQO<CH@(S`W-SL*("`@
M(&)O<F1E<BUL969T+6-O;&]R.B`C,#<W.PI]"BYQ=6]T960S('L*("`@(&-O
M;&]R.B`C.3`P.PH@("`@8F]R9&5R+6QE9G0M8V]L;W(Z(",Y,#`["GT*+G%U
M;W1E9#0@>PH@("`@8V]L;W(Z(",P,#D["B`@("!B;W)D97(M;&5F="UC;VQO
M<CH@(S`P.3L*?0HN<75O=&5D-2!["B`@("!C;VQO<CH@(V(V,#L*("`@(&)O
M<F1E<BUL969T+6-O;&]R.B`C8C8P.PI]"@HO*B!687)I;W5S('!O<'5P(&%N
M9"!S=&%T=7,@;&%Y97)S+B`J+PHN;F]T:6-E('L*("`@(&9O;G0M=V5I9VAT
M.B!B;VQD.PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C9F9C
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V%A83L*("`@('!A9&1I;F<Z(#%P
M>#L*("`@('!A9&1I;F<M;&5F=#H@-7!X.PH@("`@;6%R9VEN+6)O='1O;3H@
M,7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`X<'@["GT*+G1O;VQT:7`L
M(&1I=BYN:6-E=&ET;&4@>PH@("`@9F]N=#H@,3%P>"\Q,G!X(%9E<F1A;F$L
M07)I86PL<V5R:68["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z
M("-F9F,["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN
M9SH@-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`S<'@["GT*9&EV+FYI
M8V5T:71L92!["B`@("!P;W-I=&EO;CH@86)S;VQU=&4["B`@("!O=F5R9FQO
M=SH@:&ED9&5N.PH@("`@;W!A8VET>3H@+CDP.PI]"F1I=BYN:6-E=&ET;&4@
M<')E('L*("`@(&9O;G0M9F%M:6QY.B`B3'5C:61A($-O;G-O;&4B+&UO;F]S
M<&%C92QF:7AE9#L*?0HN:6Y0<F]G<F5S<R!["B`@("!F;VYT.B`Q,'!X($=E
M;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@('!A9&1I;F<Z
M(#)P>#L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V8P,#L*
M?0H*+RH@5')E92!S='EL97,N("HO"BYT<F5E4F]W('L*("`@(&]V97)F;&]W
M.B!H:61D96X["B`@("!M:6XM:&5I9VAT.B`R,'!X.PH@("`@8VQE87(Z(&)O
M=&@["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!O=F5R9FQO
M=SH@:&ED9&5N.PH@("`@;6EN+6AE:6=H=#H@-3!P>#L*("`@(&9O;G0M9F%M
M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@;6%R9VEN
M+6)O='1O;3H@.'!X.PI]"B-M96YU('5L('L*("`@('!A9&1I;F<Z(#5P>#L*
M?0HC;65N=2!L:2!["B`@("!L:7-T+7-T>6QE+71Y<&4Z(&YO;F4["B`@("!T
M97AT+6%L:6=N.B!C96YT97(["B`@("!M87)G:6XZ(#)P>#L*("`@(&9L;V%T
M.B!L969T.PI]"B-M96YU(&$@>PH@("`@9&ES<&QA>3H@8FQO8VL["B`@("!W
M:&ET92US<&%C93H@<')E.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L
M=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["B`@("!T
M97AT+61E8V]R871I;VXZ(&YO;F4["B`@("!P861D:6YG.B`S<'@["B`@("`M
M;6]Z+6)O<F1E<BUR861I=7,Z(#-P>#L*?0HC;65N=2!H,2!["B`@("!F;VYT
M+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O
M;G0M=V5I9VAT.B!B;VQD.PH@("`@9F]N="US:7IE.B`Q.'!X.PH@("`@;&EN
M92UH96EG:'0Z(#0X<'@["B`@("!V97)T:6-A;"UA;&EG;CH@8F]T=&]M.PI]
M"B-M96YU(&EN<'5T+"`C;65N=2!S96QE8W0@>PH@("`@;6%R9VEN+71O<#H@
M,39P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"BYS:61E8F%R("-M96YU
M('L*("`@(&UA<F=I;CH@,#L*?0HC<VED96)A<E!A;F5L('L*("`@("UM;WHM
M8F]R9&5R+7)A9&EU<RUB;W1T;VUR:6=H=#H@,35P>#L*("`@('!A9&1I;F<M
M=&]P.B`U<'@["B`@("!P861D:6YG+6)O='1O;3H@,3!P>#L*("`@(&)A8VMG
M<F]U;F0Z("-E964["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"B-S:61E
M8F%R4&%N96P@<W!A;BP@(W-I9&5B87)086YE;"!A('L*("`@(&-O;&]R.B`C
M,#`P.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@(&9O;G0M9F%M:6QY.B!6
M97)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q
M,7!X.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"B-S:61E8F%R4&%N
M96P@<W!A;BYT;V=G;&4@>PH@("`@8W5R<V]R.B!P;VEN=&5R.PI]"B-S:61E
M8F%R4&%N96P@83IH;W9E<B!["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#-P
M>#L*("`@(&-O;&]R.B`C,#`P.PI]"@HO*B!086=E<BX@*B\*+G!A9V5R('L*
M("`@('1E>'0M86QI9VXZ(&-E;G1E<CL*?0H*+RH@5&%B('-T>6QE<RX@*B\*
M+G1A8G-E="!["B`@("!F;&]A=#H@;&5F=#L*("`@('=I9'1H.B`Q,#`E.PH@
M("`@9F]N="UW96EG:'0Z(&)O;&0["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R
M87!H:6-S+W1A8E]B;W1T;VTN9VEF(BD@<F5P96%T+7@@8F]T=&]M.PI]"BYT
M86)S970@=6P@>PH@("`@;6%R9VEN+71O<#H@-'!X.PH@("`@<&%D9&EN9RUL
M969T.B`Q,'!X.PH@("`@;&ES="US='EL93H@;F]N93L*?0HN=&%B<V5T(&QI
M('L*("`@(&9L;V%T.B!L969T.PH@("`@;6%R9VEN+71O<#H@+3-P>#L*("`@
M(&UA<F=I;BUL969T.B`R<'@["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]
M"BYT86)S970@;&D@82!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-E.64Y93D["B`@("!P861D:6YG.B`R<'@@,"XU96T["B`@
M("!D:7-P;&%Y.B!B;&]C:SL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`[
M"B`@("!B;W)D97(M8F]T=&]M+6-O;&]R.B`C93EE.64Y.PH@("`@+6UO>BUB
M;W)D97(M<F%D:75S+71O<&QE9G0Z(#$P<'@["B`@("`M;6]Z+6)O<F1E<BUR
M861I=7,M=&]P<FEG:'0Z(#$P<'@["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*
M("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-F9F8["GT*+G1A8G-E="!L:2YA8W1I=F5486(@82!["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(",P,#`["B`@("!C;VQO<CH@(V9F9CL*?0HN=&%B<V5T(&QI+F%C=&EV
M951A8B!A.FAO=F5R('L*?0HN=&%B<V5T(&EM9R!["B`@("!D:7-P;&%Y.B!B
M;&]C:SL*("`@(&9L;V%T.B!L969T.PH@("`@<&%D9&EN9RUR:6=H=#H@,G!X
M.PI]"@HO*B!0<F5F97)E;F-E<R!O=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I
M97<@9&EV('L*("`@(&9L;V%T.B!L969T.PI]"BYP<F5F<T]V97)V:65W(&1I
M=B!D:78@>PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PH@("`@=VED=&@Z(#DU
M)3L*?0HN<')E9G-/=F5R=FEE=R!H,B!["B`@("!F;VYT+7-I>F4Z(#$X<'@[
M"B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*?0HN<')E9G-/=F5R=FEE=R!D="!A
M('L*("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@<&%D9&EN9SH@,G!X.PH@("`@
M9F]N="UW96EG:'0Z(&)O;&0["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",T-#8["B`@("!B86-K
M9W)O=6YD.B`C93EE.64Y.PI]"BYP<F5F<T]V97)V:65W(&1D('L*("`@('!A
M9&1I;F<Z(#)P>#L*("`@(&UA<F=I;BUB;W1T;VTZ(#$P<'@["B`@("!C;VQO
M<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!B;W)D97(M;&5F
M=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI
M9"`C,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["GT*
M"B\J($)L;V-K('-T>6QE<RX@*B\*+F-U<G)E;G1";&]C:R!["B`@("!B;W)D
M97(Z(#)P>"!S;VQI9"!R960["GT*"B\J($AE;'`@<W1Y;&5S+B`J+PHN:&5L
M<"!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8V]L;W(Z(",P,#`["GT*
M+FAE;'`@:#$@>PH@("`@9F]N="US:7IE.B`Q-7!X.PH@("`@<&%D9&EN9RUT
M;W`Z(#`N-65M.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#`N-65M.PI]"BYH96QP
M(&@R('L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C-#0V.PH@("`@<&%D
M9&EN9RUT;W`Z(#%E;3L*("`@('!A9&1I;F<M8F]T=&]M.B`P+C5E;3L*("`@
M(&9O;G0M<VEZ93H@,3-P>#L*?0HN:&5L<"!P('L*("`@(&UA<F=I;BUL969T
M.B`Q96T["B`@("!M87)G:6XM<FEG:'0Z(#%E;3L*("`@(&UA<F=I;BUB;W1T
M;VTZ(#%E;3L*?0HN:&5L<"!E;2!["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@
M('!A9&1I;F<Z(#5P>#L*("`@(&UA<F=I;BUL969T.B`Q96T["B`@("!M87)G
M:6XM<FEG:'0Z(#%E;3L*("`@(&UA<F=I;BUB;W1T;VTZ(#%E;3L*?0HN:&5L
M<"!E;2YH96QP5&EP('L*("`@(&-O;&]R.B`C,#DP.PH@("`@8F%C:V=R;W5N
M9#H@(V4P9C!E,#L*?0HN:&5L<"!E;2YH96QP5V%R;B!["B`@("!C;VQO<CH@
M(SDP,#L*("`@(&)A8VMG<F]U;F0Z("-F,&4P93`["GT*"B\J(%-O=7)C92!M
M87)K=7`@<W1Y;&5S+B`J+PIT86)L92YL:6YE3G5M8F5R960@>PH@("`@;6%R
M9VEN.B`U<'@["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PI]"BYL:6YE
M3G5M8F5R960@=&@@>PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED("-E,&4P93`["B`@("!B;W)D97(M;&5F
M=#H@,7!X('-O;&ED("-F,V8S9C,["B`@("!P861D:6YG+6QE9G0Z(#$P<'@[
M"B`@("!P861D:6YG+7)I9VAT.C$P<'@["B`@("!T97AT+6%L:6=N.B!R:6=H
M=#L*?0HN;&EN94YU;6)E<F5D('1H(&$@>PH@("`@9F]N="UF86UI;'DZ(&UO
M;F]S<&%C93L*("`@(&9O;G0M<VEZ93H@,3)P>#L*("`@(&QI;F4M:&5I9VAT
M.B`Q-G!X.PI]"BYL:6YE3G5M8F5R960@=&0@>PH@("`@=F5R=&EC86PM86QI
M9VXZ('1O<#L*("`@('=I9'1H.B`Q,#`E.PH@("`@=VAI=&4M<W!A8V4Z('!R
M93L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!P861D:6YG+6QE9G0Z(#$P
M<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E.PH@("`@9F]N="US:7IE
M.B`Q,G!X.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@(&QI;F4M:&5I9VAT
M.B`Q-G!X.PI]"BYP87)E;G1H97-E<R!["B`@("!C;VQO<CH@(S)A-CL*("`@
M(&9O;G0M=V5I9VAT.B!B;VQD.PI]"BYC;VUM96YT('L*("`@(&-O;&]R.B`C
M86%C.PI]"BYH=&%G('L*("`@(&-O;&]R.B`C-38Y.PH@("`@8F%C:V=R;W5N
M9#H@(V0U9#9D83L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]"BYM971A8R![
M"B`@("!C;VQO<CH@(S!F9CL*("`@(&)A8VMG<F]U;F0Z("-D-60V9&$["GT*
M+FED('L*("`@(&-O;&]R.B`C93@R.PH@("`@8F%C:V=R;W5N9#H@(V4T931E
M,#L*?0HN871T<B!["B`@("!C;VQO<CH@(S9A9CL*?0HN=F%L=64@>PH@("`@
M8V]L;W(Z("-D-#8["GT*+F-O;&]R('L*("`@(&-O;&]R.B`C9C4W.PI]"BYE
M;VP@>PH@("`@8V]L;W(Z(",R-F4["GT*+G5R;"!["B`@("!C;VQO<CH@(SDV
M,CL*?0HN9FEL92!["B`@("!C;VQO<CH@(S0T-#L*("`@(&)A8VMG<F]U;F0Z
M("-F930["GT*+F-L87-S('L*("`@(&9O;G0M<W1Y;&4Z(&ET86QI8SL*?0H*
M+RH@1')O<"!S:&%D;W=S+B`J+PHN9')O<%-H861O=R!["B`@("!F;&]A=#H@
M;&5F=#L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O<VAA9&]W+G!N
M9R(I(&YO+7)E<&5A="!B;W1T;VT@<FEG:'0@(6EM<&]R=&%N=#L*("`@(&)A
M8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O<VAA9&]W+F=I9B(I(&YO+7)E<&5A
M="!B;W1T;VT@<FEG:'0["B`@("!M87)G:6XZ(#$P<'@@,"`P(#5P>#L*?0H*
M+F1R;W!3:&%D;W<@:6UG('L*("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@<&]S
M:71I;VXZ(')E;&%T:79E.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O
M<F1E<CH@,7!X('-O;&ED(",V-C8["B`@("!M87)G:6XZ("TS<'@@-7!X(#5P
M>"`M,W!X.PH@("`@<&%D9&EN9SH@,G!X.PI]"@HO*B!N97=S9F5E9',@*B\*
M"BYS:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@
M(S`P-CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`V.PH@("`@
M8F%C:V=R;W5N9#H@(V4Y93EF9CL*("`@(&9O;G0M9F%M:6QY.B!697)D86YA
M+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]
M"@HN<VED96)A<DAE861E<B!["B`@8F%C:V=R;W5N9"UC;VQO<CH@(S9E.#ED
M9#L*?0H*+FAE861E<E1I=&QE('L*("!C;VQO<CH@(V9F9CL*("!P861D:6YG
M.B`S<'@@-W!X.PH@('=H:71E+7-P86-E.B!N;W=R87`["B`@9F]N="UW96EG
M:'0Z(&)O;&0["GT*+FAE861E<D)U='1O;G,@>PH@('1E>'0M86QI9VXZ(')I
M9VAT.PI]"BYH96%D97)"=71T;VYS(&$@>PH@(&]V97)F;&]W.B!H:61D96X[
M"B`@=VED=&@Z(#$V<'@["B`@:&5I9VAT.B`Q-G!X.PH@(&1I<W!L87DZ("UM
M;WHM:6YL:6YE+6)O>#L*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL["B`@=F5R
M=&EC86PM86QI9VXZ(&UI9&1L93L*("!B86-K9W)O=6YD+7)E<&5A=#H@;F\M
M<F5P96%T.PH@(&UA<F=I;BUR:6=H=#H@-W!X.PI]"BYH96%D97)"=71T;VYS
M(&$@<W!A;B!["B`@<&%D9&EN9RUL969T.B`Q,#!P>#L*("!D:7-P;&%Y.B!B
M;&]C:SL*?0HN8G1N+7)E9G)E<V@@>PH@(&)A8VMG<F]U;F0M:6UA9V4Z('5R
M;"@G+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R969R97-H+F=I9B<I.PI]"BY.
M1F-L;W-E("-N97=S1F5E9',@>PH@(&1I<W!L87DZ(&YO;F4["GT*+DY&;W!E
M;B`N8G1N+6]P96XM8VQO<V4@>PH@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"@G
M+W1H96UE<R]G<F%P:&EC<R]I;6%G92]A<G)O=RUD;W=N+F=I9B<I.PI]"BY.
M1F-L;W-E("YB=&XM;W!E;BUC;&]S92!["B`@8F%C:V=R;W5N9"UI;6%G93H@
M=7)L*"<O=&AE;65S+V=R87!H:6-S+VEM86=E+V%R<F]W+75P+F=I9B<I.PI]
M"BY.1G1I=&QE('L*9F]N="UW96EG:'0Z(&)O;&0["F1I<W!L87DZ(&)L;V-K
M.PI]"BY.1FET96T@>PID:7-P;&%Y.B!B;&]C:SL*;6%R9VEN+6)O='1O;3H@
M-7!X.PI]"BY.1G-O=7)C92!["FUA<F=I;BUR:6=H=#H@-7!X.PI]"BY.1G-T
M871U<R!["FUA<F=I;BUR:6=H=#H@-7!X.PIF;VYT+7=E:6=H=#H@8F]L9#L*
M?0HN3D9T:6UE('L*8V]L;W(Z(",S,S,["GT*(VYE=W-&965D<R!["G!A9&1I
M;F<Z(#5P>"`W<'@@-7!X(#=P>#L*?0H*"@``````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I
M939?;W)?;&5S<RYC<W,`````````````````````````````````````````
M````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`S-#,`,3`U,34T,S$P-C<`,#(P-C(S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1H96UE<R]I939?;W)?;&5S<RYC<W,L=B`Q+C$N,BXQ(#(P,#8O,#,O
M,C0@,#`Z-#`Z,S<@8VAU8VL@17AP("0*("H*("H@0U-3(&-O<G)E8W1I;VYS
M(&9O<B!)12X*("HO"@HN=')E95)O=R!["B`@("!O=F5R9FQO=SH@=FES:6)L
M93L*("`@(&AE:6=H=#H@,C!P>#L*?0H*(VUE;G4@>PH@("`@;W9E<F9L;W<Z
M('9I<VEB;&4["B`@("!H96EG:'0Z(#4P<'@["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]U=&EL+P``````````````````
M````````````````````````````````````````````````````````````
M`````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,Q,#8W`#`Q-3,W,P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W5T
M:6PO:6-O;E]B<F]W<V5R+G!H<```````````````````````````````````
M````````````````````````````````````,#$P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#4U,C<`,3`U,34T,S$P-C<`,#(P-C`U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W5T:6PO:6-O;E]B<F]W<V5R+G!H<"QV(#$N-"XR
M+C0@,C`P-B\P,2\P,2`R,3HR.3HQ-R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@
M=')U92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C
M;W)E+G!H<"<["@HD<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I
M.PHD87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H87)R87DH)VYO=&]O;&)A
M<B<L("=A8W1I=F4G+"`G861M:6XG+"`G:6YA8W1I=F4G+"`G:&ED9&5N)RDL
M('1R=64I.PIK<V]R="@D87!P<RD["@II9B`H*"1A<'`@/2!B87-E;F%M92A5
M=&EL.CIG971&;W)M1&%T82@G87!P)RDI*2`F)B!I<W-E="@D87!P<ULD87!P
M72DI('L*("`@("\O(%!R;W9I9&4@82!N;VXM=VAI=&4@8F%C:V=R;W5N9"!F
M;W(@97EE8F%L;&EN9R!T<F%N<W!A<F5N8WDN"B`@("!E8VAO("<\:'1M;#X\
M8F]D>2!B9V-O;&]R/2(C86%A86%A(CXG.PH*("`@("1T:&5M941I<B`]("1R
M96=I<W1R>2T^9V5T*"=T:&5M97-F<R<L("1A<'`I.PH@("`@:68@*"%I<U]D
M:7(H)'1H96UE1&ER*2D@>PH@("`@("`@(&5X:70H<W!R:6YT9BA?*")4:&5M
M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(BDL("1T:&5M941I<BDI
M.PH@("`@?0H*("`@("\O($)A<V4@9W)A<&AI8W,@9F]R(&YO=RP@9F5E;"!F
M<F5E('1O(&%D9"!T:&5M92!S=7!P;W)T+@H@("`@)&)A<V5D:7(@/2`D9&ER
M(#T@)'1H96UE1&ER("X@1$E214-43U)97U-%4$%2051/4B`N("=G<F%P:&EC
M<R<["B`@("!I9B`H(6ES7V1I<B@D9&ER*2D@>PH@("`@("`@(&5X:70H<W!R
M:6YT9BA?*")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(I+"`D9&ER*2D["B`@("!]"@H@("`@:68@*"@D<W5B9&ER(#T@8F%S
M96YA;64H571I;#HZ9V5T1F]R;41A=&$H)W-U8F1I<B<I*2DI('L*("`@("`@
M("`D9&ER("X]($1)4D5#5$]265]315!!4D%43U(@+B`D<W5B9&ER.PH@("`@
M("`@(&EF("@A:7-?9&ER*"1D:7(I*2!["B`@("`@("`@("`@(&5X:70H<W!R
M:6YT9BA?*")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB*2P@)&1I
M<BDI.PH@("`@("`@('T*("`@('T*"B`@("`O+R!"<F5A9&-R=6UB<RX*("`@
M(&5C:&\@2&]R9&4Z.FQI;FLH)VEC;VY?8G)O=W-E<BYP:'`G*2`N(%\H(D%P
M<&QI8V%T:6]N($QI<W0B*2`N("<\+V$^/&)R("\^)SL*("`@(&EF("@A96UP
M='DH)'-U8F1I<BDI('L*("`@("`@("!E8VAO($AO<F1E.CIL:6YK*"=I8V]N
M7V)R;W=S97(N<&AP/V%P<#TG("X@)&%P<"D@+B`D<F5G:7-T<GDM/F=E="@G
M;F%M92<L("1A<'`I("X@)SPO83X\8G(@+SXG.PH@("`@?0H@("`@96-H;R`G
M/&)R("\^)SL*"B`@("`O+R!3:&]W(&EC;VYS(&9O<B!A<'`N"B`@("!E8VAO
M("<\:#(^)R`N('-P<FEN=&8H7R@B26-O;G,@9F]R("5S(BDL("1R96=I<W1R
M>2T^9V5T*"=N86UE)RP@)&%P<"DI("X@*"%E;7!T>2@D<W5B9&ER*2`_("<O
M)R`N("1S=6)D:7(@.B`G)RD@+B`G/"]H,CXG.PH*"B`@("`O+R!,:7-T('-U
M8F1I<F5C=&]R:65S+@H@("`@)'-U8F1I<G,@/2!G;&]B*"1D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)RHG+"!'3$]"7T].3%E$25(I.PH@("`@:68@
M*"1S=6)D:7)S("8F(&-O=6YT*"1S=6)D:7)S*2D@>PH@("`@("`@(&9O<F5A
M8V@@*"1S=6)D:7)S(&%S("1S=6)D:7(I('L*("`@("`@("`@("`@:68@*&)A
M<V5N86UE*"1S=6)D:7(I(#T]("=#5E,G*2!["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO($AO<F1E
M.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@G:6-O;E]B<F]W<V5R+G!H<"<L
M(&%R<F%Y*"=S=6)D:7(G(#T^(&)A<V5N86UE*"1S=6)D:7(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=A<'`G(#T^("1A<'`I*2D@+B!B87-E
M;F%M92@D<W5B9&ER*2`N("<\+V$^/&)R("\^)SL*("`@("`@("!]"B`@("`@
M("`@96-H;R`G/&)R("\^)SL*("`@('T*"B`@("`D:6UA9V5S(#T@9VQO8B@D
M9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("<J+G!N9R<I.PH@("`@:68@
M*"1I;6%G97,@)B8@8V]U;G0H)&EM86=E<RDI('L*("`@("`@("!F;W)E86-H
M("@D:6UA9V5S(&%S("1P;F<I('L*("`@("`@("`@("`@96-H;R!(;W)D93HZ
M:6UG*'-T<E]R97!L86-E*"1B87-E9&ER("X@1$E214-43U)97U-%4$%2051/
M4BP@)R<L("1P;F<I+"`D<&YG+"!A<G)A>2@G:'-P86-E)R`]/B`Q,"P@)W9S
M<&%C92<@/3X@,3`I+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"1A<'`I*3L*
M("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&5C:&\@7R@B3F\@:6-O
M;G,@9F]U;F0N(BD["B`@("!]"@H@("`@96-H;R`G/"]B;V1Y/CPO:'1M;#XG
M.PI](&5L<V4@>PH@("`@+R\@3&ES="!A<'!S+@H@("`@9F]R96%C:"`H)&%P
M<',@87,@)&%P<"D@>PH@("`@("`@(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ
M861D4&%R86UE=&5R*"=I8V]N7V)R;W=S97(N<&AP)RP@)V%P<"<L("1A<'`I
M*2`N("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D@+B`G/"]A/CQB<B`O
M/B<["B`@("!]"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=71I;"]B87)C;V1E+G!H<```
M````````````````````````````````````````````````````````````
M```````````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3,V
M,0`Q,#4Q-30S,3`V-P`P,3<U,#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=71I;"]B87)C;V1E+G!H<"QV(#$N,3`N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y
M.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TEM86=E+G!H<"<["@HO+R!'970@
M=&5X="P@=7!P97)C87-E+"!A9&0@<W1A<G0O<W1O<"!C:&%R86-T97)S+@HD
M=&5X="`](%5T:6PZ.F=E=$9O<FU$871A*"=B87)C;V1E)RP@)W1E<W0G*3L*
M)'1E>'0@/2!3=')I;F<Z.G5P<&5R*"1T97AT+"!T<G5E*3L*)'1E>'0@/2`B
M*B1T97AT*B(["B1T97AT;&5N(#T@<W1R;&5N*"1T97AT*3L*"B1H96EG:'0@
M/2!5=&EL.CIG971&;W)M1&%T82@G:"<L(#0P*3L*)'1H:6YW:61T:"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=W)RP@,BD["B1T:&EC:W=I9'1H(#T@)'1H:6YW
M:61T:"`J(#,["B1W:61T:"`]("1T97AT;&5N("H@*#<@*B`D=&AI;G=I9'1H
M("L@,R`J("1T:&EC:W=I9'1H*2`M("1T:&EN=VED=&@["@HD8V]D:6YG;6%P
M(#T@87)R87DH)S`G(#T^("<P,#`Q,3`Q,#`G+"`G,2<@/3X@)S$P,#$P,#`P
M,2<L"B`@("`@("`@("`@("`@("`@("`G,B<@/3X@)S`P,3$P,#`P,2<L("<S
M)R`]/B`G,3`Q,3`P,#`P)RP@)S0G(#T^("<P,#`Q,3`P,#$G+`H@("`@("`@
M("`@("`@("`@("`@)S4G(#T^("<Q,#`Q,3`P,#`G+"`G-B<@/3X@)S`P,3$Q
M,#`P,"<L("<W)R`]/B`G,#`P,3`P,3`Q)RP*("`@("`@("`@("`@("`@("`@
M("<X)R`]/B`G,3`P,3`P,3`P)RP@)SDG(#T^("<P,#$Q,#`Q,#`G+"`G02<@
M/3X@)S$P,#`P,3`P,2<L"B`@("`@("`@("`@("`@("`@("`G0B<@/3X@)S`P
M,3`P,3`P,2<L("=#)R`]/B`G,3`Q,#`Q,#`P)RP@)T0G(#T^("<P,#`P,3$P
M,#$G+`H@("`@("`@("`@("`@("`@("`@)T4G(#T^("<Q,#`P,3$P,#`G+"`G
M1B<@/3X@)S`P,3`Q,3`P,"<L("=')R`]/B`G,#`P,#`Q,3`Q)RP*("`@("`@
M("`@("`@("`@("`@("=()R`]/B`G,3`P,#`Q,3`P)RP@)TDG(#T^("<P,#$P
M,#$Q,#`G+"`G2B<@/3X@)S`P,#`Q,3$P,"<L"B`@("`@("`@("`@("`@("`@
M("`G2R<@/3X@)S$P,#`P,#`Q,2<L("=,)R`]/B`G,#`Q,#`P,#$Q)RP@)TTG
M(#T^("<Q,#$P,#`P,3`G+`H@("`@("`@("`@("`@("`@("`@)TXG(#T^("<P
M,#`P,3`P,3$G+"`G3R<@/3X@)S$P,#`Q,#`Q,"<L("=0)R`]/B`G,#`Q,#$P
M,#$P)RP*("`@("`@("`@("`@("`@("`@("=1)R`]/B`G,#`P,#`P,3$Q)RP@
M)U(G(#T^("<Q,#`P,#`Q,3`G+"`G4R<@/3X@)S`P,3`P,#$Q,"<L"B`@("`@
M("`@("`@("`@("`@("`G5"<@/3X@)S`P,#`Q,#$Q,"<L("=5)R`]/B`G,3$P
M,#`P,#`Q)RP@)U8G(#T^("<P,3$P,#`P,#$G+`H@("`@("`@("`@("`@("`@
M("`@)U<G(#T^("<Q,3$P,#`P,#`G+"`G6"<@/3X@)S`Q,#`Q,#`P,2<L("=9
M)R`]/B`G,3$P,#$P,#`P)RP*("`@("`@("`@("`@("`@("`@("=:)R`]/B`G
M,#$Q,#$P,#`P)RP@)R`G(#T^("<P,3$P,#`Q,#`G+"`G)"<@/3X@)S`Q,#$P
M,3`P,"<L"B`@("`@("`@("`@("`@("`@("`G)2<@/3X@)S`P,#$P,3`Q,"<L
M("<J)R`]/B`G,#$P,#$P,3`P)RP@)RLG(#T^("<P,3`P,#$P,3`G+`H@("`@
M("`@("`@("`@("`@("`@)RTG(#T^("<P,3`P,#`Q,#$G+"`G+B<@/3X@)S$Q
M,#`P,#$P,"<L("<O)R`]/B`G,#$P,3`P,#$P)RD["@HD:6UA9V4@/2`F2&]R
M9&5?26UA9V4Z.F9A8W1O<GDH571I;#HZ9V5T1F]R;41A=&$H)W1Y<&4G+"`G
M<&YG)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M=&5M<"<@/3X@2&]R9&4Z.F=E=%1E;7!$:7(H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=W:61T:"<@/3X@)'=I9'1H+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE:6=H="<@/3X@
M)&AE:6=H="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=B86-K9W)O=6YD)R`]/B`G=VAI=&4G*2D["@HD>'!O<R`](#`["F9O<B`H
M)&ED>"`](#`[("1I9'@@/"`D=&5X=&QE;CL@)&ED>"LK*2!["B`@("`D8VAA
M<B`]('-U8G-T<B@D=&5X="P@)&ED>"P@,2D["B`@("`O+R!-86ME('5N:VYO
M=VX@8VAA<G,@82`G+2<N"B`@("!I9B`H(6ES<V5T*"1C;V1I;F=M87!;)&-H
M87)=*2D@>PH@("`@("`@("1C:&%R(#T@)RTG.PH@("`@?0H@("`@9F]R("@D
M8F%R(#T@,#L@)&)A<B`\/2`X.R`D8F%R*RLI('L*("`@("`@("`D96QE;65N
M='=I9'1H(#T@)&-O9&EN9VUA<%LD8VAA<EU[)&)A<GT@/R`D=&AI8VMW:61T
M:"`Z("1T:&EN=VED=&@["B`@("`@("`@:68@*"@D8F%R("L@,2D@)2`R*2![
M"B`@("`@("`@("`@("1I;6%G92T^<F5C=&%N9VQE*"1X<&]S+"`P+"`D96QE
M;65N='=I9'1H("T@,2P@)&AE:6=H="P@)V)L86-K)RP@)V)L86-K)RD["B`@
M("`@("`@?0H@("`@("`@("1X<&]S("L]("1E;&5M96YT=VED=&@["B`@("!]
M"B`@("`D>'!O<R`K/2`D=&AI;G=I9'1H.PI]"@IH96%D97(H)U!R86=M83H@
M<'5B;&EC)RD["B1I;6%G92T^9&ES<&QA>2@I.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]U=&EL+W)E9V5X7W1E<W0N<&AP````````````````````
M`````````````````````````````````````````````````````#`Q,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,S$V`#$P-3$U-#,Q,#8W`#`R
M,#(U-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@4VEM<&QE('-C<FEP="!T;R!H96QP('=I=&@@<F5G
M97@@8V]N<W1R=6-T:6]N+V1E8G5G9VEN9RX@4'5T(&ET"B`J('-O;65W:&5R
M92!O;B!Y;W5R('=E8G-E<G9E<B!A;F0@<&]I;G0@>6]U<B!B<F]W<V5R('1O
M(&ET+@H@*@H@*B!"87-E9"!O;CH@:'1T<#HO+VUY9FQU9F9Y9&]G+F-O;2]P
M<F]G<F%M;6EN9R]P:'`O<V-R:7!T<R]R96=E>'`N<&AP"B`J"B`J("1(;W)D
M93H@:&]R9&4O=71I;"]R96=E>%]T97-T+G!H<"QV(#$N,RXQ,"XT(#(P,#4O
M,3`O,3@@,3$Z,S0Z,C$@:F%N($5X<"`D"B`J+PH*<F5Q=6ER92`G2&]R9&4O
M571I;"YP:'`G.PHD<F5G97AP(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E9V5X
M<"<I.PHD<W5B:F5C="`](%5T:6PZ.F=E=$9O<FU$871A*"=S=6)J96-T)RD[
M"B1S=6)M:70@/2!5=&EL.CIG971&;W)M1&%T82@G<W5B;6ET)RD["@I`<V5T
M7W1I;65?;&EM:70H,BD["@IF=6YC=&EO;B!U;FAT;6QE;G1I=&EE<R@D<W1R
M:6YG*0I["B`@("`D=')A;G-?=&)L(#T@9V5T7VAT;6Q?=')A;G-L871I;VY?
M=&%B;&4H2%1-3%]%3E1)5$E%4RD["B`@("`D=')A;G-?=&)L(#T@87)R87E?
M9FQI<"@D=')A;G-?=&)L*3L*("`@(')E='5R;B!S=')T<B@D<W1R:6YG+"`D
M=')A;G-?=&)L*3L*?0H*:68@*"1S=6)M:70@/3T@(E1E<W0B*2![("\O(&1O
M:6YG(&$@<F5G(&5X<')E<W-I;VX@<V5A<F-H("TM(&=E="!V87)I86)L97,*
M("`@("1U;F5S8V%P961296=E>'`@/2!U;FAT;6QE;G1I=&EE<R@D<F5G97AP
M*3L@+R\@9F]R('-E87)C:`H@("`@)&5S8V%P961296=E>'`@/2!H=&UL96YT
M:71I97,H)')E9V5X<"D[("\O(&9O<B!S:&]W:6YG(&]N('!A9V4@86YD(&EN
M('1E>'1A<F5A"B`@("`D=&5X="`]("1S=6)J96-T.PH@("`@)'1E>'0@/2!S
M=')I<'-L87-H97,H)'1E>'0I.PH@("`@)'1E>'0@/2!U;FAT;6QE;G1I=&EE
M<R@D=&5X="D[("\O(&9O<B!S96%R8V@*("`@("1E<V-A<&5D5&5X="`](&AT
M;6QE;G1I=&EE<R@D=&5X="D[+R\@9F]R('1E>'1A<F5A"@H@("`@+R\@1&\@
M<')E9U]R97!L86-E(&]N('-O=7)C92P@<W5B<W1I='5T:6YG(&UA=&-H961?
M=&5X="!W:71H(%MB76UA=&-H961?=&5X=%LO8ET*("`@("1H:6=H;&EG:'1E
M9%1E>'0@/2!P<F5G7W)E<&QA8V4H)'5N97-C87!E9%)E9V5X<"P@)UMB75Q<
M,%LO8ETG+"`D=&5X="D["B`@("`O+R!C;VYV97)T(&AT;6QE;G1I=&EE<PH@
M("`@)&AI9VAL:6=H=&5D5&5X="`](&AT;6QE;G1I=&EE<R@D:&EG:&QI9VAT
M961497AT*3L*("`@("\O(')E<&QA8V4@6V)=(&%N9"!;+V)=('=I=&@@:&EG
M:&QI9VAT+@H@("`@)&AI9VAL:6=H=&5D5&5X="`]('-T<E]R97!L86-E*"=;
M8ETG+"`G/'-P86X@8VQA<W,](FAI9VAL:6=H="(^)RP@)&AI9VAL:6=H=&5D
M5&5X="D["B`@("`D:&EG:&QI9VAT961497AT(#T@<W1R7W)E<&QA8V4H)ULO
M8ETG+"`G/"]S<&%N/B<L("1H:6=H;&EG:'1E9%1E>'0I.PI]"C\^"CQH=&UL
M/@H\:&5A9#X*/'1I=&QE/E1E<W0@<F5G=6QA<B!E>'!R97-S:6]N<SPO=&ET
M;&4^"CQS='EL92!T>7!E/2)T97AT+V-S<R(^"CPA+2T*:#$@>PH@("`@9F]N
M="US:7IE.B!L87)G93L*?0HN9FEX960@>PH@("`@9F]N="US:7IE.B`Q,'!X
M.PH@("`@9F]N="UF86UI;'DZ(&UO;F]S<&%C92QF:7AE9#L*("`@(&-O;&]R
M.B`C,#`P,#DY.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-C8V-C8SL*?0HN
M;F]T97,@>PH@("`@9F]N="US:7IE.B!S;6%L;#L*("`@(&-O;&]R.B`C,#`P
M,#DY.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-C8V-C8SL*?0HN:&EG:&QI
M9VAT('L*("`@(&-O;&]R.B`C,#`P,#8V.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V9F9F8P,#L*?0HN96UP='D@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(V9F.3DS,PI]"BTM/@H\+W-T>6QE/@H\;65T82!H='1P+65Q=6EV/2)#;VYT
M96YT+51Y<&4B(&-O;G1E;G0](G1E>'0O:'1M;#L@8VAA<G-E=#UI<V\M.#@U
M.2TQ(CX*/"]H96%D/@H\8F]D>2!B9V-O;&]R/2(C1D9&1D9&(CX*/&@Q/E1E
M<W0@/&$@:')E9CTB:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]R968N
M<&-R92YP:'`B/E!(4"!296=U;&%R($5X<')E<W-I;VX@1G5N8W1I;VYS("A0
M97)L+4-O;7!A=&EB;&4I/"]A/CPO:#$^"CQD:78@8VQA<W,](F9I>&5D(CYP
M<F5G7VUA=&-H7V%L;"@D<&%T=&5R;BP@)'-U8FIE8W0L("1M871C:&5S+"!0
M4D5'7U-%5%]/4D1%4BD\+V1I=CX*/&9O<FT@;F%M93TB9F]R;3$B(&UE=&AO
M9#TB<&]S="(@86-T:6]N/2(\/W!H<"!E8VAO("1?4T525D526R=02%!?4T5,
M1B==(#\^(CX*/'`^/'-T<F]N9SY%;G1E<B!Y;W5R(')E9W5L87(@97AP<F5S
M<VEO;B`H)'!A='1E<FXI.CPO<W1R;VYG/CQB<B`O/@H\=&5X=&%R96$@;F%M
M93TB<F5G97AP(B!C;VQS/2(X,"(@<F]W<STB-B(@:60](G)E9V5X<"(^/#]P
M:'`@:68H)'-U8FUI="E[96-H;R`D97-C87!E9%)E9V5X<#M]/SX\+W1E>'1A
M<F5A/@H\8G(@+SX*/'-T<F]N9SY%;G1E<B!T97AT('1O('-E87)C:"!A9V%I
M;G-T(&EN('1H92!T97AT87)E82!B96QO=R`H)'-U8FIE8W0I.CPO<W1R;VYG
M/CQB<B`O/@H\=&5X=&%R96$@;F%M93TB<W5B:F5C="(@8V]L<STB.#`B(')O
M=W,](C,B/CP_<&AP(&EF*"1S=6)J96-T*7ME8VAO("1E<V-A<&5D5&5X=#M]
M/SX\+W1E>'1A<F5A/@H\8G(@+SX*/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M
M93TB<W5B;6ET(B!V86QU93TB5&5S="(^"CQI;G!U="!T>7!E/2)R97-E="(@
M;F%M93TB4F5S970B('9A;'5E/2)297-E="(^"CQA(&AR968])SP_<&AP(&5C
M:&\@)%]315)615);)U!(4%]314Q&)UT@/SXG/DAO;64\+V$^/&)R("\^"CPO
M<#X*/"]F;W)M/@H\:'(@+SX*/#]P:'`*:68@*"1S=6)M:70I('L@+R\@;VYL
M>2!S:&]W<R!U<"!O;B!R97-U;'1S('!A9V4*("`@(&EF("AP<F5G7VUA=&-H
M7V%L;"@D=6YE<V-A<&5D4F5G97AP+"`D=&5X="P@)')E<W5L=',L(%!214=?
M4T547T]21$52*2D@>R`O+R!F;W5N9"!M871C:`H@("`@("`@(&5C:&\@(E1H
M92!R96=E>'`@/'-T<F]N9SX@)&5S8V%P961296=E>'`@/"]S=')O;F<^(&UA
M=&-H960A7&X\<#XB.PH@("`@("`@(&5C:&\@(CQH,3Y(97)E)W,@=VAA="!W
M87,@;6%T8VAE9"!S96%R8VAI;F<@=&AE('1E>'0@>6]U(&5N=&5R960Z/"]H
M,3Y<;B(["B`@("`@("`@)'D@/2`P.PH@("`@("`@(&5C:&\@)SQD:78@8VQA
M<W,](F9I>&5D(CXG.PH@("`@("`@(&9O<F5A8V@@*"1R97-U;'1S(&%S("1L
M;V]P7W)E<W5L="D@>PH@("`@("`@("`@("`D>"`](#`["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1L;V]P7W)E<W5L="!A<R`D;&]O<%]R97-U;'0R*2!["B`@
M("`@("`@("`@("`@("!I9B`H)'@@(3T@,"D@>PH@("`@("`@("`@("`@("`@
M("`@("\J($EN9&5N="!S=6)P871T97)N<RX@*B\*("`@("`@("`@("`@("`@
M("`@("!E8VAO("(\8FQO8VMQ=6]T93XB.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@<')I;G1F*"<D;6%T8VAE<ULE<UU;)7-=.B9N8G-P
M.R9N8G-P.R<L("1Y+"`D>"D[+R\@<VAO=R!V87)I86)L92!N86UE"B`@("`@
M("`@("`@("`@("!I9B`H(21L;V]P7W)E<W5L=#(I('L*("`@("`@("`@("`@
M("`@("`@("!E8VAO("<\<W!A;B!C;&%S<STB96UP='DB/D5M<'1Y/"]S<&%N
M/B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&5C:&\@)SQS<&%N(&-L87-S/2)H:6=H;&EG:'0B/B<@+B!H=&UL96YT
M:71I97,H)&QO;W!?<F5S=6QT,BD@+B`G/"]S<&%N/B<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)'@@(3T@,"D@>PH@("`@("`@
M("`@("`@("`@("`@(&5C:&\@(CPO8FQO8VMQ=6]T93XB.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!E8VAO("(\<"`O
M/B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D>"LK.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1Y*RL["B`@("`@("`@?0H@("`@
M("`@(&5C:&\@)SPO9&EV/B<["B`@("!](&5L<V4@>R`O+R!N;R!M871C:`H@
M("`@("`@(&5C:&\@(G)E9V5X<"`\<W1R;VYG/B`D97-C87!E9%)E9V5X<"`\
M+W-T<F]N9SX@9&]E<VXG="!R971U<FX@86YY(')E<W5L='-<;CQP/B(["B`@
M("!]"B`@("`_/@H@("`@/&@Q/E-E87)C:&5D('1E>'0@=VET:"!M871C:&5S
M(#QS<&%N(&-L87-S/2=H:6=H;&EG:'0G/FAI9VAL:6=H=&5D/"]S<&%N/CPO
M:#$^"B`@("`\/W!H<"`O+R!3:&]W('-E87)C:&5D('1E>'0@=VET:"!M871C
M:&5S(&AI9VAL:6=H=&5D"B`@("!E8VAO("<\<')E/B<["B`@("!E8VAO("1H
M:6=H;&EG:'1E9%1E>'0["B`@("!E8VAO("<\+W!R93X\:'(@+SXG.PI]"C\^
M"@H\9&EV(&-L87-S/2)N;W1E<R(^"CQH,3Y%>&%M<&QE(')E9W5L87(@97AP
M<F5S<VEO;G,Z/"]H,3X*/'`^/'-T<F]N9SY[)FQT.R$M+2@_.BY\7',I*C\M
M+29G=#M]/"]S=')O;F<^)FYB<W`[("TM)FYB<W`[(%-H;W=S(&-O;6UE;G1S
M(&EN(&AT;6PF;F)S<#L\+W`^"CQU;#X*/&QI/CQS=')O;F<^>SPO<W1R;VYG
M/B!O<&5N(&1E;&EM:71E<CPO;&D^"CQL:3X\<W1R;VYG/B9L=#LA+2T\+W-T
M<F]N9SX@<V5A<F-H(&9O<B!O<&5N:6YG(&-O;6UE;G0@=&%G/"]L:3X*/&QI
M/CQS=')O;F<^*#\Z+GQ<<RDJ/"]S=')O;F<^(&%N>2!N=6UB97(@;V8@8VAA
M<F%C=&5R<R!O<B!W:&ET92!S<&%C93PO;&D^"CQL:3X\<W1R;VYG/C\\+W-T
M<F]N9SX@;F]N+6=R965D>3PO;&D^"CQL:3X\<W1R;VYG/BTM)F=T.SPO<W1R
M;VYG/B!S96%R8V@@9F]R(&-L;W-I;F<@8V]M;65N="!T86<\+VQI/@H\;&D^
M/'-T<F]N9SY]/"]S=')O;F<^(&-L;W-E(&1E;&EM:71E<CPO;&D^"CPO=6P^
M"CQP/CQS=')O;F<^>R9L=#MS='EL92!T>7!E*#\Z+GQ<<RDJ/R9L=#LO<W1Y
M;&4F9W0[?3PO<W1R;VYG/B`M+2!3:&]W<R`@<W1Y;&5S/"]P/@H\<#Y.;W1E
M<SH\+W`^"CQU;#X*/&QI/E1H92!R97-U;'1S('!A9V4@<VAO=W,@=&AE(&EN
M9&EV:61U86P@;6%T8VAE<R!A;F0@<W5B<&%T=&5R;B!M871C:&5S+"!A;F0@
M=&AE(&]R:6=I;F%L('1E>'0@=VET:"!T:&4@;6%T8VAE<R!H:6=H;&EG:'1E
M9"X\+VQI/@H\;&D^36EG:'0@;F]T(&)E(&%B;&4@=&\@<V5A<F-H(&9O<B!H
M=&UL(&5N=&ET:65S(&QI:V4@(B9A;7`[86UP.R(@8F5C875S92!O9B!T:&4@
M8V]N=F5R=&EN9R!F;W(@9&ES<&QA>2!A;F0@=&5X=&%R96%S("AT:&4@<V5A
M<F-H('!A='1E<FX@*')E9V5X<"D@86YD(&YO;BUU<FP@<W5B:F5C=',@87)E
M('!R;V-E<W-E9"!B>2!U;FAT;6QE;G1I=&EE<RD\+VQI/@H\+W5L/CPO9&EV
M/@H\+V)O9'D^"CPO:'1M;#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V5T8R\`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#8W`#`Q,S,P-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O971C
M+W!S82UH;W)D92\`````````````````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-C<`,#$U,3<Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+P``````````````
M````````````````````````````````````````````````````````````
M```````````P,#0P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,3`W,``P,38R-C0`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O
M:&]R9&4O8V]N9BYP:'``````````````````````````````````````````
M`````````````````````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$P,3(V`#$P-3$U-#,Q,#<P`#`Q-S<Q-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*B!#3TY&
M24<@4U1!4E0N($1/($Y/5"!#2$%.1T4@04Y95$A)3D<@24X@3U(@049415(@
M5$A)4R!,24Y%+B`J+PHO+R`D2&]R9&4Z(&AO<F1E+V-O;F9I9R]C;VYF+GAM
M;"QV(#$N-S0N,BXT,2`R,#`V+S`X+S`T(#$W.C$S.C(U(&IA;B!%>'`@)`HO
M*BH**B!0;&5S:R!P<F5D969I;F5D(&-O;F9I9W5R871I;VX@9F]R($AO<F1E
M,PHJ*B\*"B1C;VYF6R=D96)U9U]L979E;"==(#T@15]%4E)/4CL*)&-O;F9;
M)VUA>%]E>&5C7W1I;64G72`](#`["B1C;VYF6R=U<V5?<W-L)UT@/2`R.PHD
M8V]N9ELG<V5R=F5R)UU;)VYA;64G72`]("1?4T525D526R=315)615)?3D%-
M12==.PHD8V]N9ELG<V5R=F5R)UU;)W!O<G0G72`]("1?4T525D526R=315)6
M15)?4$]25"==.PHD8V]N9ELG8V]M<')E<W-?<&%G97,G72`]('1R=64["B1C
M;VYF6R=U;6%S:R==(#T@,#<W.PHD8V]N9ELG<V5S<VEO;B==6R=N86UE)UT@
M/2`G2&]R9&4S)SL*)&-O;F9;)W-E<W-I;VXG75LG8V%C:&5?;&EM:71E<B==
M(#T@)VYO8V%C:&4G.PHD8V]N9ELG<V5S<VEO;B==6R=T:6UE;W5T)UT@/2`P
M.PHD8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==(#T@)%]315)615);)U-%4E9%
M4E].04U%)UT["B1C;VYF6R=C;V]K:64G75LG<&%T:"==(#T@)R\G.PHD8V]N
M9ELG<W%L)UU;)W!E<G-I<W1E;G0G72`](&9A;'-E.PHD8V]N9ELG<W%L)UU;
M)VAO<W1S<&5C)UT@/2`G;&]C86QH;W-T)SL*)&-O;F9;)W-Q;"==6R=U<V5R
M;F%M92==(#T@)VAO<F1E)SL*)&-O;F9;)W-Q;"==6R=S;V-K970G72`]("<O
M=F%R+VQI8B]M>7-Q;"]M>7-Q;"YS;V-K)SL*)&-O;F9;)W-Q;"==6R=P<F]T
M;V-O;"==(#T@)W5N:7@G.PHD8V]N9ELG<W%L)UU;)V1A=&%B87-E)UT@/2`G
M:&]R9&4G.PH*+R\@9V5T('!A<W-W;W)D(&9R;VT@+V5T8R]P<V$O+G=E8FUA
M:6PN<VAA9&]W(`II9B`H(2@D9F0@/2!F;W!E;B@B+V5T8R]P<V$O+G=E8FUA
M:6PN<VAA9&]W(BP@(G(B*2DI('L*("!E8VAO("(\<V-R:7!T/F%L97)T*"=5
M;F%B;&4@=&\@9V5T('=E8FUA:6P@<&%S<W=O<F0A)RD\+W-C<FEP=#XB.PH@
M(&5X:70H*3L*?0IF<V-A;F8H)&9D+"`B)7,B+"`D8G5F9BD["F9C;&]S92@D
M9F0I.PH*)&-O;F9;)W-Q;"==6R=P87-S=V]R9"==(#T@<')E9U]R97!L86-E
M*"(O7&XO(BP@(B(L("1B=69F*3L*)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UT@
M/2`G=71F."<["B1C;VYF6R=S<6PG75LG<&AP='EP92==(#T@)VUY<W%L)SL*
M)&-O;F9;)V%U=&@G75LG861M:6YS)UT@/2!A<G)A>2@I.PHD8V]N9ELG875T
M:"==6R=C:&5C:VEP)UT@/2!T<G5E.PHD8V]N9ELG875T:"==6R=C:&5C:V)R
M;W=S97(G72`]('1R=64["B1C;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L;V=I
M;B==(#T@9F%L<V4["B1C;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO9V]U
M="==(#T@9F%L<V4["@HD8V]N9ELG875T:"==6R=D<FEV97(G72`]("=C;VUP
M;W-I=&4G.PHD8V]N9ELG875T:"==6R=P87)A;7,G75LG9')I=F5R<R==(#T@
M87)R87DH"B`@("`G:6UP)R`]/B!A<G)A>2@G9')I=F5R)R`]/B`G87!P;&EC
M871I;VXG+`H@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH
M)V%P<"<@/3X@)VEM<"<I*2P*("`@("=M:6UP)R`]/B!A<G)A>2@G9')I=F5R
M)R`]/B`G87!P;&EC871I;VXG+`H@("`@("`@("`@("`@("`@("`@("=P87)A
M;7,G(#T^(&%R<F%Y*"=A<'`G(#T^("=M:6UP)RDI*3L*"B1C;VYF6R=A=71H
M)UU;)W!A<F%M<R==6R=L;V=I;G-C<F5E;E]S=VET8V@G72`]("=?:&]R9&5?
M<V5L96-T7VQO9VEN<V-R965N)SL*"6EF("@A9G5N8W1I;VY?97AI<W1S*"=?
M:&]R9&5?<V5L96-T7VQO9VEN<V-R965N)RDI('L*"0EF=6YC=&EO;B!?:&]R
M9&5?<V5L96-T7VQO9VEN<V-R965N*"D*"0E["@D)"4!D969I;F4H2$]21$5?
M0D%312PG+W5S<B]S:&%R92]P<V$M:&]R9&4G*3L*"0D)<F5Q=6ER95]O;F-E
M($A/4D1%7T)!4T4@+B`G+VQI8B](;W)D92]"<F]W<V5R+G!H<"<["@D)"21B
M<F]W<V5R(#T@;F5W($)R;W=S97(H*3L*"0D):68@*"1B<F]W<V5R+3YI<TUO
M8FEL92@I("8F("1'3$]"04Q36R=R96=I<W1R>2==+3YA<'!L:6-A=&EO;G-;
M)VUI;7`G72E["@D)"0ER971U<FX@)VUI;7`G.PH)"0E]"@D)"7)E='5R;B`G
M:6UP)SL@"@D)?0I]"@HD8V]N9ELG<VEG;G5P)UU;)V%L;&]W)UT@/2!F86QS
M93L*)&-O;F9;)VQO9R==6R=P<FEO<FET>2==(#T@4$5!4E],3T=?15)2.PHD
M8V]N9ELG;&]G)UU;)VED96YT)UT@/2`G2$]21$4G.PHD8V]N9ELG;&]G)UU;
M)W!A<F%M<R==(#T@87)R87DH*3L*)&-O;F9;)VQO9R==6R=N86UE)UT@/2`G
M+W5S<B]L;V-A;"]P<V$O=F%R+VQO9R]P<V$M:&]R9&4N;&]G)SL*)&-O;F9;
M)VQO9R==6R=P87)A;7,G75LG87!P96YD)UT@/2!T<G5E.PHD8V]N9ELG;&]G
M)UU;)W1Y<&4G72`]("=F:6QE)SL*)&-O;F9;)VQO9R==6R=E;F%B;&5D)UT@
M/2!T<G5E.PHD8V]N9ELG;&]G7V%C8V5S<VME>7,G72`](&9A;'-E.PHD8V]N
M9ELG<')E9G,G75LG<&%R86US)UU;)V1R:79E<F-O;F9I9R==(#T@)VAO<F1E
M)SL*)&-O;F9;)W!R969S)UU;)V1R:79E<B==(#T@)W-Q;"<["B1C;VYF6R=D
M871A=')E92==6R=P87)A;7,G75LG9')I=F5R8V]N9FEG)UT@/2`G:&]R9&4G
M.PHD8V]N9ELG9&%T871R964G75LG9')I=F5R)UT@/2`G<W%L)SL*)&-O;F9;
M)V=R;W5P)UU;)V1R:79E<B==(#T@)V1A=&%T<F5E)SL*)&-O;F9;)V-A8VAE
M)UU;)V1E9F%U;'1?;&EF971I;64G72`](#$X,#`["B1C;VYF6R=C86-H92==
M6R=P87)A;7,G75LG9&ER)UT@/2!(;W)D93HZ9V5T5&5M<$1I<B@I.PHD8V]N
M9ELG8V%C:&4G75LG<&%R86US)UU;)V=C)UT@/2`X-C0P,#L*)&-O;F9;)V-A
M8VAE)UU;)V1R:79E<B==(#T@)V9I;&4G.PHD8V]N9ELG;6%I;&5R)UU;)W!A
M<F%M<R==6R=H;W-T)UT@/2`G;&]C86QH;W-T)SL*)&-O;F9;)VUA:6QE<B==
M6R=P87)A;7,G75LG875T:"==(#T@)S`G.PHD8V]N9ELG;6%I;&5R)UU;)W1Y
M<&4G72`]("=S;71P)SL*)&-O;F9;)W9F<R==6R=P87)A;7,G75LG=F9S<F]O
M="==(#T@)R]T;7`G.PHD8V]N9ELG=F9S)UU;)W1Y<&4G72`]("=F:6QE)SL*
M)&-O;F9;)W-E<W-I;VYH86YD;&5R)UU;)W1Y<&4G72`]("=N;VYE)SL*)&-O
M;F9;)VUI;64G75LG;6%G:6-?9&(G72`]("<@+W5S<B]S:&%R92]M:7-C+VUA
M9VEC)SL*)&-O;F9;)W!R;V)L96US)UU;)V5M86EL)UT@/2`G=V5B;6%S=&5R
M0&5X86UP;&4N8V]M)SL*)&-O;F9;)W!R;V)L96US)UU;)VUA:6QD;VUA:6XG
M72`]("=E>&%M<&QE+F-O;2<["B1C;VYF6R=P<F]B;&5M<R==6R=T:6-K971S
M)UT@/2!F86QS93L*)&-O;F9;)VUE;G4G75LG87!P<R==(#T@87)R87DH*3L*
M)&-O;F9;)VUE;G4G75LG86QW87ES)UT@/2!F86QS93L*)&-O;F9;)VUE;G4G
M75LG;&EN:W,G75LG:&5L<"==(#T@)V%L;"<["B1C;VYF6R=M96YU)UU;)VQI
M;FMS)UU;)VAE;'!?86)O=70G72`]('1R=64["B1C;VYF6R=M96YU)UU;)VQI
M;FMS)UU;)V]P=&EO;G,G72`]("=A=71H96YT:6-A=&5D)SL*)&-O;F9;)VUE
M;G4G75LG;&EN:W,G75LG<')O8FQE;2==(#T@)VYE=F5R)SL*)&-O;F9;)VUE
M;G4G75LG;&EN:W,G75LG;&]G:6XG72`]("=A;&PG.PHD8V]N9ELG;65N=2==
M6R=L:6YK<R==6R=L;V=O=70G72`]("=A=71H96YT:6-A=&5D)SL*)&-O;F9;
M)VAO;VMS)UU;)W!E<FUS9&5N:65D)UT@/2!F86QS93L*)&-O;F9;)VAO;VMS
M)UU;)W5S97)N86UE)UT@/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;)W!R96%U
M=&AE;G1I8V%T92==(#T@9F%L<V4["B1C;VYF6R=H;V]K<R==6R=P;W-T875T
M:&5N=&EC871E)UT@/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;)V%U=&AL9&%P
M)UT@/2!F86QS93L*)&-O;F9;)W!O<G1A;"==6R=F:7AE9%]B;&]C:W,G72`]
M(&%R<F%Y*"D["B1C;VYF6R=A8V-O=6YT<R==6R=D<FEV97(G72`]("=N=6QL
M)SL*)&-O;F9;)VEM<W`G75LG96YA8FQE9"==(#T@9F%L<V4["B1C;VYF6R=K
M;VQA8B==6R=E;F%B;&5D)UT@/2!F86QS93L*)&-O;F9;)W1O:V5N)UU;)W!A
M<F%M<R==6R=D<FEV97)C;VYF:6<G72`]("=H;W)D92<["B1C;VYF6R=T;VME
M;B==6R=D<FEV97(G72`]("=S<6PG.PHD8V]N9ELG8W-S)UU;)V-A8VAE9"==
M(#T@=')U93L*+RH@0T].1DE'($5.1"X@1$\@3D]4($-(04Y'12!!3EE42$E.
M1R!)3B!/4B!"149/4D4@5$A)4R!,24Y%+B`J+PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]M:6UE
M7V1R:79E<G,N<&AP````````````````````````````````````````````
M````````````````````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,S8U,S<`,3`U,34T,S$P-S``,#(Q-#<S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+V-O;F9I9R]M:6UE7V1R:79E<G,N<&AP+F1I<W0L=B`Q+CDW+C8N.2`R
M,#`V+S`T+S`V(#(Q.C,R.C$T(&IA;B!%>'`@)`H@*@H@*B!$96-I9&4@=VAI
M8V@@;W5T<'5T(&1R:79E<G,@>6]U('=A;G0@=&\@86-T:79A=&4@9F]R(&%L
M;"!(;W)D90H@*B!A<'!L:6-A=&EO;G,N($EN9&EV:61U86P@2&]R9&4@87!P
M;&EC871I;VYS(&-A;B!O=F5R<FED92!T:&5S92!S971T:6YG<PH@*B!I;B!T
M:&5I<B!C;VYF:6<O;6EM95]D<FEV97)S+G!H<"!F:6QE<RX*("H*("H@5&AE
M(&%V86EL86)L92!D<FEV97)S(&%R93H*("H@+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*("H@8W-S("`@("`@("`@("`@0U-3(%-T>6QE<PH@*B!D96(@
M("`@("`@("`@("!$96)I86X@<&%C:V%G97,*("H@96YR:6-H960@("`@("`@
M16YR:6-H960@=&5X="!F;W)M870*("H@96YS8W)I<'0@("`@("`@1TY5(&5N
M<V-R:7!T"B`J(&AT;6P@("`@("`@("`@($A434P@9&%T80H@*B!I;6%G97,@
M("`@("`@("!);6%G92!F:6QE<PH@*B!M<W=O<F0@("`@("`@("!-:6-R;W-O
M9G0@5V]R9"!F:6QE<R!V:6$@=W9(=&UL"B`J(&US97AC96P@("`@("`@($UI
M8W)O<V]F="!%>&-E;"!F:6QE<R!V:6$@>&QH=&UL"B`J(&US<&]W97)P;VEN
M="`@($UI8W)O<V]F="!0;W=E<G!O:6YT(&9I;&5S('9I82!P<'1H=&UL"B`J
M(&]O;R`@("`@("`@("`@($]P96Y/9F9I8V4N;W)G+U-T87)/9F9I8V4@1&]C
M=6UE;G1S"B`J('!D9B`@("`@("`@("`@(%!O<G1A8FQE($1O8W5M96YT($9O
M<FUA="`H4$1&*2!F:6QE<PH@*B!P:'`@("`@("`@("`@("!4:&4@:6YT97)N
M86P@4$A0-"!S>6YT87@@:&EG:&QI9VAT:6YG(&5N9VEN90H@*B!P;&%I;B`@
M("`@("`@("!2971U<FX@=&5X="P@=VET:"!L:6YK<R!M861E(&-L:6-K86)L
M92!A;F0@;W1H97(@2%1-3`H@*B`@("`@("`@("`@("`@("!F:6QT97)E9"!O
M=70*("H@<F%R("`@("`@("`@("`@4D%2(&%R8VAI=F5S"B`J(')E<&]R="`@
M("`@("`@(%)E<&]R="!M97-S86=E<R`H4D9#(#,T-3(I"B`J(')F8S@R,B`@
M("`@("`@($1I9V5S=&5D(&UE<W-A9V5S("A21D,@,C`T-B!;-2XR+C%=*0H@
M*B!R:6-H=&5X="`@("`@("!2:6-H=&5X="!T97AT(&9O<FUA="`H4D9#(#$S
M-#$@6S<N,2XS72D*("H@<G!M("`@("`@("`@("`@4E!-('!A8VMA9V5S"B`J
M('-E8W5R:71Y("`@("`@(%-E8W5R92!M=6QT:7!A<G1S("A21D,@,3@T-RD*
M("H@<VEM<&QE("`@("`@("`@3W5T<'5T('1E>'0@=VET:&]U="!M;V1I9FEC
M871I;VX*("H@<W)C:&EG:&QI=&4@("`@4V]U<F-E($AI9VAL:6=H=`H@*B!T
M9WH@("`@("`@("`@("!487)B86QL<RP@:6YC;'5D:6YG(&=Z:7!P960@;VYE
M<PH@*B!T;F5F("`@("`@("`@("!-4RU43D5&(&%T=&%C:&UE;G1S"B`J('9C
M87)D("`@("`@("`@('9#87)D<PH@*B!W96)C<'`@("`@("`@("!796(@0R!0
M;'5S(%!L=7,*("H@>FEP("`@("`@("`@("`@6FEP(&9I;&5S"B`J+PHD;6EM
M95]D<FEV97)S7VUA<%LG:&]R9&4G75LG<F5G:7-T97)E9"==(#T@87)R87DH
M"B`@("`G8W-S)RP@)V5N<FEC:&5D)RP@)VAT;6PG+"`G:6UA9V5S)RP@)V]O
M;R<L("=P9&8G+"`G<&AP)RP@)W!L86EN)RP@)W)A<B<L"B`@("`G<F5P;W)T
M)RP@)W)F8S@R,B<L("=R:6-H=&5X="<L("=S96-U<FET>2<L("=S:6UP;&4G
M+"`G=&=Z)RP@)W1N968G+`H@("`@)W9C87)D)RP@)WII<"<L"B`@("`O+R!4
M:&4@9F]L;&]W:6YG(&UI;64@9')I=F5R<R!R97%U:7)E(&5X=&5R;F%L(&%P
M<&QI8V%T:6]N<R!T;R!B90H@("`@+R\@:6YS=&%L;&5D+@H@("`@+R\@)V1E
M8B<L("=E;G-C<FEP="<L("=M<W=O<F0G+"`G;7-E>&-E;"<L("=M<W!O=V5R
M<&]I;G0G+"`G<G!M)RP*("`@("\O("=S<F-H:6=H;&ET92<L("=W96)C<'`G
M"BD["@H*+RHJ"B`J($EF('EO=2!W86YT('1O('-P96-I9FEC86QL>2!O=F5R
M<FED92!A;GD@34E-12!T>7!E('1O(&)E(&AA;F1L960@8GD*("H@82!S<&5C
M:69I8R!D<FEV97(L('1H96X@96YT97(@:70@:&5R92X@($YO<FUA;&QY+"!T
M:&ES(&ES('-A9F4@=&\*("H@;&5A=F4L(&)U="!I="=S('5S969U;"!W:&5N
M(&UU;'1I<&QE(&1R:79E<G,@:&%N9&QE('1H92!S86UE($U)344*("H@='EP
M92P@86YD('EO=2!W86YT('1O('-P96-I9GD@97AA8W1L>2!W:&EC:"!O;F4@
M<VAO=6QD(&AA;F1L92!I="X*("HO"B1M:6UE7V1R:79E<G-?;6%P6R=H;W)D
M92==6R=O=F5R<FED97,G72`](&%R<F%Y*"D["@H*+RHJ"B`J($1R:79E<B!S
M<&5C:69I8R!S971T:6YG<RX@2&5R92P@>6]U(&AA=F4@=&\@8V]N9FEG=7)E
M(&5A8V@@9')I=F5R"B`J('=H:6-H('EO=2!C:&]S92!T;R!A8W1I=F%T92!A
M8F]V92X@1&5F875L="!S971T:6YG<R!H879E(&)E96X*("H@9FEL;&5D(&EN
M(&9O<B!T:&5M+"!A;F0@:68@>6]U(&AA=F5N)W0@86-T:79A=&5D(&ET+"!T
M:&5N(&IU<W0*("H@;&5A=F4@:70@87,@:70@:7,@+2!I="!W;VXG="!G970@
M;&]A9&5D+@H@*@H@*B!4:&4@)VAA;F1L97,G('-E='1I;F<@8F5L;W<@<VAO
M=6QD;B=T(&)E(&-H86YG960@:6X@;6]S=`H@*B!C:7)C=6US=&%N8V5S+B!)
M="!R96=I<W1E<G,@82!S970@;V8@34E-12!T>7!E('1H870@=&AE(&1R:79E
M<B!C86X*("H@:&%N9&QE+B!4:&4@)W@M97AT96YS:6]N)R!-24U%('1Y<&4@
M:7,@82!S<&5C:6%L(&]N92!T;R!(;W)D92!T:&%T"B`J(&UA<',@82!F:6QE
M(&5X=&5N<VEO;B!T;R!A($U)344@='EP92X@270G<R!U<V5F=6P@=VAE;B!Y
M;W4@:VYO=PH@*B!T:&%T(&%L;"!F:6QE<R!E;F1I;F<@:6X@)RYC)R!A<F4@
M0R!F:6QE<RP@9F]R(&5X86UP;&4N(%EO=2!C86X@<V5T"B`J('1H92!-24U%
M('-U8G1Y<&4@=&\@)RHG('1O(&UA=&-H(&%L;"!P;W-S:6)L92!S=6)T>7!E
M<PH@*B`H:2YE+B`G:6UA9V4O*B<I+@H@*@H@*B!4:&4@)VEC;VYS)R!E;G1R
M>2!I<R!F;W(@=&AE(&1R:79E<B!T;R!R96=I<W1E<B!V87)I;W5S(&EC;VYS
M(&9O<@H@*B!T:&4@34E-12!T>7!E<R!I="!H86YD;&5S+B!4:&4@87)R87D@
M8V]N<VES=',@;V8@82`G9&5F875L="<@:6-O;@H@*B!F;W(@=&AA="!D<FEV
M97(L(&%N9"!C86X@86QS;R!I;F-L=61E('-P96-I9FEC($U)344M='EP97,@
M=VAI8V@@8V%N"B`J(&AA=F4@=&AE:7(@;W=N(&EC;VYS+B!9;W4@8V%N('-E
M="!T:&4@34E-12!S=6)T>7!E('1O("<J)R!T;R!M871C:`H@*B!A;&P@<&]S
M<VEB;&4@<W5B='EP97,@*&DN92X@)VEM86=E+RHG*2X*("HO"@HO*BH*("H@
M1&5F875L="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO
M<F1E)UU;)V1E9F%U;'0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U
M;'0G("`@("`@("`@("`@("`@("`@("`@("`]/B`G=&5X="YP;F<G+`H@("`@
M)V%U9&EO+RHG("`@("`@("`@("`@("`@("`@("`@("`]/B`G875D:6\N<&YG
M)RP*("`@("=M97-S86=E+RHG("`@("`@("`@("`@("`@("`@("`@/3X@)VUA
M:6PN<&YG)RP*("`@("=U;FMN;W=N+RHG("`@("`@("`@("`@("`@("`@("`@
M/3X@)V)I;F%R>2YP;F<G+`H@("`@)W9I9&5O+RHG("`@("`@("`@("`@("`@
M("`@("`@("`]/B`G=FED96\N<&YG)RP*("`@("=A<'!L:6-A=&EO;B]P9W`M
M<VEG;F%T=7)E)R`@("`@/3X@)V5N8W)Y<'1I;VXN<&YG)RP*("`@("=A<'!L
M:6-A=&EO;B]X+7!K8W,W+7-I9VYA='5R92<@/3X@)V5N8W)Y<'1I;VXN<&YG
M)RP*("`@("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG("`@("`@/3X@)V)I
M;F%R>2YP;F<G*3L*"@HO*BH*("H@1&5F875L="!T97AT(&1R:79E<B!S971T
M:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<VEM<&QE)UU;)VEN
M;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<VEM<&QE
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O*B<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=S:6UP;&4G75LG:6-O;G,G72`](&%R<F%Y*`H@
M("`@)V1E9F%U;'0G(#T^("=T97AT+G!N9R<I.PH*"B\J*@H@*B!0;&%I;B!T
M97AT(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG<&QA:6XG75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H
M;W)D92==6R=P;&%I;B==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT
M+W!L86EN)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!L86EN)UU;)VEC
M;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G=&5X="YP;F<G*3L*
M"@HO*BH*("H@4$A0(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG<&AP)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG<&AP)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)V%P<&QI8V%T:6]N+W@M<&AP)RP@)W@M97AT96YS:6]N+W!H<',G+`H@("`@
M)W@M97AT96YS:6]N+W!H<#-S)RP@)V%P<&QI8V%T:6]N+W@M:'1T<&0M<&AP
M)RP*("`@("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H<#,G+"`G87!P;&EC871I
M;VXO>"UH='1P9"UP:'!S)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!H
M<"==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)W!H<"YP
M;F<G*3L*"@HO*BH*("H@0U-3(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG8W-S)UU;)VEN;&EN92==(#T@=')U93L*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG8W-S)UU;)VAA;F1L97,G72`](&%R<F%Y
M*`H@("`@)W1E>'0O8W-S)RP@)W@M97AT96YS:6]N+V-S<R<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=C<W,G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@
M)V1E9F%U;'0G(#T^("=H=&UL+G!N9R<I.PH*"B\J*@H@*B!%;G)I8VAE9"!T
M97AT(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG:'1M;"==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S6R=H
M;W)D92==6R=H=&UL)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O
M:'1M;"<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=H=&UL)UU;)VEC;VYS
M)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G:'1M;"YP;F<G*3L*"@HO
M*BH*("H@16YR:6-H960@=&5X="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)V5N<FEC:&5D)UU;)VEN;&EN92==(#T@=')U
M93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YR:6-H960G75LG:&%N9&QE
M<R==(#T@87)R87DH"B`@("`G=&5X="]E;G)I8VAE9"<I.PHD;6EM95]D<FEV
M97)S6R=H;W)D92==6R=E;G)I8VAE9"==6R=I8V]N<R==(#T@87)R87DH"B`@
M("`G9&5F875L="<@/3X@)W1E>'0N<&YG)RD["@H*+RHJ"B`J(%)I8VAT97AT
M('1E>'0@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=R:6-H=&5X="==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)W)I8VAT97AT)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@
M("`@)W1E>'0O<FEC:'1E>'0G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M<FEC:'1E>'0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^
M("=T97AT+G!N9R<I.PH*"B\J*@H@*B!796(@0R!0;'5S(%!L=7,@9')I=F5R
M('-E='1I;F=S"B`J(&AT='`Z+R]W96)C<'`N<V]U<F-E9F]R9V4N;F5T+PH@
M*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;)VQO8V%T:6]N
M)UT@/2`G+W5S<B]B:6XO=V5B8W!P)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG=V5B8W!P)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG=V5B8W!P)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E
M>'0O>&UL)RP@)W1E>'0O<V=M;"<L("=A<'!L:6-A=&EO;B]X;6PG+`H@("`@
M)V%P<&QI8V%T:6]N+W@M<V@G+"`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T
M)RP@)V%P<&QI8V%T:6]N+W@M=&-L)RP*("`@("=X+65X=&5N<VEO;B]A<VTG
M+"`G87!P;&EC871I;VXO>"UA<W`G+"`G>"UE>'1E;G-I;VXO8F%S)RP*("`@
M("=X+65X=&5N<VEO;B]C<R<L("=T97AT+W@M8W-R8R<L("=X+65X=&5N<VEO
M;B]R8R<L"B`@("`G=&5X="]X+6,K*W-R8R<L("=T97AT+W@M8RLK<W)C)RP@
M)W1E>'0O>"UC*RMS<F,G+`H@("`@)W1E>'0O>"UC:&1R)RP@)W@M97AT96YS
M:6]N+V)A="<L("=T97AT+W@M9F]R=')A;B<L"B`@("`G>"UE>'1E;G-I;VXO
M9C<W)RP@)W@M97AT96YS:6]N+V8Y,"<L("=X+65X=&5N<VEO;B]F;W(G+`H@
M("`@)W@M97AT96YS:6]N+V9T;B<L("=T97AT+W@M:F%V82<L("=A<'!L:6-A
M=&EO;B]X+6IA=F%S8W)I<'0G+`H@("`@)W1E>'0O<V=M;"<L("=T97AT+WAM
M;"<L("=T97AT+W@M<&%S8V%L)RP*("`@("=A<'!L:6-A=&EO;B]X+6-G:2<L
M("=A<'!L:6-A=&EO;B]X+7!E<FPG+"`G87!P;&EC871I;VXO>"UP>71H;VXG
M+`H@("`@)W1E>'0O>"US<6PG+"`G=&5X="]X+71C;"<L"B`@("`G87!P;&EC
M871I;VXO>"US:&5L;'-C<FEP="<L("=X+65X=&5N<VEO;B]V:&0G+"`G>"UE
M>'1E;G-I;VXO=FAD;"<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=W96)C
M<'`G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G("`@("`@("`@
M("`@("`@("`@/3X@)W1E>'0N<&YG)RP*("`@("=T97AT+WAM;"<@("`@("`@
M("`@("`@("`@(#T^("=X;6PN<&YG)RP*("`@("=T97AT+W@M8W-R8R<@("`@
M("`@("`@("`@(#T^("=S;W5R8V4M8RYP;F<G+`H@("`@)W1E>'0O>"UC:&1R
M)R`@("`@("`@("`@("`@/3X@)W-O=7)C92UH+G!N9R<L"B`@("`G=&5X="]X
M+6IA=F$G("`@("`@("`@("`@("`]/B`G<V]U<F-E+6IA=F$N<&YG)RP*("`@
M("=A<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0G(#T^("=S8W)I<'0M:G,N<&YG
M)RD["@HO*BH*("H@4V]U<F-E+4AI9VAL:6=H="!D<FEV97(@<V5T=&EN9W,*
M("H@:'1T<#HO+W=W=RYG;G4N;W)G+W-O9G1W87)E+W-R8RUH:6=H;&ET92\*
M("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;)VQO
M8V%T:6]N)UT@/2`G+W5S<B]B:6XO<V]U<F-E+6AI9VAL:6=H="<["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;)VEN;&EN92==(#T@
M=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<W)C:&EG:&QI=&4G75LG
M:&%N9&QE<R==(#T@87)R87DH"B`@("`G=&5X="]X+6-S<F,G+"`G=&5X="]X
M+6,K*W-R8R<L("=T97AT+W@M:F%V82<L"B`@("`G87!P;&EC871I;VXO>"UP
M97)L)RP@)V%P<&QI8V%T:6]N+W@M<'ET:&]N)RP@)W1E>'0O>"UC*RMS<F,G
M+`H@("`@)W1E>'0O8W!P)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R
M8VAI9VAL:71E)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`@
M("`@("`@("`@("`@("`@(#T^("=T97AT+G!N9R<L"B`@("`G=&5X="]X+6-S
M<F,G("`@("`@("`@("`@("`]/B`G<V]U<F-E+6,N<&YG)RP*("`@("=T97AT
M+W@M8RLK<W)C)R`@("`@("`@("`@(#T^("=S;W5R8V4M8RYP;F<G+`H@("`@
M)W1E>'0O8W!P)R`@("`@("`@("`@("`@("`@/3X@)W-O=7)C92UC+G!N9R<L
M"B`@("`G=&5X="]X+6IA=F$G("`@("`@("`@("`@("`]/B`G<V]U<F-E+6IA
M=F$N<&YG)RD["@HO*BH*("H@1TY5($5N<V-R:7!T(&1R:79E<B!S971T:6YG
M<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YS8W)I<'0G75LG;&]C
M871I;VXG72`]("<O=7-R+V)I;B]E;G-C<FEP="<["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG96YS8W)I<'0G75LG:&%N9&QE<R==(#T@87)R
M87DH"B`@("`G87!P;&EC871I;VXO>"UC9VDG+"`G87!P;&EC871I;VXO>"US
M:&5L;'-C<FEP="<L("=A<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0G+`H@("`@
M)V%P<&QI8V%T:6]N+W@M<&5R;"<L("=A<'!L:6-A=&EO;B]X;6PG+"`G=&5X
M="]X;6PG+`H@("`@)W1E>'0O9&EF9B<L("=T97AT+W@M9&EF9B<L("=T97AT
M+W@M<&%T8V@G+"`G=&5X="]X+6-S<F,G+`H@("`@)W@M97AT96YS:6]N+V-S
M)RP@)W1E>'0O>"UJ879A)RP@)W1E>'0O>"UC:&1R)RP@)W1E>'0O>"UC*RMS
M<F,G+`H@("`@)W1E>'0O>"UC*RMH9'(G+"`G>"UE>'1E;G-I;VXO=FAD)RP@
M)W@M97AT96YS:6]N+W9H9&PG+"`G=&5X="]X+7-Q;"<L"B`@("`G>"UE>'1E
M;G-I;VXO=F(G+"`G>"UE>'1E;G-I;VXO=F)A)RP@)W1E>'0O>"UE;6%C<RUL
M:7-P)RP@)W1E>'0O>"UT97@G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M96YS8W)I<'0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G("`@
M("`@("`@("`@("`@("`@/3X@)W1E>'0N<&YG)RP*("`@("=T97AT+WAM;"<@
M("`@("`@("`@("`@("`@(#T^("=X;6PN<&YG)RP*("`@("=A<'!L:6-A=&EO
M;B]X;6PG("`@("`@("`@(#T^("=X;6PN<&YG)RP*("`@("=T97AT+W@M8W-R
M8R<@("`@("`@("`@("`@(#T^("=S;W5R8V4M8RYP;F<G+`H@("`@)W1E>'0O
M>"UC:&1R)R`@("`@("`@("`@("`@/3X@)W-O=7)C92UH+G!N9R<L"B`@("`G
M=&5X="]X+6IA=F$G("`@("`@("`@("`@("`]/B`G<V]U<F-E+6IA=F$N<&YG
M)RP*("`@("=A<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0G(#T^("=S8W)I<'0M
M:G,N<&YG)RD["@H*+RHJ"B`J(%1A<B!D<FEV97(@<V5T=&EN9W,*("H@5&\@
M86-C97-S(&=Z:7!P960@9FEL97,L('1H92!Z;&EB(&QI8G)A<GD@;75S="!H
M879E(&)E96X@8G5I;'0@:6YT;R!02%`*("H@*'=I=&@@=&AE("TM=VET:"UZ
M;&EB(&]P=&EO;BDN"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=T9WHG
M75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=T
M9WHG75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G87!P;&EC871I;VXO>"UC
M;VUP<F5S<V5D+71A<B<L"B`@("`G87!P;&EC871I;VXO>"UT87(G+`H@("`@
M)V%P<&QI8V%T:6]N+W@M=&=Z)RP*("`@("=A<'!L:6-A=&EO;B]X+6=Z:7`G
M+`H@("`@)V%P<&QI8V%T:6]N+W@M9W1A<B<L"B`@("`G87!P;&EC871I;VXO
M9WII<"<L"B`@("`G87!P;&EC871I;VXO>"UG>FEP+6-O;7!R97-S960G*3L*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=&=Z)UU;)VEC;VYS)UT@/2!A<G)A
M>2@*("`@("=D969A=6QT)R`]/B`G8V]M<')E<W-E9"YP;F<G*3L*"@HO*BH*
M("H@6FEP(&9I;&4@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=Z:7`G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV
M97)S6R=H;W)D92==6R=Z:7`G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G
M87!P;&EC871I;VXO>FEP)RP*("`@("=A<'!L:6-A=&EO;B]X+6-O;7!R97-S
M960G+`H@("`@)V%P<&QI8V%T:6]N+W@M>FEP+6-O;7!R97-S960G*3L*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG>FEP)UU;)VEC;VYS)UT@/2!A<G)A>2@*
M("`@("=D969A=6QT)R`]/B`G8V]M<')E<W-E9"YP;F<G*3L*"@HO*BH*("H@
M4D%2(&%R8VAI=F4@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=R87(G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV
M97)S6R=H;W)D92==6R=R87(G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G
M87!P;&EC871I;VXO>"UR87(G+`H@("`@)V%P<&QI8V%T:6]N+W@M<F%R+6-O
M;7!R97-S960G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F%R)UU;)VEC
M;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G8V]M<')E<W-E9"YP
M;F<G*3L*"@HO*BH*("H@35,@5V]R9"!D<FEV97(@<V5T=&EN9W,*("H@5&AI
M<R!D<FEV97(@<F5Q=6ER97,@=W9787)E('1O(&)E(&EN<W1A;&QE9"X*("H@
M=W9787)E(&AO;65P86=E.B!H='1P.B\O=W9W87)E+G-O=7)C969O<F=E+FYE
M="\*("H*("H@5&AE("=L;V-A=&EO;B<@96YT<GD@<VAO=6QD('!O:6YT('1O
M('1H92`G=W9(=&UL)R!P<F]G<F%M+"!.3U0@=&AE"B`J("=W=E=A<F4G('!R
M;V=R86TN"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G75LG
M;&]C871I;VXG72`]("<O=7-R+V)I;B]W=DAT;6PG.PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=M<W=O<F0G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VAA;F1L97,G72`](&%R<F%Y
M*`H@("`@)V%P<&QI8V%T:6]N+W9N9"YM<RUW;W)D)RP*("`@("=A<'!L:6-A
M=&EO;B]M<W=O<F0G+`HI.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O
M<F0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=M<W=O
M<F0N<&YG)RP**3L*"@HO*BH*("H@35,@17AC96P@9')I=F5R('-E='1I;F=S
M"B`J(%1H:7,@9')I=F5R(')E<75I<F5S('AL:'1M;"!T;R!B92!I;G-T86QL
M960N"B`J('AL:'1M;"!H;VUE<&%G93H@:'1T<#HO+V-H:6-A9V\N<V]U<F-E
M9F]R9V4N;F5T+WAL:'1M;"\*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)VUS97AC96PG75LG;&]C871I;VXG72`]("<O=7-R+VQO8V%L+V)I;B]X;&AT
M;6PG.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M<V5X8V5L)UU;)VEN;&EN
M92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG
M75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G87!P;&EC871I;VXO=FYD+FUS
M+65X8V5L)RP*("`@("=A<'!L:6-A=&EO;B]M<V5X8V5L)RP*("`@("=A<'!L
M:6-A=&EO;B]X+6US97AC96PG*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M;7-E>&-E;"==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@
M)VUS97AC96PN<&YG)RD["@H*+RHJ"B`J($U3(%!O=V5R<&]I;G0@9')I=F5R
M('-E='1I;F=S"B`J(%1H:7,@9')I=F5R(')E<75I<F5S('!P=&AT;6PL(&EN
M8VQU9&5D('=I=&@@>&QH=&UL+"!T;R!B92!I;G-T86QL960N"B`J('AL:'1M
M;"!H;VUE<&%G93H@:'1T<#HO+V-H:6-A9V\N<V]U<F-E9F]R9V4N;F5T+WAL
M:'1M;"\*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN
M="==6R=L;V-A=&EO;B==(#T@)R]U<W(O;&]C86PO8FEN+W!P=&AT;6PG.PHD
M;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W!O=V5R<&]I;G0G75LG:6YL:6YE
M)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O
M:6YT)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W9N
M9"YM<RUP;W=E<G!O:6YT)RP*("`@("=A<'!L:6-A=&EO;B]M<W!O=V5R<&]I
M;G0G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;
M)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G;7-P;W=E<G!O
M:6YT+G!N9R<I.PH*"B\J*@H@*B!V0V%R9"!D<FEV97(@<V5T=&EN9W,*("HO
M"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W9C87)D)UU;)VAA;F1L97,G72`]
M(&%R<F%Y*`H@("`@)W1E>'0O>"UV8V%R9"<L"B`@("`G=&5X="]X+79C86QE
M;F1A<B<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=V8V%R9"==6R=I8V]N
M<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)W9C87)D+G!N9R<I.PH*
M"B\J*@H@*B!24$T@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=R<&TG75LG;&]C871I;VXG72`]("<O=7-R+V)I;B]R<&TG
M.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R<&TG75LG:6YL:6YE)UT@/2!F
M86QS93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;)VAA;F1L97,G
M72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W@M<G!M)RD["B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)W)P;2==6R=I8V]N<R==(#T@87)R87DH"B`@("`G
M9&5F875L="<@/3X@)W)P;2YP;F<G*3L*"@HO*BH*("H@1&5B:6%N('!A8VMA
M9V4@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=D96(G75LG;&]C871I;VXG72`]("<O=7-R+V)I;B]D<&MG)SL*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VEN;&EN92==(#T@9F%L<V4["B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V1E8B==6R=H86YD;&5S)UT@/2!A<G)A
M>2@*("`@("=A<'!L:6-A=&EO;B]X+61E8B<L"B`@("`G87!P;&EC871I;VXO
M>"UD96)I86XM<&%C:V%G92<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=D
M96(G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=D96(N
M<&YG)RD["@H*+RHJ"B`J(%-E8W5R92!M=6QT:7!A<G1S("A21D,@,3@T-RD*
M("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-E8W5R:71Y)UU;)VEN;&EN
M92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<V5C=7)I='DG
M75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G;75L=&EP87)T+V5N8W)Y<'1E
M9"<L("=M=6QT:7!A<G0O<VEG;F5D)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W-E8W5R:71Y)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT
M)R`]/B`G96YC<GEP=&EO;BYP;F<G*3L*"@HO*BH*("H@26UA9V4@<V5T=&EN
M9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VEM86=E<R==6R=I;FQI
M;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=I;6%G97,G
M75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G:6UA9V4O*B<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=I;6%G97,G75LG:6-O;G,G72`](&%R<F%Y*`H@
M("`@)V1E9F%U;'0G(#T^("=I;6%G92YP;F<G*3L*"@HO*BH*("H@35,M5$Y%
M1B!!='1A8VAM96YT("AA<'!L:6-A=&EO;B]M<RUT;F5F*2!S971T:6YG<PH@
M*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=&YE9B==6R=I;FQI;F4G72`]
M(&9A;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=T;F5F)UU;)VAA;F1L
M97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+VUS+71N968G*3L*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG=&YE9B==6R=I8V]N<R==(#T@87)R87DH
M"B`@("`G9&5F875L="<@/3X@)W1E>'0N<&YG)RD["@H*+RHJ"B`J($1I9V5S
M="!M97-S86=E("A21D,@,C`T-B!;-2XR+C%=*2!S971T:6YG<PH@*B\*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG<F9C.#(R)UU;)VEN;&EN92==(#T@9F%L
M<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)F8S@R,B==6R=H86YD;&5S
M)UT@/2!A<G)A>2@*("`@("=M97-S86=E+W)F8S@R,B<L"B`@("`G>"UE>'1E
M;G-I;VXO96UL)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)F8S@R,B==
M6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)VUA:6PN<&YG
M)RD["@H*+RHJ"B`J(%)E<&]R="!M97-S86=E<R`H4D9#(#,T-3(I"B`J+PHD
M;6EM95]D<FEV97)S6R=H;W)D92==6R=R97!O<G0G75LG:6YL:6YE)UT@/2!T
M<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R97!O<G0G75LG:&%N9&QE
M<R==(#T@87)R87DH"B`@("`G;75L=&EP87)T+W)E<&]R="<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=R97!O<G0G75LG:6-O;G,G72`](&%R<F%Y*`H@
M("`@)V1E9F%U;'0G(#T^("=M86EL+G!N9R<I.PH*"B\J*@H@*B!/<&5N3V9F
M:6-E+F]R9R]3=&%R3V9F:6-E('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=O;V\G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG;V]O)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F-A;&,G+`H@("`@)V%P<&QI8V%T
M:6]N+W9N9"YS=6XN>&UL+F-A;&,N=&5M<&QA=&4G+`H@("`@)V%P<&QI8V%T
M:6]N+W9N9"YS=6XN>&UL+F1R87<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=6XN>&UL+F1R87<N=&5M<&QA=&4G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=6XN>&UL+FEM<')E<W,G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL
M+FEM<')E<W,N=&5M<&QA=&4G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN
M>&UL+FUA=&@G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E
M<B<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R+F=L;V)A
M;"<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R+G1E;7!L
M871E)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+F-A;&,G
M+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN9')A=R<L"B`@
M("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYI;7!R97-S)RP*("`@
M("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+FUA=&@G+`H@("`@)V%P
M<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN=W)I=&5R)RD["B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)V]O;R==6R=I8V]N<R==(#T@87)R87DH"B`@("`G
M9&5F875L="<@/3X@)V]O;U]C86QC+G!N9R<L"B`@("`G87!P;&EC871I;VXO
M=FYD+G-U;BYX;6PN8V%L8R<@("`@("`@("`@("`@/3X@)V]O;U]C86QC+G!N
M9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYC86QC)R`@
M("`@("`@/3X@)V]O;U]C86QC+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD
M+G-U;BYX;6PN8V%L8RYT96UP;&%T92<@("`@/3X@)V]O;U]C86QC+G!N9R<L
M"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN9')A=R<@("`@("`@("`@
M("`@/3X@)V]O;U]D<F%W+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T
M87)D:79I<VEO;BYD<F%W)R`@("`@("`@/3X@)V]O;U]D<F%W+G!N9R<L"B`@
M("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN9')A=RYT96UP;&%T92<@("`@
M/3X@)V]O;U]D<F%W+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX
M;6PN:6UP<F5S<R<@("`@("`@("`@/3X@)V]O;U]I;7!R97-S+G!N9R<L"B`@
M("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYI;7!R97-S)R`@("`@
M/3X@)V]O;U]I;7!R97-S+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U
M;BYX;6PN:6UP<F5S<RYT96UP;&%T92<@/3X@)V]O;U]I;7!R97-S+G!N9R<L
M"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN;6%T:"<@("`@("`@("`@
M("`@/3X@)V]O;U]M871H+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T
M87)D:79I<VEO;BYM871H)R`@("`@("`@/3X@)V]O;U]M871H+G!N9R<L"B`@
M("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R)R`@("`@("`@("`@
M/3X@)V]O;U]W<FET97(N<&YG)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W1A
M<F1I=FES:6]N+G=R:71E<B<@("`@("`]/B`G;V]O7W=R:71E<BYP;F<G+`H@
M("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYG;&]B86PG("`@
M(#T^("=O;V]?=W)I=&5R+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U
M;BYX;6PN=W)I=&5R+G1E;7!L871E)R`@/3X@)V]O;U]W<FET97(N<&YG)RD[
M"@H*+RHJ"B`J(%!O<G1A8FQE($1O8W5M96YT($9O<FUA="`H4$1&*2!F:6QE
M<PH@*B!93U4@4TA/54Q$($Y/5"!.3U)-04Q,62!!3%1%4B!42$E3(%-%5%1)
M3D<N"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=P9&8G75LG:6YL:6YE
M)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<&1F)UU;)VAA
M;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W!D9B<I.PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=P9&8G75LG:6-O;G,G72`](&%R<F%Y*`H@
M("`@)V1E9F%U;'0G(#T^("=P9&8N<&YG)RD["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O
M;6]T9"YP:'``````````````````````````````````````````````````
M`````````````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P-#,P`#$P-3$U-#,Q,#<P`#`Q-S<S,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\(2TM(%1H:7,@9FEL92!C;VYT
M86EN<R!A;GD@(DUE<W-A9V4@3V8@5&AE($1A>2(@5'EP92!I;F9O<FUA=&EO
M;B`M+3X*/"$M+2!)="!W:6QL(&)E(&EN8VQU9&5D(&)E;&]W('1H92!L;V<M
M:6X@9F]R;2!O;B!T:&4@;&]G:6X@<&%G92X@+2T^"@H\8G(@+SX*/'1A8FQE
M('=I9'1H/2(Q,#`E(CX\='(^/'1D(&%L:6=N/2)C96YT97(B/CQI;6<@<W)C
M/2)T:&5M97,O9W)A<&AI8W,O:&]R9&4M<&]W97(Q+G!N9R(@86QT/2)0;W=E
M<F5D(&)Y($AO<F1E(B`O/CPO=&0^/"]T<CX\+W1A8FQE/@H*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+VYL<RYP:'``````
M````````````````````````````````````````````````````````````
M```````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,#`S-``Q
M,#4Q-30S,3`W,``P,3<U-C<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($Y,4R`H3F%T:6]N86P@3&%N
M9W5A9V4@4W5P<&]R="D@8V]N9FEG=7)A=&EO;B!F:6QE+@H@*@H@*B`D2&]R
M9&4Z(&AO<F1E+V-O;F9I9R]N;',N<&AP+F1I<W0L=B`Q+C4Y+C$P+C<@,C`P
M-B\P-"\Q.2`R,SHS-CHR,B!J86X@17AP("0*("HO"@HO*BH*("HJ($1E9F%U
M;'1S"B`J*B\*"B\J(%1H92!L86YG=6%G92!T;R!F86QL(&)A8VL@;VX@:68@
M=V4@8V%N;F]T(&1E=&5R;6EN92!O;F4@86YY(&]T:&5R"B`@('=A>2`H=7-E
M<B!C:&]I8V4@;W(@<')E9F5R96YC97,I+B!)9B!E;7!T>2P@=V4@=VEL;"!T
M<GD@=&\@;F5G;W1I871E"B`@('=I=&@@=&AE(&)R;W=S97(@=7-I;F<@2%14
M4%]!0T-%4%1?3$%.1U5!1T4N("HO"B1N;'-;)V1E9F%U;'1S)UU;)VQA;F=U
M86=E)UT@/2`G)SL*"@HO*BH*("HJ($QA;F=U86=E"B`J*B\*"B1N;'-;)VQA
M;F=U86=E<R==6R=A<E]/32==(#T@)T%R86)I8R`H3VUA;BD@*"8C>#`V,C<[
M)B-X,#8T-#LF(W@P-C,Y.R8C>#`V,S$[)B-X,#8R.#LF(W@P-C1A.R8C>#`V
M,CD[*2<["B1N;'-;)VQA;F=U86=E<R==6R=A<E]362==(#T@)T%R86)I8R`H
M4WER:6$I("@F(W@P-C(W.R8C>#`V-#0[)B-X,#8S.3LF(W@P-C,Q.R8C>#`V
M,C@[)B-X,#8T83LF(W@P-C(Y.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:61?
M240G72`]("="86AA<V$@26YD;VYE<VEA)SL*)&YL<ULG;&%N9W5A9V5S)UU;
M)V)S7T)!)UT@/2`G0F]S86YS:VDG.PHD;FQS6R=L86YG=6%G97,G75LG8F=?
M0D<G72`]("="=6QG87)I86X@*"8C>#`T,3$[)B-X,#0T83LF(W@P-#-B.R8C
M>#`T,S,[)B-X,#0S,#LF(W@P-#0P.R8C>#`T-#$[)B-X,#0S83LF(W@P-#,X
M.RDG.PHD;FQS6R=L86YG=6%G97,G75LG8V%?15,G72`]("=#871A;"9A9W)A
M=F4[)SL*)&YL<ULG;&%N9W5A9V5S)UU;)WIH7T-.)UT@/2`G0VAI;F5S92`H
M4VEM<&QI9FEE9"D@*"8C>#=B.#`[)B-X-&8U,SLF(W@T93)D.R8C>#8U.#<[
M*2<["B1N;'-;)VQA;F=U86=E<R==6R=Z:%]45R==(#T@)T-H:6YE<V4@*%1R
M861I=&EO;F%L*2`H)B-X-F(V,SLF(W@Y860T.R8C>#1E,F0[)B-X-C4X-SLI
M)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V-S7T-:)UT@/2`G0WIE8V@@*"8C>#`Q
M,&,[97-K>2DG.PHD;FQS6R=L86YG=6%G97,G75LG9&%?1$LG72`]("=$86YS
M:R<["B1N;'-;)VQA;F=U86=E<R==6R=D95]$12==(#T@)T1E=71S8V@G.PHD
M;FQS6R=L86YG=6%G97,G75LG96Y?55,G72`]("=%;F=L:7-H("A!;65R:6-A
M;BDG.PHD;FQS6R=L86YG=6%G97,G75LG96Y?1T(G72`]("=%;F=L:7-H("A"
M<FET:7-H*2<["B1N;'-;)VQA;F=U86=E<R==6R=E;E]#02==(#T@)T5N9VQI
M<V@@*$-A;F%D:6%N*2<["B1N;'-;)VQA;F=U86=E<R==6R=E<U]%4R==(#T@
M)T5S<&$F;G1I;&1E.V]L)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V5T7T5%)UT@
M/2`G165S=&DG.PHD;FQS6R=L86YG=6%G97,G75LG9G)?1E(G72`]("=&<F%N
M)F-C961I;#MA:7,G.PHD;FQS6R=L86YG=6%G97,G75LG9VQ?15,G72`]("='
M86QE9V\G.PHD;FQS6R=L86YG=6%G97,G75LG96Q?1U(G72`]("='<F5E:R`H
M)B-X,#,Y-3LF(W@P,V)B.R8C>#`S8F([)B-X,#-B-SLF(W@P,V)D.R8C>#`S
M8CD[)B-X,#-B83LF(W@P,V%C.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:&5?
M24PG72`]("=(96)R97<@*"8C>#`U13([)B-X,#5$,3LF(W@P-44X.R8C>#`U
M1#D[)B-X,#5%03LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VES7TE3)UT@/2`G
M)DEA8W5T93MS;&5N<VMA)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VET7TE4)UT@
M/2`G271A;&EA;F\G.PHD;FQS6R=L86YG=6%G97,G75LG:F%?2E`G72`]("=*
M87!A;F5S92`H)B-X-C5E-3LF(W@V-S)C.R8C>#AA.64[*2<["B1N;'-;)VQA
M;F=U86=E<R==6R=K;5]+2"==(#T@)TMH;65R("@F(W@Q-S@Q.R8C>#$W9#([
M)B-X,3<Y.#LF(W@Q-V,R.R8C>#$W.6$[*2<["B1N;'-;)VQA;F=U86=E<R==
M6R=K;U]+4B==(#T@)TMO<F5A;B`H)B-X9#4U8SLF(WAA9#9D.R8C>&,U8C0[
M*2<["B1N;'-;)VQA;F=U86=E<R==6R=L=E],5B==(#T@)TQA='9I928C>#`Q
M-C$[=2<["B1N;'-;)VQA;F=U86=E<R==6R=L=%],5"==(#T@)TQI971U=FDF
M(W@P,3<S.R<["B1N;'-;)VQA;F=U86=E<R==6R=M:U]-2R==(#T@)TUA8V5D
M;VYI86X@*"8C>#`T,6,[)B-X,#0S,#LF(W@P-#-A.R8C>#`T,S4[)B-X,#0S
M-#LF(W@P-#-E.R8C>#`T,V0[)B-X,#0T,3LF(W@P-#-A.R8C>#`T,S@[*2<[
M"B1N;'-;)VQA;F=U86=E<R==6R=H=5](52==(#T@)TUA9WEA<B<["B1N;'-;
M)VQA;F=U86=E<R==6R=N;%].3"==(#T@)TYE9&5R;&%N9',G.PHD;FQS6R=L
M86YG=6%G97,G75LG;F)?3D\G72`]("=.;W)S:R!B;VMM)F%R:6YG.VPG.PHD
M;FQS6R=L86YG=6%G97,G75LG;FY?3D\G72`]("=.;W)S:R!N>6YO<G-K)SL*
M)&YL<ULG;&%N9W5A9V5S)UU;)V9A7TE2)UT@/2`G4&5R<VEA;B`H)B-X,#8T
M,3LF(W@P-C(W.R8C>#`V,S$[)B-X,#8S,SLF(W@P-C0Y.RDG.PHD;FQS6R=L
M86YG=6%G97,G75LG<&Q?4$PG72`]("=0;VQS:VDG.PHD;FQS6R=L86YG=6%G
M97,G75LG<'1?4%0G72`]("=0;W)T=6=U)F5C:7)C.W,G.PHD;FQS6R=L86YG
M=6%G97,G75LG<'1?0E(G72`]("=0;W)T=6=U)F5C:7)C.W,@0G)A<VEL96ER
M;R<["B1N;'-;)VQA;F=U86=E<R==6R=R;U]23R==(#T@)U)O;29A8VER8SMN
M)F%U;6P[)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W)U7U)5)UT@/2`G4G5S<VEA
M;B`H)B-X,#0R,#LF(W@P-#0S.R8C>#`T-#$[)B-X,#0T,3LF(W@P-#-A.R8C
M>#`T,S@[)B-X,#0S.3LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W-K7U-+)UT@
M/2`G4VQO=F%K("A3;&]V96XF(W@P,3!D.VEN82DG.PHD;FQS6R=L86YG=6%G
M97,G75LG<VQ?4TDG72`]("=3;&]V96YI86X@*%-L;W9E;B8C>#`Q-C$[)B-X
M,#$P9#MI;F$I)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V9I7T9))UT@/2`G4W5O
M;6DG.PHD;FQS6R=L86YG=6%G97,G75LG<W9?4T4G72`]("=3=F5N<VMA)SL*
M)&YL<ULG;&%N9W5A9V5S)UU;)W1H7U1()UT@/2`G5&AA:2`H)B-X,&4T-#LF
M(W@P93$W.R8C>#!E,C([*2<["B1N;'-;)VQA;F=U86=E<R==6R=T<E]44B==
M(#T@)U0F=75M;#MR:R9C8V5D:6P[92<["B1N;'-;)VQA;F=U86=E<R==6R=U
M:U]502==(#T@)U5K<F%I;FEA;B`H)B-X,#0R,SLF(W@P-#-A.R8C>#`T-#`[
M)B-X,#0S,#LF(W@P-#4W.R8C>#`T,V0[)B-X,#0T,3LF(W@P-#1C.R8C>#`T
M,V$[)B-X,#0S,#LI)SL*"@HO*BH*("HJ($%L:6%S97,@9F]R(&QA;F=U86=E
M<R!W:71H(&1I9F9E<F5N="!B<F]W<V5R(&%N9"!G971T97AT(&-O9&5S"B`J
M*B\*"B1N;'-;)V%L:6%S97,G75LG87(G72`]("=A<E]362<["B1N;'-;)V%L
M:6%S97,G75LG8F<G72`]("=B9U]"1R<["B1N;'-;)V%L:6%S97,G75LG8G,G
M72`]("=B<U]"02<["B1N;'-;)V%L:6%S97,G75LG8V$G72`]("=C85]%4R<[
M"B1N;'-;)V%L:6%S97,G75LG8W,G72`]("=C<U]#6B<["B1N;'-;)V%L:6%S
M97,G75LG9&$G72`]("=D85]$2R<["B1N;'-;)V%L:6%S97,G75LG9&4G72`]
M("=D95]$12<["B1N;'-;)V%L:6%S97,G75LG96PG72`]("=E;%]'4B<["B1N
M;'-;)V%L:6%S97,G75LG96XG72`]("=E;E]54R<["B1N;'-;)V%L:6%S97,G
M75LG97,G72`]("=E<U]%4R<["B1N;'-;)V%L:6%S97,G75LG970G72`]("=E
M=%]%12<["B1N;'-;)V%L:6%S97,G75LG9F$G72`]("=F85])4B<["B1N;'-;
M)V%L:6%S97,G75LG9FDG72`]("=F:5]&22<["B1N;'-;)V%L:6%S97,G75LG
M9G(G72`]("=F<E]&4B<["B1N;'-;)V%L:6%S97,G75LG9VPG72`]("=G;%]%
M4R<["B1N;'-;)V%L:6%S97,G75LG:&4G72`]("=H95])3"<["B1N;'-;)V%L
M:6%S97,G75LG:'4G72`]("=H=5](52<["B1N;'-;)V%L:6%S97,G75LG:60G
M72`]("=I9%])1"<["B1N;'-;)V%L:6%S97,G75LG:7,G72`]("=I<U])4R<[
M"B1N;'-;)V%L:6%S97,G75LG:70G72`]("=I=%])5"<["B1N;'-;)V%L:6%S
M97,G75LG:F$G72`]("=J85]*4"<["B1N;'-;)V%L:6%S97,G75LG:VTG72`]
M("=K;5]+2"<["B1N;'-;)V%L:6%S97,G75LG:V\G72`]("=K;U]+4B<["B1N
M;'-;)V%L:6%S97,G75LG;'0G72`]("=L=%],5"<["B1N;'-;)V%L:6%S97,G
M75LG;'8G72`]("=L=E],5B<["B1N;'-;)V%L:6%S97,G75LG;6LG72`]("=M
M:U]-2R<["B1N;'-;)V%L:6%S97,G75LG;FPG72`]("=N;%].3"<["B1N;'-;
M)V%L:6%S97,G75LG;FXG72`]("=N;E].3R<["B1N;'-;)V%L:6%S97,G75LG
M;F\G72`]("=N8E].3R<["B1N;'-;)V%L:6%S97,G75LG<&PG72`]("=P;%]0
M3"<["B1N;'-;)V%L:6%S97,G75LG<'0G72`]("=P=%]05"<["B1N;'-;)V%L
M:6%S97,G75LG<F\G72`]("=R;U]23R<["B1N;'-;)V%L:6%S97,G75LG<G4G
M72`]("=R=5]252<["B1N;'-;)V%L:6%S97,G75LG<VLG72`]("=S:U]32R<[
M"B1N;'-;)V%L:6%S97,G75LG<VPG72`]("=S;%]322<["B1N;'-;)V%L:6%S
M97,G75LG<W8G72`]("=S=E]312<["B1N;'-;)V%L:6%S97,G75LG=&@G72`]
M("=T:%]42"<["B1N;'-;)V%L:6%S97,G75LG='(G72`]("=T<E]44B<["B1N
M;'-;)V%L:6%S97,G75LG=6LG72`]("=U:U]502<["@H*+RHJ"B`J*B!#:&%R
M<V5T<PH@*BHO"@HD;FQS6R=C:&%R<V5T<R==6R=A<E]/32==(#T@)W=I;F1O
M=W,M,3(U-B<["B1N;'-;)V-H87)S971S)UU;)V%R7U-9)UT@/2`G=VEN9&]W
M<RTQ,C4V)SL*)&YL<ULG8VAA<G-E=',G75LG8F=?0D<G72`]("=W:6YD;W=S
M+3$R-3$G.PHD;FQS6R=C:&%R<V5T<R==6R=B<U]"02==(#T@)TE33RTX.#4Y
M+3(G.PHD;FQS6R=C:&%R<V5T<R==6R=C<U]#6B==(#T@)TE33RTX.#4Y+3(G
M.PHD;FQS6R=C:&%R<V5T<R==6R=E;%]'4B==(#T@)TE33RTX.#4Y+3<G.PHD
M;FQS6R=C:&%R<V5T<R==6R=F85])4B==(#T@)U541BTX)SL*)&YL<ULG8VAA
M<G-E=',G75LG:&5?24PG72`]("=55$8M."<["B1N;'-;)V-H87)S971S)UU;
M)VAU7TA5)UT@/2`G25-/+3@X-3DM,B<["B1N;'-;)V-H87)S971S)UU;)VIA
M7TI0)UT@/2`G4TA)1E1?2DE3)SL*)&YL<ULG8VAA<G-E=',G75LG:VU?2T@G
M72`]("=55$8M."<["B1N;'-;)V-H87)S971S)UU;)VMO7TM2)UT@/2`G155#
M+4M2)SL*)&YL<ULG8VAA<G-E=',G75LG;'1?3%0G72`]("=)4T\M.#@U.2TQ
M,R<["B1N;'-;)V-H87)S971S)UU;)VQV7TQ6)UT@/2`G=VEN9&]W<RTQ,C4W
M)SL*)&YL<ULG8VAA<G-E=',G75LG;6M?34LG72`]("=)4T\M.#@U.2TU)SL*
M)&YL<ULG8VAA<G-E=',G75LG<&Q?4$PG72`]("=)4T\M.#@U.2TR)SL*)&YL
M<ULG8VAA<G-E=',G75LG<G5?4E4G72`]("=W:6YD;W=S+3$R-3$G.PHD;FQS
M6R=C:&%R<V5T<R==6R=R=5]252Y+3TDX+5(G72`]("=+3TDX+5(G.PHD;FQS
M6R=C:&%R<V5T<R==6R=S:U]32R==(#T@)TE33RTX.#4Y+3(G.PHD;FQS6R=C
M:&%R<V5T<R==6R=S;%]322==(#T@)TE33RTX.#4Y+3(G.PHD;FQS6R=C:&%R
M<V5T<R==6R=T:%]42"==(#T@)U1)4RTV,C`G.PHD;FQS6R=C:&%R<V5T<R==
M6R=T<E]44B==(#T@)TE33RTX.#4Y+3DG.PHD;FQS6R=C:&%R<V5T<R==6R=U
M:U]502==(#T@)TM/23@M52<["B1N;'-;)V-H87)S971S)UU;)WIH7T-.)UT@
M/2`G1T(R,S$R)SL*)&YL<ULG8VAA<G-E=',G75LG>FA?5%<G72`]("="24<U
M)SL*"@HO*BH*("HJ($UU;'1I8GET92!C:&%R<V5T<PH@*BHO"@HD;FQS6R=M
M=6QT:6)Y=&4G75LG0DE'-2==(#T@=')U93L*)&YL<ULG;75L=&EB>71E)UU;
M)T550RU+4B==(#T@=')U93L*)&YL<ULG;75L=&EB>71E)UU;)T=",C,Q,B==
M(#T@=')U93L*)&YL<ULG;75L=&EB>71E)UU;)U-(24947TI)4R==(#T@=')U
M93L*)&YL<ULG;75L=&EB>71E)UU;)U541BTX)UT@/2!T<G5E.PH*"B\J*@H@
M*BH@4FEG:'0M=&\M;&5F="!L86YG=6%G97,*("HJ+PH*)&YL<ULG<G1L)UU;
M)V%R7T]-)UT@/2!T<G5E.PHD;FQS6R=R=&PG75LG87)?4UDG72`]('1R=64[
M"B1N;'-;)W)T;"==6R=F85])4B==(#T@=')U93L*)&YL<ULG<G1L)UU;)VAE
M7TE,)UT@/2!T<G5E.PH*"B\J*@H@*BH@4')E9F5R<F5D(&-H87)S971S(&9O
M<B!E;6%I;"!T<F%F9FEC(&EF(&YO="!T:&4@;&%N9W5A9V5S)R!D969A=6QT
M"B`J*B!C:&%R<V5T<RX*("HJ+PH*)&YL<ULG96UA:6QS)UU;)VIA7TI0)UT@
M/2`G25-/+3(P,C(M2E`G.PH*"B\J*@H@*BH@079A:6QA8FQE(&-H87)S971S
M(&9O<B!O=71G;VEN9R!E;6%I;"!T<F%F9FEC+@H@*BHO"@HD;FQS6R=E;F-O
M9&EN9W,G75LG=VEN9&]W<RTQ,C4V)UT@/2!?*")!<F%B:6,@*%=I;F1O=W,M
M,3(U-BDB*3L*)&YL<ULG96YC;V1I;F=S)UU;)T%235-#24DM."==(#T@7R@B
M07)M96YI86X@*$%235-#24DM."DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE3
M3RTX.#4Y+3$S)UT@/2!?*")"86QT:6,@*$E33RTX.#4Y+3$S*2(I.PHD;FQS
M6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM,30G72`](%\H(D-E;'1I8R`H25-/
M+3@X-3DM,30I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TR)UT@
M/2!?*")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(I.PHD;FQS6R=E
M;F-O9&EN9W,G75LG1T(R,S$R)UT@/2!?*")#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BDB*3L*)&YL<ULG96YC;V1I;F=S)UU;)T))1S4G72`](%\H(D-H
M:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(BD["B1N;'-;)V5N8V]D:6YG<R==
M6R=+3TDX+5(G72`](%\H(D-Y<FEL;&EC("A+3TDX+5(I(BD["B1N;'-;)V5N
M8V]D:6YG<R==6R=W:6YD;W=S+3$R-3$G72`](%\H(D-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=+3TDX+54G72`](%\H
M(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(I.PHD;FQS6R=E;F-O9&EN
M9W,G75LG25-/+3@X-3DM-R==(#T@7R@B1W)E96L@*$E33RTX.#4Y+3<I(BD[
M"B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TX+4DG72`](%\H(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3(P
M,C(M2E`G72`](%\H(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB*3L*)&YL<ULG
M96YC;V1I;F=S)UU;)T550RU+4B==(#T@7R@B2V]R96%N("A%54,M2U(I(BD[
M"B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TQ,"==(#T@7R@B3F]R9&EC
M("A)4T\M.#@U.2TQ,"DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTX.#4Y
M+3,G72`](%\H(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(I.PHD;FQS
M6R=E;F-O9&EN9W,G75LG5$E3+38R,"==(#T@7R@B5&AA:2`H5$E3+38R,"DB
M*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTX.#4Y+3DG72`](%\H(E1U<FMI
M<V@@*$E33RTX.#4Y+3DI(BD["B1N;'-;)V5N8V]D:6YG<R==6R=55$8M."==
M(#T@7R@B56YI8V]D92`H551&+3@I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=6
M25-#24DG72`](%\H(E9I971N86UE<V4@*%9)4T-)22DB*3L*)&YL<ULG96YC
M;V1I;F=S)UU;)TE33RTX.#4Y+3$G72`](%\H(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TQ-2==(#T@7R@B
M5V5S=&5R;B`H25-/+3@X-3DM,34I(BD["F%S;W)T*"1N;'-;)V5N8V]D:6YG
M<R==*3L*"@HO*BH*("HJ($UU;'1I+6QA;F=U86=E('-P96QL:6YG('-U<'!O
M<G0*("HJ+PH*)&YL<ULG<W!E;&QI;F<G75LG8W-?0UHG72`]("<M5"!L871I
M;C(@+60@8WIE8V@G.PHD;FQS6R=S<&5L;&EN9R==6R=D85]$2R==(#T@)RUD
M(&1A;G-K)SL*)&YL<ULG<W!E;&QI;F<G75LG9&5?1$4G72`]("<M5"!L871I
M;C$@+60@9&5U='-C:"<["B1N;'-;)W-P96QL:6YG)UU;)V5L7T=2)UT@/2`G
M+50@;&%T:6XQ("UD(&5L;&EN:6MA)SL*)&YL<ULG<W!E;&QI;F<G75LG96Y?
M0T$G72`]("<M9"!C86YA9&EA;B<["B1N;'-;)W-P96QL:6YG)UU;)V5N7T="
M)UT@/2`G+60@8G)I=&ES:"<["B1N;'-;)W-P96QL:6YG)UU;)V5N7U53)UT@
M/2`G+60@86UE<FEC86XG.PHD;FQS6R=S<&5L;&EN9R==6R=E<U]%4R==(#T@
M)RUD(&5S<&%N;VPG.PHD;FQS6R=S<&5L;&EN9R==6R=F<E]&4B==(#T@)RUD
M(&9R86YC86ES)SL*)&YL<ULG<W!E;&QI;F<G75LG:71?250G72`]("<M5"!L
M871I;C$@+60@:71A;&EA;B<["B1N;'-;)W-P96QL:6YG)UU;)VYL7TY,)UT@
M/2`G+60@;F5D97)L86YD<R<["B1N;'-;)W-P96QL:6YG)UU;)W!L7U!,)UT@
M/2`G+60@<&]L:7-H)SL*)&YL<ULG<W!E;&QI;F<G75LG<'1?0E(G72`]("<M
M9"!B<B<["B1N;'-;)W-P96QL:6YG)UU;)W!T7U!4)UT@/2`G+50@;&%T:6XQ
M("UD('!O<G1U9W5E<V4G.PHD;FQS6R=S<&5L;&EN9R==6R=R=5]252==(#T@
M)RUD(')U<W-I86XG.PHD;FQS6R=S<&5L;&EN9R==6R=S;%]322==(#T@)RUD
M('-L;W9E;G-K;R<["B1N;'-;)W-P96QL:6YG)UU;)W-V7U-%)UT@/2`G+60@
M<W9E;G-K82<["@HD1TQ/0D%,4ULG;FQS)UT@/2`F)&YL<SL*"@HO*BH*("HJ
M(%1I;65Z;VYE<PH@*BHO"@HD='I;)T%F<FEC82]!8FED:F%N)UT@/2`G069R
M:6-A+T%B:61J86XG.PHD='I;)T%F<FEC82]!8V-R82==(#T@)T%F<FEC82]!
M8V-R82<["B1T>ELG069R:6-A+T%D9&ES7T%B86)A)UT@/2`G069R:6-A+T%D
M9&ES($%B86)A)SL*)'1Z6R=!9G)I8V$O06QG:65R<R==(#T@)T%F<FEC82]!
M;&=I97)S)SL*)'1Z6R=!9G)I8V$O07-M97)A)UT@/2`G069R:6-A+T%S;65R
M82<["B1T>ELG069R:6-A+T)A;6%K;R==(#T@)T%F<FEC82]"86UA:V\G.PHD
M='I;)T%F<FEC82]"86YG=6DG72`]("=!9G)I8V$O0F%N9W5I)SL*)'1Z6R=!
M9G)I8V$O0F%N:G5L)UT@/2`G069R:6-A+T)A;FIU;"<["B1T>ELG069R:6-A
M+T)I<W-A=2==(#T@)T%F<FEC82]":7-S874G.PHD='I;)T%F<FEC82]";&%N
M='ER92==(#T@)T%F<FEC82]";&%N='ER92<["B1T>ELG069R:6-A+T)R87IZ
M879I;&QE)UT@/2`G069R:6-A+T)R87IZ879I;&QE)SL*)'1Z6R=!9G)I8V$O
M0G5J=6UB=7)A)UT@/2`G069R:6-A+T)U:G5M8G5R82<["B1T>ELG069R:6-A
M+T-A:7)O)UT@/2`G069R:6-A+T-A:7)O)SL*)'1Z6R=!9G)I8V$O0V%S86)L
M86YC82==(#T@)T%F<FEC82]#87-A8FQA;F-A)SL*)'1Z6R=!9G)I8V$O0V5U
M=&$G72`]("=!9G)I8V$O0V5U=&$G.PHD='I;)T%F<FEC82]#;VYA:W)Y)UT@
M/2`G069R:6-A+T-O;F%K<GDG.PHD='I;)T%F<FEC82]$86MA<B==(#T@)T%F
M<FEC82]$86MA<B<["B1T>ELG069R:6-A+T1A<E]E<U]386QA86TG72`]("=!
M9G)I8V$O1&%R(&5S(%-A;&%A;2<["B1T>ELG069R:6-A+T1J:6)O=71I)UT@
M/2`G069R:6-A+T1J:6)O=71I)SL*)'1Z6R=!9G)I8V$O1&]U86QA)UT@/2`G
M069R:6-A+T1O=6%L82<["B1T>ELG069R:6-A+T5L7T%A:75N)UT@/2`G069R
M:6-A+T5L($%A:75N)SL*)'1Z6R=!9G)I8V$O1G)E971O=VXG72`]("=!9G)I
M8V$O1G)E971O=VXG.PHD='I;)T%F<FEC82]'86)O<F]N92==(#T@)T%F<FEC
M82]'86)O<F]N92<["B1T>ELG069R:6-A+TAA<F%R92==(#T@)T%F<FEC82](
M87)A<F4G.PHD='I;)T%F<FEC82]*;VAA;FYE<V)U<F<G72`]("=!9G)I8V$O
M2F]H86YN97-B=7)G)SL*)'1Z6R=!9G)I8V$O2V%M<&%L82==(#T@)T%F<FEC
M82]+86UP86QA)SL*)'1Z6R=!9G)I8V$O2VAA<G1O=6TG72`]("=!9G)I8V$O
M2VAA<G1O=6TG.PHD='I;)T%F<FEC82]+:6=A;&DG72`]("=!9G)I8V$O2VEG
M86QI)SL*)'1Z6R=!9G)I8V$O2VEN<VAA<V$G72`]("=!9G)I8V$O2VEN<VAA
M<V$G.PHD='I;)T%F<FEC82],86=O<R==(#T@)T%F<FEC82],86=O<R<["B1T
M>ELG069R:6-A+TQI8G)E=FEL;&4G72`]("=!9G)I8V$O3&EB<F5V:6QL92<[
M"B1T>ELG069R:6-A+TQO;64G72`]("=!9G)I8V$O3&]M92<["B1T>ELG069R
M:6-A+TQU86YD82==(#T@)T%F<FEC82],=6%N9&$G.PHD='I;)T%F<FEC82],
M=6)U;6)A<VAI)UT@/2`G069R:6-A+TQU8G5M8F%S:&DG.PHD='I;)T%F<FEC
M82],=7-A:V$G72`]("=!9G)I8V$O3'5S86MA)SL*)'1Z6R=!9G)I8V$O36%L
M86)O)UT@/2`G069R:6-A+TUA;&%B;R<["B1T>ELG069R:6-A+TUA<'5T;R==
M(#T@)T%F<FEC82]-87!U=&\G.PHD='I;)T%F<FEC82]-87-E<G4G72`]("=!
M9G)I8V$O36%S97)U)SL*)'1Z6R=!9G)I8V$O36)A8F%N92==(#T@)T%F<FEC
M82]-8F%B86YE)SL*)'1Z6R=!9G)I8V$O36]G861I<VAU)UT@/2`G069R:6-A
M+TUO9V%D:7-H=2<["B1T>ELG069R:6-A+TUO;G)O=FEA)UT@/2`G069R:6-A
M+TUO;G)O=FEA)SL*)'1Z6R=!9G)I8V$O3F%I<F]B:2==(#T@)T%F<FEC82].
M86ER;V)I)SL*)'1Z6R=!9G)I8V$O3F1J86UE;F$G72`]("=!9G)I8V$O3F1J
M86UE;F$G.PHD='I;)T%F<FEC82].:6%M97DG72`]("=!9G)I8V$O3FEA;65Y
M)SL*)'1Z6R=!9G)I8V$O3F]U86MC:&]T="==(#T@)T%F<FEC82].;W5A:V-H
M;W1T)SL*)'1Z6R=!9G)I8V$O3W5A9V%D;W5G;W4G72`]("=!9G)I8V$O3W5A
M9V%D;W5G;W4G.PHD='I;)T%F<FEC82]0;W)T;RU.;W9O)UT@/2`G069R:6-A
M+U!O<G1O+4YO=F\G.PHD='I;)T%F<FEC82]386]?5&]M92==(#T@)T%F<FEC
M82]386\@5&]M92<["B1T>ELG069R:6-A+U1I;6)U:W1U)UT@/2`G069R:6-A
M+U1I;6)U:W1U)SL*)'1Z6R=!9G)I8V$O5')I<&]L:2==(#T@)T%F<FEC82]4
M<FEP;VQI)SL*)'1Z6R=!9G)I8V$O5'5N:7,G72`]("=!9G)I8V$O5'5N:7,G
M.PHD='I;)T%F<FEC82]7:6YD:&]E:R==(#T@)T%F<FEC82]7:6YD:&]E:R<[
M"B1T>ELG06UE<FEC82]!9&%K)UT@/2`G06UE<FEC82]!9&%K)SL*)'1Z6R=!
M;65R:6-A+T%N8VAO<F%G92==(#T@)T%M97)I8V$O06YC:&]R86=E)SL*)'1Z
M6R=!;65R:6-A+T%N9W5I;&QA)UT@/2`G06UE<FEC82]!;F=U:6QL82<["B1T
M>ELG06UE<FEC82]!;G1I9W5A)UT@/2`G06UE<FEC82]!;G1I9W5A)SL*)'1Z
M6R=!;65R:6-A+T%R86=U86EN82==(#T@)T%M97)I8V$O07)A9W5A:6YA)SL*
M)'1Z6R=!;65R:6-A+T%R=6)A)UT@/2`G06UE<FEC82]!<G5B82<["B1T>ELG
M06UE<FEC82]!<W5N8VEO;B==(#T@)T%M97)I8V$O07-U;F-I;VXG.PHD='I;
M)T%M97)I8V$O0F%R8F%D;W,G72`]("=!;65R:6-A+T)A<F)A9&]S)SL*)'1Z
M6R=!;65R:6-A+T)E;&5M)UT@/2`G06UE<FEC82]"96QE;2<["B1T>ELG06UE
M<FEC82]"96QI>F4G72`]("=!;65R:6-A+T)E;&EZ92<["B1T>ELG06UE<FEC
M82]";V%?5FES=&$G72`]("=!;65R:6-A+T)O82!6:7-T82<["B1T>ELG06UE
M<FEC82]";V=O=&$G72`]("=!;65R:6-A+T)O9V]T82<["B1T>ELG06UE<FEC
M82]";VES92==(#T@)T%M97)I8V$O0F]I<V4G.PHD='I;)T%M97)I8V$O0G5E
M;F]S7T%I<F5S)UT@/2`G06UE<FEC82]"=65N;W,@06ER97,G.PHD='I;)T%M
M97)I8V$O0V%M8G)I9&=E7T)A>2==(#T@)T%M97)I8V$O0V%M8G)I9&=E($)A
M>2<["B1T>ELG06UE<FEC82]#86YC=6XG72`]("=!;65R:6-A+T-A;F-U;B<[
M"B1T>ELG06UE<FEC82]#87)A8V%S)UT@/2`G06UE<FEC82]#87)A8V%S)SL*
M)'1Z6R=!;65R:6-A+T-A=&%M87)C82==(#T@)T%M97)I8V$O0V%T86UA<F-A
M)SL*)'1Z6R=!;65R:6-A+T-A>65N;F4G72`]("=!;65R:6-A+T-A>65N;F4G
M.PHD='I;)T%M97)I8V$O0V%Y;6%N)UT@/2`G06UE<FEC82]#87EM86XG.PHD
M='I;)T%M97)I8V$O0VAI8V%G;R==(#T@)T%M97)I8V$O0VAI8V%G;R<["B1T
M>ELG06UE<FEC82]#:&EH=6%H=6$G72`]("=!;65R:6-A+T-H:6AU86AU82<[
M"B1T>ELG06UE<FEC82]#;W)D;V)A)UT@/2`G06UE<FEC82]#;W)D;V)A)SL*
M)'1Z6R=!;65R:6-A+T-O<W1A7U)I8V$G72`]("=!;65R:6-A+T-O<W1A(%)I
M8V$G.PHD='I;)T%M97)I8V$O0W5I86)A)UT@/2`G06UE<FEC82]#=6EA8F$G
M.PHD='I;)T%M97)I8V$O0W5R86-A;R==(#T@)T%M97)I8V$O0W5R86-A;R<[
M"B1T>ELG06UE<FEC82]$87=S;VXG72`]("=!;65R:6-A+T1A=W-O;B<["B1T
M>ELG06UE<FEC82]$87=S;VY?0W)E96LG72`]("=!;65R:6-A+T1A=W-O;B!#
M<F5E:R<["B1T>ELG06UE<FEC82]$96YV97(G72`]("=!;65R:6-A+T1E;G9E
M<B<["B1T>ELG06UE<FEC82]$971R;VET)UT@/2`G06UE<FEC82]$971R;VET
M)SL*)'1Z6R=!;65R:6-A+T1O;6EN:6-A)UT@/2`G06UE<FEC82]$;VUI;FEC
M82<["B1T>ELG06UE<FEC82]%9&UO;G1O;B==(#T@)T%M97)I8V$O161M;VYT
M;VXG.PHD='I;)T%M97)I8V$O16ER=6YE<&4G72`]("=!;65R:6-A+T5I<G5N
M97!E)SL*)'1Z6R=!;65R:6-A+T5L7U-A;'9A9&]R)UT@/2`G06UE<FEC82]%
M;"!386QV861O<B<["B1T>ELG06UE<FEC82]&;W)T86QE>F$G72`]("=!;65R
M:6-A+T9O<G1A;&5Z82<["B1T>ELG06UE<FEC82]';&%C95]"87DG72`]("=!
M;65R:6-A+T=L86-E($)A>2<["B1T>ELG06UE<FEC82]';V1T:&%B)UT@/2`G
M06UE<FEC82]';V1T:&%B)SL*)'1Z6R=!;65R:6-A+T=O;W-E7T)A>2==(#T@
M)T%M97)I8V$O1V]O<V4@0F%Y)SL*)'1Z6R=!;65R:6-A+T=R86YD7U1U<FLG
M72`]("=!;65R:6-A+T=R86YD(%1U<FLG.PHD='I;)T%M97)I8V$O1W)E;F%D
M82==(#T@)T%M97)I8V$O1W)E;F%D82<["B1T>ELG06UE<FEC82]'=6%D96QO
M=7!E)UT@/2`G06UE<FEC82]'=6%D96QO=7!E)SL*)'1Z6R=!;65R:6-A+T=U
M871E;6%L82==(#T@)T%M97)I8V$O1W5A=&5M86QA)SL*)'1Z6R=!;65R:6-A
M+T=U87EA<75I;"==(#T@)T%M97)I8V$O1W5A>6%Q=6EL)SL*)'1Z6R=!;65R
M:6-A+T=U>6%N82==(#T@)T%M97)I8V$O1W5Y86YA)SL*)'1Z6R=!;65R:6-A
M+TAA;&EF87@G72`]("=!;65R:6-A+TAA;&EF87@G.PHD='I;)T%M97)I8V$O
M2&%V86YA)UT@/2`G06UE<FEC82](879A;F$G.PHD='I;)T%M97)I8V$O2&5R
M;6]S:6QL;R==(#T@)T%M97)I8V$O2&5R;6]S:6QL;R<["B1T>ELG06UE<FEC
M82]);F1I86YA+TMN;W@G72`]("=!;65R:6-A+TEN9&EA;F$O2VYO>"<["B1T
M>ELG06UE<FEC82]);F1I86YA+TUA<F5N9V\G72`]("=!;65R:6-A+TEN9&EA
M;F$O36%R96YG;R<["B1T>ELG06UE<FEC82]);F1I86YA+U9E=F%Y)UT@/2`G
M06UE<FEC82]);F1I86YA+U9E=F%Y)SL*)'1Z6R=!;65R:6-A+TEN9&EA;F%P
M;VQI<R==(#T@)T%M97)I8V$O26YD:6%N87!O;&ES)SL*)'1Z6R=!;65R:6-A
M+TEN=79I:R==(#T@)T%M97)I8V$O26YU=FEK)SL*)'1Z6R=!;65R:6-A+TEQ
M86QU:70G72`]("=!;65R:6-A+TEQ86QU:70G.PHD='I;)T%M97)I8V$O2F%M
M86EC82==(#T@)T%M97)I8V$O2F%M86EC82<["B1T>ELG06UE<FEC82]*=6IU
M>2==(#T@)T%M97)I8V$O2G5J=7DG.PHD='I;)T%M97)I8V$O2G5N96%U)UT@
M/2`G06UE<FEC82]*=6YE874G.PHD='I;)T%M97)I8V$O2V5N='5C:WDO36]N
M=&EC96QL;R==(#T@)T%M97)I8V$O2V5N='5C:WDO36]N=&EC96QL;R<["B1T
M>ELG06UE<FEC82],85]087HG72`]("=!;65R:6-A+TQA(%!A>B<["B1T>ELG
M06UE<FEC82],:6UA)UT@/2`G06UE<FEC82],:6UA)SL*)'1Z6R=!;65R:6-A
M+TQO<U]!;F=E;&5S)UT@/2`G06UE<FEC82],;W,@06YG96QE<R<["B1T>ELG
M06UE<FEC82],;W5I<W9I;&QE)UT@/2`G06UE<FEC82],;W5I<W9I;&QE)SL*
M)'1Z6R=!;65R:6-A+TUA8V5I;R==(#T@)T%M97)I8V$O36%C96EO)SL*)'1Z
M6R=!;65R:6-A+TUA;F%G=6$G72`]("=!;65R:6-A+TUA;F%G=6$G.PHD='I;
M)T%M97)I8V$O36%N875S)UT@/2`G06UE<FEC82]-86YA=7,G.PHD='I;)T%M
M97)I8V$O36%R=&EN:7%U92==(#T@)T%M97)I8V$O36%R=&EN:7%U92<["B1T
M>ELG06UE<FEC82]-87IA=&QA;B==(#T@)T%M97)I8V$O36%Z871L86XG.PHD
M='I;)T%M97)I8V$O365N9&]Z)UT@/2`G06UE<FEC82]-96YD;WHG.PHD='I;
M)T%M97)I8V$O365N;VUI;F5E)UT@/2`G06UE<FEC82]-96YO;6EN964G.PHD
M='I;)T%M97)I8V$O365R:61A)UT@/2`G06UE<FEC82]-97)I9&$G.PHD='I;
M)T%M97)I8V$O365X:6-O7T-I='DG72`]("=!;65R:6-A+TUE>&EC;R!#:71Y
M)SL*)'1Z6R=!;65R:6-A+TUI<75E;&]N)UT@/2`G06UE<FEC82]-:7%U96QO
M;B<["B1T>ELG06UE<FEC82]-;VYT97)R97DG72`]("=!;65R:6-A+TUO;G1E
M<G)E>2<["B1T>ELG06UE<FEC82]-;VYT979I9&5O)UT@/2`G06UE<FEC82]-
M;VYT979I9&5O)SL*)'1Z6R=!;65R:6-A+TUO;G1R96%L)UT@/2`G06UE<FEC
M82]-;VYT<F5A;"<["B1T>ELG06UE<FEC82]-;VYT<V5R<F%T)UT@/2`G06UE
M<FEC82]-;VYT<V5R<F%T)SL*)'1Z6R=!;65R:6-A+TYA<W-A=2==(#T@)T%M
M97)I8V$O3F%S<V%U)SL*)'1Z6R=!;65R:6-A+TYE=U]9;W)K)UT@/2`G06UE
M<FEC82].97<@66]R:R<["B1T>ELG06UE<FEC82].:7!I9V]N)UT@/2`G06UE
M<FEC82].:7!I9V]N)SL*)'1Z6R=!;65R:6-A+TYO;64G72`]("=!;65R:6-A
M+TYO;64G.PHD='I;)T%M97)I8V$O3F]R;VYH82==(#T@)T%M97)I8V$O3F]R
M;VYH82<["B1T>ELG06UE<FEC82]086YA;6$G72`]("=!;65R:6-A+U!A;F%M
M82<["B1T>ELG06UE<FEC82]086YG;FER='5N9R==(#T@)T%M97)I8V$O4&%N
M9VYI<G1U;F<G.PHD='I;)T%M97)I8V$O4&%R86UA<FEB;R==(#T@)T%M97)I
M8V$O4&%R86UA<FEB;R<["B1T>ELG06UE<FEC82]0:&]E;FEX)UT@/2`G06UE
M<FEC82]0:&]E;FEX)SL*)'1Z6R=!;65R:6-A+U!O<G0M874M4')I;F-E)UT@
M/2`G06UE<FEC82]0;W)T+6%U+5!R:6YC92<["B1T>ELG06UE<FEC82]0;W)T
M;U]696QH;R==(#T@)T%M97)I8V$O4&]R=&\@5F5L:&\G.PHD='I;)T%M97)I
M8V$O4&]R=%]O9E]3<&%I;B==(#T@)T%M97)I8V$O4&]R="!O9B!3<&%I;B<[
M"B1T>ELG06UE<FEC82]0=65R=&]?4FEC;R==(#T@)T%M97)I8V$O4'5E<G1O
M(%)I8V\G.PHD='I;)T%M97)I8V$O4F%I;GE?4FEV97(G72`]("=!;65R:6-A
M+U)A:6YY(%)I=F5R)SL*)'1Z6R=!;65R:6-A+U)A;FMI;E]);FQE="==(#T@
M)T%M97)I8V$O4F%N:VEN($EN;&5T)SL*)'1Z6R=!;65R:6-A+U)E8VEF92==
M(#T@)T%M97)I8V$O4F5C:69E)SL*)'1Z6R=!;65R:6-A+U)E9VEN82==(#T@
M)T%M97)I8V$O4F5G:6YA)SL*)'1Z6R=!;65R:6-A+U)I;U]"<F%N8V\G72`]
M("=!;65R:6-A+U)I;R!"<F%N8V\G.PHD='I;)T%M97)I8V$O4F]S87)I;R==
M(#T@)T%M97)I8V$O4F]S87)I;R<["B1T>ELG06UE<FEC82]386YT:6%G;R==
M(#T@)T%M97)I8V$O4V%N=&EA9V\G.PHD='I;)T%M97)I8V$O4V%N=&]?1&]M
M:6YG;R==(#T@)T%M97)I8V$O4V%N=&\@1&]M:6YG;R<["B1T>ELG06UE<FEC
M82]386]?4&%U;&\G72`]("=!;65R:6-A+U-A;R!0875L;R<["B1T>ELG06UE
M<FEC82]38V]R97-B>7-U;F0G72`]("=!;65R:6-A+U-C;W)E<V)Y<W5N9"<[
M"B1T>ELG06UE<FEC82]3:&EP<F]C:R==(#T@)T%M97)I8V$O4VAI<')O8VLG
M.PHD='I;)T%M97)I8V$O4W1?2F]H;G,G72`]("=!;65R:6-A+U-T($IO:&YS
M)SL*)'1Z6R=!;65R:6-A+U-T7TMI='1S)UT@/2`G06UE<FEC82]3="!+:71T
M<R<["B1T>ELG06UE<FEC82]3=%],=6-I82==(#T@)T%M97)I8V$O4W0@3'5C
M:6$G.PHD='I;)T%M97)I8V$O4W1?5&AO;6%S)UT@/2`G06UE<FEC82]3="!4
M:&]M87,G.PHD='I;)T%M97)I8V$O4W1?5FEN8V5N="==(#T@)T%M97)I8V$O
M4W0@5FEN8V5N="<["B1T>ELG06UE<FEC82]3=VEF=%]#=7)R96YT)UT@/2`G
M06UE<FEC82]3=VEF="!#=7)R96YT)SL*)'1Z6R=!;65R:6-A+U1E9W5C:6=A
M;'!A)UT@/2`G06UE<FEC82]496=U8VEG86QP82<["B1T>ELG06UE<FEC82]4
M:'5L92==(#T@)T%M97)I8V$O5&AU;&4G.PHD='I;)T%M97)I8V$O5&AU;F1E
M<E]"87DG72`]("=!;65R:6-A+U1H=6YD97(@0F%Y)SL*)'1Z6R=!;65R:6-A
M+U1I:G5A;F$G72`]("=!;65R:6-A+U1I:G5A;F$G.PHD='I;)T%M97)I8V$O
M5&]R=&]L82==(#T@)T%M97)I8V$O5&]R=&]L82<["B1T>ELG06UE<FEC82]6
M86YC;W5V97(G72`]("=!;65R:6-A+U9A;F-O=79E<B<["B1T>ELG06UE<FEC
M82]7:&ET96AO<G-E)UT@/2`G06UE<FEC82]7:&ET96AO<G-E)SL*)'1Z6R=!
M;65R:6-A+U=I;FYI<&5G)UT@/2`G06UE<FEC82]7:6YN:7!E9R<["B1T>ELG
M06UE<FEC82]986MU=&%T)UT@/2`G06UE<FEC82]986MU=&%T)SL*)'1Z6R=!
M;65R:6-A+UEE;&QO=VMN:69E)UT@/2`G06UE<FEC82]996QL;W=K;FEF92<[
M"B1T>ELG06YT87)C=&EC82]#87-E>2==(#T@)T%N=&%R8W1I8V$O0V%S97DG
M.PHD='I;)T%N=&%R8W1I8V$O1&%V:7,G72`]("=!;G1A<F-T:6-A+T1A=FES
M)SL*)'1Z6R=!;G1A<F-T:6-A+T1U;6]N=$15<G9I;&QE)UT@/2`G06YT87)C
M=&EC82]$=6UO;G1$57)V:6QL92<["B1T>ELG06YT87)C=&EC82]-87=S;VXG
M72`]("=!;G1A<F-T:6-A+TUA=W-O;B<["B1T>ELG06YT87)C=&EC82]-8TUU
M<F1O)UT@/2`G06YT87)C=&EC82]-8TUU<F1O)SL*)'1Z6R=!;G1A<F-T:6-A
M+U!A;&UE<B==(#T@)T%N=&%R8W1I8V$O4&%L;65R)SL*)'1Z6R=!;G1A<F-T
M:6-A+U-O=71H7U!O;&4G72`]("=!;G1A<F-T:6-A+U-O=71H(%!O;&4G.PHD
M='I;)T%N=&%R8W1I8V$O4WEO=V$G72`]("=!;G1A<F-T:6-A+U-Y;W=A)SL*
M)'1Z6R=!;G1A<F-T:6-A+U9O<W1O:R==(#T@)T%N=&%R8W1I8V$O5F]S=&]K
M)SL*)'1Z6R=!<F-T:6,O3&]N9WEE87)B>65N)UT@/2`G07)C=&EC+TQO;F=Y
M96%R8GEE;B<["B1T>ELG07-I82]!9&5N)UT@/2`G07-I82]!9&5N)SL*)'1Z
M6R=!<VEA+T%L;6%T>2==(#T@)T%S:6$O06QM871Y)SL*)'1Z6R=!<VEA+T%M
M;6%N)UT@/2`G07-I82]!;6UA;B<["B1T>ELG07-I82]!;F%D>7(G72`]("=!
M<VEA+T%N861Y<B<["B1T>ELG07-I82]!<71A=2==(#T@)T%S:6$O07%T874G
M.PHD='I;)T%S:6$O07%T;V)E)UT@/2`G07-I82]!<71O8F4G.PHD='I;)T%S
M:6$O07-H9V%B870G72`]("=!<VEA+T%S:&=A8F%T)SL*)'1Z6R=!<VEA+T)A
M9VAD860G72`]("=!<VEA+T)A9VAD860G.PHD='I;)T%S:6$O0F%H<F%I;B==
M(#T@)T%S:6$O0F%H<F%I;B<["B1T>ELG07-I82]"86MU)UT@/2`G07-I82]"
M86MU)SL*)'1Z6R=!<VEA+T)A;F=K;VLG72`]("=!<VEA+T)A;F=K;VLG.PHD
M='I;)T%S:6$O0F5I<G5T)UT@/2`G07-I82]"96ER=70G.PHD='I;)T%S:6$O
M0FES:&ME:R==(#T@)T%S:6$O0FES:&ME:R<["B1T>ELG07-I82]"<G5N96DG
M72`]("=!<VEA+T)R=6YE:2<["B1T>ELG07-I82]#86QC=71T82==(#T@)T%S
M:6$O0V%L8W5T=&$G.PHD='I;)T%S:6$O0VAU;F=K:6YG)UT@/2`G07-I82]#
M:'5N9VMI;F<G.PHD='I;)T%S:6$O0V]L;VUB;R==(#T@)T%S:6$O0V]L;VUB
M;R<["B1T>ELG07-I82]$86UA<V-U<R==(#T@)T%S:6$O1&%M87-C=7,G.PHD
M='I;)T%S:6$O1&AA:V$G72`]("=!<VEA+T1H86MA)SL*)'1Z6R=!<VEA+T1I
M;&DG72`]("=!<VEA+T1I;&DG.PHD='I;)T%S:6$O1'5B86DG72`]("=!<VEA
M+T1U8F%I)SL*)'1Z6R=!<VEA+T1U<VAA;F)E)UT@/2`G07-I82]$=7-H86YB
M92<["B1T>ELG07-I82]'87IA)UT@/2`G07-I82]'87IA)SL*)'1Z6R=!<VEA
M+TAA<F)I;B==(#T@)T%S:6$O2&%R8FEN)SL*)'1Z6R=!<VEA+TAO;F=?2V]N
M9R==(#T@)T%S:6$O2&]N9R!+;VYG)SL*)'1Z6R=!<VEA+TAO=F0G72`]("=!
M<VEA+TAO=F0G.PHD='I;)T%S:6$O27)K=71S:R==(#T@)T%S:6$O27)K=71S
M:R<["B1T>ELG07-I82]*86MA<G1A)UT@/2`G07-I82]*86MA<G1A)SL*)'1Z
M6R=!<VEA+TIA>6%P=7)A)UT@/2`G07-I82]*87EA<'5R82<["B1T>ELG07-I
M82]*97)U<V%L96TG72`]("=!<VEA+TIE<G5S86QE;2<["B1T>ELG07-I82]+
M86)U;"==(#T@)T%S:6$O2V%B=6PG.PHD='I;)T%S:6$O2V%M8VAA=&MA)UT@
M/2`G07-I82]+86UC:&%T:V$G.PHD='I;)T%S:6$O2V%R86-H:2==(#T@)T%S
M:6$O2V%R86-H:2<["B1T>ELG07-I82]+87-H9V%R)UT@/2`G07-I82]+87-H
M9V%R)SL*)'1Z6R=!<VEA+TMA=&UA;F1U)UT@/2`G07-I82]+871M86YD=2<[
M"B1T>ELG07-I82]+<F%S;F]Y87)S:R==(#T@)T%S:6$O2W)A<VYO>6%R<VLG
M.PHD='I;)T%S:6$O2W5A;&%?3'5M<'5R)UT@/2`G07-I82]+=6%L82!,=6UP
M=7(G.PHD='I;)T%S:6$O2W5C:&EN9R==(#T@)T%S:6$O2W5C:&EN9R<["B1T
M>ELG07-I82]+=7=A:70G72`]("=!<VEA+TMU=V%I="<["B1T>ELG07-I82]-
M86-A;R==(#T@)T%S:6$O36%C86\G.PHD='I;)T%S:6$O36%G861A;B==(#T@
M)T%S:6$O36%G861A;B<["B1T>ELG07-I82]-86YI;&$G72`]("=!<VEA+TUA
M;FEL82<["B1T>ELG07-I82]-=7-C870G72`]("=!<VEA+TUU<V-A="<["B1T
M>ELG07-I82].:6-O<VEA)UT@/2`G07-I82].:6-O<VEA)SL*)'1Z6R=!<VEA
M+TYO=F]S:6)I<G-K)UT@/2`G07-I82].;W9O<VEB:7)S:R<["B1T>ELG07-I
M82]/;7-K)UT@/2`G07-I82]/;7-K)SL*)'1Z6R=!<VEA+U!H;F]M7U!E;F@G
M72`]("=!<VEA+U!H;F]M(%!E;F@G.PHD='I;)T%S:6$O4'EO;F=Y86YG)UT@
M/2`G07-I82]0>6]N9WEA;F<G.PHD='I;)T%S:6$O46%T87(G72`]("=!<VEA
M+U%A=&%R)SL*)'1Z6R=!<VEA+U)A;F=O;VXG72`]("=!<VEA+U)A;F=O;VXG
M.PHD='I;)T%S:6$O4FEY861H)UT@/2`G07-I82]2:7EA9&@G.PHD='I;)T%S
M:6$O4V%I9V]N)UT@/2`G07-I82]386EG;VXG.PHD='I;)T%S:6$O4V%M87)K
M86YD)UT@/2`G07-I82]386UA<FMA;F0G.PHD='I;)T%S:6$O4V5O=6PG72`]
M("=!<VEA+U-E;W5L)SL*)'1Z6R=!<VEA+U-H86YG:&%I)UT@/2`G07-I82]3
M:&%N9VAA:2<["B1T>ELG07-I82]3:6YG87!O<F4G72`]("=!<VEA+U-I;F=A
M<&]R92<["B1T>ELG07-I82]486EP96DG72`]("=!<VEA+U1A:7!E:2<["B1T
M>ELG07-I82]487-H:V5N="==(#T@)T%S:6$O5&%S:&ME;G0G.PHD='I;)T%S
M:6$O5&)I;&ES:2==(#T@)T%S:6$O5&)I;&ES:2<["B1T>ELG07-I82]496AR
M86XG72`]("=!<VEA+U1E:')A;B<["B1T>ELG07-I82]4:&EM<&AU)UT@/2`G
M07-I82]4:&EM<&AU)SL*)'1Z6R=!<VEA+U1O:WEO)UT@/2`G07-I82]4;VMY
M;R<["B1T>ELG07-I82]5:G5N9U]086YD86YG)UT@/2`G07-I82]5:G5N9R!0
M86YD86YG)SL*)'1Z6R=!<VEA+U5L86%N8F%A=&%R)UT@/2`G07-I82]5;&%A
M;F)A871A<B<["B1T>ELG07-I82]5<G5M<6DG72`]("=!<VEA+U5R=6UQ:2<[
M"B1T>ELG07-I82]6:65N=&EA;F4G72`]("=!<VEA+U9I96YT:6%N92<["B1T
M>ELG07-I82]6;&%D:79O<W1O:R==(#T@)T%S:6$O5FQA9&EV;W-T;VLG.PHD
M='I;)T%S:6$O66%K=71S:R==(#T@)T%S:6$O66%K=71S:R<["B1T>ELG07-I
M82]996MA=&5R:6YB=7)G)UT@/2`G07-I82]996MA=&5R:6YB=7)G)SL*)'1Z
M6R=!<VEA+UEE<F5V86XG72`]("=!<VEA+UEE<F5V86XG.PHD='I;)T%T;&%N
M=&EC+T%Z;W)E<R==(#T@)T%T;&%N=&EC+T%Z;W)E<R<["B1T>ELG071L86YT
M:6,O0F5R;75D82==(#T@)T%T;&%N=&EC+T)E<FUU9&$G.PHD='I;)T%T;&%N
M=&EC+T-A;F%R>2==(#T@)T%T;&%N=&EC+T-A;F%R>2<["B1T>ELG071L86YT
M:6,O0V%P95]697)D92==(#T@)T%T;&%N=&EC+T-A<&4@5F5R9&4G.PHD='I;
M)T%T;&%N=&EC+T9A97)O92==(#T@)T%T;&%N=&EC+T9A97)O92<["B1T>ELG
M071L86YT:6,O2F%N7TUA>65N)UT@/2`G071L86YT:6,O2F%N($UA>65N)SL*
M)'1Z6R=!=&QA;G1I8R]-861E:7)A)UT@/2`G071L86YT:6,O36%D96ER82<[
M"B1T>ELG071L86YT:6,O4F5Y:VIA=FEK)UT@/2`G071L86YT:6,O4F5Y:VIA
M=FEK)SL*)'1Z6R=!=&QA;G1I8R]3;W5T:%]'96]R9VEA)UT@/2`G071L86YT
M:6,O4V]U=&@@1V5O<F=I82<["B1T>ELG071L86YT:6,O4W1A;FQE>2==(#T@
M)T%T;&%N=&EC+U-T86YL97DG.PHD='I;)T%T;&%N=&EC+U-T7TAE;&5N82==
M(#T@)T%T;&%N=&EC+U-T($AE;&5N82<["B1T>ELG075S=')A;&EA+T%D96QA
M:61E)UT@/2`G075S=')A;&EA+T%D96QA:61E)SL*)'1Z6R=!=7-T<F%L:6$O
M0G)I<V)A;F4G72`]("=!=7-T<F%L:6$O0G)I<V)A;F4G.PHD='I;)T%U<W1R
M86QI82]"<F]K96Y?2&EL;"==(#T@)T%U<W1R86QI82]"<F]K96X@2&EL;"<[
M"B1T>ELG075S=')A;&EA+T1A<G=I;B==(#T@)T%U<W1R86QI82]$87)W:6XG
M.PHD='I;)T%U<W1R86QI82](;V)A<G0G72`]("=!=7-T<F%L:6$O2&]B87)T
M)SL*)'1Z6R=!=7-T<F%L:6$O3&EN9&5M86XG72`]("=!=7-T<F%L:6$O3&EN
M9&5M86XG.PHD='I;)T%U<W1R86QI82],;W)D7TAO=V4G72`]("=!=7-T<F%L
M:6$O3&]R9"!(;W=E)SL*)'1Z6R=!=7-T<F%L:6$O365L8F]U<FYE)UT@/2`G
M075S=')A;&EA+TUE;&)O=7)N92<["B1T>ELG075S=')A;&EA+U!E<G1H)UT@
M/2`G075S=')A;&EA+U!E<G1H)SL*)'1Z6R=!=7-T<F%L:6$O4WED;F5Y)UT@
M/2`G075S=')A;&EA+U-Y9&YE>2<["B1T>ELG175R;W!E+T%M<W1E<F1A;2==
M(#T@)T5U<F]P92]!;7-T97)D86TG.PHD='I;)T5U<F]P92]!;F1O<G)A)UT@
M/2`G175R;W!E+T%N9&]R<F$G.PHD='I;)T5U<F]P92]!=&AE;G,G72`]("=%
M=7)O<&4O071H96YS)SL*)'1Z6R=%=7)O<&4O0F5L9F%S="==(#T@)T5U<F]P
M92]"96QF87-T)SL*)'1Z6R=%=7)O<&4O0F5L9W)A9&4G72`]("=%=7)O<&4O
M0F5L9W)A9&4G.PHD='I;)T5U<F]P92]"97)L:6XG72`]("=%=7)O<&4O0F5R
M;&EN)SL*)'1Z6R=%=7)O<&4O0G)A=&ES;&%V82==(#T@)T5U<F]P92]"<F%T
M:7-L879A)SL*)'1Z6R=%=7)O<&4O0G)U<W-E;',G72`]("=%=7)O<&4O0G)U
M<W-E;',G.PHD='I;)T5U<F]P92]"=6-H87)E<W0G72`]("=%=7)O<&4O0G5C
M:&%R97-T)SL*)'1Z6R=%=7)O<&4O0G5D87!E<W0G72`]("=%=7)O<&4O0G5D
M87!E<W0G.PHD='I;)T5U<F]P92]#:&ES:6YA=2==(#T@)T5U<F]P92]#:&ES
M:6YA=2<["B1T>ELG175R;W!E+T-O<&5N:&%G96XG72`]("=%=7)O<&4O0V]P
M96YH86=E;B<["B1T>ELG175R;W!E+T1U8FQI;B==(#T@)T5U<F]P92]$=6)L
M:6XG.PHD='I;)T5U<F]P92]':6)R86QT87(G72`]("=%=7)O<&4O1VEB<F%L
M=&%R)SL*)'1Z6R=%=7)O<&4O2&5L<VEN:VDG72`]("=%=7)O<&4O2&5L<VEN
M:VDG.PHD='I;)T5U<F]P92])<W1A;F)U;"==(#T@)T5U<F]P92])<W1A;F)U
M;"<["B1T>ELG175R;W!E+TMA;&EN:6YG<F%D)UT@/2`G175R;W!E+TMA;&EN
M:6YG<F%D)SL*)'1Z6R=%=7)O<&4O2VEE=B==(#T@)T5U<F]P92]+:65V)SL*
M)'1Z6R=%=7)O<&4O3&ES8F]N)UT@/2`G175R;W!E+TQI<V)O;B<["B1T>ELG
M175R;W!E+TQJ=6)L:F%N82==(#T@)T5U<F]P92],:G5B;&IA;F$G.PHD='I;
M)T5U<F]P92],;VYD;VXG72`]("=%=7)O<&4O3&]N9&]N)SL*)'1Z6R=%=7)O
M<&4O3'5X96UB;W5R9R==(#T@)T5U<F]P92],=7AE;6)O=7)G)SL*)'1Z6R=%
M=7)O<&4O36%D<FED)UT@/2`G175R;W!E+TUA9')I9"<["B1T>ELG175R;W!E
M+TUA;'1A)UT@/2`G175R;W!E+TUA;'1A)SL*)'1Z6R=%=7)O<&4O36EN<VLG
M72`]("=%=7)O<&4O36EN<VLG.PHD='I;)T5U<F]P92]-;VYA8V\G72`]("=%
M=7)O<&4O36]N86-O)SL*)'1Z6R=%=7)O<&4O36]S8V]W)UT@/2`G175R;W!E
M+TUO<V-O=R<["B1T>ELG175R;W!E+T]S;&\G72`]("=%=7)O<&4O3W-L;R<[
M"B1T>ELG175R;W!E+U!A<FES)UT@/2`G175R;W!E+U!A<FES)SL*)'1Z6R=%
M=7)O<&4O4')A9W5E)UT@/2`G175R;W!E+U!R86=U92<["B1T>ELG175R;W!E
M+U)I9V$G72`]("=%=7)O<&4O4FEG82<["B1T>ELG175R;W!E+U)O;64G72`]
M("=%=7)O<&4O4F]M92<["B1T>ELG175R;W!E+U-A;6%R82==(#T@)T5U<F]P
M92]386UA<F$G.PHD='I;)T5U<F]P92]386Y?36%R:6YO)UT@/2`G175R;W!E
M+U-A;B!-87)I;F\G.PHD='I;)T5U<F]P92]387)A:F5V;R==(#T@)T5U<F]P
M92]387)A:F5V;R<["B1T>ELG175R;W!E+U-I;69E<F]P;VPG72`]("=%=7)O
M<&4O4VEM9F5R;W!O;"<["B1T>ELG175R;W!E+U-K;W!J92==(#T@)T5U<F]P
M92]3:V]P:F4G.PHD='I;)T5U<F]P92]3;V9I82==(#T@)T5U<F]P92]3;V9I
M82<["B1T>ELG175R;W!E+U-T;V-K:&]L;2==(#T@)T5U<F]P92]3=&]C:VAO
M;&TG.PHD='I;)T5U<F]P92]486QL:6YN)UT@/2`G175R;W!E+U1A;&QI;FXG
M.PHD='I;)T5U<F]P92]4:7)A;F4G72`]("=%=7)O<&4O5&ER86YE)SL*)'1Z
M6R=%=7)O<&4O57IH9V]R;V0G72`]("=%=7)O<&4O57IH9V]R;V0G.PHD='I;
M)T5U<F]P92]6861U>B==(#T@)T5U<F]P92]6861U>B<["B1T>ELG175R;W!E
M+U9A=&EC86XG72`]("=%=7)O<&4O5F%T:6-A;B<["B1T>ELG175R;W!E+U9I
M96YN82==(#T@)T5U<F]P92]6:65N;F$G.PHD='I;)T5U<F]P92]6:6QN:75S
M)UT@/2`G175R;W!E+U9I;&YI=7,G.PHD='I;)T5U<F]P92]787)S87<G72`]
M("=%=7)O<&4O5V%R<V%W)SL*)'1Z6R=%=7)O<&4O6F%G<F5B)UT@/2`G175R
M;W!E+UIA9W)E8B<["B1T>ELG175R;W!E+UIA<&]R;WIH>64G72`]("=%=7)O
M<&4O6F%P;W)O>FAY92<["B1T>ELG175R;W!E+UIU<FEC:"==(#T@)T5U<F]P
M92]:=7)I8V@G.PHD='I;)TEN9&EA;B]!;G1A;F%N87)I=F\G72`]("=);F1I
M86XO06YT86YA;F%R:79O)SL*)'1Z6R=);F1I86XO0VAA9V]S)UT@/2`G26YD
M:6%N+T-H86=O<R<["B1T>ELG26YD:6%N+T-H<FES=&UA<R==(#T@)TEN9&EA
M;B]#:')I<W1M87,G.PHD='I;)TEN9&EA;B]#;V-O<R==(#T@)TEN9&EA;B]#
M;V-O<R<["B1T>ELG26YD:6%N+T-O;6]R;R==(#T@)TEN9&EA;B]#;VUO<F\G
M.PHD='I;)TEN9&EA;B]+97)G=65L96XG72`]("=);F1I86XO2V5R9W5E;&5N
M)SL*)'1Z6R=);F1I86XO36%H92==(#T@)TEN9&EA;B]-86AE)SL*)'1Z6R=)
M;F1I86XO36%L9&EV97,G72`]("=);F1I86XO36%L9&EV97,G.PHD='I;)TEN
M9&EA;B]-875R:71I=7,G72`]("=);F1I86XO36%U<FET:75S)SL*)'1Z6R=)
M;F1I86XO36%Y;W1T92==(#T@)TEN9&EA;B]-87EO='1E)SL*)'1Z6R=);F1I
M86XO4F5U;FEO;B==(#T@)TEN9&EA;B]2975N:6]N)SL*)'1Z6R=086-I9FEC
M+T%P:6$G72`]("=086-I9FEC+T%P:6$G.PHD='I;)U!A8VEF:6,O075C:VQA
M;F0G72`]("=086-I9FEC+T%U8VML86YD)SL*)'1Z6R=086-I9FEC+T-H871H
M86TG72`]("=086-I9FEC+T-H871H86TG.PHD='I;)U!A8VEF:6,O16%S=&5R
M)UT@/2`G4&%C:69I8R]%87-T97(G.PHD='I;)U!A8VEF:6,O169A=&4G72`]
M("=086-I9FEC+T5F871E)SL*)'1Z6R=086-I9FEC+T5N9&5R8G5R>2==(#T@
M)U!A8VEF:6,O16YD97)B=7)Y)SL*)'1Z6R=086-I9FEC+T9A:V%O9F\G72`]
M("=086-I9FEC+T9A:V%O9F\G.PHD='I;)U!A8VEF:6,O1FEJ:2==(#T@)U!A
M8VEF:6,O1FEJ:2<["B1T>ELG4&%C:69I8R]&=6YA9G5T:2==(#T@)U!A8VEF
M:6,O1G5N869U=&DG.PHD='I;)U!A8VEF:6,O1V%L87!A9V]S)UT@/2`G4&%C
M:69I8R]'86QA<&%G;W,G.PHD='I;)U!A8VEF:6,O1V%M8FEE<B==(#T@)U!A
M8VEF:6,O1V%M8FEE<B<["B1T>ELG4&%C:69I8R]'=6%D86QC86YA;"==(#T@
M)U!A8VEF:6,O1W5A9&%L8V%N86PG.PHD='I;)U!A8VEF:6,O1W5A;2==(#T@
M)U!A8VEF:6,O1W5A;2<["B1T>ELG4&%C:69I8R](;VYO;'5L=2==(#T@)U!A
M8VEF:6,O2&]N;VQU;'4G.PHD='I;)U!A8VEF:6,O2F]H;G-T;VXG72`]("=0
M86-I9FEC+TIO:&YS=&]N)SL*)'1Z6R=086-I9FEC+TMI<FET:6UA=&DG72`]
M("=086-I9FEC+TMI<FET:6UA=&DG.PHD='I;)U!A8VEF:6,O2V]S<F%E)UT@
M/2`G4&%C:69I8R]+;W-R864G.PHD='I;)U!A8VEF:6,O2W=A:F%L96EN)UT@
M/2`G4&%C:69I8R]+=V%J86QE:6XG.PHD='I;)U!A8VEF:6,O36%J=7)O)UT@
M/2`G4&%C:69I8R]-86IU<F\G.PHD='I;)U!A8VEF:6,O36%R<75E<V%S)UT@
M/2`G4&%C:69I8R]-87)Q=65S87,G.PHD='I;)U!A8VEF:6,O36ED=V%Y)UT@
M/2`G4&%C:69I8R]-:61W87DG.PHD='I;)U!A8VEF:6,O3F%U<G4G72`]("=0
M86-I9FEC+TYA=7)U)SL*)'1Z6R=086-I9FEC+TYI=64G72`]("=086-I9FEC
M+TYI=64G.PHD='I;)U!A8VEF:6,O3F]R9F]L:R==(#T@)U!A8VEF:6,O3F]R
M9F]L:R<["B1T>ELG4&%C:69I8R].;W5M96$G72`]("=086-I9FEC+TYO=6UE
M82<["B1T>ELG4&%C:69I8R]086=O7U!A9V\G72`]("=086-I9FEC+U!A9V\@
M4&%G;R<["B1T>ELG4&%C:69I8R]086QA=2==(#T@)U!A8VEF:6,O4&%L874G
M.PHD='I;)U!A8VEF:6,O4&ET8V%I<FXG72`]("=086-I9FEC+U!I=&-A:7)N
M)SL*)'1Z6R=086-I9FEC+U!O;F%P92==(#T@)U!A8VEF:6,O4&]N87!E)SL*
M)'1Z6R=086-I9FEC+U!O<G1?36]R97-B>2==(#T@)U!A8VEF:6,O4&]R="!-
M;W)E<V)Y)SL*)'1Z6R=086-I9FEC+U)A<F]T;VYG82==(#T@)U!A8VEF:6,O
M4F%R;W1O;F=A)SL*)'1Z6R=086-I9FEC+U-A:7!A;B==(#T@)U!A8VEF:6,O
M4V%I<&%N)SL*)'1Z6R=086-I9FEC+U1A:&ET:2==(#T@)U!A8VEF:6,O5&%H
M:71I)SL*)'1Z6R=086-I9FEC+U1A<F%W82==(#T@)U!A8VEF:6,O5&%R87=A
M)SL*)'1Z6R=086-I9FEC+U1O;F=A=&%P=2==(#T@)U!A8VEF:6,O5&]N9V%T
M87!U)SL*)'1Z6R=086-I9FEC+U1R=6LG72`]("=086-I9FEC+U1R=6LG.PHD
M='I;)U!A8VEF:6,O5V%K92==(#T@)U!A8VEF:6,O5V%K92<["B1T>ELG4&%C
M:69I8R]786QL:7,G72`]("=086-I9FEC+U=A;&QI<R<["B1T>ELG4&%C:69I
M8R]987`G72`]("=086-I9FEC+UEA<"<["@HD1TQ/0D%,4ULG='HG72`]("8D
M='H["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]P<F5F<RYP:'``````````
M````````````````````````````````````````````````````````````
M````,#$P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#$S-#<`,3`U,34T
M,S$P-S``,#(P,3(P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V-O;F9I9R]P
M<F5F<RYP:'`N9&ES="QV(#$N.#4N,BXW(#(P,#8O,#8O,C(@,3@Z-#<Z-34@
M8VAU8VL@17AP("0*("H*("H@4')E9F5R96YC97,@26YF;W)M871I;VX*("H@
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("H@0VAA;F=E<R!Y;W4@;6%K92!T
M;R!T:&4@<')E9G,N<&AP(&9I;&4H<RD@=VEL;"!N;W0@8F4@<F5F;&5C=&5D
M('5N=&EL('1H90H@*B!U<V5R(&QO9W,@;W5T(&%N9"!L;V=S(&EN(&%G86EN
M+@H@*@H@*B!)9B!Y;W4@8VAA;F=E('1H97-E('!R969E<F5N8V5S(&EN(&$@
M<')O9'5C=&EO;B!S>7-T96TL('EO=2!W:6QL"B`J(&YE960@=&\@9&5L971E
M(&%N>2!H;W)D95]P<F5F<R!I;B!Y;W5R('!R969E<F5N8V5S(&1A=&%B87-E
M+@H@*@H@*B!P<F5F1W)O=7!S(&%R<F%Y"B`J("TM+2TM+2TM+2TM+2TM+2T*
M("H@)'!R969'<F]U<',@87)E(&9O<B!D:7-P;&%Y('!U<G!O<V5S('=H96X@
M>6]U('!R97-S('1H92!O<'1I;VYS(&)U='1O;BX*("H@5&AE(&]P=&EO;G,@
M8VAO:6-E('=I;&P@87!P96%R('=H96X@>6]U('-E="!Y;W5R('!R969E<F5N
M8V5S(&1R:79E<@H@*B!I;B!T:&4@:&]R9&4O8V]N9FEG+V-O;F8N<&AP(&9I
M;&4N"B`J"B`J("1P<F5F1W)O=7!S(&%R<F%Y(&1E9FEN:71I;VXZ"B`J("`@
M(&-O;'5M;CH@(%=H870@8V]L=6UN(&AE860@=&AI<R!G<F]U<"!W:6QL(&=O
M('5N9&5R"B`J("`@("!L86)E;#H@($QA8F5L(&9O<B!T:&4@9W)O=7`@;V8@
M<V5T=&EN9W,*("H@("`@("!D97-C.B`@1&5S8W)I<'1I;VX@=&AA="!W:6QL
M('-H;W<@=6YD97(@;&%B96P*("H@("!M96UB97)S.B`@3&ES="!O9B!P<F5F
M97)E;F-E<R!S=7!P;W)T960@8GD@=&AI<R!G<F]U<`H@*@H@*B!?<')E9G,@
M87)R87D*("H@+2TM+2TM+2TM+2TM"B`J(%1H92`D7W!R969S(&%R<F%Y)W,@
M87)E(&QI<W1E9"!I;B!T:&4@<V%M92!O<F1E<B!A<R!L:7-T960@:6X@=&AE
M"B`J(&UE;6)E<G,@96QE;65N="!O9B`D<')E9D=R;W5P<RX*("H*("H@("!V
M86QU93H@5&AI<R!E;G1R>2!W:6QL(&5I=&AE<B!H;VQD(&$@;G5M8F5R(&]R
M(&$@=&5X="!V86QU92!B87-E9"!O;B!T:&4*("H@("`@("`@("`@<')E9F5R
M96YC92!T>7!E.@H@*B`@("`@("`@("`@(&EM<&QI8VET.B`@4V5E(%!R969E
M<F5N8V4@='EP90H@*B`@("`@("`@("`@("`@("!T97AT.B`@5&5X="!V86QU
M90H@*B`@("`@("`@("`@("`@;G5M8F5R.B`@3G5M8F5R('9A;'5E"B`J("`@
M("`@("`@("`@8VAE8VMB;W@Z("!686QU92!S:&]U;&0@8F4@,"!F;W(@=6YC
M:&5C:V5D+"`Q(&9O<B!C:&5C:V5D"B`J("`@("`@("`@("`@("!S96QE8W0Z
M("!686QU92!A<W-O8VEA=&5D('=I=&@@=&AA="!S96QE8W1I;VX@;&ES=`H@
M*@H@*B`@;&]C:V5D.B!!;&QO=R!P<F5F97)E;F-E('1O(&)E(&-H86YG960@
M9G)O;2!520H@*B`@("`@("`@("`@("!T<G5E.B`@1&\@;F]T('-H;W<@=&AI
M<R!P<F5F97)E;F-E(&EN('1H92!520H@*B`@("`@("`@("`@(&9A;'-E.B`@
M4VAO=R!T:&ES('!R969E<F5N8V4@:6X@=&AE(%5)(&%N9"!A;&QO=R!C:&%N
M9VEN9PH@*@H@*B`@<VAA<F5D.B!3:&%R92!W:71H(&]T:&5R(&AO<F1E(&%P
M<',*("H@("`@("`@("`@("`@=')U93H@(%-H87)E('1H:7,@<')E9B!W:71H
M(&]T:&5R($AO<F1E(&%P<',*("H@("`@("`@("`@("!F86QS93H@($ME97`@
M=&AI<R!P<F5F(&QO8V%L('1O('1H92!C=7)R96YT(&%P<`H@*@H@*B`@("!T
M>7!E.B!0<F5F97)E;F-E('1Y<&4*("H@("`@("`@("`@("`@<W!E8VEA;#H@
M(%!R;W9I9&5S(&$@54D@=VED9V5T"B`J("`@("`@("`@("`@("!S96QE8W0Z
M("!0<F]V:61E<R!A('-E;&5C=&EO;B!L:7-T(&EN('1H92!520H@*B`@("`@
M("`@("`@(&-H96-K8F]X.B`@4')O=FED97,@82!C:&5C:V)O>`H@*B`@("`@
M("`@("`@(&EM<&QI8VET.B`@4')O=FED97,@<W1O<F%G92!F;W(@)W-P96-I
M86PG('1Y<&5S"B`J("`@("`@("`@("`@<&%S<W=O<F0Z("!0<F]V:61E<R!A
M('1E>'1B;W@@9F]R('!A<W-W;W)D(&5N=')Y+@H@*B`@("`@("`@("`@("`@
M("!E;G5M.B`@57-E('-T871I8R!L:7-T(&]F(&5L96UE;G1S+BXN<VEM:6QA
M<B!T;R`G<V5L96-T)PH@*@H@*B`@("!E;G5M.B!3=&%T:6,@;&ES="!O9B!E
M;&5M96YT<RX*("H*("H@97-C87!E9#H@1F]R(&%N(&5N=6T@;W(@82!S96QE
M8W0L(&%R92!T:&4@:V5Y<R!A;F0@=F%L=65S(&%L<F5A9'D@:'1M;"UE<V-A
M<&5D/PH@*B`@("`@("`@("!$969A=6QT<R!T;R!F86QS92!I9B!N;W0@<')E
M<V5N="X*("H*("H@("`@:&]O:SH@0V%L;"!A(&AO;VL@9G5N8W1I;VX@9F]R
M('1H92!V86QU92!O9B!T:&ES('!R969E<F5N8V4*("H@("`@("`@("`@("`@
M=')U93H@(%=I;&P@8V%L;"!T:&4@9G5N8W1I;VX@7W!R969S7VAO;VM?/'!R
M969N86UE/@H@*B`@("`@("`@("`@("`@("`@("`@=&\@9FEL;"!I;B!T:&4@
M=F%L=64@;V8@=&AI<R!P<F5F97)E;F-E+@H@*B`@("`@("`@("`@("`@("`@
M("`@4V5E(&AO;VMS+G!H<"!F;W(@;6]R92!D971A:6QS+@H@*B`@("`@("`@
M("`@(&9A;'-E.B`@3F]R;6%L(&)E:&%V:6]U<B`M(&YO(&AO;VL@:7,@8V%L
M;&5D+@H@*B\*"B1P<F5F1W)O=7!S6R=I9&5N=&ET:65S)UT@/2!A<G)A>2@*
M("`@("=C;VQU;6XG(#T^(%\H(EEO=7(@26YF;W)M871I;VXB*2P*("`@("=L
M86)E;"<@/3X@7R@B4&5R<V]N86P@26YF;W)M871I;VXB*2P*("`@("=D97-C
M)R`]/B!?*")#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL
M<RXB*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G9&5F875L=%]I9&5N=&ET
M>2<L("=I9&5N=&ET>7-E;&5C="<L("=D96QE=&5I9&5N=&ET>2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)VED)RP@)V9U;&QN86UE)RP@)V9R;VU?861D
M<B<I"BD["@HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O
M;F8G75LG875T:"==6R=D<FEV97(G72D["FEF("AI<U]A*"1A=71H+"`G075T
M:"<I("8F("1A=71H+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@
M)'!R969'<F]U<'-;)V9O<F=O='!A<W,G72`](&%R<F%Y*`H@("`@("`@("=C
M;VQU;6XG(#T^(%\H(EEO=7(@26YF;W)M871I;VXB*2P*("`@("`@("`G;&%B
M96PG(#T^(%\H(D%C8V]U;G0@4&%S<W=O<F0B*2P*("`@("`@("`G9&5S8R<@
M/3X@7R@B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(I+`H@("`@("`@("=M
M96UB97)S)R`]/B!A<G)A>2@G<V5C=7)I='E?<75E<W1I;VXG+"`G<V5C=7)I
M='E?86YS=V5R)RP@)V%L=&5R;F%T95]E;6%I;"<I"B`@("`I.PI]"@HD<')E
M9D=R;W5P<ULG;&%N9W5A9V4G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@
M7R@B66]U<B!);F9O<FUA=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*"),;V-A
M;&4@86YD(%1I;64B*2P*("`@("=D97-C)R`]/B!?*")3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(BDL
M"B`@("`G;65M8F5R<R<@/3X@87)R87DH)VQA;F=U86=E)RP@)W1I;65Z;VYE
M)RP@)W1W96YT>49O=7(G+"`G9&%T95]F;W)M870G*0HI.PH*)'!R969'<F]U
M<'-;)V-A=&5G;W)I97,G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B
M66]U<B!);F9O<FUA=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*")#871E9V]R
M:65S(&%N9"!,86)E;',B*2P*("`@("=D97-C)R`]/B!?*")-86YA9V4@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W
M:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R
M:65S+B(I+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=C871E9V]R>6UA;F%G
M96UE;G0G*0HI.PH*)'!R969'<F]U<'-;)V1I<W!L87DG72`](&%R<F%Y*`H@
M("`@)V-O;'5M;B<@/3X@7R@B3W1H97(@26YF;W)M871I;VXB*2P*("`@("=L
M86)E;"<@/3X@7R@B1&ES<&QA>2!/<'1I;VYS(BDL"B`@("`G9&5S8R<@/3X@
M7R@B4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)VEN:71I86Q?87!P;&EC871I
M;VXG+"`G<VAO=U]L87-T7VQO9VEN)RP@)W1H96UE)RP*("`@("`@("`@("`@
M("`@("`@("`@("`G<W5M;6%R>5]R969R97-H7W1I;64G+"`G<VAO=U]S:61E
M8F%R)RP@)W-I9&5B87)?=VED=&@G+`H@("`@("`@("`@("`@("`@("`@("`@
M("=M;WI?<VED96)A<B<L("=M96YU7W9I97<G+"`G;65N=5]R969R97-H7W1I
M;64G+`H@("`@("`@("`@("`@("`@("`@("`@("=W:61G971?86-C97-S:V5Y
M)RP@)V%L<&AA7V9I;'1E<B<I"BD["@HD<')E9D=R;W5P<ULG;&]G:6YT87-K
M<R==(#T@87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")/=&AE<B!);F9O<FUA
M=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*"),;V=I;B!487-K<R(I+`H@("`@
M)V1E<V,G(#T^('-P<FEN=&8H7R@B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+B(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=N86UE)RDI+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=D;U]M86EN=&5N
M86YC92<L("=C;VYF:7)M7VUA:6YT96YA;F-E)RD**3L*"B1P<F5F1W)O=7!S
M6R=R96UO=&4G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B3W1H97(@
M26YF;W)M871I;VXB*2P*("`@("=L86)E;"<@/3X@7R@B4F5M;W1E(%-E<G9E
M<G,B*2P*("`@("=D97-C)R`]/B!?*")3970@=7`@<F5M;W1E('-E<G9E<G,@
M=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB*2P*
M("`@("=U<FPG(#T^("=S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<"<**3L*
M"B\O($9O<B!A;'1E<FYA=&4@24U34"!A=71H96YT:6-A=&EO;BX*:68@*"%E
M;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=I;7-P)UU;)V5N86)L960G72DI('L*
M("`@("1P<F5F1W)O=7!S6R=I;7-P875T:"==(#T@87)R87DH"B`@("`@("`@
M)V-O;'5M;B<@/3X@7R@B3W1H97(@26YF;W)M871I;VXB*2P*("`@("`@("`G
M;&%B96PG(#T^(%\H(D%L=&5R;F%T92!)35-0($QO9VEN(BDL"B`@("`@("`@
M)V1E<V,G(#T^(%\H(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(BDL"B`@("`@("`@)VUE;6)E<G,G(#T^(&%R
M<F%Y*"=I;7-P7V%U=&A?=7-E<B<L("=I;7-P7V%U=&A?<&%S<R<I"B`@("`I
M.PI]"@HO+R!$971E<FUI;F4@9G5N8W1I;VYA;&ET>2!O9B!R:6-H=&5X="!E
M9&ET;W(*)'!R969'<F]U<'-;)W)I8VAT97AT)UT@/2!A<G)A>2@*("`@("=C
M;VQU;6XG(#T^(%\H(D]T:&5R($EN9F]R;6%T:6]N(BDL"B`@("`G;&%B96PG
M(#T^(%\H(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(I+`H@("`@)V1E<V,G
M(#T^(%\H(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BXB*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G8V]N=&5X
M=&UE;G4G+"`G=&%B;&5O<&5R871I;VYS)RP@)VQI<W1T>7!E)RDL"BD["FEF
M("@D<F5G:7-T<GDM/FAA<TEN=&5R9F%C92@G:6UA9V5S)RDI('L*("`@("1P
M<F5F1W)O=7!S6R=R:6-H=&5X="==6R=M96UB97)S)UU;72`]("=A;G-E;&EM
M86=E)SL*?0H*+R\@4&5R<V]N86P@26YF;W)M871I;VX@<')E9F5R96YC97,*
M"B\O(&1E9F%U;'0@:61E;G1I='D*+R\@4V5T(&QO8VME9"!T;R!T<G5E(&EF
M('EO=2!D;VXG="!W86YT('1H92!U<V5R<R!T;R!H879E(&UU;'1I<&QE(&ED
M96YT:71I97,N"B1?<')E9G-;)V1E9F%U;'1?:61E;G1I='DG72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@
M("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@
M("=E;G5M)R`]/B`H:7-S970H)&ED96YT:71Y*2`F)B!I<U]O8FIE8W0H)&ED
M96YT:71Y*2D@/R`D:61E;G1I='DM/F=E=$%L;"@G:60G*2`Z(&%R<F%Y*"DL
M"B`@("`G9&5S8R<@/3X@7R@B66]U<B!D969A=6QT(&ED96YT:71Y.B(I"BD[
M"@HO+R!I9&5N=&ET:65S(&%R<F%Y"B\O($1O;B=T(&-H86YG92!A;GET:&EN
M9R!H97)E+@HD7W!R969S6R=I9&5N=&ET:65S)UT@/2!A<G)A>2@*("`@("=V
M86QU92<@/3X@)V$Z,#I[?2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@
M("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI
M.PH*+R\@:61E;G1I='D@<V5L96-T:6]N('=I9&=E=`HD7W!R969S6R=I9&5N
M=&ET>7-E;&5C="==(#T@87)R87DH"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@
M("`@)W1Y<&4G(#T^("=S<&5C:6%L)PHI.PH*+R\@9&5L971E(&)U='1O;@HD
M7W!R969S6R=D96QE=&5I9&5N=&ET>2==(#T@87)R87DH"B`@("`G='EP92<@
M/3X@)W-P96-I86PG+`H@("`@)W-H87)E9"<@/3X@=')U90HI.PH*+R\@:61E
M;G1I='D@;F%M90HO+R!)9B!Y;W4@;&]C:R!T:&ES('!R969E<F5N8V4L('EO
M=2!M=7-T('-P96-I9GD@82!V86QU92!O<B!A(&AO;VL@9F]R(&ET(&EN"B\O
M(&AO<F1E+V-O;F9I9R]H;V]K<RYP:'`N"B1?<')E9G-;)VED)UT@/2!A<G)A
M>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)W1E>'0G+`H@
M("`@)V1E<V,G(#T^(%\H(DED96YT:71Y)W,@;F%M93HB*0HI.PH*+R\@=7-E
M<B!F=6QL(&YA;64@9F]R($9R;VTZ(&QI;F4*+R\@268@>6]U(&QO8VL@=&AI
M<R!P<F5F97)E;F-E+"!Y;W4@;75S="!S<&5C:69Y(&$@=F%L=64@;W(@82!H
M;V]K(&9O<B!I="!I;@HO+R!H;W)D92]C;VYF:6<O:&]O:W,N<&AP+@HD7W!R
M969S6R=F=6QL;F%M92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@
M("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=D97-C)R`]/B!?*")9;W5R(&9U
M;&P@;F%M93HB*0HI.PH*+R\@=7-E<B!P<F5F97)R960@96UA:6P@861D<F5S
M<R!F;W(@1G)O;3H@;&EN90HO+R!)9B!Y;W4@;&]C:R!T:&ES('!R969E<F5N
M8V4L('EO=2!M=7-T('-P96-I9GD@82!V86QU92!O<B!A(&AO;VL@9F]R(&ET
M(&EN"B\O(&AO<F1E+V-O;F9I9R]H;V]K<RYP:'`N"B1?<')E9G-;)V9R;VU?
M861D<B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME
M9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G
M(#T^("=T97AT)RP*("`@("=D97-C)R`]/B`@7R@B66]U<B!&<F]M.B!A9&1R
M97-S.B(I"BD["@HO+R!U<V5R('-E8W5R:71Y('%U97-T:6]N"B1?<')E9G-;
M)W-E8W5R:71Y7W%U97-T:6]N)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^(%\H(D5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(I"BD["@HO+R!U<V5R
M('-E8W5R:71Y(&%N<W=E<@HD7W!R969S6R=S96-U<FET>5]A;G-W97(G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X
M="<L"B`@("`G9&5S8R<@/3X@7R@B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(I"BD["@HO+R!U<V5R(&%L
M=&5R;F%T92!E;6%I;`HD7W!R969S6R=A;'1E<FYA=&5?96UA:6PG72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E
M+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X="<L
M"B`@("`G9&5S8R<@/3X@7R@B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@
M=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(BD**3L*
M"B\O('5S97(@;&%N9W5A9V4*)%]P<F5F<ULG;&%N9W5A9V4G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@
M("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G<V5L96-T)RP*
M("`@("=E<V-A<&5D)R`]/B!T<G5E+`H@("`@)V1E<V,G(#T^(%\H(E-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB*0HI.PH*+R\@=7-E<B!T:6UE
M('IO;F4*)%]P<F5F<ULG=&EM97IO;F4G72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@=')U92P*("`@("=T>7!E)R`]/B`G<V5L96-T)RP*("`@("=D97-C)R`]
M/B!?*")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(I"BD["@HO+R!T:6UE(&9O
M<FUA=`HD7W!R969S6R=T=V5N='E&;W5R)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@9F%L<V4L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D
M97-C)R`]/B!?*")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(BD**3L*"B\O(&1A
M=&4@9F]R;6%T"B1?<')E9G-;)V1A=&5?9F]R;6%T)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@)R5X)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G
M96YU;2<@/3X@87)R87DH"B`@("`@("`@)R5X)R`]/B!S=')F=&EM92@G)7@G
M*2P*("`@("`@("`G)5DM)6TM)60G(#T^('-T<F9T:6UE*"<E62TE;2TE9"<I
M+`H@("`@("`@("<E9"\E;2\E62<@/3X@<W1R9G1I;64H)R5D+R5M+R59)RDL
M"B`@("`@("`@)R5!("5"("5D+"`E62<@/3X@<W1R9G1I;64H)R5!("5"("5D
M+"`E62<I+`H@("`@("`@("<E02P@)60N("5"("59)R`]/B!S=')F=&EM92@G
M)4$L("5D+B`E0B`E62<I+`H@("`@("`@("<E02P@)60@)4(@)5DG(#T^('-T
M<F9T:6UE*"<E02P@)60@)4(@)5DG*2P*("`@("`@("`G)6$L("5B("5E+"`E
M62<@/3X@<W1R9G1I;64H)R5A+"`E8B`E92P@)5DG*2P*("`@("`@("`G)6$L
M("5B("5E+"`E>2<@/3X@<W1R9G1I;64H)R5A+"`E8B`E92P@)7DG*2P*("`@
M("`@("`G)6$L("5B("5E)R`]/B!S=')F=&EM92@G)6$L("5B("5E)RDL"B`@
M("`@("`@)R5A+"`E92`E8B`E62<@/3X@<W1R9G1I;64H)R5A+"`E92`E8B`E
M62<I+`H@("`@("`@("<E82P@)64@)6(@)7DG(#T^('-T<F9T:6UE*"<E82P@
M)64@)6(@)7DG*2P*("`@("`@("`G)6$@)60@)6(@)5DG(#T^('-T<F9T:6UE
M("@G)6$@)60@)6(@)5DG*2P*("`@("`@("`G)6$@)7@G(#T^('-T<F9T:6UE
M("@G)6$@)7@G*2P*("`@("`@("`G)6$@)5DM)6TM)60G(#T^('-T<F9T:6UE
M("@G)6$@)5DM)6TM)60G*2P*("`@("`@("`G)64@)6(@)5DG(#T^('-T<F9T
M:6UE*"<E92`E8B`E62<I+`H@("`@("`@("<E92X@)6(@)5DG(#T^('-T<F9T
M:6UE*"<E92X@)6(@)5DG*2P*("`@("`@("`G)64N("5M("59)R`]/B!S=')F
M=&EM92@G)64@)6T@)5DG*2P*("`@("`@("`G)64N("5M+B<@/3X@<W1R9G1I
M;64H)R5E+B`E;2XG*2P*("`@("`@("`G)64N("5")R`]/B!S=')F=&EM92@G
M)64N("5")RDL"B`@("`@("`@)R5E+B`E0B`E62<@/3X@<W1R9G1I;64H)R5E
M+B`E0B`E62<I+`H@("`@("`@("<E92X@)4(@)7DG(#T^('-T<F9T:6UE*"<E
M92X@)4(@)7DG*2P*("`@("`@("`G)4(@)64L("59)R`]/B!S=')F=&EM92@G
M)4(@)64L("59)RDL"B`@("`I+`H@("`@)V1E<V,G(#T^(%\H(D-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SHB*2D["@HO+R!522!T:&5M90HD7W!R969S
M6R=T:&5M92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=B;'5E=VAI=&4G
M+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E
M+`H@("`@)W1Y<&4G(#T^("=S96QE8W0G+`H@("`@)V1E<V,G(#T^(%\H(E-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB*0HI.PH*+R\@8V%T96=O<FEE<PHD
M7W!R969S6R=C871E9V]R:65S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@8V%T96=O<GD@
M8V]L;W)S"B1?<')E9G-;)V-A=&5G;W)Y7V-O;&]R<R==(#T@87)R87DH"B`@
M("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G
M<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*
M"B\O(%5)(&9O<B!C871E9V]R>2!M86YA9V5M96YT+@HD7W!R969S6R=C871E
M9V]R>6UA;F%G96UE;G0G72`](&%R<F%Y*`H@("`@)W1Y<&4G(#T^("=S<&5C
M:6%L)PHI.PH*)%]P<F5F<ULG<W5M;6%R>5]R969R97-H7W1I;64G72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B`S,#`L"B`@("`G;&]C:V5D)R`]/B!F86QS
M92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=E;G5M
M)RP*("`@("=E;G5M)R`]/B!A<G)A>2@P(#T^(%\H(DYE=F5R(BDL"B`@("`@
M("`@("`@("`@("`@("`@,S`@/3X@7R@B179E<GD@,S`@<V5C;VYD<R(I+`H@
M("`@("`@("`@("`@("`@("`@(#8P(#T^(%\H(D5V97)Y(&UI;G5T92(I+`H@
M("`@("`@("`@("`@("`@("`@(#,P,"`]/B!?*")%=F5R>2`U(&UI;G5T97,B
M*2P*("`@("`@("`@("`@("`@("`@("`Y,#`@/3X@7R@B179E<GD@,34@;6EN
M=71E<R(I+`H@("`@("`@("`@("`@("`@("`@(#$X,#`@/3X@7R@B179E<GD@
M:&%L9B!H;W5R(BDI+`H@("`@)V1E<V,G(#T^(%\H(E)E9G)E<V@@4&]R=&%L
M(%9I97<Z(BD**3L*"B1?<')E9G-;)W-H;W=?<VED96)A<B==(#T@87)R87DH
M"B`@("`G=F%L=64G(#T^('1R=64L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H96-K8F]X
M)RP*("`@("=D97-C)R`]/B!S<')I;G1F*%\H(E-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA
M;64G+"`G:&]R9&4G*2D**3L*"B1?<')E9G-;)W-I9&5B87)?=VED=&@G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`Q-S4L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=N
M=6UB97(G+`H@("`@)V1E<V,G(#T^('-P<FEN=&8H7R@B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G+"`G
M:&]R9&4G*2D**3L*"B1?<')E9G-;)VUO>E]S:61E8F%R)UT@/2!A<G)A>2@*
M("`@("=T>7!E)R`]/B`G;&EN:R<L"B`@("`G>'5R;"<@/3X@<W!R:6YT9B@G
M:F%V87-C<FEP=#II9B`H=VEN9&]W+G-I9&5B87(@)B8@=VEN9&]W+G-I9&5B
M87(N861D4&%N96PI('=I;F1O=RYS:61E8F%R+F%D9%!A;F5L*%PG)7-<)RP@
M7"<E<UPG+"!<)R5S7"<I.R!E;'-E(&%L97)T*%PG)7-<)RD[)RP*("`@("`@
M("`@("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA
M;64G+"`G:&]R9&4G*2P*("`@("`@("`@("`@("`@("`@("`@(%5T:6PZ.F%D
M9%!A<F%M971E<BA(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG
M970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP)RP@=')U92P@+3$I+"`G;6]Z8F%R)RP@)S$G*2P*("`@("`@
M("`@("`@("`@("`@("`@($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]P<F5F<RYP:'`G+"!T
M<G5E+"`M,2DL"B`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*%\H
M(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN(BDI*2P*("`@("=D97-C)R`]/B!S<')I
M;G1F*%\H(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(I
M+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RP@)VAO<F1E)RDI
M"BD["@HD7W!R969S6R=M96YU7W9I97<G72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`G8F]T:"<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG
M(#T^(&%R<F%Y*"=T97AT)R`]/B!?*")497AT($]N;'DB*2P*("`@("`@("`@
M("`@("`@("`@("`G:6-O;B<@/3X@7R@B26-O;G,@3VYL>2(I+`H@("`@("`@
M("`@("`@("`@("`@("=B;W1H)R`]/B!?*"))8V]N<R!W:71H('1E>'0B*2DL
M"B`@("`G9&5S8R<@/3X@7R@B365N=2!M;V1E.B(I"BD["@HD7W!R969S6R=M
M96YU7W)E9G)E<VA?=&EM92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#,P
M,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U
M92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R87DH
M,"`]/B!?*").979E<B(I+`H@("`@("`@("`@("`@("`@("`@(#,P(#T^(%\H
M(D5V97)Y(#,P('-E8V]N9',B*2P*("`@("`@("`@("`@("`@("`@("`V,"`]
M/B!?*")%=F5R>2!M:6YU=&4B*2P*("`@("`@("`@("`@("`@("`@("`Q,C`@
M/3X@7R@B179E<GD@,B!M:6YU=&5S(BDL"B`@("`@("`@("`@("`@("`@("`@
M,S`P(#T^(%\H(D5V97)Y(#4@;6EN=71E<R(I*2P*("`@("=D97-C)R`]/B!?
M*")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB*0HI.PH*"B\O($QO
M9VEN+TUA:6YT96YA;F-E(%1A<VMS('!R969E<F5N8V5S"@HO+R!4;R!D:7-A
M8FQE(&UA:6YT96YA;F-E(&5N=&ER96QY+"!S970@)W9A;'5E)R`](&9A;'-E
M(&%N9`HO+R`G;&]C:V5D)R`]('1R=64@9F]R(&%L;"!O9B!T:&5S92X@5&\@
M:G5S="!T=7)N(&ET(&]F9B!B>2!D969A=6QT+`HO+R!S970@)W9A;'5E)R!F
M86QS92!F;W(@9&]?;6%I;G1E;F%N8V4N"B\O('!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\*)%]P<F5F<ULG9&]?;6%I;G1E;F%N8V4G72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L
M<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C
M:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/R(I+`H@("`@)VAE;'`G(#T^("=P<F5F<RUD
M;U]M86EN=&5N86YC92<I.PH*+R\@;&%S="!T:6UE(&UA:6YT96YA;F-E('=A
M<R!R=6XN"B\O('9A;'5E(&ES(&$@54Y)6"!T:6UE<W1A;7`@;V8@=&AE(&QA
M<W0@=&EM92!M86EN=&5N86YC92!R86X@9F]R('1H92!U<V5R+@HD7W!R969S
M6R=L87-T7VUA:6YT96YA;F-E)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U
M92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!C;VYF:7)M('=H
M96X@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\@268@9F%L<V4L('1H
M97D@=VEL;`HO+R!B92!P97)F;W)M960@=VET:"!N;R!I;G!U="!F<F]M+V-H
M96-K('=I=&@@=&AE('5S97(N"B1?<')E9G-;)V-O;F9I<FU?;6%I;G1E;F%N
M8V4G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME
M9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G
M(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M(BDL"B`@("`G:&5L<"<@/3X@)W!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4G
M*3L*"B\O($5N9"!,;V=I;B]-86EN=&5N86YC92!P<F5F97)E;F-E<PH*"B\O
M('=H870@87!P;&EC871I;VX@<VAO=6QD('=E(&=O('1O(&%F=&5R(&QO9VEN
M/PHD7W!R969S6R=I;FET:6%L7V%P<&QI8V%T:6]N)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@)VAO<F1E)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@
M("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G<V5L96-T)RP*
M("`@("=D97-C)R`]/B!S<')I;G1F*%\H(E=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(BDL("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG970H)VYA;64G*2D**3L*"B\O('-H;W5L9"!W92!C<F5A=&4@
M86-C97-S(&ME>7,_"B1?<')E9G-;)W=I9&=E=%]A8V-E<W-K97DG72`](&%R
M<F%Y*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L
M<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C
M:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=6QD(&%C8V5S<R!K97ES(&)E
M(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(BD**3L*"B\O('-H;W5L9"!W92!N
M;W0@=7-E('1H92!A;'!H82!I;6%G92!L;V%D97(@9F]R($E%/PHD7W!R969S
M6R=A;'!H85]F:6QT97(G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!F86QS
M92P*("`@("=L;V-K960G(#T^('1R=64L"B`@("`G<VAA<F5D)R`]/B!T<G5E
M+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B
M268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP
M;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(I"BD["@HO+R!T:&4@;&%Y;W5T(&]F
M('1H92!P;W)T86P@<&%G92X*)%]P<F5F<ULG<&]R=&%L7VQA>6]U="==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^("=A.C`Z>WTG+`H@("`@)VQO8VME9"<@
M/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]
M/B`G:6UP;&EC:70G"BD["@HO+R!T:&4@<F5M;W1E('-E<G9E<G,N"B1?<')E
M9G-;)W)E;6]T95]S=6UM87)I97,G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]
M/B`G83HP.GM])RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E
M9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@
M;&%S="!L;V=I;B!T:6UE(&]F('5S97(*+R\@=F%L=64@:7,@82!S97)I86QI
M>F5D(&%R<F%Y(&]F('1H92!53DE8('1I;65S=&%M<"!O9B!T:&4@;&%S=`HO
M+R!L;V=I;BP@86YD('1H92!H;W-T('1H870@=&AE(&QA<W0@;&]G:6X@=V%S
M(&9R;VTN"B1?<')E9G-;)VQA<W1?;&]G:6XG72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`G83HP.GM])RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD[
M"@HO+R!S:&]W('1H92!L87-T(&QO9VEN('1I;64@;V8@=7-E<@HD7W!R969S
M6R=S:&]W7VQA<W1?;&]G:6XG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!T
M<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T
M<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@
M7R@B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(I"BD[
M"@II9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)VEM<W`G75LG96YA8FQE
M9"==*2D@>PH@("`@)%]P<F5F<ULG:6US<%]A=71H7W5S97(G72`](&%R<F%Y
M*`H@("`@("`@("=V86QU92<@/3X@)R<L"B`@("`@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`@("`@)W1Y
M<&4G(#T^("=T97AT)RP*("`@("`@("`G9&5S8R<@/3X@7R@B06QT97)N871E
M($E-4U`@57-E<FYA;64B*0H@("`@*3L*"B`@("`D7W!R969S6R=I;7-P7V%U
M=&A?<&%S<R==(#T@87)R87DH"B`@("`@("`@)W9A;'5E)R`]/B`G)RP*("`@
M("`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("`@("`G<VAA<F5D)R`]/B!F
M86QS92P*("`@("`@("`G='EP92<@/3X@)W!A<W-W;W)D)RP*("`@("`@("`G
M9&5S8R<@/3X@7R@B06QT97)N871E($E-4U`@4&%S<W=O<F0B*0H@("`@*3L*
M?0H*+R\@4FEC:"!497AT($5D:71O<B!P<F5F97)E;F-E<RX*"B1?<')E9G-;
M)V-O;G1E>'1M96YU)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@=')U92P*
M("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*
M("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(D5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(BD**3L*"B1?<')E9G-;
M)W1A8FQE;W!E<F%T:6]N<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(&9A
M;'-E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T
M<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@
M7R@B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(I"BD["@HD7W!R
M969S6R=L:7-T='EP92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^('1R=64L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L
M"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(I"BD["@II9B`H
M)')E9VES=')Y+3YH87-);G1E<F9A8V4H)VEM86=E<R<I*2!["B`@("`D7W!R
M969S6R=A;G-E;&EM86=E)UT@/2!A<G)A>2@*("`@("`@("`G=F%L=64G(#T^
M('1R=64L"B`@("`@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`@("`@)W-H
M87)E9"<@/3X@=')U92P*("`@("`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*
M("`@("`@("`G9&5S8R<@/3X@7R@B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G
M97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B*0H@("`@*3L*?0H*
M+R\@16YD(%)I8V@@5&5X="!%9&ET;W(@<')E9F5R96YC97,N"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O<F5G:7-T
M<GDN<&AP````````````````````````````````````````````````````
M`````````````````#`Q,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V
M-S`W`#$P-3$U-#,Q,#<P`#`R,#8U,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@<F5G:7-T<GDN<&AP
M("TM($AO<F1E(&%P<&QI8V%T:6]N(')E9VES=')Y+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+V-O;F9I9R]R96=I<W1R>2YP:'`N9&ES="QV(#$N,C4U+C(N,3<@
M,C`P-B\P-R\R,2`Q-3HT.3HT-B!J86X@17AP("0*("H*("H@5&AI<R!C;VYF
M:6=U<F%T:6]N(&9I;&4@:7,@=7-E9"!B>2!(;W)D92!T;R!D971E<FUI;F4@
M=VAI8V@@2&]R9&4*("H@87!P;&EC871I;VYS(&%R92!I;G-T86QL960@86YD
M('=H97)E+"!A<R!W96QL(&%S(&AO=R!T:&5Y(&EN=&5R86-T+@H@*@H@*B!!
M<'!L:6-A=&EO;B!R96=I<W1R>0H@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+0H@
M*B!4:&4@9F]L;&]W:6YG('-E='1I;F=S(')E9VES=&5R(&EN<W1A;&QE9"!(
M;W)D92!A<'!L:6-A=&EO;G,N"B`J($)Y(&1E9F%U;'0L($AO<F1E(&%S<W5M
M97,@=&AA="!T:&4@87!P;&EC871I;VX@9&ER96-T;W)I97,@;&EV90H@*B!I
M;G-I9&4@=&AE(&AO<F1E(&1I<F5C=&]R>2X*("H*("H@071T<FEB=71E("`@
M("!4>7!E("`@("!$97-C<FEP=&EO;@H@*B`M+2TM+2TM+2T@("`@("TM+2T@
M("`@("TM+2TM+2TM+2TM"B`J(&9I;&5R;V]T("`@("`@<W1R:6YG("`@5&AE
M(&)A<V4@9FEL97-Y<W1E;2!P871H(&9O<B!T:&4@;6]D=6QE)W,@9FEL97,N
M"B`J('=E8G)O;W0@("`@("`@<W1R:6YG("`@5&AE(&)A<V4@55))(&9O<B!T
M:&4@;6]D=6QE+@H@*B!J<W5R:2`@("`@("`@('-T<FEN9R`@(%1H92!B87-E
M(%5222!F;W(@<W1A=&EC(&IA=F%S8W)I<'0@9FEL97,N"B`J(&IS9G,@("`@
M("`@("`@<W1R:6YG("`@5&AE(&)A<V4@9FEL97-Y<W1E;2!P871H(&9O<B!S
M=&%T:6,@:F%V87-C<FEP="!F:6QE<RX*("H@=&AE;65S=7)I("`@("!S=')I
M;F<@("!4:&4@8F%S92!54DD@9F]R('1H92!T:&5M97,N(%1H:7,@8V%N(&)E
M('5S960@=&\*("H@("`@("`@("`@("`@("`@("`@("`@("!S97)V92!A;&P@
M:6-O;G,@86YD('-T>6QE('-H965T<R!F<F]M(&$@<V5P87)A=&4*("H@("`@
M("`@("`@("`@("`@("`@("`@("!S97)V97(N"B`J('1H96UE<V9S("`@("`@
M<W1R:6YG("`@5&AE(&)A<V4@9FEL92!S>7-T96T@9&ER96-T;W)Y(&9O<B!T
M:&4@=&AE;65S+@H@*B!I8V]N("`@("`@("`@('-T<FEN9R`@(%1H92!54DD@
M9F]R(&%N(&EC;VX@=&\@<VAO=R!I;B!M96YU<R!F;W(@=&AE(&UO9'5L92X*
M("H@("`@("`@("`@("`@("`@("`@("`@("!3971T:6YG('1H:7,@=VEL;"!O
M=F5R<FED92!T:&4@9&5F875L="!T:&5M92UB87-E9`H@*B`@("`@("`@("`@
M("`@("`@("`@("`@(&QO9VEC(&EN('1H92!C;V1E+@H@*B!N86UE("`@("`@
M("`@('-T<FEN9R`@(%1H92!N86UE('5S960@:6X@;65N=7,@86YD(&1E<V-R
M:7!T:6]N<R!F;W(@82!M;V1U;&4*("H@<W1A='5S("`@("`@("!S=')I;F<@
M("`G:6YA8W1I=F4G+"`G:&ED9&5N)RP@)VYO=&]O;&)A<B<L("=H96%D:6YG
M)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`G8FQO8VLG+"`G861M:6XG
M+"!O<B`G86-T:79E)RX*("H@<')O=FED97,@("`@("!S=')I;F<@("!397)V
M:6-E('1Y<&5S('1H92!M;V1U;&4@<')O=FED97,N"B`J(&EN:71I86Q?<&%G
M92`@<W1R:6YG("`@5&AE(&EN:71I86P@*&1E9F%U;'0I('!A9V4@*&9I;&5N
M86UE*2!F;W(@=&AE(&UO9'5L92X*("H@=&5M<&QA=&5S("`@("!S=')I;F<@
M("!4:&4@9FEL97-Y<W1E;2!P871H('1O('1H92!T96UP;&%T97,@9&ER96-T
M;W)Y+@H@*B!M96YU7W!A<F5N="`@('-T<FEN9R`@(%1H92!N86UE(&]F('1H
M92`G:&5A9&EN9R<@9W)O=7`@=&AA="!T:&ES(&%P<"!S:&]U;&0*("H@("`@
M("`@("`@("`@("`@("`@("`@("!S:&]W('5P('5N9&5R+@H@*B!T87)G970@
M("`@("`@('-T<FEN9R`@(%1H92`H;W!T:6]N86PI('1A<F=E="!F<F%M92!F
M;W(@=&AE(&QI;FLN"B`J('5R;"`@("`@("`@("`@<W1R:6YG("`@5&AE("AO
M<'1I;VYA;"D@55),(&]F("=H96%D:6YG)R!E;G1R:65S+@H@*B\*"B\O(%=E
M('1R>2!T;R!A=71O;6%T:6-A;&QY(&1E=&5R;6EN92!T:&4@<')O<&5R('=E
M8G)O;W0@9F]R($AO<F1E"B\O(&AE<F4N(%1H:7,@<W1I;&P@87-S=6UE<R!T
M:&%T(&%P<&QI8V%T:6]N<R!L:79E('5N9&5R(&AO<F1E+RX@268*+R\@=&AI
M<R!R97-U;'1S(&EN(&EN8V]R<F5C="!R97-U;'1S(&9O<B!Y;W4L('-I;7!L
M>2!C:&%N9V4@=&AE('1W;PHO+R!U<V5S(&]F('1H92`D=V5B<F]O="!V87)I
M86)L92!I;B!T:&4@)VAO<F1E)R!S=&%N>F$@8F5L;W<N"B\O"B\O($YO=&4@
M9F]R(%=I;F1O=W,@=7-E<G,Z('1H92!B96QO=R!A<W-U;65S('1H870@>6]U
M<B!02%!?4T5,1@HO+R!V87)I86)L92!U<V5S(&9O<G=A<F0@<VQA<VAE<RX@
M268@:70@9&]E<R!N;W0L('EO=2=L;"!H879E('1O('1W96%K"B\O('1H:7,N
M"FEF("AI<W-E="@D7U-%4E9%4ELG4$A07U-%3$8G72DI('L*("`@("1W96)R
M;V]T(#T@<')E9U]S<&QI="@G.R\[)RP@)%]315)615);)U!(4%]314Q&)UTL
M(#(L(%!214=?4U!,251?3D]?14U05%DI.PH@("`@)'=E8G)O;W0@/2!S=')S
M='(H9&ER;F%M92A?7T9)3$5?7RDL($1)4D5#5$]265]315!!4D%43U(@+B!A
M<G)A>5]S:&EF="@D=V5B<F]O="DI.PH@("`@:68@*"1W96)R;V]T("$]/2!F
M86QS92D@>PH@("`@("`@("1W96)R;V]T(#T@<')E9U]R97!L86-E*&%R<F%Y
M*"<O7%Q<7"\G+"`G.R]C;VYF:6<D.R<I+"!A<G)A>2@G+R<L("<G*2P@)'=E
M8G)O;W0I.PH@("`@?2!E;'-E:68@*"1W96)R;V]T(#T]/2!F86QS92D@>PH@
M("`@("`@("1W96)R;V]T(#T@)R<["B`@("!](&5L<V4@>PH@("`@("`@("1W
M96)R;V]T(#T@)R]H;W)D92<["B`@("!]"GT@96QS92!["B`@("`D=V5B<F]O
M="`]("<O:&]R9&4G.PI]"@HD=&AI<RT^87!P;&EC871I;VYS6R=H;W)D92==
M(#T@87)R87DH"B`@("`G9FEL97)O;W0G(#T^("<O=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4G+`H@("`@)W=E8G)O;W0G(#T^("1W96)R;V]T+`H@("`@)VEN
M:71I86Q?<&%G92<@/3X@)VQO9VEN+G!H<"<L"B`@("`G;F%M92<@/3X@7R@B
M2&]R9&4B*2P*("`@("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@)W1E;7!L
M871E<R<@/3X@)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,G
M+`H@("`@)W!R;W9I9&5S)R`]/B`G:&]R9&4G"BD["@HO*B`*("H@2&%C:R!T
M;R!M86ME(')E9VES=&5R:6YG(&]F('!A8VMA9V5S(&5A<WD@=VET:&]U="!E
M9&ET:6YG"B`J(&-O;F9I9W5R871I;VX@9FEL97,L('-T;VQE;B!F<F]M($1E
M8FEA;@H@*B\*"FEF("@D9"`]($!O<&5N9&ER*"<O=7-R+VQO8V%L+W!S82]E
M=&,O<'-A+6AO<F1E+VAO<F1E+W)E9VES=')Y+F0G*2D@>PH@("`@=VAI;&4@
M*"1F(#T@<F5A9&1I<B@D9"DI('L@"B`@("`@("`@:68@*&5R96<H(BYP:'`D
M(BP@)&8I*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G+R]U<W(O;&]C
M86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O<F5G:7-T<GDN9"\G("X@)&8[
M"B`@("`@("`@?0H@("`@?0H@("`@8VQO<V5D:7(H)&0I.PI]"@``````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+VAO;VMS
M+G!H<```````````````````````````````````````````````````````
M```````````````````P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R
M,C,R,``Q,#4Q-30S,3`W,``P,C`Q,3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E($AO;VMS
M(&-O;F9I9W5R871I;VX@9FEL92X*("H*("H@5$A%($A/3TM3(%!23U9)1$5$
M($E.(%1(25,@1DE,12!!4D4@15A!35!,15,@3TY,62X@($1/($Y/5"!%3D%"
M3$4@5$A%30H@*B!"3$E.1$Q9($E&(%E/52!$3R!.3U0@2TY/5R!72$%4(%E/
M52!!4D4@1$])3D<N("!93U4@2$%612!43R!#55-43TU)6D4@5$A%30H@*B!4
M3R!-051#2"!93U52(%-014-)1DE#($Y%1413($%.1"!365-414T@14Y625)/
M3DU%3E0N"B`J"B`J(%1H:7,@9FEL92!I<R!W:&5R92!Y;W4@9&5F:6YE(&%N
M>2!H;V]K<RP@9F]R('!R969E<F5N8V5S(&]R(&=E;F5R86P@2&]R9&4*("H@
M=7-E+"!T:&%T('EO=7(@:6YS=&%L;&%T:6]N('5S97,N(%1H92!F=6YC=&EO
M;G,@:6X@=&AI<R!F:6QE(&-A;B!V87-T;'D*("H@8VAA;F=E(&AO=R!Y;W5R
M(&EN<W1A;&QA=&EO;B!B96AA=F5S+"!S;R!M86ME('-U<F4@=&\@=&5S="!O
M=70@86YY(&-H86YG97,*("H@:&5R92!B969O<F4@9&]I;F<@=&AE;2!I;B!A
M('!R;V1U8W1I;VX@96YV:7)O;FUE;G0N"B`J"B`J($AO;VL@9G5N8W1I;VX@
M;F%M97,@87)E(&%U=&]M871I8V%L;'D@9&5T97)M:6YE9"X@5&AE(&9O<FUA
M="!O9B!T:&4@;F%M90H@*B!I<SH*("H*("H@7SQT>7!E(&]F(&AO;VL^7VAO
M;VM?/&YA;64@;V8@:&]O:SXN"B`J"B`J(%1Y<&5S(&]F(&AO;VMS('1H870@
M87)E(&1E9FEN960@:6X@=&AI<R!F:6QE(&%R92`G<')E9G,G("AH;V]K<R!T
M;R!S970@=&AE"B`J('9A;'5E(&]F('!R969E<F5N8V5S*2P@)VAO<F1E)R`H
M:&]O:W,@9F]R('1H92!(;W)D92!&<F%M97=O<FL@<V-R:7!T<RD@86YD"B`J
M("=A<'`G("AW:&5R92!A<'`@:7,@86YY($AO<F1E(&%P<&QI8V%T:6]N(&YA
M;64L(&QI:V4@)VEM<"<I(&AO;VMS('1H870@87)E"B`J(&%P<&QI8V%T:6]N
M('-P96-I9FEC+@H@*@H@*B!3;RP@82!H;V]K('1O('-E="!T:&4@<')E9F5R
M96YC92`G=&AE;64G('=O=6QD(&)E(&YA;65D"B`J(")?<')E9G-?:&]O:U]T
M:&5M92(N"B`J"B`J($Y/5$4@,3H@2&%V:6YG(&$@:&]O:R!F=6YC=&EO;B!I
M;B!T:&ES(&9I;&4@9&]E<R!.3U0@;65A;B!T:&%T('1H92!H;V]K"B`J('=I
M;&P@875T;VUA=&EC86QL>2!B92!U<V5D+B!93U4@35535"!E;F%B;&4@=&AE
M(&AO;VLN($9O<B!P<F5F97)E;F-E<RP@<V5T"B`J("=H;V]K)R`]/B!T<G5E
M(&EN('1H870@<')E9F5R96YC97,@871T<FEB=71E<SL@9F]R(&]T:&5R(&AO
M;VMS+"!T:&5R92!W:6QL"B`J(&)E(&$@8V]N9FEG=7)A=&EO;B!O<'1I;VX@
M:6X@96%C:"!A<'!L:6-A=&EO;B=S(&-O;F8N<&AP(&9I;&4@<W5C:"!A<PH@
M*B`D8V]N9ELG:&]O:W,G75LG:&]O:VYA;64G72!W:&EC:"!M=7-T(&)E('-E
M="!T;R!T<G5E+@H@*@H@*B!.3U1%(#(Z(%!R969E<F5N8V5S(&AO;VMS(&%R
M92!/3DQ9(&5X96-U=&5D(&]N(&QO9VEN+B!0<F5F97)E;F-E<R!A<F4*("H@
M8V%C:&5D(&1U<FEN9R!A('5S97)S('-E<W-I;VX@86YD+"!T;R!A=F]I9"!U
M;FYE8V5S<V%R>2!O=F5R:&5A9"!E=F5R>2!T:6UE"B`J(&$@<')E9F5R96YC
M92!I<R!A8V-E<W-E9"P@=&AE(')E<W5L=',@;V8@:&]O:W,@87)E(&-A8VAE
M9"!A<R!W96QL+B!4:&ES"B`J(&QE861S('1O("XN+@H@*@H@*B!.3U1%(#,Z
M($%N>2!P<F5F97)E;F-E('1H870@:7,@3D]4($Q/0TM%1"P@=&AA="!I<R!S
M970@8GD@82!H;V]K+"!724Q,($)%"B`J(%-!5D5$(%=)5$@@5$A!5"!604Q5
M12X@5&AI<R!M96%N<R!S979E<F%L('1H:6YG<SH*("H@,2D@57-E<G,@=VEL
M;"!G970@=&AE(')E<W5L=',@;V8@=&AE(&AO;VL@<V5T(&9O<B!T:&5M(&EN
M('1H96ER"B`J("`@('!R969E<F5N8V5S+@H@*B`R*2!">2!V:7)T=64@;V8@
M=&AI<RP@=&AE(&YE>'0@=&EM92!T:&5Y(&QO9R!I;B!A;F0@;&]A9"!T:&5I
M<@H@*B`@("!P<F5F97)E;F-E<RP@=&AE(&AO;VL@=VEL;"!.3U0@8F4@8V%L
M;&5D+"!B96-A=7-E(&EN('1H96ER(&QA<W0@<V5S<VEO;BP*("H@("`@=V4@
M<V%V960@=&AE(')E<W5L=',@;V8@=&AE(&AO;VL@9F]R('1H96TN($AO=V5V
M97(L(&EF('1H92!P<F5F97)E;F-E(&ES"B`J("`@(&QO8VME9"P@=&AE(')E
M<W5L="!O9B!T:&4@:&]O:R!W:6QL(&YE=F5R(&)E('-A=F5D+@H@*@H@*B`D
M2&]R9&4Z(&AO<F1E+V-O;F9I9R]H;V]K<RYP:'`N9&ES="QV(#$N-S,N-BXQ
M,R`R,#`V+S`U+S(S(#`R.C$S.C0R('-E;'-K>2!%>'`@)`H@*B\*"B\O($5X
M86UP;&4@=&AE;64@:&]O:R!F=6YC=&EO;BX@5&AI<R!S:&]W<R!H;W<@>6]U
M(&-A;B!A8V-E<W,@=&AI;F=S(&QI:V4@=&AE"B\O(&-U<G)E;G1L>2!L;V=G
M960@:6X@=7-E<BP@9VQO8F%L('9A<FEA8FQE<RP@<V5R=F5R(&-O;F9I9RP@
M971C+B!)="!I<VXG="P*+R\@:&]W979E<BP@<V]M971H:6YG('EO=2!P<F]B
M86)L>2!W86YT('1O(&%C='5A;&QY('5S92!I;B!P<F]D=6-T:6]N+"!B>0HO
M+R!V:7)T=64@;V8@9&5M;VYS=')A=&EN9R!A;&P@=&AO<V4N(#HI"@HO+R!I
M9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!R969S7VAO;VM?=&AE;64G*2D@>PHO
M+R`@("`@9G5N8W1I;VX@7W!R969S7VAO;VM?=&AE;64H)'5S97)N86UE(#T@
M;G5L;"D*+R\@("`@('L*+R\@("`@("`@("!I9B`H075T:#HZ9V5T075T:"@I
M("$]("=C:'5C:R<I('L*+R\@("`@("`@("`@("`@<F5T=7)N("=M;WII;&QA
M)SL*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@9VQO8F%L("1R96=I<W1R
M>3L*+R\@("`@("`@("!S=VET8V@@*"1R96=I<W1R>2T^9V5T07!P*"DI('L*
M+R\@("`@("`@("!C87-E("=I;7`G.@HO+R`@("`@("`@("`@("!R971U<FX@
M)V)R;W=N)SL*+R\*+R\@("`@("`@("!C87-E("=T=7)B82<Z"B\O("`@("`@
M("`@("`@(')E='5R;B`G;W)A;F=E)SL*+R\*+R\@("`@("`@("!C87-E("=K
M<F]N;VQI=&@G.@HO+R`@("`@("`@("`@("!R971U<FX@)V=R965N)SL*+R\*
M+R\@("`@("`@("!D969A=6QT.@HO+R`@("`@("`@("`@("!R971U<FX@)R<[
M"B\O("`@("`@("`@?0HO+R`@("`@?0HO+R!]"@HO+R!%>&%M<&QE(&9R;VU?
M861D<B!H;V]K(&9U;F-T:6]N+B!42$E3($953D-424].($%34U5-15,@5$A!
M5"!93U4@05)%(%5324Y'"B\O($%.($Q$05`@4T525D52(&%N9"!T:&%T('EO
M=7(@+V5T8R]L9&%P+F-O;F8@;W(@=VAE<F5V97(@:70@:7,@8V]R<F5C=&QY
M('-E=`HO+R!T;R!A('9A;&ED(&AO<W0N"B\O"B\O(%EO=2!G970@<&%S<V5D
M($Y/5$A)3D<[('EO=2!A<F4@<F5S<&]N<VEB;&4@9F]R(&)R:6YG:6YG(&EN
M('1O('-C;W!E(&%N>0HO+R!I;F9O<FUA=&EO;B!Y;W4@;F5E9"X@66]U(&-A
M;B`B9VQO8F%L(B!A;GET:&EN9R!E;'-E('EO=2!N965D+B!2971U<FX@86X*
M+R\@861D<F5S<R`M(&5I=&AE<B!J=7-T('1H92!U<V5R0"!S:61E(&]R(&$@
M9G5L;"!A9&1R97-S("T@86YD(&ET('=I;&P@8F4*+R\@=7-E9"X*+R\*+R\@
M268@>6]U('=A;G0@=&\@=7-E('1H:7,@8V]D92!Y;W4@=VEL;"!N965D('1O
M('5N8V]M;65N="!I="!B96QO=RX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S
M*"=?<')E9G-?:&]O:U]F<F]M7V%D9'(G*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7W!R969S7VAO;VM?9G)O;5]A9&1R*"1N86UE(#T@;G5L;"D*+R\@("`@('L*
M+R\@("`@("`@("!I9B`H:7-?;G5L;"@D;F%M92DI('L*+R\@("`@("`@("`@
M("`@)&YA;64@/2!!=71H.CIG971!=71H*"D["B\O("`@("`@("`@?0HO+R`@
M("`@("`@(&EF("@A96UP='DH)&YA;64I*2!["B\O("`@("`@("`@("`@("1B
M87-E7V-O;G1E>'0@/2`G;SUM>6]R9R<["B\O("`@("`@("`@("`@("1S8V]P
M92`]("=S=6(G.PHO+PHO+R`@("`@("`@("`@("`O+R!9;W4@=VEL;"!P<F]B
M86)L>2!N965D('1O(')E<&QA8V4@8V0]('=I=&@@=6ED/3L@=&AI<PHO+R`@
M("`@("`@("`@("`O+R!S>6YT87@@:7,@9F]R($YE='=A<F4@-2XQ(&YL9&%P
M+@HO+R`@("`@("`@("`@("`D8VUD("`]("<O=7-R+V)I;B]L9&%P<V5A<F-H
M("UB("<@+B`D8F%S95]C;VYT97AT("X@)R`M<R`G("X@)'-C;W!E("X@)R!C
M;CTG.PHO+R`@("`@("`@("`@("`D8VUD("X](&5S8V%P95-H96QL0VUD*$%U
M=&@Z.F=E=$%U=&@H*2D["B\O("`@("`@("`@("`@("1C;60@+CT@)R!\("]U
M<W(O8FEN+V=R97`@;6%I;"!\("]U<W(O8FEN+V%W:R!<)WMP<FEN="`D,GU<
M)R<["B\O("`@("`@("`@("`@("1M86EL<R`](&`D8VUD8#L*+R\@("`@("`@
M("`@("`@)&UA:6Q?87)R87D@/2!E>'!L;V1E*")<;B(L("1M86EL<RD["B\O
M"B\O("`@("`@("`@("`@("\O(%-E;F0@8F%C:R!T:&4@9FER<W0@96UA:6P@
M9F]U;F0L(&YO="!T:&4@=VAO;&4@;&ES="X*+R\@("`@("`@("`@("`@)&UA
M:6P@/2`D;6%I;%]A<G)A>5LG,"==.PHO+PHO+R`@("`@("`@("`@("`O+R!)
M9B!N;R!E;6%I;"!A9&1R97-S(&ES(&9O=6YD+"!T:&5N('1H92!L;V=I;B!N
M86UE('=I;&P*+R\@("`@("`@("`@("`@+R\@8F4@=7-E9"X*+R\@("`@("`@
M("`@("`@<F5T=7)N("AE;7!T>2@D;6%I;"D@/R`G)R`Z("1M86EL*3L*+R\@
M("`@("`@("!]"B\O"B\O("`@("`@("`@<F5T=7)N("<G.PHO+R`@("`@?0HO
M+R!]"@HO+R!(97)E(&ES(&%N;W1H97(@=V%Y(&]F(&1O:6YG('1H92!S86UE
M('1H:6YG+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K
M7V9R;VU?861D<B<I*2!["B\O("`@("!F=6YC=&EO;B!?<')E9G-?:&]O:U]F
M<F]M7V%D9'(H)'5S97(@/2!N=6QL*0HO+R`@("`@>PHO+R`@("`@("`@("1L
M9&%P4V5R=F5R(#T@)S$W,BXS,2XP+C(S-B<["B\O("`@("`@("`@)&QD87!0
M;W)T(#T@)S,X.2<["B\O("`@("`@("`@)'-E87)C:$)A<V4@/2`G;SUM>6]R
M9R<["B\O"B\O("`@("`@("`@)&1S(#T@0&QD87!?8V]N;F5C="@D;&1A<%-E
M<G9E<BP@)&QD87!0;W)T*3L*+R\*+R\@("`@("`@("!I9B`H:7-?;G5L;"@D
M=7-E<BDI('L*+R\@("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG971!=71H
M*"D["B\O("`@("`@("`@?0HO+PHO+R`@("`@("`@("\O(%EO=2!W:6QL('!R
M;V)A8FQY(&YE960@=&\@<F5P;&%C92!C;CT@=VET:"!U:60].R!T:&ES"B\O
M("`@("`@("`@+R\@<WEN=&%X(&ES(&9O<B!.971W87)E(#4N,2!N;&1A<"X*
M+R\@("`@("`@("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H*"1D<RP@
M)'-E87)C:$)A<V4L("=C;CTG("X@)'5S97(I.PHO+R`@("`@("`@("1I;F9O
M<FUA=&EO;B`]($!L9&%P7V=E=%]E;G1R:65S*"1D<RP@)'-E87)C:%)E<W5L
M="D["B\O("`@("`@("`@:68@*"1I;F9O<FUA=&EO;ELP75LG;6%I;"==6S!=
M("$]("<G*2!["B\O("`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N
M6S!=6R=M86EL)UU;,%T["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@
M("`@("`@)&YA;64@/2`D:6YF;W)M871I;VY;,%U;)V-N)UU;,%T["B\O("`@
M("`@("`@?0HO+PHO+R`@("`@("`@(&QD87!?8VQO<V4H)&1S*3L*+R\*+R\@
M("`@("`@("!R971U<FX@*&5M<'1Y*"1N86UE*2`_("1U<V5R(#H@)&YA;64I
M.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@9G5L;&YA
M;64@:&]O:R!F=6YC=&EO;B!T;R!S970@=&AE(&9U;&QN86UE(&9R;VT@=&AE
M($=%0T]3"B\O(&EN9F]R;6%T:6]N(&EN('1H92!P87-S=V0@9FEL92X*"B\O
M(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<')E9G-?:&]O:U]F=6QL;F%M92<I
M*2!["B\O("`@("!F=6YC=&EO;B!?<')E9G-?:&]O:U]F=6QL;F%M92@D=7-E
M<B`](&YU;&PI"B\O("`@("!["B\O("`@("`@("`@:68@*&ES7VYU;&PH)'5S
M97(I*2!["B\O("`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T0F%R94%U
M=&@H*3L*+R\@("`@("`@("!]"B\O("`@("`@("`@)&%R<F%Y(#T@<&]S:7A?
M9V5T<'=N86TH)'5S97(I.PHO+R`@("`@("`@("1G96-O<U]A<G)A>2`](&5X
M<&QO9&4H)RPG+"`D87)R87E;)V=E8V]S)UTI.PHO+R`@("`@("`@(')E='5R
M;B`H96UP='DH)&=E8V]S7V%R<F%Y*2`_("1U<V5R(#H@)&=E8V]S7V%R<F%Y
M6S!=*3L*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!I<R!A;F]T:&5R(&5X86UP
M;&4@;V8@:&]W('1O(&=E="!T:&4@=7-E<B=S(&9U;&P@;F%M92P@:6X@=&AI
M<R!C87-E"B\O(&9R;VT@86X@;&1A<"!S97)V97(N($EN('1H:7,@97AA;7!L
M92!W92!L;V]K(&EF(&$@4W!A;FES:"!N86UE(&5X:7-T<R!A;F0*+R\@<F5T
M=7)N('1H:7,@;W(@=&AE('-T86YD87)D("=C;B<@96YT<GD@:68@;F]T+@H*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7V9U;&QN86UE
M)RDI('L*+R\@("`@(&9U;F-T:6]N(%]P<F5F<U]H;V]K7V9U;&QN86UE*"1U
M<V5R(#T@;G5L;"D*+R\@("`@('L*+R\@("`@("`@("`D;&1A<%-E<G9E<B`]
M("=L9&%P+F5X86UP;&4N8V]M)SL*+R\@("`@("`@("`D;&1A<%!O<G0@/2`G
M,S@Y)SL*+R\@("`@("`@("`D<V5A<F-H0F%S92`]("=O=3UP96]P;&4L;SUE
M>&%M<&QE+F-O;2<["B\O("`@("`@("`@)&QD87!C:&%R<V5T(#T@)W5T9BTX
M)SL*+R\@("`@("`@("`D;W5T<'5T8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E
M="@I.PHO+PHO+R`@("`@("`@("1D<R`]($!L9&%P7V-O;FYE8W0H)&QD87!3
M97)V97(L("1L9&%P4&]R="D["B\O"B\O("`@("`@("`@:68@*&ES7VYU;&PH
M)'5S97(I*2!["B\O("`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T
M:"@I.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D<V5A<F-H4F5S=6QT(#T@
M0&QD87!?<V5A<F-H*"1D<RP@)'-E87)C:$)A<V4L("=U:60])R`N("1U<V5R
M*3L*+R\@("`@("`@("`D:6YF;W)M871I;VX@/2!`;&1A<%]G971?96YT<FEE
M<R@D9',L("1S96%R8VA297-U;'0I.PHO+R`@("`@("`@(&EF("@D:6YF;W)M
M871I;VY;,%U;)V-N.VQA;F<M97,G75LP72`A/2`G)RD@>PHO+R`@("`@("`@
M("`@("`D;F%M92`]("1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=
M.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@("1N86UE(#T@
M)&EN9F]R;6%T:6]N6S!=6R=C;B==6S!=.PHO+R`@("`@("`@('T*+R\*+R\@
M("`@("`@("!L9&%P7V-L;W-E*"1D<RD["B\O"B\O("`@("`@("`@)&YA;64@
M/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1N86UE+"`D;&1A<&-H87)S970L
M("1O=71P=71C:&%R<V5T*3L*+R\@("`@("`@("!R971U<FX@*&5M<'1Y*"1N
M86UE*2`_("1U<V5R(#H@)&YA;64I.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E
M(&ES(&%N(&5X86UP;&4@<VEG;F%T=7)E(&AO;VL@9G5N8W1I;VX@=&\@<V5T
M('1H92!S:6=N871U<F4@9G)O;2!T:&4*+R\@<WES=&5M('1A9VQI;F5S(&9I
M;&4[('1H92!S=')I;F<@(B5404<E(B`H:68@<')E<V5N="!I;B!A('5S97(G
M<R!S:6=N871U<F4I"B\O('=I;&P@8F4@<F5P;&%C960@8GD@=&AE(&-O;G1E
M;G0@;V8@=&AE(&9I;&4@(B]U<W(O<VAA<F4O=&%G;&EN92(@*&=E;F5R871E
M9`HO+R!B>2!T:&4@(E1A4E0B('5T:6QI='DI+@HO+PHO+R!.;W1I8V4@:&]W
M('=E(&=L;V)A;"!I;B!T:&4@)'!R969S(&%R<F%Y('1O(&=E="!T:&4@=7-E
M<B=S(&-U<G)E;G0*+R\@<VEG;F%T=7)E+@H*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]P<F5F<U]H;V]K7W-I9VYA='5R92<I*2!["B\O("`@("!F=6YC
M=&EO;B!?<')E9G-?:&]O:U]S:6=N871U<F4H)'5S97)N86UE(#T@;G5L;"D*
M+R\@("`@('L*+R\@("`@("`@("`D<VEG(#T@)$=,3T)!3%-;)W!R969S)UTM
M/F=E=%9A;'5E*"=S:6=N871U<F4G*3L*+R\@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+R5404<E+R<L("1S:6<I*2!["B\O("`@("`@("`@("`@("1T86<@
M/2!@8V%T("]U<W(O<VAA<F4O=&%G;&EN96`["B\O("`@("`@("`@("`@("1S
M:6<@/2!P<F5G7W)E<&QA8V4H)WPE5$%')7PG+"`D=&%G+"`D<VEG*3L*+R\@
M("`@("`@("!]"B\O("`@("`@("`@<F5T=7)N("1S:6<["B\O("`@("!]"B\O
M('T*"B\O($E%(&]N($UA8R!H86YG<R!W:&5N('1H97)E(&%R92!S979E<F%L
M(&EC;VYS('1O(&)E(&QO861E9"X@070@;&5A<W0@;VX@<V]M90HO+R!S>7-T
M96US+B!4:&ES(&AO;VL@9&ES86)L97,@=&AE('-H;W=?:6-O;G,@<')E9F5R
M96YC92!F<F]M($MR;VYO;FQI=&@@9F]R"B\O('1H97-E(&)R;W=S97)S+@H*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7W-H;W=?:6-O
M;G,G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!R969S7VAO;VM?<VAO=U]I8V]N
M<R@I"B\O("`@("!["B\O("`@("`@("`@9VQO8F%L("1B<F]W<V5R.PHO+R`@
M("`@("`@(&EF("@D8G)O=W-E<BT^9V5T4&QA=&9O<FTH*2`]/2`G;6%C)R`F
M)@HO+R`@("`@("`@("`@("`D8G)O=W-E<BT^9V5T0G)O=W-E<B@I(#T]("=M
M<VEE)RD@>PHO+R`@("`@("`@("`@("!R971U<FX@9F%L<V4["B\O("`@("`@
M("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@<F5T=7)N('1R=64["B\O("`@
M("`@("`@?0HO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&AO;VL@:7,@8V%L;&5D
M('=H96X@82!U<V5R('-U8FUI=',@82!S:6=N=7`@<F5Q=65S="X@($ET(&%L
M;&]W<PHO+R!A(&-H86YC92!T;R!A;'1E<B!O<B!V86QI9&%T92!T:&4@9&%T
M82!S=6)M:71T960@8GD@82!U<V5R(&)E9F]R92!A;GD*+R\@871T96UP=',@
M87)E(&UA9&4@=&\@861D('1H96T@=&\@=&AE('-Y<W1E;2X*"B\O(&EF("@A
M9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S
M<R<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?<')E
M<')O8V5S<R@D:6YF;RD@>PHO+R`@("`@("`@("1I;F9O6R=U<V5R7VYA;64G
M72`](%-T<FEN9SHZ;&]W97(H)&EN9F];)W5S97)?;F%M92==*3L*+R\@("`@
M("`@("!R971U<FX@)&EN9F\["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:&]O
M:R!I<R!C86QL960@=VAE;B!A('-I9VYU<"!I<R!Q=65U960@9F]R(&%D;6EN
M:7-T<F%T:79E(&%P<')O=F%L+@HO+R!4:&ES(&5X86UP;&4@<V5N9',@82!N
M;W1I9FEC871I;VX@;65S<V%G92!T;R!T:&4@=V5B('-E<G9E<@HO+R!A9&UI
M;FES=')A=&]R)W,@92UM86EL(&%D9')E<W,N"@HO+R!I9B`H(69U;F-T:6]N
M7V5X:7-T<R@G7VAO<F1E7VAO;VM?<VEG;G5P7W%U975E9"<I*2!["B\O("`@
M("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D7W=A;&MD871A
M*"1F:65L9',L("1D871A*0HO+R`@("`@>PHO+R`@("`@("`@("1M<V<@/2`G
M)SL*+R\@("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D9FEE;&0@/3X@)'9A
M;'5E*2!["B\O("`@("`@("`@("`@(&EF("@D9FEE;&0@/3T@)W!A<W-W;W)D
M)R!\?"`D9FEE;&0@/3T@)W5R;"<I('L*+R\@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PHO+R`@("`@("`@("`@("!]"B\O"B\O("`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D=F%L=64I*2!["B\O("`@("`@("`@("`@("`@("`D;7-G
M("X](%]H;W)D95]H;V]K7W-I9VYU<%]Q=65U961?=V%L:V1A=&$H)&9I96QD
M<RP@)'9A;'5E*3L*+R\@("`@("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@
M("`@("`@("`@("1F:65L9"`](&ES<V5T*"1F:65L9'-;)&9I96QD75LG;&%B
M96PG72D@/PHO+R`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD<ULD
M9FEE;&1=6R=L86)E;"==(#H@)&9I96QD.PHO+R`@("`@("`@("`@("`@("`@
M)&US9R`N/2`B)&9I96QD.B`D=F%L=65<;B(["B\O("`@("`@("`@("`@('T*
M+R\@("`@("`@("!]"B\O("`@("`@("`@<F5T=7)N("1M<V<["B\O("`@("!]
M"B\O"B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D
M*"1U<V5R240L("1D871A*0HO+R`@("`@>PHO+R`@("`@("`@(')E<75I<F5?
M;VYC92`G36%I;"YP:'`G.PHO+R`@("`@("`@(&=L;V)A;"`D8V]N9BP@)')E
M9VES=')Y.PHO+PHO+R`@("`@("`@("1H96%D97)S(#T@87)R87DH"B\O("`@
M("`@("`@("`@("=4;R<@("`@("`]/B`D7U-%4E9%4ELG4T525D527T%$34E.
M)UTL"B\O("`@("`@("`@("`@("=&<F]M)R`@("`]/B`D7U-%4E9%4ELG4T52
M5D527T%$34E.)UTL"B\O("`@("`@("`@("`@("=3=6)J96-T)R`]/B`G3F5W
M("<@+B`D<F5G:7-T<GDM/F=E="@G;F%M92<L("=H;W)D92<I("X@)R!3:6=N
M=7`G"B\O("`@("`@("`@*3L*+R\*+R\@("`@("`@("`D97AT<F%&:65L9',@
M/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]G971E>'1R
M82<I.PHO+PHO+R`@("`@("`@("1M<V<@(#T@7R@B02!N97<@<VEG;G5P(&AA
M<R!B965N(')E8V5I=F5D(&%N9"!I<R!A=V%I=&EN9R!Y;W5R(&%P<')O=F%L
M+B(I.PHO+R`@("`@("`@("1M<V<@+CT@(EQN7&XB.PHO+R`@("`@("`@("1M
M<V<@+CT@7VAO<F1E7VAO;VM?<VEG;G5P7W%U975E9%]W86QK9&%T82@D97AT
M<F%&:65L9',L("1D871A*3L*+R\@("`@("`@("`D;7-G("X](")<;B(["B\O
M("`@("`@("`@)&US9R`N/2!S<')I;G1F*%\H(EEO=2!C86X@87!P<F]V92!T
M:&ES('-I9VYU<"!A="`E<R(I+"!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D
M;6EN+W5S97(N<&AP)RP@=')U92P@+3$I*3L*+R\*+R\@("`@("`@("`D;6%I
M;&5R(#T@36%I;#HZ9F%C=&]R>2@D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72P@
M)&-O;F9;)VUA:6QE<B==6R=P87)A;7,G72D["B\O("`@("`@("`@<F5T=7)N
M("1M86EL97(M/G-E;F0H)%]315)615);)U-%4E9%4E]!1$U)3B==+"`D:&5A
M9&5R<RP@)&US9RD["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA
M;7!L92!?:&]R9&5?:&]O:U]S:6=N=7!?9V5T97AT<F$@9G5N8W1I;VXN($ET
M(')E='5R;G,@86YY"B\O(&5X=')A(&9I96QD<R!W:&EC:"!N965D('1O(&)E
M(&9I;&QE9"!I;B!W:&5N(&$@;F]N(')E9VES=&5R960@=7-E<B!W:7-H97,*
M+R\@=&\@<VEG;B!U<"X*+R\@5&AE(&5X86UP;&4@:&5R92!T86ME<R!T:&4@
M:'EP;W1H971I8V%L(&-A<V4@=VAE<F4@=V4@=V]U;&0@=V%N="!T;R!S=&]R
M90HO+R!E>'1R82!I;F9O<FUA=&EO;B!A8F]U="!A('5S97(@:6YT;R!A('1U
M<F)A('-Q;"!A9&1R97-S(&)O;VLN($%L;"!T:&ES"B\O(&9U;F-T:6]N(&1O
M97,@=&AE;B!I<R!T;R!I;F-L=61E('1H92!A='1R:6)U=&5S+G!H<"!F:6QE
M(&9R;VT@=&AE('1U<F)A"B\O(&-O;F9I9R!D:7)E8W1O<GD@86YD(')E='5R
M;B!T:&4@)&%T=')I8G5T97,@87)R87DN"B\O($]T:&5R=VES92!A;GD@<W1R
M=6-T=7)E('1H870@=V]U;&0@<F5T=7)N(&%N(&%R<F%Y('=I=&@@=&AE(&9O
M;&QO=VEN9PHO+R!S>6YT87@@=V]U;&0@8F4@=F%L:60Z"B\O("`@)'-O;65A
M<G)A>5LG<V]M969I96QD;F%M92==(#T@87)R87DH+BXN"B\O("`@("`@;&%B
M96P@("`@+2!T:&4@=&5X="!T:&%T('1H92!U<V5R('=I;&P@<V5E(&%T=&%C
M:&5D('1O('1H:7,@9FEE;&0*+R\@("`@("!T>7!E("`@("`M(&%N>2!A;&QO
M=V5D($AO<F1E7T9O<FT@9FEE;&0@='EP90HO+R`@("`@('!A<F%M<R`@("T@
M86YY(&%L;&]W960@<&%R86UE=&5R('1O($AO<F1E7T9O<FT@9FEE;&0@='EP
M97,*+R\@("`@("!R97%U:7)E9"`M(&)O;VQE86XL('1R=64@;W(@9F%L<V4@
M=VAE=&AE<B!T:&ES(&9I96QD(&ES(&UA;F1A=&]R>0HO+R`@("`@(')E861O
M;FQY("T@8F]O;&5A;BP@=')U92!O<B!F86QS92!W:&5T:&5R('1H:7,@961I
M=&%B;&4*+R\@("`@("!D97-C("`@("`M(&%N>2!H96QP('1E>'0@871T86-H
M960@=&\@=&AE(&9I96QD"B\O($Y/5$4Z(%EO=2!$3R!.145$(%1U<F)A('1O
M(&)E(&-O<G)E8W1L>2!I;G-T86QL960@8F5F;W)E('EO=2!C86X@=7-E('1H
M:7,*+R\@97AA;7!L92!B96QO=RX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S
M*"=?:&]R9&5?:&]O:U]S:6=N=7!?9V5T97AT<F$G*2D@>PHO+R`@("`@9G5N
M8W1I;VX@7VAO<F1E7VAO;VM?<VEG;G5P7V=E=&5X=')A*"D*+R\@("`@('L*
M+R\@("`@("`@("!G;&]B86P@)')E9VES=')Y.PHO+R`@("`@("`@(')E<75I
M<F4@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)W1U<F)A)RD@+B`G+V-O
M;F9I9R]A='1R:6)U=&5S+G!H<"<["B\O("`@("`@("`@<F5T=7)N("1A='1R
M:6)U=&5S.PHO+R`@("`@?0HO+R!]"@HO+R!&;VQL;W=I;F<@;VX@9G)O;2!T
M:&4@97AA;7!L92!I;B!T:&4@86)O=F4@9G5N8W1I;VXL('1H:7,@:7,@:&]W
M(&$@<V%M<&QE"B\O(%]H;W)D95]H;V]K7W-I9VYU<%]A9&1E>'1R82!F=6YC
M=&EO;B!W;W5L9"!L;V]K(&QI:V4N"B\O($AE<F4@=V4@8V]N;F5C="!T;R!T
M:&4@9&%T86)A<V4@=7-I;F<@=&AE('-Q;"!P87)A;65T97)S(&-O;F9I9W5R
M960@:6X*+R\@)&-O;F8@86YD('-T;W)E('1H92!E>'1R82!F:65L9',@:6X@
M='5R8F%?;V)J96-T<RP@=7-I;F<@=&AE("1U<V5R260@87,@=&AE"B\O(&ME
M>2!F;W(@=&AE(&]B:F5C="!A;F0@=F%L=65S(&9R;VT@=&AE("1E>'1R82!A
M<G)A>2X*+R\@66]U(&-O=6QD(&-R96%T92!Y;W5R(&]W;B!S<6P@<WEN=&%X
M(&]R(&-O9&4@=&\@<W1O<F4@=&AI<R!I;B!W:&EC:&5V97(*+R\@8F%C:V5N
M9"!Y;W4@<F5Q=6ER92X*+R\@3D]413H@66]U($1/($Y%140@5'5R8F$@=&\@
M8F4@8V]R<F5C=&QY(&EN<W1A;&QE9"!B969O<F4@>6]U(&-A;B!U<V4@=&AI
M<PHO+R!E>&%M<&QE(&)E;&]W+B!)="!A;'-O(&%S<W5M97,@=&AA="!Y;W4@
M87)E('5S:6YG(&%N(%-13"!B86-K96YD+@H*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]H;W)D95]H;V]K7W-I9VYU<%]A9&1E>'1R82<I*2!["B\O("`@
M("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?861D97AT<F$H)'5S97))
M1"P@)&5X=')A*0HO+R`@("`@>PHO+R`@("`@("`@(&=L;V)A;"`D8V]N9CL*
M+R\*+R\@("`@("`@("!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B\O("`@("`@
M("`@)%]D8B`]("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTL('1R=64I.PHO
M+PHO+R`@("`@("`@("1F:65L9',@/2!A<G)A>2@I.PHO+R`@("`@("`@("1V
M86QU97,@/2!A<G)A>2@I.PHO+R`@("`@("`@(&9O<F5A8V@@*"1E>'1R82!A
M<R`D9FEE;&0@/3X@)'9A;'5E*2!["B\O("`@("`@("`@("`@("1F:65L9'-;
M72`]("=O8FIE8W1?)R`N(%-T<FEN9SHZ;&]W97(H)&9I96QD*3L*+R\@("`@
M("`@("`@("`@)'9A;'5E<UM=(#T@)%]D8BT^<75O=&4H4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D=F%L=64L($Y,4SHZ9V5T0VAA<G-E="@I+"`D8V]N9ELG
M<W%L)UU;)V-H87)S970G72DI.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D
M9FEE;&1S6UT@/2`G;V)J96-T7VED)SL*+R\@("`@("`@("`D=F%L=65S6UT@
M/2`D7V1B+3YQ=6]T92@D=7-E<DE$*3L*+R\*+R\@("`@("`@("`D<75E<GD@
M(#T@)TE.4T525"!)3E1/('1U<F)A7V]B:F5C=',@*"!O=VYE<E]I9"P@)R`N
M(&EM<&QO9&4H)RP@)RP@)&9I96QD<RD@+B`G*2<["B\O("`@("`@("`@)'%U
M97)Y("X]("<@5D%,5453("@@7"=A9&UI;EPG+"`G("X@:6UP;&]D92@G+"`G
M+"`D=F%L=65S*2`N("<I)SL*+R\@("`@("`@("`D<F5S=6QT(#T@)%]D8BT^
M<75E<GDH)'%U97)Y*3L*+R\*+R\@("`@("`@("!R971U<FX@:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I(#\@)')E<W5L="`Z('1R=64["B\O("`@("!]
M"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?:&]R9&5?:&]O:U]P<F5A
M=71H96YT:6-A=&4@=&AA="!M86ME($AO<F1E(')E<W!E8W0@=&AE"B\O(%5N
M:7@@8V]N=F5N=&EO;B!O9B!N;W0@86QL;W=I;F<@;&]G:6X@=VAE;B!A(&9I
M;&4@;F%M960@+V5T8R]N;VQO9VEN(&5X:7-T+@HO+R!4:&ES(&9U;F-T:6]N
M(&=E="!P87-S960@=&AE('5S97)N86UE+"!C<F5D96YT:6%L(&%N9"!R96%L
M;2!I;F9O<FUA=&EO;B!B=70*+R\@=&AE>2!A<F4@;F]T('5S960@:6X@=&AI
M<R!E>&%M<&QE+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H
M;V]K7W!R96%U=&AE;G1I8V%T92<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R
M9&5?:&]O:U]P<F5A=71H96YT:6-A=&4H)'5S97))1"P@)&-R961E;G1I86PL
M("1R96%L;2D*+R\@("`@('L*+R\@("`@("`@("!R971U<FX@(69I;&5?97AI
M<W1S*"<O971C+VYO;&]G:6XG*3L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I
M<R!A;B!E>&%M<&QE(&]F('9A;&ED871I;F<@=&AE('5S97(G<R!R:6=H="!T
M;R!L;V=I;B!T;R!(;W)D92!B>0HO+R!C;VYS=6QT:6YG(&=R;W5P(&UE;6)E
M<G-H:7`@:6X@86X@3$1!4"!D:7)E8W1O<GDN("!4:&%T('=A>2P@:68@>6]U
M<B!(;W)D90HO+R!I;G-T86QL871I;VX@:7,@8V]N9FEG=7)E9"!T;R!A=71H
M96YT:6-A=&4@86=A:6YS="!)35`@=VAI8V@@:6X@='5R;@HO+R!A=71H96YT
M:6-A=&4@=FEA($E-05`L(&ET(&ES('-T:6QL('!O<W-I8FQE('1O(&QI;6ET
M(&%C8V5S<R!T;R!(;W)D92!B>0HO+R!G<F]U<"!M96UB97)S:&EP+B`@5&AE
M(&9O;&QO=VEN9R!E>&%M<&QE(&AA9"!B965N(&UA9&4@=VET:"!A;B!-4R!!
M8W1I=F4*+R\@1&ER96-T;W)Y(&EN(&UI;F0N("!.;W1E('1H870@:68@=&AE
M($Q$05`@9&ER96-T;W)Y(&ES('5N879A:6QA8FQE(&]R('-O;64*+R\@;W1H
M97(@97)R;W(@;V-C=7(L(&%U=&AE;G1I8V%T:6]N('=I;&P@9F%I;"X*"B\O
M(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P;W-T875T:&5N
M=&EC871E)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W!O<W1A
M=71H96YT:6-A=&4H)'5S97))1"P@)&-R961E;G1I86PL("1R96%L;2D*+R\@
M("`@('L*+R\@("`@("`@("`D;&1A<%-E<G9E<B`]("=A9"YE>&%M<&QE+F-O
M;2<["B\O("`@("`@("`@)&QD87!0;W)T(#T@)S,X.2<["B\O("`@("`@("`@
M+R\@3F]T92!T:&%T(&-R961E;G1I86P@:7,@<V5N="!P;&%I;BUT97AT(&EN
M('1H:7,@8V%S92P@<V\@9&]N)W0@=7-E"B\O("`@("`@("`@+R\@<')I=FEL
M96=E9"!A8V-O=6YT(&AE<F4@;W(@<V5T=7`@4U-,("AB>2!U<VEN9R!P;W)T
M(#8S-B!A8F]V92DN"B\O("`@("`@("`@)&)I;F1D;B`]("=C;CU7:71H;W5T
M4')I=FEL96=E+&1C/75L879A;"UD978L9&,]8V$G.PHO+R`@("`@("`@("1B
M:6YD<'<@/2`G4F5M96UB97(@=&AI<R!I<R!S96YT(&EN('1H92!C;&5A<B!U
M;FQE<W,@4U-,(&ES('5S960G.PHO+R`@("`@("`@("1S96%R8VA"87-E(#T@
M)V]U/5!E;W!L92QD8SUE>&%M<&QE+&1C/6-O;2<["B\O("`@("`@("`@+R\@
M071T<FEB=71E('1O(&UA=&-H("1U<V5R240@86=A:6YS="!I;B!S96%R8V@*
M+R\@("`@("`@("`D=7-E<D%T='(@/2`G<T%-06-C;W5N=$YA;64G.PHO+R`@
M("`@("`@("\O($=R;W5P(&UE;6)E<G-H:7`@871T<FEB=71E+"!N965D('1O
M(&)E(&%L;"!L;W=E<F-A<V4*+R\@("`@("`@("`D9W)O=7!!='1R(#T@)VUE
M;6)E<F]F)SL*+R\@("`@("`@("`O+R!!='1R:6)U=&4@=&\@8VAE8VL@9F]R
M(')I9VAT('1O('5S92!(;W)D90HO+R`@("`@("`@("1G<F]U<&1N(#T@)V-N
M/4AO<F1E57-E<BQO=3U096]P;&4L9&,]97AA;7!L92QD8SUC;VTG.PHO+R`@
M("`@("`@("1R970@/2!T<G5E.PHO+PHO+R`@("`@("`@("1D<R`]($!L9&%P
M7V-O;FYE8W0H)&QD87!397)V97(L("1L9&%P4&]R="D["B\O"B\O("`@("`@
M("`@:68@*$!L9&%P7V)I;F0H)&1S+"`D8FEN9&1N+"`D8FEN9'!W*2D@>PHO
M+R`@("`@("`@("`@("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H*"1D
M<RP@)'-E87)C:$)A<V4L("1U<V5R071T<B`N("<])R`N("1U<V5R240L(&%R
M<F%Y*"1G<F]U<$%T='(I+"`P+"`Q+"`U*3L*+R\@("`@("`@("`@("`@:68@
M*"1I;F9O<FUA=&EO;B`]($!L9&%P7V=E=%]E;G1R:65S*"1D<RP@)'-E87)C
M:%)E<W5L="DI('L*+R\@("`@("`@("`@("`@("`@("\O(&UA:V4@<&%T=&5R
M;B!C87-E+6EN<V5N<VET:79E"B\O("`@("`@("`@("`@("`@("`D<&%T=&5R
M;B`]("<O)R`N("1G<F]U<&1N("X@)R]I)SL*+R\@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1I;F9O<FUA=&EO;ELP75LD9W)O=7!!='1R72!A<R`D9W)O
M=7`I('L*+R\@("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D
M<&%T=&5R;BP@)&=R;W5P*2D@>PHO+R`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T(#T@=')U93L*+R\@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B\O("`@("`@("`@("`@("`@("`@("`@?0HO+R`@("`@("`@("`@("`@
M("`@?0HO+R`@("`@("`@("`@("!]"B\O("`@("`@("`@?0HO+PHO+R`@("`@
M("`@(&QD87!?8VQO<V4H)&1S*3L*+R\@("`@("`@("!R971U<FX@)')E=#L*
M+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(&]F(&-R96%T
M:6YG(&-R961E;G1I86QS(&YE961E9"!B>2!T:&4@3$1!4"!!=71H(&1R:79E
M<@HO+R!F;W(@861D:6YG+V1E;&5T:6YG+W5P9&%T:6YG('5S97)S+@H*+R\@
M:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RDI
M('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7V%U=&AL9&%P*"1U<V5R
M240L("1C<F5D96YT:6%L<R`](&YU;&PI"B\O("`@("!["B\O("`@("`@("`@
M)&5N=')Y6R=D;B==(#T@)W5I9#TG("X@)'5S97))1"`N("<L;W4]4&5O<&QE
M+&1C/65X86UP;&4N8V]M)SL*+R\@("`@("`@("!I9B`H:7-S970H)&-R961E
M;G1I86QS*2`F)B!I<W-E="@D8W)E9&5N=&EA;'-;)W5S97)?9G5L;&YA;64G
M72DI('L*+R\@("`@("`@("`@("`@)&5N=')Y6R=C;B==(#T@)&-R961E;G1I
M86QS6R=U<V5R7V9U;&QN86UE)UT["B\O("`@("`@("`@?2!E;'-E('L*+R\@
M("`@("`@("`@("`@)&5N=')Y6R=C;B==(#T@)'5S97))1#L*+R\@("`@("`@
M("!]"B\O("`@("`@("`@)&5N=')Y6R=S;B==(#T@)'5S97))1#L*+R\@("`@
M("`@("`D96YT<GE;)V]B:F5C=&-L87-S)UU;,%T@/2`G=&]P)SL*+R\@("`@
M("`@("`D96YT<GE;)V]B:F5C=&-L87-S)UU;,5T@/2`G<&5R<V]N)SL*+R\@
M("`@("`@("`D96YT<GE;)V]B:F5C=&-L87-S)UU;,ET@/2`G<6UA:6QU<V5R
M)SL*+R\@("`@("`@("`D96YT<GE;)V]B:F5C=&-L87-S)UU;,UT@/2`G0V]U
M<FEE<DUA:6Q!0V-O=6YT)SL*+R\@("`@("`@("`D96YT<GE;)VUA:6QH;W-T
M)UT@/2`G;6%I;"YE>&%M<&QE+F-O;2<["B\O("`@("`@("`@)&5N=')Y6R=M
M86EL365S<V%G95-T;W)E)UT@/2`G+VAO;64O;6%I;"\G("X@)'5S97))1#L*
M+R\@("`@("`@("`D96YT<GE;)VAO;65$:7)E8W1O<GDG72`]("<O:&]M92]M
M86EL+R<@+B`D=7-E<DE$.PHO+R`@("`@("`@("1E;G1R>5LG;6%I;&)O>"==
M(#T@)&5N=')Y6R=H;VUE1&ER96-T;W)Y)UT@+B`G+TUA:6QD:7(G.PHO+R`@
M("`@("`@("1E;G1R>5LG=6ED)UT@/2`D=7-E<DE$.PHO+R`@("`@("`@("1E
M;G1R>5LG86-C;W5N=%-T871U<R==(#T@)V%C=&EV92<["B\O("`@("`@("`@
M)&5N=')Y6R=M86EL475O=&$G72`]("<Q,#0X-3<V,#!3)SL*+R\@("`@("`@
M("`D96YT<GE;)VUA:6PG72`]("1U<V5R240["B\O("`@("`@("`@)&5N=')Y
M6R=U:61.=6UB97(G72`](#4P,3L*+R\@("`@("`@("`D96YT<GE;)V=I9$YU
M;6)E<B==(#T@-3`Q.PHO+PHO+R`@("`@("`@("\O(&YE960@=&\@8VAE8VL@
M9F]R(&YE=R!U<V5R<R`H<&%S<W=O<F0I(&%N9"!E9&ET960@=7-E<G,@*'5S
M97)?<&%S<U\R*0HO+R`@("`@("`@(&EF("AI<W-E="@D8W)E9&5N=&EA;',I
M("8F(&ES<V5T*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*+R\@("`@
M("`@("`@("`@)&5N=')Y6R=U<V5R4&%S<W=O<F0G72`]("`G>TU$-7TG("X@
M8F%S938T7V5N8V]D92AM2&%S:"A-2$%32%]-1#4L("1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72DI.PHO+R`@("`@("`@('T@96QS96EF("AI<W-E="@D8W)E
M9&5N=&EA;',I("8F(&ES<V5T*"1C<F5D96YT:6%L<ULG=7-E<E]P87-S7S(G
M72DI('L*+R\@("`@("`@("`@("`@)&5N=')Y6R=U<V5R4&%S<W=O<F0G72`]
M("`G>TU$-7TG("X@8F%S938T7V5N8V]D92AM2&%S:"A-2$%32%]-1#4L("1C
M<F5D96YT:6%L<ULG=7-E<E]P87-S7S(G72DI.PHO+R`@("`@("`@('T*+R\@
M("`@("`@("`D96YT<GE;)V1E;&EV97)Y36]D92==(#T@)VYO;&]C86PG.PHO
M+R`@("`@("`@(')E='5R;B`D96YT<GD["B\O("`@("!]"B\O('T*"B\O(%1H
M:7,@9G5N8W1I;VX@:7,@8V%L;&5D('=H96X@82!(;W)D95]3:&%R92!O8FIE
M8W0@:7,@8W)E871E9"X@270@=&%K97,@80HO+R!R969E<F5N8V4@=&\@=&AE
M($AO<F1E7U-H87)E(&]B:F5C="!T:&%T(&ES(&)E:6YG(&-R96%T960@87,@
M=V5L;"!A<R!T:`HO+R!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!F;W(@=VAI
M8V@@=&AE($AO<F1E7U-H87)E(&]B:F5C="!I<R!B96EN9R!C<F5A=&5D(&%S
M"B\O('!A<F%M971E<G,N(%1H92!R971U<FX@=F%L=64@:7,@:6=N;W)E9"X*
M"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:&%R95]I
M;FET)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7VEN
M:70H)B1S:&%R95]O8FIE8W0L("1A<'`I"B\O("`@("!["B\O("`@("`@("`@
M:68@*"1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)V5N86)L960G72D@>PHO
M+R`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<[
M"B\O("`@("`@("`@("`@($MO;&%B.CIS>6YC:')O;FES95-H87)E<R@D<VAA
M<F5?;V)J96-T+"`D87!P*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*
M"B\O(%1H92!F;VQL;W=I;F<@=&AR964@9G5N8W1I;VYS(&%R92!E>&%M<&QE
M<R!O9B!T:&]S92!T:&%T(&-A;B!B92!C86QL960@=VAE;@HO+R!A9&1I;F<L
M(&UO9&EF>6EN9R!A;F0@<F5M;W9I;F<@<VAA<F5S+"!R97-P96-T:79E;'DN
M(%1H97D@87)E(&-A;&QE9"!W:71H"B\O('1H92!S:&%R92!T:&%T(&ES(&)E
M:6YG(&%D9&5D+"!M;V1I9FEE9"!O<B!R96UO=F5D(&%S('1H96ER('-I;F=L
M90HO+R!P87)A;65T97(N("!)9B!A(%!%05)?17)R;W(@;V)J96-T(&ES(')E
M='5R;F5D('1H92!R97-P96-T:79E('-H87)E"B\O(&]P97)A=&EO;B!W:6QL
M(&9A:6P@=VET:"!T:&4@97)R;W(@<F5S=6QT+@H*+R\@:68@*"%F=6YC=&EO
M;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H87)E7V%D9"<I*2!["B\O("`@("!F
M=6YC=&EO;B!?:&]R9&5?:&]O:U]S:&%R95]A9&0H)B1S:&%R92D*+R\@("`@
M('L*+R\@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<[
M"B\O("`@("`@("`@<F5T=7)N($MO;&%B.CIU<&1A=&53:&%R92@D<VAA<F4I
M.PHO+R`@("`@?0HO+R!]"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO
M<F1E7VAO;VM?<VAA<F5?;6]D:69Y)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H
M;W)D95]H;V]K7W-H87)E7VUO9&EF>2@F)'-H87)E*0HO+R`@("`@>PHO+R`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O2V]L86(N<&AP)SL*+R\@("`@
M("`@("!R971U<FX@2V]L86(Z.G5P9&%T95-H87)E*"1S:&%R92D["B\O("`@
M("!]"B\O('T*+R\*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H
M;V]K7W-H87)E7W)E;6]V92<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?
M:&]O:U]S:&%R95]R96UO=F4H)B1S:&%R92D*+R\@("`@('L*+R\@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@("`@
M<F5T=7)N($MO;&%B.CIR96UO=F53:&%R92@D<VAA<F4I.PHO+R`@("`@?0HO
M+R!]"@HO+R!4:&ES(&5X86UP;&4@:7,@;V8@82!F=6YC=&EO;B!T:&%T(&-A
M;B!B92!C86QL960@=VAE;B!A('-H87)E(&QI<W1I;F<@:7,*+R\@<F5Q=65S
M=&5D+B!)="!T86ME<R!A('5S97)I9"P@82!P97)M:7-S:6]N<R!L979E;"P@
M86X@;W!T:6]N86P@<W1R:6YG"B\O(&-O;G1A:6YI;F<@82!U<V5R:60@=&\@
M<F5S=')I8W0@=&AE(&]W;F5R(&]F('1H92!S:&%R97,@<F5T=7)N960L(&%N
M9"!T:&4*+R\@<F5S=6QT(&]F('1H92!C;W)R97-P;VYD:6YG($AO<F1E7U-H
M87)E.CIL:7-T4VAA<F5S*"D@8V%L;"!A<R!I=',*+R\@<&%R86UE=&5R<RX@
M07,@:7,@=&AE(&-A<V4@:6X@=&AE('!R979I;W5S('1H<F5E(&9U;F-T:6]N
M<RP@:68@82!014%27T5R<F]R"B\O(')E<W5L="!I<R!R971U<FYE9"!T:&4@
M2&]R9&5?4VAA<F4Z.FQI<W13:&%R97,H*2!C86QL('1H870@=')I9V=E<F5D
M('1H:7,*+R\@:&]O:R!W:6QL(&9A:6P@=VET:"!T:&4@<F5T=7)N960@<F5S
M=6QT+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H
M87)E7VQI<W0G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA
M<F5?;&ES="@D=7-E<FED+"`D<&5R;2P@)&]W;F5R+"`F)'-H87)E7VQI<W0I
M"B\O("`@("!["B\O("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*+R\@("`@
M("`@("`O+V5R<F]R7VQO9R@G3G5M8F5R(&]F("<@+B`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T07!P*"D@+B`G('-H87)E<R<@+B`H)&]W;F5R(#\*+R\@
M("`@("`@("`O+R`@("`G(&]W;F5D(&)Y("<@+B`D;W=N97(@.B`G)RD@+B`G
M(&%V86EL86)L92!T;R`G("X@)'5S97)I9"`N("<@870@<&5R;7,@;&5V96P@
M)R`N"B\O("`@("`@("`@+R\@("`@)'!E<FT@+B`G.B`G("X@(&-O=6YT*"1S
M:&%R95]L:7-T*2D["B\O("`@("`@("`@<F5T=7)N('1R=64["B\O("`@("!]
M"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?=7-E<FYA;65?:&]O:U]F
M<F]M8F%C:V5N9"!F=6YC=&EO;BX@270@87!P96YD<R!T:&4*+R\@=FER='5A
M;"!D;VUA:6X@=&\@=&AE('5S97(@;F%M92X*+R\*+R\@97@N("1(5%107TA/
M4U0@/2`G;6%I;"YM>61O;6%I;BYC;VTG+"`D=7-E<DE$(#T@)VUY;F%M92<@
M<F5T=7)N<SH*+R\@("`G;7EN86UE0&UY9&]M86EN+F-O;2<*"B\O(&EF("@A
M9G5N8W1I;VY?97AI<W1S*"=?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"<I
M*2!["B\O("`@("!F=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N
M9"@D=7-E<DE$*0HO+R`@("`@>PHO+R`@("`@("`@("1V9&]M86EN(#T@9V5T
M96YV*"=(5%107TA/4U0G*3L*+R\@("`@("`@("`D=F1O;6%I;B`]('!R96=?
M<F5P;&%C92@G?%YM86EL7"Y\:2<L("<G+"`D=F1O;6%I;BD["B\O("`@("`@
M("`@)'9D;VUA:6X@/2!3=')I;F<Z.FQO=V5R*"1V9&]M86EN*3L*+R\*+R\@
M("`@("`@("!R971U<FX@)'5S97))1"`N("=`)R`N("1V9&]M86EN.PHO+R`@
M("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@7W5S97)N86UE7VAO
M;VM?=&]B86-K96YD(&9U;F-T:6]N(&%S(&$@8V]U;G1E<G!A<G0@;V8@=&AE
M"B\O('!R979I;W5S(&5X86UP;&4N($ET('-T<FEP<R!T:&4@=FER='5A;"!D
M;VUA:6X@9G)O;2!T:&4@=7-E<B!N86UE+@HO+PHO+R!E>"X@)$A45%!?2$]3
M5"`]("=M86EL+FUY9&]M86EN+F-O;2<L("1U<V5R240@/2`G;7EN86UE)R!R
M971U<FYS.@HO+R`@("=M>6YA;65`;7ED;VUA:6XN8V]M)PH*+R\@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)U]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"<I*2![
M"B\O("`@("!F=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]T;V)A8VME;F0H)'5S
M97))1"D*+R\@("`@('L*+R\@("`@("`@("`D=F1O;6%I;B`](&=E=&5N=B@G
M2%144%](3U-4)RD["B\O("`@("`@("`@)'9D;VUA:6X@/2!P<F5G7W)E<&QA
M8V4H)WQ>;6%I;%PN?&DG+"`G)RP@)'9D;VUA:6XI.PHO+R`@("`@("`@("1V
M9&]M86EN(#T@)T`G("X@4W1R:6YG.CIL;W=E<B@D=F1O;6%I;BD["B\O"B\O
M("`@("`@("`@:68@*'-U8G-T<B@D=7-E<DE$+"`M<W1R;&5N*"1V9&]M86EN
M*2D@/3T@)'9D;VUA:6XI('L*+R\@("`@("`@("`@("`@)'5S97))1"`]('-U
M8G-T<B@D=7-E<DE$+"`P+"`M<W1R;&5N*"1V9&]M86EN*2D["B\O("`@("`@
M("`@?0HO+PHO+R`@("`@("`@(')E='5R;B`D=7-E<DE$.PHO+R`@("`@?0HO
M+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@7W5S97)N86UE7VAO;VM?9G)O
M;6)A8VME;F0@9G5N8W1I;VXN($ET(&-O;G9E<G1S('1H92!U<V5R"B\O(&YA
M;64@=&\@86QL(&QO=V5R(&-A<V4N(%1H:7,@;6EG:'0@8F4@;F5C97-S87)Y
M(&EF(&%N(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0*+R\@:7,@8V%S92!I;G-E
M;G-I=&EV92!T;R!T86ME(&EN=&\@86-C;W5N="!T:&%T($AO<F1E)W,@<')E
M9F5R96YC92!S>7-T96T@:7,*+R\@8V%S92!S96YS:71I=F4N"B\O"B\O(&5X
M+B`D=7-E<DE$(#T@)TUY3F%M92<@<F5T=7)N<SH@)VUY;F%M92<*"B\O(&EF
M("@A9G5N8W1I;VY?97AI<W1S*"=?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N
M9"<I*2!["B\O("`@("!F=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]F<F]M8F%C
M:V5N9"@D=7-E<DE$*0HO+R`@("`@>PHO+R`@("`@("`@(')E='5R;B!3=')I
M;F<Z.FQO=V5R*"1U<V5R240I.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES
M(&%N(&5X86UP;&4@7W!E<FUS7VAO;VM?9&5N:65D(&9U;F-T:6]N+B`@270@
M:7,@8V%L;&5D(&EF(&$@=7-E<@HO+R!T<FEE<R!T;R!M86ME(&%N(&%C=&EO
M;B!T:&%T(&ES('5N9&5R('!E<FUI<W-I;VX@8V]N=')O;"!A;F0@=&AA="!H
M90HO+R!D;V5S;B=T(&AA=F4@<W5F9FEC:65N="!P97)M:7-S:6]N<R!F;W(N
M("!)="!C86X@8F4@=7-E9"!T;R!S:&]W('1H92!U<V5R(&$*+R\@8W5S=&]M
M(&UE<W-A9V4@:6YC;'5D:6YG($A434P@8V]D92`H>6]U(&AA=F4@=&\@=&%K
M92!C87)E(&%B;W5T($A434P*+R\@97-C87!I;F<@;VX@>6]U<B!O=VXI+"!O
M<B!T;R!I;G1E<G)U<'0@=&AE(&-O9&4@9FQO=R!A;F0@<V5N9"!T:&4@=7-E
M<B!T;R!A"B\O(&1I9F9E<F5N="!P86=E(&9O<B!E>&%M<&QE+@H*+R\@:68@
M*"%F=6YC=&EO;E]E>&ES=',H)U]P97)M<U]H;V]K7V1E;FEE9"<I*2!["B\O
M("`@("!F=6YC=&EO;B!?<&5R;7-?:&]O:U]D96YI960H)'!E<FUI<W-I;VXI
M"B\O("`@("!["B\O("`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1P97)M
M:7-S:6]N+"`G.B<I*2`]/3T@9F%L<V4I('L*+R\@("`@("`@("`@("`@)&%P
M<"`]("1P97)M:7-S:6]N.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@
M("`@("`@("1A<'`@/2!S=6)S='(H)'!E<FUI<W-I;VXL(#`L("1P;W,I.PHO
M+R`@("`@("`@('T*+R\*+R\@("`@("`@("!R971U<FX@<W!R:6YT9B@G4&5R
M;6ES<VEO;B!D96YI960N($-L:6-K(#QA(&AR968](FAT='`Z+R]W=W<N97AA
M;7!L92YC;VTO=7!G<F%D92YP:'`_87!P/25S(CY(15)%/"]A/B!T;R!U<&=R
M861E("5S+B<L"B\O("`@("`@("`@("`@("`@("`@("`@("`@)&%P<"P@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<I*3L*+R\@("`@('T*+R\@
M?0H*+R\@5&AI<R!I<R!A;B!E>&%M<&QE(&]F(&$@9W)O=7`@:&]O:RX@(%1O
M('5S92!I="!Y;W4@;75S="!S970@=&AE(&=R;W5P"B\O(&1R:79E<B!T;R!H
M;V]K<R!I;B!C;VYF+G!H<"X@(%1H96X@>6]U(&UU<W0@8W)E871E(&$@251?
M9&5P87)T;65N="!G<F]U<`HO+R`H8F5C875S92!T:&%T(&ES(&AO=R!W92!K
M;F]W('=H870@:&]O:R!T;R!C86QL*2X@(%EO=2!C86X@861D('5S97)S('1O
M('1H90HO+R!G<F]U<"!A<R!N;W)M86PL(&%N9"!I;B!A9&1I=&EO;B!T:&ES
M(&9U;F-T:6]N('=I;&P@8F4@8V%L;&5D('1O"B\O(&1Y;F%M:6-A;&QY(&EN
M8VQU9&4@=7-E<G,@:6X@=&AE(&=R;W5P+B`@26X@=&AI<R!E>&%M<&QE('=E
M('=I;&P@;&]O:R!U<`HO+R!W:&5T:&5R(&]R(&YO="!T:&ES('5S97(@:7,@
M<&%R="!O9B!T:&4@250@9&5P87)T;65N="!U<VEN9R!A;B!E>'1E<FYA;`HO
M+R!D871A8F%S92X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?9W)O=7!?
M:&]O:U])5%]D97!A<G1M96YT)RDI('L*+R\@("`@(&9U;F-T:6]N(%]G<F]U
M<%]H;V]K7TE47V1E<&%R=&UE;G0H)'5S97).86UE*0HO+R`@("`@>PHO+R`@
M("`@("`@(&=L;V)A;"`D8V]N9CL*+R\*+R\@("`@("`@("`D9&5P="`]("=)
M5"<["B\O("`@("`@("`@:6YC;'5D95]O;F-E("=$0BYP:'`G.PHO+R`@("`@
M("`@("1?9&(@/2`F1$(Z.F-O;FYE8W0H)&-O;F9;)W-Q;"==+"!T<G5E*3L*
M+R\@("`@("`@("`D<75E<GD@/2`G4T5,14-4($-/54Y4*"HI($923TT@9&5P
M87)T;65N=',@5TA%4D4@=7-E<E]N86UE(#T@/R!!3D0@9&5P87)T;65N="`]
M(#\G.PHO+R`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=7-E<DYA;64L("1D
M97!T*3L*+R\@("`@("`@("`D<F5S=6QT(#T@)%]D8BT^9V5T3VYE*"1Q=65R
M>2P@)'9A;'5E<RD["B\O("`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RD@)B8@)')E<W5L="`^(#`I('L*+R\@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PHO+R`@("`@("`@('T*+R\@("`@('T*+R\@?0H*
M+R\@5&AI<R!I<R!A;B!E>&%M<&QE(&]F(&$@<&]S="UP=7-H(&AO;VL[(&ET
M(&ES(&-A;&QE9"!R:6=H="!A9G1E<B!A;@HO+R!A<'!L:6-A=&EO;B!I<R!P
M=7-H960@<W5C8V5S<V9U;&QY(&]N=&\@=&AE(&%P<"!S=&%C:RX*"B\O(&EF
M("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P;W-T7W!U<VAA<'`G
M*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<&]S=%]P=7-H87!P
M*"1A<'`I"B\O("`@("!["B\O("`@("`@("`@:68@*&EN7V%R<F%Y*"1A<'`L
M(&%R<F%Y*"=K<F]N;VQI=&@G+"`G='5R8F$G+"`G:&]R9&4G+"`G:6YG;R<I
M*2!\?`HO+R`@("`@("`@("`@("`@<W1R<&]S*"1?4T525D526R=02%!?4T5,
M1B==+"`G<')E9G,N<&AP)RD@(3T](&9A;'-E*2!["B\O("`@("`@("`@("`@
M(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE
M<F]O="<L("=D:6UP)RD@+B`G+VQI8B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S3W9E<G)I9&4N<&AP)SL*+R\@("`@("`@("`@("`@)$=,3T)!3%-;
M)VYO=&EF:6-A=&EO;B==(#T@)DYO=&EF:6-A=&EO;CHZ<VEN9VQE=&]N*"D[
M"B\O("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^871T
M86-H*"=S=&%T=7,G+"!N=6QL+"`G3F]T:69I8V%T:6]N7TQI<W1E;F5R7V1I
M;7!?<W1A='5S3W9E<G)I9&4G*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O
M('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?:6UP7VAO;VM?=')A:6QE<B!F
M=6YC=&EO;B!T;R!S970@=&AE('1R86EL97(@9G)O;2!T:&4*+R\@<WES=&5M
M('1A9VQI;F5S(&9I;&4[('1H92!S=')I;F<@(D!`5$%'0$`B("AI9B!P<F5S
M96YT(&EN(&$@=')A:6QE<BD@=VEL;"!B90HO+R!R97!L86-E9"!B>2!T:&4@
M8V]N=&5N="!O9B!T:&4@9FEL92`B+W5S<B]S:&%R92]T86=L:6YE(B`H9V5N
M97)A=&5D(&)Y('1H90HO+R`B5&%25"(@=71I;&ET>2DN"@HO+R!I9B`H(69U
M;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7W1R86EL97(G*2D@>PHO+R`@("`@
M9G5N8W1I;VX@7VEM<%]H;V]K7W1R86EL97(H)'1R86EL97(I"B\O("`@("![
M"B\O("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]`0%1!1T!`+R<L("1T<F%I
M;&5R*2D@>PHO+R`@("`@("`@("`@("`D=&%G(#T@8&-A="`O=7-R+W-H87)E
M+W1A9VQI;F5@.PHO+R`@("`@("`@("`@("`D=')A:6QE<B`]('!R96=?<F5P
M;&%C92@G?$!`5$%'0$!\)RP@)'1A9RP@)'1R86EL97(I.PHO+R`@("`@("`@
M('T*+R\@("`@("`@("!R971U<FX@)'1R86EL97(["B\O("`@("!]"B\O('T*
M"B\O($AE<F4@:7,@86X@86YO=&AE<B!E>&%M<&QE(%]I;7!?:&]O:U]T<F%I
M;&5R(&9U;F-T:6]N('1O('-E="!T:&4@=')A:6QE<@HO+R!F<F]M('1H92!,
M1$%0(&1I<F5C=&]R>2!F;W(@96%C:"!D;VUA:6XN(%1H:7,@9G5N8W1I;VX@
M<F5P;&%C97,@=&AE(&-U<G)E;G0*+R\@=')A:6QE<B!W:71H('1H92!D871A
M(&ET(&=E=',@9G)O;2!I<W!M86Y$;VUA:6Y3:6=N871U<F4N"@HO+R!I9B`H
M(69U;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7W1R86EL97(G*2D@>PHO+R`@
M("`@9G5N8W1I;VX@7VEM<%]H;V]K7W1R86EL97(H)'1R86EL97(I"B\O("`@
M("!["B\O("`@("`@("`@)'9D;VUA:6X@/2!G971E;G8H)TA45%!?2$]35"<I
M.PHO+R`@("`@("`@("1V9&]M86EN(#T@<')E9U]R97!L86-E*"=\7BXJ/UPN
M?&DG+"`G)RP@)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@4W1R
M:6YG.CIL;W=E<B@D=F1O;6%I;BD["B\O("`@("`@("`@)&QD87!397)V97(@
M/2`G;&]C86QH;W-T)SL*+R\@("`@("`@("`D;&1A<%!O<G0@/2`G,S@Y)SL*
M+R\@("`@("`@("`D<V5A<F-H0F%S92`]("=I<W!M86Y$;VUA:6X])R`N("1V
M9&]M86EN("`N("(L;SUI<W!M86XB.PHO+PHO+R`@("`@("`@("1D<R`]($!L
M9&%P7V-O;FYE8W0H)&QD87!397)V97(L("1L9&%P4&]R="D["B\O("`@("`@
M("`@)'-E87)C:%)E<W5L="`]($!L9&%P7W-E87)C:"@D9',L("1S96%R8VA"
M87-E+"`G=6ED/2<@+B`D=F1O;6%I;BD["B\O("`@("`@("`@)&EN9F]R;6%T
M:6]N(#T@0&QD87!?9V5T7V5N=')I97,H)&1S+"`D<V5A<F-H4F5S=6QT*3L*
M+R\@("`@("`@("`D=')A:6QE<CT@)&EN9F]R;6%T:6]N6S!=6R=I<W!M86YD
M;VUA:6YS:6=N871U<F4G75LP73L*+R\@("`@("`@("!L9&%P7V-L;W-E*"1D
M<RD["B\O"B\O("`@("`@("`@<F5T=7)N("1T<F%I;&5R.PHO+R`@("`@?0HO
M+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@7VEM<%]H;V]K7W9I;F9O(&9U
M;F-T:6]N+B!)9B`D='EP92`]/2`G=F1O;6%I;B<L('1H:7,*+R\@9G5N8W1I
M;VX@<F5T=7)N<R!T:&4@2%144%](3U-4('9A<FEA8FQE(&%F=&5R(')E;6]V
M:6YG('1H92`G;6%I;"XG"B\O('-U8F1O;6%I;BX*+R\*+R\@268@)'1Y<&4@
M/3T@)W5S97)N86UE)RP@=&AI<R!F=6YC=&EO;B!R971U<FYS(&$@=6YI<75E
M('5S97)N86UE(&-O;7!O<V5D(&]F"B\O("1?4T534TE/3ELG:6UP)UU;)W5S
M97(G72`K('9D;VUA:6XN"B\O"B\O(&5X+B`D2%144%](3U-4(#T@)VUA:6PN
M;7ED;VUA:6XN8V]M)RP@)%]315-324].6R=I;7`G75LG=7-E<B==(#T@)VUY
M;F%M92<Z"B\O("`@)'9D;VUA:6X@(#T@)VUY9&]M86EN+F-O;2<*+R\@("`D
M=7-E<FYA;64@/2`G;7EN86UE7VUY9&]M86EN7V-O;2<*"B\O(&EF("@A9G5N
M8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?=FEN9F\G*2D@>PHO+R`@("`@9G5N
M8W1I;VX@7VEM<%]H;V]K7W9I;F9O*"1T>7!E(#T@)W5S97)N86UE)RD*+R\@
M("`@('L*+R\@("`@("`@("`D=F1O;6%I;B`](&=E=&5N=B@G2%144%](3U-4
M)RD["B\O("`@("`@("`@)'9D;VUA:6X@/2!P<F5G7W)E<&QA8V4H)WQ>;6%I
M;%PN?&DG+"`G)RP@)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@
M4W1R:6YG.CIL;W=E<B@D=F1O;6%I;BD["B\O"B\O("`@("`@("`@:68@*"1T
M>7!E(#T]("=U<V5R;F%M92<I('L*+R\@("`@("`@("`@("`@<F5T=7)N('!R
M96=?<F5P;&%C92@G?%PN?"<L("=?)RP@)%]315-324].6R=I;7`G75LG=7-E
M<B==("X@)U\G("X@)'9D;VUA:6XI.PHO+R`@("`@("`@('T@96QS96EF("@D
M='EP92`]/2`G=F1O;6%I;B<I('L*+R\@("`@("`@("`@("`@<F5T=7)N("1V
M9&]M86EN.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=I;G9A;&ED('1Y<&4Z("<@+B`D='EP
M92D["B\O("`@("`@("`@?0HO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N
M(&5X86UP;&4@;V8@=&AE(%]I;7!?:&]O:U]F971C:&UA:6Q?9FEL=&5R(&9U
M;F-T:6]N('1O(')U;@HO+R!3<&%M07-S87-S:6X@;VX@96UA:6P@8F5F;W)E
M(&ET(&ES('=R:71T96X@=&\@=&AE(&UA:6QB;W@N"B\O($YO=&4Z('1O('5S
M92!T:&4@<W!A;6%S<V%S<VEN(&EN<W1E860@;V8@<W!A;60L(&-H86YG92`G
M<W!A;6,G('1O"B\O("=S<&%M87-S87-S:6X@+5`G(&%N9"!A9&0@86YY(&]T
M:&5R(&EM<&]R=&%N="!A<F=U;65N=',L(&)U="!R96%L:7IE('-P86UC"B\O
M(&ES($U50T@@9F%S=&5R('1H86X@<W!A;6%S<V%S<VEN+@HO+R!705).24Y'
M.B!-86ME('-U<F4@=&\@=7-E('1H92`M+6YO861D+69R;VT@9FEL=&5R(&]N
M('-P86UD(&]R('-P86UA<W-A<W-I;@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)U]I;7!?:&]O:U]F971C:&UA:6Q?9FEL=&5R)RDI('L*+R\@("`@(&9U
M;F-T:6]N(%]I;7!?:&]O:U]F971C:&UA:6Q?9FEL=&5R*"1M97-S86=E*0HO
M+R`@("`@>PHO+R`@("`@("`@("\O(%=H97)E(&1O97,@4W!A;4%S<V%S<VEN
M(&QI=F4L(&%N9"!W:&%T('5S97)N86UE('-H;W5L9"!W92!U<V4*+R\@("`@
M("`@("`O+R!F;W(@<')E9F5R96YC97,_"B\O("`@("`@("`@)&-M9"`]("<O
M=7-R+VQO8V%L+V)I;B]S<&%M8R<["B\O("`@("`@("`@)'5S97)N86UE(#T@
M075T:#HZ9V5T075T:"@I.PHO+R`@("`@("`@("\O($EF('EO=2!U<V4@=&AE
M(%]S86U?:&]O:U]U<V5R;F%M92@I(&AO;VLL('5N8V]M;65N="!T:&4@;F5X
M="!L:6YE"B\O("`@("`@("`@+R\D=7-E<FYA;64@/2!?<V%M7VAO;VM?=7-E
M<FYA;64H)'5S97)N86UE*3L*+R\@("`@("`@("`D=7-E<FYA;64@/2!E<V-A
M<&5S:&5L;&%R9R@D=7-E<FYA;64I.PHO+PHO+R`@("`@("`@("\O($%L<V\L
M('=E(')E;6]V92!T:&4@9FEL92!O=7)S96QV97,[('1H:7,@:&]O:R!M87D@
M8F4@8V%L;&5D"B\O("`@("`@("`@+R\@:'5N9')E9',@;V8@=&EM97,@<&5R
M(')U;B!D97!E;F1I;F<@;VX@:&]W(&UA;GD@;65S<V%G97,@=V4@9F5T8V@*
M+R\@("`@("`@("`D9FEL92`]($AO<F1E.CIG971496UP1FEL92@G:&]R9&4G
M+"!F86QS92D["B\O"B\O("`@("`@("`@+R\@0V%L;"!3<&%M07-S87-S:6X[
M('!I<&4@=&AE(&YE=R!M97-S86=E('1O(&]U<B!T96UP9FEL90HO+R`@("`@
M("`@("1F<"`]('!O<&5N*"(D8VUD("UU("1U<V5R;F%M92`^("1F:6QE(BP@
M)W<G*3L*+R\@("`@("`@("!F=W)I=&4H)&9P+"`D;65S<V%G92D["B\O("`@
M("`@("`@<&-L;W-E*"1F<"D["B\O"B\O("`@("`@("`@+R\@4F5A9"!T:&4@
M;F5W(&UE<W-A9V4@9G)O;2!T:&4@=&5M<&]R87)Y(&9I;&4*+R\@("`@("`@
M("`D;65S<V%G92`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L*+R\@("`@
M("`@("!U;FQI;FLH)&9I;&4I.PHO+R`@("`@("`@(')E='5R;B`D;65S<V%G
M93L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE('-I9VYA
M='5R92!H;V]K(&9U;F-T:6]N('1O('-E="!T:&4@<VEG;F%T=7)E(&9R;VT@
M=&AE"B\O('-Y<W1E;2!T86=L:6YE<R!F:6QE.R!T:&4@<W1R:6YG("(E5$%'
M)2(@*&EF('!R97-E;G0@:6X@82!U<V5R)W,@<VEG;F%T=7)E*0HO+R!W:6QL
M(&)E(')E<&QA8V5D(&)Y('1H92!C;VYT96YT(&]F('1H92!F:6QE("(O=7-R
M+W-H87)E+W1A9VQI;F4B("AG96YE<F%T960*+R\@8GD@=&AE(")485)4(B!U
M=&EL:71Y*2X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?
M<VEG;F%T=7)E)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]S:6=N
M871U<F4H)'-I9RD*+R\@("`@('L*+R\@("`@("`@("!I9B`H<')E9U]M871C
M:"@G+R5404<E+R<L("1S:6<I*2!["B\O("`@("`@("`@("`@("1T86<@/2!@
M8V%T("]U<W(O<VAA<F4O=&%G;&EN96`["B\O("`@("`@("`@("`@("1S:6<@
M/2!P<F5G7W)E<&QA8V4H)R\E5$%')2\G+"`D=&%G+"`D<VEG*3L*+R\@("`@
M("`@("!]"B\O"B\O("`@("`@("`@<F5T=7)N("1S:6<["B\O("`@("!]"B\O
M('T*"B\O(%1H:7,@:7,@86X@97AA;7!L92!H;V]K(&9U;F-T:6]N(&9O<B!T
M:&4@24U0(')E9&ER96-T:6]N('-C:&5M92X@5&AI<PHO+R!F=6YC=&EO;B!I
M<R!C86QL960@=VAE;B!T:&4@=7-E<B!O<&5N<R!A(&UA:6QB;W@@:6X@24U0
M+"!A;F0@86QL;W=S('1H90HO+R!C;&EE;G0@=&\@8F4@<F5D:7)E8W1E9"!B
M87-E9"!O;B!T:&4@;6%I;&)O>"!N86UE+B!4:&4@<F5T=7)N('9A;'5E(&]F
M('1H:7,*+R\@9G5N8W1I;VX@<VAO=6QD(&)E(&$@=F%L:60@<&%G92!W:71H
M:6X@82!H;W)D92!A<'!L:6-A=&EO;B!W:&EC:"!W:6QL(&)E"B\O('!L86-E
M9"!I;B!A("),;V-A=&EO;B(@:&5A9&5R('1O(')E9&ER96-T('1H92!C;&EE
M;G0N("!4:&4@;VYL>2!P87)A;65T97(*+R\@:7,@=&AE(&YA;64@;V8@=&AE
M(&UA:6QB;W@@=VAI8V@@=&AE('5S97(@:&%S(&]P96YE9"X@($EF(&%N(&5M
M<'1Y('-T<FEN9PHO+R!I<R!R971U<FYE9"!T:&4@=7-E<B!I<R!N;W0@<F5D
M:7)E8W1E9"X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?
M;6)O>%]R961I<F5C="<I*2!["B\O("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?
M;6)O>%]R961I<F5C="@D;6%I;&)O>"D*+R\@("`@('L*+R\@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O"B\O("`@("`@("`@
M:68@*'-T<G!O<R@D;6%I;&)O>"P@(DE.0D]8+T-A;&5N9&%R(BD@(3T](&9A
M;'-E"B\O("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=
M*R]#86QE;F1A<B$B+"`D;6%I;&)O>"DI('L*+R\@("`@("`@("`@("`@<F5T
M=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:W)O
M;F]L:71H)RD["B\O("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D;6%I;&)O
M>"P@(DE.0D]8+U1A<VMS(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@('Q\
M('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R]487-K<R$B+"`D;6%I;&)O>"DI
M('L*+R\@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)W=E8G)O;W0G+"`G;F%G)RD["B\O("`@("`@("`@?2!E;'-E:68@
M*'-T<G!O<R@D;6%I;&)O>"P@(DE.0D]8+TYO=&5S(BD@(3T](&9A;'-E"B\O
M("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R].;W1E
M<R$B+"`D;6%I;&)O>"DI('L*+R\@("`@("`@("`@("`@<F5T=7)N("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G;6YE;6\G*3L*+R\@
M("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1M86EL8F]X+"`B24Y"3U@O0V]N
M=&%C=',B*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@?'P@<')E9U]M871C
M:"@B(5YU<V5R+UM>+UTK+T-O;G1A8W1S(2(L("1M86EL8F]X*2D@>PHO+R`@
M("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M=V5B<F]O="<L("=T=7)B82<I.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@
M("!R971U<FX@)R<["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:7,@86X@97AA
M;7!L92!H;V]K(&9U;F-T:6]N(&9O<B!T:&4@24U0(&UA:6QB;W@@:6-O;B!S
M8VAE;64N(%1H:7,*+R\@9G5N8W1I;VX@:7,@8V%L;&5D('=H96X@=&AE(&9O
M;&1E<B!L:7-T(&ES(&-R96%T960@86YD(&$@(G-T86YD87)D(B!F;VQD97(*
M+R\@:7,@=&\@8F4@9&ES<&QA>65D("T@:70@86QL;W=S(&-U<W1O;2!F;VQD
M97(@:6-O;G,@=&\@8F4@<W!E8VEF:65D+@HO+R`H(E-T86YD87)D(B!M96%N
M<R!A;&P@9F]L9&5R<R!E>&-E<'0@=&AE($E.0D]8+"!S96YT+6UA:6P@9F]L
M9&5R<R!A;F0*+R\@=')A<V@@9F]L9&5R<RXI"B\O($EF(&$@;6%I;&)O>"!N
M86UE(&1O97-N)W0@87!P96%R(&EN('1H92!B96QO=R!L:7-T+"!T:&4@9&5F
M875L="!M86EL8F]X"B\O(&EC;VX@:7,@9&ES<&QA>65D+@H*+R\@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O:U]M8F]X7VEC;VYS)RDI('L*+R\@
M("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]M8F]X7VEC;VYS*"D*+R\@("`@('L*
M+R\@("`@("`@("!S=&%T:6,@)&YE=VUA:6QB;WAE<SL*+R\*+R\@("`@("`@
M("!I9B`H(65M<'1Y*"1N97=M86EL8F]X97,I*2!["B\O("`@("`@("`@("`@
M(')E='5R;B`D;F5W;6%I;&)O>&5S.PHO+R`@("`@("`@('T*+R\*+R\@("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O"B\O("`@
M("`@("`@)&MC(#T@;F5W($MO;&%B7T-Y<G5S*"1'3$]"04Q36R=C;VYF)UU;
M)VMO;&%B)UU;)W-E<G9E<B==*3L*+R\@("`@("`@("`D;6%I;&)O>&5S(#T@
M)&MC+3YL:7-T36%I;$)O>&5S*"D["B\O("`@("`@("`@)&YE=VUA:6QB;WAE
M<R`](&%R<F%Y*"D["B\O"B\O("`@("`@("`@9F]R96%C:"`H)&UA:6QB;WAE
M<R!A<R`D8F]X*2!["B\O("`@("`@("`@("`@("1B;W@@/2!P<F5G7W)E<&QA
M8V4H(B]>>UM>?5TK?2\B+"`B(BP@)&)O>"D["B\O("`@("`@("`@("`@(&EF
M("AS=')P;W,H)&)O>"P@(DE.0D]8+T-A;&5N9&%R(BD@(3T](&9A;'-E"B\O
M("`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O6UXO72LO
M0V%L96YD87(A(BP@)&)O>"DI('L*+R\@("`@("`@("`@("`@("`@("1N97=M
M86EL8F]X97-;)&)O>%T@/2!(;W)D93HZ:6UG*`HO+R`@("`@("`@("`@("`@
M("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G:W)O
M;F]L:71H)RDL"B\O("`@("`@("`@("`@("`@("`@("`@7R@B0V%L96YD87(B
M*2P*+R\@("`@("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0]
M(C$V(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B\O("`@("`@
M("`@("`@("`@("`@("`@)R<*+R\@("`@("`@("`@("`@("`@("D["B\O("`@
M("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&)O>"P@(DE.0D]8+U1A<VMS
M(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H
M*"(A7G5S97(O6UXO72LO5&%S:W,A(BP@)&)O>"DI('L*+R\@("`@("`@("`@
M("`@("`@("1N97=M86EL8F]X97-;)&)O>%T@/2!(;W)D93HZ:6UG*`HO+R`@
M("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)VEC;VXG+"`G;F%G)RDL"B\O("`@("`@("`@("`@("`@("`@("`@7R@B5&%S
M:W,B*2P*+R\@("`@("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG
M:'0](C$V(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B\O("`@
M("`@("`@("`@("`@("`@("`@)R<*+R\@("`@("`@("`@("`@("`@("D["B\O
M("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&)O>"P@(DE.0D]8+TYO
M=&5S(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@("`@("!\?"!P<F5G7VUA
M=&-H*"(A7G5S97(O6UXO72LO3F]T97,A(BP@)&)O>"DI('L*+R\@("`@("`@
M("`@("`@("`@("1N97=M86EL8F]X97-;)&)O>%T@/2!(;W)D93HZ:6UG*`HO
M+R`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG
M970H)VEC;VXG+"`G;6YE;6\G*2P*+R\@("`@("`@("`@("`@("`@("`@("!?
M*").;W1E<R(I+`HO+R`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B
M(&AE:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*
M+R\@("`@("`@("`@("`@("`@("`@("`G)PHO+R`@("`@("`@("`@("`@("`@
M*3L*+R\@("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D8F]X+"`B24Y"
M3U@O0V]N=&%C=',B*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@("`@('Q\
M('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R]#;VYT86-T<R$B+"`D8F]X*2D@
M>PHO+R`@("`@("`@("`@("`@("`@)&YE=VUA:6QB;WAE<ULD8F]X72`]($AO
M<F1E.CII;6<H"B\O("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G:6-O;B<L("=T=7)B82<I+`HO+R`@("`@("`@("`@
M("`@("`@("`@(%\H(D-O;G1A8W1S(BDL"B\O("`@("`@("`@("`@("`@("`@
M("`@)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E<G1I8V%L+6%L
M:6=N.FUI9&1L92(G+`HO+R`@("`@("`@("`@("`@("`@("`@("<G"B\O("`@
M("`@("`@("`@("`@("`I.PHO+R`@("`@("`@("`@("!]"B\O("`@("`@("`@
M?0HO+PHO+R`@("`@("`@(')E='5R;B`D;F5W;6%I;&)O>&5S.PHO+R`@("`@
M?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@:&]O:R!F=6YC=&EO;B!F
M;W(@=&AE($E-4"!S<&%M(')E<&]R=&EN9R!B;W5C92!O<'1I;VXN"B\O(%1H
M:7,@9G5N8W1I;VX@:7,@8V%L;&5D('=H96X@=&AE(&UE<W-A9V4@:7,@86)O
M=70@=&\@8F4@8F]U;F-E9"`M(&ET"B\O('=I;&P@<F5T=7)N('1H92!E;6%I
M;"!A9&1R97-S('1O(&)O=6YC92!T;RX@(%1H:7,@:7,@:&%N9'D@9F]R('-P
M86T*+R\@<F5P;W)T:6YG('-O9G1W87)E("AE+F<N($134$%-*2!W:&EC:"!H
M87,@9&EF9F5R96YT(&4M;6%I;"!A;&EA<V5S(&9O<@HO+R!S<&%M(')E<&]R
M=&EN9R!F;W(@96%C:"!U<V5R+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H
M)U]I;7!?:&]O:U]S<&%M7V)O=6YC92<I*2!["B\O("`@("!F=6YC=&EO;B!?
M:6UP7VAO;VM?<W!A;5]B;W5N8V4H)&%C=&EO;BD*+R\@("`@('L*+R\@("`@
M("`@("`D<')E9FEX(#T@*"1A8W1I;VX@/3T@)W-P86TG*2`_("=S<&%M+2<@
M.B`G9G`M)SL*+R\@("`@("`@("!R971U<FX@)'!R969I>"`N($%U=&@Z.F=E
M=$)A<F5!=71H*"D@+B`G0&5X86UP;&4N8V]M)SL*+R\@("`@('T*+R\@?0H*
M+R\@2&5R92!A;B!E>&%M<&QE(%]S86U?:&]O:U]U<V5R;F%M92!F=6YC=&EO
M;B!T;R!S970@=&AE('5S97)N86UE('1H870*+R\@4W!A;4%S<V%S<VEN('-E
M97,@=&\@;VYE(&1I9F9E<F5N="!F<F]M('1H92!(;W)D92!U<V5R;F%M92X*
M"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<V%M7VAO;VM?=7-E<FYA;64G
M*2D@>PHO+R`@("`@9G5N8W1I;VX@7W-A;5]H;V]K7W5S97)N86UE*"1H;W)D
M95]U:60I"B\O("`@("!["B\O("`@("`@("`@:68@*'-T<G-T<B@D:&]R9&5?
M=6ED+"`G0"<I*2!["B\O("`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H
M)T`G+"`D:&]R9&5?=6ED*3L*+R\@("`@("`@("`@("`@<F5T=7)N("1P87)T
M<ULP73L*+R\@("`@("`@("!](&5L<V4@>PHO+R`@("`@("`@("`@("!R971U
M<FX@)&AO<F1E7W5I9#L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O
M($AE<F4@:7,@86X@97AA;7!L92!?='5R8F%?:&]O:U]E;F-O9&5?<&%S<W=O
M<F0@*&%N9"!D96-O9&4I+B!E;F-O9&4@:7,*+R\@8V%L;&5D('=H96X@=V4@
M<W1O<F4@82!V86QU93L@9&5C;V1E('=H96X@=V4@9&ES<&QA>2!I="X@(%!A
M<W-W;W)D<R!S:&]U;&0*+R\@8F4@340U(&5N8V]D960L(&)U="!N;W0@9&ES
M<&QA>65D+@HO+PHO+R!)35!/4E1!3E0Z(%1H92!L87-T('!A<F%M971E<B!I
M;B!T:&5S92!E>&%M<&QE<R`H)B1O8FIE8W0I(&ES(&]N;'D*+R\@<&%S<V5D
M(&)Y(%1U<F)A(#(N,2!A;F0@;&%T97(N($EF('EO=2!A<F4@=7-I;F<@5'5R
M8F$@,BXP+"!T:&5N('EO=0HO+R!M=7-T(')E;6]V92!T:&4@)B1O8FIE8W0@
M<&%R86UE=&5R+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]T=7)B85]H
M;V]K7V5N8V]D95]P87-S=V]R9"<I*2!["B\O("`@("!F=6YC=&EO;B!?='5R
M8F%?:&]O:U]E;F-O9&5?<&%S<W=O<F0H)&YE=U]P87-S=V]R9"P@)&]L9%]P
M87-S=V]R9"P@)B1C;VYT86-T*0HO+R`@("`@>PHO+R`@("`@("`@(&EF("AI
M<U]N=6QL*"1N97=?<&%S<W=O<F0I('Q\("1N97=?<&%S<W=O<F0@/3T@)R<@
M?'P*+R\@("`@("`@("`@("`@)&YE=U]P87-S=V]R9"`]/2`G6TYO="!$:7-P
M;&%Y961=)RD@>PHO+R`@("`@("`@("`@("!R971U<FX@)&]L9%]P87-S=V]R
M9#L*+R\@("`@("`@("!](&5L<V4@>PHO+R`@("`@("`@("`@("!R971U<FX@
M;60U*"1N97=?<&%S<W=O<F0I.PHO+R`@("`@("`@('T*+R\@("`@('T*+R\@
M("`@(&9U;F-T:6]N(%]T=7)B85]H;V]K7V1E8V]D95]P87-S=V]R9"@D<&%S
M<W=O<F0L("8D8V]N=&%C="D*+R\@("`@('L*+R\@("`@("`@("!I9B`H<W1R
M<W1R*"1?4T525D526R=02%!?4T5,1B==+"`G961I=&]B:F5C="<I*2!["B\O
M("`@("`@("`@("`@(')E='5R;B!N=6QL.PHO+R`@("`@("`@('T@96QS92![
M"B\O("`@("`@("`@("`@(')E='5R;B`G6TYO="!$:7-P;&%Y961=)SL*+R\@
M("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L
M92!?<&%S<W=D7VAO;VM?=7-E<FYA;64@9G5N8W1I;VX@=&\@=')A;G-L871E
M('=H870@=&AE"B\O('5S97(@96YT97)S+"!I;B!T:&4@=7-E<FYA;64@8F]X
M+"!I;G1O('=H870@=&AE(&)A8VME;F0@97AP96-T<RX@268@=V4@=V%N=`HO
M+R!T;R!A9&0@0&5X86UP;&4N8V]M('1O('1H92!E;F0@;V8@=&AE('5S97)N
M86UE('1H96X@96YA8FQE('1H92!H;V]K(&%N9"!U<V4*+R\@=&AI<R!F=6YC
M=&EO;BX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<&%S<W=D7VAO;VM?
M=7-E<FYA;64G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!A<W-W9%]H;V]K7W5S
M97)N86UE*"1U<V5R:60I"B\O("`@("!["B\O("`@("`@("`@<F5T=7)N("1U
M<V5R:60@+B`G0&5X86UP;&4N8V]M)SL*+R\@("`@('T*+R\@?0H*+R\@2&5R
M92!I<R!A;B!E>&%M<&QE(%]P87-S=V1?:&]O:U]D969A=6QT7W5S97)N86UE
M(&9U;F-T:6]N('1O('-E="!T:&4*+R\@=7-E<FYA;64@=&AE('!A<W-W9"!M
M;V1U;&4@<V5E<R!W:&5N(')E<V5T=&EN9R!P87-S=V]R9',@8F%S960@;VX@
M=7-E<FED"B\O(&%N9"!R96%L;2X@(%1H92!D969A=6QT(&ES('1O('1A:V4@
M82!U<V5R;F%M92!O9B!U<V5R0&1O;6%I;BYT;&0@86YD(&-H86YG90HO+R!I
M="!T;R!U<V5R+B`@268@=V4@=V%N="!T;R!L96%V92!I="!U;G1O=6-H960L
M(&5N86)L92!T:&4@:&]O:R!A;F0@=7-E('1H:7,*+R\@9G5N8W1I;VXN"@HO
M+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!A<W-W9%]H;V]K7V1E9F%U;'1?
M=7-E<FYA;64G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!A<W-W9%]H;V]K7V1E
M9F%U;'1?=7-E<FYA;64H)'5S97)I9"D*+R\@("`@('L*+R\@("`@("`@("!R
M971U<FX@)'5S97)I9#L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E
M>&%M<&QE(%]P87-S=V1?:&]O:U]U<V5R9&X@9G5N8W1I;VX@=&AA="!Y;W4@
M8V%N('5S92!T;R!P<F]V:61E"B\O('EO=7(@;&1A<"!S97)V97(@=VET:"!A
M('5S97)D;B!S;R!T:&%T('EO=2!D;R!N;W0@:&%V92!T;R!P97)F;W)M(&%N
M;VYY;6]U<PHO+R!B:6YD<RX@5&AE(&9U;F-T:6]N('1A:V5S($%U=&@Z.F=E
M=$%U=&@H*2!A<R!A('!A<F%M971E<@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)U]P87-S=V1?:&]O:U]U<V5R9&XG*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7W!A<W-W9%]H;V]K7W5S97)D;B@D875T:"D*+R\@("`@('L*+R\@("`@("`@
M("!R971U<FX@)W5I9#TG("X@)&%U=&@@+B`G+&\]97AA;7!L92YC;VTG.PHO
M+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@;V8@82!H;V]K
M('1O('-E="!C=7-T;VT@=&%G<R!T;R!B92!I;F-L=61E9"!I;B!A($=I87!E
M=&\*+R\@<&%G92!T96UP;&%T92X@26X@=&AI<R!E>&%M<&QE(&$@=&%G(&-O
M;G1A:6YI;F<@=&AE(&-U<G)E;G0@9&%T92!I<R!S970@=&\*+R\@=&AE("1T
M96UP;&%T92!O8FIE8W0@86YD('=H:6-H(&ES('1H96X@879A:6QA8FQE(&EN
M('1H92!P86=E('1E;7!L871E(&%S.@HO+R`@("`@/'1A9SID871E("\^"@HO
M+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7V=I87!E=&]?:&]O:U]S971T86=S
M)RDI('L*+R\@("`@(&9U;F-T:6]N(%]G:6%P971O7VAO;VM?<V5T=&%G<R@F
M)'1E;7!L871E*0HO+R`@("`@>PHO+R`@("`@("`@("1T96UP;&%T92T^<V5T
M*"=D871E)RP@<W1R9G1I;64H)R5A+"`E92`E8B`E62<I*3L*+R\@("`@('T*
M+R\@?0H*+R\@5&AI<R!I<R!A;B!E>&%M<&QE(&]F(&$@9W)O=7`@:&]O:RX@
M(%1O('5S92!I="!Y;W4@;75S="!S970@=&AE(&=R;W5P"B\O(&1R:79E<B!T
M;R!H;V]K<R!I;B!C;VYF+G!H<"X@(%1H96X@>6]U(&UU<W0@8W)E871E(&$@
M251?9&5P87)T;65N="!G<F]U<`HO+R`H8F5C875S92!T:&%T(&ES(&AO=R!W
M92!K;F]W('=H870@:&]O:R!T;R!C86QL*2X@(%EO=2!C86X@861D('5S97)S
M('1O('1H90HO+R!G<F]U<"!A<R!N;W)M86PL(&%N9"!I;B!A9&1I=&EO;B!T
M:&ES(&9U;F-T:6]N('=I;&P@8F4@8V%L;&5D('1O"B\O(&1Y;F%M:6-A;&QY
M(&EN8VQU9&4@=7-E<G,@:6X@=&AE(&=R;W5P+B`@26X@=&AI<R!E>&%M<&QE
M('=E('=I;&P@;&]O:R!U<`HO+R!W:&5T:&5R(&]R(&YO="!T:&ES('5S97(@
M:7,@<&%R="!O9B!T:&4@250@9&5P87)T;65N="!U<VEN9R!A;B!E>'1E<FYA
M;`HO+R!D871A8F%S92X*"B\O($1E9F%U;'0@2V]L86(@:&]O:W,Z"FEF("@A
M96UP='DH)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG96YA8FQE9"==*2D@
M>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]+;VQA8BYP:'`G.PH@("`@:68@
M*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H87)E7VEN:70G*2D@
M>PH@("`@("`@(&9U;F-T:6]N(%]U<V5R;F%M95]H;V]K7V9R;VUB86-K96YD
M*"1U<V5R240I"B`@("`@("`@>PH@("`@("`@("`@("`O+R!#;VYN96-T('1O
M('1H92!,1$%0('-E<G9E<BX*("`@("`@("`@("`@)&1S(#T@;&1A<%]C;VYN
M96-T*`H@("`@("`@("`@("`@("`@)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G
M75LG;&1A<"==6R=S97)V97(G72P*("`@("`@("`@("`@("`@("1'3$]"04Q3
M6R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG<&]R="=="B`@("`@("`@("`@
M("D["B`@("`@("`@("`@(&EF("@A)&1S*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'5S97))1#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!L9&%P
M7W-E=%]O<'1I;VXH)&1S+"!,1$%07T]05%]04D]43T-/3%]615)324].+"`S
M*3L*("`@("`@("`@("`@+R\@0FEN9"!A;F]N>6UO=7-L>2X*("`@("`@("`@
M("`@)')E<W5L="`]($!L9&%P7V)I;F0H)&1S*3L*("`@("`@("`@("`@:68@
M*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'5S97))1#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`O+R!&:6YD('1H92!U<V5R)W,@
M1$XN"B`@("`@("`@("`@("1R97-U;'0@/2!L9&%P7W-E87)C:"@*("`@("`@
M("`@("`@("`@("1D<RP*("`@("`@("`@("`@("`@("1'3$]"04Q36R=C;VYF
M)UU;)VMO;&%B)UU;)VQD87`G75LG8F%S961N)UTL"B`@("`@("`@("`@("`@
M("`G=6ED/2<@+B`D=7-E<DE$"B`@("`@("`@("`@("D["B`@("`@("`@("`@
M("1E;G1R>2`](&QD87!?9FER<W1?96YT<GDH)&1S+"`D<F5S=6QT*3L*("`@
M("`@("`@("`@:68@*"1E;G1R>2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("\O(%1H92!U<V5R(&%L<F5A9'D@875T:&5N=&EC871E9"!W:71H(&AI
M<R!E;6%I;"!A9&1R97-S+@H@("`@("`@("`@("`@("`@<F5T=7)N("1U<V5R
M240["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5M86EL(#T@;&1A<%]G
M971?=F%L=65S*"1D<RP@)&5N=')Y+"`G;6%I;"<I.PH@("`@("`@("`@("!R
M971U<FX@)&5M86EL6S!=.PH@("`@("`@('T*("`@("`@("!F=6YC=&EO;B!?
M:&]R9&5?:&]O:U]S:&%R95]I;FET*"8D<VAA<F5?;V)J96-T+"`D87!P*0H@
M("`@("`@('L*("`@("`@("`@("`@2V]L86(Z.G-Y;F-H<F]N:7-E4VAA<F5S
M*"1S:&%R95]O8FIE8W0L("1A<'`I.PH@("`@("`@('T*("`@("`@("!F=6YC
M=&EO;B!?:&]R9&5?:&]O:U]S:&%R95]A9&0H)B1S:&%R92D*("`@("`@("![
M"B`@("`@("`@("`@(')E='5R;B!+;VQA8CHZ=7!D871E4VAA<F4H)'-H87)E
M*3L*("`@("`@("!]"B`@("`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA
M<F5?;6]D:69Y*"8D<VAA<F4I"B`@("`@("`@>PH@("`@("`@("`@("!R971U
M<FX@2V]L86(Z.G5P9&%T95-H87)E*"1S:&%R92D["B`@("`@("`@?0H@("`@
M("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7W)E;6]V92@F)'-H87)E
M*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N($MO;&%B.CIR96UO=F53
M:&%R92@D<VAA<F4I.PH@("`@("`@('T*("`@("`@("!F=6YC=&EO;B!?:6UP
M7VAO;VM?;6)O>%]R961I<F5C="@D;6%I;&)O>"D*("`@("`@("!["B`@("`@
M("`@("`@('-W:71C:"`H2V]L86(Z.F=E=$UA:6QB;WA4>7!E*"1M86EL8F]X
M*2D@>PH@("`@("`@("`@("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@
M("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L
M("=K<F]N;VQI=&@G*3L*"B`@("`@("`@("`@(&-A<V4@)W1A<VLG.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)W=E8G)O;W0G+"`G;F%G)RD["@H@("`@("`@("`@("!C87-E("=N;W1E)SH*
M("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=W96)R;V]T)RP@)VUN96UO)RD["@H@("`@("`@("`@("!C87-E("=C
M;VYT86-T)SH*("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)W1U<F)A)RD["@H@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]M
M8F]X7VEC;VYS*"D*("`@("`@("!["B`@("`@("`@("`@('-T871I8R`D:6-O
M;G,["@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1I8V]N<RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D:6-O;G,["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1F;VQD97)S(#T@2V]L86(Z.FQI<W1&;VQD97)S*"D["@H@("`@
M("`@("`@("`D:6-O;G,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@9F]R96%C
M:"`H)&9O;&1E<G,@87,@)&9O;&1E<BD@>PH@("`@("`@("`@("`@("`@)&YA
M;64@/2!P<F5G7W)E<&QA8V4H)R]>>UM>?5TK?2\G+"`G)RP@)&9O;&1E<ELP
M72D["@H@("`@("`@("`@("`@("`@<W=I=&-H("@D9F]L9&5R6S%=*2!["B`@
M("`@("`@("`@("`@("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@("`@
M("`@)&EC;VYS6R1N86UE72`]($AO<F1E.CII;6<H"B`@("`@("`@("`@("`@
M("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G
M:W)O;F]L:71H)RDL"B`@("`@("`@("`@("`@("`@("`@("`@(%\H(D-A;&5N
M9&%R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B(&AE
M:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)R<*("`@("`@("`@("`@("`@("`@("`I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)W1A<VLG.@H@("`@("`@("`@("`@("`@("`@("1I8V]N<ULD;F%M
M95T@/2!(;W)D93HZ:6UG*`H@("`@("`@("`@("`@("`@("`@("`@("`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=I8V]N)RP@)VYA9R<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("!?*")487-K<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB=F5R=&EC
M86PM86QI9VXZ;6ED9&QE(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<G
M"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=N;W1E)SH*("`@("`@("`@
M("`@("`@("`@("`D:6-O;G-;)&YA;65=(#T@2&]R9&4Z.FEM9R@*("`@("`@
M("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M:6-O;B<L("=M;F5M;R<I+`H@("`@("`@("`@("`@("`@("`@("`@("!?*").
M;W1E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H
M96EG:'0](C$V(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<G"B`@("`@("`@("`@("`@("`@("`@
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("=C;VYT86-T)SH*("`@("`@("`@("`@("`@("`@("`D:6-O;G-;
M)&YA;65=(#T@2&]R9&4Z.FEM9R@*("`@("`@("`@("`@("`@("`@("`@("`@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G:6-O;B<L("=T=7)B82<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("!?*")#;VYT86-T<R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL
M93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("<G"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@<F5T=7)N("1I8V]N<SL*("`@("`@("!]"B`@("!]
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+V-O;F8N>&UL````````````
M````````````````````````````````````````````````````````````
M```P,3`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(P-#$R,P`Q,#4Q-30S
M,3`W,``P,3<W,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H
M;W)D92]C;VYF:6<O8V]N9BYX;6PL=B`Q+C<T+C(N-#$@,C`P-B\P."\P-"`Q
M-SHQ,SHR-2!J86X@17AP("0@+2T^"CQC;VYF:6=U<F%T:6]N/@H@/&-O;F9I
M9W1A8B!N86UE/2)G96YE<F%L(B!D97-C/2)'96YE<F%L(CX*("`\8V]N9FEG
M:&5A9&5R/D=E;F5R86P@2&]R9&4@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*
M("`\8V]N9FEG<&AP(&YA;64](F1E8G5G7VQE=F5L(B!D97-C/2)4:&4@=F%L
M=64@=&\@<V5T"B`@97)R;W)?<F5P;W)T:6YG*"D@=&\N"B`@4V5E(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO9G5N8W1I;VXN97)R;W(M<F5P;W)T:6YG
M+G!H<"!F;W(@;6]R90H@(&EN9F]R;6%T:6]N(&%N9"!P;W-S:6)L92!V86QU
M97,N(CY%7T%,3"`F86UP.R!^15].3U1)0T4\+V-O;F9I9W!H<#X*("`\8V]N
M9FEG:6YT96=E<B!N86UE/2)M87A?97AE8U]T:6UE(B!D97-C/2))9B!W92!N
M965D('1O('!E<F9O<FT@82!L;VYG"B`@;W!E<F%T:6]N+"!W:&%T('-H;W5L
M9"!W92!S970@;6%X7V5X96-U=&EO;E]T:6UE('1O("AI;B!S96-O;F1S*3\@
M,"!M96%N<R!N;PH@(&QI;6ET.R!H;W=E=F5R+"!A('9A;'5E(&]F(#`@=VEL
M;"!C875S92!A('=A<FYI;F<@:68@>6]U(&%R92!R=6YN:6YG(&EN('-A9F4*
M("!M;V1E+B!3964@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]F=6YC=&EO
M;BYS970M=&EM92UL:6UI="YP:'`@9F]R(&UO<F4*("!I;F9O<FUA=&EO;BXB
M/C`\+V-O;F9I9VEN=&5G97(^"B`@/&-O;F9I9V5N=6T@;F%M93TB=7-E7W-S
M;"(@<75O=&4](F9A;'-E(B!D97-C/2)$971E<FUI;F5S(&AO=R!W92!G96YE
M<F%T90H@(&9U;&P@55),<R`H9F]R(&QO8V%T:6]N(&AE861E<G,@86YD('-U
M8V@I+B9L=#MB<B`O)F=T.TY/5$4Z($EF('EO=2!C:&]O<V4@=&\*("!A;'=A
M>7,@9V5N97)A=&4@:'1T<',@55),<RP@>6]U($U54U0@:&%R9&-O9&4@=&AE
M(&-O<G)E8W0@2%144%,@<&]R="!N=6UB97(*("!I;B!T:&4@<V5R=F5R('!O
M<G0@<V5T=&EN9R!B96QO=RX@3W1H97)W:7-E($AO<F1E('=I;&P@8F4@=6YA
M8FQE('1O(&=E;F5R871E"B`@8V]R<F5C="!(5%104R!54DQS('=H96X@82!U
M<V5R('1R:65S('1O(&%C8V5S<R!(;W)D92!V:6$@82!N;VXM2%144%,@<&]R
M="XB/C(*("`@/'9A;'5E<SX*("`@(#QV86QU92!D97-C/2)!<W-U;64@=&AA
M="!W92!A<F4@;F]T('5S:6YG(%-33"!A;F0@;F5V97(@9V5N97)A=&4@:'1T
M<',@55),<RXB/C`\+W9A;'5E/@H@("`@/'9A;'5E(&1E<V,](D%S<W5M92!T
M:&%T('=E(&%R92!U<VEN9R!34TP@86YD(&%L=V%Y<R!G96YE<F%T92!H='1P
M<R!54DQS+B(^,3PO=F%L=64^"B`@("`\=F%L=64@9&5S8STB071T96UP="!T
M;R!A=71O+61E=&5C="P@86YD(&=E;F5R871E(%523',@87!P<F]P<FEA=&5L
M>2(^,CPO=F%L=64^"B`@("`\=F%L=64@9&5S8STB07-S=6UE('1H870@=V4@
M87)E(&YO="!U<VEN9R!34TP@86YD(&=E;F5R871E(&AT='!S(%523',@;VYL
M>0H@("`@9F]R(&QO9VEN+B(^,SPO=F%L=64^"B`@(#PO=F%L=65S/@H@(#PO
M8V]N9FEG96YU;3X*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S97)V97(B/@H@
M("`\8V]N9FEG<&AP(&YA;64](FYA;64B(&1E<V,](E=H870@<V5R=F5R(&YA
M;64@<VAO=6QD('=E('5S93\@66]U)VQL('!R;V)A8FQY"B`@(&MN;W<@:68@
M>6]U(&YE960@=&\@8VAA;F=E('1H:7,@9&5F875L=#L@;VYL>2!I;B!S:71U
M871I;VYS('=H97)E('EO=2!N965D('1O"B`@(&]V97)R:61E('=H870@07!A
M8VAE('1H:6YK<R!T:&4@<V5R=F5R(&YA;64*("`@:7,N(CXD7U-%4E9%4ELG
M4T525D527TY!344G73PO8V]N9FEG<&AP/@H@("`\8V]N9FEG<&AP(&YA;64]
M(G!O<G0B(&1E<V,](E=H870@<&]R="!N=6UB97(@:7,@=&AE('=E8G-E<G9E
M<B!R=6YN:6YG(&]N/PH@("!!9V%I;BP@>6]U('-H;W5L9&XG="!N965D('1O
M(&-H86YG92!T:&4@9&5F875L="P@86YD('EO=2!P<F]B86)L>2!K;F]W(&ET
M(&EF"B`@('EO=2!D;RX@5&AE(&5X8V5P=&EO;B!I<R!I9B!Y;W4@:&%V92!C
M:&]S96X@=&\@86QW87ES(&=E;F5R871E(&AT='!S(%523',L(&%S"B`@(&1E
M<V-R:6)E9"!A8F]V92XB/B1?4T525D526R=315)615)?4$]25"==/"]C;VYF
M:6=P:'`^"B`@/"]C;VYF:6=S96-T:6]N/@H@(#QC;VYF:6=B;V]L96%N(&YA
M;64](F-O;7!R97-S7W!A9V5S(B!D97-C/2))9B!T:&ES(&]P=&EO;B!I<R!S
M970@=&\@=')U92P@86YD"B`@>6]U(&AA=F4@=&AE('!H<"!Z;&EB(&5X=&5N
M<VEO;BP@<&%G97,@;W9E<B!A(&-E<G1A:6X@<VEZ92!W:6QL(&)E(&-O;7!R
M97-S960*("!A;F0@<V5N="!T;R!T:&4@8G)O=W-E<B!A<R!G>FEP+65N8V]D
M960@9&%T82!I;B!O<F1E<B!T;R!S879E"B`@8F%N9'=I9'1H+B!4:&5R92!I
M<R!A($-052UU<V%G92!P96YA;'1Y('1O('!A>2!F;W(@=&AI<RP@8G5T('1H
M92!D96-R96%S92!I;@H@('!A9V4@<VEZ92!C86X@8F4@9')A;6%T:6,@*#<P
M:R!T;R!U;F1E<B`Q,&L@9F]R(&$@9G5L;"!M86EL8F]X('!A9V4I+"!A;F0@
M:7,*("!M;W)E('1H86X@=V]R=&@@:70@;W9E<B!A;GET:&EN9R!B=70@86X@
M97AT<F5M96QY(&9A<W0*("!L:6YK+B(^=')U93PO8V]N9FEG8F]O;&5A;CX*
M("`\8V]N9FEG:6YT96=E<B!N86UE/2)U;6%S:R(@;V-T86P](G1R=64B(&1E
M<V,](E=H870@=6UA<VL@<VAO=6QD('=E(')U;B!W:71H/R!4:&ES('=I;&P@
M869F96-T('1H92!P97)M:7-S:6]N<R!O;B!A;GD@=&5M<&]R87)Y(&9I;&5S
M('1H870@87)E(&-R96%T960N(%1H:7,@=F%L=64@:7,@86X@:6YT96=E<BXB
M/C`W-SPO8V]N9FEG:6YT96=E<CX*("`\8V]N9FEG<W1R:6YG(&YA;64](G1M
M<&1I<B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2))9B!Y;W4@=V%N="!T;R!U
M<V4@80H@('1E;7!O<F%R>2!D:7)E8W1O<GD@;W1H97(@=&AA;B!T:&4@<WES
M=&5M(&1E9F%U;'0@;W(@=&AE(&]N92!S<&5C:69I960@:6X*("!P:'`G<R!U
M<&QO861?=&UP7V1I<B!V86QU92P@96YT97(@:70@:&5R92XB+SX*("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)S97-S:6]N(CX*("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)N86UE(B!D97-C/2)7:&%T(&YA;64@<VAO=6QD('=E('5S92!F;W(@
M=&AE('-E<W-I;VX@=&AA=`H@("!(;W)D92!A<'!S('-H87)E/R!)9B!Y;W4@
M=V%N="!T;R!S:&%R92!S97-S:6]N<R!W:71H(&]T:&5R(&%P<&QI8V%T:6]N
M<R!O;@H@("!Y;W5R('=E8G-E<G9E<BP@>6]U('=I;&P@;F5E9"!T;R!M86ME
M('-U<F4@=&AA="!T:&5Y(&%R92!U<VEN9R!T:&4@<V%M90H@("!S97-S:6]N
M(&YA;64N("!.;W1E.B!397-S:6]N(&YA;65S(&UU<W0@8V]N<VES="!O9B!O
M;FQY(&%L<&AA;G5M97)I8PH@("!C:&%R86-T97)S+B(^2&]R9&4\+V-O;F9I
M9W-T<FEN9SX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB=7-E7V]N;'E?8V]O
M:VEE<R(@9&5S8STB4VAO=6QD('=E(&]N;'D@86QL;W<@<V5S<VEO;@H@("!I
M;F9O<FUA=&EO;B!T;R!B92!S=&]R960@:6X@82!S97-S:6]N(&-O;VMI92!A
M;F0@;F]T(&)E('!A<W-E9"!B>2!54DP@*$=%5"D*("`@<&%R86UE=&5R<S\@
M5&AI<R!I<R!O;B!B>2!D969A=6QT(&)E8V%U<V4@<&%S<VEN9R!S97-S:6]N
M(&EN9F]R;6%T:6]N(&EN"B`@('1H92!54DP@:7,@82!S96-U<FET>2!R:7-K
M+B!#;VYS:61E<B!C87)E9G5L;'D@8F5F;W)E('1U<FYI;F<@:70@;V9F+B(^
M"B`@('1R=64\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB8V%C:&5?;&EM:71E<B(@9&5S8STB5VAA="!C86-H:6YG(&QE=F5L('-H
M;W5L9"!W92!U<V4*("`@9F]R('1H92!S97-S:6]N/R!$3R!.3U0@0TA!3D=%
M(%1(25,@54Y,15-3(%E/52`F;'0[<W1R;VYG)F=T.U)%04Q,629L=#LO<W1R
M;VYG)F=T.R!+3D]7"B`@(%=(050@64]5($%212!$3TE.1RX@4V5T=&EN9R!T
M:&ES('1O(&%N>71H:6YG(&]T:&5R('1H86X@)VYO8V%C:&4G('=I;&P@86QM
M;W-T"B`@(&-E<G1A:6YL>2!R97-U;'0@:6X@<V5V97)E;'D@8G)O:V5N('-C
M<FEP="!B96AA=FEO<BXB/FYO8V%C:&4\+V-O;F9I9W-T<FEN9SX*("`@/&-O
M;F9I9VEN=&5G97(@;F%M93TB=&EM96]U="(@9&5S8STB2&]W(&QO;F<@<VAO
M=6QD('-E<W-I;VYS(&QA<W0@*&EN('-E8V]N9',I/R`P(&UE86YS"B`@('1H
M870@=&AE('-E<W-I;VX@96YD<R!W:&5N('1H92!U<V5R(&-L;W-E<R!T:&5I
M<B!B<F]W<V5R+B!3970@;W1H97(@=F%L=65S"B`@('=I=&@@8V%R92`M('-E
M90H@("!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G-E
M<W-I;VXM<V5T+6-O;VMI92UP87)A;7,N<&AP+B(^,#PO8V]N9FEG:6YT96=E
M<CX*("`\+V-O;F9I9W-E8W1I;VX^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M8V]O:VEE(CX*("`@/&-O;F9I9W!H<"!N86UE/2)D;VUA:6XB(&1E<V,](E=H
M870@9&]M86EN('-H;W5L9"!W92!S970@8V]O:VEE<R!F<F]M/R!)9@H@("!Y
M;W4@:&%V92!A(&-L=7-T97(@=&AA="!N965D<R!T;R!S:&%R92!C;V]K:65S
M+"!T:&ES(&UI9VAT(&)E("<N97AA;7!L92YC;VTG"B`@("T@=&AE(&QE861I
M;F<@)RXG(&ES(&EM<&]R=&%N="X@36]S="!L:6ME;'DL('1H;W5G:"P@>6]U
M('=O;B=T(&AA=F4@=&\@8VAA;F=E"B`@('1H92!D969A=6QT+B(^)%]315)6
M15);)U-%4E9%4E].04U%)UT\+V-O;F9I9W!H<#X*("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)P871H(B!D97-C/2)7:&%T('!A=&@@<VAO=6QD('=E('-E="!C
M;V]K:65S('1O/R!4:&ES"B`@('-H;W5L9"!M871C:"!W:&5R92!(;W)D92!I
M<R!O;B!Y;W5R('=E8G-E<G9E<B`M(&EF(&ET(&ES(&%T("]H;W)D92P@=&AE
M;B!T:&ES"B`@('-H;W5L9"!B92`G+VAO<F1E)RX@268@2&]R9&4@:7,@:6YS
M=&%L;&5D(&%S('1H92!D;V-U;65N="!R;V]T+"!T:&5N('1H:7,*("`@;F5E
M9',@=&\@8F4@)R\G("T@3D]4("<G+B9L=#MB<B`O)F=T.R9L=#MS=')O;F<F
M9W0[0E54)FQT.R]S=')O;F<F9W0[+"!I9B!)12!W:6QL(&)E"B`@('5S960@
M=&\@86-C97-S($AO<F1E(&UO9'5L97,L('EO=2!S:&]U;&0@<F5A9"!T:&ES
M(&9I<G-T("AD:7-C=7-S:6YG(&ES<W5E<PH@("!W:71H($E%)W,@0V]N=&5N
M="!!9'9I<V]R*3H*("`@:'1T<#HO+VQI<W1S+FAO<F1E+F]R9R]A<F-H:79E
M<R]I;7`O5V5E:RUO9BU-;VXM,C`P,S`Q,3,O,#(Y,30Y+FAT;6PB/B]H;W)D
M93PO8V]N9FEG<W1R:6YG/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG
M=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB<W%L(B!D97-C/2)$871A8F%S92(^
M"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<W%L(CX*("`@/&-O;F9I9VAE861E
M<CY(;W)D92!$871A8F%S92!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H@("`\
M8V]N9FEG9&5S8W)I<'1I;VX^)FQT.W-T<F]N9R9G=#M.3U1%.B9L=#LO<W1R
M;VYG)F=T.R!4:&5S92!A<F4@;VYL>2!T:&4*("`@)FQT.V5M)F=T.V1E9F%U
M;'0F;'0[+V5M)F=T.R!V86QU97,@9F]R(&%N>2!D871A8F%S92!D<FEV96X@
M8F%C:V5N9',N(%EO=0H@("!S=&EL;"!N965D('1O(&-O;F9I9W5R92!T:&4@
M9&EF9F5R96YT('-Y<W1E;7,@;&EK92`B4')E9F5R96YC97,B(&]R"B`@(")$
M871A5')E92(@=&\@86-T=6%L;'D@)FQT.V5M)F=T.W5S929L=#LO96TF9W0[
M(&$@9&%T86)A<V4*("`@8F%C:V5N9"X\+V-O;F9I9V1E<V-R:7!T:6]N/@H@
M("`\8V]N9FEG<W%L('-W:71C:&YA;64](G!H<'1Y<&4B(&)A<V5C;VYF:6<]
M(G1R=64B("\^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@
M/&-O;F9I9W1A8B!N86UE/2)A=71H(B!D97-C/2)!=71H96YT:6-A=&EO;B(^
M"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB875T:"(^"B`@(#QC;VYF:6=H96%D
M97(^2&]R9&4@075T:&5N=&EC871I;VX\+V-O;F9I9VAE861E<CX*("`@/&-O
M;F9I9VQI<W0@;F%M93TB861M:6YS(B!D97-C/2)7:&EC:"!U<V5R<R!S:&]U
M;&0@8F4@=')E871E9"!A<PH@("!A9&UI;FES=')A=&]R<R`H<F]O="P@<W5P
M97(M=7-E<BD@8GD@2&]R9&4_(B!R97%U:7)E9#TB9F%L<V4B+SX*("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB8VAE8VMI<"(@9&5S8STB4VAO=6QD('=E(&%L
M=V%Y<R!S=&]R92!A;F0@=F%L:61A=&4*("`@=&AE($E0(&%D9')E<W,@;V8@
M=&AE(&-L:65N="`H87,@<V5E;B!B>2!T:&4@=V5B('-E<G9E<BD@:6X@=&AE
M('-E<W-I;VX_"B`@($1O:6YG('-O('=I;&P@:&5L<"!I;F-R96%S92!S96-U
M<FET>2!B>2!E;G-U<FEN9R!T:&%T(&%N(&%T=&%C:V5R(&9R;VT*("`@86YO
M=&AE<B!H;W-T(&-A;FYO="!T<GD@=&\@:&EJ86-K('1H92!S97-S:6]N+B(^
M=')U93PO8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB
M8VAE8VMB<F]W<V5R(B!D97-C/2)3:&]U;&0@=V4@86QW87ES('-T;W)E(&%N
M9"!V86QI9&%T90H@("!T:&4@8G)O=W-E<B!S=')I;F<@;V8@=&AE(&-L:65N
M="`H87,@<V5E;B!B>2!T:&4@=V5B('-E<G9E<BD@:6X@=&AE('-E<W-I;VX_
M"B`@($1O:6YG('-O('=I;&P@:&5L<"!I;F-R96%S92!S96-U<FET>2!B>2!E
M;G-U<FEN9R!T:&%T(&%N(&%T=&%C:V5R(&9R;VT*("`@86YO=&AE<B!H;W-T
M(&-A;FYO="!T<GD@=&\@:&EJ86-K('1H92!S97-S:6]N+B(^=')U93PO8V]N
M9FEG8F]O;&5A;CX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A;'1E<FYA=&5?
M;&]G:6XB(&1E<V,](DEF('1H:7,@:7,@;F]T(&9A;'-E+"!I="!I<PH@("!A
M<W-U;65D('1O(&)E('1H92!54DP@;V8@86X@86QT97)N871E(&QO9VEN('-C
M<F5E;B!W:&EC:"!W:6QL(&)E('5S960@:6X*("`@<&QA8V4@;V8@:&]R9&4G
M<R!D969A=6QT(&QO9VEN('-C<F5E;BXB/F9A;'-E/"]C;VYF:6=S=')I;F<^
M"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB<F5D:7)E8W1?;VY?;&]G;W5T(B!D
M97-C/2))9B!T:&ES(&ES(&YO="!F86QS92P@:70@:7,*("`@87-S=6UE9"!T
M;R!B92!T:&4@55),(&]F(&%N(&%L=&5R;F%T92!L;V=O=70@<&%G92!W:&EC
M:"!U<V5R<R!W:6QL(&)E('-E;G0*("`@=&\@=VAE;B!T:&5Y(&QO9R!O=70N
M(CYF86QS93PO8V]N9FEG<W1R:6YG/@H@("`\8V]N9FEG<W=I=&-H(&YA;64]
M(F1R:79E<B(@9&5S8STB5VAA="!B86-K96YD('-H;W5L9"!W92!U<V4@9F]R
M"B`@(&%U=&AE;G1I8V%T:6YG('5S97)S('1O($AO<F1E/R(^"@H@("`@/&-A
M<V4@;F%M93TB87!P;&EC871I;VXB(&1E<V,](DQE="!A($AO<F1E(&%P<&QI
M8V%T:6]N(&AA;F1L90H@("`@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF
M:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=E;G5M(&YA
M;64](F%P<"(@9&5S8STB5&AE(&%P<&QI8V%T:6]N('=H:6-H(&ES('!R;W9I
M9&EN9PH@("`@("!A=71H96YT:6-A=&EO;B(^:6UP"B`@("`@("`\=F%L=65S
M/@H@("`@("`@(#QC;VYF:6=S<&5C:6%L(&YA;64](FQI<W0M:&]R9&4M87!P
M<R(O/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@
M("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M
M93TB875T;R(@9&5S8STB075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N(&%S(&$@
M8V5R=&%I;B!U<V5R(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A
M;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C
M/2)4:&4@=7-E<FYA;64@=&\@875T:&5N=&EC871E(&5V97)Y;VYE(&%S(CYH
M;W)D95]U<V5R/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<&%S<W=O<F0B(&1E<V,](E1H92!P87-S=V]R9"!T;R!U<V4@9F]R
M('1H92!U<V5R)W,@8W)E9&5N=&EA;',B(')E<75I<F5D/2)F86QS92(O/@H@
M("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)R97%U97-T=7-E<B(@9&5S8STB
M06QL;W<@=7-E<FYA;64@=&\@8F4@<&%S<V5D(&)Y($=%5"P@4$]35"!O<B!C
M;V]K:64_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E
M8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB8V]M<&]S:71E
M(B!D97-C/2)#;VUP;W-I=&4@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF
M:6=D97-C<FEP=&EO;CX*("`@("`@5&AI<R!A=71H96YT:6-A=&EO;B!D<FEV
M97(@;F5E9',@;6%N=6%L(&-O;F9I9W5R871I;VX@;F]T('!O<W-I8FQE"B`@
M("`@('1H<F]U9V@@=&AI<R!I;G1E<F9A8V4N($%D9"!T:&4@87!P<F]P<FEA
M=&4@8V]N9FEG=7)A=&EO;B!L:6YE<R!A="!T:&4*("`@("`@96YD(&]F('1H
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!F:6QE+@H@("`@(#PO8V]N9FEG
M9&5S8W)I<'1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB9G1P
M(B!D97-C/2)&5%`@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T
M:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M:&]S='-P96,B(&1E<V,](E1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S(&]F
M('1H92!&5%`*("`@("`@<V5R=F5R(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN
M9SX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@9&5S8STB5&AE
M('-E<G9E<B!P;W)T('1O(&-O;FYE8W0*("`@("`@=&\B/C(Q/"]C;VYF:6=I
M;G1E9V5R/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@
M("`\8V%S92!N86UE/2)H='1P(B!D97-C/2)(5%10("A"87-I8R!!=71H96YT
M:6-A=&EO;B\N:'1P87-S=V0I"B`@("!A=71H96YT:6-A=&EO;B(^"B`@("`@
M/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)H='!A<W-W9%]F:6QE(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!L;V-A=&EO;B!O9@H@("`@("!T:&4@:'1P87-S=V0@9FEL92!C
M;VYT86EN:6YG('1H92!U<V5R(&YA;65S(&%N9"!P87-S=V]R9',B+SX*("`@
M("`@/&-O;F9I9V5N=6T@;F%M93TB96YC<GEP=&EO;B(@9&5S8STB4W!E8VEF
M:65S('=H870@:VEN9"!O9B!P87-S=V]R9',@87)E"B`@("`@(&EN('1H92!H
M='!A<W-W9"!F:6QE(CYD97,*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A
M;'5E/F%P<FUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T/"]V86QU
M93X*("`@("`@("`\=F%L=64^8W)Y<'0M8FQO=V9I<V@\+W9A;'5E/@H@("`@
M("`@(#QV86QU93YC<GEP="UD97,\+W9A;'5E/@H@("`@("`@(#QV86QU93YC
M<GEP="UM9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M8F%S938T/"]V
M86QU93X*("`@("`@("`\=F%L=64^;60U+6AE>#PO=F%L=64^"B`@("`@("`@
M/'9A;'5E/G!L86EN/"]V86QU93X*("`@("`@("`\=F%L=64^<VAA/"]V86QU
M93X*("`@("`@("`\=F%L=64^<VUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/G-S:&$\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG
M96YU;3X*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@
M/&-A<V4@;F%M93TB:6UA<"(@9&5S8STB24U!4"!A=71H96YT:6-A=&EO;B(^
M"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O
M;F9I9W-W:71C:"!N86UE/2)I;6%P8V]N9FEG(B!D97-C/2)#;VYF:6=U<F%T
M:6]N('1Y<&4B/@H@("`@("`@/&-A<V4@;F%M93TB9'-N(B!D97-C/2)$4TXB
M/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9'-N(B!D97-C/2)4:&4@
M9G5L;"!)34%0(&-O;FYE8W1I;VX*("`@("`@("!S=')I;F<B/GML;V-A;&AO
M<W0Z,30S+VEM87`O;F]T;'-]/"]C;VYF:6=S=')I;F<^"B`@("`@("`\+V-A
M<V4^"B`@("`@("`\8V%S92!N86UE/2)S97!A<F%T92(@9&5S8STB4V5P87)A
M=&4@=F%L=65S(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S
M<&5C(B!D97-C/2)4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4*
M("`@("`@("!S97)V97(B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@
M("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E1H92!S97)V
M97(@<&]R="!T;R!W:&EC:"!W92!W:6QL"B`@("`@("`@8V]N;F5C="X@24U!
M4"!I<R!G96YE<F%L;'D@,30S+"!W:&EL92!)34%0+5-33"!I<R!G96YE<F%L
M;'D*("`@("`@("`Y.3,N(CXQ-#,\+V-O;F9I9VEN=&5G97(^"B`@("`@("`@
M/&-O;F9I9V5N=6T@;F%M93TB<')O=&]C;VPB(&1E<V,](E1H92!C;VYN96-T
M:6]N('!R;W1O8V]L(CYI;6%P+VYO=&QS"B`@("`@("`@(#QV86QU97,^"B`@
M("`@("`@("`\=F%L=64^:6UA<#PO=F%L=64^"B`@("`@("`@("`\=F%L=64^
M:6UA<"]N;W9A;&ED871E+6-E<G0\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E
M/FEM87`O;F]T;',\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM87`O=&QS
M/"]V86QU93X*("`@("`@("`@(#QV86QU93YI;6%P+W1L<R]N;W9A;&ED871E
M+6-E<G0\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM87`O<W-L/"]V86QU
M93X*("`@("`@("`@(#QV86QU93YI;6%P+W-S;"]N;W9A;&ED871E+6-E<G0\
M+W9A;'5E/@H@("`@("`@("`\+W9A;'5E<SX*("`@("`@("`\+V-O;F9I9V5N
M=6T^"B`@("`@("`\+V-A<V4^"B`@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@
M(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE
M/2)I;7-P(B!D97-C/2))35-0('-E<G9E<B!A=71H96YT:6-A=&EO;B(@+SX*
M"B`@("`\8V%S92!N86UE/2)I<&)A<VEC(B!D97-C/2)3:6UP;&4@25`@8F%S
M960@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G!A<F%M<R(^"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](F)L;V-K<R(@9&5S
M8STB02!L:7-T(&]F($-)1%(@;6%S:W,@=VAI8V@@87)E(&%L;&]W960*("`@
M("`@86-C97-S(B\^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E
M/@H*("`@(#QC87-E(&YA;64](FEP;6%P(B!D97-C/2))4"!B87-E9"!A=71H
M96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9VQI<W0@;F%M93TB8FQO8VMS(B!D97-C/2)!(&QI
M<W0@;V8@0TE$4B!M87-K<R!W:&EC:"!A<F4@86QL;W=E9`H@("`@("!A8V-E
M<W,B+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@
M/&-A<V4@;F%M93TB:W)B-2(@9&5S8STB2V5R8F5R;W,@875T:&5N=&EC871I
M;VXB+SX*"B`@("`\8V%S92!N86UE/2)K;VQA8B(@9&5S8STB2V]L86(@875T
M:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M
M<R(^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](FQO9VEN7V)L;V-K(B!D
M97-C/2)3:&]U;&0@=&AE(&QO9VEN(&)E(&)L;V-K960@869T97(@82!G:79E
M;B!N=6UB97(@;V8@9F%I;&5D(&QO9VEN<S\B/@H@("`@("!F86QS93PO8V]N
M9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB;&]G:6Y?
M8FQO8VM?8V]U;G0B(&1E<V,](D%F=&5R(&AO=VUA;GD@9F%I;&5D(&QO9VEN
M<R!T:&4@;&]G:6X@<VAO=6QD(&)E(&)L;V-K960_(CXS/"]C;VYF:6=I;G1E
M9V5R/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)L;V=I;E]B;&]C:U]T
M:6UE(B!D97-C/2)(;W=M86YY(&UI;G5T97,@=&AE(&QO9VEN('-H;W5L9"!B
M92!B;&]C:V5D/R(^-3PO8V]N9FEG:6YT96=E<CX*("`@("`\+V-O;F9I9W-E
M8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB;&1A<"(@9&5S
M8STB3$1!4"!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T
M<W!E8R(@9&5S8STB5&AE(&AO<W1N86UE(&]F('1H92!,1$%0('-E<G9E<B(^
M;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB8F%S961N(B!D97-C/2)4:&4@8F%S92!$3B!F;W(@=&AE($Q$05`@
M<V5R=F5R(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8FEN9&1N(B!R
M97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!$3B!U<V5D('1O(&)I;F0@=&\@
M=&AE($Q$05`@<V5R=F5R(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M<&%S<W=O<F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A<W-W;W)D
M('5S960@=&\@8FEN9"!T;R!T:&4@3$1!4"!S97)V97(B+SX*("`@("`@/&-O
M;F9I9V5N=6T@;F%M93TB=F5R<VEO;B(@9&5S8STB3$1!4"!0<F]T;V-O;"!6
M97)S:6]N(CXS"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU92!D97-C
M/2),1$%0=C(@*$1E<')E8V%T960I(CXR/"]V86QU93X*("`@("`@("`\=F%L
M=64@9&5S8STB3$1!4'8S(CXS/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@
M("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64]
M(F%D(B!D97-C/2))<R!T:&ES(&%N($%$('-E<G9E<C\B/F9A;'-E/"]C;VYF
M:6=B;V]L96%N/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5I9"(@9&5S
M8STB5&AE('5S97)N86UE('-E87)C:"!K97D@*'-E="!T;R!S86UA8V-O=6YT
M;F%M92!F;W(@040I(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](F5N8W)Y
M<'1I;VXB(&1E<V,](D%L9V]R:71H;2!T;R!E;F-R>7!T('!A<W-W;W)D<R(^
M;60U+6AE>`H@("`@("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB
M87!R;60U(CYA<')M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)C
M<GEP="(^8W)Y<'0\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)C<GEP
M="UD97,B/F-R>7!T+61E<SPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,]
M(F-R>7!T+6UD-2(^8W)Y<'0M;60U/"]V86QU93X*("`@("`@("`\=F%L=64@
M9&5S8STB8W)Y<'0M8FQO=V9I<V@B/F-R>7!T+6)L;W=F:7-H/"]V86QU93X*
M("`@("`@("`\=F%L=64@9&5S8STB;60U+6)A<V4V-"(^;60U+6)A<V4V-#PO
M=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](FUD-2UH97@B/FUD-2UH97@\
M+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)M<V%D(CYM<V%D/"]V86QU
M93X*("`@("`@("`\=F%L=64@9&5S8STB<&QA:6XB/G!L86EN/"]V86QU93X*
M("`@("`@("`\=F%L=64@9&5S8STB<W-H82(^<W-H83PO=F%L=64^"B`@("`@
M("`@/'9A;'5E(&1E<V,](G-M9#4B/G-M9#4\+W9A;'5E/@H@("`@("`@/"]V
M86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*"B`@("`@(#QC;VYF:6=L:7-T
M(&YA;64](FYE=W5S97)?;V)J96-T8VQA<W,B(&1E<V,](E=H870@;V)J96-T
M8VQA<W-E<R!S:&]U;&0@82!N97<@=7-E<B!A8V-O=6YT(&)E(&UE;6)E<B!O
M9C\@5&AE<V4@;V)J96-T8VQA<W-E<R!S:&]U;&0@8V]V97(@=&AE(&-N+'-N
M+'5S97)087-S=V]R9"!A='1R:6)U=&5S(&%S('=E;&P@87,@=&AE('5S97)N
M86UE('-E87)C:"!K97DB/G-H861O=T%C8V]U;G0L:6YE=$]R9U!E<G-O;CPO
M8V]N9FEG;&ES=#X*"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB9FEL=&5R
M7W1Y<&4B(&1E<V,](DAO=R!T;R!S<&5C:69Y(&$@9FEL=&5R(&9O<B!T:&4@
M=7-E<B!L:7-T<R(^;V)J96-T8VQA<W,*("`@("`@(#QC87-E(&YA;64](F]B
M:F5C=&-L87-S(B!D97-C/2)/;F4@;W(@;6]R92!O8FIE8W1C;&%S<R!F:6QT
M97)S(CX*("`@("`@("`\8V]N9FEG;&ES="!N86UE/2)O8FIE8W1C;&%S<R(@
M9&5S8STB5&AE(&]B:F5C=&-L87-S(&9I;'1E<B!U<V5D('1O('-E87)C:"!F
M;W(@=7-E<G,N($-A;B!B92!A('-I;F=L92!O8FIE8W1C;&%S<R!O<B!A(&QI
M<W0N(B\^"B`@("`@("`\+V-A<V4^"B`@("`@("`\8V%S92!N86UE/2)F<F5E
M(B!D97-C/2)!(&-O;7!L971E($Q$05`@9FEL=&5R(&5X<')E<W-I;VXB/@H@
M("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9FEL=&5R(B!D97-C/2)4:&4@
M3$1!4"!21D,@9F]R;6%T=&5D(&9I;'1E<B!U<V5D('1O('-E87)C:"!F;W(@
M=7-E<G,N(B\^"B`@("`@("`\+V-A<V4^"B`@("`@(#PO8V]N9FEG<W=I=&-H
M/@H*("`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)P87-S=V]R9%]E>'!I<F%T
M:6]N(B!D97-C/2)%;F%B;&4@=&AE(&-R96%T:6YG(&]F(&%C8V]U;G1S('=I
M=&@@97AP:7)I;F<@<&%S<W=O<F1S/R`H3F]T93H@3F5W('5S97)S('-H;W5L
M9"!H879E('1H92!S:&%D;W=!8V-O=6YT(&]B:F5C=&-L87-S*2(^;F\*("`@
M("`@(#QC87-E(&YA;64](FYO(B!D97-C/2)N;R(@+SX*("`@("`@(#QC87-E
M(&YA;64](GEE<R(@9&5S8STB>65S(CX*("`@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](FUI;F%G92(@9&5S8STB069T97(@:&]W(&UA;GD@9&%Y<R!M87D@
M82!P87-S=V]R9"!B92!C:&%N9V5D(&%G86EN/R(^-3PO8V]N9FEG<W1R:6YG
M/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;6%X86=E(B!D97-C/2)(
M;W<@;6%N>2!D87ES('=I;&P@82!P87-S=V]R9"!R96UA:6X@=F%L:60_(CXS
M,#PO8V]N9FEG<W1R:6YG/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=V%R;F%G92(@9&5S8STB2&]W(&UA;GD@9&%Y<R!B969O<F4@97AP:7)E<GD@
M<VAO=6QD(&$@=7-E<B!B92!W87)N960_(CXU/"]C;VYF:6=S=')I;F<^"B`@
M("`@("`\+V-A<V4^"B`@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)L;V=I
M;B(@9&5S8STB3&]G:6X@*'-U*2!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)L;V-A=&EO;B(@9&5S8STB3&]C871I;VX@;V8@=&AE('-U(&)I
M;F%R>2(^+V)I;B]S=3PO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)M8V%L(B!D97-C
M/2)-0T%,(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F-A;&5N
M9&%R(B!D97-C/2)4:&4@34-!3"!C86QE;F1A<B!N86UE(B\^"B`@("`@/"]C
M;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](G!A
M;2(@9&5S8STB4$%-("A0;'5G9V%B;&4@075T:&5N=&EC871I;VX@36]D=6QE
M<RD@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5R=FEC92(@
M9&5S8STB5&AE(&YA;64@;V8@=&AE(%!!32!S97)V:6-E('1O('5S92!W:&5N
M(&%U=&AE;G1I8V%T:6YG(CYP:'`\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O
M;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB<&%S
M<W=D(B!D97-C/2)P87-S=V0@9FEL92!A=71H96YT:6-A=&EO;B(^"B`@("`@
M/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)F:6QE;F%M92(@9&5S8STB5&AE('!A<W-W9"!F:6QE('1O
M('5S92(^+V5T8R]P87-S=V0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9V)O;VQE86X@;F%M93TB;&]C:R(@9&5S8STB4VAO=6QD('=E(&QO8VL@=&AE
M('!A<W-W9"!F:6QE/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/"]C
M;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](G)A
M9&EU<R(@9&5S8STB4F%D:75S(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](FAO<W0B(&1E<V,](E1H92!2041)55,@:&]S="!T;R!U<V4@*$E0
M(&%D9')E<W,@;W(@9G5L;'D@<75A;&EF:65D(&AO<W1N86UE*2(^;&]C86QH
M;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64]
M(G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!O<G0@=&\@=7-E
M(&]N('1H92!2041)55,@<V5R=F5R(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA
M;64](FUE=&AO9"(@9&5S8STB5&AE(%)!1$E54R!M971H;V0@=&\@=7-E(&9O
M<B!V86QI9&%T:6YG('1H92!R97%U97-T(CY005`*("`@("`@(#QV86QU97,^
M"B`@("`@("`@/'9A;'5E(&1E<V,](E!!4"(^4$%0/"]V86QU93X*("`@("`@
M("`\=F%L=64@9&5S8STB0TA!4%]-1#4@*&YO="!S=7!P;W)T960@870@=&AE
M(&UO;65N="DB/D-(05!?340U/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S
M8STB35-#2$%0=C$@*&YO="!S=7!P;W)T960@870@=&AE(&UO;65N="DB/DU3
M0TA!4'8Q/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB35-#2$%0=C(@
M*&YO="!S=7!P;W)T960@870@=&AE(&UO;65N="DB/DU30TA!4'8R/"]V86QU
M93X*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB;F%S(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!2041)55,@3D%3(&ED96YT:69I97(@=&\@=7-E+B(@+SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S96-R970B(&1E<V,](E1H92!2041)
M55,@<VAA<F5D('-E8W)E="!S=')I;F<@9F]R('1H90H@("`@("!H;W-T+B!4
M:&4@4D%$2553('!R;W1O8V]L(&EG;F]R97,@86QL(&)U="!T:&4@;&5A9&EN
M9R`Q,C@@8GET97,@;V8@=&AE"B`@("`@('-H87)E9"!S96-R970N(B\^"B`@
M("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G)E=')I97,B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE(&UA>&EM=6T@;G5M8F5R"B`@("`@(&]F(')E<&5A
M=&5D(')E<75E<W1S('1O(&UA:V4@8F5F;W)E(&=I=FEN9R!U<"!;,UTB+SX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S=69F:7@B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE(&1O;6%I;B!N86UE('1O(&%D9`H@("`@("!T;R!U
M;G%U86QI9FEE9"!U<V5R(&YA;65S(B\^"B`@("`@(#QC;VYF:6=I;G1E9V5R
M(&YA;64](G1I;65O=70B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('1I
M;65O=70@9F]R"B`@("`@(')E8V5I=FEN9R!R97!L:65S(&9R;VT@=&AE('-E
M<G9E<B`H:6X@<V5C;VYD<RD@6S-=(B\^"B`@("`@/"]C;VYF:6=S96-T:6]N
M/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](G-A<VPB(&1E<V,](E-!
M4TP@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB87!P(B!D97-C
M/2)4:&4@;F%M92!O9B!T:&4@875T:&5N=&EC871I;F<*("`@("`@87!P;&EC
M871I;VXB/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<V5R=FEC92(@9&5S8STB5&AE(&YA;64@;V8@=&AE(%-!4TP@
M<V5R=FEC92!T;R!U<V4*("`@("`@=VAE;B!A=71H96YT:6-A=&EN9R(^<&AP
M/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C
M87-E/@H*("`@(#QC87-E(&YA;64](G-M8B(@9&5S8STB4TU"(&%U=&AE;G1I
M8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2))4"P@
M1$Y3($YA;64L(&]R($YE=$)I;W,@3F%M92!O9B!T:&4*("`@("`@4TU"('-E
M<G9E<B!T;R!A=71H96YT:6-A=&4@=VET:"(^;&]C86QH;W-T/"]C;VYF:6=S
M=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&]M86EN(B!D97-C
M/2)4:&4@9&]M86EN(&YA;64@=&\@875T:&5N=&EC871E('=I=&@B+SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)G<F]U<"(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)/<'1I;VYA;"!G<F]U<"!N86UE"B`@("`@('1H870@=&AE('5S
M97(@;75S="!B92!A(&UE;6)E<B!O9B(O/@H@("`@(#PO8V]N9FEG<V5C=&EO
M;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)S<6PB(&1E<V,](E-1
M3"!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M<&%R86US(CX*("`@("`@/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C
M;VYF:6<B("\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE(&%U=&@*("`@
M("`@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]U<V5R<UTB+SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M95]F:65L9"(@<F5Q=6ER
M960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4*("`@("`@=7-E<FYA
M;64@9FEE;&0@:6X@=&AE(&%U=&@@=&%B;&4@6W5S97)?=6ED72(O/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D7V9I96QD(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E1H92!N86UE(&]F('1H90H@("`@("!P87-S=V]R
M9"!F:65L9"!I;B!T:&4@875T:"!T86)L92!;=7-E<E]P87-S72(O/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G-O9G1?97AP:7)A=&EO;E]F:65L9"(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4*("`@("`@;F%M92!O9B!A(&9I
M96QD(&-O;G1A:6YI;F<@82!53DE8('1I;65S=&%M<"X@(%=H96X@82!U<V5R
M(&QO9W,@:6X@869T97(*("`@("`@=&AE('-P96-I9FEE9"!T:6UE+"!I9B`G
M<&%S<W=D)R!I<R!I;G-T86QL960L('1H870@=7-E<B!W:6QL(&)E(&%S:V5D
M('1O"B`@("`@(&-H86YG92!H:7,@;W(@:&5R('!A<W-W;W)D+B`@5&AI<R!F
M96%T=7)E(&ES(&1I<V%B;&5D(&)Y(&1E9F%U;'0N(B\^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB:&%R9%]E>'!I<F%T:6]N7V9I96QD(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E1H90H@("`@("!N86UE(&]F(&$@9FEE;&0@8V]N
M=&%I;FEN9R!A(%5.25@@=&EM97-T86UP+B`@02!U<V5R('=I;&P@;F]T(&)E
M(&%B;&4@=&\*("`@("`@;&]G(&EN(&%F=&5R('1H92!S<&5C:69I960@=&EM
M92X@(%1H:7,@9F5A='5R92!I<R!D:7-A8FQE9"!B>2!D969A=6QT+B(O/@H@
M("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)S;V9T7V5X<&ER871I;VY?=VEN
M9&]W(B!R97%U:7)E9#TB9F%L<V4B"B`@("`@(&1E<V,](E1H:7,@:7,@:&]W
M(&]F=&5N+"!I;B!D87ES+"!T:&4@=7-E<B!M=7-T(&-H86YG92!H:7,@;W(@
M:&5R"B`@("`@('!A<W-W;W)D+B`@5VAE;B!T:&4@=7-E<B=S('!A<W-W;W)D
M(&ES('5P9&%T960L('1H92`F<75O=#MS;V9T)G%U;W0["B`@("`@(&5X<&ER
M871I;VX@:7,@<V5T('1H:7,@;6%N>2!D87ES(&EN('1H92!F=71U<F4N("!)
M9B!N;W0@<')O=FED960L"B`@("`@('1H92!U<V5R)W,@<&%S<W=O<F0@=VEL
M;"!N;W0@97AP:7)E(&)Y(&1E9F%U;'0N(B\^"B`@("`@(#QC;VYF:6=I;G1E
M9V5R(&YA;64](FAA<F1?97AP:7)A=&EO;E]W:6YD;W<B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE"B`@("`@(&YU;6)E<B!O9B!D87ES(&EN('1H92!G
M<F%C92!P97)I;V0@=&AE('5S97(@:&%S('1O(&-H86YG92!H:7,@;W(@:&5R
M"B`@("`@('!A<W-W;W)D(&%F=&5R(&ET(&AA<R!E>'!I<F5D+B`@268@;F]T
M('!R;W9I9&5D+"!T:&4@9W)A8V4@<&5R:6]D('=I;&P*("`@("`@;F]T(&5X
M<&ER92XB+SX*("`@("`@/&-O;F9I9V5N=6T@;F%M93TB96YC<GEP=&EO;B(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@96YC<GEP=&EO;B!T;R!U<V4*
M("`@("`@=&\@<W1O<F4@=&AE('!A<W-W;W)D(&EN('1H92!T86)L92(^;60U
M+6AE>`H@("`@("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64^8W)Y<'0\+W9A
M;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UB;&]W9FES:#PO=F%L=64^"B`@
M("`@("`@/'9A;'5E/F-R>7!T+61E<SPO=F%L=64^"B`@("`@("`@/'9A;'5E
M/F-R>7!T+6UD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/FUD-2UB87-E-C0\
M+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M:&5X/"]V86QU93X*("`@("`@
M("`\=F%L=64^<&QA:6X\+W9A;'5E/@H@("`@("`@(#QV86QU93YS:&$\+W9A
M;'5E/@H@("`@("`@(#QV86QU93YS;60U/"]V86QU93X*("`@("`@("`\=F%L
M=64^<W-H83PO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*("`@("`@/"]C;VYF
M:6=E;G5M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)S:&]W7V5N8W)Y
M<'1I;VXB(')E<75I<F5D/2)F86QS92(@9&5S8STB4')E<&5N9"!T:&4*("`@
M("`@96YC<GEP=&EO;B!I;B!T:&4@<&%S<W=O<F0@9FEE;&0_(CYF86QS93PO
M8V]N9FEG8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A
M<V4^"@H@("`@/&-A<V4@;F%M93TB8W5S=&]M<W%L(B!D97-C/2)344P@875T
M:&5N=&EC871I;VX@=R]C=7-T;VTM;6%D92!Q=65R:65S(CX*("`@("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG96YU;2!N
M86UE/2)P:'!T>7!E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4B
M/FUY<W%L"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU92!D97-C/2)-
M:6-R;W-O9G0@4U%,(%-E<G9E<B(^;7-S<6P\+W9A;'5E/@H@("`@("`@(#QV
M86QU92!D97-C/2)->5-13"(^;7ES<6P\+W9A;'5E/@H@("`@("`@(#QV86QU
M92!D97-C/2)/1$)#(CYO9&)C/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S
M8STB3W)A8VQE(#@B/F]C:3@\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C
M/2)0;W-T9W)E4U%,(CYP9W-Q;#PO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*
M("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG<W=I=&-H(&YA;64]
M(G!R;W1O8V]L(B!D97-C/2)7:&%T('!R;W1O8V]L('=I;&P@=V4@=7-E('1O
M(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E/R(^=6YI>`H@("`@("`@/&-A<V4@
M;F%M93TB=6YI>"(@9&5S8STB54Y)6"!3;V-K971S(CX*("`@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G-O8VME="(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2),;V-A=&EO;B!O9B!53DE8('-O8VME="(^/"]C;VYF:6=S=')I;F<^"B`@
M("`@("`\+V-A<V4^"B`@("`@("`\8V%S92!N86UE/2)T8W`B(&1E<V,](E1#
M4"])4"(^"B`@("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)0;W)T('1H92!$0B!I<R!R=6YN:6YG(&]N
M+"!I9B!N;VXM<W1A;F1A<F0B/C4T,S(\+V-O;F9I9VEN=&5G97(^"B`@("`@
M("`\+V-A<V4^"B`@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2)7:&%T(&AO<W1N86UE(&ES
M('1H92!D871A8F%S92!S97)V97(@<G5N;FEN9R!O;BP@;W(@=VAA="!I<R!T
M:&4@;F%M92!O9B!T:&4@<WES=&5M($133B!T;R!U<V4_(CYL;V-A;&AO<W0\
M+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R
M;F%M92(@9&5S8STB5VAA="!U<V5R;F%M92!D;R!W92!A=71H96YT:6-A=&4@
M=&\@=&AE(&1A=&%B87-E('-E<G9E<B!A<S\B/FAO<F1E/"]C;VYF:6=S=')I
M;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB5VAA="!P87-S=V]R9"!D;R!W92!A=71H96YT
M:6-A=&4@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!W:71H/R(O/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](F1A=&%B87-E(B!D97-C/2)7:&%T(&1A=&%B
M87-E(&YA;64O=&%B;&5S<&%C92!A<F4@=V4@=7-I;F<_(CYH;W)D93PO8V]N
M9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG9&5S8W)I<'1I;VX^"B`@("`@("!3
M;VUE('-P96-I86P@=&]K96YS(&-A;B!B92!U<V5D(&EN('1H92!S<6P@<75E
M<GDN(%1H97D@87)E(')E<&QA8V5D(&%T"B`@("`@("!T:&4@<75E<GD@<W1A
M9V4Z)FQT.W5L)F=T.PH@("`@("`@)FQT.VQI)F=T.R)<3"(@=VEL;"!B92!R
M97!L86-E9"!B>2!T:&4@=7-E<B=S(&QO9VEN)FQT.R]L:29G=#L*("`@("`@
M("9L=#ML:29G=#LB7%`B('=I;&P@8F4@<F5P;&%C960@8GD@=&AE('5S97(G
M<R!P87-S=V]R9"9L=#LO;&DF9W0["B`@("`@("`F;'0[;&DF9W0[(EQ/(B!W
M:6QL(&)E(')E<&QA8V5D(&)Y('1H92!O;&0@=7-E<B=S(&QO9VEN("AR97%U
M:7)E9"!F;W(*("`@("`@('5P9&%T92DF;'0[+VQI)F=T.R9L=#LO=6PF9W0[
M"B`@("`@("!%9SH@(E-%3$5#5"`J($923TT@=7-E<G,@5TA%4D4@=6ED(#T@
M7$P@04Y$('!A<W-W9"`](%Q0($%.1"!B:6QL:6YG(#T*("`@("`@("=P86ED
M)R(*("`@("`@/"]C;VYF:6=D97-C<FEP=&EO;CX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)Q=65R>5]A=71H(B!D97-C/2)!=71H96YT:6-A=&4@=&AE
M('5S97(B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)Q=65R>5]A9&0B
M(&1E<V,](D%D9"!U<V5R(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M<75E<GE?=7!D871E(B!D97-C/2)5<&1A=&4@=7-E<B(O/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G%U97)Y7W)E;6]V92(@9&5S8STB4F5M;W9E('5S
M97(B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)Q=65R>5]L:7-T(B!D
M97-C/2),:7-T('5S97)S(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](F5N
M8W)Y<'1I;VXB(&1E<V,](E1H92!E;F-R>7!T:6]N('1O('5S92!T;R!S=&]R
M92!T:&4*("`@("`@<&%S<W=O<F0@:6X@=&AE('1A8FQE(CYM9#4M:&5X"B`@
M("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU93YA<')M9#4\+W9A;'5E/@H@
M("`@("`@(#QV86QU93YC<GEP=#PO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R
M>7!T+6)L;W=F:7-H/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M9&5S
M/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M;60U/"]V86QU93X*("`@
M("`@("`\=F%L=64^;60U+6)A<V4V-#PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/FUD-2UH97@\+W9A;'5E/@H@("`@("`@(#QV86QU93YP;&%I;CPO=F%L=64^
M"B`@("`@("`@/'9A;'5E/G-H83PO=F%L=64^"B`@("`@("`@/'9A;'5E/G-M
M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YS<VAA/"]V86QU93X*("`@("`@
M(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=B
M;V]L96%N(&YA;64](G-H;W=?96YC<GEP=&EO;B(@9&5S8STB4')E<&5N9"!T
M:&4@96YC<GEP=&EO;B!I;B!T:&4*("`@("`@<&%S<W=O<F0@9FEE;&0_(CYF
M86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@
M("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB8WER<W%L(B!D97-C/2)344P@
M:6UP;&5M96YT871I;VX@9F]R('1H92!#>7)U<R!)34%0('-E<G9E<B(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)C>7)A9&UI;B(@9&5S8STB5&AE('5S97)N86UE(&]F
M('1H92!C>7)U<PH@("`@("!A9&UI;FES=')A=&]R(B\^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB8WER<&%S<R(@9&5S8STB5&AE('!A<W-W;W)D(&9O
M<B!T:&4@8WER=7,*("`@("`@861M:6YI<W1R871O<B(O/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](FEM87!?9'-N(B!D97-C/2)4:&4@9G5L;"!)34%0
M($133@H@("`@("`H:2YE+B![;&]C86QH;W-T.CDY,R]I;6%P+W-S;"]N;W9A
M;&ED871E+6-E<G1]*2(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)P:'!T
M>7!E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4B/FUY<W%L"B`@
M("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU92!D97-C/2)-:6-R;W-O9G0@
M4U%,(%-E<G9E<B(^;7-S<6P\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C
M/2)->5-13"(^;7ES<6P\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)-
M>5-13"`H;7ES<6QI*2(^;7ES<6QI/"]V86QU93X*("`@("`@("`\=F%L=64@
M9&5S8STB3T1"0R(^;V1B8SPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,]
M(D]R86-L92`X(CYO8VDX/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB
M4&]S=&=R95-13"(^<&=S<6P\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@
M("`@(#PO8V]N9FEG96YU;3X*("`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)P
M<F]T;V-O;"(@9&5S8STB5VAA="!P<F]T;V-O;"!W:6QL('=E('5S92!T;R!C
M;VYN96-T('1O('1H92!D871A8F%S93\B/G5N:7@*("`@("`@(#QC87-E(&YA
M;64](G5N:7@B(&1E<V,](E5.25@@4V]C:V5T<R(^"B`@("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)S;V-K970B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M3&]C871I;VX@;V8@54Y)6"!S;V-K970B/CPO8V]N9FEG<W1R:6YG/@H@("`@
M("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB=&-P(B!D97-C/2)40U`O
M25`B/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O;BP@
M:68@;F]N+7-T86YD87)D(CXU-#,R/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@
M/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA="!H;W-T;F%M92!I<R!T
M:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE
M(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA
M;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O
M('1H92!D871A8F%S92!S97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E=H870@<&%S<W=O<F0@9&\@=V4@875T:&5N=&EC
M871E('1O('1H92!D871A8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)D871A8F%S92(@9&5S8STB5VAA="!D871A8F%S
M92!N86UE+W1A8FQE<W!A8V4@87)E('=E"B`@("`@('5S:6YG/R(^:&]R9&4\
M+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T86)L
M92(@9&5S8STB5&AE(&YA;64@;V8@=&AE(&%U=&@@=&%B;&4@:6X@=&AE"B`@
M("`@(&1A=&%B87-E(CYH;W)D95]U<V5R<SPO8V]N9FEG<W1R:6YG/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE7V9I96QD(B!D97-C/2)4
M:&4@;F%M92!O9B!T:&4@=7-E<FYA;64@9FEE;&0*("`@("`@:6X@=&AE(&%U
M=&@@=&%B;&4B/G5S97)?=6ED/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB<&%S<W=O<F1?9FEE;&0B(&1E<V,](E1H92!N86UE
M(&]F('1H92!P87-S=V]R9"!F:65L9`H@("`@("!I;B!T:&4@875T:"!T86)L
M92(^=7-E<E]P87-S/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB9&]M86EN7V9I96QD(B!D97-C/2))9B!S970@=&\@86YY=&AI
M;F<@;W1H97(@=&AA;@H@("`@("`G;F]N92<@=&AI<R!I<R!U<V5D(&%S(&9I
M96QD(&YA;64@=VAE<F4@9&]M86EN(&ES"B`@("`@('-T;W)E9"(^;F]N93PO
M8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R>7!T
M:6]N(B!D97-C/2)4:&4@96YC<GEP=&EO;B!T;R!U<V4@=&\@<W1O<F4@=&AE
M"B`@("`@('!A<W-W;W)D(&EN('1H92!T86)L92(^;60U+6AE>`H@("`@("`@
M/'9A;'5E<SX*("`@("`@("`\=F%L=64^87!R;60U/"]V86QU93X*("`@("`@
M("`\=F%L=64^8W)Y<'0\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UB
M;&]W9FES:#PO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+61E<SPO=F%L
M=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+6UD-3PO=F%L=64^"B`@("`@("`@
M/'9A;'5E/FUD-2UB87-E-C0\+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M
M:&5X/"]V86QU93X*("`@("`@("`\=F%L=64^<&QA:6X\+W9A;'5E/@H@("`@
M("`@(#QV86QU93YS:&$\+W9A;'5E/@H@("`@("`@(#QV86QU93YS;60U/"]V
M86QU93X*("`@("`@("`\=F%L=64^<W-H83PO=F%L=64^"B`@("`@("`\+W9A
M;'5E<SX*("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG;&ES="!N
M86UE/2)F;VQD97)S(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](D$@;&ES="!O
M9B!F;VQD97)S('1O(&-R96%T92!U;F1E<@H@("`@("!U<V5R;F%M92(O/@H@
M("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)Q=6]T82(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&4@<75O=&$@*&EN"B`@("`@(&MI;&]B>71E<RD@=&\@
M9W)A;G0@;VX@=&AE(&UA:6QB;W@B+SX*("`@("`@/&-O;F9I9V)O;VQE86X@
M;F%M93TB=6YI>&AI97(B(&1E<V,](E1H92!V86QU92!O9B!I;6%P9"YC;VYF
M)W,*("`@("`@=6YI>&AI97)A<F-H>7-E<"!S971T:6YG+B!#:&5C:R!T:&ES
M(&EF('1H92!V86QU92!I<R!T<G5E(&EN"B`@("`@(&EM87!D+F-O;F8N(CYF
M86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@
M("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB>6%H;V\B(&1E<V,](EEA:&]O
M(2!A=71H96YT:6-A=&EO;B(O/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O
M;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64]
M(G-I9VYU<"(@9&5S8STB4VEG;B!5<"(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<VEG;G5P(CX*("`@/&-O;F9I9VAE861E<CY(;W)D92!3:6=N(%5P/"]C
M;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB86QL;W<B(&1E
M<V,](D%L;&]W(&YO;BUR96=I<W1E<F5D('5S97)S('1O(')E9VES=&5R(&%N
M9`H@("!P<F]V:61E(&$@;&EN:R!O;B!T:&4@;&]G:6X@<V-R965N/R(^9F%L
M<V4*("`@(#QC87-E(&YA;64](G1R=64B(&1E<V,](EEE<R(^"B`@("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB87!P<F]V92(@9&5S8STB061M:6X@:&%S('1O
M(&%P<')O=F4@86YY('5S97(@<W5B;6ET=&5D"B`@("`@<F5G:7-T<F%T:6]N
M(')E<75E<W1S/R`H5T%23DE.1SH@4V5T=&EN9R!T;R!F86QS92!W;W5L9"!M
M96%N('1H870@979E<GD@=7-E<@H@("`@('=H;R!S:6=N<R!U<"!W;W5L9"!H
M879E(&%U=&]M871I8R!A8V-E<W,@=&\@>6]U<B!H;W)D92!S>7-T96TN*2(^
M=')U93PO8V]N9FEG8F]O;&5A;CX*("`@("`\8V]N9FEG8F]O;&5A;B!N86UE
M/2)P<F5P<F]C97-S(B!D97-C/2)087-S('1H92!U<V5R('-U8FUI='1E9"!I
M;F9O<FUA=&EO;@H@("`@('1H<F]U9V@@=&AE(%]H;W)D95]H;V]K7W-I9VYU
M<%]P<F5P<F]C97-S(&9U;F-T:6]N(&EN(&AO;VMS+G!H<"!B969O<F4*("`@
M("!P<F]C97-S:6YG('1H92!R97%U97-T/R(^9F%L<V4\+V-O;F9I9V)O;VQE
M86X^"B`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<75E=64B(&1E<V,](E!A
M<W,@=&AE('5S97(@<W5B;6ET=&5D(&EN9F]R;6%T:6]N"B`@("`@=&AR;W5G
M:"!T:&4@7VAO<F1E7VAO;VM?<VEG;G5P7W%U975E(&9U;F-T:6]N(&EN(&AO
M;VMS+G!H<"!A9G1E<B!P<F]C97-S:6YG"B`@("`@=&AE(')E<75E<W0@8G5T
M(&)E9F]R92!A8W1U86QL>2!Q=65U96EN9R!I=#\B/F9A;'-E/"]C;VYF:6=B
M;V]L96%N/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB9F%L<V4B(&1E
M<V,](DYO(B`O/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I
M;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](FQO9R(@9&5S
M8STB3&]G9VEN9R(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB;&]G(CX*("`@
M/&-O;F9I9VAE861E<CY(;W)D92!,;V=G:6YG/"]C;VYF:6=H96%D97(^"B`@
M(#QC;VYF:6=S=VET8V@@;F%M93TB96YA8FQE9"(@<75O=&4](F9A;'-E(B!D
M97-C/2)3:&]U;&0@2&]R9&4@;&]G(&5R<F]R<R!A;F0@;W1H97(@=7-E9G5L
M"B`@(&EN9F]R;6%T:6]N/R(^=')U90H@("`@/&-A<V4@;F%M93TB=')U92(@
M9&5S8STB665S(CX*("`@("`\8V]N9FEG96YU;2!N86UE/2)P<FEO<FET>2(@
M<75O=&4](F9A;'-E(B!D97-C/2)7:&%T(&QE=F5L(&]F(&UE<W-A9V5S"B`@
M("`@<VAO=6QD('=E(&QO9S\@16%C:"!L979E;"!L;V=S(&ET<V5L9B!A;F0@
M86QL('1H;W-E('1H870@8V]M92!B969O<F4@:70Z"B`@("`@4$5!4E],3T=?
M04Q%4E0@=V]U;&0@;VYL>2!L;V<@86QE<G1S(&%N9"!E;65R9V5N8VEE<RP@
M8G5T(%!%05)?3$]'7T1%0E5'"B`@("`@=V]U;&0@;&]G(&5V97)Y=&AI;F<N
M(CY014%27TQ/1U].3U1)0T4*("`@("`@/'9A;'5E<SX*("`@("`@(#QV86QU
M92!D97-C/2)014%27TQ/1U]%34521R(^4$5!4E],3T=?14U%4D<\+W9A;'5E
M/@H@("`@("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7T%,15)4(CY014%27TQ/
M1U]!3$525#PO=F%L=64^"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],3T=?
M0U))5"(^4$5!4E],3T=?0U))5#PO=F%L=64^"B`@("`@("`\=F%L=64@9&5S
M8STB4$5!4E],3T=?15)2(CY014%27TQ/1U]%4E(\+W9A;'5E/@H@("`@("`@
M/'9A;'5E(&1E<V,](E!%05)?3$]'7U=!4DY)3D<B/E!%05)?3$]'7U=!4DY)
M3D<\+W9A;'5E/@H@("`@("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7TY/5$E#
M12(^4$5!4E],3T=?3D]424-%/"]V86QU93X*("`@("`@(#QV86QU92!D97-C
M/2)014%27TQ/1U])3D9/(CY014%27TQ/1U])3D9//"]V86QU93X*("`@("`@
M(#QV86QU92!D97-C/2)014%27TQ/1U]$14)51R(^4$5!4E],3T=?1$5"54<\
M+W9A;'5E/@H@("`@("`\+W9A;'5E<SX*("`@("`\+V-O;F9I9V5N=6T^"B`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)I9&5N="(@9&5S8STB5VAA="!I9&5N
M=&EF:65R('-H;W5L9"!W92!U<V4@:6X@=&AE"B`@("`@;&]G<S\B/DA/4D1%
M/"]C;VYF:6=S=')I;F<^"@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A
M<F%M<R(^"B`@("`@(#QC;VYF:6=P;&%C96AO;&1E<B\^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H*("`@("`\8V]N9FEG<W=I=&-H(&YA;64](G1Y<&4B(&1E
M<V,](E=H870@;&]G(&1R:79E<B!S:&]U;&0@=V4@=7-E/R(^9FEL90H@("`@
M("`\8V%S92!N86UE/2)C;VYS;VQE(B!D97-C/2)#;VYS;VQE(CX*("`@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I
M9W!H<"!N86UE/2)S=')E86TB(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE
M(&]U='!U="!S=')E86T@=&\*("`@("`@("!U<V4B+SX*("`@("`@("`\8V]N
M9FEG8F]O;&5A;B!N86UE/2)B=69F97)I;F<B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB4VAO=6QD('1H90H@("`@("`@(&]U='!U="!B92!B=69F97)E9"!U
M;G1I;"!S:'5T9&]W;C\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB;&EN949O<FUA="(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2),;V<@;&EN92!F;W)M870*("`@("`@("!S<&5C:69I8V%T
M:6]N(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T:6UE1F]R;6%T
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1I;64@<W1A;7`*("`@("`@("!F
M;W)M870B+SX*("`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`@/"]C87-E
M/@H*("`@("`@/&-A<V4@;F%M93TB9&ES<&QA>2(@9&5S8STB1&ES<&QA>2(^
M"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB97)R;W)?<')E<&5N9"(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)4:&ES('-T<FEN9PH@("`@("`@('=I;&P@8F4@<')E
M<&5N9&5D('1O('1H92!L;V<@;W5T<'5T(B\^"B`@("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)E<G)O<E]A<'!E;F0B(')E<75I<F5D/2)F86QS92(@9&5S
M8STB5&AI<R!S=')I;F<*("`@("`@("!W:6QL(&)E(&%P<&5N9&5D('1O('1H
M92!L;V<@;W5T<'5T(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@
M(#PO8V%S93X*"B`@("`@(#QC87-E(&YA;64](F5R<F]R7VQO9R(@9&5S8STB
M17)R;W(@3&]G(CX*("`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M
M<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D97-T:6YA=&EO;B(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)/<'1I;VYA;`H@("`@("`@(&1E<W1I
M;F%T:6]N('9A;'5E(&9O<B!E<G)O<E]L;V<H*2X@4V5E"B`@("`@("`@:'1T
M<#HO+W=W=RYI;F1E;&EB;&4N;W)G+W!E87(O3&]G+V=U:61E+FAT;6PC97)R
M;W(M;&]G+71Y<&5S(&9O<B!M;W)E"B`@("`@("`@9&5T86EL<RXB+SX*("`@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F5X=')A7VAE861E<G,B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB061D:71I;VYA;`H@("`@("`@(&AE861E<G,@
M=&\@<&%S<R!T;R!T:&4@;6%I;"@I(&9U;F-T:6]N('=H96X@=&AE(%!%05)?
M3$]'7U194$5?34%)3"!T>7!E"B`@("`@("`@:7,@<W!E8VEF:65D(B\^"B`@
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@("`@(#QC
M87-E(&YA;64](F9I;&4B(&1E<V,](D9I;&4B/@H@("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)N86UE(B!D97-C/2)0871H('1O('1H92!L;V<*("`@("`@
M(&9I;&4B/B]T;7`O:&]R9&4N;&]G/"]C;VYF:6=S=')I;F<^"B`@("`@("`\
M8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=B
M;V]L96%N(&YA;64](F%P<&5N9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)3
M:&]U;&0@;F5W(&QO9PH@("`@("`@(&5N=')I97,@8F4@87!P96YD960@=&\@
M86X@97AI<W1I;F<@;&]G(&9I;&4_($EF('1H:7,@:7,@9F%L<V4L(&YE=R!L
M;V<@9FEL97,*("`@("`@("!W:6QL(&]V97)W<FET92!E>&ES=&EN9R!O;F5S
M+B(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`@("`@("`\8V]N9FEG:6YT96=E
M<B!N86UE/2)M;V1E(B!O8W1A;#TB=')U92(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)/8W1A;`H@("`@("`@(')E<')E<V5N=&%T:6]N(&]F('1H92!L;V<@
M9FEL92=S('!E<FUI<W-I;VYS(&UO9&4B+SX*("`@("`@("`\8V]N9FEG<&AP
M(&YA;64](F5O;"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@96YD+6]F
M+6QI;F4@8VAA<F%C=&5R"B`@("`@("`@<V5Q=65N8V4B+SX*("`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FQI;F5&;W)M870B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB3&]G(&QI;F4@9F]R;6%T"B`@("`@("`@<W!E8VEF:6-A=&EO
M;B(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&EM949O<FUA="(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:6UE('-T86UP"B`@("`@("`@9F]R
M;6%T(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*
M"B`@("`@(#QC87-E(&YA;64](FUA:6PB(&1E<V,](DUA:6PB/@H@("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)N86UE(B!D97-C/2)4:&4@<F5C:7!I96YT
M(&9O<B!T:&4@;65S<V%G92(O/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F9R;VTB
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5F%L=64@9F]R('1H90H@("`@("`@
M(&UE<W-A9V4G<R!&<F]M.B!H96%D97(B+SX*("`@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](G-U8FIE8W0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5F%L
M=64@9F]R('1H90H@("`@("`@(&UE<W-A9V4G<R!3=6)J96-T.B!H96%D97(B
M+SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!R96%M8FQE(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E!R96%M8FQE(&9O<B!T:&4*("`@("`@("!M
M97-S86=E(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S
M93X*"B`@("`@(#QC87-E(&YA;64](FUC86PB(&1E<V,](DUC86PB/@H@("`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](F-A;&5N9&%R(B!D97-C/2)4:&4@34-!3"!C86QE
M;F1A<B!N86UE(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R
M;F%M92(@9&5S8STB0V]N;F5C="!T;R!-0T%,(&%S(B\^"B`@("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@9&5S8STB4&%S<W=O<F0@=&\@
M8V]N;F5C="!W:71H(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@
M(#PO8V%S93X*"B`@("`@(#QC87-E(&YA;64](FYU;&PB(&1E<V,](DYU;&PB
M+SX*"B`@("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB4U%,(CX*("`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB;F%M92(@9&5S8STB5&AE('1A8FQE('1O
M(&QO9PH@("`@("`@=&\B/FQO9U]T86)L93PO8V]N9FEG<W1R:6YG/@H@("`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N
M9FEG<&AP(&YA;64](F1S;B(@9&5S8STB02!$871A(%-O=7)C90H@("`@("`@
M($YA;64B/B1C;VYF6R=S<6PG73PO8V]N9FEG<&AP/@H@("`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)S
M<6QI=&4B(&1E<V,](E-13&ET92(^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](FYA;64B(&1E<V,](E1H92!T86)L92!T;R!L;V<*("`@("`@('1O(CYL
M;V=?=&%B;&4\+V-O;F9I9W-T<FEN9SX*("`@("`@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F
M:6QE;F%M92(@9&5S8STB4&%T:"!T;R!A;B!3<6QI=&4@9&%T86)A<V4B+SX*
M("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)M;V1E(B!O8W1A;#TB=')U
M92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)/8W1A;`H@("`@("`@(&UO9&4@
M=7-E9"!T;R!O<&5N('1H92!D871A8F%S92!;,#8V-ETB+SX*("`@("`@("`\
M8V]N9FEG8F]O;&5A;B!N86UE/2)P97)S:7-T96YT(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E5S92!A"B`@("`@("`@<&5R<VES=&5N="!C;VYN96-T:6]N
M(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@(#PO8V]N9FEG<V5C=&EO
M;CX*("`@("`@/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB<WES;&]G(B!D
M97-C/2)3>7-L;V<B/@H@("`@("`@/&-O;F9I9W!H<"!N86UE/2)N86UE(B!Q
M=6]T93TB9F%L<V4B(&1E<V,](E-Y<VQO9R!F86-I;&ET>2!T;R!U<V4B+SX*
M("`@("`@/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB=VEN(B!D97-C/2)7
M:6YD;W<B/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N86UE(B!D97-C
M/2).86UE(&]F('1H92!O<&5N960@=VEN9&]W(B\^"B`@("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=&ET;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('1I=&QE
M(&]F('1H90H@("`@("`@(&]U='!U="!W:6YD;W<B+SX*("`@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@("`@/"]C87-E/@H@("`@(#PO8V]N9FEG<W=I=&-H
M/@H*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](F9A;'-E(B!D97-C/2).
M;R(O/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`@
M/&-O;F9I9V)O;VQE86X@;F%M93TB;&]G7V%C8V5S<VME>7,B(&1E<V,](E-H
M;W5L9"!(;W)D92!L;V<@<W1A=&ES=&EC<R!A8F]U=`H@("!U<V5D(&%C8V5S
M<R!K97ES/R!4:&ES(&ES(&]N;'D@=7-E9G5L(&9O<B!T<F%N<VQA=&]R<R!O
M9B!T:&4*("`@54DN(%EO=2!A;'-O(&YE960@=&\@<V5T('1H92!L;V<@;&5V
M96P@=&\@870@;&5A<W0*("`@4$5!4E],3T=?24Y&3RXB/F9A;'-E/"]C;VYF
M:6=B;V]L96%N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)P
M<F5F<R(@9&5S8STB4')E9F5R96YC92!3>7-T96TB/@H@(#QC;VYF:6=S96-T
M:6]N(&YA;64](G!R969S(CX*("`@/&-O;F9I9VAE861E<CY0<F5F97)E;F-E
M(%-Y<W1E;2!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG:6YT
M96=E<B!N86UE/2)M87AS:7IE(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H
M92!S:7IE(&]F('1H90H@("!P<F5F97)E;F-E<R!F:65L9"!I;B!Y;W5R(&)A
M8VME;F0@:6X@8GET97,N($AO<F1E('=I;&P@<F5J96-T(&%N>2!W<FET92!T
M;PH@("!T:&4@<')E9F5R96YC97,@8F%C:V5N9"!I9B!I=',@;&5N9W1H(&5X
M8V5E9',@=&AI<R!V86QU92X@3&5A=F4@96UP='D@=&\*("`@<VMI<"!T:&ES
M(&-H96-K:6YG+B!%+F<N($UY4U%,('-T;W)E<R!T:&4@<')E9F5R96YC92!D
M871A(&EN(&$@3$].1U1%6%0*("`@9FEE;&0N(%1H:7,@9FEE;&0@8V%N(&AO
M;&0@-#(Y-#DV-S(Y-2!B>71E<R!S;R!M;W-T(&QI:V5L>2!C:&5C:VEN9R!I
M<R!N;W0*("`@;F5E9&5D+B!(;W=E=F5R(&]T:&5R($1"(&EN<W1A;&QA=&EO
M;G,@;6%Y(&]N;'D@:&%V92!A('-T;W)A9V4@<VEZ92!O9B`V-`H@("!+0B`H
M-C4U,S4@8GET97,I+B!4:&5S92!I;G-T86QL871I;VYS('=O=6QD('=A;G0@
M=&\@='5R;B!C:&5C:VEN9R!O;BXB+SX*("`@/&-O;F9I9W-W:71C:"!N86UE
M/2)D<FEV97(B(&1E<V,](E=H870@<')E9F5R96YC97,@9')I=F5R('-H;W5L
M9"!W92!U<V4_(CYS97-S:6]N"B`@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C
M/2)344P@1&%T86)A<V4B/@H@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P
M87)A;7,B/@H@("`@("`@/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C
M;VYF:6<B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE"B`@("`@("`@
M<')E9F5R96YC92!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W!R969S
M72(O/@H@("`@("`@/"]C;VYF:6=S<6P^"B`@("`@(#PO8V]N9FEG<V5C=&EO
M;CX*("`@("`\+V-A<V4^"B`@("`@/&-A<V4@;F%M93TB;&1A<"(@9&5S8STB
M3$1!4"(^"B`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2)4:&4@
M:&]S=&YA;64@;V8@=&AE($Q$05`@<V5R=F5R(CYL;V-A;&AO<W0\+V-O;F9I
M9W-T<FEN9SX*("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E
M<V,](E1H92!P;W)T(&]F('1H92!,1$%0('-E<G9E<B(^,S@Y/"]C;VYF:6=I
M;G1E9V5R/@H@("`@("`@/&-O;F9I9V5N=6T@;F%M93TB=F5R<VEO;B(@9&5S
M8STB3$1!4"!0<F]T;V-O;"!697)S:6]N(CXS"B`@("`@("`@/'9A;'5E<SX*
M("`@("`@("`@/'9A;'5E(&1E<V,](DQ$05!V,B`H1&5P<F5C871E9"DB/C(\
M+W9A;'5E/@H@("`@("`@("`\=F%L=64@9&5S8STB3$1!4'8S(CXS/"]V86QU
M93X*("`@("`@("`\+W9A;'5E<SX*("`@("`@(#PO8V]N9FEG96YU;3X*("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8F%S961N(B!D97-C/2)4:&4@8F%S
M92!$3B!F;W(@=&AE($Q$05`@<V5R=F5R(B\^"B`@("`@("`\8V]N9FEG8F]O
M;&5A;B!N86UE/2)F971C:&1N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E-H
M;W5L9"!(;W)D92!B:6YD"F%S(&5A8V@@=7-E<B!F;W(@=&AA="!U<V5R)W,@
M=W)I=&4@;W!E<F%T:6]N<S\B+SX*("`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB<F]O=&1N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DEF(&YO="P@<')O
M=FED92!T:&4*1$X@;V8@=&AE(')O;W0@*&%D;6EN:7-T<F%T:79E*2!A8V-O
M=6YT('1O(&)I;F0@9F]R('=R:71E(&]P97)A=&EO;G,B+SX*("`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&AE('!A<W-W;W)D(&]F('1H92!R;V]T($1.(&9O<B!B:6YD(&%U
M=&AE;G1I8V%T:6]N(B\^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5I
M9"(@9&5S8STB5&AE('5S97)N86UE('-E87)C:"!K97DB+SX*("`@("`@/"]C
M;VYF:6=S96-T:6]N/@H@("`@(#PO8V%S93X*("`@("`\8V%S92!N86UE/2)S
M97-S:6]N(B!D97-C/2)02%`@4V5S<VEO;G,B+SX*("`@("`\8V%S92!N86UE
M/2)K;VQA8B(@9&5S8STB2V]L86(@*$Q$05`I(B`O/@H@("`@(#QC87-E(&YA
M;64](FEM<W`B(&1E<V,](DE-4U`@4V5R=F5R(B`O/@H@("`\+V-O;F9I9W-W
M:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N
M9FEG=&%B(&YA;64](F1A=&%T<F5E(B!D97-C/2)$871A5')E92!3>7-T96TB
M/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F1A=&%T<F5E(CX*("`@/&-O;F9I
M9VAE861E<CY$871A5')E92!3>7-T96T@4V5T=&EN9W,\+V-O;F9I9VAE861E
M<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)D<FEV97(B(&1E<V,](E=H870@
M8F%C:V5N9"!S:&]U;&0@=V4@=7-E(&9O<B!(;W)D90H@("!$871A5')E92!S
M=&]R86=E/R(^;G5L;`H@("`@(#QC87-E(&YA;64](FYU;&PB(&1E<V,](DYO
M;F4B+SX*("`@("`\8V%S92!N86UE/2)S<6PB(&1E<V,](E-13"!$871A8F%S
M92(^"B`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@
M("`\8V]N9FEG<W%L('-W:71C:&YA;64](F1R:79E<F-O;F9I9R(^"B`@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T86)L92(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:&4@;F%M92!O9B!T:&4*("`@("`@("!D871A('1A8FQE(&EN
M('1H92!D871A8F%S92!;:&]R9&5?9&%T871R965=(B\^"B`@("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)T86)L95]A='1R:6)U=&5S(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](E1H92!N86UE"B`@("`@("`@;V8@=&AE(&1A=&$@871T
M<FEB=71E<R!T86)L92!I;B!T:&4@9&%T86)A<V4*("`@("`@("!;:&]R9&5?
M9&%T871R965?871T<FEB=71E<UTB+SX*("`@("`@(#PO8V]N9FEG<W%L/@H@
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@/"]C87-E/@H@("`\+V-O;F9I
M9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\
M8V]N9FEG=&%B(&YA;64](F=R;W5P(B!D97-C/2)'<F]U<',B/@H@(#QC;VYF
M:6=S96-T:6]N(&YA;64](F=R;W5P(CX*("`@/&-O;F9I9VAE861E<CY'<F]U
M<',@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9V1E<V-R:7!T
M:6]N/@H@("`@5&AE($AO;VMS(&)A8VME;F0@97AT96YD<R!T:&4@1&%T851R
M964@8F%C:V5N9"!T;R!A;&QO=R!H;V]K<R!T;R!E>'1E;F0@80H@("`@9W)O
M=7`@=&\@9'EN86UI8V%L;'D@:6YC;'5D92!M96UB97)S(&EN=&\@82!G<F]U
M<"X@(%-E92!H;V]K<RYP:'`N9&ES="!F;W(*("`@(&%N(&5X86UP;&4N"B`@
M(#PO8V]N9FEG9&5S8W)I<'1I;VX^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M9')I=F5R(B!D97-C/2)7:&%T(&)A8VME;F0@<VAO=6QD('=E('5S92!F;W(@
M2&]R9&4*("`@1W)O=7!S/R(^9&%T871R964*("`@("`\8V%S92!N86UE/2)D
M871A=')E92(@9&5S8STB1&%T851R964B+SX*("`@("`\8V%S92!N86UE/2)H
M;V]K<R(@9&5S8STB2&]O:W,B+SX*"B`@("`@/&-A<V4@;F%M93TB;&1A<"(@
M9&5S8STB3$1!4"(^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A
M;7,B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E
M<V,](E1H92!H;W-T;F%M92!O9B!T:&4@3$1!4"!S97)V97(B/FQO8V%L:&]S
M=#PO8V]N9FEG<W1R:6YG/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M8F%S961N(B!D97-C/2)4:&4@8F%S92!$3B!F;W(@=&AE($Q$05`@<V5R=F5R
M(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)B:6YD9&XB(')E<75I
M<F5D/2)F86QS92(@9&5S8STB5&AE($1.('5S960@=&\@8FEN9"!T;R!T:&4@
M3$1!4"!S97)V97(B+SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A
M<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P87-S=V]R9"!U
M<V5D('1O(&)I;F0@=&\@=&AE($Q$05`@<V5R=F5R(B\^"B`@("`@("`@/&-O
M;F9I9V5N=6T@;F%M93TB=F5R<VEO;B(@9&5S8STB3$1!4"!0<F]T;V-O;"!6
M97)S:6]N(CXS"B`@("`@("`@(#QV86QU97,^"B`@("`@("`@("`\=F%L=64@
M9&5S8STB3$1!4'8R("A$97!R96-A=&5D*2(^,CPO=F%L=64^"B`@("`@("`@
M("`\=F%L=64@9&5S8STB3$1!4'8S(CXS/"]V86QU93X*("`@("`@("`@/"]V
M86QU97,^"B`@("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB9VED(B!D97-C/2)4:&4@9W)O=7`@<V5A<F-H(&ME>2(^
M8VX\+V-O;F9I9W-T<FEN9SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(FUE;6)E<G5I9"(@9&5S8STB1W)O=7`@;65M8F5R<VAI<"!F:65L9"(^;65M
M8F5R56ED/"]C;VYF:6=S=')I;F<^"B`@("`@("`@/&-O;F9I9VQI<W0@;F%M
M93TB;F5W9W)O=7!?;V)J96-T8VQA<W,B(&1E<V,](E=H870@;V)J96-T8VQA
M<W-E<R!S:&]U;&0@82!N97<@9W)O=7`@8F4@;65M8F5R(&]F/R!4:&5S92!O
M8FIE8W1C;&%S<V5S('-H;W5L9"!C;W9E<B!T:&4@;6%I;"!A;F0@9VED;G5M
M8F5R(&%T=')I8G5T97,@87,@=V5L;"!A<R!T:&4@9W)O=7`@<V5A<F-H(&ME
M>2(^<&]S:7A'<F]U<"QH;W)D94=R;W5P/"]C;VYF:6=L:7-T/@H@("`@("`@
M(#QC;VYF:6=S=VET8V@@;F%M93TB9FEL=&5R7W1Y<&4B(&1E<V,](DAO=R!T
M;R!S<&5C:69Y(&$@9FEL=&5R(&9O<B!T:&4@9W)O=7`@;&ES=',B/F]B:F5C
M=&-L87-S"B`@("`@("`@(#QC87-E(&YA;64](F]B:F5C=&-L87-S(B!D97-C
M/2)/;F4@;W(@;6]R92!O8FIE8W1C;&%S<R!F:6QT97)S(CX*("`@("`@("`@
M(#QC;VYF:6=L:7-T(&YA;64](F]B:F5C=&-L87-S(B!D97-C/2)4:&4@;V)J
M96-T8VQA<W,@9FEL=&5R('5S960@=&\@<V5A<F-H(&9O<B!G<F]U<',N($-A
M;B!B92!A('-I;F=L92!O8FIE8W1C;&%S<R!O<B!A(&QI<W0N(CYP;W-I>$=R
M;W5P/"]C;VYF:6=L:7-T/@H@("`@("`@("`\+V-A<V4^"B`@("`@("`@(#QC
M87-E(&YA;64](F9R964B(&1E<V,](D$@8V]M<&QE=&4@3$1!4"!F:6QT97(@
M97AP<F5S<VEO;B(^"B`@("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F9I
M;'1E<B(@9&5S8STB5&AE($Q$05`@4D9#(&9O<FUA='1E9"!F:6QT97(@=7-E
M9"!T;R!S96%R8V@@9F]R(&=R;W5P<RXB+SX*("`@("`@("`@/"]C87-E/@H@
M("`@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`@/"]C87-E/@H*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S
M96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)C86-H
M92(@9&5S8STB0V%C:&4@4WES=&5M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE
M/2)C86-H92(^"B`@(#QC;VYF:6=H96%D97(^0V%C:&4@4WES=&5M(%-E='1I
M;F=S/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=I;G1E9V5R(&YA;64](F1E
M9F%U;'1?;&EF971I;64B(&1E<V,](DAO=R!L;VYG+"!I;B!S96-O;F1S+"!S
M:&]U;&0*("`@;V)J96-T<R!B92!C86-H960@8GD@9&5F875L=#\B/C$X,#`\
M+V-O;F9I9VEN=&5G97(^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB9')I=F5R
M(B!D97-C/2))9B!Y;W4@=V%N="!T;R!E;F%B;&4@=&AE($AO<F1E($-A8VAE
M+`H@("!S96QE8W0@82!D<FEV97(@:&5R92X@5&AI<R!I<R!U<V5D('1O('-P
M965D('5P('!O<G1I;VYS(&]F($AO<F1E(&)Y('-T;W)I;F<*("`@8V]M;6]N
M;'D@<')O8V5S<V5D(&]B:F5C=',@=&\@9&ES:RXB/F9I;&4*("`@(#QC87-E
M(&YA;64](FYO;F4B(&1E<V,](D1O;B=T(&-A8VAE(&%N>2!O8FIE8W1S(B\^
M"B`@("`\8V%S92!N86UE/2)F:6QE(B!D97-C/2)3=&]R92!O8FIE8W1S(&EN
M(&9I;&5S>7-T96TB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M
M<R(^"B`@("`@(#QC;VYF:6=P:'`@;F%M93TB9&ER(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H92!L;V-A=&EO;B!T;R!S=&]R92!T:&4*("`@("`@8V%C
M:&5D(&9I;&5S(CY(;W)D93HZ9V5T5&5M<$1I<B@I/"]C;VYF:6=P:'`^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<')E9FEX(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H92!F:6QE;F%M92!P<F5F:7@@=&\*("`@("`@=7-E(&9O
M<B!T:&4@8V%C:&4@9FEL97,N(B\^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA
M;64](F=C(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!E<F9O<FT@9V%R8F%G
M90H@("`@("!C;VQL96-T:6]N(&]N(&-A8VAE(&9I;&5S/R!);G!U="!T:&4@
M;G5M8F5R(&]F('-E8V]N9',@;VQD('1H92!F:6QE(&AA<PH@("`@("!T;R!B
M92!W:71H;W5T(&UO9&EF:6-A=&EO;B!B969O<F4@=&AE(&-A8VAE('-Y<W1E
M;2!C86X@9&5L971E('1H92!F:6QE+@H@("`@("!);G!U="`P('1O('-K:7`@
M9V%R8F%G92!C;VQL96-T:6]N+B(^.#8T,#`\+V-O;F9I9VEN=&5G97(^"B`@
M("`@(&%F=&5R('=H:6-H(&-A8VAE"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@
M("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB>G!S-"(@9&5S8STB57-E('1H
M92!:96YD(%!E<F9O<FUA;F-E(%-U:71E(&]U='!U="!C86-H92(O/@H@("`\
M+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A
M8CX*"B`\8V]N9FEG=&%B(&YA;64](G1O:V5N(B!D97-C/2)4;VME;B!3>7-T
M96TB/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G1O:V5N(CX*("`@/&-O;F9I
M9VAE861E<CY4;VME;B!3>7-T96T@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*
M("`@/&-O;F9I9VEN=&5G97(@;F%M93TB=&EM96]U="(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&4@<&5R:6]D("AI;@H@("!S96-O;F1S*2!A9G1E<B!W
M:&EC:"!A;B!I9"!I<R!P=7)G960B+SX*("`@/&-O;F9I9W-W:71C:"!N86UE
M/2)D<FEV97(B(&1E<V,](DEF('EO=2!W86YT('1O(&5N86)L92!&;W)M(%1O
M:V5N<RP@<V5L96-T"B`@(&$@9')I=F5R(&AE<F4N(%1H:7,@:7,@=7-E9"!B
M>2!T:&4@2&]R9&4Z.D9O<FTZ.B!!4$D@86YD('-O;64@;W1H97(@<&%R=',*
M("`@;V8@2&]R9&4@=&\@96YS=7)E('1H870@82!F;W)M(&-A;B!O;FQY(&)E
M('-U8FUI='1E9"!O;F-E+B(^;F]N90H@("`@/&-A<V4@;F%M93TB;F]N92(@
M9&5S8STB1&ES86)L92!&;W)M(%1O:V5N<R(O/@H@("`@/&-A<V4@;F%M93TB
M9FEL92(@9&5S8STB3&]C86P@9FEL97-Y<W1E;2!T;VME;B!S=&]R86=E(CX*
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G1O:V5N7V1I<B(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)4:&4@9&ER96-T;W)Y('=H97)E"B`@("`@=&\@:V5E
M<"!T;VME;B!F:6QE<R(O/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB
M<W%L(B!D97-C/2)344PM8F%S960@=&]K96X@<W1O<F%G92(^"B`@("`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-Q;"!S
M=VET8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)T86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M
M92!O9B!T:&4*("`@("`@('1O:V5N<R!T86)L92!I;B!T:&4@9&%T86)A<V4@
M6VAO<F1E7W1O:V5N<UTB+SX*("`@("`@/"]C;VYF:6=S<6P^"B`@("`@/"]C
M;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*
M("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B
M(&YA;64](FUA:6QE<B(@9&5S8STB36%I;&5R(CX*("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)M86EL97(B/@H@("`\8V]N9FEG:&5A9&5R/DUA:6QE<CPO8V]N
M9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](G1Y<&4B(&1E<V,]
M(E=H870@;65T:&]D('-H;W5L9"!W92!U<V4@9F]R('-E;F1I;F<*("`@;6%I
M;#\B/G-E;F1M86EL"B`@("`\8V%S92!N86UE/2)N=6QL(B!D97-C/2)$:7-A
M8FQE(&UA:6QI;F<B("\^"B`@("`\8V%S92!N86UE/2)S96YD;6%I;"(@9&5S
M8STB57-E('1H92!L;V-A;"!S96YD;6%I;"!B:6YA<GDB/@H@("`@(#QC;VYF
M:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<V5N9&UA:6Q?<&%T:"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4
M:&4@;&]C871I;VX*("`@("`@;V8@=&AE('-E;F1M86EL(&)I;F%R>2!O;B!T
M:&4@9FEL97-Y<W1E;0H@("`@("!;+W5S<B]S8FEN+W-E;F1M86EL72(^+W5S
M<B]L:6(O<V5N9&UA:6P\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)S96YD;6%I;%]A<F=S(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](D%N>2!E>'1R80H@("`@("!P87)A;65T97)S('1O('!A<W,@=&\@=&AE
M('-E;F1M86EL(&]R('-E;F1M86EL('=R87!P97(*("`@("`@8FEN87)Y(CXM
M;VD\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\
M+V-A<V4^"B`@("`\8V%S92!N86UE/2)S;71P(B!D97-C/2)5<V4@82!33510
M('-E<G9E<B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H92!S97)V97(@=&\@8V]N;F5C=`H@("`@("!T;R!;;&]C
M86QH;W-T72(O/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!R
M97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P;W)T('1O(&-O;FYE8W0*("`@
M("`@=&\@6S(U72(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FQO8V%L
M:&]S="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;&]C86P@:&]S=&YA
M;64*("`@("`@+R!D;VUA:6X@6VQO8V%L:&]S=%TB+SX*("`@("`@/&-O;F9I
M9V5N=6T@;F%M93TB875T:"(@9&5S8STB4TU44"!A=71H96YT:6-A=&EO;B(^
M,`H@("`@("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB3F\@875T
M:&5N=&EC871I;VXB/C`\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)"
M97-T(&%V86EL86)L92!A=71H96YT:6-A=&EO;B(^,3PO=F%L=64^"B`@("`@
M("`@/'9A;'5E/D1)1T535"U-1#4\+W9A;'5E/@H@("`@("`@(#QV86QU93Y#
M4D%-+4U$-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/DQ/1TE./"]V86QU93X*
M("`@("`@("`\=F%L=64^4$Q!24X\+W9A;'5E/@H@("`@("`@/"]V86QU97,^
M"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)U<V5R;F%M92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@=7-E<FYA
M;64@=&\@=7-E(&9O<B!33510(&%U=&@B+SX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@
M<&%S<W=O<F0@=&\@=7-E(&9O<B!33510(&%U=&@B+SX*("`@("`\+V-O;F9I
M9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO
M8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M
M93TB=F9S(B!D97-C/2)6:7)T=6%L($9I;&4@4W1O<F%G92(^"B`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB=F9S(CX*("`@/&-O;F9I9VAE861E<CY6:7)T=6%L
M($9I;&4@4W1O<F%G93PO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H
M(&YA;64](G1Y<&4B(&1E<V,](DEF(&$@5D93("AV:7)T=6%L(&9I;&5S>7-T
M96TI(&)A8VME;F0@:7,*("`@<F5Q=6ER960L('=H:6-H(&]N92!S:&]U;&0@
M=V4@=7-E/R(^9FEL90H@("`@/&-A<V4@;F%M93TB9FEL92(@9&5S8STB1FEL
M97,@;VX@=&AE(&QO8V%L('-Y<W1E;2(^"B`@("`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)V9G-R
M;V]T(B!D97-C/2)7:&5R92!O;B!T:&4@<F5A;"!F:6QE<WES=&5M('-H;W5L
M9`H@("`@("!(;W)D92!U<V4@87,@<F]O="!O9B!T:&4@=FER='5A;"!F:6QE
M<WES=&5M/R(^+W1M<#PO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB
M4U%,(&1A=&%B87-E(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A
M;7,B/@H@("`@("`\8V]N9FEG<W%L('-W:71C:&YA;64](F1R:79E<F-O;F9I
M9R(^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G9F<U]T86)L92(@9&5S
M8STB5&AE(&YA;64@;V8@=&AE(%9&4R!T86)L92!I;B!T:&4*("`@("`@(&1A
M=&%B87-E(%MH;W)D95]V9G-=(B!R97%U:7)E9#TB9F%L<V4B+SX*("`@("`@
M/"]C;VYF:6=S<6P^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E
M/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O
M;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](G-E<W-I;VXB(&1E<V,](D-U
M<W1O;2!397-S:6]N($AA;F1L97(B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G-E<W-I;VYH86YD;&5R(CX*("`@/&-O;F9I9VAE861E<CY#=7-T;VT@4V5S
M<VEO;B!(86YD;&5R/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=VET8V@@
M;F%M93TB='EP92(@9&5S8STB5VAA="!S97-S:6]N:&%N9&QE<B!D<FEV97(@
M<VAO=6QD('=E"B`@('5S93\B/FYO;F4*("`@(#QC87-E(&YA;64](FYO;F4B
M(&1E<V,](E5S92!T:&4@9&5F875L="!02%`@*&9I;&4M8F%S960I('-E<W-I
M;VX@:&%N9&QE<B(O/@H@("`@/&-A<V4@;F%M93TB97AT97)N86PB(&1E<V,]
M(E5S92!Y;W5R(&]W;B!C=7-T;VT@<V5S<VEO;B!H86YD;&5R(CX*("`@("`\
M8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F]P96XB(&1E<V,](EEO=7(@;W!E;B@I(&9U;F-T:6]N(B\^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8VQO<V4B(&1E<V,](EEO=7(@
M8VQO<V4H*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G)E860B(&1E<V,](EEO=7(@<F5A9"@I(&9U;F-T:6]N(B\^"B`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB=W)I=&4B(&1E<V,](EEO=7(@=W)I=&4H*2!F
M=6YC=&EO;B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F1E<W1R;WDB
M(&1E<V,](EEO=7(@9&5S=')O>2@I(&9U;F-T:6]N(B\^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB9V,B(&1E<V,](EEO=7(@9V,H*2!F=6YC=&EO;B(O
M/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E
M(&YA;64](F1B;2(@9&5S8STB1$)-(&)A<V5D('-E<W-I;VYS(B\^"B`@("`\
M8V%S92!N86UE/2)M>7-Q;"(@9&5S8STB37E344P@8F%S960@<V5S<VEO;G,B
M/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC
M;VYF:6=B;V]L96%N(&YA;64](G!E<G-I<W1E;G0B(&1E<V,](E)E<75E<W0@
M<&5R<VES=&5N="!C;VYN96-T:6]N<S\B/F9A;'-E/"]C;VYF:6=B;V]L96%N
M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)R;W=L;V-K:6YG(B!D97-C
M/2)3:&]U;&0@=V4@=7-E(')O=RUL979E;"!L;V-K:6YG"B`@("`@(&%N9"!T
M<F%N<V%C=&EO;G,_(%1H:7,@:7,@<W1R;VYG;'D@<F5C;VUM96YD960L(&)U
M="!R97%U:7)E<R!A('1A8FQE"B`@("`@('1Y<&4@=&AA="!I<R!T<F%N<V%C
M=&EO;BUS869E(&%N9"!S=7!P;W)T<R!R;W<M;&5V96P@;&]C:VEN9RP@;&EK
M90H@("`@("!);FYO1$(N($EF('EO=2!D;VXG="!H879E('-U8V@@82!T86)L
M92!T>7!E+"!D:7-A8FQE('1H:7,@<V5T=&EN9R!A;F0@=V4*("`@("`@=VEL
M;"!U<V4@=&%B;&4M;&5V96P@;&]C:VEN9R!A;F0@;F\@;&]C:VEN9PH@("`@
M("!I;G-T96%D+B(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I
M9W-W:71C:"!N86UE/2)P<F]T;V-O;"(@9&5S8STB5VAA="!P<F]T;V-O;"!W
M:6QL('=E('5S92!T;R!C;VYN96-T('1O('1H92!D871A8F%S93\B/G5N:7@*
M("`@("`@(#QC87-E(&YA;64](G5N:7@B(&1E<V,](E5.25@@4V]C:V5T<R(^
M"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S;V-K970B(')E<75I<F5D
M/2)F86QS92(@9&5S8STB3&]C871I;VX@;V8@54Y)6"!S;V-K970B/CPO8V]N
M9FEG<W1R:6YG/@H@("`@("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB
M=&-P(B!D97-C/2)40U`O25`B/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA
M;64](G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB4&]R="!T:&4@1$(@
M:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D(CXS,S`V/"]C;VYF:6=I
M;G1E9V5R/@H@("`@("`@/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA
M="!H;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI;F<@;VXL
M(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E
M/R(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@
M875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@87,_(CYH;W)D
M93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A
M<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E=H870@<&%S<W=O<F0@
M9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@=VET
M:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D871A8F%S92(@9&5S
M8STB5VAA="!D871A8F%S92!N86UE+W1A8FQE<W!A8V4@87)E('=E('5S:6YG
M/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)T86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O
M9B!T:&4@<V5S<VEO;B!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W-E
M<W-I;VYH86YD;&5R72(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO
M8V%S93X*("`@(#QC87-E(&YA;64](F]C:3@B(&1E<V,](D]R86-L92!B87-E
M9"!S97-S:6]N<R(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<&5R<VES=&5N="(@9&5S
M8STB4F5Q=65S="!P97)S:7-T96YT(&-O;FYE8W1I;VYS/R(^"B`@("`@(&9A
M;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(FAO<W1S<&5C(B!D97-C/2)$871A8F%S92!N86UE(&]R($5A<WD@0V]N;F5C
M=`H@("`@("!P87)A;65T97(B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@=7-E
M<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O"B`@("`@('1H92!D871A8F%S
M92!S97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E=H870@<&%S<W=O<F0@9&\@=V4*("`@("`@875T:&5N=&EC871E('1O
M('1H92!D871A8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)T86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@
M;F%M92!O9B!T:&4@<V5S<VEO;@H@("`@("!T86)L92!I;B!T:&4@9&%T86)A
M<V4@6VAO<F1E7W-E<W-I;VYH86YD;&5R72(O/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G!G<W%L(B!D97-C
M/2)0;W-T9W)E4U%,(&)A<V5D('-E<W-I;VYS(CX*("`@("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE
M/2)P97)S:7-T96YT(B!D97-C/2)297%U97-T('!E<G-I<W1E;G0@8V]N;F5C
M=&EO;G,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-W
M:71C:"!N86UE/2)P<F]T;V-O;"(@9&5S8STB5VAA="!P<F]T;V-O;"!W:6QL
M('=E('5S92!T;R!C;VYN96-T('1O('1H92!D871A8F%S93\B/G5N:7@*("`@
M("`@(#QC87-E(&YA;64](G5N:7@B(&1E<V,](E5.25@@4V]C:V5T<R(^"B`@
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S;V-K970B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB3&]C871I;VX@;V8@54Y)6"!S;V-K970B/CPO8V]N9FEG
M<W1R:6YG/@H@("`@("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB=&-P
M(B!D97-C/2)40U`O25`B/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64]
M(G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB4&]R="!T:&4@1$(@:7,@
M<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D(CXU-#,R/"]C;VYF:6=I;G1E
M9V5R/@H@("`@("`@/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA="!H
M;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI;F<@;VXL(&]R
M('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E/R(^
M;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@875T
M:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@87,_(CYH;W)D93PO
M8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W
M;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E=H870@<&%S<W=O<F0@9&\@
M=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@=VET:#\B
M+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D871A8F%S92(@9&5S8STB
M5VAA="!D871A8F%S92!N86UE+W1A8FQE<W!A8V4@87)E('=E('5S:6YG/R(^
M:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)T86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T
M:&4@<V5S<VEO;B!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W-E<W-I
M;VYH86YD;&5R72(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S
M93X*("`@(#QC87-E(&YA;64](G-A<&1B(B!D97-C/2)5<V4@4$5!4B=S($1"
M(&%B<W1R86-T:6]N(&QA>65R('<O3T1"0R(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H
M;W-T<W!E8R(@9&5S8STB5VAA="!H;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@
M<V5R=F5R(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE
M('-Y<W1E;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H
M870@=7-E<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S
M92!S97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E=H870@<&%S<W=O<F0@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D
M871A8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)D871A8F%S92(@9&5S8STB5VAA="!D871A8F%S92!N86UE+W1A8FQE
M<W!A8V4@87)E('=E('5S:6YG/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T86)L92(@9&5S8STB5&AE(&YA;64@
M;V8@=&AE('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E(B\^"B`@("`@
M/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB
M<W%L(B!D97-C/2)5<V4@4$5!4B=S($1"(&%B<W1R86-T:6]N(&QA>65R(CX*
M("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N
M9FEG8F]O;&5A;B!N86UE/2)P97)S:7-T96YT(B!D97-C/2)297%U97-T('!E
M<G-I<W1E;G0@8V]N;F5C=&EO;G,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*
M("`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)P<F]T;V-O;"(@9&5S8STB5VAA
M="!P<F]T;V-O;"!W:6QL('=E('5S92!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S93\B/G5N:7@*("`@("`@(#QC87-E(&YA;64](G5N:7@B(&1E<V,](E5.
M25@@4V]C:V5T<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S;V-K
M970B(')E<75I<F5D/2)F86QS92(@9&5S8STB3&]C871I;VX@;V8@54Y)6"!S
M;V-K970B/CPO8V]N9FEG<W1R:6YG/@H@("`@("`@/"]C87-E/@H@("`@("`@
M/&-A<V4@;F%M93TB=&-P(B!D97-C/2)40U`O25`B/@H@("`@("`@(#QC;VYF
M:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D(CXU
M-#,R/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@/"]C87-E/@H@("`@("`\+V-O
M;F9I9W-W:71C:#X*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E
M8R(@9&5S8STB5VAA="!H;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@<V5R=F5R
M(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y<W1E
M;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@=7-E
M<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V
M97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E=H
M870@<&%S<W=O<F0@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S
M92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D
M871A8F%S92(@9&5S8STB5VAA="!D871A8F%S92!N86UE+W1A8FQE<W!A8V4@
M87)E('=E('5S:6YG/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)T86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)4:&4@;F%M92!O9B!T:&4@<V5S<VEO;B!T86)L92!I;B!T:&4@9&%T86)A
M<V4@6VAO<F1E7W-E<W-I;VYH86YD;&5R72(O/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](FUE;6-A8VAE(B!D
M97-C/2)-96UC86-H92!S97)V97(B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](FAO<W1S<&5C
M(B!D97-C/2)7:&%T(&AO<W1N86UE(&ES('1H92!M96UC86-H92!S97)V97(*
M("`@("`@<G5N;FEN9R!O;BP@;W(@=VAA="!I<R!T:&4@;F%M92!O9B!T:&4@
M<WES=&5M($133B!T;R!U<V4_("!3<&5C:69Y"B`@("`@(&UU;'1I<&QE('-E
M<G9E<G,@<V5P87)A=&5D(&)Y(&-O;6UA<RXB/FQO8V%L:&]S=#PO8V]N9FEG
M;&ES=#X*("`@("`@/&-O;F9I9VQI<W0@;F%M93TB<&]R="(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)0;W)T*',I('1H92!M96UC86-H90H@("`@("!S97)V
M97(@:7,@<G5N;FEN9R!O;BX@268@;6]R92!T:&%N(&]N92!H;W-T(&ES('5S
M960L('-P96-I9GD@<&]R=',@9F]R"B`@("`@(')E<W!E8W1I=F4@<V5R=F5R
M<RP@<V5P87)A=&5D(&)Y(&-O;6UA<R(^,3$R,3$\+V-O;F9I9VQI<W0^"B`@
M("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G!E<G-I<W1E;G0B(')E<75I<F5D
M/2)F86QS92(@9&5S8STB4F5Q=65S=`H@("`@("!P97)S:7-T96YT(&-O;FYE
M8W1I;VX@=&\@<V5R=F5R+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@
M(#QC;VYF:6=B;V]L96%N(&YA;64](F-O;7!R97-S:6]N(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](D5N86)L90H@("`@("!C;VUP<F5S<VEO;B!F;W(@<W1O
M<FEN9R!E;G1R:65S(&]N('-E<G9E<BXB/F9A;'-E/"]C;VYF:6=B;V]L96%N
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FQO8VM?9&ER(B!D97-C/2)3
M<&5C:69Y(&$@9&ER96-T;W)Y('1O('=H:6-H('1H90H@("`@("!S97-S:6]N
M(&QO8VMS('-H;W5L9"!B92!W<FET=&5N(CXO=&UP/"]C;VYF:6=S=')I;F<^
M"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I
M9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\
M8V]N9FEG=&%B(&YA;64](FEM86=E(B!D97-C/2));6%G92!-86YI<'5L871I
M;VXB/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FEM86=E(CX*("`@/&-O;F9I
M9VAE861E<CY);6%G92!-86YI<'5L871I;VX\+V-O;F9I9VAE861E<CX*("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)C;VYV97)T(B!R97%U:7)E9#TB9F%L<V4B
M(&1E<V,](DAO<F1E(')E<75I<F5S(&5I=&AE<@H@("!'1"!S=7!P;W)T(&)U
M:6QT+6EN('1O(%!(4"`H+2UW:71H+6=D*2!O<B!T:&4@26UA9V5-86=I8VL@
M<V]F='=A<F4*("`@<&%C:V%G92`H:'1T<#HO+W=W=RYI;6%G96UA9VEC:RYO
M<F<O*2!T;R!D;R!I;6%G90H@("!M86YI<'5L871I;VXO8W)E871I;VXN($EF
M('5S:6YG($EM86=E36%G:6-K+"!S<&5C:69Y('1H92!F=6QL('!A=&@*("`@
M;F%M92!T;R!T:&4@)V-O;G9E<G0G('!R;V=R86TN($]N(%=I;F1O=W,L('1H
M:7,@<&%T:"`J8V%N;F]T*B!H879E"B`@('-P86-E<R!I;B!I="X@57-E($1/
M4RUS='EL92!A8F)R979I871I;VYS(&EF(&YE8V5S<V%R>3H@4')O9W)A?C$*
M("`@:6YS=&5A9"!O9B!0<F]G<F%M($9I;&5S+"!F;W(@:6YS=&%N8V4N($EF
M('5S:6YG($=$+"!O<B!U<VEN9PH@("!N96ET:&5R+"!L96%V92!T:&ES(&9I
M96QD(&)L86YK+B(O/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B
M/@H*(#QC;VYF:6=T86(@;F%M93TB;6EM92(@9&5S8STB34E-12!$971E8W1I
M;VXB/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FUI;64B/@H@("`\8V]N9FEG
M:&5A9&5R/DU)344@1&5T96-T:6]N/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB;6%G:6-?9&(B(')E<75I<F5D/2)F86QS92(@9&5S
M8STB3&]C871I;VX@;V8@=&AE($U)344*("`@;6%G:6,@9&%T86)A<V4N(%5S
M=6%L;'D@+W5S<B]S:&%R92]M:7-C+VUA9VEC(&]R("]E=&,O;6%G:6,N(B\^
M"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A
M8B!N86UE/2)G96]I<"(@9&5S8STB2&]S=&YA;64M)F=T.T-O=6YT<GD@3&]O
M:W5P(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)G96]I<"(^"B`@(#QC;VYF
M:6=H96%D97(^2&]S=&YA;64M)F=T.T-O=6YT<GD@3&]O:W5P/"]C;VYF:6=H
M96%D97(^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T869I;&4B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB2&]R9&4L(&)Y(&1E9F%U;'0L(&-A;@H@("!D
M;R!(;W-T;F%M92`M)F=T.R!#;W5N=')Y(&QO;VMU<"!U<VEN9R!T:&4@=&]P
M(&QE=F5L(&1O;6%I;B`H92YG+B`G=6LG+`H@("`G9&4G*2!O9B!T:&4@:&]S
M=&YA;64N("!(;W=E=F5R+"!M86YY('!O<'5L87(@=&]P(&QE=F5L(&1O;6%I
M;G,*("`@*&4N9RX@)V-O;2<L("=N970G*2!S<&%N(&UO<F4@=&AA;B!O;F4@
M8V]U;G1R>2X@($EN('1H97-E(&EN<W1A;F-E<RP@2&]R9&4*("`@8V%N('5S
M92!T:&4@36%X36EN9"!'96])4"!(;W-T;F%M92!T;R!#;W5N=')Y(&QO;VMU
M<"!T;R!T<GD@=&\@9&5T97)M:6YE"B`@('1H92!C;W)R96-T(&-O=6YT<GDN
M("!4;R!A8W1I=F%T92!T:&ES(&9U;F-T:6]N86QI='DL('1H92!'96])4"YD
M870@8V]U;G1R>0H@("!D871A8F%S92!M=7-T(&)E('!R97-E;G0@;VX@>6]U
M<B!L;V-A;"!S>7-T96TN("!4:&ES(&9I;&4@8V%N(&)E(&1O=VYL;V%D960*
M("`@9G)E92!O9B!C:&%R9V4@9G)O;2!H='1P.B\O=W=W+FUA>&UI;F0N8V]M
M+V1O=VYL;V%D+V=E;VEP+V1A=&%B87-E+RX@($EF"B`@('1H:7,@9&%T86)A
M<V4@:7,@<')E<V5N="P@<W!E8VEF>2!T:&4@9G5L;"!P871H(&YA;64@=&\@
M=&AE(&1A=&%B87-E(&)E;&]W+@H@("!)9B!E;7!T>2P@=&AE($=E;TE0(&QO
M;VMU<"!W:6QL(&YO="!B92!P97)F;W)M960N(B\^"B`@/"]C;VYF:6=S96-T
M:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)P<F]B;&5M
M<R(@9&5S8STB4')O8FQE;2!297!O<G1I;F<B/@H@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G!R;V)L96US(CX*("`@/&-O;F9I9VAE861E<CY0<F]B;&5M(%)E
M<&]R=&EN9SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64]
M(G1I8VME=',B(&1E<V,](DEF(&$@=&EC:V5T('-Y<W1E;2!W:71H(&$*("`@
M=&EC:V5T<R]A9&14:6-K970@05!)(&UE=&AO9"!I<R!P<F5S96YT+"!S:&]U
M;&0@=V4@8W)E871E('1I8VME=',@9F]R"B`@('!R;V)L96T@<F5P;W)T<R!I
M;G-T96%D(&]F(&5M86EL:6YG('1H96T_(CYF86QS90H@("`@/&-A<V4@;F%M
M93TB=')U92(@9&5S8STB665S(CX*("`@("`\8V]N9FEG<&AP(&YA;64](G1I
M8VME=%]P87)A;7,B(&1E<V,](D5N=&5R(&%S(&$@4$A0(&%R<F%Y(&%N>0H@
M("`@(&%D9&ET:6]N86P@87)G=6UE;G1S(&9O<B!T:&4@8W)E871E9"!T:6-K
M970@*'%U975E+"!S=&%T92P@<')I;W)I='DL"B`@("`@971C*2X@17AA;7!L
M92!F;W(@5VAU<',Z(&%R<F%Y*"=Q=65U92<@/3X@,BP@)W-T871E)R`]/B`Q
M+"`G<')I;W)I='DG(#T^(#$L"B`@("`@)W1Y<&4G(#T^(#$I+B!9;W4@=VEL
M;"!N965D('1O(&QO;VL@=7`@=&AE(&%P<')O<')I871E($E$<R!I;B!7:'5P
M<R=S"B`@("`@9&%T86)A<V4L(&]R('=H871E=F5R(&ES(&%P<')O<')I871E
M(&9O<B!T:&4@=&EC:V5T('-Y<W1E;2!Y;W4@87)E"B`@("`@=7-I;F<N(CYA
M<G)A>2@I/"]C;VYF:6=P:'`^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE
M/2)F86QS92(@9&5S8STB3F\B/@H@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M96UA:6PB(&1E<V,](E=H97)E('-H;W5L9"!P<F]B;&5M(')E<&]R="!E;6%I
M;',@8F4@<V5N=#\B/@H@("`@('=E8FUA<W1E<D!E>&%M<&QE+F-O;3PO8V]N
M9FEG<W1R:6YG/@H@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;6%I;&1O;6%I
M;B(@9&5S8STB268@2&]R9&4@8V%N;F]T(&1E=&5R;6EN92!A('5S97(G<PH@
M("`@(&5M86EL(&%D9')E<W,L('1H:7,@9&]M86EN('=I;&P@8F4@87!P96YD
M960@=&\@=&AE:7(*("`@("!U<V5R;F%M92XB/F5X86UP;&4N8V]M/"]C;VYF
M:6=S=')I;F<^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M92(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2))9B!R97%U:7)I;F<@4TU44`H@("`@
M(&%U=&AE;G1I8V%T:6]N('=I=&AO=70@82!G;&]B86P@4TU44"!U<V5R("AI
M;B!S96-T:6]N("9Q=6]T.TUA:6QE<B9Q=6]T.PH@("`@(&%N9"!A;&QO=VEN
M9R!P<F]B;&5M(')E<&]R=&EN9R!F;W(@;F]T(&%U=&AE;G1I8V%T960@=7-E
M<G,@*&EN('-E8W1I;VX*("`@("`F<75O=#M-96YU(%-E='1I;F=S)G%U;W0[
M*2P@=VAA="!U<V5R;F%M92!S:&]U;&0@8F4@=7-E(&9O<B!33510"B`@("`@
M875T:&5N=&EC871I;VX_(B\^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P
M87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&%S<W=O<F0@
M=&\@=7-E(B\^"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO
M8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M
M93TB;65N=2(@9&5S8STB365N=2!3971T:6YG<R(^"B`@/&-O;F9I9VAE861E
M<CY-96YU(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB;65N=2(^"B`@(#QC;VYF:6=M=6QT:65N=6T@;F%M93TB87!P
M<R(@9&5S8STB4V5L96-T(&%N>2!A<'!L:6-A=&EO;G,@=&AA="!S:&]U;&0@
M8F4*("`@;&EN:V5D(&EN($AO<F1E)W,@;65N=2(^"B`@("`\=F%L=65S/@H@
M("`@(#QC;VYF:6=S<&5C:6%L(&YA;64](FQI<W0M:&]R9&4M87!P<R(@+SX*
M("`@(#PO=F%L=65S/@H@("`\+V-O;F9I9VUU;'1I96YU;3X*"B`@(#QC;VYF
M:6=B;V]L96%N(&YA;64](F%L=V%Y<R(@9&5S8STB4VAO=6QD('=E"B`@("9L
M=#MS=')O;F<F9W0[86QW87ES)FQT.R]S=')O;F<F9W0[(&1I<W!L87D@=&AE
M($AO<F1E"B`@(&9R86UE<V5T/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"@H@
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)L:6YK<R(^"B`@("`\8V]N9FEG96YU
M;2!N86UE/2)H96QP(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!H96QP(&QI
M;FMS(&EN('1H90H@("`@;65N=3\B/F%L;`H@("`@(#QV86QU97,^"B`@("`@
M(#QV86QU92!D97-C/2)!;&P@=7-E<G,B/F%L;#PO=F%L=64^"B`@("`@(#QV
M86QU92!D97-C/2)!=71H96YT:6-A=&5D('5S97)S(CYA=71H96YT:6-A=&5D
M/"]V86QU93X*("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E<CPO=F%L
M=64^"B`@("`@/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@("`\8V]N
M9FEG8F]O;&5A;B!N86UE/2)H96QP7V%B;W5T(B!D97-C/2)3:&]U;&0@=V4@
M9&ES<&QA>2!T:&4@86)O=70@;&EN:R!I;@H@("`@=&AE(&AE;'`@;65N=3\B
M/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@("`\8V]N9FEG96YU;2!N86UE/2)O
M<'1I;VYS(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!O<'1I;VYS(&QI;FMS
M(&EN('1H90H@("`@;65N=3\@66]U('-T:6QL(&YE960@=&\@8V]N9FEG=7)E
M(&$@<')E9F5R96YC92!B86-K96YD(&EN('1H90H@("`@)G%U;W0[4')E9F5R
M96YC92!3>7-T96TF<75O=#L@<V5C=&EO;BXB/F%U=&AE;G1I8V%T960*("`@
M("`\=F%L=65S/@H@("`@("`\=F%L=64@9&5S8STB06QL('5S97)S(CYA;&P\
M+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB075T:&5N=&EC871E9"!U<V5R
M<R(^875T:&5N=&EC871E9#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2).
M979E<B(^;F5V97(\+W9A;'5E/@H@("`@(#PO=F%L=65S/@H@("`@/"]C;VYF
M:6=E;G5M/@H@("`@/&-O;F9I9V5N=6T@;F%M93TB<')O8FQE;2(@9&5S8STB
M4VAO=6QD('=E(&1I<W!L87D@<')O8FQE;2!R97!O<G1I;F<@;&EN:W,*("`@
M(&EN('1H92!M96YU/R(^86QL"B`@("`@/'9A;'5E<SX*("`@("`@/'9A;'5E
M(&1E<V,](D%L;"!U<V5R<R(^86QL/"]V86QU93X*("`@("`@/'9A;'5E(&1E
M<V,](D%U=&AE;G1I8V%T960@=7-E<G,B/F%U=&AE;G1I8V%T960\+W9A;'5E
M/@H@("`@("`\=F%L=64@9&5S8STB3F5V97(B/FYE=F5R/"]V86QU93X*("`@
M("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG96YU;3X*("`@(#QC;VYF:6=E;G5M
M(&YA;64](FQO9VEN(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!A(&QO9VEN
M(&QI;FL@:6X@=&AE(&UE;G4*("`@('=H96X@;F]T(&QO9V=E9"!I;C\B/F%L
M;`H@("`@(#QV86QU97,^"B`@("`@(#QV86QU92!D97-C/2)!;&P@=7-E<G,B
M/F%L;#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\
M+W9A;'5E/@H@("`@(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@
M/&-O;F9I9V5N=6T@;F%M93TB;&]G;W5T(B!D97-C/2)3:&]U;&0@=V4@9&ES
M<&QA>2!A(&QO9V]U="!L:6YK(&EN('1H90H@("`@;65N=2!W:&5N(&QO9V=E
M9"!I;C\B/F%U=&AE;G1I8V%T960*("`@("`\=F%L=65S/@H@("`@("`\=F%L
M=64@9&5S8STB075T:&5N=&EC871E9"!U<V5R<R(^875T:&5N=&EC871E9#PO
M=F%L=64^"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E
M/@H@("`@(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@/&-O;F9I
M9V5N=6T@;F%M93TB;&]G:6XB(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&$@
M;&]G:6X@;&EN:R!I;B!T:&4@;65N=0H@("`@=VAE;B!N;W0@;&]G9V5D(&EN
M/R(^86QL"B`@("`@/'9A;'5E<SX*("`@("`@/'9A;'5E(&1E<V,](D%L;"!U
M<V5R<R(^86QL/"]V86QU93X*("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN
M979E<CPO=F%L=64^"B`@("`@/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^
M"B`@("`\8V]N9FEG96YU;2!N86UE/2)L;V=O=70B(&1E<V,](E-H;W5L9"!W
M92!D:7-P;&%Y(&$@;&]G;W5T(&QI;FL@:6X@=&AE"B`@("!M96YU('=H96X@
M;&]G9V5D(&EN/R(^875T:&5N=&EC871E9`H@("`@(#QV86QU97,^"B`@("`@
M(#QV86QU92!D97-C/2)!=71H96YT:6-A=&5D('5S97)S(CYA=71H96YT:6-A
M=&5D/"]V86QU93X*("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E<CPO
M=F%L=64^"B`@("`@/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@(#PO
M8V]N9FEG<V5C=&EO;CX*("`\+V-O;F9I9W-E8W1I;VX^"@H@(#QC;VYF:6=S
M96-T:6]N(&YA;64](FQO9V\B/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](FEM
M86=E(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!54DP@;V8@86X@:6UA
M9V4@9F]R"B`@('1H92!T;W`@;V8@=&AE($AO<F1E(&UE;G4N(%1H92!I;6%G
M92!S:&]U;&0@8F4@;F\@;&%R9V5R('1H86X@,30P('!I>&5L<PH@("!W:61E
M(&)Y(#0P('!I>&5L<R!H:6=H('1O('!R979E;G0@=&AE(&9R86UE(&9R;VT@
M<V-R;VQL:6YG+B(O/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](FQI;FLB(')E
M<75I<F5D/2)F86QS92(@9&5S8STB268@82!L;V=O(&ES(&1I<W!L87EE9"!I
M;@H@("!T:&4@2&]R9&4@;65N=2P@=VAA="!54DP@*&EF(&%N>2D@<VAO=6QD
M(&ET(&QI;FL@=&\_(B\^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T
M86(^"@H@/&-O;F9I9W1A8B!N86UE/2)H;V]K<R(@9&5S8STB0W5S=&]M($9U
M;F-T:6]N($AO;VMS(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)H;V]K<R(^
M"B`@(#QC;VYF:6=H96%D97(^0W5S=&]M($9U;F-T:6]N($AO;VMS/"]C;VYF
M:6=H96%D97(^"B`@(#QC;VYF:6=D97-C<FEP=&EO;CX*("`@(%1H97)E(&%R
M92!E>&%M<&QE(&9U;F-T:6]N<R!F;W(@86QL(&AO;VMS(&EN(&AO<F1E+V-O
M;F9I9R]H;V]K<RYP:'`N9&ES="X*("`@/"]C;VYF:6=D97-C<FEP=&EO;CX*
M("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<&5R;7-D96YI960B(&1E<V,](DEF
M('1H:7,@:7,@8VAE8VME9"P@=&AE"B`@(&9U;F-T:6]N(%]P97)M<U]H;V]K
M7V1E;FEE9"@I('=I;&P@8F4@8V%L;&5D('1O(')E='5R;B!A;B!E<G)O<B!M
M97-S86=E(&EF"B`@(&$@<&5R;6ES<VEO;B!H87,@8F5E;B!D96YI960N($]T
M:&5R=VES92!A('-T86YD87)D(&UE<W-A9V4@=VEL;"!B92!S:&]W;@H@("!A
M;F0@=&AE('5S97(@=V]N)W0@<V5E(&%N>2!A8W1I;VX@=VED9V5T<R!T:&%T
M(&AE(&1O97-N)W0@:&%V92!A8V-E<W,*("`@=&\N(CYF86QS93PO8V]N9FEG
M8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB=7-E<FYA;64B(&1E
M<V,](DEF('1H:7,@:7,@8VAE8VME9"P@=&AE(&9U;F-T:6]N"B`@(%]U<V5R
M;F%M95]H;V]K7V9R;VUB86-K96YD*"D@=VEL;"!B92!U<V5D('1O('-E="!T
M:&4@=7-E<B!N86UE(&%T(&QO9VEN"B`@('1I;64N(%1H92!C;W5N=&5R<&%R
M="!F=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]T;V)A8VME;F0H*2!W:6QL(&)E
M('5S960@=&\*("`@8V]N=F5R="!U<V5R(&YA;65S(&)A8VLL(&9O<B!E>&%M
M<&QE('=H96X@<VAO=VEN9R!N86UE(&QI<W1S('1O('1H90H@("!U<V5R+B(^
M9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64]
M(G!R96%U=&AE;G1I8V%T92(@9&5S8STB268@=&AI<R!I<R!C:&5C:V5D(&%N
M9"!T:&4*("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<')E875T:&5N=&EC871E
M*"D@<F5T=7)N<R!F86QS92P@875T:&5N=&EC871I;VX@=VEL;`H@("!F86EL
M+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA
M;64](G!O<W1A=71H96YT:6-A=&4B(&1E<V,](DEF('1H:7,@:7,@8VAE8VME
M9"!A;F0@=&AE"B`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W!O<W1A=71H96YT
M:6-A=&4H*2!R971U<FYS(&9A;'-E+"!A=71H96YT:6-A=&EO;B!W:6QL"B`@
M(&9A:6PN(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB875T:&QD87`B(&1E<V,](DEF('1H:7,@:7,@8VAE8VME9"P@
M=&AE(&9U;F-T:6]N"B`@(%]H;W)D95]H;V]K7V%U=&AL9&%P*"D@=VEL;"!B
M92!U<V5D('1O(&-R96%T92!A;F0@<V5T('1H92!A='1R:6)U=&5S(&YE961E
M9`H@("!T;R!A9&0O961I="]D96QE=&4@=7-E<G,@8GD@=&AE($Q$05`@075T
M:"!D<FEV97(N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`\+V-O;F9I9W-E
M8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](F)L;V-K
M(B!D97-C/2)0;W)T86P@0FQO8VL@0V]N9FEG=7)A=&EO;B(^"B`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB<&]R=&%L(CX*("`@/&-O;F9I9VAE861E<CY&:7AE
M9"!";&]C:W,\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9VUU;'1I96YU;2!N
M86UE/2)F:7AE9%]B;&]C:W,B(&UU;&1E<V,](E=H:6-H(&)L;V-K<R!S:&]U
M;&0@86QW87ES(&)E"B`@("!D:7-P;&%Y960@:6X@=&AE('!O<G1A;#\B/@H@
M("`@/'9A;'5E<SX*("`@("`\8V]N9FEG<W!E8VEA;"!N86UE/2)L:7-T+6)L
M;V-K<R(@+SX*("`@(#PO=F%L=65S/@H@("`\+V-O;F9I9VUU;'1I96YU;3X*
M("`\+V-O;F9I9W-E8W1I;VX^"B`@/&-O;F9I9VAE861E<CYW96%T:&5R+F-O
M;2!#;VYF:6=U<F%T:6]N/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB=V5A=&AE<F1O=&-O;2(^"B`@(#QC;VYF:6=D97-C<FEP=&EO
M;CX*("`@(%5S92!O9B!T:&4@=V5A=&AE<BYC;VT@8FQO8VL@<F5Q=6ER97,@
M9G)E92!R96=I<W1R871I;VX@9F]R('1H92!834P*("`@(&9E960@870@:'1T
M<#HO+W=W=RYW96%T:&5R+F-O;2]S97)V:6-E<R]X;6QO87`N:'1M;"X*("`@
M($%F=&5R(')E9VES=')A=&EO;BP@86X@96UA:6P@=VEL;"!B92!R971U<FYE
M9"!W:71H('1H92!087)T;F5R($E$(&%N9`H@("`@;&EC96YS92!K97DN)FQT
M.V)R("\F9W0["B`@("!.3U1%.B!W96%T:&5R+F-O;2!G=6ED96QI;F5S(')E
M<75I<F4@<F5G:7-T<F%T:6]N(&%N9"!U<V4@;V8@=&AE(')E='5R;F5D"B`@
M("!V86QU97,L(&)U="!T:&4@87!P;&EC871I;VX@87!P96%R<R!T;R!F=6YC
M=&EO;B!W:71H(&%N>2!S=')I;F<@=F%L=65S+@H@("`\+V-O;F9I9V1E<V-R
M:7!T:6]N/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<G1N97)?:60B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A<G1N97(@22Y$+@H@("!F<F]M
M('=E871H97(N8V]M(B\^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB;&EC96YS
M95]K97DB(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&QI8V5N<V4@:V5Y
M"B`@(&9R;VT@=V5A=&AE<BYC;VTB+SX*("`\+V-O;F9I9W-E8W1I;VX^"@H@
M(#QC;VYF:6=H96%D97(^1F]R='5N92!#;VYF:6=U<F%T:6]N/"]C;VYF:6=H
M96%D97(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB9F]R='5N92(^"B`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB97AE8U]P871H(B!R97%U:7)E9#TB9F%L<V4B
M(&1E<V,](E!A=&@@=&\@9F]R='5N90H@("!E>&5C=71A8FQE+"!E+F<N("]U
M<W(O9V%M97,O9F]R='5N92(O/@H@(#PO8V]N9FEG<V5C=&EO;CX*"B`@/&-O
M;F9I9VAE861E<CY!8V-O=6YT($EN9F\@0V]N9FEG=7)A=&EO;CPO8V]N9FEG
M:&5A9&5R/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F%C8V]U;G1S(CX*("`@
M/&-O;F9I9W-W:71C:"!N86UE/2)D<FEV97(B(&1E<V,](E=H870@(&1R:79E
M<B!S:&]U;&0@=V4@=7-E/R(^;G5L;`H@("`@/&-A<V4@;F%M93TB;G5L;"(@
M9&5S8STB;G5L;"(O/@H@("`@/&-A<V4@;F%M93TB;&]C86QH;W-T(B!D97-C
M/2)L;V-A;&AO<W0B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M
M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<75O=&%?<&%T:"(@9&5S
M8STB4&%T:"!T;R!T:&4@<75O=&$@<')O9W)A;2(^+W5S<B]B:6XO<75O=&$\
M+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)G<F5P
M7W!A=&@B(&1E<V,](E!A=&@@=&\@=&AE(&=R97`@<')O9W)A;2(^+V)I;B]G
M<F5P/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64]
M(G1R86YS;&%T94UO=6YT4&]I;G0B(&1E<V,](E-H;W5L9"!W92!T<F%N<VQA
M=&4@:&]M92!D:7)E8W1O<FEE<R!T;R!M;W5N="!P;VEN="!D979I8V4@;F%M
M97,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)T<F%N<VQA=&EO;E1A8FQE(B!D97-C/2)&:6QE('1O('1R86YS
M;&%T92!D:7)E8W1O<GD@;F%M97,@=&\@;6]U;G0@<&]I;G0@9&5V:6-E(&YA
M;65S/R(^+V5T8R]M=&%B/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF:6=S
M96-T:6]N/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB;&1A<"(@9&5S
M8STB3$1!4"(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T(B!D97-C/2),1$%0('-E
M<G9E<B]H;W-T(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O
M;F9I9VEN=&5G97(@;F%M93TB<&]R="(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)0;W)T($Q$05`@:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D(CXS
M.#D\+V-O;F9I9VEN=&5G97(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M8F%S961N(B!D97-C/2)B87-E9&X@<W1R:6YG(CYO/65X86UP;&4N8V]M+&,]
M55,\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A
M='1R(B!D97-C/2),1$%0(&%T=')I8G5T92!T;R!S96%R8V@@;VXB/G5I9#PO
M8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)V97)S:6]N
M(B!D97-C/2),1$%0(%!R;W1O8V]L(%9E<G-I;VXB/C,*("`@("`@(#QV86QU
M97,^"B`@("`@("`@/'9A;'5E(&1E<V,](DQ$05!V,B`H1&5P<F5C871E9"DB
M/C(\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2),1$%0=C,B/C,\+W9A
M;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@
M("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I
M=&-H/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H@/&-O;F9I
M9W1A8B!N86UE/2)I;7-P(B!D97-C/2))35-0('-E<G9E<B!S971T:6YG<R(^
M"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB:6US<"(^"B`@(#QC;VYF:6=D97-C
M<FEP=&EO;CX*("`@"4EF('EO=2!P;&%N('1O('5S92!A;GD@;V8@2&]R9&4G
M<R!)35-0('-E<G9E<B!S=7!P;W)T+"!E;F%B;&4@=&AI<R!O<'1I;VX@86YD
M"B`@(`EC;VYF:6=U<F4@=&AE('-E<G9E<B!S971T:6YG<R!B96QO=RX@($YO
M=&4@=&AA="!Y;W4@;75S="!S=&EL;"!C;VYF:6=U<F4O96YA8FQE"B`@(`ES
M<&5C:69I8R!)35-0('-U<'!O<G0@:6X@=&AE(&%P<')O<')I871E('-E8W1I
M;VXN"B`@(#PO8V]N9FEG9&5S8W)I<'1I;VX^"B`@(#QC;VYF:6=S=VET8V@@
M;F%M93TB96YA8FQE9"(^9F%L<V4*("`@(#QC87-E(&YA;64](F9A;'-E(B!D
M97-C/2)$:7-A8FQE9"(@+SX*("`@(#QC87-E(&YA;64](G1R=64B(&1E<V,]
M(D5N86)L960B/@H@("`@(#QC;VYF:6=H96%D97(^24U34"!397)V97(@4V5T
M=&EN9W,\+V-O;F9I9VAE861E<CX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G-E<G9E<B(@9&5S8STB4V5R=F5R($%D9')E<W,Z(CYL;V-A;&AO<W0\+V-O
M;F9I9W-T<FEN9SX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!O<G0B(&1E
M<V,](E-E<G9E<B!P;W)T.B(^-#`V/"]C;VYF:6=S=')I;F<^"B`@("`@/&-O
M;F9I9W-W:71C:"!N86UE/2)A=71H7VUE=&AO9"(@9&5S8STB5&AE(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"!T;R!U<V4B/G!L86EN=&5X=`H@("`@("`\8V%S
M92!N86UE/2)P;&%I;G1E>'0B(&1E<V,](E!L86EN=&5X="(@+SX*("`@("`@
M/&-A<V4@;F%M93TB8W)A;5]M9#4B(&1E<V,](D-204TM340U(B`O/@H@("`@
M("`\8V%S92!N86UE/2)I;71E<W0B(&1E<V,](D-Y<G5S(&EM=&5S="(^"B`@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-O8VME="(@9&5S8STB4&%T:"!T
M;R!T:&4@9&ER96-T;W)Y('1H870@=VEL;"!H;VQD('1H92!S;V-K970N"B`@
M("`@("`H5&AE('-O8VME="!W:6QL(&)E(&YA;65D("=I;7-P7W5S97)N86UE
M+G-C:R<I+B(^+W1M<"\\+V-O;F9I9W-T<FEN9SX*("`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB8V]M;6%N9"(@9&5S8STB4&%T:"!T;R!I;71E<W0@8FEN
M87)Y(CXO8WER=7,O=7-R+V-Y<G5S+V)I;B]I;71E<W0\+V-O;F9I9W-T<FEN
M9SX*("`@("`@(#QC;VYF:6=E;G5M(&YA;64](F%U=&A?;65C:&%N:7-M(B!D
M97-C<FEP=&EO;CTB5VAA="!A=71H96YT:6-A=&EO;B!M971H;V0@9&\@>6]U
M('=A;G0*("`@("`@('1O('5S92!W:71H('1H92!I;71E<W0@=71I;&ET>3\B
M/@H@("`@("`@(#QV86QU97,^"B`@("`@("`@(#QV86QU92!D97-C/2)0;&%I
M;G1E>'0@*$Q/1TE.*2(^3$]'24X\+W9A;'5E/@H@("`@("`@("`\=F%L=64@
M9&5S8STB1U-305!)(CYG<W-A<&D\+W9A;'5E/@H@("`@("`@(#PO=F%L=65S
M/@H@("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\+V-A<V4^"B`@("`@/"]C
M;VYF:6=S=VET8V@^"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H/@H@
M(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@
M;F%M93TB:V]L86(B(&1E<V,](DMO;&%B($=R;W5P=V%R92!397)V97(B/@H@
M(#QC;VYF:6=S96-T:6]N(&YA;64](FMO;&%B(CX*("`@/&-O;F9I9V1E<V-R
M:7!T:6]N/@H@("`@)FQT.W-T<F]N9R9G=#LJ*BH@248@64]5($A!5D4@3D\@
M241%02!72$%4($M/3$%"($E3(%1(14X@64]5($-!3B!3049%3%D*("`@($E'
M3D]212!42$E3(%1!0B`J*BHF;'0[+W-T<F]N9R9G=#LF;'0[8G(@+R9G=#L*
M("`@($MO;&%B(&ES(&EN(&YO('=A>2!R97%U:7)E9"!F;W(@;F]R;6%L($AO
M<F1E('5S86=E+B!)9BP@:&]W979E<BP@>6]U"B`@("!I;G1E;F0@=&\@=7-E
M($AO<F1E(&%S(&$@=V5B8VQI96YT(&9O<B!+;VQA8B!T:&5N('EO=2!W:6QL
M(&YE960@=&\@96YS=7)E"B`@("!T:&%T('1H92!F;VQL;W=I;F<@9FEE;&1S
M(&-O<G)E<W!O;F0@=&\@=&AO<V4@<F5Q=6ER960@8GD@>6]U<B!+;VQA8@H@
M("`@:6YS=&%L;&%T:6]N+B`@66]U(&-A;B!F:6YD('-O;64@;V8@=&AE(')E
M<75I<F5D('9A;'5E<R!I;B!T:&4*("`@("9L=#MC;V1E)F=T.R`D2T],04)?
M4D]/5"]E=&,O:V]L86(O:V]L86(N8V]N9B9L=#LO8V]D929G=#L@8V]N9FEG
M=7)A=&EO;@H@("`@9FEL92X@4&QE87-E(&YO=&4@=&AA="!T:&4@;VQD(&E#
M86PO=D-A<F0@<W1O<F%G92!F;W)M870@:&%S(&)E96X@9')O<'!E9`H@("`@
M:6X@9F%V;W5R(&]F('1H92!N97<@6$U,('-T;W)A9V4@9F]R;6%T("9A;7`[
M86UP.R!)34%0(&9O;&1E<B!A;FYO=&%T:6]N<SL*("`@('-U8G-E<75E;G1L
M>2!T:&4@2&]R9&4@2V]L86(@;6]D=6QE<R!W:6QL(&]N;'D@=V]R:R!W:71H
M('9E<G-I;VX@,B!O9B!T:&4*("`@($MO;&%B('-E<G9E<BXF;'0[8G(@+R9G
M=#L*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&9I;F0@;W5T(&UO<F4@86)O
M=70@2V]L86(@=&AE;B!P;&5A<V4@=FES:70@=&AE($MO;&%B"B`@("!C;VUM
M=6YI='D@=V5B<VET92!A="!H='1P.B\O=W=W+FMO;&%B+F]R9R\*("`@/"]C
M;VYF:6=D97-C<FEP=&EO;CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)E;F%B
M;&5D(B!Q=6]T93TB9F%L<V4B(&1E<V,](DAO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N"B`@("!S=&%T=7,B/F9A;'-E"B`@("`\8V%S92!N86UE/2)F86QS92(@
M9&5S8STB1&ES86)L960B("\^"B`@("`\8V%S92!N86UE/2)T<G5E(B!D97-C
M/2)%;F%B;&5D(CX*("`@("`\8V]N9FEG:&5A9&5R/DMO;&%B($Q$05`@4V5R
M=F5R(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB;&1A<"(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5R
M=F5R(B!D97-C/2)397)V97(*("`@("`@861D<F5S<SHB/FQO8V%L:&]S=#PO
M8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T
M(B!D97-C/2)397)V97(@<&]R=#HB/C,X.3PO8V]N9FEG:6YT96=E<CX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)B87-E9&XB(&1E<V,](D)A<V4@1$XZ
M(CYD8SUE>&%M<&QE+`H@("`@("!D8SUC;VT\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)B:6YD9&XB(&1E<V,](D)I;F0@1$XZ
M(CYC;CUM86YA9V5R+"!C;CUI;G1E<FYA;"P*("`@("`@9&,]97AA;7!L92P@
M9&,]8V]M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB8FEN9'!W(B!D97-C/2)":6YD(%!A<W-W;W)D.B(^<&%S<W=O<F0\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P:'!D;B(@
M9&5S8STB4V5A<F-H($1..B(^8VX];F]B;V1Y+"!C;CUI;G1E<FYA;"P*("`@
M("`@9&,]97AA;7!L92P@9&,]8V]M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB<&AP<'<B(&1E<V,](E-E87)C:`H@("`@("!0
M87-S=V]R9#HB/G!A<W-W;W)D/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@(#QC;VYF:6=H96%D97(^2V]L86(@0WER=7,@24U!
M4"!397)V97(@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)I;6%P(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)S97)V97(B(&1E<V,](E-E<G9E<@H@("`@("!A9&1R97-S.B(^;6%I;"YE
M>&%M<&QE+F-O;3PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG:6YT96=E
M<B!N86UE/2)P;W)T(B!D97-C/2)397)V97(@<&]R=#HB/C$T,SPO8V]N9FEG
M:6YT96=E<CX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<VEE=F5P;W)T
M(B!D97-C/2)3:65V92!P;W)T.B(^,C`P,#PO8V]N9FEG:6YT96=E<CX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)M86EL9&]M86EN(B!D97-C/2)$969A
M=6QT"B`@("`@(&UA:6QD;VUA:6XZ(CYE>&%M<&QE+F-O;3PO8V]N9FEG<W1R
M:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F%D;6EN=7-E<B(@9&5S
M8STB061M:6YI<W1R871O<@H@("`@("!U<V5R.B(^;6%N86=E<CPO8V]N9FEG
M<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F%D;6EN<'<B(&1E
M<V,](D%D;6EN:7-T<F%T;W(*("`@("`@<&%S<W=O<F0Z(CYP87-S=V]R9#PO
M8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)V:7)T
M9&]M86EN<R(@9&5S8STB5FER='5A;`H@("`@("!D;VUA:6YS.B(^=')U93PO
M8V]N9FEG8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@(#QC;VYF
M:6=B;V]L96%N(&YA;64](F=R;W5P;&1A<"(@9&5S8STB268@=&AI<R!I<R!C
M:&5C:V5D+"!T:&4@9G5N8W1I;VX*("`@7VAO<F1E7VAO;VM?9W)O=7!L9&%P
M*"D@=VEL;"!B92!U<V5D('1O(&-R96%T92!A;F0@<V5T('1H92!A='1R:6)U
M=&5S(&YE961E9`H@("!T;R!A9&0O961I="]D96QE=&4@9W)O=7!S(&)Y('1H
M92!,1$%0($=R;W5P(&1R:79E<BXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@
M("`@(#QC;VYF:6=H96%D97(^2V]L86(@4TU44"!397)V97(@4V5T=&EN9W,\
M+V-O;F9I9VAE861E<CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S;71P
M(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S97)V97(B(&1E<V,](E-E
M<G9E<@H@("`@("!A9&1R97-S.B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^
M"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E-E<G9E
M<B!P;W)T.B(^,C4\+V-O;F9I9VEN=&5G97(^"B`@("`@/"]C;VYF:6=S96-T
M:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I
M9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*/"]C;VYF:6=U<F%T:6]N/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH
M;W)D92]H;W)D92\N:'1A8V-E<W,`````````````````````````````````
M````````````````````````````````````````,#$P,#0T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,38`,3`U,34T,S$P-S``,#(P,#4R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$1E;GD@9G)O
M;2!A;&P*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W1M<"\`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#`P-#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,Q,#<P`#`Q,S,R-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O=&UP
M+VAO=&9I>"TX,#`V,3`Q."XR,"\`````````````````````````````````
M````````````````````````````````````````````````,#`T,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S$P-S``,#$U-S4T
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]T;7`O:&]T9FEX+3@P,#8Q,#$X+C(P+V9I;&5L:7-T
M````````````````````````````````````````````````````````````
M```````````P,3`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#0S,34P,P`Q
M,#4Q-30S,3`W,``P,3<U,34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S
M+W-K:6YS+V%Q=6$N8V]M<&%C="]C<W,O:64N8W-S(')O;W0@,"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYS96$O
M8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI
M;B]H=&1O8W,O<VMI;G,O87%U82]C<W,O:64N8W-S(')O;W0@,"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYS:6QV
M97(O8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A
M9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN865R;R]C<W,O:64N8W-S(')O
M;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:RYV:6]L970O8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN8FQA8VLO
M8W-S+VEE+F-S<R`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M
M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+F)L=64O8W-S+VEE+F-S<R`@("`@(')O
M;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN
M<R]L;VYG:&]R;BYY96QL;W<O8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;F5W+F-O
M;7!A8W0O8W-S+VEE+F-S<R`@("`@("!R;V]T(#`@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLX+FYE=R]C<W,O:64N
M8W-S("`@("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO
M:'1D;V-S+W-K:6YS+W=I;GAP+FYE=R]C<W,O:64N8W-S("`@("`@(')O;W0@
M,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]P
M;&5S:RYB;'5E+V-S<R]I92YC<W,@("`@("!R;V]T(#`@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;VQI=F5G<F5E
M;B]C<W,O:64N8W-S("`@("`@("!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN8VQA<W-I8RYS:6QV97(O
M8W-S+VEE+F-S<R`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M
M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+G-I;'9E<B]C<W,O:64N8W-S("`@(')O
M;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:RYN871U<F4O8W-S+VEE+F-S<R`@("!R;V]T(#`@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]A9&UI;B]P;&EB+V-O;6UO;E]F=6YC+G!H<#,@<F]O
M="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO<V)I;B]F:6QE;6YG
M(')O;W0@<'-A861M(#`U-3`*)'M04D]$54-47U)/3U1?1'TO861M:6XO<&QI
M8B]C;&%S<RY#:&5C:V5R+G!H<"!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]A9&UI;B]P;&EB+V-L87-S+D9I;&5-86YA9V5R+G!H<"!R;V]T(#`@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI;B]P;&EB+VQO8V%L97,O96XM
M55,O;65S<V%G97-?96XM55,N<&AP(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+V%D;6EN+VAT9&]C<R]F:6QE;6%N86=E<B]F:6QE;6%N86=E<BYP
M:'`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4V5R=FEC97,O5V5A=&AE<B]%:G-E+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A
M=&AE<B]';&]B86QW96%T:&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<B]-
M971A<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O5V5A=&AE<F1O=&-O;2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U-E<G9I8V5S+U=E871H97(O0V]M;6]N+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4V5R=FEC
M97,O5V5A=&AE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+T%R8VAI=F4O5&%R+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O075T:"]3
M05-,+T-O;6UO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]#<F%M340U+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M075T:"]305-,+T1I9V5S=$U$-2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"],;V=I;BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+T%U=&@O4T%33"]0;&%I;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]!;F]N
M>6UO=7,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN
M97(O9&(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O;61B+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C
M:&4O0V]N=&%I;F5R+V9I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O;7-E
M<W-I;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O<&AP;&EB+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M0V%C:&4O0V]N=&%I;F5R+W-H;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]T
M<FEF:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+V1B>"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A
M8VAE+T5R<F]R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O1G5N8W1I;VXN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H
M92]'<F%P:&EC<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+T-A8VAE+TA45%!?4F5Q=65S="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+T-A8VAE+T]U='!U="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T]U='!U=$-O;7!R97-S:6]N
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O07!P;&EC
M871I;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]#;VYS;VQE+T=E=&]P="YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O2%14
M4%]297%U97-T+V1O8W,O97AA;7!L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O2%144%]297%U
M97-T+V1O8W,O9&]W;FQO860M<')O9W)E<W,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O
M8R]-04E.5$%)3D524PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]$0B]D;V,O4U1!5%53"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+T1"+V1O8R]415-415)3"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O8R])1$5!4PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C
M<R].971?4TU44"]D;V-S+V5X86UP;&5S+V)A<VEC+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R].
M971?4TU44"]D;V-S+V=U:61E+G1X=`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X
M86UP;&5S+WAM;%]P87)S97)?9FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E
M<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7VAA;F1L97(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]087)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]S:6UP;&4Q+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,2YX
M;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I
M;7!L93(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A
M<G-E<E]S:6UP;&4R+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S
M+WAM;%]P87)S97)?<VEM<&QE7VAA;F1L97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]0
M87)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]F:6QE+GAM;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],
M;V<O9&]C<R]E>&%M<&QE<R]C;VUP;W-I=&4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D
M;V-S+V5X86UP;&5S+V1I<W!L87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X
M86UP;&5S+V5R<F]R7VQO9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L
M97,O9FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O;6%I;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O;G5L;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O
M8W,O3&]G+V1O8W,O97AA;7!L97,O;V)S97)V97)?;6%I;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O
M8W,O3&]G+V1O8W,O97AA;7!L97,O<&5A<E]E<G)O<E]H86YD;&5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]P:'!?97)R;W)?:&%N9&QE<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O<W%L+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C
M<R],;V<O9&]C<R]E>&%M<&QE<R]S<6QI=&4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D
M;V-S+V5X86UP;&5S+W-Y<VQO9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA
M;7!L97,O=VEN+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]C;VYS
M;VQE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]G=6ED92YT>'0)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M1&%T92],24-%3E-%"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+T1A=&4O5$]$3PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R].971?
M55),+V1O8W,O97AA;7!L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O07)C:&EV95]487(O9&]C
M<R]!<F-H:79E7U1A<BYT>'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E
M>&%M<&QE<R]M971A<BUB87-I8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A
M=&AE<B]E>&%M<&QE<R]M971A<BUE>'1E;G-I=F4N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E
M<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A=&AE<BYC
M;VTM97AT96YS:79E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X
M86UP;&5S+V5J<V4M8F%S:6,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H
M97(O97AA;7!L97,O9VQO8F%L=V5A=&AE<BUB87-I8RYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U5T:6PO97AA;7!L97,O97AA;7!L93(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]5
M=&EL+V5X86UP;&5S+V5X86UP;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI
M>F5R+V5X86UP;&5S+W-E<FEA;&EZ94%N9$5N8V]D92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE07)R87E7:71H3V)J
M96-T<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R
M:6%L:7IE0T1A=&$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP
M;&5S+W-E<FEA;&EZ945M<'1Y07)R87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ94EN9&5X961!<G)A>2YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE26YD97AE
M9$%R<F%Y5VET:$-O;G1E>'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R
M+V5X86UP;&5S+W-E<FEA;&EZ94YU;&Q0<F]P97)T:65S+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5/8FIE8W0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95)$
M1BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L
M:7IE4V5L96-T:79E071T<FEB=71E<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE5VET:$%T=')I8G5T97,N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A!
M='1R:6)U=&5S,BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L
M97,O<V5R:6%L:7IE5VET:$-O;6UE;G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+V5X86UP;&4N>&UL"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A$=&0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A);F1E;G1E
M9$%T=')I8G5T97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP
M;&5S+W-E<FEA;&EZ95=I=&A.86UE<W!A8V4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]3
M97)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A486=-87`N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE06YY
M6$U,+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E
M<FEA;&EZ94-L87-S3F%M97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R
M+V5X86UP;&5S+W5N<V5R:6%L:7IE16YC;V1E9"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,
M7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F5%;G5M+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ94]B:F5C
M="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I
M86QI>F521$8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S
M+W5N<V5R:6%L:7IE5VAI=&5S<&%C92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F57:71H071T<FEB=71E<RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F57
M:71H5&%G36%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE
M<R]U;G-E<FEA;&EZ95=I=&A4>7!E1W5E<W-I;F<N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ94%N9%)E='5R;BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O4T]!4"]E>&%M<&QE+V%T=&%C:&UE;G0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-/05`O97AA;7!L92]C;VU?8VQI96YT+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X
M86UP;&4O9&ES8V]?<V5R=F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O
M96UA:6Q?8VQI96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O96UA:6Q?
M9V%T97=A>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7W!O<%]G
M871E=V%Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O96UA:6Q?<&]P7W-E
M<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7W-E<G9E<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5X86UP;&5?<V5R=F5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]33T%0+V5X86UP;&4O97AA;7!L95]T>7!E<RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O
M8W,O4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+W-E<G9E<C(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S;71P+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]33T%0+V5X86UP;&4O<W1O8VMQ=6]T92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O
M8W,O4T]!4"]E>&%M<&QE+W1C<%]C;&EE;G0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O
M97AA;7!L92]T8W!?9&%E;6]N+G!L"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]T
M8W!?<V5R=F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=W-D;%]C;&EE
M;G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]C;&EE;G0N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+TYE=%]&5%`O97AA;7!L92]I;F1E>"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7T94
M4"]E>&%M<&QE+V]B<V5R=F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R].971?1E10+V5X86UP
M;&4O97AT96YS:6]N<RYI;FD)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O4$5!4B]T96UP;&%T92YS<&5C
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D871A+U!%05(O<&%C:V%G92YD=&0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O36%I;%]-:6UE
M+WAM86EL+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&%T82]-86EL7TUI;64O>&UA:6PN9'1D"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M871A+TQO9R]M:7-C+VQO9RYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O4V5R=FEC97-?5V5A=&AE
M<B]I;6%G97,O<W5N<V5T+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T82]397)V:6-E<U]796%T:&5R
M+VEM86=E<R]S=6YR:7-E+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T82]397)V:6-E<U]796%T:&5R
M+V)U:6QD365T87)$0BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O6$U,7U-E<FEA;&EZ97(O9&]C
M+W1O9&\N='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D871A+T-A8VAE+T-O;G1A:6YE<B]M9&)?8V%C:&5?
M<V-H96UA+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O6$U,+U)00R]397)V97(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]834PO4E!#
M+T1U;7`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]834PO4&%R<V5R+U-I;7!L92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-3"]0
M87)S97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]834PO571I;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-3"]5;G-E<FEA;&EZ
M97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]834PO4V5R:6%L:7IE<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-3"]24$,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]$0B]C;VUM;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]F8G-Q;"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+VEB
M87-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O1$(O:69X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O;7-Q;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"
M+VUS<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O1$(O;7ES<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]M>7-Q;&DN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]$0B]O8VDX+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O;V1B8RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+W!G<W%L
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O1$(O<WEB87-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O<W1O<F%G92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+T1"+W-Q;&ET92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+T1"+V1B87-E+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+V-O;7!O
M<VET92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+TQO9R]D865M;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O9&ES<&QA>2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+TQO9R]E<G)O<E]L;V<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O9FEL92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+TQO9R]M86EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O3&]G+VUC86PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O;61B,BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+TQO9R]N=6QL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+V]B<V5R=F5R+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M3&]G+W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+TQO9R]S<6QI=&4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O<WES;&]G
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O3&]G+W=I;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+TQO9R]C;VYS;VQE+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4T]!4"]4<F%N<W!O<G0O4TU44"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O5')A;G-P;W)T+U1#
M4"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U-/05`O5')A;G-P;W)T+TA45%`N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U-E
M<G9E<B]40U`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]33T%0+U-E<G9E<B]%;6%I;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/
M05`O4V5R=F5R+T5M86EL7T=A=&5W87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O9'5R
M871I;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O:&5X0FEN87)Y+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!
M4"]4>7!E+V1A=&54:6UE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]T;V]L<R]G96YP<F]X>2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U-/05`O4V5R=F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O<G0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]33T%0+U9A;'5E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]74T1,+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!
M4"]#;&EE;G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]33T%0+T)A<V4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+T1I<V-O
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O4T]!4"]&875L="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O4&%R<V5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O1&%T92](=6UA;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+T1A=&4O4W!A;BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1A=&4O
M5&EM95IO;F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]$871E+T-A;&,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+T=5
M22](5$U,+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$A056YI="]'54DO2%1-3"YT<&P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N
M:70O1U5)+U-E='5P1&5C;W)A=&]R+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$A056YI="]'54DO1W1K
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O4$A056YI="]297!E871E9%1E<W0N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET
M+U-K96QE=&]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T0V%S92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(
M4%5N:70O5&5S=$1E8V]R871O<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=$9A:6QU
M<F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1,:7-T96YE<BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N
M:70O5&5S=%)E<W5L="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=%-U:71E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$A056YI="]!<W-E<G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]&:6QE+T-35BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T9I
M;&4O571I;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O1&]W;FQO861E<B]086-K86=E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]487-K+U5N:7AE;VPO<G<N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO5VEN
M9&]W<V5O;"]R=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]297!L86-E+W)W+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]487-K+U!O<W1I;G-T86QL<V-R:7!T+W)W+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!
M4B]487-K+T-O;6UO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]0;W-T:6YS=&%L;'-C
M<FEP="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O5&%S:R]297!L86-E+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]4
M87-K+U5N:7AE;VPN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO5VEN9&]W<V5O;"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O5F%L:61A=&]R+U!%0TPN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O
M4&%C:V%G92YP:'`N;W)I9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T)U:6QD+GAM;`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+T)U:6QD+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T-H
M86YN96QS+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T-H86YN96QS+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]#;VUM86YD+T-O;6UO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#;VYF
M:6<N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0V]N9FEG+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#
M;VUM86YD+TEN<W1A;&PN>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O26YS=&%L;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O0V]M;6%N9"]086-K86=E+GAM;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD+U!A8VMA9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4&EC:VQE+GAM;`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+U!I8VML92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]2
M96=I<W1R>2YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]296=I<W1R>2YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+U!%05(O0V]M;6%N9"]296UO=&4N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4F5M
M;W1E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+TUI<G)O<BYX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M0V]M;6%N9"]-:7)R;W(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O5&5S="YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6%N9"]497-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T%U
M=&@N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O075T:"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O4D53
M5"\Q,2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O4D535"\Q,"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O1G)O;G1E
M;F0O0TQ)+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]#;VUM;VXN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+T1A=&$N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN
M<W1A;&QE<B]2;VQE+T1O8RYX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M1&]C+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]%>'0N>&UL"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+TEN<W1A;&QE<B]2;VQE+T5X="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R
M+U)O;&4O4&AP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]0:'`N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-C<FEP="YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M26YS=&%L;&5R+U)O;&4O4V-R:7!T+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O
M4F]L92]3<F,N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-R8RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O26YS=&%L;&5R+U)O;&4O5&5S="YX;6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS
M=&%L;&5R+U)O;&4O5&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M1&%T82YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G
M949I;&4O1V5N97)A=&]R+W8Q+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]0
M87)S97(O=C(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+U!A<G-E<B]V,2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O4&%C:V%G949I;&4O=C(O<G<N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U!A
M8VMA9V5&:6QE+W8R+U9A;&ED871O<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I
M;&4O=C(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8Q+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!
M4B]#:&%N;F5L1FEL92]087)S97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T1O=VYL;V%D97(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]014%2+T5R<F]R4W1A8VLN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T5X8V5P=&EO
M;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U!%05(O1G)O;G1E;F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U!%05(O4F5M;W1E+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O4&%C:V%G949I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U)E9VES=')Y
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O4$5!4B]215-4+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]2=6Y497-T+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]686QI9&%T92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O6$U,4&%R<V5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]"=6EL9&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]!=71O;&]A9&5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]#:&%N;F5L1FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VYF:6<N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+T1E<&5N9&5N8WDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T1E<&5N9&5N8WE$0BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O1&5P96YD96YC>3(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]/4R]'=65S<RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`U+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-
M3%]087)S97(O=&5S=',O,#`S+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O
M=&5S=',O,#`T+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`R
M+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O=&5S=#(N>&UL"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+W1E<W0S+GAM;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M6$U,7U!A<G-E<B]T97-T<R\P,#$N<&AP=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9')I=F5R+W-E='5P+FEN8RYC=G,N;W)I9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9')I=F5R+S`S<VEM<&QE<75E<GDN<&AP=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9')I=F5R+S`T;G5M8V]L<RYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV
M97(O,#5S97%U96YC97,N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R
M+S`V<')E<&5X96,N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`X
M869F96-T961R;W=S+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P
M.6YU;7)O=W,N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$P97)R
M;W)M87`N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$Q=')A;G-A
M8W1I;VYS+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q,VQI;6ET
M+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q-&9E=&-H;6]D95]O
M8FIE8W0N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$U<75O=&4N
M<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$V=&%B;&5I;F9O+G!H
M<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q-W%U97)Y+G!H<'0)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q.&=E="YP:'!T"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M0B]T97-T<R]D<FEV97(O,3EG971L:7-T;V8N<&AP=`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+V-O;FYE8W0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O;6MT86)L92YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]M
M=6QT:6-O;FYE8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<G5N
M+F-V<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+W-E='5P+FEN8RYC=G,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]S:VEP:68N:6YC"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]D<FEV97(O,#%C;VYN96-T+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B\P,F9E=&-H+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S
M+V1B7V9A8W1O<GDN<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9&)?:7-M86YI
M<"YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D8E]E<G)O<C(N<&AP=`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O1$(O=&5S=',O97)R;W)S+FEN8PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9F5T8VAM;V1E7V]B:F5C="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V9E=&-H
M;6]D97,N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]I;F-L=61E+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O1$(O=&5S=',O;&EM:70N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]N
M=6UC;VQS+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O;G5M<F]W<RYI;F,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+W!R97!E>&4N:6YC"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]R=6XN8W9S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]S97%U96YC97,N:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]$0B]T97-T<R]S:6UP;&5Q=65R>2YI;F,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+W1R86YS86-T:6]N<RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+W-K
M:7!I9BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1B7V5R<F]R+G!H<'0)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+V1B7W!A<G-E9'-N+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+VEN8VQU9&4N:6YC+F]R:6<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]33510+W1E
M<W1S+V)A<VEC+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]33510+W1E<W1S+V-O;F9I
M9RYP:'`N9&ES=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T7U--5%`O=&5S=',O<75O=&5D871A
M+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+TYE=%]33510+W1E<W1S+V%U=&@N<&AP=`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O36%I;"]T97-T<R]S;71P7V5R<F]R+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TUA
M:6PO=&5S=',O<F9C.#(R+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O
M=&5S=%]$=6UP+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T97-T<R]E>'1R82UL
M:6YE<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O<')O=&]P;W)T+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O=&5S=',O6$U,7U)00R]T97-T<R]E;7!T>2UV86QU92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+UA-3%]24$,O=&5S=',O='EP97,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?
M4E!#+W1E<W1S+V%L;&=O="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O
M96UP='DM=F%L=64M<W1R=6-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V-O
M;7!O<VET92YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O9&ES<&QA>2YP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R],;V<O=&5S=',O97)R;W)?;&]G+G!H<'0)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S
M+TQO9R]T97-T<R]E>'1R86-T+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]E
M>'1R86-T,BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O9F%C=&]R>2YP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R],;V<O=&5S=',O9FEL92YP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O
M=&5S=',O;&5V96QS+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]N=6QL+G!H
M<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W1E<W1S+TQO9R]T97-T<R]P<FEO<FET>2YP:'!T"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R],;V<O=&5S=',O<VEN9VQE=&]N+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T
M<R]S<6QI=&4N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+W-Q;%]I9&5N="YP
M:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]T97-T<R],;V<O=&5S=',O8V]N<V]L92YP:'!T"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$871E+W1E<W1S+V-A;&,N<&AP+F]R:6<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S
M=',O8G5G-S(W7S(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S<R-U\S
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<W,C=?-"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O8G5G.38W+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T
M<R]C86QC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T97-T=6YI="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S='5N:71?9&%T92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O=&5S='5N:71?9&%T95]S<&%N+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1&%T92]T97-T<R]T97-T7V-A;&,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E
M<W1S+W1E<W1?9&%T95]M971H;V1S7W-P86XN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E
M+W1E<W1S+W=E96MS:6YM;VYT:%\T7VUO;F1A>2YT>'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A
M=&4O=&5S=',O=V5E:W-I;FUO;G1H7S1?<W5N9&%Y+G1X=`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M1&%T92]T97-T<R]W965K<VEN;6]N=&A?<F1M7VUO;F1A>2YT>'0)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O=V5E:W-I;FUO;G1H7W)D;5]S=6YD87DN='AT"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]$871E+W1E<W1S+W=K;F]T97-T+G1X=`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T
M92]T97-T<R]B=6<V-S0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S<R
M-U\Q+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`Q+G!H<'0)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P,BYP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE
M+W1E<W1S+T-35B\P,#(N8W-V"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P
M,#,N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`S+F-S=@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O1FEL92]T97-T<R]#4U8O,#`T+G!H<'0)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O
M=&5S=',O0U-6+S`P-"YC<W8)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P
M-2YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#4N8W-V"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]&:6QE+W1E<W1S+T-35B\P,#8N<&AP=`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T
M97-T<R]#4U8O,#`V+F-S=@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O=&5S
M=',N='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#$N8W-V"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]&:6QE+W1E<W1S+W1E<W0N8W-V"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S
M+T9I;&5497-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]P87)S97(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B](5%10+U)E<75E<W0O3&ES=&5N97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B](5%10+U)E<75E
M<W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]-86EL+VUI;65$96-O9&4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]-86EL+W-E;F1M
M86EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O36%I;"]S;71P+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O36%I;"]21D,X,C(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]-86EL+VUI;65087)T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O36%I;"]M:6UE+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M36%I;"]M86EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O36%I;"]N=6QL+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3F5T+T944"]/
M8G-E<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+TYE="]3;V-K970N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B].970O4TU44"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+TYE="]54DPN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B].970O1E10+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O<&5C;&-M
M9"YP:'`N;W)I9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O36%I;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T9I;&4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O1&%T92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U-Y<W1E;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W!E87)C;60N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W!E87)C;60N<&AP+F]R:6<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W!E8VQC;60N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O9&]C<R]#3U!924Y'"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O9&]C<R]214%$344)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+T-(04Y'15,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+T-/
M1$E.1U]35$%.1$%21%,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]D;V-S+T-/3E1224)55$E.1PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O0U)%1$E44PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O
M8W,O2$%#2TE.1PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+V1O8W,O24Y35$%,3`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O4$521D]234%.0T4)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+U-%
M0U522519"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O9&]C<R]43T1/"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O9&]C<R]44D%.4TQ!5$E/3E,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+U501U)!1$E.
M1PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1E<W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<VEG;G5P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W)P8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V=I;BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]I;F1E>"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A
M9&UI;B]L;V-A;&4O96Y?55,O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]L;V-A;&4O9FE?1DDO
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]A9&UI;B]L;V-A;&4O:'5?2%4O:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]P97)M
M<R]E9&ET+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+V%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+W!E<FUS
M+VEN9&5X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+V%D;6EN+W!E<FUS+V1E;&5T92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]S971U<"]D
M:69F+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+V%D;6EN+W-E='5P+V-O;F9I9RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]S971U<"]I;F1E
M>"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]A9&UI;B]S971U<"]S8W)I<'1S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+W!H<'-H96QL+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+V%D;6EN+VEN9&5X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+V%D;6EN+W5S97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO8VUD<VAE;&PN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O861M:6XO9&%T871R964N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO<V5S<VEO;G,N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO
M<W%L<VAE;&PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O861M:6XO=&5M<&QA=&5S+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+V=R;W5P<RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]J<R]T86)L97,N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]J<R]S=')I<&4N:G,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]H;W)D92YI92YJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+W-O
M<G1E<BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VIS+V9O<FU?:&5L<&5R<RYJ<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+VAT='!C;&EE;G0N:G,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]I
M945S8T=U87)D+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O:G,O9F]R;5]S96-T:6]N<RYJ<PD*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VIS+V5N=&5R7VME>5]T<F%P+FIS"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O:&ED96%B
M;&4N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]J<R]T;V]L=&EP+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O:G,O<&]P=7`N:G,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]F;W)M7V%S<VEG;BYJ
M<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VIS+V%L<&AA26UA9V5,;V%D97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O:&]R9&4N:G,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]O<&5N7V-O
M;&]R<&EC:V5R+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O:G,O:6UA9V4N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]A9&1%=F5N="YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN
M8TU,+T1E=FEC92]3>6YC-&HN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4O4#@P,"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O4WEN8TU,+T1E=FEC92]3>6YT:&5S:7,N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$
M979I8V4O3F]K:6$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+T9I;F%L+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]3>6YC34PO0V]M;6%N9"]0=70N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U)E
M<W5L=',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+TUA<"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,
M+T-O;6UA;F0O4WEN8T5L96UE;G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U-T
M871U<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O06QE<G0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--
M3"]#;VUM86YD+T=E="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O4WEN8RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O4WEN8TU,+U-T871E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO0F%C:V5N9"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M4WEN8TU,+T1E=FEC92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,+U-Y;F,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--
M3"]#;VYS=&%N=',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V5);F9O+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3
M>6YC34PO0V]M;6%N9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O8V]U<FEE<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O1FEL92]01$8O9F]N=',O:&5L=F5T:6-A8FDN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O
M4$1&+V9O;G1S+W1I;65S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]Z87!F9&EN
M9V)A=',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S8BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL
M92]01$8O9F]N=',O=&EM97-I+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV
M971I8V%B+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV971I8V%I+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]&:6QE+U!$1B]F;VYT<R]T:6UE<V)I+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT
M<R]H96QV971I8V$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W-Y;6)O;"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O1FEL92]01$8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O0U-6+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O
M1F]R;6%T=&5R+VAT;6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E>'0O<F535"]087)S97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+U1E>'0O<F535"]&;W)M871T97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9B]296YD97)E
M<B]I;FQI;F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9B]296YD97)E<B]U;FEF:65D+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]497AT+T1I9F8O4F5N9&5R97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O5&5X="]&;&]W960N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9C,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E>'0O
M<F535"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34Q$979);F8N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+UA-3"]70EA-3"]$5$0O4WEN8TU,365T26YF+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]834PO5T)834PO
M1%1$+U-Y;F--3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T-O;G1E;G1(86YD;&5R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]834PO5T)834PO1%1$+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]834PO5T)834PO1%1$36%N86=E
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O6$U,+U="6$U,+T5N8V]D97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$
M96-O9&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]834PO4U9'+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]834PO5T)834PN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V1I<F5C="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&
M4R])4T]7<FET97(O;6MI<V]F<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93
M+T]B:F5C="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O5D93+W-M8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+T=#+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]6
M1E,O<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]61E,O;75S<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R]F='`N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+U9&4R]"<F]W<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O<W%L7V9I;&4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R]F
M:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B]61E,O3&ES=$ET96TN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T)L;V-K+W1I;64N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+T)L;V-K+V=O;V=L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O0FQO8VLO<W5N<FES92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O0FQO8VLO;6]O;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O0FQO8VLO9F]R='5N92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]I9G)A;64N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+T)L;V-K+VUE=&%R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]C;VQO<BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O36]B:6QE+U)E;F1E<F5R+VAT;6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL
M92]296YD97)E<B]W;6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL92]296YD97)E<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O1&%T82]O=71L;V]K8W-V+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$871A
M+W9C87)D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]$871A+W9T;V1O+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$
M871A+W1S=BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]I8V%L96YD87(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T1A=&$O=FYO=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O:6UC+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]$871A+V-S=BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O4&QO="]B87)G<F]U
M<&5D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T+V)A<BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M1W)A<&@O4&QO="]B87)S=&%C:V5D+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T
M+VQI;F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+U!L;W0O<V-A='1E<BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O1W)A<&@O0VAA<G0O<&EE,V0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+T-H
M87)T+W!I92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M1W)O=7`O:&]O:W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+W)G8BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O26UA9V4O<W9G+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]S=V8N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TEM86=E+V=D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]I;2YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O26UA9V4O<&YG+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]097)M<R]522YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O4&5R;7,O9&%T871R964N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+VUY<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]397-S:6]N2&%N9&QE<B]L9&%P+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]397-S
M:6]N2&%N9&QE<B]S87!D8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O
M<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]M96UC86-H92YP:'`)
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(O;V-I."YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O<&=S
M<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+V1B;2YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+V%U9&EO+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O:F%V87-C<FEP="YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+T5V96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O061M:6XN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TE-05`O04-,+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+U-E87)C:"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O24U!4"]4<F5E+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+U1H<F5A
M9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O24U!4"]3;W)T+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T-A
M8VAE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]0<F5F<R]S<6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S
M+U5)+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]0<F5F<R]K;VQA8BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4')E
M9G,O;&1A<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]I
M;7-P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T9O<FTO06-T:6]N+V-O;F1I=&EO;F%L7V5N86)L92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O1F]R;2]!8W1I;VXO<F5L;V%D+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO
M;B]C;VYD:71I;VYA;%]S971V86QU92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I
M;VXO<W5B;6ET+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]U<&1A=&5F:65L
M9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO<W5M7V9I96QD<RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O1F]R;2]!8W1I;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U1O:V5N+V9I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1O:V5N+W-Q
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W1A8FQE7V-E;&QS+GAS
M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O;6%I;E]H=&UL+GAS;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]O;V\O<&%L;2YX<VP)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O;V]O+W-T>6QE7VUA<'!I;F<N>'-L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+V]O;R]G;&]B86Q?9&]C=6UE;G0N>'-L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+V]O;R]T86)L95]R;W=S+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O
M;V\O<W1Y;&5?:6YL:6YE9"YX<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O
M+W1A8FQE7V-O;'5M;G,N>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]C
M;VUM;VXN>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]T86)L92YX<VP)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W-T>6QE7VAE861E<BYX<VP)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O9&5B+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O<&QA:6XN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+V-S<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]M<W=O<F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V1E9F%U;'0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)E<&]R="YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O=V5B8W!P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O<V]U<F-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]T;F5F
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O<&1F+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]O;V\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W-E8W5R:71Y+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%+U9I97=E<B]P:'`N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)I8VAT97AT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]E;G)I8VAE
M9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O<VEM<&QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U!A<G0N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O36%G:6,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O341.
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+VUI;64N;6%P<&EN9RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]M:6UE+FUA9VEC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+WAS<RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O5&5X="]&:6QT97(O8VQE86YA<V-I:2YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X
M="]&:6QT97(O=V]R9',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W)S="YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O5&5X="]&:6QT97(O<W!A8V4R:'1M;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&5X="]&:6QT97(O<VEM<&QE;6%R:W5P+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<B]D:6US:6=N871U<F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+V)B8V]D92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O;&EN:W5R;',N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X
M="]&:6QT97(O96YV:7)O;FUE;G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+VAT;6PR=&5X="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O96UO=&EC;VYS
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]T86)S,G-P86-E<RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O5&5X="]&:6QT97(O=&5X=#)H=&UL+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O5')E92]H=&UL+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]4
M<F5E+W-E;&5C="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5')E92]J879A<V-R:7!T+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S
M+WII<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#
M;VUP<F5S<R]G>FEP+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S<R]T;F5F+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]60R]R8W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+V-V<RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O5D,O<W9N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92].3%,O8V]O<F1I;F%T97,N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TY,4R]C87)S:6=N<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+W1L9"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]$871A5')E92]S<6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&%4
M<F5E+VYU;&PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O96-B+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]#:7!H97(O0FQO8VM-;V1E+V]F8C8T+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]#:7!H97(O0FQO8VM-;V1E+V-F8C8T+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O
M0FQO8VM-;V1E+V-B8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+V)L;W=F:7-H+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]#:7!H97(O0FQO8VM-;V1E+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H
M97(O9&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O8V%S=#$R."YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O0VEP:&5R+W)C,BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+W)C-"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O4E!#+W)E<W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U)00R]W96)D878N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S>6YC;6Q?=V)X
M;6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U)00R]S>6YC;6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S
M;V%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]344PO071T<FEB=71E<RYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M4U%,+TME>7=O<F1S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]"<F]W<V5R+VEM;V1E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]%9&ET;W(O:'1M;&%R96$N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-A8VAE+V9I
M;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-A8VAE+WIP<S0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]6:65W+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O0FQO8VLO54DN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]!=71H+VEP8F%S:6,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@O:7!M87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<V%S;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"]C;VUP;W-I=&4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O
M875T;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O075T:"]H='1P+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H
M+W-M8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]C=7-T;VUS<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:V]L86(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T%U=&@O<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VMR8C4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T%U=&@O;6-A;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]F='`N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T%U=&@O:6UA<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T%U=&@O>6%H;V\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<&%M+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]!=71H+VEM<W`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]!=71H+V%P<&QI8V%T:6]N+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L
M96YD87(O=FYO=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V:F]U<FYA;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9T;V1O+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L
M96YD87(O=F5V96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=G1I;65Z;VYE
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]I0V%L96YD87(O=F9R965B=7-Y+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]I0V%L96YD87(O=F%L87)M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=F-A
M<F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-C:&5D=6QE<B]C<F]N+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]522]687)296YD97)E
M<B]T86)L97-E=%]H=&UL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]522]7:61G970N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U5)+U1A8G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+TQA;F=U86=E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]522]687)296YD97)E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O54DO4&%G97(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TAE;'`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U5T:6PN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U-C:&5D=6QE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O161I=&]R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]-96YU+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]4<F5E+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]397)I86QI
M>F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T1A=&$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&4N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U-E8W)E="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0TQ)+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#
M86-H92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O4')E9G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TAI<W1O<GDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O2V]L86(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&%4<F5E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]097)M<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O36]B:6QE+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]24$,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-H87)E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!<G)A>2YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&]K96XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L
M96YD87(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E;7!L871E+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]60RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O1W)A<&@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-13"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O4W1R:6YG+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U9A<FEA8FQE<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0V]N9FEG+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]'<F]U<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]296=I
M<W1R>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O0W)Y<'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92],1$%0+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92])9&5N=&ET>2YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M4V5S<VEO;D]B:F5C=',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T)R;W=S97(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TYE="])35-0+T%U=&@O:6UT97-T+G!H<`ER;V]T('=H965L
M(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U3
M4"]!=71H+V-R86U?;60U+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H+W!L86EN=&5X
M="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O3F5T+TE-4U`O0F]O:RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O571I;',N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TYE="])35-0+T]P=&EO;G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="])35-0+T%U=&@N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TYE="]335,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="])35-0+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]B87-E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]497-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O<')E9G,N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y
M;F--3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O+FAT86-C97-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+W9E<G-I;VXN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+V-O<F4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+U9&4RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O87!I+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]K;5]+2"],0U]-15-3
M04=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQO8V%L92]A<E]362],0U]-15-304=%4R]H;W)D92YM
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQO8V%L92]C85]%4R],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]B<U]"
M02],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]D85]$2R],0U]-15-304=%
M4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQO8V%L92]D85]$2R]H96QP+GAM;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]D95]$12],
M0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]D95]$12]H96QP+GAM;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L
M92]C<U]#6B],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]C<U]#6B]H96QP
M+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQO8V%L92]E;%]'4B],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]E
M;%]'4B]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQO8V%L92]F85])4B],0U]-15-304=%4R]H;W)D92YM
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQO8V%L92]F85])4B]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]E;E]54R]H96QP+GAM;`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO
M8V%L92]E<U]%4R],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]E<U]%4R]H
M96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQO8V%L92]F:5]&22],0U]-15-304=%4R]H;W)D92YM;PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L
M92]F:5]&22]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]E=%]%12],0U]-15-304=%4R]H;W)D
M92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQO8V%L92]E=%]%12]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]F<E]&4B],0U]-15-3
M04=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQO8V%L92]F<E]&4B]H96QP+GAM;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]G;%]%
M4R],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]H95])3"],0U]-15-304=%
M4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQO8V%L92]I9%])1"],0U]-15-304=%4R]H;W)D92YM;PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO
M8V%L92]H=5](52],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]H=5](52]H
M96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQO8V%L92]J85]*4"],0U]-15-304=%4R]H;W)D92YM;PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L
M92]J85]*4"]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]I<U])4R],0U]-15-304=%4R]H;W)D
M92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQO8V%L92]I=%])5"],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]I
M=%])5"]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQO8V%L92]B9U]"1R],0U]-15-304=%4R]H;W)D92YM
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQO8V%L92]B9U]"1R]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]K;U]+4B],0U]-15-304=%
M4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQO8V%L92]K;U]+4B]H96QP+GAM;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]L=%],5"],
M0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]L=%],5"]H96QP+GAM;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L
M92]M:U]-2R],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]L=E],5B],0U]-
M15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]N8E].3R],0U]-15-304=%4R]H;W)D
M92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQO8V%L92]N8E].3R]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]N;%].3"],0U]-15-3
M04=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQO8V%L92]N;%].3"]H96QP+GAM;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]N;E].
M3R],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]N;E].3R]H96QP+GAM;`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO
M8V%L92]P;%]03"],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]P;%]03"]H
M96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQO8V%L92]P=%]"4B],0U]-15-304=%4R]H;W)D92YM;PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L
M92]P=%]"4B]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]P=%]05"],0U]-15-304=%4R]H;W)D
M92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQO8V%L92]P=%]05"]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]R;U]23R],0U]-15-3
M04=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQO8V%L92]R=5]252],0U]-15-304=%4R]H;W)D92YM
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQO8V%L92]R=5]252]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]S:U]32R],0U]-15-304=%
M4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQO8V%L92]S:U]32R]H96QP+GAM;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]S;%]322],
M0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]S;%]322]H96QP+GAM;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L
M92]S=E]312],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]S=E]312]H96QP
M+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQO8V%L92]T<E]44B],0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]T
M<E]44B]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQO8V%L92]U:U]502],0U]-15-304=%4R]H;W)D92YM
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQO8V%L92]U:U]502]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]Z:%]#3B],0U]-15-304=%
M4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQO8V%L92]Z:%]#3B]H96QP+GAM;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]Z:%]45R],
M0U]-15-304=%4R]H;W)D92YM;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L92]Z:%]45R]H96QP+GAM;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQO8V%L
M92\N:'1A8V-E<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P;R]F85])4BYP;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V5S7T53+G!O"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O>FA?0TXN<&\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M;R]Z:%]45RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!O+VAU7TA5+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O9FE?1DDN<&\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]E=%]%12YP;PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O
M+U)%041-10ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!O+W)U7U)5+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&\O9VQ?15,N<&\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]C85]%4RYP;PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V)S
M7T)!+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&\O:61?240N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P;R]R;U]23RYP;PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+W-K7U-++G!O"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O+FAT
M86-C97-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&\O;'1?3%0N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P;R]D95]$12YP;PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+VYL7TY,+G!O"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O:F%?
M2E`N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P;R]T<F%N<VQA=&EO;BYP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]I<U])4RYP;PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+W-L7U-)+G!O
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&\O8F=?0D<N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P;R]F<E]&4BYP;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V%R7U-9+G!O"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O=6M?54$N<&\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M;R]I=%])5"YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!O+VAO<F1E+G!O=`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+VUK7TU++G!O"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O;'9?3%8N<&\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M;R]N;E].3RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!O+W!L7U!,+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O:VU?2T@N<&\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]H95])3"YP;PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O
M+V1A7T1++G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&\O8W-?0UHN<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P;R]P=%]"4BYP;PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+W!T7U!4+G!O"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O
M;F)?3D\N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P;R]S=E]312YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!O+W1R7U12+G!O"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O96Q?1U(N<&\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]K
M;U]+4BYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O;&1A<"]H;W)D92YS8VAE;6$)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A
M9&5S+VUO=F5?:&ES=&]R>5]O=71?;V9?9&%T871R964N<&AP"7)O;W0@=VAE
M96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]U
M<&=R861E<R\R,#`V+3`V+3(Y7VAO<F1E7W!R969S7VEN9&5X97,N<W%L"0HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R
M+C)?=&]?,RXP+G!G<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,BXR7W1O7S,N
M,"YM>7-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(N,E]T;U\S+C`N;V-I."YS
M<6P)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A
M9&5S+S,N,%]T;U\S+C$N;7ES<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?
M=&]?,RXQ+F]C:3@N<W%L"0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V-R:7!T<R]U<&=R861E<R\R,#`U+3`Y+3(R7VAO<F1E7W!R969S7W9A<F-H
M87(R+F]C:3@N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?,RXQ+G-Q;`D*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T
M92YO8VDX+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YM>7-Q;"YS<6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS<6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A
M=&4N;7-D92YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]214%$344)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]S8W)I
M<'0N:6YI=&EA;%]H;W)D95]U<V5R+G-Q;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VAI
M<W1O<FEE<RYM<W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N<W%L"0HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+GAM
M;`D*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7W-E<W-I;VYH86YD;&5R+G!G<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7V1A=&%T<F5E+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R
M+FUY<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E+FUS<W%L+G-Q
M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7VUU=F9S+G-Q;`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7W9F<RYP9W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]L;V<N<W%L"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T
M<R]S<6PO4D5!1$U%+D]#23@)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]U<V5R<RYS<6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]H:7-T;W)I97,N<W%L"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?<V5S<VEO;FAA;F1L97(N;V-I."YS<6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]V
M9G,N;V-I."YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]P<F5F<RYM<W-Q;"YS<6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]T;VME;G,N<W%L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M<V5S<VEO;FAA;F1L97(N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;&]G
M+FUS<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-A
M<&1B+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VUU=F9S+FUS<W%L+G-Q;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP
M=',O<W%L+V-R96%T92YS>6)A<V4N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=F9S
M+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYM<W-Q;"YS<6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q
M;"]H;W)D95]P<F5F<RYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A=')E92YM
M>7-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N<&=S<6PN<W%L"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]C
M<F]N9`ER;V]T('=H965L(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-C<FEP=',O=&AE;65S7V-H96-K+G!H<`ER;V]T('=H965L(#`W-34*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O8V]U;G1?<V5S
M<VEO;G,N<&AP"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V-R:7!T<R\N:'1A8V-E<W,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+VAT='!?;&]G:6Y?
M<F5F97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V-R:7!T<R]M:6=R871E7W5S97)?8V%T96=O<FEE<RYP:'`)
M<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W)E;6]V95]P<F5F<RYP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-E='5P+G!H<`ER;V]T
M('=H965L(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP
M=',O=&5M<"UC;&5A;G5P+F-R;VX)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-E=%]P97)M<RYS:`ER;V]T
M('=H965L(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP
M=',O8W)E871E+7-Y;6QI;FMS+G!H<`ER;V]T('=H965L(#`W-34*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O8V]O:VEE7VQO9VEN+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-C<FEP=',O4T-225!44PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O9V5T7VQO9VEN+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]L86YG+V5N+FIS"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+W!L=6=I;G,O06YS96Q);6%G92]L86YG+V5N+FIS"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS96Q);6%G92]A;G-E;"UI;6%G
M92YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA
M9V4O:6YS97)T7VEM86=E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+T%N<V5L26UA9V4O<VAO=VEM86=E+FAT;6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT97AT365N=2]L86YG+V5N+FIS"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O0V]N=&5X=$UE;G4O;65N
M=2YC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT97AT
M365N=2]C;VYT97AT+6UE;G4N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM9&5L971E+F=I9@ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N
M<R]I;6<O8V]L+7-P;&ET+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V5L;"UM97)G92YG:68)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O
M:6UG+W)O=RUI;G-E<G0M86)O=F4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M9&5L971E+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T
M:6]N<R]I;6<O8V5L;"UI;G-E<G0M8F5F;W)E+F=I9@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V5L;"UI
M;G-E<G0M869T97(N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+7-P;&ET+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O
M8V]L+6EN<V5R="UA9G1E<BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-O;"UI;G-E<G0M8F5F;W)E
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E
M<F%T:6]N<R]I;6<O<F]W+7!R;W`N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C;VPM9&5L971E+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T
M:6]N<R]I;6<O8V5L;"UP<F]P+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O=&%B;&4M<')O<"YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+W)O=RUS<&QI="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+W)O=RUI;G-E<G0M=6YD97(N
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+VQA;F<O96XN:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]486)L94]P97)A=&EO;G,O=&%B;&4M;W!E<F%T:6]N<RYJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+TQI<W14>7!E+VQA;F<O96XN
M:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R],:7-T5'EP92]L
M:7-T+71Y<&4N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+V9U
M;&QS8W)E96XN:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O
M<&]P=7`N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+V%B;W5T
M+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+W-E;&5C=%]C
M;VQO<BYH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]I;G-E
M<G1?=&%B;&4N:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O
M;&EN:RYH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]B;&%N
M:RYH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]I;G-E<G1?
M:6UA9V4N:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?
M86QI9VY?;&5F="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7VMI;&QW;W)D+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?8W5S=&]M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?8FQA;FLN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]E9%]I;F1E;G1?;&5S<RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7VEN9&5N=%]M;W)E+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?86QI9VY?:G5S=&EF>2YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]I=&%L:6,N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C:&%R;6%P+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O9G5L;'-C<F5E;E]M:6YI;6EZ
M92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W!A<W1E
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8W5T+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?<VAO=U]B;W)D
M97(N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]R961O
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?;&EN:RYG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VAE;'`N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?8F]L
M9"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VQE9G1?
M=&]?<FEG:'0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E
M9%]U;F1O+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?
M9F]R;6%T7W-U8BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+VEN<V5R=%]T86)L92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7V9O<FUA=%]S=7`N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]I;6%G92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7VAR+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?<FEG:'1?=&]?;&5F="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7VAT;6PN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]S879E+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I
M;6%G97,O961?9F]R;6%T7W-T<FEK92YG:68)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:6UA9V5S+V5D7V1E;&5T92YG:68)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:6UA9V5S+V5D7V-O;&]R7V)G+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?86)O=70N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]E9%]L:7-T7V)U;&QE="YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-O;&]R7V9G+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?86QI9VY?<FEG:'0N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?=6YD97)L:6YE
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O9G5L;'-C<F5E
M;E]M87AI;6EZ92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7W)M9F]R;6%T+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?86QI9VY?8V5N=&5R+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?8V]P>2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7VQI<W1?;G5M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?<W!L:71C96PN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+V1I86QO9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<'=I
M;BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<&1I=BYJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]H=&UL87)E82YJ<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]H=&UL87)E82YC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO961I="YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O9&]W;FQO860O:6YD97@N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+VEM86=E<R]P:7AE;"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]I;6%G97,O=FEE=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]H96QP+VEN9&5X+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+VQA;F=U86=E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+VIA=F%S8W)I<'0N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O:V5Y8F]A<F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O8V%C:&5V:65W+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O<')E9G,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O9V\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O<')O8FQE;2YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP
M;&%T97,O:&5L<"]M96YU+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]H96QP+VEN9&5X+FEN8PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E
M;7!L871E<R]H96QP+V%B;W5T+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]M96YU+VUE;G4N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&5M<&QA=&5S+W1E<W0O=F5R<VEO;BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]P:'!?
M=F5R<VEO;BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]E>'1E;G-I;VYS+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L
M871E<R]T97-T+V9O;W1E<BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]H96%D97(N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T
M97,O861M:6XO=7-E<B]A9&0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A
M9&UI;B]S971U<"]C;VYF:6<N:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]S971U<"]D
M:69F+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E
M<BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O:6YD97@O9G)A;65S7VEN9&5X+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E
M<R]S:&%R97,O961I="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O;75L=&EE;G5M+FEN
M8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W!R969S+W!A<W-W;W)D+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&5M<&QA=&5S+W!R969S+V]V97)V:65W+FEN8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]S
M96QE8W0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+W1E>'0N:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R
M969S+VYU;6)E<BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&5M<&QA=&5S+W!R969S+W1E>'1A<F5A+FEN8PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F
M<R]C:&5C:V)O>"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O96YU;2YI;F,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T
M97,O<')E9G,O8F5G:6XN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V%P<"YI;F,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP
M;&%T97,O<')E9G,O;&EN:RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP
M;&%T97,O9&%T82]D871E+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]D871A+W1I;64N:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]D871E=&EM
M92YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O8V]N=&5N=',O;W!E;E]V:65W7W=I;BYJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V=O;V=L95]W:6XN:G,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O=')E92YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7VAT;6Q?:&5L<&5R+FIS"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VME
M>6)I;F1I;F=S+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO961I="YI;F,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O
M<G1A;"]B;&]C:RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]C;VUM;VXM9F]O
M=&5R+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1E;7!L871E<R]C;VUM;VXM:&5A9&5R+FEN8PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R\N
M:'1A8V-E<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9V5N;F5V:6QL:65R<R]I;F9O+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M96YN979I;&QI97)S+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O87IU<B]I;F9O+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]A>G5R+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)E>2]I;F9O+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F5Y+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O3F585&=R97DO:6YF;RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O3F585&=R97DO<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+V=R87!H
M:6-S+W1A8E]B;W1T;VTN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O9W)A<&AI8W,O
M=&%B7W)I9VAT+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+V=R87!H:6-S+W1A8E]L
M969T+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+VEN9F\N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V-O<FYF
M;&]W97(O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B<F]W;B]I;F9O+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B
M<F]W;B]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R965N+VEN9F\N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M965N+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O8F%C:V=R;W5N
M9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O;65N=5]T;W`N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+VED96%S+V=R87!H:6-S+VQE9G1?;65N=5]T;W`N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VED96%S
M+V=R87!H:6-S+VQE9G1?;65N=5]B;W1T;VTN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VED96%S+VEN
M9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+VED96%S+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O:V]L86(O9W)A
M<&AI8W,O:V]L86(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+V=R87!H:6-S+V)G+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]K;VQA8B]G<F%P:&EC<R]K;VQA8FQO9V\N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VMO;&%B
M+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+VMO;&%B+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;&%V86YD
M97(O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O;&%V86YD97(O<V-R965N+F-S<PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]Z=RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86PN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)A+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]A;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F(N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V%N+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]A;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F0N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V)E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B9BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F<N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V%R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B:"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8FDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V%T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B:BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O874N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-A+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A=RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O8FTN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)N+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]B;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M87HN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-F+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]C9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G(N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V-H+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]B<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VDN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V)T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C
M:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VPN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V)W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C;2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V)Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C;RYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O8GHN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V1E
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C<BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O8W4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V1K+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]C=BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O96,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-Y+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]C>BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O964N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5G+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]D>BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O97(N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V5S+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]F:2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O970N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V9J+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G82YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9F\N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V=E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]F<BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O9VDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V=L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G<"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O9W(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=T+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G=2YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O:&LN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=Y+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]I9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M:64N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VAR+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]H="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'4N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VEL+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:7$N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VER+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I
M<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:70N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VIM+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]J;RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O:V4N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VIP+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K9RYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O:V@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMI
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L8BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;&,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMP+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]K<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O;&LN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUA+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]M8RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:WDN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUD+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]K>BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6<N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VQT+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]L=2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;'8N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VYA+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M;BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;F,N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+VQY+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M;RYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O;7`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VYF+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M<RYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O;70N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYL+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M>"YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O;7DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYO+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]M>BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M;G`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYR+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]P82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;VTN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VYZ+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]P92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&8N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W!H+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P
M:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&PN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W%A+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P;2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O<'(N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W!T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P>2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O<V$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-B
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]R;RYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O<V0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-E+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]S9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O<VDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W)U+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]S:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<VPN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1C+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]S;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&<N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+W-R+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]T:"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=6$N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W1N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S>2YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&\N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W1P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]U9RYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O='(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W1T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]U:RYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O='8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9A+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T=RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O='HN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9E+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]V9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M=7,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9I+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]V;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=7DN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W=S+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]Y92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O>F$N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+WEU+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A
M9BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]M<V5X8V5L+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+V]O;U]W<FET97(N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI
M;64O=FED96\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O>&UL+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]M:6UE+V]O;U]I;7!R97-S+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]M:6UE+W-O=7)C92UP>71H;VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M;7-P;W=E<G!O:6YT+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VUS=V]R9"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6EM92]B:6YA<GDN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O:'1M;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]V8V%R9"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?9')A=RYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O;6EM92]R<&TN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;V]O7V-A
M;&,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O96YC<GEP=&EO;BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;6EM92]O;V]?;6%T:"YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;6EM92]M86EL+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V%U9&EO+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]M:6UE+V-O;7!R97-S960N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O=&5X="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M
M8RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M:"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]S;W5R8V4M:F%V82YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;6EM92]I;6%G92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M8W!P
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VEC86QE;F1A<BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]P9&8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<&AP
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-C<FEP="UJ<RYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]D96(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO
M;VXO9G5L;&UO;VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO;&%S
M='%U87)T97(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO;F5W;6]O
M;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]F:7)S='%U87)T97(N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M-#<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R
M,W@R,R\R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,C-X,C,O-"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\R,W@R,R\U+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+SDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O;F$N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3$N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3(N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3,N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,30N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,34N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,38N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M,3<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,3@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O,3DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,C-X,C,O,C`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,C-X,C,O,C$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O,C(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,C,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,C0N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C4N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C8N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C<N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C@N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,CDN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S`N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S$N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M,S(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,S,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O,S0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,C-X,C,O,S4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,C-X,C,O,S8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O,S<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,S@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,SDN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#$N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#(N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#,N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#0N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#4N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#8N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\T-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O,RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O-BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O.2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B]N82YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B]45T-L;V=O7S,R<'@N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3`N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3$N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,3(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X
M,S(O,3,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O,30N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O,34N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O,38N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O,3<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O,3@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O,3DN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C$N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C(N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C,N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C0N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C4N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C8N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,C<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X
M,S(O,C@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O,CDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O,S`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O,S$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O,S(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O,S,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O,S0N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S4N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S8N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S<N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S@N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,SDN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#`N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#$N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M-#(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X
M,S(O-#,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O-#0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O-#4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O-#8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO<W5N
M<FES92]S=6YR:7-E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]S=6YR:7-E
M+W-U;G-E="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?;&5F="YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&5F="YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO9&]W;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?
M<FEG:'0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W5P+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]L87)G95]U<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO;&%R9V5?9&]W;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO<FEG:'0N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;&EN=7@N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O9G)A;F,N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O9&5V:6PN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;&ES82YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]E;&UE<F9U9&0N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O9V%R9FEE;&0N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O<F5I+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=R;W9E<BYJ
M<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]P=69F+FIP9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+W1R:6XN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M:VED+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUA<F=E+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+W!I8V%R9"YJ<&<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]F96UA;&4Q+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9E
M;6%L93(N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;6%L93$N:G!G"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O;6%L93(N:G!G"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O9&]G+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-Y;'9E
M<W1E<BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;6EL97DN9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O9&EN;RYG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]B<F5T+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=I;FYI
M92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]E;&UO+FIP9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V=R965N:&5A9"YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]T:6=G97(N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F]Y
M86YD;6]W97(N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:F5R:2YJ<&<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]T:&]M87,N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O8F]B869E='0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O;6%N+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VAU;7`N:G!G"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O<VUU<F9S+F=I9@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+W)Y=2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]A;F=R
M>6)O>2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B97)T,BYJ<&<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]D:6=I;6]N+F=I9@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+VUI8BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]V86UP
M:7)E,BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]A=2YJ<&<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]K:7)K+FIP9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W)E9&-R96%T=7)E+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-O
M;FEC+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)U;FYY+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+W=O;6%N+FIP9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V9R961F;&EN<W1O;F4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O<&%I;G1I;F=B:7)D+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)E
M<G0N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:6-E<VMA=&5K:60N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O;F5O+FIP9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+VUA=6PN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V]L
M=F5R:6YE+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V%L:65N+FIP9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W-P965D>2YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]B87)B87)I86XN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O;6]N:V5Y+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5V:6PN:G!G
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F]Y86YD<&,N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O>&5N82YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]V86UP:7)E+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-T86XN:G!G
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O=7,N:G!G"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O8V]C:WDN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F%B
M>2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W:7IA<F0N:G!G"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O86QY+FIP9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V-H87)L:65?8G)O=VXN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M87!E+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUE;&]N+FIP9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+W=O;V1I92YJ<&<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]W86-K;RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]C;&]W
M;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D=6-K+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V5I;G-T96EN+FIP9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V)A=&UA;BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S97AY
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VQO=F5B:7)D+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+V)O;RYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]H;VUE<BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B87)T+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VYI;FIA+FIP9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+W-U<&5R;6%N+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V1I;&)E<G0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<F5I,BYJ
M<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G<F5M;&EN+FIP9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V=O<&AE<BYG:68)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]K<GET;VXN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A;F=E
M;'=I;FLN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W:6YK=&]N9W5E
M;W5T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O9&5V:6PN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]R87-P8F5R<GDN<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V5M;W1I8V]N<R]B;'5S:"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO
M=&EC;VYS+V5M8F%R<F%S<V5D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O<'5N:VUO:&%W:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V9R
M=7-T<F%T960N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]C;VYF=7-E
M9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAI<'!I971O;F=U92YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V1A>F5D+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O<V%D+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O9G)O=VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]C;V]L
M9W)I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W!U;FLN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]G<FEN+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O;6%D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O
M9&5V:6QT;VYG=64N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]P=6YK
M=&]N9W5E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]O;'1O;F=U
M92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V)I9V=R:6XN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H=7)T+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O86YG96PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]C;V]L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;7)T+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<VUI;&4N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]S:&]U="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+V%N;F]Y960N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W:6YK
M=&]N9W5E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O86YG<GDN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W:6YK+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O=F%M<&ER92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO
M=&EC;VYS+VAA;F=O=F5R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O
M8FEG9G)O=VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W:6YK9W)I
M;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAI<'!I96=R:6XN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]T;VYG=65O=70N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]C;&]W;BYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M96UO=&EC;VYS+VEN9&EF9F5R96YT+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O9&ES87!P;VEN=&5D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O=V]R<FEE9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V%S;&5E
M<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V5N<F%G960N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]L;W9E+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O=&ER960N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]H:7!P:64N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92]D:7-P;&%Y+FIP
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O<FEG:'0N:G!G"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUO8FEL92]L969T+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O=&]P
M+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O8F]T=&]M+FIP9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A;&5R=',O=V%R;FEN9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE
M<G1S+VUE<W-A9V4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T<R]S=6-C97-S
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A;&5R=',O97)R;W(N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VEM86=E+V%R<F]W+61O=VXN9VEF"0HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+W)A=&EO+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]I;6%G92]R;W1A=&4M,3@P+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]I;6%G92]R;W1A=&4M,C<P+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G
M92]F;&EP+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]M:7)R;W(N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VEM86=E+V=R87ES8V%L92YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O:6UA9V4O8W)O<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E
M+3DP+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R969R97-H+F=I9@D*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G
M92]A<G)O=RUU<"YG:68)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O:6UA9V4O<F5F<F5S:"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=')E92]R978M:F]I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]P;'5S
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+V9O;&1E<F]P96XN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W1R964O8FQA;FLN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O
M<&QU<V)O='1O;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;6EN=7-O
M;FQY+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUJ;VEN8F]T=&]M+61O
M=VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O;&5A9BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]J;VEN8F]T=&]M+61O=VXN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O<F5V+7!L=7-O;FQY+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VYU
M;&QO;FQY+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VIO:6YB;W1T;VTN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6QI;F4N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+W1R964O<F5V+6UI;G5S8F]T=&]M+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T
M<F5E+W)E=BUP;'5S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP;'5S
M8F]T=&]M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VUI;G5S+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]T<F5E+VUI;G5S=&]P+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T
M<F5E+VUI;G5S;VYL>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]J;VEN+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]T<F5E+VUI;G5S8F]T=&]M+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]T<F5E+W)E=BUL96%F+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E
M+W)E=BUJ;VEN8F]T=&]M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+V9O;&1E
M<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;G5L;&]N;'DN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O<F5V+6UI;G5S+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]T<F5E+W!L=7-O;FQY+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP
M;'5S=&]P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU<W1O<"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O=')E92]L:6YE+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]T<F5E+W!L=7-T;W`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]B;W1T;VTN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VYA=B]D;W=N+6=R97DN<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VYA=B]L87-T+6=R97DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]L
M969T+6=R97DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]D;W=N+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]N878O9FER<W0M9W)E>2YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;F%V+W)I9VAT+6=R97DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]R:6=H="YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;F%V+VQE9G0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VYA=B]B;W1T;VTM9W)E>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W1O<"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;F%V+W5P+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N
M878O=7`M9W)E>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W1O<"UG<F5Y+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]N878O;&%S="YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;F%V+V9I<G-T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C86QE;F1A<BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O=&%B7V)O='1O;2YG:68)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<')E
M9G,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUA<"YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;W)G86YI>FEN9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;&]G:6XN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VQH86YD+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S<6PN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V-O;F9I9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<&5R;7,N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%Z+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]U;FQO
M8VME9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&ED95]P86YE;"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9&5L971E+7-M86QL+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P<F]B
M;&5M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C;VQO<G-C86QE+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M>6%C8V]U;G0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H861O=RYG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O<VAA9&]W+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C
M;VQO<G!I8VME<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<F5L;V%D+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]H;W)D92UP;W=E<C$N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAO
M<F1E+7!O=V5R,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<VAO=U]P86YE;"YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O:&]R9&4M<&]W97(S+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]H96QP7VEN9&5X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O<V5A<F-H+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]G<F]U<"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8VQO<V4N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+WIA
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]L;V-K960N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V1E;&5T92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=7-E<BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O:6YF;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;&%Y;W5T+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]R:&%N9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;V9F:6-E+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]D871A=')E92YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M961I="US;6%L;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<F5Q=6ER960N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VEN9F]?:6-O;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9&]W
M;FQO860N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQO9V]U="YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1E=F5L+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]W96)S:71E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P<FEN="YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O:&5L<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<VAE
M;&PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5D:70N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VME>6)O87)D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F879I8V]N+FEC;PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&%N:RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9&%T82YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O861M:6YI<W1R871I;VXN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUA<%]E=2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9V]O9VQE+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]S879E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]P<FEN="]S8W)E96XN8W-S"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+VAI+6-O;G1R87-T+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VAI+6-O;G1R87-T+W-C
M<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O8FQU97=H:71E+VEN9F\N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)L=65W
M:&ET92]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+W-I;7!L97@O9W)A<&AI8W,O8F%C:V=R
M;W5N9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O<VEM<&QE>"]I;F9O+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X
M+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O8V%M;W5F;&%G92]G<F%P:&EC<R]M96YU+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]C86UO=69L86=E+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O
M<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O=&%B7V)O='1O;2YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O;'5C+V=R87!H:6-S+W1A8E]R:6=H="YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;'5C+V=R
M87!H:6-S+W1A8E]L969T+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O8W5R<F5N
M=%1A8E]R:6=H="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H:6-S+V-U<G)E;G1486)?
M;&5F="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O;'5C+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQU8R]S8W)E96XN
M8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+VQU8V)L=64O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;'5C8FQU92]S8W)E
M96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+W!O<W1N=6ME+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+W!O<W1N=6ME
M+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O8F%R8FEE+VEN9F\N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)A<F)I
M92]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O;65N=2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O;6]Z:6QL82]G<F%P:&EC<R]M96YU+6%C=&EV92YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M;6]Z:6QL82]G<F%P:&EC<R]H96%D97(N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O:6YF
M;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O;6]Z:6QL82]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)L=65M;V]N
M+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V)L=65M;V]N+W-C<F5E;BYC<W,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;&EG
M:'1B;'5E+V=R87!H:6-S+VUE;G4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU92]I;F9O
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]L:6=H=&)L=64O<V-R965N+F-S<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]M;V)I;&4O
M<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]P=7)P;&4O:6YF;RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<'5R<&QE
M+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O8G5R;G1O<F%N9V4O:6YF;RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M8G5R;G1O<F%N9V4O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]R=&PN8W-S"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VEE
M-6UA8RYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O;6]Z,30N8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V]P97)A+F-S<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]S869A<FDN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O:64V7V]R7VQE
M<W,N8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=71I;"]I8V]N7V)R;W=S97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=71I;"]B87)C;V1E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W5T
M:6PO<F5G97A?=&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+V5T8R]P<V$M:&]R9&4O:&]R9&4O8V]N9BYP:'`)<F]O="!W:&5E
M;"`P-#0T"B1[4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M:&]R9&4O:&]R9&4O
M;6EM95]D<FEV97)S+G!H<`ER;V]T('=H965L(#`T-#0*)'M04D]$54-47U)/
M3U1?1'TO971C+W!S82UH;W)D92]H;W)D92]M;W1D+G!H<`ER;V]T('=H965L
M(#`T-#0*)'M04D]$54-47U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D92]N
M;',N<&AP"7)O;W0@=VAE96P@,#0T-`HD>U!23T150U1?4D]/5%]$?2]E=&,O
M<'-A+6AO<F1E+VAO<F1E+W!R969S+G!H<`ER;V]T('=H965L(#`T-#0*)'M0
M4D]$54-47U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D92]R96=I<W1R>2YP
M:'`)<F]O="!W:&5E;"`P-#0T"B1[4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M
M:&]R9&4O:&]R9&4O:&]O:W,N<&AP"7)O;W0@=VAE96P@,#0T-`HD>U!23T15
M0U1?4D]/5%]$?2]E=&,O<'-A+6AO<F1E+VAO<F1E+V-O;F8N>&UL"7)O;W0@
M=VAE96P@,#0T-`HD>U!23T150U1?4D]/5%]$?2]E=&,O<'-A+6AO<F1E+VAO
M<F1E+RYH=&%C8V5S<PER;V]T('=H965L(#`T-#0*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
`
end
